Index: libgomp/ChangeLog
===================================================================
--- libgomp/ChangeLog	(.../tags/gcc_8_2_0_release)
+++ libgomp/ChangeLog	(.../branches/gcc-8-branch)
@@ -1,3 +1,19 @@
+2018-07-26  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from mainline
+	2018-07-17  Jakub Jelinek  <jakub@redhat.com>
+
+	PR middle-end/86542
+	* testsuite/libgomp.c++/pr86542.C: New test.
+
+	PR middle-end/86539
+	* testsuite/libgomp.c++/pr86539.C: New test.
+
+2018-07-26  Jakub Jelinek  <jakub@redhat.com>
+
+	PR middle-end/86660
+	* testsuite/libgomp.c/pr86660.c: New test.
+
 2018-07-26  Release Manager
 
 	* GCC 8.2.0 released.
Index: libgomp/testsuite/libgomp.c++/pr86542.C
===================================================================
--- libgomp/testsuite/libgomp.c++/pr86542.C	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ libgomp/testsuite/libgomp.c++/pr86542.C	(.../branches/gcc-8-branch)
@@ -0,0 +1,37 @@
+// PR middle-end/86542
+
+struct S { int s; S (); ~S (); S (const S &); };
+S s;
+
+S::S ()
+{
+}
+
+S::~S ()
+{
+}
+
+S::S (const S &x)
+{
+  s = x.s;
+}
+
+__attribute__((noipa)) void
+foo (int i, int j, int k, S s)
+{
+  if (i != 0 || j != 0 || k != 0 || s.s != 12)
+    __builtin_abort ();
+}
+
+int
+main ()
+{
+  volatile int inc = 16, jnc = 16, knc = 16;
+  s.s = 12;
+  #pragma omp taskloop collapse (3) firstprivate (s)
+  for (int i = 0; i < 16; i += inc)
+    for (int j = 0; j < 16; j += jnc)
+      for (int k = 0; k < 16; k += knc)
+	foo (i, j, k, s);
+  return 0;
+}
Index: libgomp/testsuite/libgomp.c++/pr86539.C
===================================================================
--- libgomp/testsuite/libgomp.c++/pr86539.C	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ libgomp/testsuite/libgomp.c++/pr86539.C	(.../branches/gcc-8-branch)
@@ -0,0 +1,28 @@
+// PR middle-end/86539
+
+int a[384];
+
+__attribute__((noipa)) void
+foo (int &b, int &c)
+{
+  #pragma omp taskloop shared (a) collapse(3)
+  for (int i = 0; i < 1; i++)
+    for (int *p = &b; p < &c; p++)
+      for (int j = 0; j < 1; j++)
+	if (p < &a[128] || p >= &a[256])
+	  __builtin_abort ();
+	else
+	  p[0]++;
+}
+
+int
+main ()
+{
+  #pragma omp parallel
+  #pragma omp single
+    foo (a[128], a[256]);
+  for (int i = 0; i < 384; i++)
+    if (a[i] != (i >= 128 && i < 256))
+      __builtin_abort ();
+  return 0;
+}
Index: libgomp/testsuite/libgomp.c/pr86660.c
===================================================================
--- libgomp/testsuite/libgomp.c/pr86660.c	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ libgomp/testsuite/libgomp.c/pr86660.c	(.../branches/gcc-8-branch)
@@ -0,0 +1,28 @@
+/* PR middle-end/86660 */
+
+#pragma omp declare target
+int v[20];
+
+void
+foo (void)
+{
+  if (v[7] != 2)
+    __builtin_abort ();
+  v[7] = 1;
+}
+#pragma omp end declare target
+
+int
+main ()
+{
+  v[5] = 8;
+  v[7] = 2;
+  #pragma omp target map (always, tofrom: v)
+  {
+    foo ();
+    v[5] = 3;
+  }
+  if (v[7] != 1 || v[5] != 3)
+    __builtin_abort ();
+  return 0;
+}
Index: libsanitizer/sanitizer_common/sanitizer_linux_libcdep.cc
===================================================================
--- libsanitizer/sanitizer_common/sanitizer_linux_libcdep.cc	(.../tags/gcc_8_2_0_release)
+++ libsanitizer/sanitizer_common/sanitizer_linux_libcdep.cc	(.../branches/gcc-8-branch)
@@ -235,7 +235,7 @@
         val = FIRST_32_SECOND_64(1168, 1776);
       else if (minor == 11 || (minor == 12 && patch == 1))
         val = FIRST_32_SECOND_64(1168, 2288);
-      else if (minor <= 13)
+      else if (minor <= 14)
         val = FIRST_32_SECOND_64(1168, 2304);
       else
         val = FIRST_32_SECOND_64(1216, 2304);
Index: libsanitizer/ChangeLog
===================================================================
--- libsanitizer/ChangeLog	(.../tags/gcc_8_2_0_release)
+++ libsanitizer/ChangeLog	(.../branches/gcc-8-branch)
@@ -1,3 +1,19 @@
+2018-08-16  Martin Liska  <mliska@suse.cz>
+
+	Backport from mainline
+	2018-08-02  Martin Liska  <mliska@suse.cz>
+
+        PR sanitizer/86022
+	* sanitizer_common/sanitizer_linux_libcdep.cc (ThreadDescriptorSize):
+        Cherry-pick compiler-rt revision 338606.
+
+2018-08-01  Marek Polacek  <polacek@redhat.com>
+
+	PR sanitizer/86759
+	* tsan/tsan_platform.h: Cherry-pick compiler-rt revision 318044.
+	* tsan/tsan_platform_linux.cc: Cherry-pick compiler-rt revision
+	319180.
+
 2018-07-26  Release Manager
 
 	* GCC 8.2.0 released.
Index: libsanitizer/tsan/tsan_platform_linux.cc
===================================================================
--- libsanitizer/tsan/tsan_platform_linux.cc	(.../tags/gcc_8_2_0_release)
+++ libsanitizer/tsan/tsan_platform_linux.cc	(.../branches/gcc-8-branch)
@@ -214,9 +214,9 @@
     Die();
   }
 #elif defined(__powerpc64__)
-  if (vmaSize != 44 && vmaSize != 46) {
+  if (vmaSize != 44 && vmaSize != 46 && vmaSize != 47) {
     Printf("FATAL: ThreadSanitizer: unsupported VMA range\n");
-    Printf("FATAL: Found %d - Supported 44 and 46\n", vmaSize);
+    Printf("FATAL: Found %d - Supported 44, 46, and 47\n", vmaSize);
     Die();
   }
 #endif
Index: libsanitizer/tsan/tsan_platform.h
===================================================================
--- libsanitizer/tsan/tsan_platform.h	(.../tags/gcc_8_2_0_release)
+++ libsanitizer/tsan/tsan_platform.h	(.../branches/gcc-8-branch)
@@ -301,6 +301,38 @@
   static const uptr kVdsoBeg       = 0x7800000000000000ull;
 };
 
+/*
+C/C++ on linux/powerpc64 (47-bit VMA)
+0000 0000 1000 - 0100 0000 0000: main binary
+0100 0000 0000 - 0200 0000 0000: -
+0100 0000 0000 - 1000 0000 0000: shadow
+1000 0000 0000 - 1000 0000 0000: -
+1000 0000 0000 - 2000 0000 0000: metainfo (memory blocks and sync objects)
+2000 0000 0000 - 2000 0000 0000: -
+2000 0000 0000 - 2200 0000 0000: traces
+2200 0000 0000 - 7d00 0000 0000: -
+7d00 0000 0000 - 7e00 0000 0000: heap
+7e00 0000 0000 - 7e80 0000 0000: -
+7e80 0000 0000 - 8000 0000 0000: modules and main thread stack
+*/
+struct Mapping47 {
+  static const uptr kMetaShadowBeg = 0x100000000000ull;
+  static const uptr kMetaShadowEnd = 0x200000000000ull;
+  static const uptr kTraceMemBeg   = 0x200000000000ull;
+  static const uptr kTraceMemEnd   = 0x220000000000ull;
+  static const uptr kShadowBeg     = 0x010000000000ull;
+  static const uptr kShadowEnd     = 0x100000000000ull;
+  static const uptr kHeapMemBeg    = 0x7d0000000000ull;
+  static const uptr kHeapMemEnd    = 0x7e0000000000ull;
+  static const uptr kLoAppMemBeg   = 0x000000001000ull;
+  static const uptr kLoAppMemEnd   = 0x010000000000ull;
+  static const uptr kHiAppMemBeg   = 0x7e8000000000ull;
+  static const uptr kHiAppMemEnd   = 0x800000000000ull; // 47 bits
+  static const uptr kAppMemMsk     = 0x7c0000000000ull;
+  static const uptr kAppMemXor     = 0x020000000000ull;
+  static const uptr kVdsoBeg       = 0x7800000000000000ull;
+};
+
 // Indicates the runtime will define the memory regions at runtime.
 #define TSAN_RUNTIME_VMA 1
 #endif
@@ -427,11 +459,13 @@
   DCHECK(0);
   return 0;
 #elif defined(__powerpc64__)
-  if (vmaSize == 44)
-    return MappingImpl<Mapping44, Type>();
-  else
-    return MappingImpl<Mapping46, Type>();
+  switch (vmaSize) {
+    case 44: return MappingImpl<Mapping44, Type>();
+    case 46: return MappingImpl<Mapping46, Type>();
+    case 47: return MappingImpl<Mapping47, Type>();
+  }
   DCHECK(0);
+  return 0;
 #else
   return MappingImpl<Mapping, Type>();
 #endif
@@ -580,11 +614,13 @@
   DCHECK(0);
   return false;
 #elif defined(__powerpc64__)
-  if (vmaSize == 44)
-    return IsAppMemImpl<Mapping44>(mem);
-  else
-    return IsAppMemImpl<Mapping46>(mem);
+  switch (vmaSize) {
+    case 44: return IsAppMemImpl<Mapping44>(mem);
+    case 46: return IsAppMemImpl<Mapping46>(mem);
+    case 47: return IsAppMemImpl<Mapping47>(mem);
+  }
   DCHECK(0);
+  return false;
 #else
   return IsAppMemImpl<Mapping>(mem);
 #endif
@@ -607,11 +643,13 @@
   DCHECK(0);
   return false;
 #elif defined(__powerpc64__)
-  if (vmaSize == 44)
-    return IsShadowMemImpl<Mapping44>(mem);
-  else
-    return IsShadowMemImpl<Mapping46>(mem);
+  switch (vmaSize) {
+    case 44: return IsShadowMemImpl<Mapping44>(mem);
+    case 46: return IsShadowMemImpl<Mapping46>(mem);
+    case 47: return IsShadowMemImpl<Mapping47>(mem);
+  }
   DCHECK(0);
+  return false;
 #else
   return IsShadowMemImpl<Mapping>(mem);
 #endif
@@ -634,11 +672,13 @@
   DCHECK(0);
   return false;
 #elif defined(__powerpc64__)
-  if (vmaSize == 44)
-    return IsMetaMemImpl<Mapping44>(mem);
-  else
-    return IsMetaMemImpl<Mapping46>(mem);
+  switch (vmaSize) {
+    case 44: return IsMetaMemImpl<Mapping44>(mem);
+    case 46: return IsMetaMemImpl<Mapping46>(mem);
+    case 47: return IsMetaMemImpl<Mapping47>(mem);
+  }
   DCHECK(0);
+  return false;
 #else
   return IsMetaMemImpl<Mapping>(mem);
 #endif
@@ -671,11 +711,13 @@
   DCHECK(0);
   return 0;
 #elif defined(__powerpc64__)
-  if (vmaSize == 44)
-    return MemToShadowImpl<Mapping44>(x);
-  else
-    return MemToShadowImpl<Mapping46>(x);
+  switch (vmaSize) {
+    case 44: return MemToShadowImpl<Mapping44>(x);
+    case 46: return MemToShadowImpl<Mapping46>(x);
+    case 47: return MemToShadowImpl<Mapping47>(x);
+  }
   DCHECK(0);
+  return 0;
 #else
   return MemToShadowImpl<Mapping>(x);
 #endif
@@ -710,11 +752,13 @@
   DCHECK(0);
   return 0;
 #elif defined(__powerpc64__)
-  if (vmaSize == 44)
-    return MemToMetaImpl<Mapping44>(x);
-  else
-    return MemToMetaImpl<Mapping46>(x);
+  switch (vmaSize) {
+    case 44: return MemToMetaImpl<Mapping44>(x);
+    case 46: return MemToMetaImpl<Mapping46>(x);
+    case 47: return MemToMetaImpl<Mapping47>(x);
+  }
   DCHECK(0);
+  return 0;
 #else
   return MemToMetaImpl<Mapping>(x);
 #endif
@@ -762,11 +806,13 @@
   DCHECK(0);
   return 0;
 #elif defined(__powerpc64__)
-  if (vmaSize == 44)
-    return ShadowToMemImpl<Mapping44>(s);
-  else
-    return ShadowToMemImpl<Mapping46>(s);
+  switch (vmaSize) {
+    case 44: return ShadowToMemImpl<Mapping44>(s);
+    case 46: return ShadowToMemImpl<Mapping46>(s);
+    case 47: return ShadowToMemImpl<Mapping47>(s);
+  }
   DCHECK(0);
+  return 0;
 #else
   return ShadowToMemImpl<Mapping>(s);
 #endif
@@ -797,11 +843,13 @@
   DCHECK(0);
   return 0;
 #elif defined(__powerpc64__)
-  if (vmaSize == 44)
-    return GetThreadTraceImpl<Mapping44>(tid);
-  else
-    return GetThreadTraceImpl<Mapping46>(tid);
+  switch (vmaSize) {
+    case 44: return GetThreadTraceImpl<Mapping44>(tid);
+    case 46: return GetThreadTraceImpl<Mapping46>(tid);
+    case 47: return GetThreadTraceImpl<Mapping47>(tid);
+  }
   DCHECK(0);
+  return 0;
 #else
   return GetThreadTraceImpl<Mapping>(tid);
 #endif
@@ -827,11 +875,13 @@
   DCHECK(0);
   return 0;
 #elif defined(__powerpc64__)
-  if (vmaSize == 44)
-    return GetThreadTraceHeaderImpl<Mapping44>(tid);
-  else
-    return GetThreadTraceHeaderImpl<Mapping46>(tid);
+  switch (vmaSize) {
+    case 44: return GetThreadTraceHeaderImpl<Mapping44>(tid);
+    case 46: return GetThreadTraceHeaderImpl<Mapping46>(tid);
+    case 47: return GetThreadTraceHeaderImpl<Mapping47>(tid);
+  }
   DCHECK(0);
+  return 0;
 #else
   return GetThreadTraceHeaderImpl<Mapping>(tid);
 #endif
Index: libstdc++-v3/configure
===================================================================
--- libstdc++-v3/configure	(.../tags/gcc_8_2_0_release)
+++ libstdc++-v3/configure	(.../branches/gcc-8-branch)
@@ -729,6 +729,8 @@
 CSTDIO_H
 SECTION_FLAGS
 WERROR
+ENABLE_FLOAT128_FALSE
+ENABLE_FLOAT128_TRUE
 thread_header
 glibcxx_PCHFLAGS
 GLIBCXX_BUILD_PCH_FALSE
@@ -11606,7 +11608,7 @@
   lt_dlunknown=0; lt_dlno_uscore=1; lt_dlneed_uscore=2
   lt_status=$lt_dlunknown
   cat > conftest.$ac_ext <<_LT_EOF
-#line 11609 "configure"
+#line 11611 "configure"
 #include "confdefs.h"
 
 #if HAVE_DLFCN_H
@@ -11712,7 +11714,7 @@
   lt_dlunknown=0; lt_dlno_uscore=1; lt_dlneed_uscore=2
   lt_status=$lt_dlunknown
   cat > conftest.$ac_ext <<_LT_EOF
-#line 11715 "configure"
+#line 11717 "configure"
 #include "confdefs.h"
 
 #if HAVE_DLFCN_H
@@ -15398,7 +15400,7 @@
   # Fake what AC_TRY_COMPILE does.
 
     cat > conftest.$ac_ext << EOF
-#line 15401 "configure"
+#line 15403 "configure"
 int main()
 {
   typedef bool atomic_type;
@@ -15433,7 +15435,7 @@
     rm -f conftest*
 
     cat > conftest.$ac_ext << EOF
-#line 15436 "configure"
+#line 15438 "configure"
 int main()
 {
   typedef short atomic_type;
@@ -15468,7 +15470,7 @@
     rm -f conftest*
 
     cat > conftest.$ac_ext << EOF
-#line 15471 "configure"
+#line 15473 "configure"
 int main()
 {
   // NB: _Atomic_word not necessarily int.
@@ -15504,7 +15506,7 @@
     rm -f conftest*
 
     cat > conftest.$ac_ext << EOF
-#line 15507 "configure"
+#line 15509 "configure"
 int main()
 {
   typedef long long atomic_type;
@@ -15585,7 +15587,7 @@
   # unnecessary for this test.
 
     cat > conftest.$ac_ext << EOF
-#line 15588 "configure"
+#line 15590 "configure"
 int main()
 {
   _Decimal32 d1;
@@ -15627,7 +15629,7 @@
   # unnecessary for this test.
 
     cat > conftest.$ac_ext << EOF
-#line 15630 "configure"
+#line 15632 "configure"
 template<typename T1, typename T2>
   struct same
   { typedef T2 type; };
@@ -15661,7 +15663,7 @@
     rm -f conftest*
 
     cat > conftest.$ac_ext << EOF
-#line 15664 "configure"
+#line 15666 "configure"
 template<typename T1, typename T2>
   struct same
   { typedef T2 type; };
@@ -15683,9 +15685,6 @@
   ac_status=$?
   $as_echo "$as_me:${as_lineno-$LINENO}: \$? = $ac_status" >&5
   test $ac_status = 0; }; then
-
-$as_echo "#define _GLIBCXX_USE_FLOAT128 1" >>confdefs.h
-
       enable_float128=yes
     else
       enable_float128=no
@@ -15692,6 +15691,7 @@
     fi
     { $as_echo "$as_me:${as_lineno-$LINENO}: result: $enable_float128" >&5
 $as_echo "$enable_float128" >&6; }
+
     rm -f conftest*
 
   ac_ext=c
@@ -81261,6 +81261,15 @@
 fi
 
 
+    if test $enable_float128 = yes; then
+  ENABLE_FLOAT128_TRUE=
+  ENABLE_FLOAT128_FALSE='#'
+else
+  ENABLE_FLOAT128_TRUE='#'
+  ENABLE_FLOAT128_FALSE=
+fi
+
+
     if test $enable_libstdcxx_allocator_flag = new; then
   ENABLE_ALLOCATOR_NEW_TRUE=
   ENABLE_ALLOCATOR_NEW_FALSE='#'
@@ -81804,6 +81813,10 @@
   as_fn_error "conditional \"GLIBCXX_BUILD_PCH\" was never defined.
 Usually this means the macro was only invoked conditionally." "$LINENO" 5
 fi
+if test -z "${ENABLE_FLOAT128_TRUE}" && test -z "${ENABLE_FLOAT128_FALSE}"; then
+  as_fn_error "conditional \"ENABLE_FLOAT128\" was never defined.
+Usually this means the macro was only invoked conditionally." "$LINENO" 5
+fi
 if test -z "${ENABLE_ALLOCATOR_NEW_TRUE}" && test -z "${ENABLE_ALLOCATOR_NEW_FALSE}"; then
   as_fn_error "conditional \"ENABLE_ALLOCATOR_NEW\" was never defined.
 Usually this means the macro was only invoked conditionally." "$LINENO" 5
Index: libstdc++-v3/src/filesystem/std-path.cc
===================================================================
--- libstdc++-v3/src/filesystem/std-path.cc	(.../tags/gcc_8_2_0_release)
+++ libstdc++-v3/src/filesystem/std-path.cc	(.../branches/gcc-8-branch)
@@ -378,7 +378,7 @@
     {
 #ifdef _GLIBCXX_FILESYSTEM_IS_WINDOWS
       // Replace each slash character in the root-name
-      if (p.is_root_name())
+      if (p._M_type == _Type::_Root_name || p._M_type == _Type::_Root_dir)
 	{
 	  string_type s = p.native();
 	  std::replace(s.begin(), s.end(), L'/', L'\\');
@@ -398,7 +398,8 @@
 	    }
 	  else if (!ret.has_relative_path())
 	    {
-	      if (!ret.is_absolute())
+	      // remove a dot-dot filename immediately after root-directory
+	      if (!ret.has_root_directory())
 		ret /= p;
 	    }
 	  else
@@ -411,8 +412,18 @@
 		{
 		  // Remove the filename before the trailing slash
 		  // (equiv. to ret = ret.parent_path().remove_filename())
-		  ret._M_pathname.erase(elem._M_cur->_M_pos);
-		  ret._M_cmpts.erase(elem._M_cur, ret._M_cmpts.end());
+
+		  if (elem == ret.begin())
+		    ret.clear();
+		  else
+		    {
+		      ret._M_pathname.erase(elem._M_cur->_M_pos);
+		      // Do we still have a trailing slash?
+		      if (std::prev(elem)->_M_type == _Type::_Filename)
+			ret._M_cmpts.erase(elem._M_cur);
+		      else
+			ret._M_cmpts.erase(elem._M_cur, ret._M_cmpts.end());
+		    }
 		}
 	      else // ???
 		ret /= p;
Index: libstdc++-v3/src/c++11/system_error.cc
===================================================================
--- libstdc++-v3/src/c++11/system_error.cc	(.../tags/gcc_8_2_0_release)
+++ libstdc++-v3/src/c++11/system_error.cc	(.../branches/gcc-8-branch)
@@ -29,6 +29,7 @@
 #include <system_error>
 #include <bits/functexcept.h>
 #include <limits>
+#include <errno.h>
 #undef __sso_string
 
 namespace
@@ -65,6 +66,261 @@
       // _GLIBCXX_HAVE_STRERROR_L, strerror_l(i, cloc)
       return string(strerror(i));
     }
+
+    virtual std::error_condition
+    default_error_condition(int ev) const noexcept
+    {
+      switch (ev)
+      {
+      // List of errno macros from [cerrno.syn].
+      // C11 only defines EDOM, EILSEQ and ERANGE, the rest are from POSIX.
+      // They expand to integer constant expressions with type int,
+      // and distinct positive values, suitable for use in #if directives.
+      // POSIX adds more macros (but they're not defined on all targets,
+      // see config/os/*/error_constants.h), and POSIX allows
+      // EAGAIN == EWOULDBLOCK and ENOTSUP == EOPNOTSUPP.
+
+#ifdef E2BIG
+      case E2BIG:
+#endif
+#ifdef EACCES
+      case EACCES:
+#endif
+#ifdef EADDRINUSE
+      case EADDRINUSE:
+#endif
+#ifdef EADDRNOTAVAIL
+      case EADDRNOTAVAIL:
+#endif
+#ifdef EAFNOSUPPORT
+      case EAFNOSUPPORT:
+#endif
+#ifdef EAGAIN
+      case EAGAIN:
+#endif
+#ifdef EALREADY
+      case EALREADY:
+#endif
+#ifdef EBADF
+      case EBADF:
+#endif
+#ifdef EBADMSG
+      case EBADMSG:
+#endif
+#ifdef EBUSY
+      case EBUSY:
+#endif
+#ifdef ECANCELED
+      case ECANCELED:
+#endif
+#ifdef ECHILD
+      case ECHILD:
+#endif
+#ifdef ECONNABORTED
+      case ECONNABORTED:
+#endif
+#ifdef ECONNREFUSED
+      case ECONNREFUSED:
+#endif
+#ifdef ECONNRESET
+      case ECONNRESET:
+#endif
+#ifdef EDEADLK
+      case EDEADLK:
+#endif
+#ifdef EDESTADDRREQ
+      case EDESTADDRREQ:
+#endif
+      case EDOM:
+#ifdef EEXIST
+      case EEXIST:
+#endif
+#ifdef EFAULT
+      case EFAULT:
+#endif
+#ifdef EFBIG
+      case EFBIG:
+#endif
+#ifdef EHOSTUNREACH
+      case EHOSTUNREACH:
+#endif
+#ifdef EIDRM
+      case EIDRM:
+#endif
+      case EILSEQ:
+#ifdef EINPROGRESS
+      case EINPROGRESS:
+#endif
+#ifdef EINTR
+      case EINTR:
+#endif
+#ifdef EINVAL
+      case EINVAL:
+#endif
+#ifdef EIO
+      case EIO:
+#endif
+#ifdef EISCONN
+      case EISCONN:
+#endif
+#ifdef EISDIR
+      case EISDIR:
+#endif
+#ifdef ELOOP
+      case ELOOP:
+#endif
+#ifdef EMFILE
+      case EMFILE:
+#endif
+#ifdef EMLINK
+      case EMLINK:
+#endif
+#ifdef EMSGSIZE
+      case EMSGSIZE:
+#endif
+#ifdef ENAMETOOLONG
+      case ENAMETOOLONG:
+#endif
+#ifdef ENETDOWN
+      case ENETDOWN:
+#endif
+#ifdef ENETRESET
+      case ENETRESET:
+#endif
+#ifdef ENETUNREACH
+      case ENETUNREACH:
+#endif
+#ifdef ENFILE
+      case ENFILE:
+#endif
+#ifdef ENOBUFS
+      case ENOBUFS:
+#endif
+#ifdef ENODATA
+      case ENODATA:
+#endif
+#ifdef ENODEV
+      case ENODEV:
+#endif
+#ifdef ENOENT
+      case ENOENT:
+#endif
+#ifdef ENOEXEC
+      case ENOEXEC:
+#endif
+#ifdef ENOLCK
+      case ENOLCK:
+#endif
+#ifdef ENOLINK
+      case ENOLINK:
+#endif
+#ifdef ENOMEM
+      case ENOMEM:
+#endif
+#ifdef ENOMSG
+      case ENOMSG:
+#endif
+#ifdef ENOPROTOOPT
+      case ENOPROTOOPT:
+#endif
+#ifdef ENOSPC
+      case ENOSPC:
+#endif
+#ifdef ENOSR
+      case ENOSR:
+#endif
+#ifdef ENOSTR
+      case ENOSTR:
+#endif
+#ifdef ENOSYS
+      case ENOSYS:
+#endif
+#ifdef ENOTCONN
+      case ENOTCONN:
+#endif
+#ifdef ENOTDIR
+      case ENOTDIR:
+#endif
+#if defined ENOTEMPTY && (!defined EEXIST || ENOTEMPTY != EEXIST)
+      // AIX sometimes uses the same value for EEXIST and ENOTEMPTY
+      case ENOTEMPTY:
+#endif
+#ifdef ENOTRECOVERABLE
+      case ENOTRECOVERABLE:
+#endif
+#ifdef ENOTSOCK
+      case ENOTSOCK:
+#endif
+#ifdef ENOTSUP
+      case ENOTSUP:
+#endif
+#ifdef ENOTTY
+      case ENOTTY:
+#endif
+#ifdef ENXIO
+      case ENXIO:
+#endif
+#if defined EOPNOTSUPP && (!defined ENOTSUP || EOPNOTSUPP != ENOTSUP)
+      case EOPNOTSUPP:
+#endif
+#ifdef EOVERFLOW
+      case EOVERFLOW:
+#endif
+#ifdef EOWNERDEAD
+      case EOWNERDEAD:
+#endif
+#ifdef EPERM
+      case EPERM:
+#endif
+#ifdef EPIPE
+      case EPIPE:
+#endif
+#ifdef EPROTO
+      case EPROTO:
+#endif
+#ifdef EPROTONOSUPPORT
+      case EPROTONOSUPPORT:
+#endif
+#ifdef EPROTOTYPE
+      case EPROTOTYPE:
+#endif
+      case ERANGE:
+#ifdef EROFS
+      case EROFS:
+#endif
+#ifdef ESPIPE
+      case ESPIPE:
+#endif
+#ifdef ESRCH
+      case ESRCH:
+#endif
+#ifdef ETIME
+      case ETIME:
+#endif
+#ifdef ETIMEDOUT
+      case ETIMEDOUT:
+#endif
+#ifdef ETXTBSY
+      case ETXTBSY:
+#endif
+#if defined EWOULDBLOCK && (!defined EAGAIN || EWOULDBLOCK != EAGAIN)
+      case EWOULDBLOCK:
+#endif
+#ifdef EXDEV
+      case EXDEV:
+#endif
+        return std::error_condition(ev, std::generic_category());
+
+      /* Additional system-dependent mappings from non-standard error codes
+       * to one of the POSIX values above would go here, e.g.
+      case EBLAH:
+	return std::error_condition(EINVAL, std::generic_category());
+       */
+
+      default:
+	return std::error_condition(ev, std::system_category());
+      }
+    }
   };
 
   const generic_error_category generic_category_instance{};
Index: libstdc++-v3/doc/xml/manual/using.xml
===================================================================
--- libstdc++-v3/doc/xml/manual/using.xml	(.../tags/gcc_8_2_0_release)
+++ libstdc++-v3/doc/xml/manual/using.xml	(.../branches/gcc-8-branch)
@@ -128,7 +128,7 @@
      must be available to all hosted implementations.  Actually, the
      word "files" is a misnomer, since the contents of the
      headers don't necessarily have to be in any kind of external
-     file.  The only rule is that when one <code>#include</code>'s a
+     file.  The only rule is that when one <code>#include</code>s a
      header, the contents of that header become available, no matter
      how.
    </para>
@@ -140,16 +140,24 @@
    <para>
      There are two main types of include files: header files related
      to a specific version of the ISO C++ standard (called Standard
-     Headers), and all others (TR1, C++ ABI, and Extensions).
+     Headers), and all others (TS, TR1, C++ ABI, and Extensions).
    </para>
 
    <para>
-     Two dialects of standard headers are supported, corresponding to
-     the 1998 standard as updated for 2003, and the current 2011 standard.
+     Multiple dialects of standard headers are supported, corresponding to
+     the 1998 standard as updated for 2003, the 2011 standard, the 2014
+     standard, and so on.
    </para>
 
    <para>
-     C++98/03 include files. These are available in the default compilation mode, i.e. <code>-std=c++98</code> or <code>-std=gnu++98</code>.
+     <xref linkend="table.cxx98_headers"/> and
+     <xref linkend="table.cxx98_cheaders"/> and
+     <xref linkend="table.cxx98_deprheaders"/>
+     show the C++98/03 include files.
+     These are available in the C++98 compilation mode,
+     i.e. <code>-std=c++98</code> or <code>-std=gnu++98</code>.
+     Unless specified otherwise below, they are also available in later modes
+     (C++11, C++14 etc).
    </para>
 
 <table frame="all" xml:id="table.cxx98_headers">
@@ -207,6 +215,7 @@
 <row>
 <entry><filename class="headerfile">valarray</filename></entry>
 <entry><filename class="headerfile">vector</filename></entry>
+<entry namest="c3" nameend="c5"/>
 </row>
 </tbody>
 </tgroup>
@@ -248,6 +257,7 @@
 <entry><filename class="headerfile">ctime</filename></entry>
 <entry><filename class="headerfile">cwchar</filename></entry>
 <entry><filename class="headerfile">cwctype</filename></entry>
+<entry namest="c4" nameend="c5"/>
 </row>
 </tbody>
 </tgroup>
@@ -254,8 +264,31 @@
 </table>
 
 <para>
-C++11 include files. These are only available in C++11 compilation
+  The following header is deprecated
+  and might be removed from a future C++ standard.
+</para>
+
+<table frame="all" xml:id="table.cxx98_deprheaders">
+<title>C++ 1998 Deprecated Library Header</title>
+
+<tgroup cols="1" align="left" colsep="1" rowsep="1">
+<colspec colname="c1"/>
+<tbody>
+<row>
+<entry><filename class="headerfile">strstream</filename></entry>
+</row>
+</tbody>
+</tgroup>
+</table>
+
+<para>
+<xref linkend="table.cxx11_headers"/> and
+<xref linkend="table.cxx11_cheaders"/> show the C++11 include files.
+These are available in C++11 compilation
 mode, i.e. <literal>-std=c++11</literal> or <literal>-std=gnu++11</literal>.
+Including these headers in C++98/03 mode may result in compilation errors.
+Unless specified otherwise below, they are also available in later modes
+(C++14 etc).
 </para>
 
 <para/>
@@ -271,73 +304,33 @@
 <tbody>
 
 <row>
-<entry><filename class="headerfile">algorithm</filename></entry>
 <entry><filename class="headerfile">array</filename></entry>
-<entry><filename class="headerfile">bitset</filename></entry>
+<entry><filename class="headerfile">atomic</filename></entry>
 <entry><filename class="headerfile">chrono</filename></entry>
-<entry><filename class="headerfile">complex</filename></entry>
+<entry><filename class="headerfile">codecvt</filename></entry>
+<entry><filename class="headerfile">condition_variable</filename></entry>
 </row>
 <row>
-<entry><filename class="headerfile">condition_variable</filename></entry>
-<entry><filename class="headerfile">deque</filename></entry>
-<entry><filename class="headerfile">exception</filename></entry>
 <entry><filename class="headerfile">forward_list</filename></entry>
-<entry><filename class="headerfile">fstream</filename></entry>
-</row>
-<row>
-<entry><filename class="headerfile">functional</filename></entry>
 <entry><filename class="headerfile">future</filename></entry>
 <entry><filename class="headerfile">initalizer_list</filename></entry>
-<entry><filename class="headerfile">iomanip</filename></entry>
-<entry><filename class="headerfile">ios</filename></entry>
-</row>
-<row>
-<entry><filename class="headerfile">iosfwd</filename></entry>
-<entry><filename class="headerfile">iostream</filename></entry>
-<entry><filename class="headerfile">istream</filename></entry>
-<entry><filename class="headerfile">iterator</filename></entry>
-<entry><filename class="headerfile">limits</filename></entry>
-</row>
-<row>
-<entry><filename class="headerfile">list</filename></entry>
-<entry><filename class="headerfile">locale</filename></entry>
-<entry><filename class="headerfile">map</filename></entry>
-<entry><filename class="headerfile">memory</filename></entry>
 <entry><filename class="headerfile">mutex</filename></entry>
-</row>
-<row>
-<entry><filename class="headerfile">new</filename></entry>
-<entry><filename class="headerfile">numeric</filename></entry>
-<entry><filename class="headerfile">ostream</filename></entry>
-<entry><filename class="headerfile">queue</filename></entry>
 <entry><filename class="headerfile">random</filename></entry>
 </row>
 <row>
 <entry><filename class="headerfile">ratio</filename></entry>
 <entry><filename class="headerfile">regex</filename></entry>
-<entry><filename class="headerfile">set</filename></entry>
-<entry><filename class="headerfile">sstream</filename></entry>
-<entry><filename class="headerfile">stack</filename></entry>
-</row>
-<row>
-<entry><filename class="headerfile">stdexcept</filename></entry>
-<entry><filename class="headerfile">streambuf</filename></entry>
-<entry><filename class="headerfile">string</filename></entry>
+<entry><filename class="headerfile">scoped_allocator</filename></entry>
 <entry><filename class="headerfile">system_error</filename></entry>
 <entry><filename class="headerfile">thread</filename></entry>
 </row>
 <row>
 <entry><filename class="headerfile">tuple</filename></entry>
+<entry><filename class="headerfile">typeindex</filename></entry>
 <entry><filename class="headerfile">type_traits</filename></entry>
-<entry><filename class="headerfile">typeinfo</filename></entry>
 <entry><filename class="headerfile">unordered_map</filename></entry>
 <entry><filename class="headerfile">unordered_set</filename></entry>
 </row>
-<row>
-<entry><filename class="headerfile">utility</filename></entry>
-<entry><filename class="headerfile">valarray</filename></entry>
-<entry><filename class="headerfile">vector</filename></entry>
-</row>
 
 </tbody>
 </tgroup>
@@ -356,39 +349,77 @@
 <colspec colname="c5"/>
 <tbody>
 <row>
-<entry><filename class="headerfile">cassert</filename></entry>
 <entry><filename class="headerfile">ccomplex</filename></entry>
-<entry><filename class="headerfile">cctype</filename></entry>
-<entry><filename class="headerfile">cerrno</filename></entry>
 <entry><filename class="headerfile">cfenv</filename></entry>
+<entry><filename class="headerfile">cinttypes</filename></entry>
+<entry><filename class="headerfile">cstdalign</filename></entry>
+<entry><filename class="headerfile">cstdbool</filename></entry>
 </row>
 <row>
-<entry><filename class="headerfile">cfloat</filename></entry>
-<entry><filename class="headerfile">cinttypes</filename></entry>
-<entry><filename class="headerfile">ciso646</filename></entry>
-<entry><filename class="headerfile">climits</filename></entry>
-<entry><filename class="headerfile">clocale</filename></entry>
+<entry><filename class="headerfile">cstdint</filename></entry>
+<entry><filename class="headerfile">ctgmath</filename></entry>
+<entry><filename class="headerfile">cuchar</filename></entry>
+<entry namest="c4" nameend="c5"/>
 </row>
+</tbody>
+</tgroup>
+</table>
+
+<para>
+<xref linkend="table.cxx14_headers"/> shows the C++14 include file.
+This is available in C++14 compilation
+mode, i.e. <literal>-std=c++14</literal> or <literal>-std=gnu++14</literal>.
+Including this header in C++98/03 mode or C++11 will not result in
+compilation errors, but will not define anything.
+Unless specified otherwise below, it is also available in later modes
+(C++17 etc).
+</para>
+
+<para/>
+<table frame="all" xml:id="table.cxx14_headers">
+<title>C++ 2014 Library Header</title>
+
+<tgroup cols="1" align="left" colsep="1" rowsep="1">
+<colspec colname="c1"/>
+<tbody>
 <row>
-<entry><filename class="headerfile">cmath</filename></entry>
-<entry><filename class="headerfile">csetjmp</filename></entry>
-<entry><filename class="headerfile">csignal</filename></entry>
-<entry><filename class="headerfile">cstdarg</filename></entry>
-<entry><filename class="headerfile">cstdbool</filename></entry>
+<entry><filename class="headerfile">shared_mutex</filename></entry>
 </row>
+</tbody>
+</tgroup>
+</table>
+
+<para>
+<xref linkend="table.cxx17_headers"/> shows the C++17 include files.
+These are available in C++17 compilation
+mode, i.e. <literal>-std=c++17</literal> or <literal>-std=gnu++17</literal>.
+Including these headers in earlier modes will not result in
+compilation errors, but will not define anything.
+Unless specified otherwise below, they are also available in later modes
+(C++20 etc).
+</para>
+
+<para/>
+<table frame="all" xml:id="table.cxx17_headers">
+<title>C++ 2017 Library Headers</title>
+
+<tgroup cols="5" align="left" colsep="1" rowsep="1">
+<colspec colname="c1"/>
+<colspec colname="c2"/>
+<colspec colname="c3"/>
+<colspec colname="c4"/>
+<colspec colname="c5"/>
+<tbody>
 <row>
-<entry><filename class="headerfile">cstddef</filename></entry>
-<entry><filename class="headerfile">cstdint</filename></entry>
-<entry><filename class="headerfile">cstdlib</filename></entry>
-<entry><filename class="headerfile">cstdio</filename></entry>
-<entry><filename class="headerfile">cstring</filename></entry>
+<entry><filename class="headerfile">any</filename></entry>
+<entry><filename class="headerfile">charconv</filename></entry>
+<entry><filename class="headerfile">filesystem</filename></entry>
+<entry><filename class="headerfile">optional</filename></entry>
+<entry><filename class="headerfile">string_view</filename></entry>
 </row>
 <row>
-<entry><filename class="headerfile">ctgmath</filename></entry>
-<entry><filename class="headerfile">ctime</filename></entry>
-<entry><filename class="headerfile">cuchar</filename></entry>
-<entry><filename class="headerfile">cwchar</filename></entry>
-<entry><filename class="headerfile">cwctype</filename></entry>
+<entry><filename class="headerfile">variant</filename></entry>
+<entry namest="c2" nameend="c5"/>
 </row>
 </tbody>
 </tgroup>
@@ -396,6 +427,97 @@
 
 
 <para>
+<xref linkend="table.filesystemts_headers"/>,
+shows the additional include file define by the
+File System Technical Specification, ISO/IEC TS 18822.
+This is available in C++11 and later compilation modes.
+Including this header in earlier modes will not result in
+compilation errors, but will not define anything.
+</para>
+
+<para/>
+<table frame="all" xml:id="table.filesystemts_headers">
+<title>File System TS Header</title>
+
+<tgroup cols="1" align="left" colsep="1" rowsep="1">
+<colspec colname="c1"/>
+<tbody>
+<row>
+<entry><filename class="headerfile">experimental/filesystem</filename></entry>
+</row>
+</tbody>
+</tgroup>
+</table>
+
+
+<para>
+<xref linkend="table.libfundts_headers"/>,
+shows the additional include files define by the C++ Extensions for 
+Library Fundamentals Technical Specification, ISO/IEC TS 19568.
+These are available in C++14 and later compilation modes.
+Including these headers in earlier modes will not result in
+compilation errors, but will not define anything.
+</para>
+
+<para/>
+<table frame="all" xml:id="table.libfundts_headers">
+<title>Library Fundamentals TS Headers</title>
+
+<tgroup cols="5" align="left" colsep="1" rowsep="1">
+<colspec colname="c1"/>
+<colspec colname="c2"/>
+<colspec colname="c3"/>
+<colspec colname="c4"/>
+<colspec colname="c5"/>
+<tbody>
+<row>
+<entry><filename class="headerfile">experimental/algorithm</filename></entry>
+<entry><filename class="headerfile">experimental/any</filename></entry>
+<entry><filename class="headerfile">experimental/array</filename></entry>
+<entry><filename class="headerfile">experimental/chrono</filename></entry>
+<entry><filename class="headerfile">experimental/deque</filename></entry>
+</row>
+<row>
+<entry><filename class="headerfile">experimental/forward_list</filename></entry>
+<entry><filename class="headerfile">experimental/functional</filename></entry>
+<entry><filename class="headerfile">experimental/iterator</filename></entry>
+<entry><filename class="headerfile">experimental/list</filename></entry>
+<entry><filename class="headerfile">experimental/map</filename></entry>
+</row>
+<row>
+<entry><filename class="headerfile">experimental/memory</filename></entry>
+<entry><filename class="headerfile">experimental/memory_resource</filename></entry>
+<entry><filename class="headerfile">experimental/numeric</filename></entry>
+<entry><filename class="headerfile">experimental/optional</filename></entry>
+<entry><filename class="headerfile">experimental/propagate_const</filename></entry>
+</row>
+<row>
+<entry><filename class="headerfile">experimental/random</filename></entry>
+<entry><filename class="headerfile">experimental/ratio</filename></entry>
+<entry><filename class="headerfile">experimental/regex</filename></entry>
+<entry><filename class="headerfile">experimental/set</filename></entry>
+<entry><filename class="headerfile">experimental/source_location</filename></entry>
+</row>
+<row>
+<entry><filename class="headerfile">experimental/string</filename></entry>
+<entry><filename class="headerfile">experimental/string_view</filename></entry>
+<entry><filename class="headerfile">experimental/system_error</filename></entry>
+<entry><filename class="headerfile">experimental/tuple</filename></entry>
+<entry><filename class="headerfile">experimental/type_traits</filename></entry>
+</row>
+<row>
+<entry><filename class="headerfile">experimental/unordered_map</filename></entry>
+<entry><filename class="headerfile">experimental/unordered_set</filename></entry>
+<entry><filename class="headerfile">experimental/utility</filename></entry>
+<entry><filename class="headerfile">experimental/vector</filename></entry>
+<entry />
+</row>
+</tbody>
+</tgroup>
+</table>
+
+
+<para>
   In addition, TR1 includes as:
 </para>
 
@@ -426,6 +548,7 @@
 </row>
 <row>
 <entry><filename class="headerfile">tr1/utility</filename></entry>
+<entry namest="c2" nameend="c5"/>
 </row>
 
 </tbody>
@@ -566,6 +689,7 @@
 </row>
 <row>
 <entry><filename class="headerfile">ext/vstring.h</filename></entry>
+<entry namest="c2" nameend="c5"/>
 </row>
 
 </tbody>
@@ -586,18 +710,22 @@
 <tbody>
 
 <row>
+<entry><filename class="headerfile">debug/array</filename></entry>
 <entry><filename class="headerfile">debug/bitset</filename></entry>
 <entry><filename class="headerfile">debug/deque</filename></entry>
+<entry><filename class="headerfile">debug/forward_list</filename></entry>
 <entry><filename class="headerfile">debug/list</filename></entry>
+</row>
+<row>
 <entry><filename class="headerfile">debug/map</filename></entry>
 <entry><filename class="headerfile">debug/set</filename></entry>
-</row>
-
-<row>
 <entry><filename class="headerfile">debug/string</filename></entry>
 <entry><filename class="headerfile">debug/unordered_map</filename></entry>
 <entry><filename class="headerfile">debug/unordered_set</filename></entry>
+</row>
+<row>
 <entry><filename class="headerfile">debug/vector</filename></entry>
+<entry namest="c2" nameend="c5"/>
 </row>
 
 </tbody>
Index: libstdc++-v3/doc/xml/manual/test.xml
===================================================================
--- libstdc++-v3/doc/xml/manual/test.xml	(.../tags/gcc_8_2_0_release)
+++ libstdc++-v3/doc/xml/manual/test.xml	(.../branches/gcc-8-branch)
@@ -763,12 +763,15 @@
 
   <para>
     Similarly, tests which depend on a newer standard than the default
-    should use <literal>dg-options</literal> instead of an effective target,
-    so that they are not skipped by default.
+    must use <literal>dg-options</literal> instead of (or in addition to)
+    an effective target, so that they are not skipped by default.
     For example, tests for C++17 features should use
 <programlisting>    // { dg-options "-std=gnu++17" }</programlisting>
-    and not
-<programlisting>    // { dg-do run "c++1z" }</programlisting>
+    before any <literal>dg-do</literal> such as:
+<programlisting>    // { dg-do run "c++17" }</programlisting>
+    The <literal>dg-options</literal> directive must come first, so that
+    the <literal>-std</literal> flag has already been added to the options
+    before checking the <literal>c++17</literal> target.
   </para>
 
 <section xml:id="tests.dg.examples"><info><title>Examples of Test Directives</title></info>
Index: libstdc++-v3/doc/html/manual/bugs.html
===================================================================
--- libstdc++-v3/doc/html/manual/bugs.html	(.../tags/gcc_8_2_0_release)
+++ libstdc++-v3/doc/html/manual/bugs.html	(.../branches/gcc-8-branch)
@@ -526,4 +526,8 @@
          <code class="code">weak_ptr::owner_before</code>
        </em></span>
     </span></dt><dd><p>Add noexcept.
+    </p></dd><dt><a id="manual.bugs.dr3076"></a><span class="term"><a class="link" href="http://www.open-std.org/jtc1/sc22/wg21/docs/lwg-defects.html#3076" target="_top">3076</a>:
+       <span class="emphasis"><em><code class="code">basic_string</code> CTAD ambiguity
+       </em></span>
+    </span></dt><dd><p>Change constructors to constrained templates.
     </p></dd></dl></div></div></div><div class="navfooter"><hr /><table width="100%" summary="Navigation footer"><tr><td width="40%" align="left"><a accesskey="p" href="license.html">Prev</a> </td><td width="20%" align="center"><a accesskey="u" href="status.html">Up</a></td><td width="40%" align="right"> <a accesskey="n" href="setup.html">Next</a></td></tr><tr><td width="40%" align="left" valign="top">License </td><td width="20%" align="center"><a accesskey="h" href="../index.html">Home</a></td><td width="40%" align="right" valign="top"> Chapter 2. Setup</td></tr></table></div></body></html>
\ No newline at end of file
Index: libstdc++-v3/doc/html/manual/test.html
===================================================================
--- libstdc++-v3/doc/html/manual/test.html	(.../tags/gcc_8_2_0_release)
+++ libstdc++-v3/doc/html/manual/test.html	(.../branches/gcc-8-branch)
@@ -464,12 +464,15 @@
     possible variations.
   </p><p>
     Similarly, tests which depend on a newer standard than the default
-    should use <code class="literal">dg-options</code> instead of an effective target,
-    so that they are not skipped by default.
+    must use <code class="literal">dg-options</code> instead of (or in addition to)
+    an effective target, so that they are not skipped by default.
     For example, tests for C++17 features should use
 </p><pre class="programlisting">    // { dg-options "-std=gnu++17" }</pre><p>
-    and not
-</p><pre class="programlisting">    // { dg-do run "c++1z" }</pre><p>
+    before any <code class="literal">dg-do</code> such as:
+</p><pre class="programlisting">    // { dg-do run "c++17" }</pre><p>
+    The <code class="literal">dg-options</code> directive must come first, so that
+    the <code class="literal">-std</code> flag has already been added to the options
+    before checking the <code class="literal">c++17</code> target.
   </p><div class="section"><div class="titlepage"><div><div><h4 class="title"><a id="tests.dg.examples"></a>Examples of Test Directives</h4></div></div></div><p>
 Example 1: Testing compilation only:
 </p><pre class="programlisting">
Index: libstdc++-v3/doc/html/manual/using_headers.html
===================================================================
--- libstdc++-v3/doc/html/manual/using_headers.html	(.../tags/gcc_8_2_0_release)
+++ libstdc++-v3/doc/html/manual/using_headers.html	(.../branches/gcc-8-branch)
@@ -4,7 +4,7 @@
      must be available to all hosted implementations.  Actually, the
      word "files" is a misnomer, since the contents of the
      headers don't necessarily have to be in any kind of external
-     file.  The only rule is that when one <code class="code">#include</code>'s a
+     file.  The only rule is that when one <code class="code">#include</code>s a
      header, the contents of that header become available, no matter
      how.
    </p><p>
@@ -12,25 +12,71 @@
    </p><p>
      There are two main types of include files: header files related
      to a specific version of the ISO C++ standard (called Standard
-     Headers), and all others (TR1, C++ ABI, and Extensions).
+     Headers), and all others (TS, TR1, C++ ABI, and Extensions).
    </p><p>
-     Two dialects of standard headers are supported, corresponding to
-     the 1998 standard as updated for 2003, and the current 2011 standard.
+     Multiple dialects of standard headers are supported, corresponding to
+     the 1998 standard as updated for 2003, the 2011 standard, the 2014
+     standard, and so on.
    </p><p>
-     C++98/03 include files. These are available in the default compilation mode, i.e. <code class="code">-std=c++98</code> or <code class="code">-std=gnu++98</code>.
-   </p><div class="table"><a id="table.cxx98_headers"></a><p class="title"><strong>Table 3.2. C++ 1998 Library Headers</strong></p><div class="table-contents"><table class="table" summary="C++ 1998 Library Headers" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /></colgroup><tbody><tr><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="filename">bitset</code></td><td align="left"><code class="filename">complex</code></td><td align="left"><code class="filename">deque</code></td><td align="left"><code class="filename">exception</code></td></tr><tr><td align="left"><code class="filename">fstream</code></td><td align="left"><code class="filename">functional</code></td><td align="left"><code class="filename">iomanip</code></td><td align="left"><code class="filename">ios</code></td><td align="left"><code class="filename">iosfwd</code></td></tr><tr><td align="left"><code class="filename">iostream</code></td><td align="left"><code class="filename">istream</code></td><td align="left"><code class="filename">iterator</code></td><td align="left"><code class="filename">limits</code></td><td align="left"><code class="filename">list</code></td></tr><tr><td align="left"><code class="filename">locale</code></td><td align="left"><code class="filename">map</code></td><td align="left"><code class="filename">memory</code></td><td align="left"><code class="filename">new</code></td><td align="left"><code class="filename">numeric</code></td></tr><tr><td align="left"><code class="filename">ostream</code></td><td align="left"><code class="filename">queue</code></td><td align="left"><code class="filename">set</code></td><td align="left"><code class="filename">sstream</code></td><td align="left"><code class="filename">stack</code></td></tr><tr><td align="left"><code class="filename">stdexcept</code></td><td align="left"><code class="filename">streambuf</code></td><td align="left"><code class="filename">string</code></td><td align="left"><code class="filename">utility</code></td><td align="left"><code class="filename">typeinfo</code></td></tr><tr><td align="left"><code class="filename">valarray</code></td><td align="left"><code class="filename">vector</code></td><td class="auto-generated"> </td><td class="auto-generated"> </td><td class="auto-generated"> </td></tr></tbody></table></div></div><br class="table-break" /><p></p><div class="table"><a id="table.cxx98_cheaders"></a><p class="title"><strong>Table 3.3. C++ 1998 Library Headers for C Library Facilities</strong></p><div class="table-contents"><table class="table" summary="C++ 1998 Library Headers for C Library Facilities" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /></colgroup><tbody><tr><td align="left"><code class="filename">cassert</code></td><td align="left"><code class="filename">cerrno</code></td><td align="left"><code class="filename">cctype</code></td><td align="left"><code class="filename">cfloat</code></td><td align="left"><code class="filename">ciso646</code></td></tr><tr><td align="left"><code class="filename">climits</code></td><td align="left"><code class="filename">clocale</code></td><td align="left"><code class="filename">cmath</code></td><td align="left"><code class="filename">csetjmp</code></td><td align="left"><code class="filename">csignal</code></td></tr><tr><td align="left"><code class="filename">cstdarg</code></td><td align="left"><code class="filename">cstddef</code></td><td align="left"><code class="filename">cstdio</code></td><td align="left"><code class="filename">cstdlib</code></td><td align="left"><code class="filename">cstring</code></td></tr><tr><td align="left"><code class="filename">ctime</code></td><td align="left"><code class="filename">cwchar</code></td><td align="left"><code class="filename">cwctype</code></td><td class="auto-generated"> </td><td class="auto-generated"> </td></tr></tbody></table></div></div><br class="table-break" /><p>
-C++11 include files. These are only available in C++11 compilation
+     <a class="xref" href="using_headers.html#table.cxx98_headers" title="Table 3.2. C++ 1998 Library Headers">Table 3.2, “C++ 1998 Library Headers”</a> and
+     <a class="xref" href="using_headers.html#table.cxx98_cheaders" title="Table 3.3. C++ 1998 Library Headers for C Library Facilities">Table 3.3, “C++ 1998 Library Headers for C Library Facilities”</a> and
+     <a class="xref" href="using_headers.html#table.cxx98_deprheaders" title="Table 3.4. C++ 1998 Deprecated Library Header">Table 3.4, “C++ 1998 Deprecated Library Header”</a>
+     show the C++98/03 include files.
+     These are available in the C++98 compilation mode,
+     i.e. <code class="code">-std=c++98</code> or <code class="code">-std=gnu++98</code>.
+     Unless specified otherwise below, they are also available in later modes
+     (C++11, C++14 etc).
+   </p><div class="table"><a id="table.cxx98_headers"></a><p class="title"><strong>Table 3.2. C++ 1998 Library Headers</strong></p><div class="table-contents"><table class="table" summary="C++ 1998 Library Headers" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /></colgroup><tbody><tr><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="filename">bitset</code></td><td align="left"><code class="filename">complex</code></td><td align="left"><code class="filename">deque</code></td><td align="left"><code class="filename">exception</code></td></tr><tr><td align="left"><code class="filename">fstream</code></td><td align="left"><code class="filename">functional</code></td><td align="left"><code class="filename">iomanip</code></td><td align="left"><code class="filename">ios</code></td><td align="left"><code class="filename">iosfwd</code></td></tr><tr><td align="left"><code class="filename">iostream</code></td><td align="left"><code class="filename">istream</code></td><td align="left"><code class="filename">iterator</code></td><td align="left"><code class="filename">limits</code></td><td align="left"><code class="filename">list</code></td></tr><tr><td align="left"><code class="filename">locale</code></td><td align="left"><code class="filename">map</code></td><td align="left"><code class="filename">memory</code></td><td align="left"><code class="filename">new</code></td><td align="left"><code class="filename">numeric</code></td></tr><tr><td align="left"><code class="filename">ostream</code></td><td align="left"><code class="filename">queue</code></td><td align="left"><code class="filename">set</code></td><td align="left"><code class="filename">sstream</code></td><td align="left"><code class="filename">stack</code></td></tr><tr><td align="left"><code class="filename">stdexcept</code></td><td align="left"><code class="filename">streambuf</code></td><td align="left"><code class="filename">string</code></td><td align="left"><code class="filename">utility</code></td><td align="left"><code class="filename">typeinfo</code></td></tr><tr><td align="left"><code class="filename">valarray</code></td><td align="left"><code class="filename">vector</code></td><td colspan="3" align="left"> </td></tr></tbody></table></div></div><br class="table-break" /><p></p><div class="table"><a id="table.cxx98_cheaders"></a><p class="title"><strong>Table 3.3. C++ 1998 Library Headers for C Library Facilities</strong></p><div class="table-contents"><table class="table" summary="C++ 1998 Library Headers for C Library Facilities" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /></colgroup><tbody><tr><td align="left"><code class="filename">cassert</code></td><td align="left"><code class="filename">cerrno</code></td><td align="left"><code class="filename">cctype</code></td><td align="left"><code class="filename">cfloat</code></td><td align="left"><code class="filename">ciso646</code></td></tr><tr><td align="left"><code class="filename">climits</code></td><td align="left"><code class="filename">clocale</code></td><td align="left"><code class="filename">cmath</code></td><td align="left"><code class="filename">csetjmp</code></td><td align="left"><code class="filename">csignal</code></td></tr><tr><td align="left"><code class="filename">cstdarg</code></td><td align="left"><code class="filename">cstddef</code></td><td align="left"><code class="filename">cstdio</code></td><td align="left"><code class="filename">cstdlib</code></td><td align="left"><code class="filename">cstring</code></td></tr><tr><td align="left"><code class="filename">ctime</code></td><td align="left"><code class="filename">cwchar</code></td><td align="left"><code class="filename">cwctype</code></td><td colspan="2" align="left"> </td></tr></tbody></table></div></div><br class="table-break" /><p>
+  The following header is deprecated
+  and might be removed from a future C++ standard.
+</p><div class="table"><a id="table.cxx98_deprheaders"></a><p class="title"><strong>Table 3.4. C++ 1998 Deprecated Library Header</strong></p><div class="table-contents"><table class="table" summary="C++ 1998 Deprecated Library Header" border="1"><colgroup><col align="left" class="c1" /></colgroup><tbody><tr><td align="left"><code class="filename">strstream</code></td></tr></tbody></table></div></div><br class="table-break" /><p>
+<a class="xref" href="using_headers.html#table.cxx11_headers" title="Table 3.5. C++ 2011 Library Headers">Table 3.5, “C++ 2011 Library Headers”</a> and
+<a class="xref" href="using_headers.html#table.cxx11_cheaders" title="Table 3.6. C++ 2011 Library Headers for C Library Facilities">Table 3.6, “C++ 2011 Library Headers for C Library Facilities”</a> show the C++11 include files.
+These are available in C++11 compilation
 mode, i.e. <code class="literal">-std=c++11</code> or <code class="literal">-std=gnu++11</code>.
-</p><p></p><div class="table"><a id="table.cxx11_headers"></a><p class="title"><strong>Table 3.4. C++ 2011 Library Headers</strong></p><div class="table-contents"><table class="table" summary="C++ 2011 Library Headers" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /></colgroup><tbody><tr><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="filename">array</code></td><td align="left"><code class="filename">bitset</code></td><td align="left"><code class="filename">chrono</code></td><td align="left"><code class="filename">complex</code></td></tr><tr><td align="left"><code class="filename">condition_variable</code></td><td align="left"><code class="filename">deque</code></td><td align="left"><code class="filename">exception</code></td><td align="left"><code class="filename">forward_list</code></td><td align="left"><code class="filename">fstream</code></td></tr><tr><td align="left"><code class="filename">functional</code></td><td align="left"><code class="filename">future</code></td><td align="left"><code class="filename">initalizer_list</code></td><td align="left"><code class="filename">iomanip</code></td><td align="left"><code class="filename">ios</code></td></tr><tr><td align="left"><code class="filename">iosfwd</code></td><td align="left"><code class="filename">iostream</code></td><td align="left"><code class="filename">istream</code></td><td align="left"><code class="filename">iterator</code></td><td align="left"><code class="filename">limits</code></td></tr><tr><td align="left"><code class="filename">list</code></td><td align="left"><code class="filename">locale</code></td><td align="left"><code class="filename">map</code></td><td align="left"><code class="filename">memory</code></td><td align="left"><code class="filename">mutex</code></td></tr><tr><td align="left"><code class="filename">new</code></td><td align="left"><code class="filename">numeric</code></td><td align="left"><code class="filename">ostream</code></td><td align="left"><code class="filename">queue</code></td><td align="left"><code class="filename">random</code></td></tr><tr><td align="left"><code class="filename">ratio</code></td><td align="left"><code class="filename">regex</code></td><td align="left"><code class="filename">set</code></td><td align="left"><code class="filename">sstream</code></td><td align="left"><code class="filename">stack</code></td></tr><tr><td align="left"><code class="filename">stdexcept</code></td><td align="left"><code class="filename">streambuf</code></td><td align="left"><code class="filename">string</code></td><td align="left"><code class="filename">system_error</code></td><td align="left"><code class="filename">thread</code></td></tr><tr><td align="left"><code class="filename">tuple</code></td><td align="left"><code class="filename">type_traits</code></td><td align="left"><code class="filename">typeinfo</code></td><td align="left"><code class="filename">unordered_map</code></td><td align="left"><code class="filename">unordered_set</code></td></tr><tr><td align="left"><code class="filename">utility</code></td><td align="left"><code class="filename">valarray</code></td><td align="left"><code class="filename">vector</code></td><td class="auto-generated"> </td><td class="auto-generated"> </td></tr></tbody></table></div></div><br class="table-break" /><p></p><div class="table"><a id="table.cxx11_cheaders"></a><p class="title"><strong>Table 3.5. C++ 2011 Library Headers for C Library Facilities</strong></p><div class="table-contents"><table class="table" summary="C++ 2011 Library Headers for C Library Facilities" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /></colgroup><tbody><tr><td align="left"><code class="filename">cassert</code></td><td align="left"><code class="filename">ccomplex</code></td><td align="left"><code class="filename">cctype</code></td><td align="left"><code class="filename">cerrno</code></td><td align="left"><code class="filename">cfenv</code></td></tr><tr><td align="left"><code class="filename">cfloat</code></td><td align="left"><code class="filename">cinttypes</code></td><td align="left"><code class="filename">ciso646</code></td><td align="left"><code class="filename">climits</code></td><td align="left"><code class="filename">clocale</code></td></tr><tr><td align="left"><code class="filename">cmath</code></td><td align="left"><code class="filename">csetjmp</code></td><td align="left"><code class="filename">csignal</code></td><td align="left"><code class="filename">cstdarg</code></td><td align="left"><code class="filename">cstdbool</code></td></tr><tr><td align="left"><code class="filename">cstddef</code></td><td align="left"><code class="filename">cstdint</code></td><td align="left"><code class="filename">cstdlib</code></td><td align="left"><code class="filename">cstdio</code></td><td align="left"><code class="filename">cstring</code></td></tr><tr><td align="left"><code class="filename">ctgmath</code></td><td align="left"><code class="filename">ctime</code></td><td align="left"><code class="filename">cuchar</code></td><td align="left"><code class="filename">cwchar</code></td><td align="left"><code class="filename">cwctype</code></td></tr></tbody></table></div></div><br class="table-break" /><p>
+Including these headers in C++98/03 mode may result in compilation errors.
+Unless specified otherwise below, they are also available in later modes
+(C++14 etc).
+</p><p></p><div class="table"><a id="table.cxx11_headers"></a><p class="title"><strong>Table 3.5. C++ 2011 Library Headers</strong></p><div class="table-contents"><table class="table" summary="C++ 2011 Library Headers" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /></colgroup><tbody><tr><td align="left"><code class="filename">array</code></td><td align="left"><code class="filename">atomic</code></td><td align="left"><code class="filename">chrono</code></td><td align="left"><code class="filename">codecvt</code></td><td align="left"><code class="filename">condition_variable</code></td></tr><tr><td align="left"><code class="filename">forward_list</code></td><td align="left"><code class="filename">future</code></td><td align="left"><code class="filename">initalizer_list</code></td><td align="left"><code class="filename">mutex</code></td><td align="left"><code class="filename">random</code></td></tr><tr><td align="left"><code class="filename">ratio</code></td><td align="left"><code class="filename">regex</code></td><td align="left"><code class="filename">scoped_allocator</code></td><td align="left"><code class="filename">system_error</code></td><td align="left"><code class="filename">thread</code></td></tr><tr><td align="left"><code class="filename">tuple</code></td><td align="left"><code class="filename">typeindex</code></td><td align="left"><code class="filename">type_traits</code></td><td align="left"><code class="filename">unordered_map</code></td><td align="left"><code class="filename">unordered_set</code></td></tr></tbody></table></div></div><br class="table-break" /><p></p><div class="table"><a id="table.cxx11_cheaders"></a><p class="title"><strong>Table 3.6. C++ 2011 Library Headers for C Library Facilities</strong></p><div class="table-contents"><table class="table" summary="C++ 2011 Library Headers for C Library Facilities" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /></colgroup><tbody><tr><td align="left"><code class="filename">ccomplex</code></td><td align="left"><code class="filename">cfenv</code></td><td align="left"><code class="filename">cinttypes</code></td><td align="left"><code class="filename">cstdalign</code></td><td align="left"><code class="filename">cstdbool</code></td></tr><tr><td align="left"><code class="filename">cstdint</code></td><td align="left"><code class="filename">ctgmath</code></td><td align="left"><code class="filename">cuchar</code></td><td colspan="2" align="left"> </td></tr></tbody></table></div></div><br class="table-break" /><p>
+<a class="xref" href="using_headers.html#table.cxx14_headers" title="Table 3.7. C++ 2014 Library Header">Table 3.7, “C++ 2014 Library Header”</a> shows the C++14 include file.
+This is available in C++14 compilation
+mode, i.e. <code class="literal">-std=c++14</code> or <code class="literal">-std=gnu++14</code>.
+Including this header in C++98/03 mode or C++11 will not result in
+compilation errors, but will not define anything.
+Unless specified otherwise below, it is also available in later modes
+(C++17 etc).
+</p><p></p><div class="table"><a id="table.cxx14_headers"></a><p class="title"><strong>Table 3.7. C++ 2014 Library Header</strong></p><div class="table-contents"><table class="table" summary="C++ 2014 Library Header" border="1"><colgroup><col align="left" class="c1" /></colgroup><tbody><tr><td align="left"><code class="filename">shared_mutex</code></td></tr></tbody></table></div></div><br class="table-break" /><p>
+<a class="xref" href="using_headers.html#table.cxx17_headers" title="Table 3.8. C++ 2017 Library Headers">Table 3.8, “C++ 2017 Library Headers”</a> shows the C++17 include files.
+These are available in C++17 compilation
+mode, i.e. <code class="literal">-std=c++17</code> or <code class="literal">-std=gnu++17</code>.
+Including these headers in earlier modes will not result in
+compilation errors, but will not define anything.
+Unless specified otherwise below, they are also available in later modes
+(C++20 etc).
+</p><p></p><div class="table"><a id="table.cxx17_headers"></a><p class="title"><strong>Table 3.8. C++ 2017 Library Headers</strong></p><div class="table-contents"><table class="table" summary="C++ 2017 Library Headers" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /></colgroup><tbody><tr><td align="left"><code class="filename">any</code></td><td align="left"><code class="filename">charconv</code></td><td align="left"><code class="filename">filesystem</code></td><td align="left"><code class="filename">optional</code></td><td align="left"><code class="filename">string_view</code></td></tr><tr><td align="left"><code class="filename">variant</code></td><td colspan="4" align="left"> </td></tr></tbody></table></div></div><br class="table-break" /><p>
+<a class="xref" href="using_headers.html#table.filesystemts_headers" title="Table 3.9. File System TS Header">Table 3.9, “File System TS Header”</a>,
+shows the additional include file define by the
+File System Technical Specification, ISO/IEC TS 18822.
+This is available in C++11 and later compilation modes.
+Including this header in earlier modes will not result in
+compilation errors, but will not define anything.
+</p><p></p><div class="table"><a id="table.filesystemts_headers"></a><p class="title"><strong>Table 3.9. File System TS Header</strong></p><div class="table-contents"><table class="table" summary="File System TS Header" border="1"><colgroup><col align="left" class="c1" /></colgroup><tbody><tr><td align="left"><code class="filename">experimental/filesystem</code></td></tr></tbody></table></div></div><br class="table-break" /><p>
+<a class="xref" href="using_headers.html#table.libfundts_headers" title="Table 3.10. Library Fundamentals TS Headers">Table 3.10, “Library Fundamentals TS Headers”</a>,
+shows the additional include files define by the C++ Extensions for 
+Library Fundamentals Technical Specification, ISO/IEC TS 19568.
+These are available in C++14 and later compilation modes.
+Including these headers in earlier modes will not result in
+compilation errors, but will not define anything.
+</p><p></p><div class="table"><a id="table.libfundts_headers"></a><p class="title"><strong>Table 3.10. Library Fundamentals TS Headers</strong></p><div class="table-contents"><table class="table" summary="Library Fundamentals TS Headers" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /></colgroup><tbody><tr><td align="left"><code class="filename">experimental/algorithm</code></td><td align="left"><code class="filename">experimental/any</code></td><td align="left"><code class="filename">experimental/array</code></td><td align="left"><code class="filename">experimental/chrono</code></td><td align="left"><code class="filename">experimental/deque</code></td></tr><tr><td align="left"><code class="filename">experimental/forward_list</code></td><td align="left"><code class="filename">experimental/functional</code></td><td align="left"><code class="filename">experimental/iterator</code></td><td align="left"><code class="filename">experimental/list</code></td><td align="left"><code class="filename">experimental/map</code></td></tr><tr><td align="left"><code class="filename">experimental/memory</code></td><td align="left"><code class="filename">experimental/memory_resource</code></td><td align="left"><code class="filename">experimental/numeric</code></td><td align="left"><code class="filename">experimental/optional</code></td><td align="left"><code class="filename">experimental/propagate_const</code></td></tr><tr><td align="left"><code class="filename">experimental/random</code></td><td align="left"><code class="filename">experimental/ratio</code></td><td align="left"><code class="filename">experimental/regex</code></td><td align="left"><code class="filename">experimental/set</code></td><td align="left"><code class="filename">experimental/source_location</code></td></tr><tr><td align="left"><code class="filename">experimental/string</code></td><td align="left"><code class="filename">experimental/string_view</code></td><td align="left"><code class="filename">experimental/system_error</code></td><td align="left"><code class="filename">experimental/tuple</code></td><td align="left"><code class="filename">experimental/type_traits</code></td></tr><tr><td align="left"><code class="filename">experimental/unordered_map</code></td><td align="left"><code class="filename">experimental/unordered_set</code></td><td align="left"><code class="filename">experimental/utility</code></td><td align="left"><code class="filename">experimental/vector</code></td><td align="left"> </td></tr></tbody></table></div></div><br class="table-break" /><p>
   In addition, TR1 includes as:
-</p><div class="table"><a id="table.tr1_headers"></a><p class="title"><strong>Table 3.6. C++ TR 1 Library Headers</strong></p><div class="table-contents"><table class="table" summary="C++ TR 1 Library Headers" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /></colgroup><tbody><tr><td align="left"><code class="filename">tr1/array</code></td><td align="left"><code class="filename">tr1/complex</code></td><td align="left"><code class="filename">tr1/memory</code></td><td align="left"><code class="filename">tr1/functional</code></td><td align="left"><code class="filename">tr1/random</code></td></tr><tr><td align="left"><code class="filename">tr1/regex</code></td><td align="left"><code class="filename">tr1/tuple</code></td><td align="left"><code class="filename">tr1/type_traits</code></td><td align="left"><code class="filename">tr1/unordered_map</code></td><td align="left"><code class="filename">tr1/unordered_set</code></td></tr><tr><td align="left"><code class="filename">tr1/utility</code></td><td class="auto-generated"> </td><td class="auto-generated"> </td><td class="auto-generated"> </td><td class="auto-generated"> </td></tr></tbody></table></div></div><br class="table-break" /><p></p><div class="table"><a id="table.tr1_cheaders"></a><p class="title"><strong>Table 3.7. C++ TR 1 Library Headers for C Library Facilities</strong></p><div class="table-contents"><table class="table" summary="C++ TR 1 Library Headers for C Library Facilities" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /></colgroup><tbody><tr><td align="left"><code class="filename">tr1/ccomplex</code></td><td align="left"><code class="filename">tr1/cfenv</code></td><td align="left"><code class="filename">tr1/cfloat</code></td><td align="left"><code class="filename">tr1/cmath</code></td><td align="left"><code class="filename">tr1/cinttypes</code></td></tr><tr><td align="left"><code class="filename">tr1/climits</code></td><td align="left"><code class="filename">tr1/cstdarg</code></td><td align="left"><code class="filename">tr1/cstdbool</code></td><td align="left"><code class="filename">tr1/cstdint</code></td><td align="left"><code class="filename">tr1/cstdio</code></td></tr><tr><td align="left"><code class="filename">tr1/cstdlib</code></td><td align="left"><code class="filename">tr1/ctgmath</code></td><td align="left"><code class="filename">tr1/ctime</code></td><td align="left"><code class="filename">tr1/cwchar</code></td><td align="left"><code class="filename">tr1/cwctype</code></td></tr></tbody></table></div></div><br class="table-break" /><p>Decimal floating-point arithmetic is available if the C++
+</p><div class="table"><a id="table.tr1_headers"></a><p class="title"><strong>Table 3.11. C++ TR 1 Library Headers</strong></p><div class="table-contents"><table class="table" summary="C++ TR 1 Library Headers" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /></colgroup><tbody><tr><td align="left"><code class="filename">tr1/array</code></td><td align="left"><code class="filename">tr1/complex</code></td><td align="left"><code class="filename">tr1/memory</code></td><td align="left"><code class="filename">tr1/functional</code></td><td align="left"><code class="filename">tr1/random</code></td></tr><tr><td align="left"><code class="filename">tr1/regex</code></td><td align="left"><code class="filename">tr1/tuple</code></td><td align="left"><code class="filename">tr1/type_traits</code></td><td align="left"><code class="filename">tr1/unordered_map</code></td><td align="left"><code class="filename">tr1/unordered_set</code></td></tr><tr><td align="left"><code class="filename">tr1/utility</code></td><td colspan="4" align="left"> </td></tr></tbody></table></div></div><br class="table-break" /><p></p><div class="table"><a id="table.tr1_cheaders"></a><p class="title"><strong>Table 3.12. C++ TR 1 Library Headers for C Library Facilities</strong></p><div class="table-contents"><table class="table" summary="C++ TR 1 Library Headers for C Library Facilities" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /></colgroup><tbody><tr><td align="left"><code class="filename">tr1/ccomplex</code></td><td align="left"><code class="filename">tr1/cfenv</code></td><td align="left"><code class="filename">tr1/cfloat</code></td><td align="left"><code class="filename">tr1/cmath</code></td><td align="left"><code class="filename">tr1/cinttypes</code></td></tr><tr><td align="left"><code class="filename">tr1/climits</code></td><td align="left"><code class="filename">tr1/cstdarg</code></td><td align="left"><code class="filename">tr1/cstdbool</code></td><td align="left"><code class="filename">tr1/cstdint</code></td><td align="left"><code class="filename">tr1/cstdio</code></td></tr><tr><td align="left"><code class="filename">tr1/cstdlib</code></td><td align="left"><code class="filename">tr1/ctgmath</code></td><td align="left"><code class="filename">tr1/ctime</code></td><td align="left"><code class="filename">tr1/cwchar</code></td><td align="left"><code class="filename">tr1/cwctype</code></td></tr></tbody></table></div></div><br class="table-break" /><p>Decimal floating-point arithmetic is available if the C++
 compiler supports scalar decimal floating-point types defined via
 <code class="code">__attribute__((mode(SD|DD|LD)))</code>.
-</p><div class="table"><a id="table.decfp_headers"></a><p class="title"><strong>Table 3.8. C++ TR 24733 Decimal Floating-Point Header</strong></p><div class="table-contents"><table class="table" summary="C++ TR 24733 Decimal Floating-Point Header" border="1"><colgroup><col align="left" class="c1" /></colgroup><tbody><tr><td align="left"><code class="filename">decimal/decimal</code></td></tr></tbody></table></div></div><br class="table-break" /><p>
+</p><div class="table"><a id="table.decfp_headers"></a><p class="title"><strong>Table 3.13. C++ TR 24733 Decimal Floating-Point Header</strong></p><div class="table-contents"><table class="table" summary="C++ TR 24733 Decimal Floating-Point Header" border="1"><colgroup><col align="left" class="c1" /></colgroup><tbody><tr><td align="left"><code class="filename">decimal/decimal</code></td></tr></tbody></table></div></div><br class="table-break" /><p>
   Also included are files for the C++ ABI interface:
-</p><div class="table"><a id="table.abi_headers"></a><p class="title"><strong>Table 3.9. C++ ABI Headers</strong></p><div class="table-contents"><table class="table" summary="C++ ABI Headers" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /></colgroup><tbody><tr><td align="left"><code class="filename">cxxabi.h</code></td><td align="left"><code class="filename">cxxabi_forced.h</code></td></tr></tbody></table></div></div><br class="table-break" /><p>
+</p><div class="table"><a id="table.abi_headers"></a><p class="title"><strong>Table 3.14. C++ ABI Headers</strong></p><div class="table-contents"><table class="table" summary="C++ ABI Headers" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /></colgroup><tbody><tr><td align="left"><code class="filename">cxxabi.h</code></td><td align="left"><code class="filename">cxxabi_forced.h</code></td></tr></tbody></table></div></div><br class="table-break" /><p>
   And a large variety of extensions.
-</p><div class="table"><a id="table.ext_headers"></a><p class="title"><strong>Table 3.10. Extension Headers</strong></p><div class="table-contents"><table class="table" summary="Extension Headers" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /></colgroup><tbody><tr><td align="left"><code class="filename">ext/algorithm</code></td><td align="left"><code class="filename">ext/atomicity.h</code></td><td align="left"><code class="filename">ext/array_allocator.h</code></td><td align="left"><code class="filename">ext/bitmap_allocator.h</code></td><td align="left"><code class="filename">ext/cast.h</code></td></tr><tr><td align="left"><code class="filename">ext/codecvt_specializations.h</code></td><td align="left"><code class="filename">ext/concurrence.h</code></td><td align="left"><code class="filename">ext/debug_allocator.h</code></td><td align="left"><code class="filename">ext/enc_filebuf.h</code></td><td align="left"><code class="filename">ext/extptr_allocator.h</code></td></tr><tr><td align="left"><code class="filename">ext/functional</code></td><td align="left"><code class="filename">ext/iterator</code></td><td align="left"><code class="filename">ext/malloc_allocator.h</code></td><td align="left"><code class="filename">ext/memory</code></td><td align="left"><code class="filename">ext/mt_allocator.h</code></td></tr><tr><td align="left"><code class="filename">ext/new_allocator.h</code></td><td align="left"><code class="filename">ext/numeric</code></td><td align="left"><code class="filename">ext/numeric_traits.h</code></td><td align="left"><code class="filename">ext/pb_ds/assoc_container.h</code></td><td align="left"><code class="filename">ext/pb_ds/priority_queue.h</code></td></tr><tr><td align="left"><code class="filename">ext/pod_char_traits.h</code></td><td align="left"><code class="filename">ext/pool_allocator.h</code></td><td align="left"><code class="filename">ext/rb_tree</code></td><td align="left"><code class="filename">ext/rope</code></td><td align="left"><code class="filename">ext/slist</code></td></tr><tr><td align="left"><code class="filename">ext/stdio_filebuf.h</code></td><td align="left"><code class="filename">ext/stdio_sync_filebuf.h</code></td><td align="left"><code class="filename">ext/throw_allocator.h</code></td><td align="left"><code class="filename">ext/typelist.h</code></td><td align="left"><code class="filename">ext/type_traits.h</code></td></tr><tr><td align="left"><code class="filename">ext/vstring.h</code></td><td class="auto-generated"> </td><td class="auto-generated"> </td><td class="auto-generated"> </td><td class="auto-generated"> </td></tr></tbody></table></div></div><br class="table-break" /><p></p><div class="table"><a id="table.debug_headers"></a><p class="title"><strong>Table 3.11. Extension Debug Headers</strong></p><div class="table-contents"><table class="table" summary="Extension Debug Headers" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /></colgroup><tbody><tr><td align="left"><code class="filename">debug/bitset</code></td><td align="left"><code class="filename">debug/deque</code></td><td align="left"><code class="filename">debug/list</code></td><td align="left"><code class="filename">debug/map</code></td><td align="left"><code class="filename">debug/set</code></td></tr><tr><td align="left"><code class="filename">debug/string</code></td><td align="left"><code class="filename">debug/unordered_map</code></td><td align="left"><code class="filename">debug/unordered_set</code></td><td align="left"><code class="filename">debug/vector</code></td><td class="auto-generated"> </td></tr></tbody></table></div></div><br class="table-break" /><p></p><div class="table"><a id="table.profile_headers"></a><p class="title"><strong>Table 3.12. Extension Profile Headers</strong></p><div class="table-contents"><table class="table" summary="Extension Profile Headers" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /></colgroup><tbody><tr><td align="left"><code class="filename">profile/bitset</code></td><td align="left"><code class="filename">profile/deque</code></td><td align="left"><code class="filename">profile/list</code></td><td align="left"><code class="filename">profile/map</code></td></tr><tr><td align="left"><code class="filename">profile/set</code></td><td align="left"><code class="filename">profile/unordered_map</code></td><td align="left"><code class="filename">profile/unordered_set</code></td><td align="left"><code class="filename">profile/vector</code></td></tr></tbody></table></div></div><br class="table-break" /><p></p><div class="table"><a id="table.parallel_headers"></a><p class="title"><strong>Table 3.13. Extension Parallel Headers</strong></p><div class="table-contents"><table class="table" summary="Extension Parallel Headers" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /></colgroup><tbody><tr><td align="left"><code class="filename">parallel/algorithm</code></td><td align="left"><code class="filename">parallel/numeric</code></td></tr></tbody></table></div></div><br class="table-break" /></div><div class="section"><div class="titlepage"><div><div><h3 class="title"><a id="manual.intro.using.headers.mixing"></a>Mixing Headers</h3></div></div></div><p> A few simple rules.
+</p><div class="table"><a id="table.ext_headers"></a><p class="title"><strong>Table 3.15. Extension Headers</strong></p><div class="table-contents"><table class="table" summary="Extension Headers" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /></colgroup><tbody><tr><td align="left"><code class="filename">ext/algorithm</code></td><td align="left"><code class="filename">ext/atomicity.h</code></td><td align="left"><code class="filename">ext/array_allocator.h</code></td><td align="left"><code class="filename">ext/bitmap_allocator.h</code></td><td align="left"><code class="filename">ext/cast.h</code></td></tr><tr><td align="left"><code class="filename">ext/codecvt_specializations.h</code></td><td align="left"><code class="filename">ext/concurrence.h</code></td><td align="left"><code class="filename">ext/debug_allocator.h</code></td><td align="left"><code class="filename">ext/enc_filebuf.h</code></td><td align="left"><code class="filename">ext/extptr_allocator.h</code></td></tr><tr><td align="left"><code class="filename">ext/functional</code></td><td align="left"><code class="filename">ext/iterator</code></td><td align="left"><code class="filename">ext/malloc_allocator.h</code></td><td align="left"><code class="filename">ext/memory</code></td><td align="left"><code class="filename">ext/mt_allocator.h</code></td></tr><tr><td align="left"><code class="filename">ext/new_allocator.h</code></td><td align="left"><code class="filename">ext/numeric</code></td><td align="left"><code class="filename">ext/numeric_traits.h</code></td><td align="left"><code class="filename">ext/pb_ds/assoc_container.h</code></td><td align="left"><code class="filename">ext/pb_ds/priority_queue.h</code></td></tr><tr><td align="left"><code class="filename">ext/pod_char_traits.h</code></td><td align="left"><code class="filename">ext/pool_allocator.h</code></td><td align="left"><code class="filename">ext/rb_tree</code></td><td align="left"><code class="filename">ext/rope</code></td><td align="left"><code class="filename">ext/slist</code></td></tr><tr><td align="left"><code class="filename">ext/stdio_filebuf.h</code></td><td align="left"><code class="filename">ext/stdio_sync_filebuf.h</code></td><td align="left"><code class="filename">ext/throw_allocator.h</code></td><td align="left"><code class="filename">ext/typelist.h</code></td><td align="left"><code class="filename">ext/type_traits.h</code></td></tr><tr><td align="left"><code class="filename">ext/vstring.h</code></td><td colspan="4" align="left"> </td></tr></tbody></table></div></div><br class="table-break" /><p></p><div class="table"><a id="table.debug_headers"></a><p class="title"><strong>Table 3.16. Extension Debug Headers</strong></p><div class="table-contents"><table class="table" summary="Extension Debug Headers" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /></colgroup><tbody><tr><td align="left"><code class="filename">debug/array</code></td><td align="left"><code class="filename">debug/bitset</code></td><td align="left"><code class="filename">debug/deque</code></td><td align="left"><code class="filename">debug/forward_list</code></td><td align="left"><code class="filename">debug/list</code></td></tr><tr><td align="left"><code class="filename">debug/map</code></td><td align="left"><code class="filename">debug/set</code></td><td align="left"><code class="filename">debug/string</code></td><td align="left"><code class="filename">debug/unordered_map</code></td><td align="left"><code class="filename">debug/unordered_set</code></td></tr><tr><td align="left"><code class="filename">debug/vector</code></td><td colspan="4" align="left"> </td></tr></tbody></table></div></div><br class="table-break" /><p></p><div class="table"><a id="table.profile_headers"></a><p class="title"><strong>Table 3.17. Extension Profile Headers</strong></p><div class="table-contents"><table class="table" summary="Extension Profile Headers" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /></colgroup><tbody><tr><td align="left"><code class="filename">profile/bitset</code></td><td align="left"><code class="filename">profile/deque</code></td><td align="left"><code class="filename">profile/list</code></td><td align="left"><code class="filename">profile/map</code></td></tr><tr><td align="left"><code class="filename">profile/set</code></td><td align="left"><code class="filename">profile/unordered_map</code></td><td align="left"><code class="filename">profile/unordered_set</code></td><td align="left"><code class="filename">profile/vector</code></td></tr></tbody></table></div></div><br class="table-break" /><p></p><div class="table"><a id="table.parallel_headers"></a><p class="title"><strong>Table 3.18. Extension Parallel Headers</strong></p><div class="table-contents"><table class="table" summary="Extension Parallel Headers" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /></colgroup><tbody><tr><td align="left"><code class="filename">parallel/algorithm</code></td><td align="left"><code class="filename">parallel/numeric</code></td></tr></tbody></table></div></div><br class="table-break" /></div><div class="section"><div class="titlepage"><div><div><h3 class="title"><a id="manual.intro.using.headers.mixing"></a>Mixing Headers</h3></div></div></div><p> A few simple rules.
 </p><p>First, mixing different dialects of the standard headers is not
 possible. It's an all-or-nothing affair. Thus, code like
 </p><pre class="programlisting">
Index: libstdc++-v3/doc/html/manual/index.html
===================================================================
--- libstdc++-v3/doc/html/manual/index.html	(.../tags/gcc_8_2_0_release)
+++ libstdc++-v3/doc/html/manual/index.html	(.../branches/gcc-8-branch)
@@ -149,7 +149,7 @@
 	  </a></dt><dt>22.10. <a href="policy_data_structures_design.html#id-1.3.5.9.4.3.3.3.23">Non-unique Mapping Containers</a></dt><dt>22.11. <a href="policy_data_structures_design.html#id-1.3.5.9.4.3.4.3.5">Point Iterator Hierarchy</a></dt><dt>22.12. <a href="policy_data_structures_design.html#id-1.3.5.9.4.3.4.4.5">Invalidation Guarantee Tags Hierarchy</a></dt><dt>22.13. <a href="policy_data_structures_design.html#id-1.3.5.9.4.3.5.7.4">Container Tag Hierarchy</a></dt><dt>22.14. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.2.3.2.2.3">Hash functions, ranged-hash functions, and
 	      range-hashing functions</a></dt><dt>22.15. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.2.3.2.5.3.4">Insert hash sequence diagram</a></dt><dt>22.16. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.2.3.2.5.3.6">Insert hash sequence diagram with a null policy</a></dt><dt>22.17. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.2.3.2.5.5.5">Hash policy class diagram</a></dt><dt>22.18. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.2.3.3.4.7">Balls and bins</a></dt><dt>22.19. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.2.3.3.5.3.6">Insert resize sequence diagram</a></dt><dt>22.20. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.2.3.3.5.3.9">Standard resize policy trigger sequence
 		diagram</a></dt><dt>22.21. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.2.3.3.5.3.10">Standard resize policy size sequence
-		diagram</a></dt><dt>22.22. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.3.3.2.5">Tree node invariants</a></dt><dt>22.23. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.3.3.2.8">Tree node invalidation</a></dt><dt>22.24. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.3.3.2.11.3">A tree and its update policy</a></dt><dt>22.25. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.3.3.2.11.8">Restoring node invariants</a></dt><dt>22.26. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.3.3.2.11.10">Insert update sequence</a></dt><dt>22.27. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.3.3.2.11.20">Useless update path</a></dt><dt>22.28. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.4.3.2.10">A PATRICIA trie</a></dt><dt>22.29. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.4.3.3.5">A trie and its update policy</a></dt><dt>22.30. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.5.3.3.3">A simple list</a></dt><dt>22.31. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.5.3.3.6">The counter algorithm</a></dt><dt>22.32. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.6.3.3.3">Underlying Priority-Queue Data-Structures.</a></dt><dt>22.33. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.6.3.4.4">Priority-Queue Data-Structure Tags.</a></dt><dt>B.1. <a href="appendix_porting.html#fig.build_hacking.deps">Configure and Build File Dependencies</a></dt></dl></div><div class="list-of-tables"><p><strong>List of Tables</strong></p><dl><dt>1.1. <a href="status.html#table.cxx98_status">C++ 1998/2003 Implementation Status</a></dt><dt>1.2. <a href="status.html#table.cxx11_status">C++ 2011 Implementation Status</a></dt><dt>1.3. <a href="status.html#table.cxx14_status">C++ 2014 Implementation Status</a></dt><dt>1.4. <a href="status.html#table.ts_status">C++ Technical Specifications Implementation Status</a></dt><dt>1.5. <a href="status.html#table.cxx17_status">C++ 2017 Implementation Status</a></dt><dt>1.6. <a href="status.html#table.cxx17_ts_status">C++ Technical Specifications Implementation Status</a></dt><dt>1.7. <a href="status.html#table.tr1_status">C++ TR1 Implementation Status</a></dt><dt>1.8. <a href="status.html#table.decfp_status">C++ TR 24733 Implementation Status</a></dt><dt>1.9. <a href="status.html#table.specfun_status">C++ Special Functions Implementation Status</a></dt><dt>3.1. <a href="using.html#table.cmd_options">C++ Command Options</a></dt><dt>3.2. <a href="using_headers.html#table.cxx98_headers">C++ 1998 Library Headers</a></dt><dt>3.3. <a href="using_headers.html#table.cxx98_cheaders">C++ 1998 Library Headers for C Library Facilities</a></dt><dt>3.4. <a href="using_headers.html#table.cxx11_headers">C++ 2011 Library Headers</a></dt><dt>3.5. <a href="using_headers.html#table.cxx11_cheaders">C++ 2011 Library Headers for C Library Facilities</a></dt><dt>3.6. <a href="using_headers.html#table.tr1_headers">C++ TR 1 Library Headers</a></dt><dt>3.7. <a href="using_headers.html#table.tr1_cheaders">C++ TR 1 Library Headers for C Library Facilities</a></dt><dt>3.8. <a href="using_headers.html#table.decfp_headers">C++ TR 24733 Decimal Floating-Point Header</a></dt><dt>3.9. <a href="using_headers.html#table.abi_headers">C++ ABI Headers</a></dt><dt>3.10. <a href="using_headers.html#table.ext_headers">Extension Headers</a></dt><dt>3.11. <a href="using_headers.html#table.debug_headers">Extension Debug Headers</a></dt><dt>3.12. <a href="using_headers.html#table.profile_headers">Extension Profile Headers</a></dt><dt>3.13. <a href="using_headers.html#table.parallel_headers">Extension Parallel Headers</a></dt><dt>17.1. <a href="debug_mode_using.html#table.debug_mode_containers">Debugging Containers</a></dt><dt>17.2. <a href="debug_mode_using.html#table.debug_mode_containers_cxx11">Debugging Containers C++11</a></dt><dt>18.1. <a href="parallel_mode_using.html#table.parallel_algos">Parallel Algorithms</a></dt><dt>19.1. <a href="profile_mode_design.html#table.profile_code_loc">Profile Code Location</a></dt><dt>19.2. <a href="profile_mode_diagnostics.html#table.profile_diagnostics">Profile Diagnostics</a></dt><dt>21.1. <a href="bitmap_allocator_impl.html#table.bitmap_alloc">Bitmap Allocator Memory Map</a></dt><dt>B.1. <a href="documentation_hacking.html#table.doxygen_prereq">Doxygen Prerequisites</a></dt><dt>B.2. <a href="documentation_hacking.html#table.doxygen_cmp">HTML to Doxygen Markup Comparison</a></dt><dt>B.3. <a href="documentation_hacking.html#table.docbook_prereq">Docbook Prerequisites</a></dt><dt>B.4. <a href="documentation_hacking.html#table.docbook_cmp">HTML to Docbook XML Markup Comparison</a></dt><dt>B.5. <a href="documentation_hacking.html#table.docbook_elem">Docbook XML Element Use</a></dt><dt>B.6. <a href="api.html#table.extension_allocators">Extension Allocators</a></dt><dt>B.7. <a href="api.html#table.extension_allocators2">Extension Allocators Continued</a></dt></dl></div><div class="list-of-equations"><p><strong>List of Equations</strong></p><dl><dt>22.1. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.2.3.2.2.15">Ranged Hash Function</a></dt><dt>22.2. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.2.3.2.3.3">Range-Hashing, Division Method</a></dt><dt>22.3. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.2.3.2.3.9">Division via Prime Modulo</a></dt><dt>22.4. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.2.3.2.3.11">Division via Bit Mask</a></dt><dt>22.5. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.2.3.2.4.7">
+		diagram</a></dt><dt>22.22. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.3.3.2.5">Tree node invariants</a></dt><dt>22.23. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.3.3.2.8">Tree node invalidation</a></dt><dt>22.24. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.3.3.2.11.3">A tree and its update policy</a></dt><dt>22.25. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.3.3.2.11.8">Restoring node invariants</a></dt><dt>22.26. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.3.3.2.11.10">Insert update sequence</a></dt><dt>22.27. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.3.3.2.11.20">Useless update path</a></dt><dt>22.28. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.4.3.2.10">A PATRICIA trie</a></dt><dt>22.29. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.4.3.3.5">A trie and its update policy</a></dt><dt>22.30. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.5.3.3.3">A simple list</a></dt><dt>22.31. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.5.3.3.6">The counter algorithm</a></dt><dt>22.32. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.6.3.3.3">Underlying Priority-Queue Data-Structures.</a></dt><dt>22.33. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.6.3.4.4">Priority-Queue Data-Structure Tags.</a></dt><dt>B.1. <a href="appendix_porting.html#fig.build_hacking.deps">Configure and Build File Dependencies</a></dt></dl></div><div class="list-of-tables"><p><strong>List of Tables</strong></p><dl><dt>1.1. <a href="status.html#table.cxx98_status">C++ 1998/2003 Implementation Status</a></dt><dt>1.2. <a href="status.html#table.cxx11_status">C++ 2011 Implementation Status</a></dt><dt>1.3. <a href="status.html#table.cxx14_status">C++ 2014 Implementation Status</a></dt><dt>1.4. <a href="status.html#table.ts_status">C++ Technical Specifications Implementation Status</a></dt><dt>1.5. <a href="status.html#table.cxx17_status">C++ 2017 Implementation Status</a></dt><dt>1.6. <a href="status.html#table.cxx17_ts_status">C++ Technical Specifications Implementation Status</a></dt><dt>1.7. <a href="status.html#table.tr1_status">C++ TR1 Implementation Status</a></dt><dt>1.8. <a href="status.html#table.decfp_status">C++ TR 24733 Implementation Status</a></dt><dt>1.9. <a href="status.html#table.specfun_status">C++ Special Functions Implementation Status</a></dt><dt>3.1. <a href="using.html#table.cmd_options">C++ Command Options</a></dt><dt>3.2. <a href="using_headers.html#table.cxx98_headers">C++ 1998 Library Headers</a></dt><dt>3.3. <a href="using_headers.html#table.cxx98_cheaders">C++ 1998 Library Headers for C Library Facilities</a></dt><dt>3.4. <a href="using_headers.html#table.cxx98_deprheaders">C++ 1998 Deprecated Library Header</a></dt><dt>3.5. <a href="using_headers.html#table.cxx11_headers">C++ 2011 Library Headers</a></dt><dt>3.6. <a href="using_headers.html#table.cxx11_cheaders">C++ 2011 Library Headers for C Library Facilities</a></dt><dt>3.7. <a href="using_headers.html#table.cxx14_headers">C++ 2014 Library Header</a></dt><dt>3.8. <a href="using_headers.html#table.cxx17_headers">C++ 2017 Library Headers</a></dt><dt>3.9. <a href="using_headers.html#table.filesystemts_headers">File System TS Header</a></dt><dt>3.10. <a href="using_headers.html#table.libfundts_headers">Library Fundamentals TS Headers</a></dt><dt>3.11. <a href="using_headers.html#table.tr1_headers">C++ TR 1 Library Headers</a></dt><dt>3.12. <a href="using_headers.html#table.tr1_cheaders">C++ TR 1 Library Headers for C Library Facilities</a></dt><dt>3.13. <a href="using_headers.html#table.decfp_headers">C++ TR 24733 Decimal Floating-Point Header</a></dt><dt>3.14. <a href="using_headers.html#table.abi_headers">C++ ABI Headers</a></dt><dt>3.15. <a href="using_headers.html#table.ext_headers">Extension Headers</a></dt><dt>3.16. <a href="using_headers.html#table.debug_headers">Extension Debug Headers</a></dt><dt>3.17. <a href="using_headers.html#table.profile_headers">Extension Profile Headers</a></dt><dt>3.18. <a href="using_headers.html#table.parallel_headers">Extension Parallel Headers</a></dt><dt>17.1. <a href="debug_mode_using.html#table.debug_mode_containers">Debugging Containers</a></dt><dt>17.2. <a href="debug_mode_using.html#table.debug_mode_containers_cxx11">Debugging Containers C++11</a></dt><dt>18.1. <a href="parallel_mode_using.html#table.parallel_algos">Parallel Algorithms</a></dt><dt>19.1. <a href="profile_mode_design.html#table.profile_code_loc">Profile Code Location</a></dt><dt>19.2. <a href="profile_mode_diagnostics.html#table.profile_diagnostics">Profile Diagnostics</a></dt><dt>21.1. <a href="bitmap_allocator_impl.html#table.bitmap_alloc">Bitmap Allocator Memory Map</a></dt><dt>B.1. <a href="documentation_hacking.html#table.doxygen_prereq">Doxygen Prerequisites</a></dt><dt>B.2. <a href="documentation_hacking.html#table.doxygen_cmp">HTML to Doxygen Markup Comparison</a></dt><dt>B.3. <a href="documentation_hacking.html#table.docbook_prereq">Docbook Prerequisites</a></dt><dt>B.4. <a href="documentation_hacking.html#table.docbook_cmp">HTML to Docbook XML Markup Comparison</a></dt><dt>B.5. <a href="documentation_hacking.html#table.docbook_elem">Docbook XML Element Use</a></dt><dt>B.6. <a href="api.html#table.extension_allocators">Extension Allocators</a></dt><dt>B.7. <a href="api.html#table.extension_allocators2">Extension Allocators Continued</a></dt></dl></div><div class="list-of-equations"><p><strong>List of Equations</strong></p><dl><dt>22.1. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.2.3.2.2.15">Ranged Hash Function</a></dt><dt>22.2. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.2.3.2.3.3">Range-Hashing, Division Method</a></dt><dt>22.3. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.2.3.2.3.9">Division via Prime Modulo</a></dt><dt>22.4. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.2.3.2.3.11">Division via Bit Mask</a></dt><dt>22.5. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.2.3.2.4.7">
 		A Standard String Hash Function
 	      </a></dt><dt>22.6. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.2.3.2.4.12">
 		Only k String DNA Hash
Index: libstdc++-v3/include/Makefile.in
===================================================================
--- libstdc++-v3/include/Makefile.in	(.../tags/gcc_8_2_0_release)
+++ libstdc++-v3/include/Makefile.in	(.../branches/gcc-8-branch)
@@ -1662,6 +1662,11 @@
 @ENABLE_ALLOCATOR_NEW_FALSE@stamp-allocator-new:
 @ENABLE_ALLOCATOR_NEW_FALSE@	echo 0 > stamp-allocator-new
 
+@ENABLE_FLOAT128_TRUE@stamp-float128:
+@ENABLE_FLOAT128_TRUE@	echo 'define _GLIBCXX_USE_FLOAT128 1' > stamp-float128
+@ENABLE_FLOAT128_FALSE@stamp-float128:
+@ENABLE_FLOAT128_FALSE@	echo 'undef _GLIBCXX_USE_FLOAT128' > stamp-float128
+
 # NB: The non-empty default ldbl_compat works around an AIX sed
 # oddity, see libstdc++/31957 for details.
 ${host_builddir}/c++config.h: ${CONFIG_HEADER} \
@@ -1673,7 +1678,8 @@
 			      stamp-extern-template \
 			      stamp-dual-abi \
 			      stamp-cxx11-abi \
-			      stamp-allocator-new
+			      stamp-allocator-new \
+			      stamp-float128
 	@date=`cat ${toplevel_srcdir}/gcc/DATESTAMP` ;\
 	release=`sed 's/^\([0-9]*\).*$$/\1/' ${toplevel_srcdir}/gcc/BASE-VER` ;\
 	ns_version=`cat stamp-namespace-version` ;\
@@ -1682,6 +1688,7 @@
 	dualabi=`cat stamp-dual-abi` ;\
 	cxx11abi=`cat stamp-cxx11-abi` ;\
 	allocatornew=`cat stamp-allocator-new` ;\
+	float128=`cat stamp-float128` ;\
 	ldbl_compat='s,g,g,' ;\
 	grep "^[	 ]*#[	 ]*define[	 ][	 ]*_GLIBCXX_LONG_DOUBLE_COMPAT[	 ][	 ]*1[	 ]*$$" \
 	${CONFIG_HEADER} > /dev/null 2>&1 \
@@ -1694,6 +1701,7 @@
 	-e "s,define _GLIBCXX_USE_DUAL_ABI, define _GLIBCXX_USE_DUAL_ABI $$dualabi," \
 	-e "s,define _GLIBCXX_USE_CXX11_ABI, define _GLIBCXX_USE_CXX11_ABI $$cxx11abi," \
 	-e "s,define _GLIBCXX_USE_ALLOCATOR_NEW, define _GLIBCXX_USE_ALLOCATOR_NEW $$allocatornew," \
+	-e "s,define _GLIBCXX_USE_FLOAT128,$$float128," \
 	-e "$$ldbl_compat" \
 	    < ${glibcxx_srcdir}/include/bits/c++config > $@ ;\
 	sed -e 's/HAVE_/_GLIBCXX_HAVE_/g' \
Index: libstdc++-v3/include/std/thread
===================================================================
--- libstdc++-v3/include/std/thread	(.../tags/gcc_8_2_0_release)
+++ libstdc++-v3/include/std/thread	(.../branches/gcc-8-branch)
@@ -102,21 +102,26 @@
   private:
     id				_M_id;
 
-  public:
-    thread() noexcept = default;
     // _GLIBCXX_RESOLVE_LIB_DEFECTS
     // 2097.  packaged_task constructors should be constrained
-    thread(thread&) = delete;
-    thread(const thread&) = delete;
-    thread(const thread&&) = delete;
+    template<typename _Tp>
+      using __not_same = __not_<is_same<
+	typename remove_cv<typename remove_reference<_Tp>::type>::type,
+	thread>>;
 
-    thread(thread&& __t) noexcept
-    { swap(__t); }
+  public:
+    thread() noexcept = default;
 
-    template<typename _Callable, typename... _Args>
+    template<typename _Callable, typename... _Args,
+	     typename = _Require<__not_same<_Callable>>>
       explicit
       thread(_Callable&& __f, _Args&&... __args)
       {
+	static_assert( __is_invocable<typename decay<_Callable>::type,
+				      typename decay<_Args>::type...>::value,
+	  "std::thread arguments must be invocable after conversion to rvalues"
+	  );
+
 #ifdef GTHR_ACTIVE_PROXY
 	// Create a reference to pthread_create, not just the gthr weak symbol.
 	auto __depend = reinterpret_cast<void(*)()>(&pthread_create);
@@ -135,6 +140,11 @@
 	std::terminate();
     }
 
+    thread(const thread&) = delete;
+
+    thread(thread&& __t) noexcept
+    { swap(__t); }
+
     thread& operator=(const thread&) = delete;
 
     thread& operator=(thread&& __t) noexcept
Index: libstdc++-v3/include/std/functional
===================================================================
--- libstdc++-v3/include/std/functional	(.../tags/gcc_8_2_0_release)
+++ libstdc++-v3/include/std/functional	(.../branches/gcc-8-branch)
@@ -864,7 +864,8 @@
       template<typename... _Args>					\
 	decltype(_S_not<__inv_res_t<_Fn _QUALS, _Args...>>())		\
 	operator()(_Args&&... __args) _QUALS				\
-	noexcept(noexcept(_S_not<__inv_res_t<_Fn _QUALS, _Args...>>()))	\
+	noexcept(__is_nothrow_invocable<_Fn _QUALS, _Args...>::value	\
+	    && noexcept(_S_not<__inv_res_t<_Fn _QUALS, _Args...>>()))	\
 	{								\
 	  return !std::__invoke(std::forward< _Fn _QUALS >(_M_fn),	\
 				std::forward<_Args>(__args)...);	\
Index: libstdc++-v3/include/std/variant
===================================================================
--- libstdc++-v3/include/std/variant	(.../tags/gcc_8_2_0_release)
+++ libstdc++-v3/include/std/variant	(.../branches/gcc-8-branch)
@@ -506,6 +506,20 @@
 	  }
       }
 
+      void _M_destructive_move(_Move_ctor_base&& __rhs)
+      {
+	this->~_Move_ctor_base();
+	__try
+	  {
+	    ::new (this) _Move_ctor_base(std::move(__rhs));
+	  }
+	__catch (...)
+	  {
+	    this->_M_index = variant_npos;
+	    __throw_exception_again;
+	  }
+      }
+
       _Move_ctor_base(const _Move_ctor_base&) = default;
       _Move_ctor_base& operator=(const _Move_ctor_base&) = default;
       _Move_ctor_base& operator=(_Move_ctor_base&&) = default;
@@ -516,6 +530,12 @@
     {
       using _Base = _Copy_ctor_alias<_Types...>;
       using _Base::_Base;
+
+      void _M_destructive_move(_Move_ctor_base&& __rhs)
+      {
+	this->~_Move_ctor_base();
+	::new (this) _Move_ctor_base(std::move(__rhs));
+      }
     };
 
   template<typename... _Types>
@@ -538,22 +558,14 @@
 	      {
 		static constexpr void (*_S_vtable[])(void*, void*) =
 		  { &__erased_assign<_Types&, const _Types&>... };
-		_S_vtable[__rhs._M_index](this->_M_storage(), __rhs._M_storage());
+		_S_vtable[__rhs._M_index](this->_M_storage(),
+					  __rhs._M_storage());
 	      }
 	  }
 	else
 	  {
 	    _Copy_assign_base __tmp(__rhs);
-	    this->~_Copy_assign_base();
-	    __try
-	      {
-		::new (this) _Copy_assign_base(std::move(__tmp));
-	      }
-	    __catch (...)
-	      {
-		this->_M_index = variant_npos;
-		__throw_exception_again;
-	      }
+	    this->_M_destructive_move(std::move(__tmp));
 	  }
 	__glibcxx_assert(this->_M_index == __rhs._M_index);
 	return *this;
@@ -582,20 +594,6 @@
       using _Base = _Copy_assign_alias<_Types...>;
       using _Base::_Base;
 
-      void _M_destructive_move(_Move_assign_base&& __rhs)
-      {
-	this->~_Move_assign_base();
-	__try
-	  {
-	    ::new (this) _Move_assign_base(std::move(__rhs));
-	  }
-	__catch (...)
-	  {
-	    this->_M_index = variant_npos;
-	    __throw_exception_again;
-	  }
-      }
-
       _Move_assign_base&
       operator=(_Move_assign_base&& __rhs)
 	  noexcept(_Traits<_Types...>::_S_nothrow_move_assign)
@@ -613,16 +611,7 @@
 	else
 	  {
 	    _Move_assign_base __tmp(std::move(__rhs));
-	    this->~_Move_assign_base();
-	    __try
-	      {
-		::new (this) _Move_assign_base(std::move(__tmp));
-	      }
-	    __catch (...)
-	      {
-		this->_M_index = variant_npos;
-		__throw_exception_again;
-	      }
+	    this->_M_destructive_move(std::move(__tmp));
 	  }
 	__glibcxx_assert(this->_M_index == __rhs._M_index);
 	return *this;
Index: libstdc++-v3/include/bits/shared_ptr.h
===================================================================
--- libstdc++-v3/include/bits/shared_ptr.h	(.../tags/gcc_8_2_0_release)
+++ libstdc++-v3/include/bits/shared_ptr.h	(.../branches/gcc-8-branch)
@@ -718,7 +718,7 @@
     inline shared_ptr<_Tp>
     make_shared(_Args&&... __args)
     {
-      typedef typename std::remove_const<_Tp>::type _Tp_nc;
+      typedef typename std::remove_cv<_Tp>::type _Tp_nc;
       return std::allocate_shared<_Tp>(std::allocator<_Tp_nc>(),
 				       std::forward<_Args>(__args)...);
     }
Index: libstdc++-v3/include/bits/fs_dir.h
===================================================================
--- libstdc++-v3/include/bits/fs_dir.h	(.../tags/gcc_8_2_0_release)
+++ libstdc++-v3/include/bits/fs_dir.h	(.../branches/gcc-8-branch)
@@ -313,7 +313,10 @@
     _M_file_type(error_code& __ec) const noexcept
     {
       if (_M_type != file_type::none && _M_type != file_type::symlink)
-	return _M_type;
+	{
+	  __ec.clear();
+	  return _M_type;
+	}
       return status(__ec).type();
     }
 
Index: libstdc++-v3/include/bits/c++config
===================================================================
--- libstdc++-v3/include/bits/c++config	(.../tags/gcc_8_2_0_release)
+++ libstdc++-v3/include/bits/c++config	(.../branches/gcc-8-branch)
@@ -609,4 +609,9 @@
 # endif
 #endif
 
+/* Define if __float128 is supported on this host. */
+#if defined(__FLOAT128__) || defined(__SIZEOF_FLOAT128__)
+#define _GLIBCXX_USE_FLOAT128
+#endif
+
 // End of prewritten config; the settings discovered at configure time follow.
Index: libstdc++-v3/include/bits/stl_iterator.h
===================================================================
--- libstdc++-v3/include/bits/stl_iterator.h	(.../tags/gcc_8_2_0_release)
+++ libstdc++-v3/include/bits/stl_iterator.h	(.../branches/gcc-8-branch)
@@ -122,6 +122,7 @@
       */
       // _GLIBCXX_RESOLVE_LIB_DEFECTS
       // 235 No specification of default ctor for reverse_iterator
+      // 1012. reverse_iterator default ctor should value initialize
       _GLIBCXX17_CONSTEXPR
       reverse_iterator() : current() { }
 
@@ -176,9 +177,11 @@
        *
        *  This requires that @c --current is dereferenceable.
       */
+      // _GLIBCXX_RESOLVE_LIB_DEFECTS
+      // 2188. Reverse iterator does not fully support targets that overload &
       _GLIBCXX17_CONSTEXPR pointer
       operator->() const
-      { return &(operator*()); }
+      { return std::__addressof(operator*()); }
 
       /**
        *  @return  @c *this
Index: libstdc++-v3/include/bits/shared_ptr_base.h
===================================================================
--- libstdc++-v3/include/bits/shared_ptr_base.h	(.../tags/gcc_8_2_0_release)
+++ libstdc++-v3/include/bits/shared_ptr_base.h	(.../branches/gcc-8-branch)
@@ -508,7 +508,7 @@
       friend class _Sp_counted_ptr_inplace;
 
     static const type_info&
-    _S_ti() noexcept
+    _S_ti() noexcept _GLIBCXX_VISIBILITY(default)
     {
       alignas(type_info) static constexpr _Sp_make_shared_tag __tag;
       return reinterpret_cast<const type_info&>(__tag);
Index: libstdc++-v3/include/Makefile.am
===================================================================
--- libstdc++-v3/include/Makefile.am	(.../tags/gcc_8_2_0_release)
+++ libstdc++-v3/include/Makefile.am	(.../branches/gcc-8-branch)
@@ -1230,6 +1230,14 @@
 	echo 0 > stamp-allocator-new
 endif
 
+if ENABLE_FLOAT128
+stamp-float128:
+	echo 'define _GLIBCXX_USE_FLOAT128 1' > stamp-float128
+else
+stamp-float128:
+	echo 'undef _GLIBCXX_USE_FLOAT128' > stamp-float128
+endif
+
 # NB: The non-empty default ldbl_compat works around an AIX sed
 # oddity, see libstdc++/31957 for details.
 ${host_builddir}/c++config.h: ${CONFIG_HEADER} \
@@ -1241,7 +1249,8 @@
 			      stamp-extern-template \
 			      stamp-dual-abi \
 			      stamp-cxx11-abi \
-			      stamp-allocator-new
+			      stamp-allocator-new \
+			      stamp-float128
 	@date=`cat ${toplevel_srcdir}/gcc/DATESTAMP` ;\
 	release=`sed 's/^\([0-9]*\).*$$/\1/' ${toplevel_srcdir}/gcc/BASE-VER` ;\
 	ns_version=`cat stamp-namespace-version` ;\
@@ -1250,6 +1259,7 @@
 	dualabi=`cat stamp-dual-abi` ;\
 	cxx11abi=`cat stamp-cxx11-abi` ;\
 	allocatornew=`cat stamp-allocator-new` ;\
+	float128=`cat stamp-float128` ;\
 	ldbl_compat='s,g,g,' ;\
 	grep "^[	 ]*#[	 ]*define[	 ][	 ]*_GLIBCXX_LONG_DOUBLE_COMPAT[	 ][	 ]*1[	 ]*$$" \
 	${CONFIG_HEADER} > /dev/null 2>&1 \
@@ -1262,6 +1272,7 @@
 	-e "s,define _GLIBCXX_USE_DUAL_ABI, define _GLIBCXX_USE_DUAL_ABI $$dualabi," \
 	-e "s,define _GLIBCXX_USE_CXX11_ABI, define _GLIBCXX_USE_CXX11_ABI $$cxx11abi," \
 	-e "s,define _GLIBCXX_USE_ALLOCATOR_NEW, define _GLIBCXX_USE_ALLOCATOR_NEW $$allocatornew," \
+	-e "s,define _GLIBCXX_USE_FLOAT128,$$float128," \
 	-e "$$ldbl_compat" \
 	    < ${glibcxx_srcdir}/include/bits/c++config > $@ ;\
 	sed -e 's/HAVE_/_GLIBCXX_HAVE_/g' \
Index: libstdc++-v3/libsupc++/new_opa.cc
===================================================================
--- libstdc++-v3/libsupc++/new_opa.cc	(.../tags/gcc_8_2_0_release)
+++ libstdc++-v3/libsupc++/new_opa.cc	(.../branches/gcc-8-branch)
@@ -25,20 +25,36 @@
 
 #include <bits/c++config.h>
 #include <stdlib.h>
+#include <stdint.h>
 #include <bits/exception_defines.h>
 #include "new"
 
+#if !_GLIBCXX_HAVE_ALIGNED_ALLOC && !_GLIBCXX_HAVE__ALIGNED_MALLOC \
+  && !_GLIBCXX_HAVE_POSIX_MEMALIGN && _GLIBCXX_HAVE_MEMALIGN
+# if _GLIBCXX_HOSTED && __has_include(<malloc.h>)
+// Some C libraries declare memalign in <malloc.h>
+#  include <malloc.h>
+# else
+extern "C" void *memalign(std::size_t boundary, std::size_t size);
+# endif
+#endif
+
 using std::new_handler;
 using std::bad_alloc;
 
-#if !_GLIBCXX_HAVE_ALIGNED_ALLOC
-#if _GLIBCXX_HAVE__ALIGNED_MALLOC
-#define aligned_alloc(al,sz) _aligned_malloc(sz,al)
+namespace __gnu_cxx {
+#if _GLIBCXX_HAVE_ALIGNED_ALLOC
+using ::aligned_alloc;
+#elif _GLIBCXX_HAVE__ALIGNED_MALLOC
+static inline void*
+aligned_alloc (std::size_t al, std::size_t sz)
+{ return _aligned_malloc(sz, al); }
 #elif _GLIBCXX_HAVE_POSIX_MEMALIGN
 static inline void*
 aligned_alloc (std::size_t al, std::size_t sz)
 {
   void *ptr;
+  // posix_memalign has additional requirement, not present on aligned_alloc:
   // The value of alignment shall be a power of two multiple of sizeof(void *).
   if (al < sizeof(void*))
     al = sizeof(void*);
@@ -48,25 +64,23 @@
   return nullptr;
 }
 #elif _GLIBCXX_HAVE_MEMALIGN
-#if _GLIBCXX_HOSTED
-#include <malloc.h>
-#else
-extern "C" void *memalign(std::size_t boundary, std::size_t size);
+static inline void*
+aligned_alloc (std::size_t al, std::size_t sz)
+{
+#ifdef __sun
+  // Solaris 10 memalign requires that alignment is greater than or equal to
+  // the size of a word.
+  if (al < sizeof(int))
+    al = sizeof(int);
 #endif
-#define aligned_alloc memalign
-#else
-#include <stdint.h>
+  return memalign (al, sz);
+}
+#else // !HAVE__ALIGNED_MALLOC && !HAVE_POSIX_MEMALIGN && !HAVE_MEMALIGN
 // The C library doesn't provide any aligned allocation functions, define one.
 // This is a modified version of code from gcc/config/i386/gmm_malloc.h
 static inline void*
 aligned_alloc (std::size_t al, std::size_t sz)
 {
-  // Alignment must be a power of two.
-  if (al & (al - 1))
-    return nullptr;
-  else if (!sz)
-    return nullptr;
-
   // We need extra bytes to store the original value returned by malloc.
   if (al < sizeof(void*))
     al = sizeof(void*);
@@ -82,7 +96,7 @@
   return aligned_ptr;
 }
 #endif
-#endif
+} // namespace __gnu_cxx
 
 _GLIBCXX_WEAK_DEFINITION void *
 operator new (std::size_t sz, std::align_val_t al)
@@ -90,16 +104,28 @@
   void *p;
   std::size_t align = (std::size_t)al;
 
+  /* Alignment must be a power of two.  */
+  /* XXX This should be checked by the compiler (PR 86878).  */
+  if (__builtin_expect (align & (align - 1), false))
+    _GLIBCXX_THROW_OR_ABORT(bad_alloc());
+
   /* malloc (0) is unpredictable; avoid it.  */
-  if (sz == 0)
+  if (__builtin_expect (sz == 0, false))
     sz = 1;
 
 #if _GLIBCXX_HAVE_ALIGNED_ALLOC
+# ifdef _AIX
+  /* AIX 7.2.0.0 aligned_alloc incorrectly has posix_memalign's requirement
+   * that alignment is a multiple of sizeof(void*).  */
+  if (align < sizeof(void*))
+    align = sizeof(void*);
+# endif
   /* C11: the value of size shall be an integral multiple of alignment.  */
   if (std::size_t rem = sz & (align - 1))
     sz += align - rem;
 #endif
 
+  using __gnu_cxx::aligned_alloc;
   while (__builtin_expect ((p = aligned_alloc (align, sz)) == 0, false))
     {
       new_handler handler = std::get_new_handler ();
Index: libstdc++-v3/ChangeLog
===================================================================
--- libstdc++-v3/ChangeLog	(.../tags/gcc_8_2_0_release)
+++ libstdc++-v3/ChangeLog	(.../branches/gcc-8-branch)
@@ -1,3 +1,198 @@
+2018-10-08  Joseph Myers  <joseph@codesourcery.com>
+
+	Backport from mainline
+	2018-10-02  Joseph Myers  <joseph@codesourcery.com>
+
+	* testsuite/lib/libstdc++.exp (libstdc++_init): Use
+	-fno-show-column in default cxxflags.
+
+2018-10-08  Jonathan Wakely  <jwakely@redhat.com>
+
+	Backport from mainline
+	2018-10-08  Jonathan Wakely  <jwakely@redhat.com>
+
+	PR libstdc++/87538
+	* include/std/functional (_Not_fn::operator()): Check value of
+	__is_nothrow_invocable as well.
+	* testsuite/20_util/function_objects/not_fn/87538.cc: New test.
+	* testsuite/experimental/functional/87538.cc: New test.
+
+2018-09-11  Jonathan Wakely  <jwakely@redhat.com>
+
+	PR libstdc++/87278
+	* include/bits/shared_ptr.h (make_shared): Use remove_cv instead of
+	remove_const.
+	* testsuite/20_util/shared_ptr/creation/87278.cc: New test.
+
+2018-08-28  Jonathan Wakely  <jwakely@redhat.com>
+
+	PR libstdc++/87116
+	* src/filesystem/std-path.cc (path::lexically_normal): When handling
+	a dot-dot filename, preserve an empty final component in the iteration
+	sequence.
+	[_GLIBCXX_FILESYSTEM_IS_WINDOWS]: Use preferred-separator for
+	root-directory.
+	* testsuite/27_io/filesystem/path/generation/normal.cc: Add new tests
+	for more than two adjacent dot-dot filenames.
+	[_GLIBCXX_FILESYSTEM_IS_WINDOWS]: Replace slashes with
+	preferred-separator in expected normalized strings.
+
+2018-08-13  Jonathan Wakely  <jwakely@redhat.com>
+
+	Revert
+	2018-08-10  Sebastian Huber  <sebastian.huber@embedded-brains.de>
+
+	PR target/85904
+	* configure.ac: Define HAVE_ALIGNED_ALLOC if building for
+	Newlib.
+	* configure: Regenerate.
+
+2018-08-10  Sebastian Huber  <sebastian.huber@embedded-brains.de>
+
+	Backport from mainline
+	2018-08-10  Sebastian Huber  <sebastian.huber@embedded-brains.de>
+
+	PR target/85904
+	* configure.ac: Define HAVE_ALIGNED_ALLOC if building for
+	Newlib.
+	* configure: Regenerate.
+
+2018-08-08  Jonathan Wakely  <jwakely@redhat.com>
+
+	* libsupc++/new_opa.cc (aligned_alloc): Declare inside namespace to
+	avoid clashing with an ::aligned_alloc function that was not detected
+	by configure.
+
+	PR libstdc++/86597
+	* include/bits/fs_dir.h (directory_entry::_M_file_type(error_code&)):
+	Clear error_code when cached type is used.
+	* testsuite/27_io/filesystem/directory_entry/86597.cc: New test.
+
+	* doc/xml/manual/using.xml: Remove C++2a headers not on gcc-8-branch.
+	* doc/html/*: Regenerate.
+
+	* doc/xml/manual/using.xml: Add missing header to table and fix typo.
+	Remove C++17 headers not present on gcc-8-branch.
+	* doc/html/*: Regenerate.
+
+2018-08-07  Jonathan Wakely  <jwakely@redhat.com>
+
+	Backport from mainline
+	2018-07-31  Jonathan Wakely  <jwakely@redhat.com>
+
+	* doc/xml/manual/test.xml: Improve documentation on writing tests for
+	newer standards.
+	* doc/xml/manual/using.xml: Document all headers for C++11 and later.
+	* doc/html/*: Regenerate.
+
+	Backport from mainline
+	2018-05-03  Jonathan Wakely  <jwakely@redhat.com>
+
+	PR libstdc++/84535
+	* include/std/thread (thread::__not_same): New SFINAE helper.
+	(thread::thread(_Callable&&, _Args&&...)): Add SFINAE constraint that
+	first argument is not a std::thread. Add static assertion to check
+	INVOKE expression is valid.
+	(thread::thread(thread&), thread::thread(const thread&&)): Remove.
+	* testsuite/30_threads/thread/cons/84535.cc: New.
+
+	Backport from mainline
+	2018-08-03  Jonathan Wakely  <jwakely@redhat.com>
+
+	* src/c++11/system_error.cc
+	(system_error_category::default_error_condition): Add workaround for
+	ENOTEMPTY and EEXIST having the same value on AIX.
+	* testsuite/19_diagnostics/error_category/system_category.cc: Add
+	extra testcases for EDOM, EILSEQ, ERANGE, EEXIST and ENOTEMPTY.
+
+	Backport from mainline
+	2018-08-01  Jonathan Wakely  <jwakely@redhat.com>
+
+	PR libstdc++/60555
+	* src/c++11/system_error.cc
+	(system_error_category::default_error_condition): New override to
+	check for POSIX errno values.
+	* testsuite/19_diagnostics/error_category/generic_category.cc: New
+	* testsuite/19_diagnostics/error_category/system_category.cc: New
+	test.
+
+	Backport from mainline
+	2018-08-07  Jonathan Wakely  <jwakely@redhat.com>
+
+	PR libstdc++/86874
+	* include/std/variant (_Copy_ctor_base::_M_destructive_move): Define
+	here instead of in _Move_assign_base.
+	(_Copy_ctor_base<true, _Types...>::_M_destructive_move): Define.
+	(_Copy_assign_base::operator=): Use _M_destructive_move when changing
+	the contained value to another alternative.
+	(_Move_assign_base::operator=): Likewise.
+	(_Move_assign_base::_M_destructive_move): Remove.
+	* testsuite/20_util/variant/86874.cc: New test.
+
+	Backport from mainline
+	2018-08-07  Jonathan Wakely  <jwakely@redhat.com>
+
+	PR libstdc++/86861
+	* libsupc++/new_opa.cc [_GLIBCXX_HAVE_MEMALIGN] (aligned_alloc):
+	Replace macro with inline function.
+	[__sun]: Increase alignment to meet memalign precondition.
+	[!HAVE__ALIGNED_MALLOC && !HAVE_POSIX_MEMALIGN && !HAVE_MEMALIGN]
+	(aligned_alloc): Move check for valid alignment to operator new.
+	Remove redundant check for non-zero size, it's enforced by the caller.
+	(operator new): Move check for valid alignment here. Use
+	__builtin_expect on check for zero size.
+
+2018-07-31  Jonathan Wakely  <jwakely@redhat.com>
+
+	Backport from mainline
+	2018-07-30  Jonathan Wakely  <jwakely@redhat.com>
+
+	* libsupc++/new_opa.cc (operator new(size_t, align_val_t)): Add
+	workaround for aligned_alloc bug on AIX.
+	* testsuite/18_support/new_aligned.cc: New test.
+
+	Backport from mainline
+	2018-07-20  Fangrui Song  <maskray@google.com>
+
+	* include/bits/shared_ptr_base.h (_Sp_make_shared_tag::_S_ti): Use
+	_GLIBCXX_VISIBILITY(default).
+
+	Backport from mainline
+	2018-07-30  Jonathan Wakely  <jwakely@redhat.com>
+
+	PR libstdc++/86734
+	* include/bits/stl_iterator.h (reverse_iterator::operator->): Use
+	addressof (LWG 2188).
+	* testsuite/24_iterators/reverse_iterator/dr2188.cc: New test.
+
+	Backport from mainline
+	2018-05-08  Jonathan Wakely  <jwakely@redhat.com>
+
+	PR libstdc++/85672
+	* include/Makefile.am [!ENABLE_FLOAT128]: Change c++config.h entry
+	to #undef _GLIBCXX_USE_FLOAT128 instead of defining it to zero.
+	* include/Makefile.in: Regenerate.
+	* include/bits/c++config (_GLIBCXX_USE_FLOAT128): Move definition
+	within conditional block.
+
+	Backport from mainline
+	2018-05-01  Tulio Magno Quites Machado Filho  <tuliom@linux.vnet.ibm.com>
+
+	PR libstdc++/84654
+	* acinclude.m4: Set ENABLE_FLOAT128 instead of _GLIBCXX_USE_FLOAT128.
+	* config.h.in: Remove references to _GLIBCXX_USE_FLOAT128.
+	* configure: Regenerate.
+	* include/Makefile.am: Replace the value of _GLIBCXX_USE_FLOAT128
+	based on ENABLE_FLOAT128.
+	* include/Makefile.in: Regenerate.
+	* include/bits/c++config: Define _GLIBCXX_USE_FLOAT128.
+	[!defined(__FLOAT128__) && !defined(__SIZEOF_FLOAT128__)]: Undefine
+	_GLIBCXX_USE_FLOAT128.
+
+2018-07-26  Marek Polacek  <polacek@redhat.com>
+
+	* testsuite/30_threads/condition_variable_any/cond.cc: New.
+
 2018-07-26  Release Manager
 
 	* GCC 8.2.0 released.
Index: libstdc++-v3/testsuite/24_iterators/reverse_iterator/dr2188.cc
===================================================================
--- libstdc++-v3/testsuite/24_iterators/reverse_iterator/dr2188.cc	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ libstdc++-v3/testsuite/24_iterators/reverse_iterator/dr2188.cc	(.../branches/gcc-8-branch)
@@ -0,0 +1,47 @@
+// Copyright (C) 2018 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// { dg-do run { target c++11 } }
+
+// PR libstdc++/86734
+
+#include <iterator>
+#include <testsuite_hooks.h>
+
+void
+test01()
+{
+  // LWG DR 2188
+  // Reverse iterator does not fully support targets that overload operator&
+  struct X {
+    int val;
+    int* operator&() { return &val; }
+    const int* operator&() const { return &val; }
+  };
+
+  X x[2] = { {1}, {2} };
+  std::reverse_iterator<X*> rev(x+2);
+  VERIFY( rev->val == 2 );
+  ++rev;
+  VERIFY( rev->val == 1 );
+}
+
+int
+main()
+{
+  test01();
+}
Index: libstdc++-v3/testsuite/18_support/new_aligned.cc
===================================================================
--- libstdc++-v3/testsuite/18_support/new_aligned.cc	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ libstdc++-v3/testsuite/18_support/new_aligned.cc	(.../branches/gcc-8-branch)
@@ -0,0 +1,119 @@
+// Copyright (C) 2018 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// { dg-options "-std=gnu++17" }
+// { dg-do run { target c++17 } }
+
+#include <new>
+#include <memory>
+#include <testsuite_hooks.h>
+
+struct Test
+{
+  Test(std::size_t size, std::size_t a)
+  : size(size), alignment(std::align_val_t{a}),
+    p(::operator new(size, alignment))
+  { }
+
+  ~Test() { ::operator delete(p, size, alignment); }
+
+  std::size_t size;
+  std::align_val_t alignment;
+  void* p;
+
+  bool valid() const { return p != nullptr; }
+
+  bool aligned() const
+  {
+    auto ptr = p;
+    auto space = size;
+    return std::align((std::size_t)alignment, size, ptr, space) == p;
+  }
+};
+
+// operator new(size_t size, align_val_t alignment) has
+// undefined behaviour if the alignment argument is not
+// a valid alignment value (i.e. not a power of two).
+//
+// Unlike posix_memalign there is no requirement that
+// alignment >= sizeof(void*).
+//
+// Unlike aligned_alloc there is no requirement that
+// size is an integer multiple of alignment.
+
+void
+test01()
+{
+  // Test small values that would not be valid for
+  // posix_memalign or aligned_alloc.
+
+  Test t11{1, 1};
+  VERIFY( t11.valid() );
+  VERIFY( t11.aligned() );
+
+  Test t21{2, 1};
+  VERIFY( t21.valid() );
+  VERIFY( t21.aligned() );
+
+  Test t12{1, 2};
+  VERIFY( t12.valid() );
+  VERIFY( t12.aligned() );
+
+  Test t22{2, 2};
+  VERIFY( t22.valid() );
+  VERIFY( t22.aligned() );
+
+  Test t32{3, 2};
+  VERIFY( t32.valid() );
+  VERIFY( t32.aligned() );
+
+  Test t42{4, 2};
+  VERIFY( t42.valid() );
+  VERIFY( t42.aligned() );
+
+  Test t24{2, 4};
+  VERIFY( t24.valid() );
+  VERIFY( t24.aligned() );
+
+  Test t34{3, 4};
+  VERIFY( t34.valid() );
+  VERIFY( t34.aligned() );
+
+  Test t44{4, 4};
+  VERIFY( t44.valid() );
+  VERIFY( t44.aligned() );
+
+  // Test some larger values.
+
+  Test t128_16{128, 16};
+  VERIFY( t128_16.valid() );
+  VERIFY( t128_16.aligned() );
+
+  Test t128_64{128, 64};
+  VERIFY( t128_64.valid() );
+  VERIFY( t128_64.aligned() );
+
+  Test t64_128{64, 128};
+  VERIFY( t64_128.valid() );
+  VERIFY( t64_128.aligned() );
+}
+
+int
+main()
+{
+  test01();
+}
Index: libstdc++-v3/testsuite/30_threads/condition_variable_any/cond.cc
===================================================================
--- libstdc++-v3/testsuite/30_threads/condition_variable_any/cond.cc	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ libstdc++-v3/testsuite/30_threads/condition_variable_any/cond.cc	(.../branches/gcc-8-branch)
@@ -0,0 +1,35 @@
+// { dg-do run }
+// { dg-options "-pthread"  }
+// { dg-require-effective-target c++11 }
+// { dg-require-effective-target pthread }
+// { dg-require-gthreads "" }
+
+// Copyright (C) 2018 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+#include <condition_variable>
+#include <cstring>
+
+int main()
+{
+  const size_t sz = sizeof(std::condition_variable_any);
+  char garbage[sz];
+  memset(garbage, 0xff, sz);
+  auto cond = new ((void*)garbage) std::condition_variable_any();
+  cond->notify_all();
+  cond->~condition_variable_any();
+}
Index: libstdc++-v3/testsuite/30_threads/thread/cons/84535.cc
===================================================================
--- libstdc++-v3/testsuite/30_threads/thread/cons/84535.cc	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ libstdc++-v3/testsuite/30_threads/thread/cons/84535.cc	(.../branches/gcc-8-branch)
@@ -0,0 +1,31 @@
+// { dg-do compile { target c++11 } }
+// { dg-require-cstdint "" }
+// { dg-require-gthreads "" }
+
+// Copyright (C) 2018 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+#include <thread>
+
+using std::is_constructible;
+using std::thread;
+
+// PR libstdc++/84535
+static_assert(!is_constructible<thread, thread, int>::value, "");
+static_assert(!is_constructible<thread, thread&, int>::value, "");
+static_assert(!is_constructible<thread, const thread&, int>::value, "");
+static_assert(!is_constructible<thread, const thread&&, int>::value, "");
Index: libstdc++-v3/testsuite/lib/libstdc++.exp
===================================================================
--- libstdc++-v3/testsuite/lib/libstdc++.exp	(.../tags/gcc_8_2_0_release)
+++ libstdc++-v3/testsuite/lib/libstdc++.exp	(.../branches/gcc-8-branch)
@@ -239,7 +239,7 @@
 
     # Default settings.
     set cxx [transform "g++"]
-    set cxxflags "-fmessage-length=0"
+    set cxxflags "-fmessage-length=0 -fno-show-column"
     set cxxpchflags ""
     set cxxvtvflags ""
     set cxxldflags ""
Index: libstdc++-v3/testsuite/27_io/filesystem/directory_entry/86597.cc
===================================================================
--- libstdc++-v3/testsuite/27_io/filesystem/directory_entry/86597.cc	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ libstdc++-v3/testsuite/27_io/filesystem/directory_entry/86597.cc	(.../branches/gcc-8-branch)
@@ -0,0 +1,74 @@
+// Copyright (C) 2018 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// { dg-options "-std=gnu++17 -lstdc++fs" }
+// { dg-do run { target c++17 } }
+// { dg-require-filesystem-ts "" }
+
+#include <filesystem>
+#include <system_error>
+#include <testsuite_hooks.h>
+#include <testsuite_fs.h>
+
+// PR libstdc++/86597
+
+void
+test01()
+{
+  const auto bad_ec = make_error_code(std::errc::address_in_use);
+  std::error_code ec;
+  std::filesystem::directory_entry ent(".");
+
+  ec = bad_ec;
+  VERIFY( ent.exists(ec) );
+  VERIFY( !ec );
+
+  ec = bad_ec;
+  VERIFY( ent.is_directory(ec) );
+  VERIFY( !ec );
+
+  ec = bad_ec;
+  VERIFY( !ent.is_regular_file(ec) );
+  VERIFY( !ec );
+}
+
+void
+test02()
+{
+  const auto bad_ec = make_error_code(std::errc::address_in_use);
+  std::error_code ec;
+  std::filesystem::directory_entry ent(__gnu_test::nonexistent_path());
+
+  ec = bad_ec;
+  VERIFY( !ent.exists(ec) );
+  VERIFY( !ec );
+
+  ec = bad_ec;
+  VERIFY( !ent.is_directory(ec) );
+  VERIFY( !ec );
+
+  ec = bad_ec;
+  VERIFY( !ent.is_regular_file(ec) );
+  VERIFY( !ec );
+}
+
+int
+main()
+{
+  test01();
+  test02();
+}
Index: libstdc++-v3/testsuite/27_io/filesystem/path/generation/normal.cc
===================================================================
--- libstdc++-v3/testsuite/27_io/filesystem/path/generation/normal.cc	(.../tags/gcc_8_2_0_release)
+++ libstdc++-v3/testsuite/27_io/filesystem/path/generation/normal.cc	(.../branches/gcc-8-branch)
@@ -24,9 +24,19 @@
 #include <testsuite_hooks.h>
 
 using std::filesystem::path;
-using __gnu_test::compare_paths;
 
 void
+compare_paths(path p, std::string expected)
+{
+#if defined(_WIN32) && !defined(__CYGWIN__)
+  for (auto& c : expected)
+    if (c == '/')
+      c = '\\';
+#endif
+  __gnu_test::compare_paths(p, expected);
+}
+
+void
 test01()
 {
   // C++17 [fs.path.gen] p2
@@ -69,8 +79,11 @@
     {"/foo"        , "/foo" },
     {"/foo/"       , "/foo/" },
     {"/foo/."      , "/foo/" },
+    {"/foo/.."     , "/" },
+    {"/foo/../.."  , "/" },
     {"/foo/bar/.." , "/foo/" },
-    {"/foo/.."     , "/" },
+    {"/foo/bar/../.." , "/" },
+    {"/foo/bar/baz/../../.." , "/" }, // PR libstdc++/87116
 
     {"/."          , "/" },
     {"/./"         , "/" },
@@ -88,10 +101,11 @@
     {"foo/.."      , "." },
     {"foo/../"     , "." },
     {"foo/../.."   , ".." },
+    {"foo/../../..", "../.." },
 
     // with root name (OS-dependent):
 #if defined(_WIN32) && !defined(__CYGWIN__)
-    {"C:bar/.."    , "C:." },
+    {"C:bar/.."    , "C:" },
 #else
     {"C:bar/.."    , "." },
 #endif
@@ -119,6 +133,48 @@
     compare_paths( path(test.input).lexically_normal(), test.normalized );
 }
 
+void
+test04()
+{
+  // PR libstdc++/87116
+  path p = "a/b/c";
+  compare_paths( (p/"../..").lexically_normal(), "a/" );
+
+  p = "a/b/c/d/e";
+  compare_paths( (p/"..").lexically_normal(),  "a/b/c/d/" );
+  compare_paths( (p/"../..").lexically_normal(),  "a/b/c/" );
+  compare_paths( (p/"../../..").lexically_normal(),  "a/b/" );
+  compare_paths( (p/"../../../..").lexically_normal(),  "a/" );
+  compare_paths( (p/"../../../../..").lexically_normal(),  "." );
+  compare_paths( (p/"../../../../../..").lexically_normal(),  ".." );
+
+  p = "/a/b/c/d/e";
+  compare_paths( (p/"..").lexically_normal(),  "/a/b/c/d/" );
+  compare_paths( (p/"../..").lexically_normal(),  "/a/b/c/" );
+  compare_paths( (p/"../../..").lexically_normal(),  "/a/b/" );
+  compare_paths( (p/"../../../..").lexically_normal(),  "/a/" );
+  compare_paths( (p/"../../../../..").lexically_normal(),  "/" );
+  compare_paths( (p/"../../../../../..").lexically_normal(),  "/" );
+
+#if defined(_WIN32) && !defined(__CYGWIN__)
+  p = "A:b/c/d/e";
+  compare_paths( (p/"..").lexically_normal(),  "A:b/c/d/" );
+  compare_paths( (p/"../..").lexically_normal(),  "A:b/c/" );
+  compare_paths( (p/"../../..").lexically_normal(),  "A:b/" );
+  compare_paths( (p/"../../../..").lexically_normal(),  "A:" );
+  compare_paths( (p/"../../../../..").lexically_normal(),  "A:.." );
+  compare_paths( (p/"../../../../../..").lexically_normal(),  "A:../.." );
+
+  p = "A:/b/c/d/e";
+  compare_paths( (p/"..").lexically_normal(),  "A:/b/c/d/" );
+  compare_paths( (p/"../..").lexically_normal(),  "A:/b/c/" );
+  compare_paths( (p/"../../..").lexically_normal(),  "A:/b/" );
+  compare_paths( (p/"../../../..").lexically_normal(),  "A:/" );
+  compare_paths( (p/"../../../../..").lexically_normal(),  "A:/" );
+  compare_paths( (p/"../../../../../..").lexically_normal(),  "A:/" );
+#endif
+}
+
 int
 main()
 {
@@ -125,4 +181,5 @@
   test01();
   test02();
   test03();
+  test04();
 }
Index: libstdc++-v3/testsuite/19_diagnostics/error_category/system_category.cc
===================================================================
--- libstdc++-v3/testsuite/19_diagnostics/error_category/system_category.cc	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ libstdc++-v3/testsuite/19_diagnostics/error_category/system_category.cc	(.../branches/gcc-8-branch)
@@ -0,0 +1,114 @@
+// Copyright (C) 2018 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// { dg-do run { target c++11 } }
+
+#include <system_error>
+#include <locale>
+#include <testsuite_hooks.h>
+
+void
+test01()
+{
+  const char* name = std::system_category().name();
+  VERIFY( name == std::string("system") );
+}
+
+void
+test02()
+{
+  const std::error_category& cat = std::system_category();
+  std::error_condition cond;
+
+  // As of 2011, ISO C only defines EDOM, EILSEQ and ERANGE:
+  cond = cat.default_error_condition(EDOM);
+  VERIFY( cond.value() == EDOM );
+  VERIFY( cond == std::errc::argument_out_of_domain );
+  VERIFY( cond.category() == std::generic_category() );
+  cond = cat.default_error_condition(EILSEQ);
+  VERIFY( cond.value() == EILSEQ );
+  VERIFY( cond == std::errc::illegal_byte_sequence );
+  VERIFY( cond.category() == std::generic_category() );
+  cond = cat.default_error_condition(ERANGE);
+  VERIFY( cond.value() == ERANGE );
+  VERIFY( cond == std::errc::result_out_of_range );
+  VERIFY( cond.category() == std::generic_category() );
+
+  // EBADF and EACCES are defined on all targets,
+  // according to config/os/*/error_constants.h
+  cond = cat.default_error_condition(EBADF);
+  VERIFY( cond.value() == EBADF );
+  VERIFY( cond == std::errc::bad_file_descriptor );
+  VERIFY( cond.category() == std::generic_category() );
+  cond = cat.default_error_condition(EACCES);
+  VERIFY( cond.value() == EACCES );
+  VERIFY( cond == std::errc::permission_denied );
+  VERIFY( cond.category() == std::generic_category() );
+
+  // All POSIX errno values are positive:
+  cond = cat.default_error_condition(-1);
+  VERIFY( cond.value() == -1 );
+  VERIFY( cond.category() == cat );
+  cond = cat.default_error_condition(-99);
+  VERIFY( cond.value() == -99 );
+  VERIFY( cond.category() == cat );
+
+  // PR libstdc++/60555
+  VERIFY( std::error_code(EDOM, cat) == std::errc::argument_out_of_domain );
+  VERIFY( std::error_code(EILSEQ, cat) == std::errc::illegal_byte_sequence );
+  VERIFY( std::error_code(ERANGE, cat) == std::errc::result_out_of_range );
+  VERIFY( std::error_code(EBADF, cat) == std::errc::bad_file_descriptor );
+  VERIFY( std::error_code(EACCES, cat) == std::errc::permission_denied );
+
+  // As shown at https://gcc.gnu.org/ml/libstdc++/2018-08/msg00018.html
+  // these two error codes might have the same value on AIX, but we still
+  // expect both to be matched by system_category and so use generic_category:
+#ifdef EEXIST
+  cond = cat.default_error_condition(EEXIST);
+  VERIFY( cond.value() == EEXIST );
+  VERIFY( cond == std::errc::file_exists );
+  VERIFY( cond.category() == std::generic_category() );
+  VERIFY( std::error_code(EEXIST, cat) == std::errc::file_exists );
+#endif
+#ifdef ENOTEMPTY
+  cond = cat.default_error_condition(ENOTEMPTY);
+  VERIFY( cond.value() == ENOTEMPTY );
+  VERIFY( cond == std::errc::directory_not_empty );
+  VERIFY( cond.category() == std::generic_category() );
+  VERIFY( std::error_code(ENOTEMPTY, cat) == std::errc::directory_not_empty );
+#endif
+}
+
+void
+test03()
+{
+  // set "C" locale to get expected message
+  auto loc = std::locale::global(std::locale::classic());
+
+  std::string msg = std::system_category().message(EBADF);
+  VERIFY( msg.find("file") != std::string::npos );
+
+  std::locale::global(loc);
+}
+
+int
+main()
+{
+  test01();
+  test02();
+  test03();
+}
Index: libstdc++-v3/testsuite/19_diagnostics/error_category/generic_category.cc
===================================================================
--- libstdc++-v3/testsuite/19_diagnostics/error_category/generic_category.cc	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ libstdc++-v3/testsuite/19_diagnostics/error_category/generic_category.cc	(.../branches/gcc-8-branch)
@@ -0,0 +1,69 @@
+// Copyright (C) 2018 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// { dg-do run { target c++11 } }
+
+#include <system_error>
+#include <locale>
+#include <testsuite_hooks.h>
+
+void
+test01()
+{
+  const char* name = std::generic_category().name();
+  VERIFY( name == std::string("generic") );
+}
+
+void
+test02()
+{
+  const std::error_category& cat = std::generic_category();
+  std::error_condition cond;
+
+  cond = cat.default_error_condition(EBADF);
+  VERIFY( cond.value() == EBADF );
+  VERIFY( cond == std::errc::bad_file_descriptor );
+  VERIFY( cond.category() == std::generic_category() );
+  cond = cat.default_error_condition(EACCES);
+  VERIFY( cond.value() == EACCES );
+  VERIFY( cond == std::errc::permission_denied );
+  VERIFY( cond.category() == std::generic_category() );
+
+  // PR libstdc++/60555
+  VERIFY( std::error_code(EBADF, cat) == std::errc::bad_file_descriptor );
+  VERIFY( std::error_code(EACCES, cat) == std::errc::permission_denied );
+}
+
+void
+test03()
+{
+  // set "C" locale to get expected message
+  auto loc = std::locale::global(std::locale::classic());
+
+  std::string msg = std::generic_category().message(EBADF);
+  VERIFY( msg.find("file") != std::string::npos );
+
+  std::locale::global(loc);
+}
+
+int
+main()
+{
+  test01();
+  test02();
+  test03();
+}
Index: libstdc++-v3/testsuite/experimental/functional/87538.cc
===================================================================
--- libstdc++-v3/testsuite/experimental/functional/87538.cc	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ libstdc++-v3/testsuite/experimental/functional/87538.cc	(.../branches/gcc-8-branch)
@@ -0,0 +1,48 @@
+// Copyright (C) 2018 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// { dg-do run { target c++14 } }
+
+#include <experimental/functional>
+#include <testsuite_hooks.h>
+
+struct N {
+  int operator()(int i) { if (i == 0) throw -1; return i; }
+};
+
+void
+test01()
+{
+  N n;
+  auto not_n = std::experimental::not_fn(n);
+  static_assert( !noexcept(not_n(1)), "can throw" );
+  VERIFY(not_n(1) == 0);
+  int exception = 0;
+  try {
+    not_n(0);
+  }
+  catch (int e) {
+    exception = e;
+  }
+  VERIFY(exception == -1);
+}
+
+int
+main()
+{
+  test01();
+}
Index: libstdc++-v3/testsuite/20_util/shared_ptr/creation/87278.cc
===================================================================
--- libstdc++-v3/testsuite/20_util/shared_ptr/creation/87278.cc	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ libstdc++-v3/testsuite/20_util/shared_ptr/creation/87278.cc	(.../branches/gcc-8-branch)
@@ -0,0 +1,26 @@
+// Copyright (C) 2018 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// { dg-do compile { target c++11 } }
+
+#include <memory>
+
+void
+test01()
+{
+  std::make_shared<volatile int>();
+}
Index: libstdc++-v3/testsuite/20_util/function_objects/not_fn/87538.cc
===================================================================
--- libstdc++-v3/testsuite/20_util/function_objects/not_fn/87538.cc	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ libstdc++-v3/testsuite/20_util/function_objects/not_fn/87538.cc	(.../branches/gcc-8-branch)
@@ -0,0 +1,49 @@
+// Copyright (C) 2018 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// { dg-options "-std=gnu++17" }
+// { dg-do run { target c++17 } }
+
+#include <functional>
+#include <testsuite_hooks.h>
+
+struct N {
+  int operator()(int i) { if (i == 0) throw -1; return i; }
+};
+
+void
+test01()
+{
+  N n;
+  auto not_n = std::not_fn(n);
+  static_assert( !noexcept(not_n(1)) );
+  VERIFY(not_n(1) == 0);
+  int exception = 0;
+  try {
+    not_n(0);
+  }
+  catch (int e) {
+    exception = e;
+  }
+  VERIFY(exception == -1);
+}
+
+int
+main()
+{
+  test01();
+}
Index: libstdc++-v3/testsuite/20_util/variant/86874.cc
===================================================================
--- libstdc++-v3/testsuite/20_util/variant/86874.cc	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ libstdc++-v3/testsuite/20_util/variant/86874.cc	(.../branches/gcc-8-branch)
@@ -0,0 +1,55 @@
+// Copyright (C) 2018 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// { dg-options "-std=gnu++17" }
+// { dg-do run { target c++17 } }
+
+#include <variant>
+#include <testsuite_hooks.h>
+
+void
+test01()
+{
+  std::variant<std::monostate> v1, v2;
+  std::swap(v1, v2);
+}
+
+void
+test02()
+{
+  std::variant<int> v1{1}, v2{2};
+  std::swap(v1, v2);
+  VERIFY( std::get<0>(v1) == 2 );
+  VERIFY( std::get<0>(v2) == 1 );
+}
+
+void
+test03()
+{
+  std::variant<double, int> v1{1}, v2{2.3};
+  std::swap(v1, v2);
+  VERIFY( std::get<double>(v1) == 2.3 );
+  VERIFY( std::get<int>(v2) == 1 );
+}
+
+int
+main()
+{
+  test01();
+  test02();
+  test03();
+}
Index: libstdc++-v3/config.h.in
===================================================================
--- libstdc++-v3/config.h.in	(.../tags/gcc_8_2_0_release)
+++ libstdc++-v3/config.h.in	(.../branches/gcc-8-branch)
@@ -918,9 +918,6 @@
 /* Define if fchmodat is available in <sys/stat.h>. */
 #undef _GLIBCXX_USE_FCHMODAT
 
-/* Define if __float128 is supported on this host. */
-#undef _GLIBCXX_USE_FLOAT128
-
 /* Defined if gettimeofday is available. */
 #undef _GLIBCXX_USE_GETTIMEOFDAY
 
Index: libstdc++-v3/acinclude.m4
===================================================================
--- libstdc++-v3/acinclude.m4	(.../tags/gcc_8_2_0_release)
+++ libstdc++-v3/acinclude.m4	(.../branches/gcc-8-branch)
@@ -3062,7 +3062,7 @@
 dnl
 dnl Defines:
 dnl  _GLIBCXX_USE_INT128
-dnl  _GLIBCXX_USE_FLOAT128
+dnl  ENABLE_FLOAT128
 dnl
 AC_DEFUN([GLIBCXX_ENABLE_INT128_FLOAT128], [
 
@@ -3117,13 +3117,12 @@
 
     AC_MSG_CHECKING([for __float128])
     if AC_TRY_EVAL(ac_compile); then
-      AC_DEFINE(_GLIBCXX_USE_FLOAT128, 1,
-      [Define if __float128 is supported on this host.])
       enable_float128=yes
     else
       enable_float128=no
     fi
     AC_MSG_RESULT($enable_float128)
+    GLIBCXX_CONDITIONAL(ENABLE_FLOAT128, test $enable_float128 = yes)
     rm -f conftest*
 
   AC_LANG_RESTORE
Index: libgcc/ChangeLog
===================================================================
--- libgcc/ChangeLog	(.../tags/gcc_8_2_0_release)
+++ libgcc/ChangeLog	(.../branches/gcc-8-branch)
@@ -1,3 +1,26 @@
+2018-10-03  H.J. Lu  <hongjiu.lu@intel.com>
+
+	Backport from mainline
+	2018-07-27  H.J. Lu  <hongjiu.lu@intel.com>
+
+	PR libgcc/85334
+	* config/i386/shadow-stack-unwind.h (_Unwind_Frames_Increment):
+
+2018-08-17  John David Anglin  <danglin@gcc.gnu.org>
+
+	Backport from mainline
+	2018-08-11  John David Anglin  <danglin@gcc.gnu.org>
+
+	* config/pa/linux-atomic.c: Update comment.
+	(FETCH_AND_OP_2, OP_AND_FETCH_2, FETCH_AND_OP_WORD, OP_AND_FETCH_WORD,
+	COMPARE_AND_SWAP_2, __sync_val_compare_and_swap_4,
+	SYNC_LOCK_TEST_AND_SET_2, __sync_lock_test_and_set_4): Use
+	__ATOMIC_RELAXED for atomic loads.
+	(SYNC_LOCK_RELEASE_1): New define.  Use __sync_synchronize() and
+	unordered store to release lock.
+	(__sync_lock_release_8): Likewise.
+	(SYNC_LOCK_RELEASE_2): Remove define.
+	 
 2018-07-26  Release Manager
 
 	* GCC 8.2.0 released.
Index: libgcc/config/i386/shadow-stack-unwind.h
===================================================================
--- libgcc/config/i386/shadow-stack-unwind.h	(.../tags/gcc_8_2_0_release)
+++ libgcc/config/i386/shadow-stack-unwind.h	(.../branches/gcc-8-branch)
@@ -49,8 +49,3 @@
 	}					\
     }						\
     while (0)
-
-/* Increment frame count.  Skip signal frames.  */
-#undef _Unwind_Frames_Increment
-#define _Unwind_Frames_Increment(context, frames) \
-  if (!_Unwind_IsSignalFrame (context)) frames++
Index: libgcc/config/pa/linux-atomic.c
===================================================================
--- libgcc/config/pa/linux-atomic.c	(.../tags/gcc_8_2_0_release)
+++ libgcc/config/pa/linux-atomic.c	(.../branches/gcc-8-branch)
@@ -28,15 +28,10 @@
 #define EBUSY   16
 #define ENOSYS 251 
 
-/* All PA-RISC implementations supported by linux have strongly
-   ordered loads and stores.  Only cache flushes and purges can be
-   delayed.  The data cache implementations are all globally
-   coherent.  Thus, there is no need to synchonize memory accesses.
+/* PA-RISC 2.0 supports out-of-order execution for loads and stores.
+   Thus, we need to synchonize memory accesses.  For more info, see:
+   "Advanced Performance Features of the 64-bit PA-8000" by Doug Hunt.
 
-   GCC automatically issues a asm memory barrier when it encounters
-   a __sync_synchronize builtin.  Thus, we do not need to define this
-   builtin.
-
    We implement byte, short and int versions of each atomic operation
    using the kernel helper defined below.  There is no support for
    64-bit operations yet.  */
@@ -119,7 +114,7 @@
     long failure;							\
 									\
     do {								\
-      tmp = __atomic_load_n (ptr, __ATOMIC_SEQ_CST);			\
+      tmp = __atomic_load_n (ptr, __ATOMIC_RELAXED);			\
       newval = PFX_OP (tmp INF_OP val);					\
       failure = __kernel_cmpxchg2 (ptr, &tmp, &newval, INDEX);		\
     } while (failure != 0);						\
@@ -156,7 +151,7 @@
     long failure;							\
 									\
     do {								\
-      tmp = __atomic_load_n (ptr, __ATOMIC_SEQ_CST);			\
+      tmp = __atomic_load_n (ptr, __ATOMIC_RELAXED);			\
       newval = PFX_OP (tmp INF_OP val);					\
       failure = __kernel_cmpxchg2 (ptr, &tmp, &newval, INDEX);		\
     } while (failure != 0);						\
@@ -193,7 +188,7 @@
     long failure;							\
 									\
     do {								\
-      tmp = __atomic_load_n (ptr, __ATOMIC_SEQ_CST);			\
+      tmp = __atomic_load_n (ptr, __ATOMIC_RELAXED);			\
       failure = __kernel_cmpxchg (ptr, tmp, PFX_OP (tmp INF_OP val));	\
     } while (failure != 0);						\
 									\
@@ -215,7 +210,7 @@
     long failure;							\
 									\
     do {								\
-      tmp = __atomic_load_n (ptr, __ATOMIC_SEQ_CST);			\
+      tmp = __atomic_load_n (ptr, __ATOMIC_RELAXED);			\
       failure = __kernel_cmpxchg (ptr, tmp, PFX_OP (tmp INF_OP val));	\
     } while (failure != 0);						\
 									\
@@ -241,7 +236,7 @@
 									\
     while (1)								\
       {									\
-	actual_oldval = __atomic_load_n (ptr, __ATOMIC_SEQ_CST);	\
+	actual_oldval = __atomic_load_n (ptr, __ATOMIC_RELAXED);	\
 									\
 	if (__builtin_expect (oldval != actual_oldval, 0))		\
 	  return actual_oldval;						\
@@ -273,7 +268,7 @@
     
   while (1)
     {
-      actual_oldval = __atomic_load_n (ptr, __ATOMIC_SEQ_CST);
+      actual_oldval = __atomic_load_n (ptr, __ATOMIC_RELAXED);
 
       if (__builtin_expect (oldval != actual_oldval, 0))
 	return actual_oldval;
@@ -300,7 +295,7 @@
     long failure;							\
 									\
     do {								\
-      oldval = __atomic_load_n (ptr, __ATOMIC_SEQ_CST);			\
+      oldval = __atomic_load_n (ptr, __ATOMIC_RELAXED);			\
       failure = __kernel_cmpxchg2 (ptr, &oldval, &val, INDEX);		\
     } while (failure != 0);						\
 									\
@@ -318,7 +313,7 @@
   int oldval;
 
   do {
-    oldval = __atomic_load_n (ptr, __ATOMIC_SEQ_CST);
+    oldval = __atomic_load_n (ptr, __ATOMIC_RELAXED);
     failure = __kernel_cmpxchg (ptr, oldval, val);
   } while (failure != 0);
 
@@ -325,31 +320,24 @@
   return oldval;
 }
 
-#define SYNC_LOCK_RELEASE_2(TYPE, WIDTH, INDEX)			\
+void HIDDEN
+__sync_lock_release_8 (long long *ptr)
+{
+  /* All accesses must be complete before we release the lock.  */
+  __sync_synchronize ();
+  *(double *)ptr = 0;
+}
+
+#define SYNC_LOCK_RELEASE_1(TYPE, WIDTH)			\
   void HIDDEN							\
   __sync_lock_release_##WIDTH (TYPE *ptr)			\
   {								\
-    TYPE oldval, zero = 0;					\
-    long failure;						\
-								\
-    do {							\
-      oldval = __atomic_load_n (ptr, __ATOMIC_SEQ_CST);		\
-      failure = __kernel_cmpxchg2 (ptr, &oldval, &zero, INDEX);	\
-    } while (failure != 0);					\
+    /* All accesses must be complete before we release		\
+       the lock.  */						\
+    __sync_synchronize ();					\
+    *ptr = 0;							\
   }
 
-SYNC_LOCK_RELEASE_2 (long long, 8, 3)
-SYNC_LOCK_RELEASE_2 (short, 2, 1)
-SYNC_LOCK_RELEASE_2 (signed char, 1, 0)
-
-void HIDDEN
-__sync_lock_release_4 (int *ptr)
-{
-  long failure;
-  int oldval;
-
-  do {
-    oldval = __atomic_load_n (ptr, __ATOMIC_SEQ_CST);
-    failure = __kernel_cmpxchg (ptr, oldval, 0);
-  } while (failure != 0);
-}
+SYNC_LOCK_RELEASE_1 (int, 4)
+SYNC_LOCK_RELEASE_1 (short, 2)
+SYNC_LOCK_RELEASE_1 (signed char, 1)
Index: gcc/doc/invoke.texi
===================================================================
--- gcc/doc/invoke.texi	(.../tags/gcc_8_2_0_release)
+++ gcc/doc/invoke.texi	(.../branches/gcc-8-branch)
@@ -260,7 +260,7 @@
 @xref{Warning Options,,Options to Request or Suppress Warnings}.
 @gccoptlist{-fsyntax-only  -fmax-errors=@var{n}  -Wpedantic @gol
 -pedantic-errors @gol
--w  -Wextra  -Wall  -Waddress  -Waggregate-return  @gol
+-w  -Wextra  -Wall  -Waddress  -Waggregate-return  -Waligned-new @gol
 -Walloc-zero  -Walloc-size-larger-than=@var{n}
 -Walloca  -Walloca-larger-than=@var{n} @gol
 -Wno-aggressive-loop-optimizations  -Warray-bounds  -Warray-bounds=@var{n} @gol
@@ -12418,9 +12418,9 @@
 across different shared libraries.  In that case, each of the libraries
 as well as the application itself should use the shared @file{libgcc}.
 
-Therefore, the G++ and driver automatically adds @option{-shared-libgcc}
- whenever you build a shared library or a main executable, because C++
- programs typically use exceptions, so this is the right thing to do.
+Therefore, the G++ driver automatically adds @option{-shared-libgcc}
+whenever you build a shared library or a main executable, because C++
+programs typically use exceptions, so this is the right thing to do.
 
 If, instead, you use the GCC driver to create shared libraries, you may
 find that they are not always linked with the shared @file{libgcc}.
@@ -12434,8 +12434,7 @@
 costs at library load time.
 
 However, if a library or main executable is supposed to throw or catch
-exceptions, you must link it using the G++ driver, as appropriate
-for the languages used in the program, or using the option
+exceptions, you must link it using the G++ driver, or using the option
 @option{-shared-libgcc}, such that it is linked with the shared
 @file{libgcc}.
 
Index: gcc/tree-ssa-tail-merge.c
===================================================================
--- gcc/tree-ssa-tail-merge.c	(.../tags/gcc_8_2_0_release)
+++ gcc/tree-ssa-tail-merge.c	(.../branches/gcc-8-branch)
@@ -286,6 +286,21 @@
 #define BB_VOP_AT_EXIT(bb) (((struct aux_bb_info *)bb->aux)->vop_at_exit)
 #define BB_DEP_BB(bb) (((struct aux_bb_info *)bb->aux)->dep_bb)
 
+/* Valueization helper querying the VN lattice.  */
+
+static tree
+tail_merge_valueize (tree name)
+{
+  if (TREE_CODE (name) == SSA_NAME
+      && has_VN_INFO (name))
+    {
+      tree tem = VN_INFO (name)->valnum;
+      if (tem != VN_TOP)
+	return tem;
+    }
+  return name;
+}
+
 /* Returns true if the only effect a statement STMT has, is to define locally
    used SSA_NAMEs.  */
 
@@ -301,7 +316,15 @@
   if (gimple_vdef (stmt) != NULL_TREE
       || gimple_has_side_effects (stmt)
       || gimple_could_trap_p_1 (stmt, false, false)
-      || gimple_vuse (stmt) != NULL_TREE)
+      || gimple_vuse (stmt) != NULL_TREE
+      /* Copied from tree-ssa-ifcombine.c:bb_no_side_effects_p():
+	 const calls don't match any of the above, yet they could
+	 still have some side-effects - they could contain
+	 gimple_could_trap_p statements, like floating point
+	 exceptions or integer division by zero.  See PR70586.
+	 FIXME: perhaps gimple_has_side_effects or gimple_could_trap_p
+	 should handle this.  */
+      || is_gimple_call (stmt))
     return false;
 
   def_p = SINGLE_SSA_DEF_OPERAND (stmt, SSA_OP_DEF);
@@ -363,7 +386,7 @@
   if (val1 == val2)
     return true;
 
-  if (vn_valueize (val1) != vn_valueize (val2))
+  if (tail_merge_valueize (val1) != tail_merge_valueize (val2))
     return false;
 
   return ((TREE_CODE (val1) == SSA_NAME || CONSTANT_CLASS_P (val1))
@@ -473,7 +496,7 @@
       for (i = 0; i < gimple_call_num_args (stmt); i++)
 	{
 	  arg = gimple_call_arg (stmt, i);
-	  arg = vn_valueize (arg);
+	  arg = tail_merge_valueize (arg);
 	  inchash::add_expr (arg, hstate);
 	}
     }
@@ -1139,7 +1162,7 @@
       if (lhs1 == NULL_TREE || lhs2 == NULL_TREE)
 	return false;
       if (TREE_CODE (lhs1) == SSA_NAME && TREE_CODE (lhs2) == SSA_NAME)
-	return vn_valueize (lhs1) == vn_valueize (lhs2);
+	return tail_merge_valueize (lhs1) == tail_merge_valueize (lhs2);
       return operand_equal_p (lhs1, lhs2, 0);
 
     case GIMPLE_ASSIGN:
Index: gcc/c-family/c.opt
===================================================================
--- gcc/c-family/c.opt	(.../tags/gcc_8_2_0_release)
+++ gcc/c-family/c.opt	(.../branches/gcc-8-branch)
@@ -1339,8 +1339,8 @@
 static-libmpxwrappers
 Driver
 
-fcilkplus Undocumented
-C ObjC C++ ObjC++ LTO Report Var(flag_cilkplus) Init(0)
+fcilkplus
+C ObjC C++ ObjC++ LTO Report Var(flag_cilkplus) Init(0) Undocumented
 Deprecated in GCC 8.  This switch has no effect.
 
 fconcepts
Index: gcc/c-family/ChangeLog
===================================================================
--- gcc/c-family/ChangeLog	(.../tags/gcc_8_2_0_release)
+++ gcc/c-family/ChangeLog	(.../branches/gcc-8-branch)
@@ -1,3 +1,8 @@
+2018-08-17  Martin Liska  <mliska@suse.cz>
+
+        PR other/86992
+	* c.opt: Fix declaration of cilkplus.
+
 2018-07-26  Release Manager
 
 	* GCC 8.2.0 released.
Index: gcc/c/ChangeLog
===================================================================
--- gcc/c/ChangeLog	(.../tags/gcc_8_2_0_release)
+++ gcc/c/ChangeLog	(.../branches/gcc-8-branch)
@@ -1,3 +1,10 @@
+2018-08-01  Jakub Jelinek  <jakub@redhat.com>
+
+	PR c/85704
+	* c-typeck.c (init_field_decl_cmp): New function.
+	(output_pending_init_elements): Use it for field comparisons
+	instead of pure bit_position comparisons.
+
 2018-07-26  Release Manager
 
 	* GCC 8.2.0 released.
Index: gcc/c/c-typeck.c
===================================================================
--- gcc/c/c-typeck.c	(.../tags/gcc_8_2_0_release)
+++ gcc/c/c-typeck.c	(.../branches/gcc-8-branch)
@@ -9316,6 +9316,65 @@
     output_pending_init_elements (0, braced_init_obstack);
 }
 
+/* For two FIELD_DECLs in the same chain, return -1 if field1
+   comes before field2, 1 if field1 comes after field2 and
+   0 if field1 == field2.  */
+
+static int
+init_field_decl_cmp (tree field1, tree field2)
+{
+  if (field1 == field2)
+    return 0;
+
+  tree bitpos1 = bit_position (field1);
+  tree bitpos2 = bit_position (field2);
+  if (tree_int_cst_equal (bitpos1, bitpos2))
+    {
+      /* If one of the fields has non-zero bitsize, then that
+	 field must be the last one in a sequence of zero
+	 sized fields, fields after it will have bigger
+	 bit_position.  */
+      if (TREE_TYPE (field1) != error_mark_node
+	  && COMPLETE_TYPE_P (TREE_TYPE (field1))
+	  && integer_nonzerop (TREE_TYPE (field1)))
+	return 1;
+      if (TREE_TYPE (field2) != error_mark_node
+	  && COMPLETE_TYPE_P (TREE_TYPE (field2))
+	  && integer_nonzerop (TREE_TYPE (field2)))
+	return -1;
+      /* Otherwise, fallback to DECL_CHAIN walk to find out
+	 which field comes earlier.  Walk chains of both
+	 fields, so that if field1 and field2 are close to each
+	 other in either order, it is found soon even for large
+	 sequences of zero sized fields.  */
+      tree f1 = field1, f2 = field2;
+      while (1)
+	{
+	  f1 = DECL_CHAIN (f1);
+	  f2 = DECL_CHAIN (f2);
+	  if (f1 == NULL_TREE)
+	    {
+	      gcc_assert (f2);
+	      return 1;
+	    }
+	  if (f2 == NULL_TREE)
+	    return -1;
+	  if (f1 == field2)
+	    return -1;
+	  if (f2 == field1)
+	    return 1;
+	  if (!tree_int_cst_equal (bit_position (f1), bitpos1))
+	    return 1;
+	  if (!tree_int_cst_equal (bit_position (f2), bitpos1))
+	    return -1;
+	}
+    }
+  else if (tree_int_cst_lt (bitpos1, bitpos2))
+    return -1;
+  else
+    return 1;
+}
+
 /* Output any pending elements which have become next.
    As we output elements, constructor_unfilled_{fields,index}
    advances, which may cause other elements to become next;
@@ -9387,26 +9446,19 @@
 	}
       else if (RECORD_OR_UNION_TYPE_P (constructor_type))
 	{
-	  tree ctor_unfilled_bitpos, elt_bitpos;
-
 	  /* If the current record is complete we are done.  */
 	  if (constructor_unfilled_fields == NULL_TREE)
 	    break;
 
-	  ctor_unfilled_bitpos = bit_position (constructor_unfilled_fields);
-	  elt_bitpos = bit_position (elt->purpose);
-	  /* We can't compare fields here because there might be empty
-	     fields in between.  */
-	  if (tree_int_cst_equal (elt_bitpos, ctor_unfilled_bitpos))
+	  int cmp = init_field_decl_cmp (constructor_unfilled_fields,
+					 elt->purpose);
+	  if (cmp == 0)
+	    output_init_element (input_location, elt->value, elt->origtype,
+				 true, TREE_TYPE (elt->purpose),
+				 elt->purpose, false, false,
+				 braced_init_obstack);
+	  else if (cmp < 0)
 	    {
-	      constructor_unfilled_fields = elt->purpose;
-	      output_init_element (input_location, elt->value, elt->origtype,
-				   true, TREE_TYPE (elt->purpose),
-				   elt->purpose, false, false,
-				   braced_init_obstack);
-	    }
-	  else if (tree_int_cst_lt (ctor_unfilled_bitpos, elt_bitpos))
-	    {
 	      /* Advance to the next smaller node.  */
 	      if (elt->left)
 		elt = elt->left;
@@ -9431,8 +9483,8 @@
 		    elt = elt->parent;
 		  elt = elt->parent;
 		  if (elt
-		      && (tree_int_cst_lt (ctor_unfilled_bitpos,
-					   bit_position (elt->purpose))))
+		      && init_field_decl_cmp (constructor_unfilled_fields,
+					      elt->purpose) < 0)
 		    {
 		      next = elt->purpose;
 		      break;
Index: gcc/DATESTAMP
===================================================================
--- gcc/DATESTAMP	(.../tags/gcc_8_2_0_release)
+++ gcc/DATESTAMP	(.../branches/gcc-8-branch)
@@ -1 +1 @@
-20180726
+20181009
Index: gcc/defaults.h
===================================================================
--- gcc/defaults.h	(.../tags/gcc_8_2_0_release)
+++ gcc/defaults.h	(.../branches/gcc-8-branch)
@@ -1282,6 +1282,10 @@
 #define TARGET_PECOFF 0
 #endif
 
+#ifndef TARGET_COFF
+#define TARGET_COFF 0
+#endif
+
 #ifndef EH_RETURN_HANDLER_RTX
 #define EH_RETURN_HANDLER_RTX NULL
 #endif
Index: gcc/tree-ssa-strlen.c
===================================================================
--- gcc/tree-ssa-strlen.c	(.../tags/gcc_8_2_0_release)
+++ gcc/tree-ssa-strlen.c	(.../branches/gcc-8-branch)
@@ -1182,6 +1182,7 @@
      suggests if it's treated as a poor-man's flexible array member.  */
   src = TREE_OPERAND (src, 0);
   if (TREE_CODE (TREE_TYPE (src)) != ARRAY_TYPE
+      || TREE_CODE (src) == MEM_REF
       || array_at_struct_end_p (src))
     return;
 
Index: gcc/tree.c
===================================================================
--- gcc/tree.c	(.../tags/gcc_8_2_0_release)
+++ gcc/tree.c	(.../branches/gcc-8-branch)
@@ -9784,8 +9784,7 @@
       TYPE_SIZE (int_n_trees[i].signed_type) = bitsize_int (int_n_data[i].bitsize);
       TYPE_SIZE (int_n_trees[i].unsigned_type) = bitsize_int (int_n_data[i].bitsize);
 
-      if (int_n_data[i].bitsize > LONG_LONG_TYPE_SIZE
-	  && int_n_enabled_p[i])
+      if (int_n_enabled_p[i])
 	{
 	  integer_types[itk_intN_0 + i * 2] = int_n_trees[i].signed_type;
 	  integer_types[itk_unsigned_intN_0 + i * 2] = int_n_trees[i].unsigned_type;
Index: gcc/tree.h
===================================================================
--- gcc/tree.h	(.../tags/gcc_8_2_0_release)
+++ gcc/tree.h	(.../branches/gcc-8-branch)
@@ -3061,6 +3061,10 @@
 #define DECL_CXX_DESTRUCTOR_P(NODE)\
    (FUNCTION_DECL_CHECK (NODE)->decl_with_vis.cxx_destructor)
 
+/* In FUNCTION_DECL, this is set if this function is a lambda function.  */
+#define DECL_LAMBDA_FUNCTION(NODE) \
+  (FUNCTION_DECL_CHECK (NODE)->function_decl.lambda_function)
+
 /* In FUNCTION_DECL that represent an virtual method this is set when
    the method is final.  */
 #define DECL_FINAL_P(NODE)\
Index: gcc/rtlanal.c
===================================================================
--- gcc/rtlanal.c	(.../tags/gcc_8_2_0_release)
+++ gcc/rtlanal.c	(.../branches/gcc-8-branch)
@@ -1802,6 +1802,7 @@
  recurse:
   switch (GET_CODE (x))
     {
+    case CLOBBER:
     case STRICT_LOW_PART:
     case ZERO_EXTRACT:
     case SIGN_EXTRACT:
Index: gcc/fold-const.c
===================================================================
--- gcc/fold-const.c	(.../tags/gcc_8_2_0_release)
+++ gcc/fold-const.c	(.../branches/gcc-8-branch)
@@ -4922,8 +4922,8 @@
   /* Disable this optimization for function pointer expressions
      on targets that require function pointer canonicalization.  */
   if (targetm.have_canonicalize_funcptr_for_compare ()
-      && TREE_CODE (etype) == POINTER_TYPE
-      && TREE_CODE (TREE_TYPE (etype)) == FUNCTION_TYPE)
+      && POINTER_TYPE_P (etype)
+      && FUNC_OR_METHOD_TYPE_P (TREE_TYPE (etype)))
     return NULL_TREE;
 
   if (! in_p)
@@ -11565,10 +11565,16 @@
 	  && integer_pow2p (arg1)
 	  && TREE_CODE (TREE_OPERAND (arg0, 0)) == BIT_AND_EXPR
 	  && operand_equal_p (TREE_OPERAND (TREE_OPERAND (arg0, 0), 1),
-			      arg1, OEP_ONLY_CONST))
+			      arg1, OEP_ONLY_CONST)
+	  /* operand_equal_p compares just value, not precision, so e.g.
+	     arg1 could be 8-bit -128 and be power of two, but BIT_AND_EXPR
+	     second operand 32-bit -128, which is not a power of two (or vice
+	     versa.  */
+	  && integer_pow2p (TREE_OPERAND (TREE_OPERAND (arg0, 0), 1)))
 	return pedantic_non_lvalue_loc (loc,
-				    fold_convert_loc (loc, type,
-						      TREE_OPERAND (arg0, 0)));
+					fold_convert_loc (loc, type,
+							  TREE_OPERAND (arg0,
+									0)));
 
       /* Disable the transformations below for vectors, since
 	 fold_binary_op_with_conditional_arg may undo them immediately,
Index: gcc/omp-low.c
===================================================================
--- gcc/omp-low.c	(.../tags/gcc_8_2_0_release)
+++ gcc/omp-low.c	(.../branches/gcc-8-branch)
@@ -1190,7 +1190,7 @@
 	  /* Global variables with "omp declare target" attribute
 	     don't need to be copied, the receiver side will use them
 	     directly.  However, global variables with "omp declare target link"
-	     attribute need to be copied.  */
+	     attribute need to be copied.  Or when ALWAYS modifier is used.  */
 	  if (OMP_CLAUSE_CODE (c) == OMP_CLAUSE_MAP
 	      && DECL_P (decl)
 	      && ((OMP_CLAUSE_MAP_KIND (c) != GOMP_MAP_FIRSTPRIVATE_POINTER
@@ -1197,6 +1197,9 @@
 		   && (OMP_CLAUSE_MAP_KIND (c)
 		       != GOMP_MAP_FIRSTPRIVATE_REFERENCE))
 		  || TREE_CODE (TREE_TYPE (decl)) == ARRAY_TYPE)
+	      && OMP_CLAUSE_MAP_KIND (c) != GOMP_MAP_ALWAYS_TO
+	      && OMP_CLAUSE_MAP_KIND (c) != GOMP_MAP_ALWAYS_FROM
+	      && OMP_CLAUSE_MAP_KIND (c) != GOMP_MAP_ALWAYS_TOFROM
 	      && is_global_var (maybe_lookup_decl_in_outer_ctx (decl, ctx))
 	      && varpool_node::get_create (decl)->offloadable
 	      && !lookup_attribute ("omp declare target link",
@@ -7099,6 +7102,7 @@
   splay_tree_node n;
   struct omp_taskcopy_context tcctx;
   location_t loc = gimple_location (task_stmt);
+  size_t looptempno = 0;
 
   child_fn = gimple_omp_task_copy_fn (task_stmt);
   child_cfun = DECL_STRUCT_FUNCTION (child_fn);
@@ -7212,6 +7216,15 @@
 	t = build2 (MODIFY_EXPR, TREE_TYPE (dst), dst, src);
 	append_to_statement_list (t, &list);
 	break;
+      case OMP_CLAUSE__LOOPTEMP_:
+	/* Fields for first two _looptemp_ clauses are initialized by
+	   GOMP_taskloop*, the rest are handled like firstprivate.  */
+        if (looptempno < 2)
+	  {
+	    looptempno++;
+	    break;
+	  }
+	/* FALLTHRU */
       case OMP_CLAUSE_FIRSTPRIVATE:
 	decl = OMP_CLAUSE_DECL (c);
 	if (is_variable_sized (decl))
@@ -7237,7 +7250,10 @@
 	  src = decl;
 	dst = build_simple_mem_ref_loc (loc, arg);
 	dst = omp_build_component_ref (dst, f);
-	t = lang_hooks.decls.omp_clause_copy_ctor (c, dst, src);
+	if (OMP_CLAUSE_CODE (c) == OMP_CLAUSE__LOOPTEMP_)
+	  t = build2 (MODIFY_EXPR, TREE_TYPE (dst), dst, src);
+	else
+	  t = lang_hooks.decls.omp_clause_copy_ctor (c, dst, src);
 	append_to_statement_list (t, &list);
 	break;
       case OMP_CLAUSE_PRIVATE:
Index: gcc/gcov.c
===================================================================
--- gcc/gcov.c	(.../tags/gcc_8_2_0_release)
+++ gcc/gcov.c	(.../branches/gcc-8-branch)
@@ -536,6 +536,7 @@
 static void print_usage (int) ATTRIBUTE_NORETURN;
 static void print_version (void) ATTRIBUTE_NORETURN;
 static void process_file (const char *);
+static void process_all_functions (void);
 static void generate_results (const char *);
 static void create_file_names (const char *);
 static char *canonicalize_name (const char *);
@@ -791,6 +792,7 @@
 
       if (flag_intermediate_format || argno == argc - 1)
 	{
+	  process_all_functions ();
 	  generate_results (argv[argno]);
 	  release_structures ();
 	}
@@ -1066,7 +1068,8 @@
 	}
 
       /* Follow with lines associated with the source file.  */
-      output_intermediate_line (gcov_file, &src->lines[line_num], line_num);
+      if (line_num < src->lines.size ())
+	output_intermediate_line (gcov_file, &src->lines[line_num], line_num);
     }
 }
 
@@ -1132,11 +1135,14 @@
 {
   create_file_names (file_name);
   read_graph_file ();
-  if (functions.empty ())
-    return;
-
   read_count_file ();
+}
 
+/* Process all functions in all files.  */
+
+static void
+process_all_functions (void)
+{
   hash_map<function_start_pair_hash, function_info *> fn_map;
 
   /* Identify group functions.  */
@@ -1213,7 +1219,6 @@
 	  if (fn->is_group)
 	    fn->lines.resize (fn->end_line - fn->start_line + 1);
 
-
 	  solve_flow_graph (fn);
 	  if (fn->has_catch)
 	    find_exception_blocks (fn);
Index: gcc/pretty-print.c
===================================================================
--- gcc/pretty-print.c	(.../tags/gcc_8_2_0_release)
+++ gcc/pretty-print.c	(.../branches/gcc-8-branch)
@@ -640,6 +640,16 @@
 	{
 	  attrib_add |= sb.wAttributes & ~attrib_rm;
 	}
+      if (attrib_add & COMMON_LVB_REVERSE_VIDEO)
+	{
+	  /* COMMON_LVB_REVERSE_VIDEO is only effective for DBCS.
+	   * Swap foreground and background colors by hand.
+	   */
+	  attrib_add = (attrib_add & 0xFF00)
+			| ((attrib_add & 0x00F0) >> 4)
+			| ((attrib_add & 0x000F) << 4);
+	  attrib_add &= ~COMMON_LVB_REVERSE_VIDEO;
+	}
       SetConsoleTextAttribute (h, attrib_add);
       break;
     }
@@ -684,7 +694,6 @@
     /* If it is not a console, write everything as-is.  */
     write_all (h, read, strlen (read));
 
-  _close ((intptr_t) h);
   return 1;
 }
 
Index: gcc/ChangeLog
===================================================================
--- gcc/ChangeLog	(.../tags/gcc_8_2_0_release)
+++ gcc/ChangeLog	(.../branches/gcc-8-branch)
@@ -1,3 +1,552 @@
+2018-10-09  H.J. Lu  <hongjiu.lu@intel.com>
+
+	Backport from mainline
+	2018-09-29  H.J. Lu  <hongjiu.lu@intel.com>
+
+	PR target/87370
+	* config/i386/i386.c (construct_container): Use TImode for
+	BLKmode values in 2 integer registers.
+
+2018-10-08  H.J. Lu  <hongjiu.lu@intel.com>
+
+	Backport from mainline
+	2018-10-08  H.J. Lu  <hongjiu.lu@intel.com>
+
+	PR target/87517
+	* config/i386/avx512fintrin.h (_mm512_mask_fmaddsub_round_pd):
+	Defined with __builtin_ia32_vfmaddsubpd512_mask.
+
+2018-10-05  H.J. Lu  <hongjiu.lu@intel.com>
+
+	Backport from mainline
+	2018-10-05  H.J. Lu  <hongjiu.lu@intel.com>
+
+	PR target/87522
+	* config/i386/gnu-user.h (ASM_SPEC): Don't pass -msse2avx to
+	assembler for -mavx.
+	* config/i386/gnu-user64.h (ASM_SPEC): Likewise.
+
+2018-10-03  Uros Bizjak  <ubizjak@gmail.com>
+
+	Backport from mainline
+	2018-09-28  Uros Bizjak  <ubizjak@gmail.com>
+
+	* config/i386/i386.h (SSE_REGNO): Fix check for FIRST_REX_SSE_REG.
+	(GET_SSE_REGNO): Rename from SSE_REGNO.  Update all uses for rename.
+
+2018-10-03  Jonathan Wakely  <jwakely@redhat.com>
+
+	PR other/87353
+	* doc/invoke.texi (Link Options): Fix formatting and grammar.
+
+2018-10-03  Martin Liska  <mliska@suse.cz>
+
+	Backport from mainline
+	2018-10-03  Martin Liska  <mliska@suse.cz>
+
+	PR gcov-profile/86109
+	* coverage.c (coverage_begin_function): Do not
+	mark lambdas as artificial.
+	* tree-core.h (struct GTY): Remove tm_clone_flag
+	and introduce new lambda_function.
+	* tree.h (DECL_LAMBDA_FUNCTION): New macro.
+
+2018-10-02  H.J. Lu  <hongjiu.lu@intel.com>
+
+	Backport from mainline
+	2018-09-24  H.J. Lu  <hongjiu.lu@intel.com>
+
+	PR target/82699
+	* config/i386/i386.c (rest_of_insert_endbranch): Set
+	endbr_queued_at_entrance to true and don't insert ENDBR if
+	x86_function_profiler will be called.
+	(x86_function_profiler): Insert ENDBR if endbr_queued_at_entrance
+	is true.
+	* config/i386/i386.h (machine_function): Add
+	endbr_queued_at_entrance.
+
+2018-10-01  Kyrylo Tkachov  <kyrylo.tkachov@arm.com>
+
+	Backport from mainline
+	2018-06-29  Kyrylo Tkachov  <kyrylo.tkachov@arm.com>
+
+	* config/arm/arm.c (output_move_double): Don't allow STRD instructions
+	if starting source register is not even.
+
+2018-09-29  Jakub Jelinek  <jakub@redhat.com>
+
+	PR target/87467
+	* config/i386/avx512fintrin.h (_mm512_abs_pd, _mm512_mask_abs_pd): Use
+	__m512d type for __A argument rather than __m512.
+
+2018-09-27  Michael Meissner  <meissner@linux.ibm.com>
+
+	Backport from mainline
+	2018-08-20  Michael Meissner  <meissner@linux.ibm.com>
+
+	PR target/87033
+	* config/rs6000/rs6000.md (extendsi<mode>2): Change constraints
+	from 'Y' to 'YZ' to enable the LWAX instruction to be generated
+	for indexed loads.
+
+2018-09-25  Martin Liska  <mliska@suse.cz>
+
+	Backport from mainline
+	2018-09-24  Martin Liska  <mliska@suse.cz>
+
+	PR sanitizer/85774
+	* asan.c: Make asan_handled_variables extern.
+	* asan.h: Likewise.
+	* cfgexpand.c (expand_stack_vars): Make sure
+	a representative is unpoison if another
+	variable in the partition is handled by
+	use-after-scope sanitization.
+
+2018-09-24  Andrew Pinski  <apinski@marvell.com>
+
+	*  config/aarch64/aarch64.c (aarch_macro_fusion_pair_p): Don't
+	access prev before checking it for NULLness in the
+	AARCH64_FUSE_CMP_BRANCH case.
+
+2018-09-21  Eric Botcazou  <ebotcazou@adacore.com>
+
+	* config/rs6000/rs6000.c (rs6000_function_ok_for_sibcall): Return false
+	if the call takes a static chain.
+
+2018-09-19  John David Anglin  <danglin@gcc.gnu.org>
+
+	* config/pa/pa.md (atomic_storeqi): Restore deleted expander.
+	(atomic_storehi): Likewise.
+	(atomic_storesi): Likewise.
+	(atomic_loaddi): Restore compare and swap exchange loop code.
+
+2018-09-18  Segher Boessenkool  <segher@kernel.crashing.org>
+
+	Backport from trunk
+	2018-09-18  Segher Boessenkool  <segher@kernel.crashing.org>
+
+	PR rtl-optimization/86882
+	* rtlanal.c (reg_overlap_mentioned_p): Handle CLOBBER.
+
+2018-09-18  Martin Liska  <mliska@suse.cz>
+
+	Backport from mainline
+	2018-09-17  Martin Liska  <mliska@suse.cz>
+
+	PR gcov-profile/85871
+	* gcov.c (output_intermediate_file): Fix out of bounds
+	access.
+
+2018-09-16  Hans-Peter Nilsson  <hp@bitrange.com>
+
+	PR target/85666
+	* config/mmix/mmix.c (mmix_assemble_integer): Handle byte-size
+	non-CONST_INT rtx:es using assemble_integer_with_op ".byte".
+	(MMIX_CFUN_NEEDS_SAVED_EH_RETURN_ADDRESS): Don't call
+	leaf_function_p, instead use has_hard_reg_initial_val.
+
+2018-09-14  John David Anglin  <danglin@gcc.gnu.org>
+
+	PR middle-end/87188
+	* dojump.c (do_compare_and_jump): Canonicalize function pointers
+	when one operand is a function pointer.  Use POINTER_TYPE_P and
+	FUNC_OR_METHOD_TYPE_P.
+	* expr.c (do_store_flag): Use POINTER_TYPE_P and FUNC_OR_METHOD_TYPE_P.
+	* fold-const.c (build_range_check): Likewise.
+	* match.pd (simple_comparison): Likewise.
+
+2018-09-14  Segher Boessenkool  <segher@kernel.crashing.org>
+
+	Backport from trunk
+	2018-09-14  Segher Boessenkool  <segher@kernel.crashing.org>
+
+	PR target/87224
+	* config/rs6000/rs6000.md (*mov<mode>_hardfloat64): Add Z to the Y
+	alternatives.
+
+2018-09-14  Carl Love  <cel@us.ibm.com>
+
+        Backport from trunk
+        2018-09-14  Carl Love  <cel@us.ibm.com>
+
+	* config/rs6000/emmintrin.h: Add _MM_SHUFFLE2.
+	* config/rs6000/xmmintrin.h: Add _MM_SHUFFLE.
+
+2018-09-12  Segher Boessenkool  <segher@kernel.crashing.org>
+
+	Backport from trunk
+	2018-08-24  Segher Boessenkool  <segher@kernel.crashing.org>
+
+	PR target/86989
+	* config/rs6000/rs6000.c (toc_relative_expr_p): Check that the base is
+	the TOC register.
+
+2018-09-12  Segher Boessenkool  <segher@kernel.crashing.org>
+
+	Backport from trunk
+	2018-08-22  Segher Boessenkool  <segher@kernel.crashing.org>
+
+	PR rtl-optimization/86771
+	* combine.c (try_combine): Do not allow splitting a resulting PARALLEL
+	of two SETs into those two SETs, one to be placed at i2, if that SETs
+	destination is modified between i2 and i3.
+
+2018-09-12  Andreas Krebbel  <krebbel@linux.ibm.com>
+
+	Backport from mainline
+	2018-09-12  Andreas Krebbel  <krebbel@linux.ibm.com>
+
+	* config/s390/s390.md (PFPO_RND_MODE_DFP, PFPO_RND_MODE_BFP): New
+	constants.
+	("trunc<BFP:mode><DFP_ALL:mode>2")
+	("trunc<DFP_ALL:mode><BFP:mode>2")
+	("extend<BFP:mode><DFP_ALL:mode>2")
+	("extend<DFP_ALL:mode><BFP:mode>2"): Set proper rounding mode
+	according to the target operand type.
+
+2018-09-12  Jakub Jelinek  <jakub@redhat.com>
+
+	PR middle-end/87248
+	* fold-const.c (fold_ternary_loc) <case COND_EXPR>: Verify also that
+	BIT_AND_EXPR's second operand is a power of two.  Formatting fix.
+
+2018-09-05  Nathan Sidwell  <nathan@acm.org>
+
+	PR c++/87137
+	* stor-layout.c (place_field): Scan forwards to check last
+	bitfield when ms_bitfield_placement is in effect.
+
+2018-09-05  Richard Biener  <rguenther@suse.de>
+
+	PR bootstrap/87225
+	* tree-vect-stmts.c (vectorizable_simd_clone_call): Fix bogus
+	return.
+
+2018-09-05  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from mainline
+	2018-09-04  Jakub Jelinek  <jakub@redhat.com>
+
+	PR target/87198
+	* common/config/i386/i386-common.c (OPTION_MASK_ISA_XSAVEOPT_SET,
+	OPTION_MASK_ISA_XSAVES_SET, OPTION_MASK_ISA_XSAVEC_SET): Use
+	OPTION_MASK_ISA_XSAVE_SET instead of OPTION_MASK_ISA_XSAVE.
+	(OPTION_MASK_ISA_XSAVE_UNSET): Add OPTION_MASK_ISA_XSAVES_UNSET
+	and OPTION_MASK_ISA_XSAVEC_UNSET.
+
+	2018-08-31  Jakub Jelinek  <jakub@redhat.com>
+
+	PR middle-end/87138
+	* expmed.c (expand_mult_const): Use immed_wide_int_const instead of
+	gen_int_mode.  Formatting fixes.
+
+	2018-08-11  Jakub Jelinek  <jakub@redhat.com>
+
+	PR tree-optimization/86835
+	* tree-ssa-math-opts.c (insert_reciprocals): Even when inserting
+	new_stmt after def_gsi, make sure to insert new_square_stmt after
+	that stmt, not 2 stmts before it.
+
+2018-09-04  Max Filippov  <jcmvbkbc@gmail.com>
+
+	Backport from mainline
+	2018-09-04  Max Filippov  <jcmvbkbc@gmail.com>
+
+	* config/xtensa/xtensa.c (xtensa_expand_atomic): Reorder AND and
+	XOR operations in NAND case.
+
+2018-09-04  Jonathan Wakely  <jwakely@redhat.com>
+
+	* doc/invoke.texi (Option Summary): Add -Waligned-new.
+
+2018-09-03  Tom de Vries  <tdevries@suse.de>
+
+	backport from trunk:
+	2018-06-21  Tom de Vries  <tdevries@suse.de>
+
+	PR tree-optimization/85859
+	* tree-ssa-tail-merge.c (stmt_local_def): Copy gimple_is_call
+	test with comment from bb_no_side_effects_p.
+
+2018-09-01  Michael Matz  <matz@suse.de>
+
+	Backport from mainline
+	PR tree-optimization/87074
+	* gimple-loop-jam.c (unroll_jam_possible_p): Check loop exit
+	PHIs for outer-loop uses.
+
+2018-08-31  Richard Biener  <rguenther@suse.de>
+
+	Backport from mainline
+	2018-08-27  Richard Biener  <rguenther@suse.de>
+
+	PR tree-optimization/86927
+	* tree-vect-loop.c (vect_create_epilog_for_reduction): Properly
+	use const cond reduction code.
+
+	2018-08-23  Richard Biener  <rguenther@suse.de>
+
+	PR middle-end/87024
+	* tree-inline.c (copy_bb): Drop unused __builtin_va_arg_pack_len
+	calls.
+
+	2018-08-22  Richard Biener  <rguenther@suse.de>
+
+	PR tree-optimization/86945
+	* tree-cfg.c (generate_range_test): Use unsigned arithmetic.
+
+	2018-08-17  Richard Biener  <rguenther@suse.de>
+
+	PR middle-end/86505
+	* tree-inline.c (copy_bb): When inlining __builtin_va_arg_pack_len ()
+	across a va-arg-pack using call adjust its return value accordingly.
+
+	2018-08-02  Richard Biener  <rguenther@suse.de>
+
+	PR tree-optimization/86816
+	* tree-ssa-tail-merge.c (tail_merge_valueize): New function
+	which checks for value availability before querying it.
+	(gvn_uses_equal): Use it.
+	(same_succ_hash): Likewise.
+	(gimple_equal_p): Likewise.
+
+	2018-07-17  Richard Biener  <rguenther@suse.de>
+
+	PR lto/86456
+	* dwarf2out.c (init_sections_and_labels): Always generate
+	a debug_line_str_section for early LTO debug.
+	(dwarf2out_finish): Reset debug_line_str_hash output early.
+	Bump counter for extra dwarf5 .debug_loc labels to not conflict
+	with fat LTO part.
+	(dwarf2out_early_finish): Output debug_line_str.
+
+2018-08-29  Luis Machado  <luis.machado@linaro.org>
+
+	* config/aarch64/aarch64.c (qdf24xx_vector_cost): New static global.
+	(qdf24xx_tunings): Set vector cost structure to qdf24xx_vector_cost.
+
+2018-08-29  Luis Machado  <luis.machado@linaro.org>
+
+	* config/aarch64/aarch64.c (qdf24xx_addrcost_table)
+	<register_sextend>: Set to 3.
+
+2018-08-27  Martin Sebor  <msebor@redhat.com>
+
+	PR tree-optimization/86914
+	* tree-ssa-strlen.c (maybe_set_strlen_range): Avoid MEM_REF.
+
+2018-08-28  Jakub Jelinek  <jakub@redhat.com>
+
+	PR middle-end/87099
+	* calls.c (maybe_warn_nonstring_arg): Punt early if
+	warn_stringop_overflow is zero.  Don't call get_range_strlen
+	on 3rd argument, keep iterating until lenrng[1] is INTEGER_CST.
+	Only use lenrng[1] if non-NULL and INTEGER_CST.  Don't uselessly
+	increment lenrng[0].
+
+2018-08-27  Jakub Jelinek  <jakub@redhat.com>
+
+	PR rtl-optimization/87065
+	* combine.c (simplify_if_then_else): Formatting fix.
+	(if_then_else_cond): Guard MULT optimization with SCALAR_INT_MODE_P
+	check.
+	(known_cond): Don't return const_true_rtx for vector modes.  Use
+	CONST0_RTX instead of const0_rtx.  Formatting fixes.
+
+2018-08-25  Jozef Lawrynowicz  <jozef.l@mittosystems.com>
+
+	Backport from mainline
+	PR target/86662
+	* gcc/tree.c (build_common_tree_nodes): Initialize integer_types array
+	with all enabled __intN types.
+
+	* gcc/testsuite/gcc.target/msp430/pr86662.c: New test.
+
+2018-08-21  H.J. Lu  <hongjiu.lu@intel.com>
+
+	Backport from mainline
+	2018-08-20  H.J. Lu  <hongjiu.lu@intel.com>
+
+	PR target/87014
+	* config/i386/i386.md (eh_return): Always update EH return
+	address in word_mode.
+
+2018-08-17  John David Anglin  <danglin@gcc.gnu.org>
+
+	Backport from mainline
+	2018-08-11  John David Anglin  <danglin@gcc.gnu.org>
+
+	* config/pa/pa.md (UNSPEC_MEMORY_BARRIER): New unspec enum.
+	Update comment for atomic instructions.
+	(atomic_storeqi, atomic_storehi, atomic_storesi, atomic_storesf,
+	atomic_loaddf, atomic_loaddf_1, atomic_storedf, atomic_storedf_1):
+	Remove.
+	(atomic_loaddi): Revise fence expansion to only emit fence prior to
+	load for __ATOMIC_SEQ_CST model.
+	(atomic_loaddi_1): Remove float register target.
+	(atomic_storedi): Handle CONST_INT values.
+	(atomic_storedi_1): Remove float register source.  Add special case
+	for zero value.
+	(memory_barrier): New expander and insn.
+
+2018-08-16  Tamar Christina <tamar.christina@arm.com>
+
+	Backport from mainline
+	2018-07-30  Segher Boessenkool  <segher@kernel.crashing.org>
+
+	PR target/86640
+	* config/arm/arm.c (arm_block_set_aligned_vect): Use gen_int_mode
+	instead of GEN_INT.
+
+2018-08-16  Martin Liska  <mliska@suse.cz>
+
+	Backport from mainline
+	2018-08-02  Martin Liska  <mliska@suse.cz>
+
+        PR gcov-profile/86817
+	* gcov.c (process_all_functions): New function.
+	(main): Call it.
+	(process_file): Move functions processing to
+        process_all_functions.
+
+2018-08-14  Siddhesh Poyarekar  <siddhesh@sourceware.org>
+
+	Backport from mainline
+	2018-08-03  Siddhesh Poyarekar  <siddhesh@sourceware.org>
+
+	* config/aarch64/falkor.md (falkor_am_1_vxvy_vxvy): Move
+	neon_dup_q to...
+	(falkor_am_1_gtov_gtov): ... a new insn reservation.
+
+2018-08-13  Liu Hao  <lh_mouse@126.com>
+
+	Backport from mainline
+	2018-08-13  Liu Hao  <lh_mouse@126.com>
+
+	* pretty-print.c (eat_esc_sequence): Swap the foreground and
+	background colors if the COMMON_LVB_REVERSE_VIDEO flag is set,
+	and clear it thereafter, as it only works for DBCS.
+
+2018-08-13  Liu Hao  <lh_mouse@126.com>
+
+	Backport from mainline
+	2018-08-13  Liu	Hao  <lh_mouse@126.com>
+
+	* pretty-print.c (mingw_ansi_fputs): Do not call _close() on the
+	handle returned by _get_osf_handle().
+
+2018-08-14  Richard Sandiford  <richard.sandiford@arm.com>
+
+	Backport from mainline
+	2018-08-09  Richard Sandiford  <richard.sandiford@arm.com>
+
+	PR tree-optimization/86871
+	* tree-vect-stmts.c (vect_transform_stmt): Use gimple_get_lhs
+	instead of gimple_assign_lhs.
+
+2018-08-07  H.J. Lu  <hongjiu.lu@intel.com>
+
+	Backport from mainline
+	2018-08-05  H.J. Lu  <hongjiu.lu@intel.com>
+
+	PR target/86386
+	* config/i386/i386.c (ix86_finalize_stack_frame_flags): Set
+	cfun->machine->max_used_stack_alignment if needed.
+
+2018-08-02  Jozef Lawrynowicz  <jozef.l@mittosystems.com>
+
+	Backport from mainline
+	2018-07-31  Jozef Lawrynowicz  <jozef.l@mittosystems.com>
+	
+	PR middle-end/86705
+	* gcc/cfgexpand.c (set_parm_rtl): Use the alignment of Pmode when
+	MAX_SUPPORTED_STACK_ALIGNMENT would otherwise be exceeded by the
+	requested variable alignment.
+	(expand_one_ssa_partition): Likewise.
+	(expand_one_var): Likewise.
+
+2018-08-02  Andreas Schwab  <schwab@linux-m68k.org>
+
+	Backport from mainline
+	2018-07-17  Andreas Schwab  <schwab@linux-m68k.org>
+
+	PR target/86820
+	* config/m68k/m68k.md (umulsi3_highpart+1, const_umulsi3_highpart)
+	(smulsi3_highpart+1, const_smulsi3_highpart): Add CC_STATUS_INIT.
+
+2018-08-01  Richard Biener  <rguenther@suse.de>
+
+	PR bootstrap/86724
+	* graphite.h: Include isl/id.h and isl/space.h to allow build
+	with ISL 0.20.
+
+2018-08-01 Jan Willem Jagersma  <jwjagersma@gmail.com>
+
+	PR target/86651
+	* dwarf2out.c (dwarf2out_early_finish): Do not generate assembly in LTO
+	mode for COFF targets.
+	* defaults.h (TARGET_COFF): Define.
+	* config/i386/djgpp.h (TARGET_ASM_LTO_START, TARGET_ASM_LTO_END,
+	TARGET_COFF): Define.
+	(i386_djgpp_asm_lto_start, i386_djgpp_asm_lto_end): Declare.
+	* config/i386/djgpp.c (saved_debug_info_level): New static variable.
+	(i386_djgpp_asm_lto_start, i386_djgpp_asm_lto_end): New functions.
+
+2018-07-29  Bernd Edlinger  <bernd.edlinger@hotmail.de>
+
+	Backport from mainline
+	2018-07-23  Bernd Edlinger  <bernd.edlinger@hotmail.de>
+
+	PR c/86617
+	* genmatch.c (dt_operand::gen_match_op): Avoid folding volatile values.
+
+2018-07-29  John David Anglin  <danglin@gcc.gnu.org>
+
+	* config/pa/pa.c (pa_output_addr_vec): Align address table.
+	* config/pa/pa.h (JUMP_TABLES_IN_TEXT_SECTION): Revise comment.
+	* config/pa/pa32-linux.h (JUMP_TABLES_IN_TEXT_SECTION): Define.
+
+2018-07-26  Uros Bizjak  <ubizjak@gmail.com>
+
+	Backport from mainline
+	2018-07-16  Uros Bizjak  <ubizjak@gmail.com>
+
+	PR target/86511
+	* expmed.c (emit_store_flag): Do not emit setcc followed by a
+	conditional move when trapping comparison was split to a
+	non-trapping one (and vice versa).
+
+2018-07-26  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from mainline
+	2018-07-24  Jakub Jelinek  <jakub@redhat.com>
+
+	PR middle-end/86627
+	* expmed.c (expand_divmod): Punt if d == HOST_WIDE_INT_MIN
+	and size > HOST_BITS_PER_WIDE_INT.  For size > HOST_BITS_PER_WIDE_INT
+	and abs_d == d, do the power of two handling if profitable.
+
+	2018-07-17  Jakub Jelinek  <jakub@redhat.com>
+
+	PR middle-end/86542
+	* omp-low.c (create_task_copyfn): Copy over also fields corresponding
+	to _looptemp_ clauses, other than the first two.
+
+	PR middle-end/86539
+	* gimplify.c (gimplify_omp_for): Ensure taskloop firstprivatized init
+	and cond temporaries don't have reference type if iterator has
+	pointer type.  For init use &for_pre_body instead of pre_p if
+	for_pre_body is non-empty.
+
+2018-07-26  Jakub Jelinek  <jakub@redhat.com>
+
+	PR middle-end/86660
+	* omp-low.c (scan_sharing_clauses): Don't ignore map clauses for
+	declare target to variables if they have always,{to,from,tofrom} map
+	kinds.
+
+	* BASE-VER: Set to 8.2.1.
+
 2018-07-26  Release Manager
 
 	* GCC 8.2.0 released.
Index: gcc/testsuite/gcc.target/powerpc/pr87033.c
===================================================================
--- gcc/testsuite/gcc.target/powerpc/pr87033.c	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/gcc.target/powerpc/pr87033.c	(.../branches/gcc-8-branch)
@@ -0,0 +1,12 @@
+/* { dg-do compile { target { powerpc*-*-* && lp64 } } } */
+/* { dg-options "-O2" } */
+
+/* Insure that a LWAX is generated instead of ADD + LWA.  LP64 is needed
+   because the LWA and LWAX instructions are only available in 64-bit mode.  */
+long func (int *p, unsigned long n)
+{
+  return p[n];
+}
+
+/* { dg-final { scan-assembler     {\mlwax\M} } } */
+/* { dg-final { scan-assembler-not {\mlwa\M}  } } */
Index: gcc/testsuite/gcc.target/powerpc/pr58673-2.c
===================================================================
--- gcc/testsuite/gcc.target/powerpc/pr58673-2.c	(.../tags/gcc_8_2_0_release)
+++ gcc/testsuite/gcc.target/powerpc/pr58673-2.c	(.../branches/gcc-8-branch)
@@ -140,7 +140,7 @@
 									   malloc
 									   (__len);
 									   __retval;}
-	    )):	    __strdup (eoNames[i])));
+	    )):	    strdup (eoNames[i])));
 	      raleg[j++] =
 		(__extension__
 		 (__builtin_constant_p (buf)
@@ -165,7 +165,7 @@
 									   malloc
 									   (__len);
 									   __retval;}
-	    )):	    __strdup (buf)));
+	    )):	    strdup (buf)));
 	    }
 	}
       if (tcr->nLJ)
Index: gcc/testsuite/gcc.target/arm/pr86640.c
===================================================================
--- gcc/testsuite/gcc.target/arm/pr86640.c	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/gcc.target/arm/pr86640.c	(.../branches/gcc-8-branch)
@@ -0,0 +1,10 @@
+/* { dg-options "-O3" } */
+
+/* This ICEd with  -O3 -mfpu=neon -mfloat-abi=hard -march=armv7-a  .  */
+
+char fn1() {
+  long long b[5];
+  for (int a = 0; a < 5; a++)
+    b[a] = ~0ULL;
+  return b[3];
+}
Index: gcc/testsuite/gcc.target/arm/arm-soft-strd-even.c
===================================================================
--- gcc/testsuite/gcc.target/arm/arm-soft-strd-even.c	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/gcc.target/arm/arm-soft-strd-even.c	(.../branches/gcc-8-branch)
@@ -0,0 +1,19 @@
+/* { dg-do assemble } */
+/* { dg-require-effective-target arm_arm_ok } */
+/* { dg-skip-if "do not override -mfloat-abi" { *-*-* } { "-mfloat-abi=*" } {"-mfloat-abi=soft" } } */
+/* { dg-options "-O2 -marm -mfloat-abi=soft" } */
+
+/* Check that we don't try to emit STRD in ARM state with
+   odd starting register.  */
+
+struct S {
+  double M0;
+} __attribute((aligned)) __attribute((packed));
+
+void bar(void *);
+
+void foo(int x, struct S y) {
+  asm("" : : : "r1", "r8", "r7", "r4");
+  y.M0 ?: bar(0);
+  bar(__builtin_alloca(8));
+}
Index: gcc/testsuite/gcc.target/s390/dfp_to_bfp_rounding.c
===================================================================
--- gcc/testsuite/gcc.target/s390/dfp_to_bfp_rounding.c	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/gcc.target/s390/dfp_to_bfp_rounding.c	(.../branches/gcc-8-branch)
@@ -0,0 +1,29 @@
+/* { dg-do run } */
+/* { dg-options "-O3 -mzarch -march=z10" } */
+
+/* According to IEEE 754 2008 4.3 Conversion operations between
+   different radixes must use the rounding mode of the target radix.
+   On S/390 this means passing the right value in GPR0 to PFPO
+   instruction.  */
+
+#include <fenv.h>
+
+double __attribute__((noclone,noinline))
+convert (_Decimal64 in)
+{
+  return (double)in;
+}
+
+int
+main ()
+{
+  fesetround (FE_UPWARD);
+
+  if (convert (1e-325DD) != __DBL_DENORM_MIN__)
+    __builtin_abort ();
+
+  fesetround (FE_DOWNWARD);
+
+  if (convert (-1e-325DD) != -__DBL_DENORM_MIN__)
+    __builtin_abort ();
+}
Index: gcc/testsuite/gcc.target/m68k/mulsi_highpart.c
===================================================================
--- gcc/testsuite/gcc.target/m68k/mulsi_highpart.c	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/gcc.target/m68k/mulsi_highpart.c	(.../branches/gcc-8-branch)
@@ -0,0 +1,8 @@
+/* { dg-do compile } */
+/* { dg-options "-O2 -m68020" } */
+/* Don't optimize away a compare after [us]mulsi_highpart.  */
+/* { dg-final { scan-assembler {tst\.?l} } } */
+int cmp (unsigned int a, unsigned int b)
+{
+  return (a > 0xffffffff / b);
+}
Index: gcc/testsuite/gcc.target/msp430/pr86662.c
===================================================================
--- gcc/testsuite/gcc.target/msp430/pr86662.c	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/gcc.target/msp430/pr86662.c	(.../branches/gcc-8-branch)
@@ -0,0 +1,13 @@
+/* PR/86662 */
+
+/* { dg-do link } */
+/* -nostdlib prevents link errors due to mismatched code models for
+   libgloss objects.  */
+/* { dg-options "-mlarge -flto -nostdlib" } */
+/* { dg-skip-if "" { *-*-* } { "-mcpu=msp430" } } */
+
+int main(void)
+{
+  __int20 n = 5;
+  return 0;
+}
Index: gcc/testsuite/gcc.target/i386/pr82699-6.c
===================================================================
--- gcc/testsuite/gcc.target/i386/pr82699-6.c	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/gcc.target/i386/pr82699-6.c	(.../branches/gcc-8-branch)
@@ -0,0 +1,11 @@
+/* { dg-do compile { target *-*-linux* } } */
+/* { dg-options "-fno-pic -O2 -fcf-protection -pg -mfentry -mrecord-mcount -mnop-mcount -fasynchronous-unwind-tables" } */
+/* { dg-final { scan-assembler-times {\t\.cfi_startproc\n\tendbr} 1 } } */
+
+extern int bar (int);
+
+int
+foo (int i)
+{
+  return bar (i);
+}
Index: gcc/testsuite/gcc.target/i386/pr87198.c
===================================================================
--- gcc/testsuite/gcc.target/i386/pr87198.c	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/gcc.target/i386/pr87198.c	(.../branches/gcc-8-branch)
@@ -0,0 +1,13 @@
+/* PR target/87198 */
+/* { dg-do compile } */
+/* { dg-options "-O2 -mxsavec -mno-xsave" } */
+
+#include <x86intrin.h>
+
+void
+test_xsavec (void *__A, long long __B)
+{
+  _xsavec (__A, __B);
+}
+
+/* { dg-error "target specific option mismatch" "" { target *-*-* } 0 } */
Index: gcc/testsuite/gcc.target/i386/pr82699-1.c
===================================================================
--- gcc/testsuite/gcc.target/i386/pr82699-1.c	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/gcc.target/i386/pr82699-1.c	(.../branches/gcc-8-branch)
@@ -0,0 +1,11 @@
+/* { dg-do compile { target *-*-linux* } } */
+/* { dg-options "-O2 -fno-pic -fcf-protection -pg -fasynchronous-unwind-tables" } */
+/* { dg-final { scan-assembler-times {\t\.cfi_startproc\n\tendbr} 1 } } */
+
+extern int bar (int);
+
+int
+foo (int i)
+{
+  return bar (i);
+}
Index: gcc/testsuite/gcc.target/i386/pr82699-2.c
===================================================================
--- gcc/testsuite/gcc.target/i386/pr82699-2.c	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/gcc.target/i386/pr82699-2.c	(.../branches/gcc-8-branch)
@@ -0,0 +1,11 @@
+/* { dg-do compile { target *-*-linux* } } */
+/* { dg-options "-O2 -fno-pic -fcf-protection -pg -mfentry -fasynchronous-unwind-tables" } */
+/* { dg-final { scan-assembler-times {\t\.cfi_startproc\n\tendbr} 1 } } */
+
+extern int bar (int);
+
+int
+foo (int i)
+{
+  return bar (i);
+}
Index: gcc/testsuite/gcc.target/i386/pr82699-3.c
===================================================================
--- gcc/testsuite/gcc.target/i386/pr82699-3.c	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/gcc.target/i386/pr82699-3.c	(.../branches/gcc-8-branch)
@@ -0,0 +1,11 @@
+/* { dg-do compile { target *-*-linux* } } */
+/* { dg-options "-O2 -fpic -fcf-protection -pg -fasynchronous-unwind-tables" } */
+/* { dg-final { scan-assembler-times {\t\.cfi_startproc\n\tendbr} 1 } } */
+
+extern int bar (int);
+
+int
+foo (int i)
+{
+  return bar (i);
+}
Index: gcc/testsuite/gcc.target/i386/avx512f-abspd-1.c
===================================================================
--- gcc/testsuite/gcc.target/i386/avx512f-abspd-1.c	(.../tags/gcc_8_2_0_release)
+++ gcc/testsuite/gcc.target/i386/avx512f-abspd-1.c	(.../branches/gcc-8-branch)
@@ -6,11 +6,11 @@
 
 #include "avx512f-helper.h"
 
-#define SIZE (AVX512F_LEN / 32)
+#define SIZE (AVX512F_LEN / 64)
 #include "avx512f-mask-type.h"
 
 static void
-CALC (float *i1, float *r)
+CALC (double *i1, double *r)
 {
   int i;
 
@@ -24,14 +24,14 @@
 void
 TEST (void)
 {
-  float ck[SIZE];
+  double ck[SIZE];
   int i;
-  UNION_TYPE (AVX512F_LEN, ) s, d, dm;
+  UNION_TYPE (AVX512F_LEN, d) s, d, dm;
   MASK_TYPE mask = MASK_VALUE;
 
   for (i = 0; i < SIZE; i++)
     {
-      s.a[i] = i * ((i & 1) ? 3.5f : -7.5f);
+      s.a[i] = i * ((i & 1) ? 3.5 : -7.5);
       d.a[i] = DEFAULT_VALUE;
       dm.a[i] = DEFAULT_VALUE;
     }
@@ -38,13 +38,13 @@
 
   CALC (s.a, ck);
 
-  d.x = INTRINSIC (_abs_ps) (s.x);
-  dm.x = INTRINSIC (_mask_abs_ps) (dm.x, mask, s.x);
+  d.x = INTRINSIC (_abs_pd) (s.x);
+  dm.x = INTRINSIC (_mask_abs_pd) (dm.x, mask, s.x);
 
-  if (UNION_CHECK (AVX512F_LEN, ) (d, ck))
+  if (UNION_CHECK (AVX512F_LEN, d) (d, ck))
     abort ();
 
-  MASK_MERGE () (ck, mask, SIZE);
-  if (UNION_CHECK (AVX512F_LEN, ) (dm, ck))
+  MASK_MERGE (d) (ck, mask, SIZE);
+  if (UNION_CHECK (AVX512F_LEN, d) (dm, ck))
     abort ();
 }
Index: gcc/testsuite/gcc.target/i386/avx512bw-pr87138.c
===================================================================
--- gcc/testsuite/gcc.target/i386/avx512bw-pr87138.c	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/gcc.target/i386/avx512bw-pr87138.c	(.../branches/gcc-8-branch)
@@ -0,0 +1,29 @@
+/* PR middle-end/87138 */
+/* { dg-do run { target int128 } } */
+/* { dg-options "-O -fno-tree-fre -mavx512bw -mtune=k8" } */
+/* { dg-require-effective-target avx512bw } */
+
+#include "avx512bw-check.h"
+
+typedef int U __attribute__ ((vector_size (64)));
+typedef __int128 V __attribute__ ((vector_size (64)));
+V g, i;
+
+static inline void
+foo (unsigned h, V j, U k, V n)
+{
+  k /= h;
+  __builtin_memmove (&h, &n, 1);
+  n[j[1]] *= 0x7FFFFFFFFFFFFFFF;
+  j[k[5]] = 0;
+  g = n;
+  i = h + j + n;
+}
+
+void
+avx512bw_test ()
+{
+  foo (~0, (V) { }, (U) { 5 }, (V) { 3 });
+  if (g[0] != (__int128) 3 * 0x7FFFFFFFFFFFFFFF)
+    abort ();
+}
Index: gcc/testsuite/gcc.target/i386/pr82699-4.c
===================================================================
--- gcc/testsuite/gcc.target/i386/pr82699-4.c	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/gcc.target/i386/pr82699-4.c	(.../branches/gcc-8-branch)
@@ -0,0 +1,11 @@
+/* { dg-do compile { target { *-*-linux* && { ! ia32 } } } } */
+/* { dg-options "-O2 -fpic -fcf-protection -pg -mfentry -fasynchronous-unwind-tables" } */
+/* { dg-final { scan-assembler-times {\t\.cfi_startproc\n\tendbr} 1 } } */
+
+extern int bar (int);
+
+int
+foo (int i)
+{
+  return bar (i);
+}
Index: gcc/testsuite/gcc.target/i386/pr86386.c
===================================================================
--- gcc/testsuite/gcc.target/i386/pr86386.c	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/gcc.target/i386/pr86386.c	(.../branches/gcc-8-branch)
@@ -0,0 +1,26 @@
+/* PR target/86386 */
+/* { dg-do run { target { avx_runtime && int128 } } } */
+/* { dg-options "-Os -fno-tree-dce -mstringop-strategy=vector_loop -mavx" } */
+
+unsigned c, d, e, f;
+
+unsigned __attribute__((noipa))
+foo (unsigned char g, unsigned short h, unsigned i, unsigned long long j,
+     unsigned char k, unsigned short l, unsigned m, unsigned __int128 n)
+{
+  __builtin_memset (&e, 0, 3);
+  n <<= m;
+  __builtin_memcpy (&m, 2 + (char *) &n, 1);
+  m >>= 0;
+  d ^= __builtin_mul_overflow (l, n, &m);
+  return m;
+}
+
+int
+main ()
+{
+  unsigned __int128 x = foo (0, 0, 0, 0, 0, 4, 1, 3);
+  if (x != 24)
+    __builtin_abort ();
+  return 0;
+}
Index: gcc/testsuite/gcc.target/i386/pr87065.c
===================================================================
--- gcc/testsuite/gcc.target/i386/pr87065.c	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/gcc.target/i386/pr87065.c	(.../branches/gcc-8-branch)
@@ -0,0 +1,22 @@
+/* PR rtl-optimization/87065 */
+/* { dg-do compile } */
+/* { dg-options "-O3 -mxop -mprefer-vector-width=128" } */
+
+int a, c, d, e;
+short *b;
+
+void
+foo (void)
+{
+  short *g = b;
+  int h = 1;
+  unsigned i;
+  for (; h <= 1; h++)
+    g = (short *) &c;
+  for (; c; c++)
+    {
+      for (; i <= 1; i++)
+	;
+      a ^= (a > 0 <= i) + ((e += d) == 0 ?: (*g = 8));
+    }
+}
Index: gcc/testsuite/gcc.target/i386/pr87370.c
===================================================================
--- gcc/testsuite/gcc.target/i386/pr87370.c	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/gcc.target/i386/pr87370.c	(.../branches/gcc-8-branch)
@@ -0,0 +1,39 @@
+/* { dg-do compile { target { ! ia32 } } } */
+/* { dg-options "-O2" } */
+
+struct A
+{
+  int b[4];
+};
+struct B
+{
+  char a[12];
+  int b;
+};
+struct C
+{
+  char a[16];
+};
+
+struct A
+f1 (void)
+{
+  struct A x = {};
+  return x;
+}
+
+struct B
+f2 (void)
+{
+  struct B x = {};
+  return x;
+}
+
+struct C
+f3 (void)
+{
+  struct C x = {};
+  return x;
+}
+
+/* { dg-final { scan-assembler-not "xmm" } } */
Index: gcc/testsuite/gcc.target/i386/pr86627.c
===================================================================
--- gcc/testsuite/gcc.target/i386/pr86627.c	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/gcc.target/i386/pr86627.c	(.../branches/gcc-8-branch)
@@ -0,0 +1,28 @@
+/* PR middle-end/86627 */
+/* { dg-do compile { target int128 } } */
+/* { dg-options "-O2" } */
+/* { dg-final { scan-assembler-not "call\[^\n\r]*__divti3" } } */
+
+__int128_t
+f1 (__int128_t a)
+{
+  return a / 2;
+}
+
+__int128_t
+f2 (__int128_t a)
+{
+  return a / -2;
+}
+
+__int128_t
+f3 (__int128_t a)
+{
+  return a / 0x4000000000000000LL;
+}
+
+__int128_t
+f4 (__int128_t a)
+{
+  return a / -0x4000000000000000LL;
+}
Index: gcc/testsuite/gcc.target/i386/pr82699-5.c
===================================================================
--- gcc/testsuite/gcc.target/i386/pr82699-5.c	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/gcc.target/i386/pr82699-5.c	(.../branches/gcc-8-branch)
@@ -0,0 +1,12 @@
+/* { dg-do compile { target *-*-linux* } } */
+/* { dg-options "-O2 -fcf-protection -mfentry -fasynchronous-unwind-tables" } */
+/* { dg-additional-options "-fno-pic" { target ia32 } } */
+/* { dg-final { scan-assembler-times {\t\.cfi_startproc\n\tendbr} 1 } } */
+
+extern int bar (int);
+
+int
+foo (int i)
+{
+  return bar (i);
+}
Index: gcc/testsuite/gfortran.dg/pr86328.f90
===================================================================
--- gcc/testsuite/gfortran.dg/pr86328.f90	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/gfortran.dg/pr86328.f90	(.../branches/gcc-8-branch)
@@ -0,0 +1,49 @@
+! { dg-do run }
+!
+! Test the fix for PR86328 in which temporaries were not being
+! assigned for array component references.
+!
+! Contributed by Martin  <mscfd@gmx.net>
+!
+program ptr_alloc
+
+   type :: t
+      class(*), allocatable :: val
+   end type
+
+   type :: list
+      type(t), dimension(:), pointer :: ll
+   end type
+
+   integer :: i
+   type(list) :: a
+
+   allocate(a%ll(1:2))
+   do i = 1,2
+      allocate(a%ll(i)%val, source=i)
+   end do
+
+   do i = 1,2
+     call rrr(a, i)
+   end do
+
+   do i = 1,2
+      deallocate(a%ll(i)%val)
+   end do
+   deallocate (a%ll)
+contains
+
+   subroutine rrr(a, i)
+      type(list), intent(in) :: a
+      class(*), allocatable :: c
+      integer :: i
+
+      allocate(c, source=a%ll(i)%val)
+      select type (c)
+        type is (integer)
+          if (c .ne. i) stop 1
+      end select
+
+   end subroutine
+
+end
Index: gcc/testsuite/gfortran.dg/matmul_19.f90
===================================================================
--- gcc/testsuite/gfortran.dg/matmul_19.f90	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/gfortran.dg/matmul_19.f90	(.../branches/gcc-8-branch)
@@ -0,0 +1,25 @@
+! { dg-do  run }
+! { dg-options "-finline-matmul-limit=0" }
+! PR 86704 - this used to segfault.
+
+program testmaticovenasobeni
+implicit none
+  
+  character(len=10) :: line
+  write (unit=line,fmt=*) testmatmul(120,1,3)
+
+  contains
+
+   function testmatmul(m,n,o)
+     integer, intent(in) :: m,n,o
+     real    :: A(n,m),B(n,o),C(m,o)
+     logical :: testmatmul
+    
+     call random_number(A)
+     call random_number(B)
+     
+     C=matmul(transpose(A),B) 
+     testmatmul=.true.
+   end function 
+
+end program testmaticovenasobeni
Index: gcc/testsuite/gfortran.dg/allocate_with_mold_2.f90
===================================================================
--- gcc/testsuite/gfortran.dg/allocate_with_mold_2.f90	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/gfortran.dg/allocate_with_mold_2.f90	(.../branches/gcc-8-branch)
@@ -0,0 +1,62 @@
+! { dg-do compile }
+! { dg-options "-fdump-tree-original" }
+!
+! Test the fix for PR87284 in which the indexing in allocate with mold
+! was incorrect for class array initialization and resulted in the valgrind
+! error:
+! "Conditional jump or move depends on uninitialised value(s)" at line 42.
+!
+! Contributed by Andrew Baldwin on clf.
+!
+      MODULE INTS_TYPE_MODULE
+        TYPE, ABSTRACT :: BASE_TYPE
+        END TYPE BASE_TYPE
+
+        TYPE, EXTENDS (BASE_TYPE) :: INTS_TYPE
+          INTEGER, ALLOCATABLE :: INTS(:)
+        END TYPE INTS_TYPE
+      CONTAINS
+        SUBROUTINE MOLD_ALLOCATE (IT_OBJS, MOLD_OBJ)
+          CLASS (BASE_TYPE), ALLOCATABLE, INTENT (OUT) :: IT_OBJS(:)
+          CLASS (BASE_TYPE), INTENT (IN) :: MOLD_OBJ
+
+          ALLOCATE (IT_OBJS(2), mold = MOLD_OBJ)
+
+          RETURN
+        END SUBROUTINE MOLD_ALLOCATE
+      END MODULE INTS_TYPE_MODULE
+
+      PROGRAM MFE
+        USE INTS_TYPE_MODULE
+        IMPLICIT NONE
+
+        CLASS (BASE_TYPE), ALLOCATABLE :: IT_OBJS(:)
+        INTEGER :: I
+        TYPE (INTS_TYPE) :: MOLD_OBJ
+
+        ALLOCATE (INTS_TYPE :: IT_OBJS(2))
+
+        SELECT TYPE (IT_OBJS)
+        TYPE IS (INTS_TYPE)
+          ALLOCATE (IT_OBJS(1)%INTS(10))
+
+          ALLOCATE (IT_OBJS(2)%INTS(10))
+        END SELECT
+
+
+        DEALLOCATE (IT_OBJS)
+
+        CALL MOLD_ALLOCATE (IT_OBJS, MOLD_OBJ)
+
+        IF (ALLOCATED(IT_OBJS)) THEN
+          IF (SIZE(IT_OBJS) .GE. 2) THEN
+            SELECT TYPE (IT_OBJS)
+            TYPE IS (INTS_TYPE)
+              ALLOCATE (IT_OBJS(1)%INTS(10))
+
+              ALLOCATE (IT_OBJS(2)%INTS(10))
+            END SELECT
+          END IF
+        END IF
+      END PROGRAM MFE
+! { dg-final { scan-tree-dump-times "it_objs->_vptr->_size" 1 "original" } }
Index: gcc/testsuite/gfortran.dg/array_constructor_type_23.f90
===================================================================
--- gcc/testsuite/gfortran.dg/array_constructor_type_23.f90	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/gfortran.dg/array_constructor_type_23.f90	(.../branches/gcc-8-branch)
@@ -0,0 +1,7 @@
+! { dg-do compile }
+! PR 83999 - this used to ICE
+! Origial test case by Gerhard Steinmetz
+
+program p
+        character(2) :: c = 'a' // [character :: [1]] ! { dg-error "Illegal type in character concatenation" }
+end
Index: gcc/testsuite/gfortran.dg/select_type_43.f90
===================================================================
--- gcc/testsuite/gfortran.dg/select_type_43.f90	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/gfortran.dg/select_type_43.f90	(.../branches/gcc-8-branch)
@@ -0,0 +1,48 @@
+! { dg-do run }
+!
+! Tests the fix for PRxxxxx - runtime segfault as indicated.
+!
+! Contributed by Andrew Baldwin on clf.
+!
+      MODULE INTS_TYPE_MODULE
+        TYPE INTS_TYPE
+          INTEGER, ALLOCATABLE :: INTS(:)
+        END TYPE INTS_TYPE
+      CONTAINS
+        SUBROUTINE ALLOCATE_INTS_TYPE (IT_OBJ)
+          CLASS (INTS_TYPE), POINTER, INTENT (OUT) :: IT_OBJ
+
+          ALLOCATE (INTS_TYPE :: IT_OBJ)
+
+          SELECT TYPE (IT_OBJ)
+          TYPE IS (INTS_TYPE)
+            CALL ALLOCATE_ARRAY (IT_OBJ%INTS) ! Sefaulted at runtime here.
+            if (.not.allocated (IT_OBJ%INTS)) stop 1
+            if (any (IT_OBJ%INTS .ne. [1,2,3,4])) stop 2
+          END SELECT
+
+          RETURN
+        END SUBROUTINE ALLOCATE_INTS_TYPE
+
+        SUBROUTINE ALLOCATE_ARRAY (ALLOC_ARR)
+          INTEGER, ALLOCATABLE, INTENT (OUT) :: ALLOC_ARR(:)
+          INTEGER :: I
+
+          ALLOCATE (ALLOC_ARR(4))
+
+          DO I = 1, SIZE(ALLOC_ARR)
+            ALLOC_ARR(I) = I
+          END DO
+
+          RETURN
+        END SUBROUTINE ALLOCATE_ARRAY
+      END MODULE INTS_TYPE_MODULE
+
+      PROGRAM MFE
+        USE INTS_TYPE_MODULE
+        IMPLICIT NONE
+
+        CLASS (INTS_TYPE), POINTER :: IT_OBJ
+
+        CALL ALLOCATE_INTS_TYPE (IT_OBJ)
+      END PROGRAM MFE
Index: gcc/testsuite/gfortran.dg/proc_ptr_comp_52.f90
===================================================================
--- gcc/testsuite/gfortran.dg/proc_ptr_comp_52.f90	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/gfortran.dg/proc_ptr_comp_52.f90	(.../branches/gcc-8-branch)
@@ -0,0 +1,33 @@
+! { dg-do compile }
+!
+! PR 85395: [F03] private clause contained in derived type acquires spurious scope
+!
+! Contributed by <cfd@mnet-mail.de>
+
+module defs
+   implicit none
+
+   type :: base
+   contains
+      private
+   end type
+
+   type :: options
+      procedure(), pointer, nopass :: ptr
+   end type
+
+   type :: t
+      private
+      procedure(), pointer, nopass, public :: ptr
+   end type
+end module
+
+
+program p
+   use defs
+   implicit none
+   type(options) :: self
+   type(t) :: dt
+   self%ptr => null()
+   dt%ptr => null()
+end
Index: gcc/testsuite/gfortran.dg/vect/pr86421.f90
===================================================================
--- gcc/testsuite/gfortran.dg/vect/pr86421.f90	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/gfortran.dg/vect/pr86421.f90	(.../branches/gcc-8-branch)
@@ -0,0 +1,35 @@
+! PR fortran/86421
+! { dg-require-effective-target vect_simd_clones }
+! { dg-additional-options "-fopenmp-simd" }
+! { dg-additional-options "-mavx" { target avx_runtime } }
+
+module mod86421
+  implicit none
+contains
+  subroutine foo(x, y, z)
+    real :: x
+    integer :: y, z
+    !$omp declare simd linear(ref(x)) linear(val(y)) linear(uval(z))
+    x = x + y
+    z = z + 1
+  end subroutine
+end module mod86421
+
+program pr86421
+  use mod86421
+  implicit none
+  integer :: i, j
+  real :: a(64)
+  j = 0
+  do i = 1, 64
+    a(i) = i
+  end do
+  !$omp simd
+  do i = 1, 64
+    call foo (a(i), i, j)
+  end do
+  do i = 1, 64
+    if (a(i) .ne. (2 * i)) stop 1
+  end do
+  if (j .ne. 64) stop 2
+end program pr86421
Index: gcc/testsuite/gfortran.dg/generic_34.f90
===================================================================
--- gcc/testsuite/gfortran.dg/generic_34.f90	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/gfortran.dg/generic_34.f90	(.../branches/gcc-8-branch)
@@ -0,0 +1,27 @@
+! { dg-do compile }
+!
+! PR 86116: [6/7/8/9 Regression] Ambiguous generic interface not recognised
+!
+! Contributed by martin <mscfd@gmx.net>
+
+module mod
+
+   type :: t
+   end type t
+
+   interface sub
+      module procedure s1
+      module procedure s2
+   end interface
+
+contains
+
+   subroutine s1(x)  ! { dg-error "Ambiguous interfaces in generic interface" }
+      type(t) :: x
+   end subroutine
+
+   subroutine s2(x)  ! { dg-error "Ambiguous interfaces in generic interface" }
+      class(*), allocatable :: x
+   end subroutine
+
+end
Index: gcc/testsuite/gfortran.dg/deferred_character_21.f90
===================================================================
--- gcc/testsuite/gfortran.dg/deferred_character_21.f90	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/gfortran.dg/deferred_character_21.f90	(.../branches/gcc-8-branch)
@@ -0,0 +1,29 @@
+! { dg-do compile }
+! { dg-options "-O3" }
+!
+! Tests the fix for PR85954 in which the gimplifier could not determine
+! the space required for the dummy argument data types, when inlining the
+! subroutines.
+!
+! Contributed by G.Steinmetz  <gscfq@t-online.de>
+!
+program p
+   character(kind=1,len=:), allocatable :: z(:)
+   allocate (z, source = ["xyz"])
+   print *, allocated(z), size(z), len(z), z
+   call s(z)
+   call t(z)
+contains
+   subroutine s(x)
+      character(kind=1,len=:), allocatable :: x(:)
+      x = ['abcd']
+      print *, allocated(x), size(x), len(x), x
+   end
+   subroutine t(x)
+      character(kind=1,len=:), allocatable :: x(:)
+      associate (y => x)
+         y = ['abc']
+      end associate
+      print *, allocated(x), size(x), len(x), x
+   end
+end
Index: gcc/testsuite/gfortran.dg/elemental_function_4.f90
===================================================================
--- gcc/testsuite/gfortran.dg/elemental_function_4.f90	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/gfortran.dg/elemental_function_4.f90	(.../branches/gcc-8-branch)
@@ -0,0 +1,18 @@
+! { dg-do compile }
+!
+! Tests the fix for PR83999, where the invalid function 'f' caused an ICE.
+!
+! Contributed by Gerhard Steinmetz  <gscfq@t-online.de>
+!
+program p
+   type t
+      integer :: a
+   end type
+   type(t) :: x(3)
+   x = f()
+   print *, x
+contains
+   elemental function f() result(z) ! { dg-error "must have a scalar result" }
+      type(t), pointer :: z(:)
+   end
+end
Index: gcc/testsuite/gfortran.dg/implied_do_io_6.f90
===================================================================
--- gcc/testsuite/gfortran.dg/implied_do_io_6.f90	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/gfortran.dg/implied_do_io_6.f90	(.../branches/gcc-8-branch)
@@ -0,0 +1,39 @@
+! { dg-do  run }
+! { dg-options "-ffrontend-optimize" }
+! PR 86837 - this was mis-optimized by trying to turn this into an
+! array I/O statement.
+! Original test case by "Pascal".
+
+Program read_loop
+
+  implicit none
+
+  integer :: i, j
+
+  ! number of values per column
+  integer, dimension(3) :: nvalues
+  data nvalues / 1, 2, 4 /
+
+  ! values in a 1D array
+  real, dimension(7) :: one_d
+  data one_d / 1,   11, 12,   21, 22, 23, 24 /
+
+  ! where to store the data back
+  real, dimension(4, 3) :: two_d
+
+  ! 1 - write our 7 values in one block
+  open(unit=10, file="loop.dta", form="unformatted")
+  write(10) one_d
+  close(unit=10)
+
+  ! 2 - read them back in chosen cells of a 2D array
+  two_d = -9
+  open(unit=10, file="loop.dta", form="unformatted", status='old')
+  read(10) ((two_d(i,j), i=1,nvalues(j)), j=1,3)
+  close(unit=10, status='delete')
+
+  ! 4 - print the whole array, just in case
+
+  if (any(reshape(two_d,[12]) /= [1.,-9.,-9.,-9.,11.,12.,-9.,-9.,21.,22.,23.,24.])) call abort
+
+end Program read_loop
Index: gcc/testsuite/gfortran.dg/pr86760.f90
===================================================================
--- gcc/testsuite/gfortran.dg/pr86760.f90	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/gfortran.dg/pr86760.f90	(.../branches/gcc-8-branch)
@@ -0,0 +1,57 @@
+! { dg-do run }
+!
+! Test the fix for PR86760 in which temporaries were not being
+! assigned for array component references.
+!
+! Contributed by Chris Hansen  <hansec@uw.edu>
+!
+MODULE test_nesting_mod
+  IMPLICIT NONE
+  TYPE :: test_obj1
+  CONTAINS
+    PROCEDURE :: destroy
+  END TYPE
+
+  TYPE :: obj_ptr
+    CLASS(test_obj1), POINTER :: f => NULL()
+  END TYPE
+
+  TYPE :: obj_container
+    TYPE(obj_ptr), POINTER, DIMENSION(:) :: v => NULL()
+  END TYPE
+
+  integer :: ctr = 0
+
+CONTAINS
+
+  SUBROUTINE destroy(self)
+    CLASS(test_obj1), INTENT(INOUT):: self
+    ctr = ctr + 1
+  END SUBROUTINE
+
+  SUBROUTINE container_destroy(self)
+    type(obj_container), INTENT(INOUT) :: self
+    INTEGER :: i
+    DO i=1,ubound(self%v,1)
+      CALL self%v(i)%f%destroy()
+    END DO
+  END SUBROUTINE
+
+END MODULE
+
+
+PROGRAM test_nesting_ptr
+  USE test_nesting_mod
+  IMPLICIT NONE
+  INTEGER :: i
+  INTEGER, PARAMETER :: n = 2
+  TYPE(obj_container) :: var
+
+  ALLOCATE(var%v(n))
+  DO i=1,n
+    ALLOCATE(test_obj1::var%v(i)%f)
+  END DO
+  CALL container_destroy(var)
+
+  if (ctr .ne. 2) stop 1
+END
Index: gcc/testsuite/gfortran.dg/modulo_check.f90
===================================================================
--- gcc/testsuite/gfortran.dg/modulo_check.f90	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/gfortran.dg/modulo_check.f90	(.../branches/gcc-8-branch)
@@ -0,0 +1,8 @@
+! { dg-do compile }
+! Test checks on modulo with p == 0
+program p
+   logical :: a(2) = (modulo([2,3],0) == 0)     ! { dg-error "shall not be zero" }
+   integer :: b = count(modulo([2,3],0) == 0)   ! { dg-error "shall not be zero" }
+   integer :: c = all(modulo([2,3],0) == 0)     ! { dg-error "shall not be zero" }
+   integer :: d = any(modulo([2,3],0) == 0)     ! { dg-error "shall not be zero" }
+end program
Index: gcc/testsuite/gfortran.dg/typebound_call_30.f90
===================================================================
--- gcc/testsuite/gfortran.dg/typebound_call_30.f90	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/gfortran.dg/typebound_call_30.f90	(.../branches/gcc-8-branch)
@@ -0,0 +1,32 @@
+! { dg-do compile }
+!
+! PR 86830: [8/9 Regression] Contiguous array pointer function result not recognized as contiguous
+!
+! Contributed by <only_for_nouse@gmx.de>
+
+module m
+  implicit none
+
+  type :: t1
+   contains
+     procedure :: get_ptr
+  end type
+
+  type :: t2
+     class(t1), allocatable :: c
+  end type
+
+contains
+
+  function get_ptr(this)
+    class(t1) :: this
+    real, dimension(:), contiguous, pointer :: get_ptr
+  end function
+
+  subroutine test()
+    real, dimension(:), contiguous, pointer:: ptr
+    type(t2) :: x
+    ptr => x%c%get_ptr()
+  end subroutine
+
+end module
Index: gcc/testsuite/gfortran.dg/associate_41.f90
===================================================================
--- gcc/testsuite/gfortran.dg/associate_41.f90	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/gfortran.dg/associate_41.f90	(.../branches/gcc-8-branch)
@@ -0,0 +1,25 @@
+! { dg-do run }
+!
+! Test the fix for PR86372 in which the associate name string length was
+! not being set, thereby causing a segfault.
+!
+! Contributed by Janus Weil  <janus@gcc.gnu.org>
+!
+program xxx
+
+   character(len=50) :: s
+
+   s = repeat ('*', len(s))
+   call sub(s)
+   if (s .ne. '**'//'123'//repeat ('*', len(s) - 5)) stop 1
+
+contains
+
+   subroutine sub(str)
+      character(len=*), intent(inout) :: str
+      associate (substr => str(3:5))
+         substr = '123'
+      end associate
+   end subroutine
+
+end
Index: gcc/testsuite/gfortran.dg/use_rename_9.f90
===================================================================
--- gcc/testsuite/gfortran.dg/use_rename_9.f90	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/gfortran.dg/use_rename_9.f90	(.../branches/gcc-8-branch)
@@ -0,0 +1,19 @@
+! { dg-do compile }
+!
+! Test the fix for PR86906, in which a spurious error was generated
+! by 'config' in the subroutine having the same symbol name as the
+! renamed 'foo_config'.
+!
+! Contributed by Damian Rouson  <damian@sourceryinstitute.org>
+!
+module foo
+  type config
+  end type
+end module
+  use foo, only: foo_config => config
+contains
+  subroutine cap
+    integer config
+    type(foo_config) extra
+  end subroutine
+end
Index: gcc/testsuite/gcc.c-torture/compile/pr85704.c
===================================================================
--- gcc/testsuite/gcc.c-torture/compile/pr85704.c	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/gcc.c-torture/compile/pr85704.c	(.../branches/gcc-8-branch)
@@ -0,0 +1,10 @@
+/* PR c/85704 */
+
+struct C { struct {} c; };
+struct D { int d; struct C e; int f; };
+
+void
+foo (struct D *x)
+{
+  *x = (struct D) { .e = (struct C) { .c = {} } };
+}
Index: gcc/testsuite/gcc.dg/pr87074.c
===================================================================
--- gcc/testsuite/gcc.dg/pr87074.c	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/gcc.dg/pr87074.c	(.../branches/gcc-8-branch)
@@ -0,0 +1,25 @@
+/* { dg-do run } */
+/* { dg-options "-O3 -floop-unroll-and-jam --param unroll-jam-min-percent=0" } */
+long b;
+unsigned c[5];
+unsigned long long d = 3;
+int e, f, g;
+
+void h() {
+  for (; f < 11; f++) {
+    b = g;
+    for (e = 0; e < 5; e++) {
+      c[e] = e - b - (c[e] >> 5);
+      g = c[e];
+    }
+  }
+  if (c[0])
+    d = 0;
+}
+
+extern void abort(void);
+int main() {
+  h();
+  if (d != 0)
+    abort ();
+}
Index: gcc/testsuite/gcc.dg/pr87024.c
===================================================================
--- gcc/testsuite/gcc.dg/pr87024.c	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/gcc.dg/pr87024.c	(.../branches/gcc-8-branch)
@@ -0,0 +1,14 @@
+/* { dg-do compile } */
+/* { dg-options "-O -fno-tree-dce" } */
+
+static inline void __attribute__((always_inline))
+mp ()
+{
+  (void) __builtin_va_arg_pack_len ();
+}
+
+void
+ui (void)
+{
+  mp ();
+}
Index: gcc/testsuite/gcc.dg/strlenopt-57.c
===================================================================
--- gcc/testsuite/gcc.dg/strlenopt-57.c	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/gcc.dg/strlenopt-57.c	(.../branches/gcc-8-branch)
@@ -0,0 +1,49 @@
+/* PR tree-optimization/86914 - wrong code with strlen() of poor-man's
+   flexible array member plus offset
+   { dg-do compile }
+   { dg-options "-O2 -Wall -fdump-tree-optimized" } */
+
+#include "strlenopt.h"
+
+struct A0 { char i, a[0]; };
+struct A1 { char i, a[1]; };
+struct A9 { char i, a[9]; };
+struct Ax { char i, a[]; };
+
+extern int a[];
+
+extern struct A0 a0;
+extern struct A1 a1;
+extern struct A9 a9;
+extern struct Ax ax;
+
+void test_var_flexarray_cst_off (void)
+{
+  /* Use arbitrary constants greater than 16 in case GCC ever starts
+     unrolling strlen() calls with small array arguments.  */
+  a[0] = 17 < strlen (a0.a + 1);
+  a[1] = 19 < strlen (a1.a + 1);
+  a[2] = 23 < strlen (a9.a + 9);
+  a[3] = 29 < strlen (ax.a + 3);
+}
+
+void test_ptr_flexarray_cst_off (struct A0 *p0, struct A1 *p1,
+				 struct A9 *p9, struct Ax *px)
+{
+  a[0] = 17 < strlen (p0->a + 1);
+  a[1] = 19 < strlen (p1->a + 1);
+  a[2] = 23 < strlen (p9->a + 9);
+  a[3] = 29 < strlen (px->a + 3);
+}
+
+void test_ptr_flexarray_var_off (struct A0 *p0, struct A1 *p1,
+				 struct A9 *p9, struct Ax *px,
+				 int i)
+{
+  a[0] = 17 < strlen (p0->a + i);
+  a[1] = 19 < strlen (p1->a + i);
+  a[2] = 23 < strlen (p9->a + i);
+  a[3] = 29 < strlen (px->a + i);
+}
+
+/* { dg-final { scan-tree-dump-times "strlen" 12 "optimized" } } */
Index: gcc/testsuite/gcc.dg/torture/pr86945.c
===================================================================
--- gcc/testsuite/gcc.dg/torture/pr86945.c	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/gcc.dg/torture/pr86945.c	(.../branches/gcc-8-branch)
@@ -0,0 +1,18 @@
+/* { dg-do run } */
+
+void __attribute__((noinline,noipa))
+foo(int id)
+{
+  switch (id)
+    {
+    case (-__INT_MAX__ - 1)...-1:
+      __builtin_abort ();
+    default:;
+    }
+}
+
+int main()
+{
+  foo(1);
+  return 0;
+}
Index: gcc/testsuite/gcc.dg/torture/pr86505.c
===================================================================
--- gcc/testsuite/gcc.dg/torture/pr86505.c	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/gcc.dg/torture/pr86505.c	(.../branches/gcc-8-branch)
@@ -0,0 +1,32 @@
+/* { dg-do run } */
+
+static inline __attribute__(( __always_inline__)) int 
+funA(unsigned int param, ...) 
+{ 
+  return __builtin_va_arg_pack_len(); 
+}
+
+static inline __attribute__(( __always_inline__)) int
+funB(unsigned int param, ...)
+{ 
+  return funA(param,  2, 4, __builtin_va_arg_pack()); 
+}
+
+int 
+testBuiltin(void) 
+{ 
+  int rc = funB(0,1,2); 
+  if (rc != 4)
+    return 1;
+  return 0;
+}
+
+int
+main()
+{
+  int rc = testBuiltin();
+  if (rc == 1)
+    __builtin_abort ();
+
+  return 0;
+}
Index: gcc/testsuite/gcc.dg/vect/pr86927.c
===================================================================
--- gcc/testsuite/gcc.dg/vect/pr86927.c	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/gcc.dg/vect/pr86927.c	(.../branches/gcc-8-branch)
@@ -0,0 +1,15 @@
+#include "tree-vect.h"
+
+int a[28];
+int main()
+{
+  check_vect ();
+  a[4] = 1;
+  int c = 1;
+  for (int b = 0; b < 8; b++)
+    if (a[b])
+      c = 0;
+  if (c)
+    abort();
+  return 0;
+}
Index: gcc/testsuite/gcc.dg/vect/no-section-anchors-vect-69.c
===================================================================
--- gcc/testsuite/gcc.dg/vect/no-section-anchors-vect-69.c	(.../tags/gcc_8_2_0_release)
+++ gcc/testsuite/gcc.dg/vect/no-section-anchors-vect-69.c	(.../branches/gcc-8-branch)
@@ -119,5 +119,6 @@
   return main1 ();
 } 
 
-/* { dg-final { scan-tree-dump-times "vectorized 4 loops" 1 "vect" } } */
-/* { dg-final { scan-tree-dump-times "Alignment of access forced using versioning" 1 "vect" { target { {! vector_alignment_reachable} && {! vect_hw_misalign} } } } } */
+/* { dg-final { scan-tree-dump-times "vectorized 4 loops" 1 "vect" { target vect_hw_misalign } } } */
+/* { dg-final { scan-tree-dump-times "vectorized 3 loops" 1 "vect" { target { ! vect_hw_misalign } } } } */
+/* { dg-final { scan-tree-dump-times "Alignment of access forced using versioning" 1 "vect" { target { { ! vector_alignment_reachable } && { ! vect_hw_misalign } } } } } */
Index: gcc/testsuite/gcc.dg/vect/pr86871.c
===================================================================
--- gcc/testsuite/gcc.dg/vect/pr86871.c	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/gcc.dg/vect/pr86871.c	(.../branches/gcc-8-branch)
@@ -0,0 +1,15 @@
+/* { dg-do compile } */
+
+extern int b[];
+extern int c[];
+void g(int f) {
+  for (; f; f++) {
+    int d = 0;
+    for (int e = -1; e <= 1; e++) {
+      int a = f + e;
+      if (a)
+        d = *(c + a);
+    }
+    *(b + f) = d;
+  }
+ }
Index: gcc/testsuite/gcc.dg/pr86617.c
===================================================================
--- gcc/testsuite/gcc.dg/pr86617.c	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/gcc.dg/pr86617.c	(.../branches/gcc-8-branch)
@@ -0,0 +1,11 @@
+/* { dg-options "-Os -fdump-rtl-final" } */
+
+volatile unsigned char u8;
+
+void test (void)
+{
+  u8 = u8 + u8;
+  u8 = u8 - u8;
+}
+
+/* { dg-final { scan-rtl-dump-times "mem/v" 6 "final" } } */
Index: gcc/testsuite/gcc.dg/nested-func-11.c
===================================================================
--- gcc/testsuite/gcc.dg/nested-func-11.c	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/gcc.dg/nested-func-11.c	(.../branches/gcc-8-branch)
@@ -0,0 +1,34 @@
+/* { dg-do run } */
+/* { dg-options "-O2 -fno-omit-frame-pointer" } */
+
+int __attribute__((noipa)) foo (int i)
+{
+  int a;
+
+  void __attribute__((noipa)) nested2 (int i)
+  {
+    a = i;
+  }
+
+  void  __attribute__((noipa)) nested1 (int i)
+  {
+    int b[32];
+
+    for (int j = 0; j < 32; j++)
+      b[j] = i + j;
+
+    nested2 (b[i]);
+  }
+
+  nested1 (i);
+
+  return a;
+}
+
+int main (void)
+{
+  if (foo (4) != 8)
+    __builtin_abort ();
+
+  return 0;
+}
Index: gcc/testsuite/gcc.dg/pr87099.c
===================================================================
--- gcc/testsuite/gcc.dg/pr87099.c	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/gcc.dg/pr87099.c	(.../branches/gcc-8-branch)
@@ -0,0 +1,21 @@
+/* PR middle-end/87099 */
+/* { dg-do compile } */
+/* { dg-options "-Wstringop-overflow" } */
+
+void bar (char *);
+
+int
+foo (int n)
+{
+  char v[n];
+  bar (v);
+  return __builtin_strncmp (&v[1], "aaa", 3);
+}
+
+int
+baz (int n, char *s)
+{
+  char v[n];
+  bar (v);
+  return __builtin_strncmp (&v[1], s, 3);
+}
Index: gcc/testsuite/gcc.dg/pr86835.c
===================================================================
--- gcc/testsuite/gcc.dg/pr86835.c	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/gcc.dg/pr86835.c	(.../branches/gcc-8-branch)
@@ -0,0 +1,29 @@
+/* PR tree-optimization/86835 */
+/* { dg-do run } */
+/* { dg-options "-O2 -ffast-math -Wuninitialized" } */
+
+__attribute__((noipa)) void
+foo (int n, double *x, double *y)
+{		/* { dg-bogus "is used uninitialized in this function" "" { target *-*-* } 0 } */
+  int i;
+  double b = y[4];
+  for (i = 0; i < n; ++i)
+    y[3] += __builtin_sin (x[i] / b);
+  y[0] /= b;
+  y[1] /= b * b;
+  y[2] /= b;
+}
+
+int
+main ()
+{
+  double y[] = { 16.0, 64.0, 128.0, 0.0, 2.0 };
+  foo (0, y, y);
+  if (__builtin_fabs (y[0] - 8.0) > 0.0001
+      || __builtin_fabs (y[1] - 16.0) > 0.0001
+      || __builtin_fabs (y[2] - 64.0) > 0.0001
+      || y[3] != 0.0
+      || y[4] != 2.0)
+    __builtin_abort ();
+  return 0;
+}
Index: gcc/testsuite/gcc.dg/pr85859.c
===================================================================
--- gcc/testsuite/gcc.dg/pr85859.c	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/gcc.dg/pr85859.c	(.../branches/gcc-8-branch)
@@ -0,0 +1,19 @@
+/* { dg-do run } */
+/* { dg-options "-ftree-tail-merge -Wno-div-by-zero -O2 -fno-dce -fno-isolate-erroneous-paths-dereference -fno-tree-dce -fno-tree-vrp" } */
+
+int b, c, d, e;
+
+__attribute__ ((noinline, noclone))
+int foo (short f)
+{
+  f %= 0;
+  return f;
+}
+
+int
+main (void)
+{
+  b = (unsigned char) __builtin_parity (d);
+  e ? foo (0) : (long) &c;
+  return 0;
+}
Index: gcc/testsuite/ChangeLog
===================================================================
--- gcc/testsuite/ChangeLog	(.../tags/gcc_8_2_0_release)
+++ gcc/testsuite/ChangeLog	(.../branches/gcc-8-branch)
@@ -1,3 +1,404 @@
+2018-10-09  H.J. Lu  <hongjiu.lu@intel.com>
+
+	Backport from mainline
+	2018-09-29  H.J. Lu  <hongjiu.lu@intel.com>
+
+	PR target/87370
+	* gcc.target/i386/pr87370.c: New test.
+
+2018-10-08  Paul Thomas  <pault@gcc.gnu.org>
+
+	PR fortran/83999
+	Backport from trunk
+	* gfortran.dg/elemental_function_4.f90 : New test.
+
+2018-10-08  Paul Thomas  <pault@gcc.gnu.org>
+
+	Backport from trunk
+	PR fortran/86372
+	* gfortran.dg/associate_41.f90: New test.
+
+2018-10-06  Thomas Koenig  <tkoenig@gcc.gnu.org>
+
+	PR fortran/86111
+	Backport from trunk
+	* gfortran.dg/array_constructor_type_23.f90: New test.
+
+2018-10-03  Martin Liska  <mliska@suse.cz>
+
+	Backport from mainline
+	2018-10-03  Martin Liska  <mliska@suse.cz>
+
+	PR gcov-profile/86109
+	* g++.dg/gcov/pr86109.C: New test.
+
+2018-10-02  H.J. Lu  <hongjiu.lu@intel.com>
+
+	Backport from mainline
+	2018-09-25  H.J. Lu  <hongjiu.lu@intel.com>
+
+	PR target/82699
+	* gcc.target/i386/pr82699-5.c: Add -fno-pic for ia32.
+	* gcc.target/i386/pr82699-6.c: Add -fno-pic.
+
+	2018-09-24  H.J. Lu  <hongjiu.lu@intel.com>
+
+	PR target/82699
+	* gcc.target/i386/pr82699-1.c: New file.
+	* gcc.target/i386/pr82699-2.c: Likewise.
+	* gcc.target/i386/pr82699-3.c: Likewise.
+	* gcc.target/i386/pr82699-4.c: Likewise.
+	* gcc.target/i386/pr82699-5.c: Likewise.
+	* gcc.target/i386/pr82699-6.c: Likewise.
+
+2018-10-01  Kyrylo Tkachov  <kyrylo.tkachov@arm.com>
+
+	Backport from mainline
+	2018-07-02  Christophe Lyon  <christophe.lyon@linaro.org>
+
+	* gcc.target/arm/arm-soft-strd-even.c: Skip if -mfloat-abi is
+	overriden.
+	2018-06-29  Kyrylo Tkachov  <kyrylo.tkachov@arm.com>
+
+	* gcc.target/arm/arm-soft-strd-even.c: New test.
+
+2018-09-29  Jakub Jelinek  <jakub@redhat.com>
+
+	PR target/87467
+	* gcc.target/i386/avx512f-abspd-1.c (SIZE): Divide by two.
+	(CALC): Use double instead of float.
+	(TEST): Adjust to test _mm512_abs_pd and _mm512_mask_abs_pd rather than
+	_mm512_abs_ps and _mm512_mask_abs_ps.
+
+2018-09-27  Michael Meissner  <meissner@linux.ibm.com>
+
+	Backport from mainline
+	2018-08-20  Michael Meissner  <meissner@linux.ibm.com>
+
+	PR target/87033
+	* gcc.target/powerpc/pr87033.c: New test.
+
+2018-09-25  Martin Liska  <mliska@suse.cz>
+
+	Backport from mainline
+	2018-09-24  Martin Liska  <mliska@suse.cz>
+
+	PR sanitizer/85774
+	* g++.dg/asan/pr85774.C: New test.
+
+2018-09-24  Paolo Carlini  <paolo.carlini@oracle.com>
+
+	PR c++/85070
+	* g++.dg/cpp0x/pr85070.C: New.
+
+2018-09-21  Eric Botcazou  <ebotcazou@adacore.com>
+
+	* gcc.dg/nested-func-11.c: New test.
+
+2018-09-18  Janus Weil  <janus@gcc.gnu.org>
+
+	Backport from trunk
+	PR fortran/85395
+	* gfortran.dg/proc_ptr_comp_52.f90: New test case.
+
+2018-09-18  Janus Weil  <janus@gcc.gnu.org>
+
+	Backport from trunk
+	PR fortran/86830
+	* gfortran.dg/typebound_call_30.f90: New test case.
+
+2018-09-18  Paul Thomas  <pault@gcc.gnu.org>
+
+	Backported from trunk
+	PR fortran/85954
+	* gfortran.dg/deferred_character_21.f90 : New test.
+
+2018-09-18  Nathan Sidwell  <nathan@acm.org>
+
+	PR c++/86881
+	* g++.dg/warn/pr86881.C: New.
+
+2018-09-12  Paul Thomas  <pault@gcc.gnu.org>
+
+	Backported from trunk
+	PR fortran/87284
+	* gfortran.dg/allocate_with_mold_2.f90: New test.
+
+2018-09-12  Andreas Krebbel  <krebbel@linux.ibm.com>
+
+	Backport from mainline
+	2018-09-12  Andreas Krebbel  <krebbel@linux.ibm.com>
+
+	* gcc.target/s390/dfp_to_bfp_rounding.c: New test.
+
+2018-09-12  Jakub Jelinek  <jakub@redhat.com>
+
+	PR middle-end/87248
+	* c-c++-common/torture/pr87248.c: New test.
+
+2018-09-11  Paul Thomas  <pault@gcc.gnu.org>
+
+	Backported from trunk
+	PR fortran/87277
+	* gfortran.dg/select_type_43.f90: New test.
+
+2018-09-05  Janus Weil  <janus@gcc.gnu.org>
+
+	Backported from trunk
+	PR fortran/86116
+	* gfortran.dg/generic_34.f90: New test case.
+
+2018-09-05   Pádraig Brady  <p@draigbrady.com>
+
+	PR c++/87185
+	* g++.dg/pr87185.C: New.
+
+2018-09-05  Nathan Sidwell  <nathan@acm.org>
+
+	PR c++/87137
+	* g++.dg/abi/pr87137.C: New.
+
+2018-09-05  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from mainline
+	2018-09-04  Jakub Jelinek  <jakub@redhat.com>
+
+	PR target/87198
+	* gcc.target/i386/pr87198.c: New test.
+
+	2018-08-31  Jakub Jelinek  <jakub@redhat.com>
+
+	PR middle-end/87138
+	* gcc.target/i386/avx512bw-pr87138.c: New test.
+
+	2018-08-29  Jakub Jelinek  <jakub@redhat.com>
+
+	PR c++/87095
+	* g++.dg/ubsan/vptr-13.C: New test.
+
+	2018-08-11  Jakub Jelinek  <jakub@redhat.com>
+
+	PR tree-optimization/86835
+	* gcc.dg/pr86835.c: New test.
+
+	2018-08-08  Jakub Jelinek  <jakub@redhat.com>
+
+	PR c++/86836
+	* g++.dg/cpp1z/decomp46.C: New test.
+
+	PR c++/86738
+	* g++.dg/opt/pr86738.C: New test.
+
+	2018-08-03  Jason Merrill  <jason@redhat.com>
+
+	PR c++/86706
+	* g++.dg/template/pr86706.C: New test.
+
+2018-09-04  Jerry DeLisle  <jvdelisle@gcc.gnu.org>
+
+	Backport from mainline
+	* gfortran.dg/modulo_check: New test.
+
+2018-09-03  Tom de Vries  <tdevries@suse.de>
+
+	backport from trunk:
+	2018-06-21  Tom de Vries  <tdevries@suse.de>
+
+	PR tree-optimization/85859
+	* gcc.dg/pr85859.c: New test.
+
+2018-09-01  Michael Matz  <matz@suse.de>
+
+	Backport from mainline
+	PR tree-optimization/87074
+	* gcc.dg/pr87074.c: New test.
+
+2018-09-01  Paul Thomas  <pault@gcc.gnu.org>
+
+	PR fortran/86328
+	PR fortran/86760
+	* gfortran.dg/pr86328.f90 : New test.
+	* gfortran.dg/pr86760.f90 : New test.
+
+2018-08-31  Nathan Sidwell  <nathan@acm.org>
+
+	PR c++/87155
+	PR c++/84707
+	* g++.dg/cpp0x/pr87155.C: New.
+	* g++.dg/cpp0x/inline-ns10.C: Adjust.
+
+2018-08-31  Richard Biener  <rguenther@suse.de>
+
+	Backport from mainline
+	2018-08-27  Richard Biener  <rguenther@suse.de>
+
+	PR tree-optimization/86927
+	* gcc.dg/vect/pr86927.c: New testcase.
+
+	2018-08-23  Richard Biener  <rguenther@suse.de>
+
+	PR middle-end/87024
+	* gcc.dg/pr87024.c: New testcase.
+
+	2018-08-22  Richard Biener  <rguenther@suse.de>
+
+	PR tree-optimization/86945
+	* gcc.dg/torture/pr86945.c: New testcase.
+
+	2018-08-17  Richard Biener  <rguenther@suse.de>
+
+	PR middle-end/86505
+	* gcc.dg/torture/pr86505.c: New testcase.
+
+	2018-08-02  Richard Biener  <rguenther@suse.de>
+
+	PR tree-optimization/86816
+	* g++.dg/torture/pr86816.C: New testcase.
+
+	2018-07-17  Richard Biener  <rguenther@suse.de>
+
+	PR lto/86456
+	* g++.dg/debug/dwarf2/pr86456.C: New testcase.
+
+2018-08-29  Jakub Jelinek  <jakub@redhat.com>
+
+	PR c++/87122
+	* g++.dg/cpp1z/decomp47.C: New test.
+
+2018-08-27  Martin Sebor  <msebor@redhat.com>
+
+	PR tree-optimization/86914
+	* gcc.dg/strlenopt-57.c: New test.
+
+2018-08-28  Jakub Jelinek  <jakub@redhat.com>
+
+	PR middle-end/87099
+	* gcc.dg/pr87099.c: New test.
+
+2018-08-27  Jakub Jelinek  <jakub@redhat.com>
+
+	PR rtl-optimization/87065
+	* gcc.target/i386/pr87065.c: New test.
+
+2018-08-26  Thomas Koenig  <tkoenig@gcc.gnu.org>
+
+	Backport from trunk
+	PR libfortran/86704
+	* gfortran.dg/matmul_19.f90: New test.
+
+2018-08-24  Thomas Koenig  <tkoenig@gcc.gnu.org>
+
+	Backport from trunk
+	PR fortran/86837
+	* gfortran.dg/implied_do_io_6.f90: New test.
+
+2018-08-21  H.J. Lu  <hongjiu.lu@intel.com>
+
+	Backport from mainline
+	2018-08-20  H.J. Lu  <hongjiu.lu@intel.com>
+
+	PR target/87014
+	* g++.dg/torture/pr87014.C: New file.
+
+2018-08-21  Szabolcs Nagy  <szabolcs.nagy@arm.com>
+
+	Backport from mainline
+	2018-08-21  Szabolcs Nagy  <szabolcs.nagy@arm.com>
+
+	* g++.dg/torture/pr86763.C: Restrict to *-*-linux*.
+
+2018-08-17  Richard Biener  <rguenther@suse.de>
+
+	Backport from mainline
+	2018-08-02  Richard Biener  <rguenther@suse.de>
+
+	PR c++/86763
+	* g++.dg/torture/pr86763.C: New testcase.
+
+2018-08-16  Tamar Christina  <tamar.christina@arm.com>
+
+	Backport from mainline
+	2018-07-31  Segher Boessenkool  <segher@kernel.crashing.org>
+
+	PR target/86640
+	* gcc.target/arm/pr86640.c: New testcase.
+
+2018-08-14  Richard Sandiford  <richard.sandiford@arm.com>
+
+	Backport from mainline
+	2018-08-09  Richard Sandiford  <richard.sandiford@arm.com>
+
+	PR tree-optimization/86871
+	* gcc.dg/vect/pr86871.c: New test.
+
+2018-08-12  Paul Thomas  <pault@gcc.gnu.org>
+
+	Backported from trunk
+	PR fortran/86906
+	* gfortran.dg/use_rename_9.f90: New test.
+
+2018-08-07  H.J. Lu  <hongjiu.lu@intel.com>
+
+	Backport from mainline
+	2018-08-05  H.J. Lu  <hongjiu.lu@intel.com>
+
+	PR target/86386
+	* gcc.target/i386/pr86386.c: New file.
+
+2018-08-07  Steve Ellcey  <sellcey@cavium.com>
+	    Rainer Orth  <ro@CeBiTec.Uni-Bielefeld.DE>
+
+	PR tree-optimization/80925
+	* gcc.dg/vect/no-section-anchors-vect-69.c: Expect 3 loops
+	vectorized on !vect_hw_misalign targets.
+
+2018-08-04  Uros Bizjak  <ubizjak@gmail.com>
+
+	PR testsuite/86153
+	* g++.dg/pr83239.C (dg-options): Add -finline-limit=500.
+
+2018-08-02  Andreas Schwab  <schwab@linux-m68k.org>
+
+	Backport from mainline
+	2018-07-17  Andreas Schwab  <schwab@linux-m68k.org>
+
+	PR target/86820
+	* gcc.target/m68k/mulsi_highpart.c: New test.
+
+2018-08-01  Jakub Jelinek  <jakub@redhat.com>
+
+	PR c/85704
+	* gcc.c-torture/compile/pr85704.c: New test.
+
+2018-07-29  Bernd Edlinger  <bernd.edlinger@hotmail.de>
+
+	Backport from mainline
+	2018-07-23  Bernd Edlinger  <bernd.edlinger@hotmail.de>
+
+	PR c/86617
+	* gcc.dg/pr86617.c: New test.
+
+2018-07-26  Pat Haugen  <pthaugen@us.ibm.com>
+
+	Backport from mainline
+	2018-07-26  Pat Haugen  <pthaugen@us.ibm.com>
+
+	PR target/86612
+	* gcc.target/powerpc/pr58673-2.c: Call strdup.
+
+2018-07-26  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from mainline
+	2018-07-24  Jakub Jelinek  <jakub@redhat.com>
+
+	PR middle-end/86627
+	* gcc.target/i386/pr86627.c: New test.
+
+	2018-07-10  Jakub Jelinek  <jakub@redhat.com>
+
+	PR fortran/86421
+	* gfortran.dg/vect/pr86421.f90: New test.
+
 2018-07-26  Release Manager
 
 	* GCC 8.2.0 released.
@@ -8,10 +409,10 @@
 	2018-07-16  Carl Love  <cel@us.ibm.com>
 
 	PR target/86414
- 	* gcc.target/powerpc/divkc3-2.c: Add dg-require-effective-target
+	* gcc.target/powerpc/divkc3-2.c: Add dg-require-effective-target
 	longdouble128.
 	* gcc.target/powerpc/divkc3-3.c: Ditto.
- 	* gcc.target/powerpc/mulkc3-2.c: Ditto.
+	* gcc.target/powerpc/mulkc3-2.c: Ditto.
 	* gcc.target/powerpc/mulkc3-3.c: Ditto.
 	* gcc.target/powerpc/fold-vec-mergehl-double.c: Update counts.
 	* gcc.target/powerpc/pr85456.c: Make check Linux and AIX specific.
@@ -743,7 +1144,7 @@
 	Backport from mainline
 	2018-05-11  Martin Liska  <mliska@suse.cz>
 
-        PR sanitizer/85556
+	PR sanitizer/85556
 	* c-c++-common/ubsan/attrib-6.c: New test.
 
 2018-05-22  Martin Sebor  <msebor@redhat.com>
@@ -1443,11 +1844,11 @@
 
 2018-04-13  Andreas Krebbel  <krebbel@linux.ibm.com>
 
-        PR testsuite/85326
-        * gcc.target/s390/pr77822-1.C: Rename to ...
-        * gcc.target/s390/pr77822-1.c: ... this. Add asm scan check.
-        * gcc.target/s390/pr77822-2.c: Add asm scan check.
-        * gcc.target/s390/s390.exp: Remove C from testcase regexps.
+	PR testsuite/85326
+	* gcc.target/s390/pr77822-1.C: Rename to ...
+	* gcc.target/s390/pr77822-1.c: ... this. Add asm scan check.
+	* gcc.target/s390/pr77822-2.c: Add asm scan check.
+	* gcc.target/s390/s390.exp: Remove C from testcase regexps.
 
 2018-04-13  Jan Hubicka  <hubicka@ucw.cz>
 
@@ -2780,7 +3181,7 @@
 	* g++.dg/cpp2a/desig7.C: New test.
 
 2018-03-16  Mark Doffman  <mark.doffman@codethink.co.uk>
-            Jim MacArthur  <jim.macarthur@codethink.co.uk>
+	    Jim MacArthur  <jim.macarthur@codethink.co.uk>
 
 	* gfortran.dg/automatic_1.f90: New test.
 	* gfortran.dg/automatic_repeat.f90: New test
@@ -4015,9 +4416,9 @@
 
 2018-02-20  Jeff Law  <law@redhat.com>
 
-        PR middle-end/82123
-        PR tree-optimization/81592
-        PR middle-end/79257
+	PR middle-end/82123
+	PR tree-optimization/81592
+	PR middle-end/79257
 	* gcc.dg/pr81592.c: New test.
 	* gcc.dg/pr82123.c: New test.
 	* gcc.dg/builtin-unreachable-6.c: Turn off VRP.
@@ -6741,7 +7142,7 @@
 
 2018-02-14  Carl Love  <cel@us.ibm.com>
 
-        * gcc.target/powerpc/builtins-4-int128-runnable.c
+	* gcc.target/powerpc/builtins-4-int128-runnable.c
 	(dg-require-effective-target): Change vsx_hw to p8vector_hw.
 	(dg-options): Change -maltivec -mvsx to -mpower8-vector.
 
Index: gcc/testsuite/g++.dg/pr83239.C
===================================================================
--- gcc/testsuite/g++.dg/pr83239.C	(.../tags/gcc_8_2_0_release)
+++ gcc/testsuite/g++.dg/pr83239.C	(.../branches/gcc-8-branch)
@@ -1,7 +1,7 @@
 // PR tree-optimization/83239 - False positive from -Wstringop-overflow
 // on simple std::vector code
 // { dg-do compile }
-// { dg-options "-O3 -Wall -fdump-tree-optimized"  }
+// { dg-options "-O3 -finline-limit=500 -Wall -fdump-tree-optimized"  }
 
 #include <vector>
 
Index: gcc/testsuite/g++.dg/ubsan/vptr-13.C
===================================================================
--- gcc/testsuite/g++.dg/ubsan/vptr-13.C	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/g++.dg/ubsan/vptr-13.C	(.../branches/gcc-8-branch)
@@ -0,0 +1,19 @@
+// PR c++/87095
+// { dg-do run }
+// { dg-options "-fsanitize=vptr -fno-sanitize-recover=vptr" }
+
+struct A
+{
+  virtual ~A () {}
+};
+
+struct B : virtual A {};
+
+struct C : B {};
+
+int
+main ()
+{
+  C c;
+  return 0;
+}
Index: gcc/testsuite/g++.dg/warn/pr86881.C
===================================================================
--- gcc/testsuite/g++.dg/warn/pr86881.C	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/g++.dg/warn/pr86881.C	(.../branches/gcc-8-branch)
@@ -0,0 +1,20 @@
+// PR c++/86881 ICE with shadow warning
+// { dg-do compile { target c++11 } }
+// { dg-additional-options { -Wshadow-compatible-local } }}
+
+void a() {
+  auto b([] {});
+  {
+    auto b = 0;
+  }
+}
+
+struct Proxy { };
+
+void Two ()
+{
+  auto my = Proxy ();
+  {
+    auto my = Proxy (); // { dg-warning "shadows" "" { xfail *-*-* } }
+  };
+}
Index: gcc/testsuite/g++.dg/warn/Wsign-conversion-3.C
===================================================================
--- gcc/testsuite/g++.dg/warn/Wsign-conversion-3.C	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/g++.dg/warn/Wsign-conversion-3.C	(.../branches/gcc-8-branch)
@@ -0,0 +1,13 @@
+// PR c++/86190
+// { dg-options "-Wsign-conversion -Wsign-compare" }
+
+typedef unsigned long sz_t;
+sz_t s();
+bool f(int i) { return s() < (unsigned long) i; }
+bool f2(int i) { return s() < static_cast<unsigned long>(i); }
+bool f3(int i) { return s() < i; } // { dg-warning "comparison of integer expressions of different signedness" }
+bool f4(int i) { return s() < (long) i; } // { dg-warning "comparison of integer expressions of different signedness" }
+bool f5(short int i) { return s() < (int) i; } // { dg-warning "comparison of integer expressions of different signedness" }
+bool f6(signed char i) { return s() < (int) i; } // { dg-warning "comparison of integer expressions of different signedness" }
+bool f7(unsigned char i) { return s() < i; }
+bool f8(signed char i) { return s() < i; } // { dg-warning "comparison of integer expressions of different signedness" }
Index: gcc/testsuite/g++.dg/warn/Wsign-conversion-4.C
===================================================================
--- gcc/testsuite/g++.dg/warn/Wsign-conversion-4.C	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/g++.dg/warn/Wsign-conversion-4.C	(.../branches/gcc-8-branch)
@@ -0,0 +1,14 @@
+// PR c++/86190
+// { dg-options "-Wsign-conversion -Wsign-compare" }
+
+typedef unsigned long size_t;
+
+struct vector {
+  typedef size_t size_type;
+  size_type size();
+};
+
+bool func(vector vec, int var)
+{
+  return vec.size() < static_cast<size_t>(var); // { dg-bogus "may change" }
+}
Index: gcc/testsuite/g++.dg/asan/pr85774.C
===================================================================
--- gcc/testsuite/g++.dg/asan/pr85774.C	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/g++.dg/asan/pr85774.C	(.../branches/gcc-8-branch)
@@ -0,0 +1,51 @@
+/* PR sanitizer/85774 */
+/* { dg-do run } */
+
+#include <functional>
+
+void
+DoSomething ()
+{
+}
+
+void
+DoFunc (const std::function<void(void)> &func)
+{
+  func ();
+}
+
+void
+Setup ()
+{
+  switch (1)
+    {
+    case 1:
+      {
+	DoFunc ([]() {});
+	break;
+      }
+    case 2:
+      {
+	DoFunc ([]() {});
+	break;
+      }
+    default:
+      break;
+    }
+
+  DoSomething ();
+}
+
+void
+DemostrateBadPoisoning ()
+{
+  DoFunc ([]() {});
+}
+
+int
+main ()
+{
+  Setup ();
+  DemostrateBadPoisoning ();
+  return 0;
+}
Index: gcc/testsuite/g++.dg/gcov/pr86109.C
===================================================================
--- gcc/testsuite/g++.dg/gcov/pr86109.C	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/g++.dg/gcov/pr86109.C	(.../branches/gcc-8-branch)
@@ -0,0 +1,16 @@
+
+/* { dg-options "-fprofile-arcs -ftest-coverage -std=c++11" } */
+/* { dg-do run { target native } } */
+
+int main()
+{
+    auto partially_uncovered_lambda = [](int i) { /* count(1) */
+        if (i > 10) /* count(1) */
+            return 0; /* count(1) */
+        return 1; /* count(#####) */
+    };
+
+    return partially_uncovered_lambda(20); /* count(1) */
+}
+
+/* { dg-final { run-gcov pr86109.C } } */
Index: gcc/testsuite/g++.dg/pr87185.C
===================================================================
--- gcc/testsuite/g++.dg/pr87185.C	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/g++.dg/pr87185.C	(.../branches/gcc-8-branch)
@@ -0,0 +1,4 @@
+// PR c++/87185
+// { dg-do compile { target c++11 } }
+
+void f() { const int i=0; [&]() noexcept {i;}; }
Index: gcc/testsuite/g++.dg/debug/dwarf2/pr86456.C
===================================================================
--- gcc/testsuite/g++.dg/debug/dwarf2/pr86456.C	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/g++.dg/debug/dwarf2/pr86456.C	(.../branches/gcc-8-branch)
@@ -0,0 +1,5 @@
+// { dg-do compile }
+// { dg-require-effective-target lto }
+// { dg-options "-g -gdwarf-5 -flto -ffat-lto-objects" }
+
+int a;
Index: gcc/testsuite/g++.dg/opt/pr86738.C
===================================================================
--- gcc/testsuite/g++.dg/opt/pr86738.C	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/g++.dg/opt/pr86738.C	(.../branches/gcc-8-branch)
@@ -0,0 +1,12 @@
+// PR c++/86738
+// { dg-do compile }
+
+struct S { int s; };
+unsigned char a[20];
+unsigned char *p = &a[(__UINTPTR_TYPE__) &((S *) 0)->s];
+
+void
+foo ()
+{
+  __builtin_memcpy (&a[15], &a[(__UINTPTR_TYPE__) &((S *) 0)->s], 2);
+}
Index: gcc/testsuite/g++.dg/cpp0x/pr87155.C
===================================================================
--- gcc/testsuite/g++.dg/cpp0x/pr87155.C	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/g++.dg/cpp0x/pr87155.C	(.../branches/gcc-8-branch)
@@ -0,0 +1,14 @@
+// { dg-do compile { target c++11 } }
+// PR c++/87155 confused about which anon namespace
+
+namespace {
+  void a (); // this one
+}
+
+inline namespace n2 {
+	 namespace {}
+} 
+
+namespace {
+  int a ();  // { dg-error "ambiguating" "" }
+}
Index: gcc/testsuite/g++.dg/cpp0x/pr85070.C
===================================================================
--- gcc/testsuite/g++.dg/cpp0x/pr85070.C	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/g++.dg/cpp0x/pr85070.C	(.../branches/gcc-8-branch)
@@ -0,0 +1,13 @@
+// { dg-do compile { target c++11 } }
+
+struct A;
+
+struct B
+{
+  constexpr A & operator= (const A &);  // { dg-warning "used" "" { target c++14_only } }
+};
+
+struct A : B  // { dg-error "cannot be overloaded" "" { target c++14_only } }
+{
+  using B::operator=;
+} a { a = a };
Index: gcc/testsuite/g++.dg/cpp0x/inline-ns10.C
===================================================================
--- gcc/testsuite/g++.dg/cpp0x/inline-ns10.C	(.../tags/gcc_8_2_0_release)
+++ gcc/testsuite/g++.dg/cpp0x/inline-ns10.C	(.../branches/gcc-8-branch)
@@ -2,7 +2,10 @@
 // { dg-do compile { target c++11 } }
 
 inline namespace {
-  namespace {}
+	 namespace {} // not this one
+	 void a ();
 }
 
-namespace {} // { dg-error "conflicts" }
+namespace {
+  int a (); // { dg-error "ambiguating" "" }
+}
Index: gcc/testsuite/g++.dg/torture/pr86763.C
===================================================================
--- gcc/testsuite/g++.dg/torture/pr86763.C	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/g++.dg/torture/pr86763.C	(.../branches/gcc-8-branch)
@@ -0,0 +1,37 @@
+// { dg-do run { target { *-*-linux* } } }
+// { dg-additional-options "-fschedule-insns2 -fstrict-aliasing" }
+// { dg-additional-options "-lrt" }
+
+#include <cstdint>
+#include <cassert>
+#include <time.h>
+struct ID {
+  uint64_t value;
+};
+uint64_t value(ID id) { return id.value; }
+uint64_t gen { 1000 };
+struct Msg {
+  uint64_t time;
+  ID id;
+};
+struct V {
+  V() { }
+  V(Msg const & msg) : msg(msg) { }
+  Msg & get() { return msg; }
+  Msg msg;
+  char pad[237 - sizeof(Msg)];
+};
+struct T : V { using V::V; };
+Msg init_msg() {
+  Msg msg;
+  timespec t;
+  clock_gettime(CLOCK_REALTIME, &t);
+  msg.time = t.tv_sec + t.tv_nsec;
+  msg.id.value = ++gen;
+  return msg;
+}
+int main() {
+  T t;
+  t = init_msg();
+  assert(value(t.get().id) == 1001);
+}
Index: gcc/testsuite/g++.dg/torture/pr86816.C
===================================================================
--- gcc/testsuite/g++.dg/torture/pr86816.C	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/g++.dg/torture/pr86816.C	(.../branches/gcc-8-branch)
@@ -0,0 +1,42 @@
+// { dg-do compile }
+
+class Signal
+{
+public:
+    int  m_Mode;
+};
+
+class Ctx
+{
+public:
+    bool  m_Invert;
+
+    void DoSomething();
+};
+
+class Test
+{
+  void TestIce( Ctx& ctx, Signal* sig);
+};
+
+void Test::TestIce( Ctx& ctx, Signal* sig)
+{
+  int invert = false;
+
+  if( ! ctx.m_Invert)
+    invert = ! invert;
+
+  switch( sig->m_Mode)
+    {
+    case 1:
+    invert = ! invert;
+    break;
+
+    case 2:
+    invert = true;
+    break;
+    }
+
+  if( invert)
+    ctx.DoSomething();
+}
Index: gcc/testsuite/g++.dg/torture/pr87014.C
===================================================================
--- gcc/testsuite/g++.dg/torture/pr87014.C	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/g++.dg/torture/pr87014.C	(.../branches/gcc-8-branch)
@@ -0,0 +1,37 @@
+// { dg-do run }
+
+void
+fillstack ()
+{
+  long long foo[] =
+    {
+      -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
+    };
+}
+
+void
+f (long long=-1,long long=-1,long long=-1,long long=-1,
+   long long=-1,long long=-1,long long arg7_on_stack=-1)
+{
+  throw 0;
+}
+
+void
+g()
+{
+  try
+    {
+      f ();
+    }
+  catch (int)
+    {
+    }
+}
+
+int
+main()
+{
+  fillstack ();
+  g ();
+  return 0;
+}
Index: gcc/testsuite/g++.dg/cpp1y/lambda-generic-variadic19.C
===================================================================
--- gcc/testsuite/g++.dg/cpp1y/lambda-generic-variadic19.C	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/g++.dg/cpp1y/lambda-generic-variadic19.C	(.../branches/gcc-8-branch)
@@ -0,0 +1,4 @@
+// PR c++/86728
+// { dg-do compile { target c++14 } }
+
+auto c = [](auto x ...) { };
Index: gcc/testsuite/g++.dg/cpp1y/constexpr-86767.C
===================================================================
--- gcc/testsuite/g++.dg/cpp1y/constexpr-86767.C	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/g++.dg/cpp1y/constexpr-86767.C	(.../branches/gcc-8-branch)
@@ -0,0 +1,119 @@
+// PR c++/86767
+// { dg-do compile { target c++14 } }
+
+constexpr int
+fn0 () noexcept
+{
+  int r = 0;
+  for (int i = 0; i < 10; ++i)
+    {
+      continue;
+      r++;
+      for (int j = 0; j < 10; ++j )
+	{
+	}
+    }
+  return r;
+}
+static_assert (fn0 () == 0, "");
+
+constexpr int
+fn1 () noexcept
+{
+  int r = 0;
+  for (int i = 0; i < 10; ++i)
+    for (int j = 0; j < 10; ++j)
+      {
+	continue;
+	r++;
+      }
+  return r;
+}
+static_assert (fn1 () == 0, "");
+
+constexpr int
+fn2 () noexcept
+{
+  int r = 0;
+  for (int i = 0; i < 10; ++i)
+    {
+      continue;
+      r++;
+    }
+  return r;
+}
+static_assert (fn2 () == 0, "");
+
+constexpr int
+fn3 () noexcept
+{
+  int r = 0;
+  for (int i = 0; i < 10; ++i)
+    {
+      continue;
+      r++;
+      while (1)
+	{
+	}
+    }
+  return r;
+}
+static_assert (fn3 () == 0, "");
+
+constexpr int
+fn4 () noexcept
+{
+  for (int i = 0; i < 10; ++i)
+    {
+      switch (i)
+	{
+	case 5:
+	  return i;
+	default:
+	  continue;
+	}
+      while (1)
+	{
+	}
+    }
+  return 0;
+}
+static_assert (fn4 () == 5, "");
+
+constexpr int
+fn5 () noexcept
+{
+  for (int i = 0; i < 10; ++i)
+    {
+      switch (i)
+	{
+	case 0:
+	case 1:
+	case 2:
+	case 3:
+	case 4:
+	  continue;
+	default:
+	  return i;
+	}
+      while (1)
+	{
+	}
+    }
+  return 0;
+}
+static_assert (fn5 () == 5, "");
+
+constexpr int
+fn6 () noexcept
+{
+  int r = 0;
+  for (int i = 0; i < 10; ++i)
+    {
+      continue;
+      for (int j = 0; j < 10; ++j )
+	r++;
+    }
+  return r;
+}
+static_assert (fn6 () == 0, "");
Index: gcc/testsuite/g++.dg/cpp1z/decomp46.C
===================================================================
--- gcc/testsuite/g++.dg/cpp1z/decomp46.C	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/g++.dg/cpp1z/decomp46.C	(.../branches/gcc-8-branch)
@@ -0,0 +1,25 @@
+// PR c++/86836
+// { dg-do compile { target c++11 } }
+// { dg-options "" }
+
+struct A {
+  int operator*();
+  void operator++();
+  bool operator!=(A);
+};
+template <typename> class map {
+public:
+  A begin();
+  A end();
+};
+
+template <typename T> void mergemap(map<T> orig, map<T> toadd) {
+  for (auto p : toadd)
+    auto [orig] = orig;		// { dg-error "use of 'orig' before deduction of 'auto'" }
+}				// { dg-warning "structured bindings only available with" "" { target c++14_down } .-1 }
+
+int
+main() {
+  map<double> x, y;
+  mergemap(x, y);
+}
Index: gcc/testsuite/g++.dg/cpp1z/decomp47.C
===================================================================
--- gcc/testsuite/g++.dg/cpp1z/decomp47.C	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/g++.dg/cpp1z/decomp47.C	(.../branches/gcc-8-branch)
@@ -0,0 +1,32 @@
+// PR c++/87122
+// { dg-do run { target c++14 } }
+// { dg-options "" }
+
+extern "C" void abort ();
+struct S { int a, b; };
+int c;
+
+template <int N>
+void
+foo ()
+{
+  S x[4] = { { N, 2 }, { 3, 4 }, { 5, 6 }, { 7, 8 } };
+  auto f = [](auto & y) {
+    for (auto & [ u, v ] : y)	// { dg-warning "structured bindings only available with" "" { target c++14_down } }
+      {
+	if ((u & 1) != 1 || v != u + 1 || u < N || u > 7 || (c & (1 << u))
+	    || &u != &y[v / 2 - 1].a || &v != &y[v / 2 - 1].b)
+	  abort ();
+	c |= 1 << u;
+      }
+  };
+  f (x);
+}
+
+int
+main ()
+{
+  foo<1> ();
+  if (c != 0xaa)
+    abort ();
+}
Index: gcc/testsuite/g++.dg/ext/is_constructible2.C
===================================================================
--- gcc/testsuite/g++.dg/ext/is_constructible2.C	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/g++.dg/ext/is_constructible2.C	(.../branches/gcc-8-branch)
@@ -0,0 +1,12 @@
+// { dg-do compile { target c++11 } }
+
+#include <type_traits>
+
+template <typename T> struct x {
+  operator bool() {
+    static_assert(!std::is_same<T, T>::value, "");
+    return false;
+  }
+};
+
+static constexpr auto a = __is_constructible(bool, x<int>);
Index: gcc/testsuite/g++.dg/abi/pr87137.C
===================================================================
--- gcc/testsuite/g++.dg/abi/pr87137.C	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/g++.dg/abi/pr87137.C	(.../branches/gcc-8-branch)
@@ -0,0 +1,40 @@
+// PR c++/87137
+
+// Empty macro args are undefined in C++ 98
+// { dg-do compile { target c++11 } }
+
+// We got confused by non-field decls separating bitfields when
+// ms_bitfield_layout was in effect.
+
+#if defined (__x86_64__) || defined (__i686__) || defined (__powerpc__)
+#define ATTRIB  __attribute__((ms_struct))
+#elif defined (__superh__)
+#define ATTRIB __attribute__((renesas))
+#else
+#define ATTRIB
+#endif
+
+#define DEFINE(NAME,BASE,THING)		\
+  struct ATTRIB NAME BASE {		\
+    unsigned one : 12;			\
+    THING				\
+    unsigned two : 4;			\
+  }
+
+template<unsigned I, unsigned J> struct Test;
+template<unsigned I> struct Test<I,I> {};
+
+#define TEST(NAME,BASE,THING)			\
+  DEFINE(NAME##_WITH,BASE,THING);		\
+  DEFINE(NAME##_WITHOUT,BASE,);			\
+  int NAME = sizeof (Test<sizeof(NAME##_WITH),sizeof (NAME##_WITHOUT)>)
+
+TEST(NSFun,,int fun (););
+TEST(SFun,,static int fun (););
+TEST(Tdef,,typedef int tdef;);
+
+TEST(Var,,static int var;);
+struct base { int f; };
+TEST(Use,:base,using base::f;);
+TEST(Tmpl,,template<unsigned> class X {};);
+TEST(TmplFN,,template<unsigned> void fu (););
Index: gcc/testsuite/g++.dg/template/pr86706.C
===================================================================
--- gcc/testsuite/g++.dg/template/pr86706.C	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/g++.dg/template/pr86706.C	(.../branches/gcc-8-branch)
@@ -0,0 +1,16 @@
+// PR c++/86706
+// { dg-do compile }
+
+class A { int b; };
+
+template <class, typename>
+class C : A { C (); static C *f; };
+
+template <class T, typename U>
+C<T, U> *C<T, U>::f;
+
+template <class T, typename U>
+C<T, U>::C ()
+{
+  f->b;
+}
Index: gcc/testsuite/c-c++-common/torture/pr87248.c
===================================================================
--- gcc/testsuite/c-c++-common/torture/pr87248.c	(.../tags/gcc_8_2_0_release)	1970-01-01 01:00:00.000000000 +0100
+++ gcc/testsuite/c-c++-common/torture/pr87248.c	(.../branches/gcc-8-branch)
@@ -0,0 +1,36 @@
+/* PR middle-end/87248 */
+/* { dg-do run } */
+
+void
+foo (signed char *p, int q)
+{
+  *p = q & (-__SCHAR_MAX__ - 1) ? (-__SCHAR_MAX__ - 1) : 0;
+}
+
+int
+bar (long long x)
+{
+  return x & (-__INT_MAX__ - 1) ? (-__INT_MAX__ - 1) : 0;
+}
+
+int
+main ()
+{
+#if __INT_MAX__ > 4 * __SCHAR_MAX__
+  signed char a[4];
+  foo (a, __SCHAR_MAX__ + 1U);
+  foo (a + 1, 2 * (__SCHAR_MAX__ + 1U));
+  foo (a + 2, -__INT_MAX__ - 1);
+  foo (a + 3, (__SCHAR_MAX__ + 1U) / 2);
+  if (a[0] != (-__SCHAR_MAX__ - 1) || a[1] != a[0] || a[2] != a[0] || a[3] != 0)
+    __builtin_abort ();
+#endif
+#if __LONG_LONG_MAX__ > 4 * __INT_MAX__
+  if (bar (__INT_MAX__ + 1LL) != (-__INT_MAX__ - 1)
+      || bar (2 * (__INT_MAX__ + 1LL)) != (-__INT_MAX__ - 1)
+      || bar (-__LONG_LONG_MAX__ - 1) != (-__INT_MAX__ - 1)
+      || bar ((__INT_MAX__ + 1LL) / 2) != 0)
+    __builtin_abort ();
+#endif
+  return 0;
+}
Index: gcc/cp/typeck.c
===================================================================
--- gcc/cp/typeck.c	(.../tags/gcc_8_2_0_release)
+++ gcc/cp/typeck.c	(.../branches/gcc-8-branch)
@@ -5353,6 +5353,7 @@
      otherwise, it will be given type RESULT_TYPE.  */
   if (! converted)
     {
+      warning_sentinel w (warn_sign_conversion, short_compare);
       if (TREE_TYPE (op0) != result_type)
 	op0 = cp_convert_and_check (result_type, op0, complain);
       if (TREE_TYPE (op1) != result_type)
Index: gcc/cp/class.c
===================================================================
--- gcc/cp/class.c	(.../tags/gcc_8_2_0_release)
+++ gcc/cp/class.c	(.../branches/gcc-8-branch)
@@ -278,6 +278,9 @@
   probe = TYPE_MAIN_VARIANT (TREE_TYPE (expr));
   if (want_pointer)
     probe = TYPE_MAIN_VARIANT (TREE_TYPE (probe));
+  if (dependent_type_p (probe))
+    if (tree open = currently_open_class (probe))
+      probe = open;
 
   if (code == PLUS_EXPR
       && !SAME_BINFO_TYPE_P (BINFO_TYPE (d_binfo), probe))
@@ -6243,6 +6246,7 @@
 				  bitsize_int (BITS_PER_UNIT)));
       SET_TYPE_ALIGN (base_t, rli->record_align);
       TYPE_USER_ALIGN (base_t) = TYPE_USER_ALIGN (t);
+      TYPE_TYPELESS_STORAGE (base_t) = TYPE_TYPELESS_STORAGE (t);
 
       /* Copy the non-static data members of T. This will include its
 	 direct non-virtual bases & vtable.  */
Index: gcc/cp/decl.c
===================================================================
--- gcc/cp/decl.c	(.../tags/gcc_8_2_0_release)
+++ gcc/cp/decl.c	(.../branches/gcc-8-branch)
@@ -15557,6 +15557,18 @@
 	    tree stmt = cp_build_modify_expr (input_location, vtbl_ptr,
 					      NOP_EXPR, vtbl,
 					      tf_warning_or_error);
+	    /* If the vptr is shared with some virtual nearly empty base,
+	       don't clear it if not in charge, the dtor of the virtual
+	       nearly empty base will do that later.  */
+	    if (CLASSTYPE_VBASECLASSES (current_class_type)
+		&& CLASSTYPE_PRIMARY_BINFO (current_class_type)
+		&& BINFO_VIRTUAL_P
+			  (CLASSTYPE_PRIMARY_BINFO (current_class_type)))
+	      {
+		stmt = convert_to_void (stmt, ICV_STATEMENT,
+					tf_warning_or_error);
+		stmt = build_if_in_charge (stmt);
+	      }
 	    finish_decl_cleanup (NULL_TREE, stmt);
 	  }
 	else
Index: gcc/cp/method.c
===================================================================
--- gcc/cp/method.c	(.../tags/gcc_8_2_0_release)
+++ gcc/cp/method.c	(.../branches/gcc-8-branch)
@@ -1144,11 +1144,11 @@
 constructible_expr (tree to, tree from)
 {
   tree expr;
+  cp_unevaluated cp_uneval_guard;
   if (CLASS_TYPE_P (to))
     {
       tree ctype = to;
       vec<tree, va_gc> *args = NULL;
-      cp_unevaluated cp_uneval_guard;
       if (TREE_CODE (to) != REFERENCE_TYPE)
 	to = cp_build_reference_type (to, /*rval*/false);
       tree ob = build_stub_object (to);
@@ -2405,7 +2405,7 @@
 
   /* Add it to the class  */
   bool added = add_method (type, fn, false);
-  gcc_assert (added);
+  gcc_assert (added || errorcount);
 
   /* Add it to TYPE_FIELDS.  */
   if (sfk == sfk_destructor
Index: gcc/cp/constexpr.c
===================================================================
--- gcc/cp/constexpr.c	(.../tags/gcc_8_2_0_release)
+++ gcc/cp/constexpr.c	(.../branches/gcc-8-branch)
@@ -2066,6 +2066,7 @@
     {
       if (!ctx->quiet)
 	error ("arithmetic involving a null pointer in %qE", lhs);
+      *non_constant_p = true;
       return t;
     }
   else if (code == POINTER_PLUS_EXPR)
@@ -2506,9 +2507,13 @@
 					     lval,
 					     non_constant_p, overflow_p);
   if (INDIRECT_REF_P (whole)
-      && integer_zerop (TREE_OPERAND (whole, 0))
-      && !ctx->quiet)
-    error ("dereferencing a null pointer in %qE", orig_whole);
+      && integer_zerop (TREE_OPERAND (whole, 0)))
+    {
+      if (!ctx->quiet)
+	error ("dereferencing a null pointer in %qE", orig_whole);
+      *non_constant_p = true;
+      return t;
+    }
 
   if (TREE_CODE (whole) == PTRMEM_CST)
     whole = cplus_expand_constant (whole);
@@ -3926,6 +3931,16 @@
   for (i = tsi_start (t); !tsi_end_p (i); tsi_next (&i))
     {
       tree stmt = tsi_stmt (i);
+      /* We've found a continue, so skip everything until we reach
+	 the label its jumping to.  */
+      if (continues (jump_target))
+	{
+	  if (label_matches (ctx, jump_target, stmt))
+	    /* Found it.  */
+	    *jump_target = NULL_TREE;
+	  else
+	    continue;
+	}
       if (TREE_CODE (stmt) == DEBUG_BEGIN_STMT)
 	continue;
       r = cxx_eval_constant_expression (ctx, stmt, false,
Index: gcc/cp/ChangeLog
===================================================================
--- gcc/cp/ChangeLog	(.../tags/gcc_8_2_0_release)
+++ gcc/cp/ChangeLog	(.../branches/gcc-8-branch)
@@ -1,3 +1,114 @@
+2018-10-03  Martin Liska  <mliska@suse.cz>
+
+	Backport from mainline
+	2018-10-03  Martin Liska  <mliska@suse.cz>
+
+	PR gcov-profile/86109
+	* parser.c (cp_parser_lambda_declarator_opt):
+	Set DECL_LAMBDA_FUNCTION for lambdas.
+
+2018-09-24  Paolo Carlini  <paolo.carlini@oracle.com>
+
+	PR c++/85070
+	* method.c (lazily_declare_fn): During error-recovery add_method
+	may return false.
+
+2018-09-18  Nathan Sidwell  <nathan@acm.org>
+
+	PR c++/86881
+	* name-lookup.c (check_local_shadow): Ignore auto types.
+
+2018-09-13  Ville Voutilainen  <ville.voutilainen@gmail.com>
+
+	Backport from mainline
+	2018-09-13  Ville Voutilainen  <ville.voutilainen@gmail.com>
+	gcc/cp
+
+	PR c++/87093
+	* method.c (constructible_expr): We're in an unevaluated context
+	in all cases, not just for class targets.
+
+	testsuite/
+
+	PR c++/87093
+	* g++.dg/ext/is_constructible2.C: New.
+
+2018-09-05   Pádraig Brady  <p@draigbrady.com>
+
+	PR c++/87185
+	* lambda.c (prune_lambda_captures): Protect against const_vars.get
+	returning NULL.
+
+2018-09-05  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from mainline
+	2018-08-29  Jakub Jelinek  <jakub@redhat.com>
+
+	PR c++/87095
+	* decl.c (begin_destructor_body): If current_class_type has
+	virtual bases and the primary base is nearly empty virtual base,
+	voidify clearing of vptr and make it conditional on in-charge
+	argument.
+
+	2018-08-08  Jakub Jelinek  <jakub@redhat.com>
+
+	PR c++/86836
+	* pt.c (tsubst_expr): For structured bindings, call tsubst_decomp_names
+	before tsubst_init, not after it.
+
+	PR c++/86738
+	* constexpr.c (cxx_eval_binary_expression): For arithmetics involving
+	NULL pointer set *non_constant_p to true.
+	(cxx_eval_component_reference): For dereferencing of a NULL pointer,
+	set *non_constant_p to true and return t.
+
+	2018-08-03  Jason Merrill  <jason@redhat.com>
+
+	PR c++/86706
+	* class.c (build_base_path): Use currently_open_class.
+
+2018-08-31  Nathan Sidwell  <nathan@acm.org>
+
+	PR c++/87155
+	PR c++/84707
+	* name-lookup.c (name_lookup::search_namespace): Don't look at
+	inlines when searching for NULL names.
+
+2018-08-29  Jakub Jelinek  <jakub@redhat.com>
+
+	PR c++/87122
+	* pt.c (tsubst_expr) <case RANGE_FOR_STMT>: If
+	processing_template_decl and decl is structured binding decl, call
+	cp_finish_decomp.
+
+2018-08-17  Richard Biener  <rguenther@suse.de>
+
+	Backport from mainline
+	2018-08-02  Richard Biener  <rguenther@suse.de>
+
+	PR c++/86763
+	* class.c (layout_class_type): Copy TYPE_TYPELESS_STORAGE
+	to the CLASSTYPE_AS_BASE.
+
+2018-08-10  Jason Merrill  <jason@redhat.com>
+
+	PR c++/86728 - C variadic generic lambda.
+	* parser.c (cp_parser_parameter_declaration): Don't turn 'auto' into
+	a pack if it's followed by a declarator-id.
+
+2018-08-08  Marek Polacek  <polacek@redhat.com>
+
+	Backport from mainline
+	2018-08-06  Marek Polacek  <polacek@redhat.com>
+
+	PR c++/86767
+	* constexpr.c (cxx_eval_statement_list): Handle continue.
+
+2018-08-01  Marek Polacek  <polacek@redhat.com>
+
+	PR c++/86190 - bogus -Wsign-conversion warning
+	* typeck.c (cp_build_binary_op): Add a warning sentinel.
+
 2018-07-26  Release Manager
 
 	* GCC 8.2.0 released.
Index: gcc/cp/pt.c
===================================================================
--- gcc/cp/pt.c	(.../tags/gcc_8_2_0_release)
+++ gcc/cp/pt.c	(.../branches/gcc-8-branch)
@@ -16734,8 +16734,18 @@
 		else
 		  {
 		    int const_init = false;
+		    unsigned int cnt = 0;
+		    tree first = NULL_TREE, ndecl = error_mark_node;
 		    maybe_push_decl (decl);
+
 		    if (VAR_P (decl)
+			&& DECL_DECOMPOSITION_P (decl)
+			&& TREE_TYPE (pattern_decl) != error_mark_node)
+		      ndecl = tsubst_decomp_names (decl, pattern_decl, args,
+						   complain, in_decl, &first,
+						   &cnt);
+
+		    if (VAR_P (decl)
 			&& DECL_PRETTY_FUNCTION_P (decl))
 		      {
 			/* For __PRETTY_FUNCTION__ we have to adjust the
@@ -16750,23 +16760,14 @@
 		    if (VAR_P (decl))
 		      const_init = (DECL_INITIALIZED_BY_CONSTANT_EXPRESSION_P
 				    (pattern_decl));
-		    if (VAR_P (decl)
-			&& DECL_DECOMPOSITION_P (decl)
-			&& TREE_TYPE (pattern_decl) != error_mark_node)
-		      {
-			unsigned int cnt;
-			tree first;
-			tree ndecl
-			  = tsubst_decomp_names (decl, pattern_decl, args,
-						 complain, in_decl, &first, &cnt);
-			if (ndecl != error_mark_node)
-			  cp_maybe_mangle_decomp (ndecl, first, cnt);
-			cp_finish_decl (decl, init, const_init, NULL_TREE, 0);
-			if (ndecl != error_mark_node)
-			  cp_finish_decomp (ndecl, first, cnt);
-		      }
-		    else
-		      cp_finish_decl (decl, init, const_init, NULL_TREE, 0);
+
+		    if (ndecl != error_mark_node)
+		      cp_maybe_mangle_decomp (ndecl, first, cnt);
+
+		    cp_finish_decl (decl, init, const_init, NULL_TREE, 0);
+
+		    if (ndecl != error_mark_node)
+		      cp_finish_decomp (ndecl, first, cnt);
 		  }
 	      }
 	  }
@@ -16816,6 +16817,8 @@
 	    RANGE_FOR_IVDEP (stmt) = RANGE_FOR_IVDEP (t);
 	    RANGE_FOR_UNROLL (stmt) = RANGE_FOR_UNROLL (t);
 	    finish_range_for_decl (stmt, decl, expr);
+	    if (decomp_first && decl != error_mark_node)
+	      cp_finish_decomp (decl, decomp_first, decomp_cnt);
 	  }
 	else
 	  {
Index: gcc/cp/parser.c
===================================================================
--- gcc/cp/parser.c	(.../tags/gcc_8_2_0_release)
+++ gcc/cp/parser.c	(.../branches/gcc-8-branch)
@@ -10620,6 +10620,7 @@
 	DECL_ARTIFICIAL (fco) = 1;
 	/* Give the object parameter a different name.  */
 	DECL_NAME (DECL_ARGUMENTS (fco)) = get_identifier ("__closure");
+	DECL_LAMBDA_FUNCTION (fco) = 1;
 	if (return_type)
 	  TYPE_HAS_LATE_RETURN_TYPE (TREE_TYPE (fco)) = 1;
       }
@@ -21598,7 +21599,8 @@
      parameter was introduced during cp_parser_parameter_declaration,
      change any implicit parameters introduced into packs.  */
   if (parser->implicit_template_parms
-      && (token->type == CPP_ELLIPSIS
+      && ((token->type == CPP_ELLIPSIS
+	   && declarator_can_be_parameter_pack (declarator))
 	  || (declarator && declarator->parameter_pack_p)))
     {
       int latest_template_parm_idx = TREE_VEC_LENGTH
Index: gcc/cp/lambda.c
===================================================================
--- gcc/cp/lambda.c	(.../tags/gcc_8_2_0_release)
+++ gcc/cp/lambda.c	(.../branches/gcc-8-branch)
@@ -1511,8 +1511,8 @@
       tree cap = *capp;
       if (tree var = var_to_maybe_prune (cap))
 	{
-	  tree *use = *const_vars.get (var);
-	  if (TREE_CODE (*use) == DECL_EXPR)
+	  tree **use = const_vars.get (var);
+	  if (use && TREE_CODE (**use) == DECL_EXPR)
 	    {
 	      /* All uses of this capture were folded away, leaving only the
 		 proxy declaration.  */
@@ -1527,7 +1527,7 @@
 	      *fieldp = DECL_CHAIN (*fieldp);
 
 	      /* And remove the capture proxy declaration.  */
-	      *use = void_node;
+	      **use = void_node;
 	      continue;
 	    }
 	}
Index: gcc/cp/name-lookup.c
===================================================================
--- gcc/cp/name-lookup.c	(.../tags/gcc_8_2_0_release)
+++ gcc/cp/name-lookup.c	(.../branches/gcc-8-branch)
@@ -560,12 +560,15 @@
 
   /* Look in exactly namespace. */
   bool found = search_namespace_only (scope);
-  
-  /* Recursively look in its inline children.  */
-  if (vec<tree, va_gc> *inlinees = DECL_NAMESPACE_INLINEES (scope))
-    for (unsigned ix = inlinees->length (); ix--;)
-      found |= search_namespace ((*inlinees)[ix]);
 
+  /* Don't look into inline children, if we're looking for an
+     anonymous name -- it must be in the current scope, if anywhere.  */
+  if (name)
+    /* Recursively look in its inline children.  */
+    if (vec<tree, va_gc> *inlinees = DECL_NAMESPACE_INLINEES (scope))
+      for (unsigned ix = inlinees->length (); ix--;)
+	found |= search_namespace ((*inlinees)[ix]);
+
   if (found)
     mark_found (scope);
 
@@ -2737,6 +2740,13 @@
 	       && (same_type_p (TREE_TYPE (old), TREE_TYPE (decl))
 		   || (!dependent_type_p (TREE_TYPE (decl))
 		       && !dependent_type_p (TREE_TYPE (old))
+		       /* If the new decl uses auto, we don't yet know
+			  its type (the old type cannot be using auto
+			  at this point, without also being
+			  dependent).  This is an indication we're
+			  (now) doing the shadow checking too
+			  early.  */
+		       && !type_uses_auto (TREE_TYPE (decl))
 		       && can_convert (TREE_TYPE (old), TREE_TYPE (decl),
 				       tf_none))))
 	warning_code = OPT_Wshadow_compatible_local;
Index: gcc/dojump.c
===================================================================
--- gcc/dojump.c	(.../tags/gcc_8_2_0_release)
+++ gcc/dojump.c	(.../branches/gcc-8-branch)
@@ -1214,15 +1214,15 @@
   code = unsignedp ? unsigned_code : signed_code;
 
   /* If function pointers need to be "canonicalized" before they can
-     be reliably compared, then canonicalize them.
-     Only do this if *both* sides of the comparison are function pointers.
-     If one side isn't, we want a noncanonicalized comparison.  See PR
-     middle-end/17564.  */
+     be reliably compared, then canonicalize them.  Canonicalize the
+     expression when one of the operands is a function pointer.  This
+     handles the case where the other operand is a void pointer.  See
+     PR middle-end/17564.  */
   if (targetm.have_canonicalize_funcptr_for_compare ()
-      && POINTER_TYPE_P (TREE_TYPE (treeop0))
-      && POINTER_TYPE_P (TREE_TYPE (treeop1))
-      && FUNC_OR_METHOD_TYPE_P (TREE_TYPE (TREE_TYPE (treeop0)))
-      && FUNC_OR_METHOD_TYPE_P (TREE_TYPE (TREE_TYPE (treeop1))))
+      && ((POINTER_TYPE_P (TREE_TYPE (treeop0))
+	   && FUNC_OR_METHOD_TYPE_P (TREE_TYPE (TREE_TYPE (treeop0))))
+	  || (POINTER_TYPE_P (TREE_TYPE (treeop1))
+	      && FUNC_OR_METHOD_TYPE_P (TREE_TYPE (TREE_TYPE (treeop1))))))
     {
       rtx new_op0 = gen_reg_rtx (mode);
       rtx new_op1 = gen_reg_rtx (mode);
Index: gcc/tree-ssa-math-opts.c
===================================================================
--- gcc/tree-ssa-math-opts.c	(.../tags/gcc_8_2_0_release)
+++ gcc/tree-ssa-math-opts.c	(.../branches/gcc-8-branch)
@@ -422,6 +422,8 @@
 	    gsi_next (&gsi);
 
 	  gsi_insert_before (&gsi, new_stmt, GSI_SAME_STMT);
+	  if (should_insert_square_recip)
+	    gsi_insert_before (&gsi, new_square_stmt, GSI_SAME_STMT);
 	}
       else if (def_gsi && occ->bb == def_gsi->bb)
 	{
@@ -429,8 +431,9 @@
 	     never happen if the definition statement can throw, because in
 	     that case the sole successor of the statement's basic block will
 	     dominate all the uses as well.  */
-	  gsi = *def_gsi;
 	  gsi_insert_after (def_gsi, new_stmt, GSI_NEW_STMT);
+	  if (should_insert_square_recip)
+	    gsi_insert_after (def_gsi, new_square_stmt, GSI_NEW_STMT);
 	}
       else
 	{
@@ -437,13 +440,10 @@
 	  /* Case 3: insert in a basic block not containing defs/uses.  */
 	  gsi = gsi_after_labels (occ->bb);
 	  gsi_insert_before (&gsi, new_stmt, GSI_SAME_STMT);
+	  if (should_insert_square_recip)
+	    gsi_insert_before (&gsi, new_square_stmt, GSI_SAME_STMT);
 	}
 
-      /* Regardless of which case the reciprocal as inserted in,
-	 we insert the square immediately after the reciprocal.  */
-      if (should_insert_square_recip)
-	gsi_insert_before (&gsi, new_square_stmt, GSI_SAME_STMT);
-
       reciprocal_stats.rdivs_inserted++;
 
       occ->recip_def_stmt = new_stmt;
Index: gcc/dwarf2out.c
===================================================================
--- gcc/dwarf2out.c	(.../tags/gcc_8_2_0_release)
+++ gcc/dwarf2out.c	(.../branches/gcc-8-branch)
@@ -28472,7 +28472,7 @@
       debug_str_section = get_section (DEBUG_LTO_STR_SECTION,
 				       DEBUG_STR_SECTION_FLAGS
 				       | SECTION_EXCLUDE, NULL);
-      if (!dwarf_split_debug_info && !output_asm_line_debug_info ())
+      if (!dwarf_split_debug_info)
 	debug_line_str_section
 	  = get_section (DEBUG_LTO_LINE_STR_SECTION,
 			 DEBUG_STR_SECTION_FLAGS | SECTION_EXCLUDE, NULL);
@@ -31074,6 +31074,11 @@
 
       /* Remove indirect string decisions.  */
       debug_str_hash->traverse<void *, reset_indirect_string> (NULL);
+      if (debug_line_str_hash)
+	{
+	  debug_line_str_hash->traverse<void *, reset_indirect_string> (NULL);
+	  debug_line_str_hash = NULL;
+	}
     }
 
 #if ENABLE_ASSERT_CHECKING
@@ -31330,8 +31335,8 @@
       switch_to_section (debug_loc_section);
       if (dwarf_version >= 5)
 	{
-	  ASM_GENERATE_INTERNAL_LABEL (l1, DEBUG_LOC_SECTION_LABEL, 1);
-	  ASM_GENERATE_INTERNAL_LABEL (l2, DEBUG_LOC_SECTION_LABEL, 2);
+	  ASM_GENERATE_INTERNAL_LABEL (l1, DEBUG_LOC_SECTION_LABEL, 2);
+	  ASM_GENERATE_INTERNAL_LABEL (l2, DEBUG_LOC_SECTION_LABEL, 3);
 	  if (DWARF_INITIAL_LENGTH_SIZE - DWARF_OFFSET_SIZE == 4)
 	    dw2_asm_output_data (4, 0xffffffff,
 				 "Initial length escape value indicating "
@@ -31832,10 +31837,10 @@
 
   /* Do not generate DWARF assembler now when not producing LTO bytecode.  */
   if ((!flag_generate_lto && !flag_generate_offload)
-      /* FIXME: Disable debug info generation for PE-COFF targets since the
+      /* FIXME: Disable debug info generation for (PE-)COFF targets since the
 	 copy_lto_debug_sections operation of the simple object support in
 	 libiberty is not implemented for them yet.  */
-      || TARGET_PECOFF)
+      || TARGET_PECOFF || TARGET_COFF)
     return;
 
   /* Now as we are going to output for LTO initialize sections and labels
@@ -31950,6 +31955,13 @@
   /* If we emitted any indirect strings, output the string table too.  */
   if (debug_str_hash || skeleton_debug_str_hash)
     output_indirect_strings ();
+  if (debug_line_str_hash)
+    {
+      switch_to_section (debug_line_str_section);
+      const enum dwarf_form form = DW_FORM_line_strp;
+      debug_line_str_hash->traverse<enum dwarf_form,
+				    output_indirect_string> (form);
+    }
 
   /* Switch back to the text section.  */
   switch_to_section (text_section);
Index: gcc/match.pd
===================================================================
--- gcc/match.pd	(.../tags/gcc_8_2_0_release)
+++ gcc/match.pd	(.../branches/gcc-8-branch)
@@ -3462,8 +3462,8 @@
        /* Disable this optimization if we're casting a function pointer
 	  type on targets that require function pointer canonicalization.  */
        && !(targetm.have_canonicalize_funcptr_for_compare ()
-	    && TREE_CODE (TREE_TYPE (@00)) == POINTER_TYPE
-	    && TREE_CODE (TREE_TYPE (TREE_TYPE (@00))) == FUNCTION_TYPE)
+	    && POINTER_TYPE_P (TREE_TYPE (@00))
+	    && FUNC_OR_METHOD_TYPE_P (TREE_TYPE (TREE_TYPE (@00))))
        && single_use (@0))
    (if (TYPE_PRECISION (TREE_TYPE (@00)) == TYPE_PRECISION (TREE_TYPE (@0))
 	&& (TREE_CODE (@10) == INTEGER_CST
Index: gcc/expr.c
===================================================================
--- gcc/expr.c	(.../tags/gcc_8_2_0_release)
+++ gcc/expr.c	(.../branches/gcc-8-branch)
@@ -11532,12 +11532,10 @@
   /* We won't bother with store-flag operations involving function pointers
      when function pointers must be canonicalized before comparisons.  */
   if (targetm.have_canonicalize_funcptr_for_compare ()
-      && ((TREE_CODE (TREE_TYPE (arg0)) == POINTER_TYPE
-	   && (TREE_CODE (TREE_TYPE (TREE_TYPE (arg0)))
-	       == FUNCTION_TYPE))
-	  || (TREE_CODE (TREE_TYPE (arg1)) == POINTER_TYPE
-	      && (TREE_CODE (TREE_TYPE (TREE_TYPE (arg1)))
-		  == FUNCTION_TYPE))))
+      && ((POINTER_TYPE_P (TREE_TYPE (arg0))
+	   && FUNC_OR_METHOD_TYPE_P (TREE_TYPE (TREE_TYPE (arg0))))
+	  || (POINTER_TYPE_P (TREE_TYPE (arg1))
+	      && FUNC_OR_METHOD_TYPE_P (TREE_TYPE (TREE_TYPE (arg1))))))
     return 0;
 
   STRIP_NOPS (arg0);
Index: gcc/ada/libgnarl/s-osinte__solaris.ads
===================================================================
--- gcc/ada/libgnarl/s-osinte__solaris.ads	(.../tags/gcc_8_2_0_release)
+++ gcc/ada/libgnarl/s-osinte__solaris.ads	(.../branches/gcc-8-branch)
@@ -536,17 +536,18 @@
    end record;
    pragma Convention (C, record_type_3);
 
+   type upad64_t is new Interfaces.Unsigned_64;
+
    type mutex_t is record
       flags : record_type_3;
-      lock  : String (1 .. 8);
-      data  : String (1 .. 8);
+      lock  : upad64_t;
+      data  : upad64_t;
    end record;
    pragma Convention (C, mutex_t);
 
    type cond_t is record
-      flag  : array_type_9;
-      Xtype : unsigned_long;
-      data  : String (1 .. 8);
+      flags : record_type_3;
+      data  : upad64_t;
    end record;
    pragma Convention (C, cond_t);
 
Index: gcc/ada/ChangeLog
===================================================================
--- gcc/ada/ChangeLog	(.../tags/gcc_8_2_0_release)
+++ gcc/ada/ChangeLog	(.../branches/gcc-8-branch)
@@ -1,3 +1,12 @@
+2018-09-13  Eric Botcazou  <ebotcazou@adacore.com>
+
+	Backport from mainline
+	2018-07-31  Eric Botcazou  <ebotcazou@adacore.com>
+
+	* libgnarl/s-osinte__solaris.ads (upad64_t): New private type.
+	(mutex_t): Use it for 'lock' and 'data' components.
+	(cond_t): Likewise for 'data' and use single 'flags' component.
+
 2018-07-26  Release Manager
 
 	* GCC 8.2.0 released.
Index: gcc/common/config/i386/i386-common.c
===================================================================
--- gcc/common/config/i386/i386-common.c	(.../tags/gcc_8_2_0_release)
+++ gcc/common/config/i386/i386-common.c	(.../branches/gcc-8-branch)
@@ -59,7 +59,7 @@
 #define OPTION_MASK_ISA_FXSR_SET OPTION_MASK_ISA_FXSR
 #define OPTION_MASK_ISA_XSAVE_SET OPTION_MASK_ISA_XSAVE
 #define OPTION_MASK_ISA_XSAVEOPT_SET \
-  (OPTION_MASK_ISA_XSAVEOPT | OPTION_MASK_ISA_XSAVE)
+  (OPTION_MASK_ISA_XSAVEOPT | OPTION_MASK_ISA_XSAVE_SET)
 #define OPTION_MASK_ISA_AVX512F_SET \
   (OPTION_MASK_ISA_AVX512F | OPTION_MASK_ISA_AVX2_SET)
 #define OPTION_MASK_ISA_AVX512CD_SET \
@@ -95,9 +95,9 @@
 #define OPTION_MASK_ISA_PREFETCHWT1_SET OPTION_MASK_ISA_PREFETCHWT1
 #define OPTION_MASK_ISA_CLFLUSHOPT_SET OPTION_MASK_ISA_CLFLUSHOPT
 #define OPTION_MASK_ISA_XSAVES_SET \
-  (OPTION_MASK_ISA_XSAVES | OPTION_MASK_ISA_XSAVE)
+  (OPTION_MASK_ISA_XSAVES | OPTION_MASK_ISA_XSAVE_SET)
 #define OPTION_MASK_ISA_XSAVEC_SET \
-  (OPTION_MASK_ISA_XSAVEC | OPTION_MASK_ISA_XSAVE)
+  (OPTION_MASK_ISA_XSAVEC | OPTION_MASK_ISA_XSAVE_SET)
 #define OPTION_MASK_ISA_CLWB_SET OPTION_MASK_ISA_CLWB
 
 /* SSE4 includes both SSE4.1 and SSE4.2. -msse4 should be the same
@@ -183,7 +183,8 @@
 #define OPTION_MASK_ISA_FMA_UNSET OPTION_MASK_ISA_FMA
 #define OPTION_MASK_ISA_FXSR_UNSET OPTION_MASK_ISA_FXSR
 #define OPTION_MASK_ISA_XSAVE_UNSET \
-  (OPTION_MASK_ISA_XSAVE | OPTION_MASK_ISA_XSAVEOPT_UNSET)
+  (OPTION_MASK_ISA_XSAVE | OPTION_MASK_ISA_XSAVEOPT_UNSET \
+   | OPTION_MASK_ISA_XSAVES_UNSET | OPTION_MASK_ISA_XSAVEC_UNSET)
 #define OPTION_MASK_ISA_XSAVEOPT_UNSET OPTION_MASK_ISA_XSAVEOPT
 #define OPTION_MASK_ISA_AVX2_UNSET \
   (OPTION_MASK_ISA_AVX2 | OPTION_MASK_ISA_AVX512F_UNSET)
Index: gcc/asan.c
===================================================================
--- gcc/asan.c	(.../tags/gcc_8_2_0_release)
+++ gcc/asan.c	(.../branches/gcc-8-branch)
@@ -253,7 +253,7 @@
 /* Set of variable declarations that are going to be guarded by
    use-after-scope sanitizer.  */
 
-static hash_set<tree> *asan_handled_variables = NULL;
+hash_set<tree> *asan_handled_variables = NULL;
 
 hash_set <tree> *asan_used_labels = NULL;
 
Index: gcc/asan.h
===================================================================
--- gcc/asan.h	(.../tags/gcc_8_2_0_release)
+++ gcc/asan.h	(.../branches/gcc-8-branch)
@@ -110,6 +110,8 @@
 
 extern bool asan_sanitize_allocas_p (void);
 
+extern hash_set<tree> *asan_handled_variables;
+
 /* Return TRUE if builtin with given FCODE will be intercepted by
    libasan.  */
 
Index: gcc/fortran/interface.c
===================================================================
--- gcc/fortran/interface.c	(.../tags/gcc_8_2_0_release)
+++ gcc/fortran/interface.c	(.../branches/gcc-8-branch)
@@ -735,6 +735,13 @@
   if (s2->attr.ext_attr & (1 << EXT_ATTR_NO_ARG_CHECK))
     return true;
 
+  return gfc_compare_types (&s1->ts, &s2->ts) || s2->ts.type == BT_ASSUMED;
+}
+
+
+static bool
+compare_type_characteristics (gfc_symbol *s1, gfc_symbol *s2)
+{
   /* TYPE and CLASS of the same declared type are type compatible,
      but have different characteristics.  */
   if ((s1->ts.type == BT_CLASS && s2->ts.type == BT_DERIVED)
@@ -741,7 +748,7 @@
       || (s1->ts.type == BT_DERIVED && s2->ts.type == BT_CLASS))
     return false;
 
-  return gfc_compare_types (&s1->ts, &s2->ts) || s2->ts.type == BT_ASSUMED;
+  return compare_type (s1, s2);
 }
 
 
@@ -1291,7 +1298,8 @@
   /* Check type and rank.  */
   if (type_must_agree)
     {
-      if (!compare_type (s1, s2) || !compare_type (s2, s1))
+      if (!compare_type_characteristics (s1, s2)
+	  || !compare_type_characteristics (s2, s1))
 	{
 	  snprintf (errmsg, err_len, "Type mismatch in argument '%s' (%s/%s)",
 		    s1->name, gfc_typename (&s1->ts), gfc_typename (&s2->ts));
@@ -1510,7 +1518,7 @@
     return true;
 
   /* Check type and rank.  */
-  if (!compare_type (r1, r2))
+  if (!compare_type_characteristics (r1, r2))
     {
       snprintf (errmsg, err_len, "Type mismatch in function result (%s/%s)",
 		gfc_typename (&r1->ts), gfc_typename (&r2->ts));
Index: gcc/fortran/trans-expr.c
===================================================================
--- gcc/fortran/trans-expr.c	(.../tags/gcc_8_2_0_release)
+++ gcc/fortran/trans-expr.c	(.../branches/gcc-8-branch)
@@ -1505,7 +1505,6 @@
   gfc_start_block (&block);
 
   lhs = gfc_copy_expr (code->expr1);
-  gfc_add_data_component (lhs);
 
   rhs = gfc_copy_expr (code->expr1);
   gfc_add_vptr_component (rhs);
@@ -1523,11 +1522,15 @@
     {
       gfc_array_spec *tmparr = gfc_get_array_spec ();
       *tmparr = *CLASS_DATA (code->expr1)->as;
+      /* Adding the array ref to the class expression results in correct
+	 indexing to the dynamic type.  */
       gfc_add_full_array_ref (lhs, tmparr);
       tmp = gfc_trans_class_array_init_assign (rhs, lhs, code->expr1);
     }
   else
     {
+      /* Scalar initialization needs the _data component.  */
+      gfc_add_data_component (lhs);
       sz = gfc_copy_expr (code->expr1);
       gfc_add_vptr_component (sz);
       gfc_add_size_component (sz);
@@ -2234,7 +2237,8 @@
   if (!cl->length)
     {
       gfc_expr* expr_flat;
-      gcc_assert (expr);
+      if (!expr)
+	return;
       expr_flat = gfc_copy_expr (expr);
       flatten_array_ctors_without_strlen (expr_flat);
       gfc_resolve_expr (expr_flat);
Index: gcc/fortran/trans-array.c
===================================================================
--- gcc/fortran/trans-array.c	(.../tags/gcc_8_2_0_release)
+++ gcc/fortran/trans-array.c	(.../branches/gcc-8-branch)
@@ -3414,11 +3414,7 @@
   if (is_pointer_array (info->descriptor))
     {
       if (TREE_CODE (info->descriptor) == COMPONENT_REF)
-	{
-	  decl = gfc_evaluate_now (info->descriptor, &se->pre);
-	  GFC_DECL_PTR_ARRAY_P (decl) = 1;
-	  TREE_USED (decl) = 1;
-	}
+	decl = info->descriptor;
       else if (TREE_CODE (info->descriptor) == INDIRECT_REF)
 	decl = TREE_OPERAND (info->descriptor, 0);
 
@@ -3659,11 +3655,7 @@
       && is_pointer_array (se->expr))
     {
       if (TREE_CODE (se->expr) == COMPONENT_REF)
-	{
-	  decl = gfc_evaluate_now (se->expr, &se->pre);
-	  GFC_DECL_PTR_ARRAY_P (decl) = 1;
-	  TREE_USED (decl) = 1;
-	}
+	decl = se->expr;
       else if (TREE_CODE (se->expr) == INDIRECT_REF)
 	decl = TREE_OPERAND (se->expr, 0);
       else
@@ -9505,6 +9497,9 @@
 
   sym = expr->symtree->n.sym;
 
+  if (sym->attr.associate_var)
+    return false;
+
   /* An allocatable class variable with no reference.  */
   if (sym->ts.type == BT_CLASS
       && CLASS_DATA (sym)->attr.allocatable
Index: gcc/fortran/decl.c
===================================================================
--- gcc/fortran/decl.c	(.../tags/gcc_8_2_0_release)
+++ gcc/fortran/decl.c	(.../branches/gcc-8-branch)
@@ -10557,7 +10557,8 @@
 
 done:
   if (ba->access == ACCESS_UNKNOWN)
-    ba->access = gfc_typebound_default_access;
+    ba->access = ppc ? gfc_current_block()->component_access
+                     : gfc_typebound_default_access;
 
   if (ppc && !seen_ptr)
     {
Index: gcc/fortran/gfortran.h
===================================================================
--- gcc/fortran/gfortran.h	(.../tags/gcc_8_2_0_release)
+++ gcc/fortran/gfortran.h	(.../branches/gcc-8-branch)
@@ -191,7 +191,8 @@
 /* Arithmetic results.  */
 enum arith
 { ARITH_OK = 1, ARITH_OVERFLOW, ARITH_UNDERFLOW, ARITH_NAN,
-  ARITH_DIV0, ARITH_INCOMMENSURATE, ARITH_ASYMMETRIC, ARITH_PROHIBIT
+  ARITH_DIV0, ARITH_INCOMMENSURATE, ARITH_ASYMMETRIC, ARITH_PROHIBIT,
+  ARITH_WRONGCONCAT
 };
 
 /* Statements.  */
Index: gcc/fortran/ChangeLog
===================================================================
--- gcc/fortran/ChangeLog	(.../tags/gcc_8_2_0_release)
+++ gcc/fortran/ChangeLog	(.../branches/gcc-8-branch)
@@ -1,3 +1,128 @@
+2018-10-08  Paul Thomas  <pault@gcc.gnu.org>
+
+	PR fortran/83999
+	Backport from trunk
+	* resolve.c (resolve_fl_procedure): Include class functions in
+	the test that elemental function results be scalar.
+
+2018-10-08  Paul Thomas  <pault@gcc.gnu.org>
+
+	Backport from trunk
+	PR fortran/86372
+	* trans-stmt.c (trans_associate_var): Character associate names
+	with variable string length do not have to be deferred length
+	for the string length to be set, if variable.
+
+2018-10-06  Thomas Koenig  <tkoenig@gcc.gnu.org>
+
+	PR fortran/86111
+	Backport from trunk
+	* gfortran.h (enum arith): Add ARITH_WRONGCONCAT.
+	* arith.h (gfc_arith_error): Issue error for ARITH_WRONGCONCAT.
+	(gfc_arith_concat):  If the types of op1 and op2 are not
+	character of if their kinds do not match, issue ARITH_WRONGCONCAT.
+
+2018-09-18  Janus Weil  <janus@gcc.gnu.org>
+
+	Backport from trunk
+	PR fortran/85395
+	* decl.c (match_binding_attributes): Use correct default accessibility
+	for procedure pointer components.
+
+2018-09-18  Janus Weil  <janus@gcc.gnu.org>
+
+	Backport from trunk
+	PR fortran/86830
+	* expr.c (gfc_is_simply_contiguous): Handle type-bound procedure calls
+	with non-polymorphic objects.
+
+2018-09-18  Paul Thomas  <pault@gcc.gnu.org>
+
+	Backported from trunk
+	PR fortran/85954
+	* resolve.c (resolve_assoc_var): If the target expression is a
+	deferred charlen dummy and the associate name shares the
+	charlen, generate a new one. Make sure that new charlens are in
+	the namespace list so that they get cleaned up.
+	* trans-array.c (gfc_is_reallocatable_lhs): Associate names are
+	not reallocatable.
+	* trans-decl.c (gfc_get_symbol_decl): Put deferred character
+	length dummy and result arrays on the deferred initialization
+	list so that the variable length arrays can be correctly dealt
+	with.
+	* trans-expr.c (gfc_conv_string_length): Return if 'expr' is
+	NULL rather than ICEing.
+
+2018-09-12  Paul Thomas  <pault@gcc.gnu.org>
+
+	Backported from trunk
+	PR fortran/87284
+	* trans-expr.c (gfc_trans_class_init_assign): Access to
+	to array elements of the dynamic type requires that the array
+	reference be added to the class expression and not the _data
+	component, unlike scalar expressions.
+
+2018-09-11  Paul Thomas  <pault@gcc.gnu.org>
+
+	Backported from trunk
+	PR fortran/87277
+	* expr.c (is_subref_array): Add the check of dimensionality for
+	class, dummy, pointer arrays.
+
+2018-09-05  Janus Weil  <janus@gcc.gnu.org>
+
+	Backported from trunk
+	PR fortran/86116
+	* interface.c (compare_type): Remove a CLASS/TYPE check.
+	(compare_type_characteristics): New function that behaves like the old
+	'compare_type'.
+	(gfc_check_dummy_characteristics, gfc_check_result_characteristics):
+	Call 'compare_type_characteristics' instead of 'compare_type'.
+
+2018-09-04  Jerry DeLisle  <jvdelisle@gcc.gnu.org>
+
+	* simplify.c (gfc_simplify_modulo): Re-arrange code to test
+	whether 'P' is zero and issue an error if it is.
+
+2018-09-01  Paul Thomas  <pault@gcc.gnu.org>
+
+	PR fortran/86328
+	PR fortran/86760
+	* trans-array.c (gfc_conv_scalarized_array_ref): Do not fix
+	info->descriptor but pass it directly to gfc_build_array_ref.
+	(gfc_conv_array_ref): Likewise for se->expr.
+	* trans.c (gfc_build_array_ref): If 'decl' is a COMPONENT_REF
+	obtain the span field directly from it.
+
+2018-08-24  Thomas Koenig  <tkoenig@gcc.gnu.org>
+
+	Backport from trunk
+	PR fortran/86837
+	* frontend-passes.c (var_in_expr_callback): New function.
+	(var_in_expr): New function.
+	(traverse_io_block): Use var_in_expr instead of
+	gfc_check_dependency for checking if the variable depends on the
+	previous interators.
+
+2018-08-12  Paul Thomas  <pault@gcc.gnu.org>
+
+	Backported from trunk
+	PR fortran/86906
+	* resolve.c (resolve_fl_variable_derived): Check if the derived
+	type is use associated before checking for the host association
+	error.
+
+2018-07-26  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from mainline
+	2018-07-10  Jakub Jelinek  <jakub@redhat.com>
+
+	PR fortran/86421
+	* module.c (omp_declare_simd_clauses): Add LINEAR with _REF, _VAL and
+	_UVAL suffixes.
+	(mio_omp_declare_simd): Save and restore ref, val and uval modifiers
+	on linear clauses.  Initialize n->where to gfc_current_locus.
+
 2018-07-26  Release Manager
 
 	* GCC 8.2.0 released.
Index: gcc/fortran/trans-stmt.c
===================================================================
--- gcc/fortran/trans-stmt.c	(.../tags/gcc_8_2_0_release)
+++ gcc/fortran/trans-stmt.c	(.../branches/gcc-8-branch)
@@ -1887,7 +1887,6 @@
 	}
 
       if (sym->ts.type == BT_CHARACTER
-	  && sym->ts.deferred
 	  && !sym->attr.select_type_temporary
 	  && VAR_P (sym->ts.u.cl->backend_decl)
 	  && se.string_length != sym->ts.u.cl->backend_decl)
Index: gcc/fortran/expr.c
===================================================================
--- gcc/fortran/expr.c	(.../tags/gcc_8_2_0_release)
+++ gcc/fortran/expr.c	(.../branches/gcc-8-branch)
@@ -1069,6 +1069,7 @@
 
   if (e->symtree->n.sym->ts.type == BT_CLASS
       && e->symtree->n.sym->attr.dummy
+      && CLASS_DATA (e->symtree->n.sym)->attr.dimension
       && CLASS_DATA (e->symtree->n.sym)->attr.class_pointer)
     return true;
 
@@ -5360,16 +5361,13 @@
 	return expr->value.function.esym->result->attr.contiguous;
       else
 	{
-	  /* We have to jump through some hoops if this is a vtab entry.  */
-	  gfc_symbol *s;
-	  gfc_ref *r, *rc;
+	  /* Type-bound procedures.  */
+	  gfc_symbol *s = expr->symtree->n.sym;
+	  if (s->ts.type != BT_CLASS && s->ts.type != BT_DERIVED)
+	    return false;
 
-	  s = expr->symtree->n.sym;
-	  if (s->ts.type != BT_CLASS)
-	    return false;
-	  
-	  rc = NULL;
-	  for (r = expr->ref; r; r = r->next)
+	  gfc_ref *rc = NULL;
+	  for (gfc_ref *r = expr->ref; r; r = r->next)
 	    if (r->type == REF_COMPONENT)
 	      rc = r;
 
Index: gcc/fortran/module.c
===================================================================
--- gcc/fortran/module.c	(.../tags/gcc_8_2_0_release)
+++ gcc/fortran/module.c	(.../branches/gcc-8-branch)
@@ -4100,6 +4100,9 @@
     minit ("UNIFORM", 3),
     minit ("LINEAR", 4),
     minit ("ALIGNED", 5),
+    minit ("LINEAR_REF", 33),
+    minit ("LINEAR_VAL", 34),
+    minit ("LINEAR_UVAL", 35),
     minit (NULL, -1)
 };
 
@@ -4142,7 +4145,10 @@
 	    }
 	  for (n = ods->clauses->lists[OMP_LIST_LINEAR]; n; n = n->next)
 	    {
-	      mio_name (4, omp_declare_simd_clauses);
+	      if (n->u.linear_op == OMP_LINEAR_DEFAULT)
+		mio_name (4, omp_declare_simd_clauses);
+	      else
+		mio_name (32 + n->u.linear_op, omp_declare_simd_clauses);
 	      mio_symbol_ref (&n->sym);
 	      mio_expr (&n->expr);
 	    }
@@ -4183,11 +4189,20 @@
 	    case 4:
 	    case 5:
 	      *ptrs[t - 3] = n = gfc_get_omp_namelist ();
+	    finish_namelist:
+	      n->where = gfc_current_locus;
 	      ptrs[t - 3] = &n->next;
 	      mio_symbol_ref (&n->sym);
 	      if (t != 3)
 		mio_expr (&n->expr);
 	      break;
+	    case 33:
+	    case 34:
+	    case 35:
+	      *ptrs[1] = n = gfc_get_omp_namelist ();
+	      n->u.linear_op = (enum gfc_omp_linear_op) (t - 32);
+	      t = 4;
+	      goto finish_namelist;
 	    }
 	}
     }
Index: gcc/fortran/trans.c
===================================================================
--- gcc/fortran/trans.c	(.../tags/gcc_8_2_0_release)
+++ gcc/fortran/trans.c	(.../branches/gcc-8-branch)
@@ -407,7 +407,12 @@
   if (vptr)
     span = gfc_vptr_size_get (vptr);
   else if (decl)
-    span = get_array_span (type, decl);
+    {
+      if (TREE_CODE (decl) == COMPONENT_REF)
+	span = gfc_conv_descriptor_span_get (decl);
+      else
+	span = get_array_span (type, decl);
+    }
 
   /* If a non-null span has been generated reference the element with
      pointer arithmetic.  */
Index: gcc/fortran/frontend-passes.c
===================================================================
--- gcc/fortran/frontend-passes.c	(.../tags/gcc_8_2_0_release)
+++ gcc/fortran/frontend-passes.c	(.../branches/gcc-8-branch)
@@ -1099,6 +1099,31 @@
   return 0;
 }
 
+/* Callback function to var_in_expr - return true if expr1 and
+   expr2 are identical variables. */
+static int
+var_in_expr_callback (gfc_expr **e, int *walk_subtrees ATTRIBUTE_UNUSED,
+		      void *data)
+{
+  gfc_expr *expr1 = (gfc_expr *) data;
+  gfc_expr *expr2 = *e;
+
+  if (expr2->expr_type != EXPR_VARIABLE)
+    return 0;
+
+  return expr1->symtree->n.sym == expr2->symtree->n.sym;
+}
+
+/* Return true if expr1 is found in expr2. */
+
+static bool
+var_in_expr (gfc_expr *expr1, gfc_expr *expr2)
+{
+  gcc_assert (expr1->expr_type == EXPR_VARIABLE);
+
+  return gfc_expr_walker (&expr2, var_in_expr_callback, (void *) expr1);
+}
+
 struct do_stack
 {
   struct do_stack *prev;
@@ -1251,9 +1276,9 @@
 	  for (int j = i - 1; j < i; j++)
 	    {
 	      if (iters[j]
-		  && (gfc_check_dependency (var, iters[j]->start, true)
-		      || gfc_check_dependency (var, iters[j]->end, true)
-		      || gfc_check_dependency (var, iters[j]->step, true)))
+		  && (var_in_expr (var, iters[j]->start)
+		      || var_in_expr (var, iters[j]->end)
+		      || var_in_expr (var, iters[j]->step)))
 		  return false;
 	    }		  
 	}
Index: gcc/fortran/resolve.c
===================================================================
--- gcc/fortran/resolve.c	(.../tags/gcc_8_2_0_release)
+++ gcc/fortran/resolve.c	(.../branches/gcc-8-branch)
@@ -8658,6 +8658,14 @@
       if (!sym->ts.u.cl)
 	sym->ts.u.cl = target->ts.u.cl;
 
+      if (sym->ts.deferred && target->expr_type == EXPR_VARIABLE
+	  && target->symtree->n.sym->attr.dummy
+	  && sym->ts.u.cl == target->ts.u.cl)
+	{
+	  sym->ts.u.cl = gfc_new_charlen (sym->ns, NULL);
+	  sym->ts.deferred = 1;
+	}
+
       if (!sym->ts.u.cl->length
 	  && !sym->ts.deferred
 	  && target->expr_type == EXPR_CONSTANT)
@@ -8670,7 +8678,7 @@
 		|| sym->ts.u.cl->length->expr_type != EXPR_CONSTANT)
 		&& target->expr_type != EXPR_VARIABLE)
 	{
-	  sym->ts.u.cl = gfc_get_charlen();
+	  sym->ts.u.cl = gfc_new_charlen (sym->ns, NULL);
 	  sym->ts.deferred = 1;
 
 	  /* This is reset in trans-stmt.c after the assignment
@@ -12050,6 +12058,7 @@
      namespace.  14.6.1.3 of the standard and the discussion on
      comp.lang.fortran.  */
   if (sym->ns != sym->ts.u.derived->ns
+      && !sym->ts.u.derived->attr.use_assoc
       && sym->ns->proc_name->attr.if_source != IFSRC_IFBODY)
     {
       gfc_symbol *s;
@@ -12404,7 +12413,8 @@
     }
 
   /* An elemental function is required to return a scalar 12.7.1  */
-  if (sym->attr.elemental && sym->attr.function && sym->as)
+  if (sym->attr.elemental && sym->attr.function
+      && (sym->as || (sym->ts.type == BT_CLASS && CLASS_DATA (sym)->as)))
     {
       gfc_error ("ELEMENTAL function %qs at %L must have a scalar "
 		 "result", sym->name, &sym->declared_at);
Index: gcc/fortran/trans-decl.c
===================================================================
--- gcc/fortran/trans-decl.c	(.../tags/gcc_8_2_0_release)
+++ gcc/fortran/trans-decl.c	(.../branches/gcc-8-branch)
@@ -1543,6 +1543,13 @@
       /* Dummy variables should already have been created.  */
       gcc_assert (sym->backend_decl);
 
+      /* However, the string length of deferred arrays must be set.  */
+      if (sym->ts.type == BT_CHARACTER
+	  && sym->ts.deferred
+	  && sym->attr.dimension
+	  && sym->attr.allocatable)
+	gfc_defer_symbol_init (sym);
+
       if (sym->attr.pointer && sym->attr.dimension && sym->ts.type != BT_CLASS)
 	GFC_DECL_PTR_ARRAY_P (sym->backend_decl) = 1;
 
Index: gcc/fortran/arith.c
===================================================================
--- gcc/fortran/arith.c	(.../tags/gcc_8_2_0_release)
+++ gcc/fortran/arith.c	(.../branches/gcc-8-branch)
@@ -113,6 +113,11 @@
       p =
 	_("Integer outside symmetric range implied by Standard Fortran at %L");
       break;
+    case ARITH_WRONGCONCAT:
+      p =
+	_("Illegal type in character concatenation at %L");
+      break;
+
     default:
       gfc_internal_error ("gfc_arith_error(): Bad error code");
     }
@@ -982,7 +987,12 @@
   gfc_expr *result;
   size_t len;
 
-  gcc_assert (op1->ts.kind == op2->ts.kind);
+  /* By cleverly playing around with constructors, is is possible
+     to get mismaching types here.  */
+  if (op1->ts.type != BT_CHARACTER || op2->ts.type != BT_CHARACTER
+      || op1->ts.kind != op2->ts.kind)
+    return ARITH_WRONGCONCAT;
+
   result = gfc_get_constant_expr (BT_CHARACTER, op1->ts.kind,
 				  &op1->where);
 
Index: gcc/fortran/simplify.c
===================================================================
--- gcc/fortran/simplify.c	(.../tags/gcc_8_2_0_release)
+++ gcc/fortran/simplify.c	(.../branches/gcc-8-branch)
@@ -5509,54 +5509,57 @@
   gfc_expr *result;
   int kind;
 
-  if (a->expr_type != EXPR_CONSTANT || p->expr_type != EXPR_CONSTANT)
+  /* First check p.  */
+  if (p->expr_type != EXPR_CONSTANT)
     return NULL;
 
-  kind = a->ts.kind > p->ts.kind ? a->ts.kind : p->ts.kind;
-  result = gfc_get_constant_expr (a->ts.type, kind, &a->where);
-
-  switch (a->ts.type)
+  /* p shall not be 0.  */
+  switch (p->ts.type)
     {
       case BT_INTEGER:
 	if (mpz_cmp_ui (p->value.integer, 0) == 0)
 	  {
-	    /* Result is processor-dependent. This processor just opts
-	      to not handle it at all.  */
-	    gfc_error ("Second argument of MODULO at %L is zero", &a->where);
-	    gfc_free_expr (result);
+	    gfc_error ("Argument %qs of MODULO at %L shall not be zero",
+			"P", &p->where);
 	    return &gfc_bad_expr;
 	  }
-	mpz_fdiv_r (result->value.integer, a->value.integer, p->value.integer);
-
 	break;
-
       case BT_REAL:
 	if (mpfr_cmp_ui (p->value.real, 0) == 0)
 	  {
-	    /* Result is processor-dependent.  */
-	    gfc_error ("Second argument of MODULO at %L is zero", &p->where);
-	    gfc_free_expr (result);
+	    gfc_error ("Argument %qs of MODULO at %L shall not be zero",
+			"P", &p->where);
 	    return &gfc_bad_expr;
 	  }
-
-	gfc_set_model_kind (kind);
-	mpfr_fmod (result->value.real, a->value.real, p->value.real,
-		   GFC_RND_MODE);
-	if (mpfr_cmp_ui (result->value.real, 0) != 0)
-	  {
-	    if (mpfr_signbit (a->value.real) != mpfr_signbit (p->value.real))
-	      mpfr_add (result->value.real, result->value.real, p->value.real,
-			GFC_RND_MODE);
-	  }
-	else
-	  mpfr_copysign (result->value.real, result->value.real,
-			 p->value.real, GFC_RND_MODE);
 	break;
-
       default:
 	gfc_internal_error ("gfc_simplify_modulo(): Bad arguments");
     }
 
+  if (a->expr_type != EXPR_CONSTANT)
+    return NULL;
+
+  kind = a->ts.kind > p->ts.kind ? a->ts.kind : p->ts.kind;
+  result = gfc_get_constant_expr (a->ts.type, kind, &a->where);
+
+  if (a->ts.type == BT_INTEGER)
+	mpz_fdiv_r (result->value.integer, a->value.integer, p->value.integer);
+  else
+    {
+      gfc_set_model_kind (kind);
+      mpfr_fmod (result->value.real, a->value.real, p->value.real,
+                 GFC_RND_MODE);
+      if (mpfr_cmp_ui (result->value.real, 0) != 0)
+        {
+          if (mpfr_signbit (a->value.real) != mpfr_signbit (p->value.real))
+            mpfr_add (result->value.real, result->value.real, p->value.real,
+                      GFC_RND_MODE);
+	    }
+	  else
+        mpfr_copysign (result->value.real, result->value.real,
+                       p->value.real, GFC_RND_MODE);
+    }
+
   return range_check (result, "MODULO");
 }
 
Index: gcc/BASE-VER
===================================================================
--- gcc/BASE-VER	(.../tags/gcc_8_2_0_release)
+++ gcc/BASE-VER	(.../branches/gcc-8-branch)
@@ -1 +1 @@
-8.2.0
+8.2.1
Index: gcc/stor-layout.c
===================================================================
--- gcc/stor-layout.c	(.../tags/gcc_8_2_0_release)
+++ gcc/stor-layout.c	(.../branches/gcc-8-branch)
@@ -1685,14 +1685,21 @@
     {
       rli->bitpos = size_binop (PLUS_EXPR, rli->bitpos, DECL_SIZE (field));
 
-      /* If we ended a bitfield before the full length of the type then
-	 pad the struct out to the full length of the last type.  */
-      if ((DECL_CHAIN (field) == NULL
-	   || TREE_CODE (DECL_CHAIN (field)) != FIELD_DECL)
-	  && DECL_BIT_FIELD_TYPE (field)
+      /* If FIELD is the last field and doesn't end at the full length
+	 of the type then pad the struct out to the full length of the
+	 last type.  */
+      if (DECL_BIT_FIELD_TYPE (field)
 	  && !integer_zerop (DECL_SIZE (field)))
-	rli->bitpos = size_binop (PLUS_EXPR, rli->bitpos,
-				  bitsize_int (rli->remaining_in_alignment));
+	{
+	  /* We have to scan, because non-field DECLS are also here.  */
+	  tree probe = field;
+	  while ((probe = DECL_CHAIN (probe)))
+	    if (TREE_CODE (probe) == FIELD_DECL)
+	      break;
+	  if (!probe)
+	    rli->bitpos = size_binop (PLUS_EXPR, rli->bitpos,
+				      bitsize_int (rli->remaining_in_alignment));
+	}
 
       normalize_rli (rli);
     }
Index: gcc/genmatch.c
===================================================================
--- gcc/genmatch.c	(.../tags/gcc_8_2_0_release)
+++ gcc/genmatch.c	(.../branches/gcc-8-branch)
@@ -2680,12 +2680,14 @@
   char match_opname[20];
   match_dop->get_name (match_opname);
   if (value_match)
-    fprintf_indent (f, indent, "if (%s == %s || operand_equal_p (%s, %s, 0))\n",
-		    opname, match_opname, opname, match_opname);
+    fprintf_indent (f, indent, "if ((%s == %s && ! TREE_SIDE_EFFECTS (%s)) "
+		    "|| operand_equal_p (%s, %s, 0))\n",
+		    opname, match_opname, opname, opname, match_opname);
   else
-    fprintf_indent (f, indent, "if (%s == %s || (operand_equal_p (%s, %s, 0) "
+    fprintf_indent (f, indent, "if ((%s == %s && ! TREE_SIDE_EFFECTS (%s)) "
+		    "|| (operand_equal_p (%s, %s, 0) "
 		    "&& types_match (%s, %s)))\n",
-		    opname, match_opname, opname, match_opname,
+		    opname, match_opname, opname, opname, match_opname,
 		    opname, match_opname);
   fprintf_indent (f, indent + 2, "{\n");
   return 1;
Index: gcc/tree-vect-loop.c
===================================================================
--- gcc/tree-vect-loop.c	(.../tags/gcc_8_2_0_release)
+++ gcc/tree-vect-loop.c	(.../branches/gcc-8-branch)
@@ -5558,6 +5558,9 @@
 	  if (STMT_VINFO_VEC_REDUCTION_TYPE (stmt_info)
 	      == INTEGER_INDUC_COND_REDUCTION)
 	    code = induc_code;
+	  else if (STMT_VINFO_VEC_REDUCTION_TYPE (stmt_info)
+		   == CONST_COND_REDUCTION)
+	    code = STMT_VINFO_VEC_CONST_COND_REDUC_CODE (stmt_info);
 	  else
 	    code = MAX_EXPR;
 	}
Index: gcc/gimplify.c
===================================================================
--- gcc/gimplify.c	(.../tags/gcc_8_2_0_release)
+++ gcc/gimplify.c	(.../branches/gcc-8-branch)
@@ -9734,9 +9734,26 @@
 	  t = TREE_VEC_ELT (OMP_FOR_INIT (for_stmt), i);
 	  if (!is_gimple_constant (TREE_OPERAND (t, 1)))
 	    {
+	      tree type = TREE_TYPE (TREE_OPERAND (t, 0));
 	      TREE_OPERAND (t, 1)
 		= get_initialized_tmp_var (TREE_OPERAND (t, 1),
-					   pre_p, NULL, false);
+					   gimple_seq_empty_p (for_pre_body)
+					   ? pre_p : &for_pre_body, NULL,
+					   false);
+	      /* Reference to pointer conversion is considered useless,
+		 but is significant for firstprivate clause.  Force it
+		 here.  */
+	      if (TREE_CODE (type) == POINTER_TYPE
+		  && (TREE_CODE (TREE_TYPE (TREE_OPERAND (t, 1)))
+		      == REFERENCE_TYPE))
+		{
+		  tree v = create_tmp_var (TYPE_MAIN_VARIANT (type));
+		  tree m = build2 (INIT_EXPR, TREE_TYPE (v), v,
+				   TREE_OPERAND (t, 1));
+		  gimplify_and_add (m, gimple_seq_empty_p (for_pre_body)
+				       ? pre_p : &for_pre_body);
+		  TREE_OPERAND (t, 1) = v;
+		}
 	      tree c = build_omp_clause (input_location,
 					 OMP_CLAUSE_FIRSTPRIVATE);
 	      OMP_CLAUSE_DECL (c) = TREE_OPERAND (t, 1);
@@ -9748,11 +9765,26 @@
 	  t = TREE_VEC_ELT (OMP_FOR_COND (for_stmt), i);
 	  if (!is_gimple_constant (TREE_OPERAND (t, 1)))
 	    {
+	      tree type = TREE_TYPE (TREE_OPERAND (t, 0));
 	      TREE_OPERAND (t, 1)
 		= get_initialized_tmp_var (TREE_OPERAND (t, 1),
 					   gimple_seq_empty_p (for_pre_body)
 					   ? pre_p : &for_pre_body, NULL,
 					   false);
+	      /* Reference to pointer conversion is considered useless,
+		 but is significant for firstprivate clause.  Force it
+		 here.  */
+	      if (TREE_CODE (type) == POINTER_TYPE
+		  && (TREE_CODE (TREE_TYPE (TREE_OPERAND (t, 1)))
+		      == REFERENCE_TYPE))
+		{
+		  tree v = create_tmp_var (TYPE_MAIN_VARIANT (type));
+		  tree m = build2 (INIT_EXPR, TREE_TYPE (v), v,
+				   TREE_OPERAND (t, 1));
+		  gimplify_and_add (m, gimple_seq_empty_p (for_pre_body)
+				       ? pre_p : &for_pre_body);
+		  TREE_OPERAND (t, 1) = v;
+		}
 	      tree c = build_omp_clause (input_location,
 					 OMP_CLAUSE_FIRSTPRIVATE);
 	      OMP_CLAUSE_DECL (c) = TREE_OPERAND (t, 1);
Index: gcc/calls.c
===================================================================
--- gcc/calls.c	(.../tags/gcc_8_2_0_release)
+++ gcc/calls.c	(.../branches/gcc-8-branch)
@@ -1627,6 +1627,9 @@
   if (!fndecl || DECL_BUILT_IN_CLASS (fndecl) != BUILT_IN_NORMAL)
     return;
 
+  if (!warn_stringop_overflow)
+    return;
+
   bool with_bounds = CALL_WITH_BOUNDS_P (exp);
 
   unsigned nargs = call_expr_nargs (exp);
@@ -1655,7 +1658,10 @@
 	   conservatively as the bound for the unbounded function,
 	   and to adjust the range of the bound of the bounded ones.  */
 	unsigned stride = with_bounds ? 2 : 1;
-	for (unsigned argno = 0; argno < nargs && !*lenrng; argno += stride)
+	for (unsigned argno = 0;
+	     argno < MIN (nargs, 2 * stride)
+	     && !(lenrng[1] && TREE_CODE (lenrng[1]) == INTEGER_CST);
+	     argno += stride)
 	  {
 	    tree arg = CALL_EXPR_ARG (exp, argno);
 	    if (!get_attr_nonstring_decl (arg))
@@ -1693,11 +1699,9 @@
   if (bound)
     get_size_range (bound, bndrng);
 
-  if (*lenrng)
+  if (lenrng[1] && TREE_CODE (lenrng[1]) == INTEGER_CST)
     {
       /* Add one for the nul.  */
-      lenrng[0] = const_binop (PLUS_EXPR, TREE_TYPE (lenrng[0]),
-			       lenrng[0], size_one_node);
       lenrng[1] = const_binop (PLUS_EXPR, TREE_TYPE (lenrng[1]),
 			       lenrng[1], size_one_node);
 
Index: gcc/expmed.c
===================================================================
--- gcc/expmed.c	(.../tags/gcc_8_2_0_release)
+++ gcc/expmed.c	(.../branches/gcc-8-branch)
@@ -3343,9 +3343,9 @@
 	  /* Write a REG_EQUAL note on the last insn so that we can cse
 	     multiplication sequences.  Note that if ACCUM is a SUBREG,
 	     we've set the inner register and must properly indicate that.  */
-          tem = op0, nmode = mode;
-          accum_inner = accum;
-          if (GET_CODE (accum) == SUBREG)
+	  tem = op0, nmode = mode;
+	  accum_inner = accum;
+	  if (GET_CODE (accum) == SUBREG)
 	    {
 	      accum_inner = SUBREG_REG (accum);
 	      nmode = GET_MODE (accum_inner);
@@ -3352,10 +3352,12 @@
 	      tem = gen_lowpart (nmode, op0);
 	    }
 
-          insn = get_last_insn ();
-          set_dst_reg_note (insn, REG_EQUAL,
-			    gen_rtx_MULT (nmode, tem,
-					  gen_int_mode (val_so_far, nmode)),
+	  insn = get_last_insn ();
+	  wide_int wval_so_far
+	    = wi::uhwi (val_so_far,
+			GET_MODE_PRECISION (as_a <scalar_mode> (nmode)));
+	  rtx c = immed_wide_int_const (wval_so_far, nmode);
+	  set_dst_reg_note (insn, REG_EQUAL, gen_rtx_MULT (nmode, tem, c),
 			    accum_inner);
 	}
     }
@@ -4480,6 +4482,11 @@
 		HOST_WIDE_INT d = INTVAL (op1);
 		unsigned HOST_WIDE_INT abs_d;
 
+		/* Not prepared to handle division/remainder by
+		   0xffffffffffffffff8000000000000000 etc.  */
+		if (d == HOST_WIDE_INT_MIN && size > HOST_BITS_PER_WIDE_INT)
+		  break;
+
 		/* Since d might be INT_MIN, we have to cast to
 		   unsigned HOST_WIDE_INT before negating to avoid
 		   undefined signed overflow.  */
@@ -4522,9 +4529,7 @@
 			     || (optab_handler (sdivmod_optab, int_mode)
 				 != CODE_FOR_nothing)))
 		  ;
-		else if (EXACT_POWER_OF_2_OR_ZERO_P (abs_d)
-			 && (size <= HOST_BITS_PER_WIDE_INT
-			     || abs_d != (unsigned HOST_WIDE_INT) d))
+		else if (EXACT_POWER_OF_2_OR_ZERO_P (abs_d))
 		  {
 		    if (rem_flag)
 		      {
@@ -6038,6 +6043,11 @@
       if (!HAVE_conditional_move)
 	return 0;
 
+      /* Do not turn a trapping comparison into a non-trapping one.  */
+      if ((code != EQ && code != NE && code != UNEQ && code != LTGT)
+	  && flag_trapping_math)
+	return 0;
+
       /* Try using a setcc instruction for ORDERED/UNORDERED, followed by a
 	 conditional move.  */
       tem = emit_store_flag_1 (subtarget, first_code, op0, op1, mode, 0,
Index: gcc/coverage.c
===================================================================
--- gcc/coverage.c	(.../tags/gcc_8_2_0_release)
+++ gcc/coverage.c	(.../branches/gcc-8-branch)
@@ -663,7 +663,8 @@
   gcov_write_unsigned (cfg_checksum);
   gcov_write_string (IDENTIFIER_POINTER
 		     (DECL_ASSEMBLER_NAME (current_function_decl)));
-  gcov_write_unsigned (DECL_ARTIFICIAL (current_function_decl));
+  gcov_write_unsigned (DECL_ARTIFICIAL (current_function_decl)
+		       && !DECL_LAMBDA_FUNCTION (current_function_decl));
   gcov_write_filename (xloc.file);
   gcov_write_unsigned (xloc.line);
   gcov_write_unsigned (xloc.column);
Index: gcc/cfgexpand.c
===================================================================
--- gcc/cfgexpand.c	(.../tags/gcc_8_2_0_release)
+++ gcc/cfgexpand.c	(.../branches/gcc-8-branch)
@@ -1157,6 +1157,20 @@
 	      if (repr_decl == NULL_TREE)
 		repr_decl = stack_vars[i].decl;
 	      data->asan_decl_vec.safe_push (repr_decl);
+
+	      /* Make sure a representative is unpoison if another
+		 variable in the partition is handled by
+		 use-after-scope sanitization.  */
+	      if (asan_handled_variables != NULL
+		  && !asan_handled_variables->contains (repr_decl))
+		{
+		  for (j = i; j != EOC; j = stack_vars[j].next)
+		    if (asan_handled_variables->contains (stack_vars[j].decl))
+		      break;
+		  if (j != EOC)
+		    asan_handled_variables->add (repr_decl);
+		}
+
 	      data->asan_alignb = MAX (data->asan_alignb, alignb);
 	      if (data->asan_base == NULL)
 		data->asan_base = gen_reg_rtx (Pmode);
@@ -1259,10 +1273,10 @@
 	 allocate it, which means that in-frame portion is just a
 	 pointer.  ??? We've got a pseudo for sure here, do we
 	 actually dynamically allocate its spilling area if needed?
-	 ??? Isn't it a problem when POINTER_SIZE also exceeds
-	 MAX_SUPPORTED_STACK_ALIGNMENT, as on cris and lm32?  */
+	 ??? Isn't it a problem when Pmode alignment also exceeds
+	 MAX_SUPPORTED_STACK_ALIGNMENT, as can happen on cris and lm32?  */
       if (align > MAX_SUPPORTED_STACK_ALIGNMENT)
-	align = POINTER_SIZE;
+	align = GET_MODE_ALIGNMENT (Pmode);
 
       record_alignment_for_reg_var (align);
     }
@@ -1383,7 +1397,7 @@
   /* If the variable alignment is very large we'll dynamicaly allocate
      it, which means that in-frame portion is just a pointer.  */
   if (align > MAX_SUPPORTED_STACK_ALIGNMENT)
-    align = POINTER_SIZE;
+    align = GET_MODE_ALIGNMENT (Pmode);
 
   record_alignment_for_reg_var (align);
 
@@ -1610,7 +1624,7 @@
       /* If the variable alignment is very large we'll dynamicaly allocate
 	 it, which means that in-frame portion is just a pointer.  */
       if (align > MAX_SUPPORTED_STACK_ALIGNMENT)
-	align = POINTER_SIZE;
+	align = GET_MODE_ALIGNMENT (Pmode);
     }
 
   record_alignment_for_reg_var (align);
Index: gcc/graphite.h
===================================================================
--- gcc/graphite.h	(.../tags/gcc_8_2_0_release)
+++ gcc/graphite.h	(.../branches/gcc-8-branch)
@@ -37,6 +37,8 @@
 #include <isl/schedule.h>
 #include <isl/ast_build.h>
 #include <isl/schedule_node.h>
+#include <isl/id.h>
+#include <isl/space.h>
 
 typedef struct poly_dr *poly_dr_p;
 
Index: gcc/po/es.po
===================================================================
--- gcc/po/es.po	(.../tags/gcc_8_2_0_release)
+++ gcc/po/es.po	(.../branches/gcc-8-branch)
@@ -41,7 +41,7 @@
 msgstr ""
 "Project-Id-Version: gcc 8.1.0\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2018-05-01 20:30+0000\n"
+"POT-Creation-Date: 2018-07-25 14:25+0000\n"
 "PO-Revision-Date: 2018-07-07 15:54+0200\n"
 "Last-Translator: Antonio Ceballos Roa <aceballos@gmail.com>\n"
 "Language-Team: Spanish <es@tp.org.es>\n"
@@ -73,12 +73,12 @@
 msgid "[cannot find %s]"
 msgstr "[no se puede encontrar %s]"
 
-#: collect2.c:1557
+#: collect2.c:1585
 #, c-format
 msgid "collect2 version %s\n"
 msgstr "collect2 versión %s\n"
 
-#: collect2.c:1664
+#: collect2.c:1692
 #, c-format
 msgid "%d constructor found\n"
 msgid_plural "%d constructors found\n"
@@ -85,7 +85,7 @@
 msgstr[0] "se encontró %d constructor\n"
 msgstr[1] "se encontraron %d constructores\n"
 
-#: collect2.c:1668
+#: collect2.c:1696
 #, c-format
 msgid "%d destructor found\n"
 msgid_plural "%d destructors found\n"
@@ -92,7 +92,7 @@
 msgstr[0] "se encontró %d  destructor\n"
 msgstr[1] "se encontraron %d  destructores\n"
 
-#: collect2.c:1672
+#: collect2.c:1700
 #, c-format
 msgid "%d frame table found\n"
 msgid_plural "%d frame tables found\n"
@@ -100,12 +100,12 @@
 msgstr[1] "se encontraron %d tablas de marco\n"
 
 # %s se refiere a un fichero. cfuga
-#: collect2.c:1836
+#: collect2.c:1864
 #, c-format
 msgid "[Leaving %s]\n"
 msgstr "[Saliendo de %s]\n"
 
-#: collect2.c:2068
+#: collect2.c:2094
 #, c-format
 msgid ""
 "\n"
@@ -114,7 +114,7 @@
 "\n"
 "write_c_file - el nombre de salida es %s, el prefijo es %s\n"
 
-#: collect2.c:2584
+#: collect2.c:2610
 #, c-format
 msgid ""
 "\n"
@@ -137,7 +137,7 @@
 msgid "%s: some warnings being treated as errors"
 msgstr "%s: algunos avisos se tratan como errores"
 
-#: diagnostic.c:324 input.c:222 input.c:1834 c-family/c-opts.c:1377
+#: diagnostic.c:324 input.c:222 input.c:1834 c-family/c-opts.c:1392
 #: fortran/cpp.c:576 fortran/error.c:1008 fortran/error.c:1028
 msgid "<built-in>"
 msgstr "<interno>"
@@ -229,13 +229,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:4164 config/arc/arc.c:5784 config/i386/i386.c:17302
+#: final.c:4164 config/arc/arc.c:5775 config/i386/i386.c:17305
 #: config/pdp11/pdp11.c:1715
 #, c-format
 msgid "floating constant misused"
 msgstr "constante de coma flotante mal usada"
 
-#: final.c:4222 config/arc/arc.c:5881 config/i386/i386.c:17393
+#: final.c:4222 config/arc/arc.c:5872 config/i386/i386.c:17396
 #: config/pdp11/pdp11.c:1756
 #, c-format
 msgid "invalid expression as operand"
@@ -1145,7 +1145,7 @@
 msgid "GCSE disabled"
 msgstr "GCSE desactivado"
 
-#: gimple-ssa-isolate-paths.c:542 c/c-typeck.c:10240
+#: gimple-ssa-isolate-paths.c:542 c/c-typeck.c:10245
 #, gcc-internal-format
 msgid "function returns address of local variable"
 msgstr "la función devuelve la dirección de una variable local"
@@ -1446,7 +1446,7 @@
 msgid "options enabled: "
 msgstr "opciones activadas: "
 
-#: tree-diagnostic.c:299 c/c-decl.c:5419 c/c-typeck.c:7259 cp/error.c:1042
+#: tree-diagnostic.c:299 c/c-decl.c:5439 c/c-typeck.c:7264 cp/error.c:1042
 #: c-family/c-pretty-print.c:413
 #, gcc-internal-format
 msgid "<anonymous>"
@@ -2911,64 +2911,64 @@
 msgstr "modificador de longitud en formato strfmon"
 
 #. Handle deferred options from command-line.
-#: c-family/c-opts.c:1402 fortran/cpp.c:590
+#: c-family/c-opts.c:1417 fortran/cpp.c:590
 msgid "<command-line>"
 msgstr "<línea-de-órdenes>"
 
-#: config/aarch64/aarch64.c:6613
+#: config/aarch64/aarch64.c:6629
 #, c-format
 msgid "unsupported operand for code '%c'"
 msgstr "no se admite el operando para el código '%c'"
 
-#: config/aarch64/aarch64.c:6624 config/aarch64/aarch64.c:6640
-#: config/aarch64/aarch64.c:6652 config/aarch64/aarch64.c:6663
-#: config/aarch64/aarch64.c:6673 config/aarch64/aarch64.c:6694
-#: config/aarch64/aarch64.c:6764 config/aarch64/aarch64.c:6775
-#: config/aarch64/aarch64.c:6789 config/aarch64/aarch64.c:7011
-#: config/aarch64/aarch64.c:7029
+#: config/aarch64/aarch64.c:6640 config/aarch64/aarch64.c:6656
+#: config/aarch64/aarch64.c:6668 config/aarch64/aarch64.c:6679
+#: config/aarch64/aarch64.c:6689 config/aarch64/aarch64.c:6710
+#: config/aarch64/aarch64.c:6780 config/aarch64/aarch64.c:6791
+#: config/aarch64/aarch64.c:6805 config/aarch64/aarch64.c:7027
+#: config/aarch64/aarch64.c:7045
 #, c-format
 msgid "invalid operand for '%%%c'"
 msgstr "operando no válido para '%%%c'"
 
-#: config/aarch64/aarch64.c:6709 config/aarch64/aarch64.c:6720
-#: config/aarch64/aarch64.c:6871 config/aarch64/aarch64.c:6882
+#: config/aarch64/aarch64.c:6725 config/aarch64/aarch64.c:6736
+#: config/aarch64/aarch64.c:6887 config/aarch64/aarch64.c:6898
 #, c-format
 msgid "invalid vector constant"
 msgstr "constante de vector no válida"
 
-#: config/aarch64/aarch64.c:6732 config/aarch64/aarch64.c:6744
-#: config/aarch64/aarch64.c:6755
+#: config/aarch64/aarch64.c:6748 config/aarch64/aarch64.c:6760
+#: config/aarch64/aarch64.c:6771
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr "coma flotante incompatible / operando de registro de vector para '%%%c'"
 
-#: config/aarch64/aarch64.c:6823 config/arm/arm.c:22704
+#: config/aarch64/aarch64.c:6839 config/arm/arm.c:22704
 #, c-format
 msgid "missing operand"
 msgstr "falta un operando"
 
-#: config/aarch64/aarch64.c:6908
+#: config/aarch64/aarch64.c:6924
 #, c-format
 msgid "invalid constant"
 msgstr "constante no válida"
 
-#: config/aarch64/aarch64.c:6911
+#: config/aarch64/aarch64.c:6927
 #, c-format
 msgid "invalid operand"
 msgstr "operando no válido"
 
-#: config/aarch64/aarch64.c:7040 config/aarch64/aarch64.c:7045
+#: config/aarch64/aarch64.c:7056 config/aarch64/aarch64.c:7061
 #, c-format
 msgid "invalid operand prefix '%%%c'"
 msgstr "prefijo de operando no válido '%%%c'"
 
-#: config/aarch64/aarch64.c:7062
+#: config/aarch64/aarch64.c:7078
 #, c-format
 msgid "invalid address mode"
 msgstr "modo de direccionamiento no válido"
 
-#: config/alpha/alpha.c:5125 config/i386/i386.c:18558
-#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21798
+#: config/alpha/alpha.c:5125 config/i386/i386.c:18561
+#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21875
 #: config/sparc/sparc.c:9290
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
@@ -2985,7 +2985,7 @@
 msgstr "valor %%r no válido"
 
 #: config/alpha/alpha.c:5223 config/ia64/ia64.c:5534
-#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21506
+#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21583
 #: config/xtensa/xtensa.c:2429
 #, c-format
 msgid "invalid %%R value"
@@ -2992,13 +2992,13 @@
 msgstr "valor %%R no válido"
 
 #: config/alpha/alpha.c:5229 config/powerpcspe/powerpcspe.c:23933
-#: config/rs6000/rs6000.c:21426 config/xtensa/xtensa.c:2396
+#: config/rs6000/rs6000.c:21503 config/xtensa/xtensa.c:2396
 #, c-format
 msgid "invalid %%N value"
 msgstr "valor %%N no válido"
 
 #: config/alpha/alpha.c:5237 config/powerpcspe/powerpcspe.c:23961
-#: config/rs6000/rs6000.c:21454
+#: config/rs6000/rs6000.c:21531
 #, c-format
 msgid "invalid %%P value"
 msgstr "valor %%P no válido"
@@ -3029,7 +3029,7 @@
 msgstr "valor %%U no válido"
 
 #: config/alpha/alpha.c:5323 config/powerpcspe/powerpcspe.c:24021
-#: config/rs6000/rs6000.c:21514
+#: config/rs6000/rs6000.c:21591
 #, c-format
 msgid "invalid %%s value"
 msgstr "valor %%s no válido"
@@ -3040,7 +3040,7 @@
 msgstr "valor %%C no válido"
 
 #: config/alpha/alpha.c:5371 config/powerpcspe/powerpcspe.c:23797
-#: config/rs6000/rs6000.c:21290
+#: config/rs6000/rs6000.c:21367
 #, c-format
 msgid "invalid %%E value"
 msgstr "valor %%E no válido"
@@ -3051,7 +3051,7 @@
 msgstr "reubicación unspec desconocida"
 
 #: config/alpha/alpha.c:5405 config/cr16/cr16.c:1569
-#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21803
+#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21880
 #: config/spu/spu.c:1458
 #, c-format
 msgid "invalid %%xn code"
@@ -3062,57 +3062,57 @@
 msgid "invalid operand address"
 msgstr "dirección de operando no válida"
 
-#: config/arc/arc.c:3810
+#: config/arc/arc.c:3808
 #, c-format
 msgid "invalid operand to %%Z code"
 msgstr "operando no válido para el código %%Z"
 
-#: config/arc/arc.c:3818
+#: config/arc/arc.c:3816
 #, c-format
 msgid "invalid operand to %%z code"
 msgstr "operando no válido para el código %%z"
 
-#: config/arc/arc.c:3826
+#: config/arc/arc.c:3824
 #, c-format
 msgid "invalid operands to %%c code"
 msgstr "operandos no válidos para el código %%c"
 
-#: config/arc/arc.c:3834
+#: config/arc/arc.c:3832
 #, c-format
 msgid "invalid operand to %%M code"
 msgstr "operando no válido para el código %%M"
 
-#: config/arc/arc.c:3842 config/m32r/m32r.c:2100
+#: config/arc/arc.c:3840 config/m32r/m32r.c:2100
 #, c-format
 msgid "invalid operand to %%p code"
 msgstr "operador no válido para el código %%p"
 
-#: config/arc/arc.c:3853 config/m32r/m32r.c:2093
+#: config/arc/arc.c:3851 config/m32r/m32r.c:2093
 #, c-format
 msgid "invalid operand to %%s code"
 msgstr "operando no válido para el código %%s"
 
-#: config/arc/arc.c:4001 config/m32r/m32r.c:2126
+#: config/arc/arc.c:3999 config/m32r/m32r.c:2126
 #, c-format
 msgid "invalid operand to %%R code"
 msgstr "operando no válido para el código %%R"
 
-#: config/arc/arc.c:4077 config/m32r/m32r.c:2149
+#: config/arc/arc.c:4075 config/m32r/m32r.c:2149
 #, c-format
 msgid "invalid operand to %%H/%%L code"
 msgstr "operando no válido para el código %%H%%L"
 
-#: config/arc/arc.c:4145 config/m32r/m32r.c:2220
+#: config/arc/arc.c:4143 config/m32r/m32r.c:2220
 #, c-format
 msgid "invalid operand to %%U code"
 msgstr "operando no válido para el código %%U"
 
-#: config/arc/arc.c:4157
+#: config/arc/arc.c:4155
 #, c-format
 msgid "invalid operand to %%V code"
 msgstr "operando no válido para el código %%V"
 
-#: config/arc/arc.c:4214
+#: config/arc/arc.c:4212
 #, c-format
 msgid "invalid operand to %%O code"
 msgstr "operando no válido para el código %%O"
@@ -3119,18 +3119,18 @@
 
 #. Unknown flag.
 #. Undocumented flag.
-#: config/arc/arc.c:4240 config/epiphany/epiphany.c:1305
-#: config/m32r/m32r.c:2247 config/nds32/nds32.c:3079 config/sparc/sparc.c:9569
+#: config/arc/arc.c:4238 config/epiphany/epiphany.c:1305
+#: config/m32r/m32r.c:2247 config/nds32/nds32.c:3080 config/sparc/sparc.c:9569
 #, c-format
 msgid "invalid operand output code"
 msgstr "operando no válido en el código de salida"
 
-#: config/arc/arc.c:5869
+#: config/arc/arc.c:5860
 #, c-format
 msgid "invalid UNSPEC as operand: %d"
 msgstr "UNSPEC no válido como operando: %d"
 
-#: config/arc/arc.c:6158 config/cris/cris.c:2568
+#: config/arc/arc.c:6149 config/cris/cris.c:2568
 msgid "unrecognized supposed constant"
 msgstr "no se reconoce la constante supuesta"
 
@@ -3165,7 +3165,7 @@
 #: config/arm/arm.c:22685 config/arm/arm.c:22692 config/bfin/bfin.c:1441
 #: config/bfin/bfin.c:1448 config/bfin/bfin.c:1455 config/bfin/bfin.c:1462
 #: config/bfin/bfin.c:1471 config/bfin/bfin.c:1478 config/bfin/bfin.c:1485
-#: config/bfin/bfin.c:1492 config/nds32/nds32.c:3098
+#: config/bfin/bfin.c:1492 config/nds32/nds32.c:3099
 #, c-format
 msgid "invalid operand for code '%c'"
 msgstr "operando no válido para el código '%c'"
@@ -3506,98 +3506,98 @@
 msgid "bad output_condmove_single operand"
 msgstr "operando output_condmove_single erróneo"
 
-#: config/i386/i386.c:17387
+#: config/i386/i386.c:17390
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "UNSPEC no válido como operando"
 
-#: config/i386/i386.c:17925
+#: config/i386/i386.c:17928
 #, c-format
 msgid "invalid use of register '%s'"
 msgstr "uso no válido del registro '%s'"
 
-#: config/i386/i386.c:17930
+#: config/i386/i386.c:17933
 #, c-format
 msgid "invalid use of asm flag output"
 msgstr "tipo no válido de la salida del indicador asm"
 
-#: config/i386/i386.c:18160
+#: config/i386/i386.c:18163
 #, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr "tamaño de operando no válido para el código de operando 'O'"
 
-#: config/i386/i386.c:18195
+#: config/i386/i386.c:18198
 #, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr "tamaño de operando no válido para el código de operando 'z'"
 
-#: config/i386/i386.c:18264
+#: config/i386/i386.c:18267
 #, c-format
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "se usó un tipo de operando no válido con el código de operando 'Z'"
 
-#: config/i386/i386.c:18269
+#: config/i386/i386.c:18272
 #, c-format
 msgid "invalid operand size for operand code 'Z'"
 msgstr "tamaño de operando no válido para el código de operando 'Z'"
 
-#: config/i386/i386.c:18346
+#: config/i386/i386.c:18349
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "el operando no es un código de condición, código de operando 'Y' no válido"
 
-#: config/i386/i386.c:18425
+#: config/i386/i386.c:18428
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "el operando no es un código de condición, código de operando 'D' no válido"
 
-#: config/i386/i386.c:18443
+#: config/i386/i386.c:18446
 #, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "el operando no es un código de condición, código de operando '%c' no válido"
 
-#: config/i386/i386.c:18456
+#: config/i386/i386.c:18459
 #, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "el operando no es una referencia de memoria desplazable, código de operando 'H' no válido"
 
-#: config/i386/i386.c:18471
+#: config/i386/i386.c:18474
 #, c-format
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr "el operando no es un entero, código de operando 'K' no válido"
 
-#: config/i386/i386.c:18499
+#: config/i386/i386.c:18502
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr "el operando no es un entero concreto, código de operando 'r' no válido"
 
-#: config/i386/i386.c:18517
+#: config/i386/i386.c:18520
 #, c-format
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr "el operando no es un entero, código de operando 'R' no válido"
 
-#: config/i386/i386.c:18540
+#: config/i386/i386.c:18543
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "el operando no es un entero concreto, código de operando 'R' no válido"
 
-#: config/i386/i386.c:18626
+#: config/i386/i386.c:18629
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "código de operando '%c' no válido"
 
-#: config/i386/i386.c:18688
+#: config/i386/i386.c:18691
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "restricciones no válidas para el operando"
 
-#: config/i386/i386.c:18738
+#: config/i386/i386.c:18741
 #, fuzzy, c-format
 #| msgid "invalid vector constant"
 msgid "invalid vector immediate"
 msgstr "constante de vector no válida"
 
-#: config/i386/i386.c:29572
+#: config/i386/i386.c:29575
 msgid "unknown insn mode"
 msgstr "modo insn desconocido"
 
@@ -3635,7 +3635,7 @@
 msgstr "operando %%P no válido"
 
 #: config/iq2000/iq2000.c:3185 config/powerpcspe/powerpcspe.c:23951
-#: config/rs6000/rs6000.c:21444
+#: config/rs6000/rs6000.c:21521
 #, c-format
 msgid "invalid %%p value"
 msgstr "valor %%p no válido"
@@ -3689,7 +3689,7 @@
 msgstr "la dirección de post-incremento no es un registro"
 
 #: config/m32r/m32r.c:2350 config/m32r/m32r.c:2365
-#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33292
+#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33348
 msgid "bad address"
 msgstr "dirección errónea"
 
@@ -3808,185 +3808,185 @@
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr "Pruebe ejecutar '%s' en el intérprete de órdenes para elevar su límite.\n"
 
-#: config/powerpcspe/powerpcspe.c:4411 config/rs6000/rs6000.c:4258
+#: config/powerpcspe/powerpcspe.c:4411 config/rs6000/rs6000.c:4278
 msgid "-maltivec=le not allowed for big-endian targets"
 msgstr "-maltivec=le no permitida para destinos big-endian"
 
-#: config/powerpcspe/powerpcspe.c:4423 config/rs6000/rs6000.c:4273
+#: config/powerpcspe/powerpcspe.c:4423 config/rs6000/rs6000.c:4293
 msgid "-mvsx requires hardware floating point"
 msgstr "-mvsx requiere coma flotante de hardware"
 
-#: config/powerpcspe/powerpcspe.c:4431 config/rs6000/rs6000.c:4281
+#: config/powerpcspe/powerpcspe.c:4431 config/rs6000/rs6000.c:4301
 msgid "-mvsx and -mpaired are incompatible"
 msgstr "-mvsx y -mpaired son incompatibles"
 
-#: config/powerpcspe/powerpcspe.c:4433 config/rs6000/rs6000.c:4283
+#: config/powerpcspe/powerpcspe.c:4433 config/rs6000/rs6000.c:4303
 msgid "-mvsx needs indexed addressing"
 msgstr "-mvsx necesita direccionamiento indizado"
 
-#: config/powerpcspe/powerpcspe.c:4438 config/rs6000/rs6000.c:4288
+#: config/powerpcspe/powerpcspe.c:4438 config/rs6000/rs6000.c:4308
 msgid "-mvsx and -mno-altivec are incompatible"
 msgstr "-mvsx y -mno-altivec son incompatibles"
 
-#: config/powerpcspe/powerpcspe.c:4440 config/rs6000/rs6000.c:4290
+#: config/powerpcspe/powerpcspe.c:4440 config/rs6000/rs6000.c:4310
 msgid "-mno-altivec disables vsx"
 msgstr "-mno-altivec desactiva vsx"
 
-#: config/powerpcspe/powerpcspe.c:4648 config/rs6000/rs6000.c:4416
+#: config/powerpcspe/powerpcspe.c:4648 config/rs6000/rs6000.c:4436
 msgid "-mquad-memory requires 64-bit mode"
 msgstr "-mquad-memory requiere modo de 64 bits"
 
-#: config/powerpcspe/powerpcspe.c:4651 config/rs6000/rs6000.c:4419
+#: config/powerpcspe/powerpcspe.c:4651 config/rs6000/rs6000.c:4439
 msgid "-mquad-memory-atomic requires 64-bit mode"
 msgstr "-mquad-memory-atomic requiere modo de 64 bits"
 
-#: config/powerpcspe/powerpcspe.c:4663 config/rs6000/rs6000.c:4431
+#: config/powerpcspe/powerpcspe.c:4663 config/rs6000/rs6000.c:4451
 msgid "-mquad-memory is not available in little endian mode"
 msgstr "-mquad-memory no está disponible en modo little endian"
 
-#: config/powerpcspe/powerpcspe.c:4735 config/rs6000/rs6000.c:4512
+#: config/powerpcspe/powerpcspe.c:4735 config/rs6000/rs6000.c:4532
 msgid "-mtoc-fusion requires 64-bit"
 msgstr "-mtoc-fusion requiere 64 bits"
 
-#: config/powerpcspe/powerpcspe.c:4742 config/rs6000/rs6000.c:4519
+#: config/powerpcspe/powerpcspe.c:4742 config/rs6000/rs6000.c:4539
 msgid "-mtoc-fusion requires medium/large code model"
 msgstr "-mtoc-fusion requiere modelo de código medio/grande"
 
-#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10915
+#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10947
 msgid "bad move"
 msgstr "move erróneo"
 
-#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21087
+#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21164
 msgid "Bad 128-bit move"
 msgstr "Movimiento de 128 bits erróneo"
 
-#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21278
+#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21355
 #, c-format
 msgid "invalid %%e value"
 msgstr "valor %%e no válido"
 
-#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21299
+#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21376
 #, c-format
 msgid "invalid %%f value"
 msgstr "valor %%f no válido"
 
-#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21308
+#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21385
 #, c-format
 msgid "invalid %%F value"
 msgstr "valor %%F no válido"
 
-#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21317
+#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21394
 #, c-format
 msgid "invalid %%G value"
 msgstr "valor %%G no válido"
 
-#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21352
+#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21429
 #, c-format
 msgid "invalid %%j code"
 msgstr "código %%j no válido"
 
-#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21362
+#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21439
 #, c-format
 msgid "invalid %%J code"
 msgstr "código %%J no válido"
 
-#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21372
+#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21449
 #, c-format
 msgid "invalid %%k value"
 msgstr "valor %%k no válido"
 
-#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21387
+#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21464
 #: config/xtensa/xtensa.c:2415
 #, c-format
 msgid "invalid %%K value"
 msgstr "valor %%K no válido"
 
-#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21434
+#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21511
 #, c-format
 msgid "invalid %%O value"
 msgstr "valor %%O no válido"
 
-#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21481
+#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21558
 #, c-format
 msgid "invalid %%q value"
 msgstr "valor %%q no válido"
 
-#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21534
+#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21611
 #, c-format
 msgid "invalid %%T value"
 msgstr "valor %%T no válido"
 
-#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21546
+#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21623
 #, c-format
 msgid "invalid %%u value"
 msgstr "valor %%u no válido"
 
-#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21560
+#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21637
 #: config/xtensa/xtensa.c:2384
 #, c-format
 msgid "invalid %%v value"
 msgstr "valor %%v no válido"
 
-#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21627
+#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21704
 #: config/xtensa/xtensa.c:2436
 #, c-format
 msgid "invalid %%x value"
 msgstr "valor %%x no válido"
 
-#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21747
+#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21824
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "valor %%y no válido, pruebe usando la restricción 'Z'"
 
-#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22282
+#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22359
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr "__float128 y __ibm128 no pueden utilizarse en la misma expresión"
 
-#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22288
+#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22365
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr "__ibm128 y long double no pueden utilizarse en la misma expresión"
 
-#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22294
+#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22371
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr "__float128 y long double no pueden utilizarse en la misma expresión"
 
-#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36572
+#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36628
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "Se pasó un argumento Altivec a una función sin prototipo"
 
-#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38739
+#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38795
 msgid "Could not generate addis value for fusion"
 msgstr "No se ha podido generar valor addis para fusión"
 
-#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38809
+#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38865
 msgid "Unable to generate load/store offset for fusion"
 msgstr "No se puede generar desplazamiento de carga/almacenamiento para fusión"
 
-#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38908
+#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38964
 msgid "Bad GPR fusion"
 msgstr "Fusión GPR errónea"
 
-#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39126
+#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39182
 msgid "emit_fusion_p9_load, bad reg #1"
 msgstr "emit_fusion_p9_load, reg #1 erróneo"
 
-#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39172
+#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39228
 msgid "emit_fusion_p9_load, bad reg #2"
 msgstr "emit_fusion_p9_load, reg #2 erróneo"
 
-#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39175
+#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39231
 msgid "emit_fusion_p9_load not MEM"
 msgstr "emit_fusion_p9_load no MEM"
 
-#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39213
+#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39269
 msgid "emit_fusion_p9_store, bad reg #1"
 msgstr "emit_fusion_p9_store, reg #1 erróneo"
 
-#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39259
+#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39315
 msgid "emit_fusion_p9_store, bad reg #2"
 msgstr "emit_fusion_p9_store, reg #2 erróneo"
 
-#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39262
+#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39318
 msgid "emit_fusion_p9_store not MEM"
 msgstr "emit_fusion_p9_store no MEM"
 
@@ -4363,14 +4363,14 @@
 #: c/gimple-parser.c:188 c/gimple-parser.c:197 c/gimple-parser.c:226
 #: c/gimple-parser.c:1375 c/gimple-parser.c:1404 c/gimple-parser.c:1484
 #: c/gimple-parser.c:1511 c/c-parser.c:3204 c/c-parser.c:9967
-#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27841
-#: cp/parser.c:28430
+#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27838
+#: cp/parser.c:28427
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "se esperaba %<;%>"
 
 #: c/c-parser.c:2431 c/c-parser.c:7573 c/c-parser.c:8015 c/c-parser.c:8058
-#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27839 cp/parser.c:28448
+#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27836 cp/parser.c:28445
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "se esperaba %<,%>"
@@ -4385,7 +4385,7 @@
 #: c/gimple-parser.c:821 c/gimple-parser.c:837 c/gimple-parser.c:853
 #: c/gimple-parser.c:880 c/gimple-parser.c:915 c/gimple-parser.c:1038
 #: c/gimple-parser.c:1209 c/gimple-parser.c:1220 c/gimple-parser.c:1342
-#: c/gimple-parser.c:1441 cp/parser.c:28478
+#: c/gimple-parser.c:1441 cp/parser.c:28475
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "se esperaba %<)%>"
@@ -4393,7 +4393,7 @@
 #: c/c-parser.c:3824 c/c-parser.c:4733 c/c-parser.c:4769 c/c-parser.c:6441
 #: c/c-parser.c:8125 c/c-parser.c:8983 c/c-parser.c:9127 c/c-parser.c:11588
 #: c/c-parser.c:18220 c/c-parser.c:18222 c/gimple-parser.c:1015
-#: cp/parser.c:28442
+#: cp/parser.c:28439
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "se esperaba %<]%>"
@@ -4407,7 +4407,7 @@
 #: c/c-parser.c:17792 c/gimple-parser.c:363 c/gimple-parser.c:811
 #: c/gimple-parser.c:873 c/gimple-parser.c:911 c/gimple-parser.c:1198
 #: c/gimple-parser.c:1339 c/gimple-parser.c:1438 c/c-parser.c:11911
-#: cp/parser.c:28433
+#: cp/parser.c:28430
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "se esperaba %<(%>"
@@ -4414,7 +4414,7 @@
 
 #: c/c-parser.c:4903 c/c-parser.c:10310 c/c-parser.c:16212 c/c-parser.c:18449
 #: c/gimple-parser.c:141 c/gimple-parser.c:1444 c/c-parser.c:3018
-#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18155 cp/parser.c:28439
+#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18152 cp/parser.c:28436
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "se esperaba %<{%>"
@@ -4424,13 +4424,13 @@
 #: c/c-parser.c:12351 c/c-parser.c:12493 c/c-parser.c:12864 c/c-parser.c:12957
 #: c/c-parser.c:13566 c/c-parser.c:17636 c/c-parser.c:17695
 #: c/gimple-parser.c:431 c/gimple-parser.c:1492 c/gimple-parser.c:1519
-#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28472 cp/parser.c:29597
-#: cp/parser.c:32279
+#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28469 cp/parser.c:29594
+#: cp/parser.c:32276
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "se esperaba %<:%>"
 
-#: c/c-parser.c:5974 cp/parser.c:28365
+#: c/c-parser.c:5974 cp/parser.c:28362
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "se esperaba %<while%>"
@@ -4439,18 +4439,18 @@
 msgid "expected %<.%>"
 msgstr "se esperaba %<.%>"
 
-#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30172
-#: cp/parser.c:30246
+#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30169
+#: cp/parser.c:30243
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "se esperaba %<@end%>"
 
-#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28457
+#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28454
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "se esperaba %<>%>"
 
-#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28481
+#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28478
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "se esperaba %<,%> o %<)%>"
@@ -4458,32 +4458,32 @@
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15190 c/c-parser.c:15234 c/c-parser.c:15466 c/c-parser.c:15701
 #: c/c-parser.c:17833 c/gimple-parser.c:286 c/c-parser.c:4792
-#: cp/parser.c:28460
+#: cp/parser.c:28457
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "se esperaba %<=%>"
 
-#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28436
-#: cp/parser.c:30389
+#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28433
+#: cp/parser.c:30386
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "se esperaba %<}%>"
 
-#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35674
+#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35671
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "se esperaba %<#pragma omp section%> o %<}%>"
 
-#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28445 cp/parser.c:31535
+#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28442 cp/parser.c:31532
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "se esperaba %<[%>"
 
-#: c/c-typeck.c:7847
+#: c/c-typeck.c:7852
 msgid "(anonymous)"
 msgstr "(anónimo)"
 
-#: c/gimple-parser.c:795 cp/parser.c:15791 cp/parser.c:28454
+#: c/gimple-parser.c:795 cp/parser.c:15788 cp/parser.c:28451
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "se esperaba %<<%>"
@@ -4739,11 +4739,11 @@
 msgid "%r%s:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr "%r%s:%d:%R   en la expansión de la %<constexpr%> de %qs"
 
-#: cp/pt.c:1949 cp/semantics.c:5268
+#: cp/pt.c:1949 cp/semantics.c:5271
 msgid "candidates are:"
 msgstr "los candidatos son:"
 
-#: cp/pt.c:1951 cp/pt.c:22975
+#: cp/pt.c:1951 cp/pt.c:23053
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "el candidato es:"
@@ -4789,27 +4789,27 @@
 msgid "source type is not polymorphic"
 msgstr "el tipo fuente no es polimórfico"
 
-#: cp/typeck.c:6083 c/c-typeck.c:4261
+#: cp/typeck.c:6083 c/c-typeck.c:4266
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "argumento de tipo erróneo para el decremento unario"
 
-#: cp/typeck.c:6084 c/c-typeck.c:4248
+#: cp/typeck.c:6084 c/c-typeck.c:4253
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "argumento de tipo erróneo para el incremento unario"
 
-#: cp/typeck.c:6111 c/c-typeck.c:4302
+#: cp/typeck.c:6111 c/c-typeck.c:4307
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "argumento de tipo erróneo para complemento de bits"
 
-#: cp/typeck.c:6128 c/c-typeck.c:4310
+#: cp/typeck.c:6128 c/c-typeck.c:4315
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "argumento de tipo erróneo para abs"
 
-#: cp/typeck.c:6140 c/c-typeck.c:4322
+#: cp/typeck.c:6140 c/c-typeck.c:4327
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "argumento de tipo erróneo para la conjugación"
@@ -5049,67 +5049,67 @@
 msgid "Expected attribute bit name"
 msgstr "Se esperaba un nombre de atributo de bit"
 
-#: fortran/module.c:3223
+#: fortran/module.c:3225
 msgid "Expected integer string"
 msgstr "Se esperaba una cadena entera"
 
-#: fortran/module.c:3227
+#: fortran/module.c:3229
 msgid "Error converting integer"
 msgstr "Error al convertir el entero"
 
-#: fortran/module.c:3249
+#: fortran/module.c:3251
 msgid "Expected real string"
 msgstr "Se esperaba una cadena real"
 
-#: fortran/module.c:3474
+#: fortran/module.c:3476
 msgid "Expected expression type"
 msgstr "Se esperaba un tipo de expresión"
 
-#: fortran/module.c:3554
+#: fortran/module.c:3556
 msgid "Bad operator"
 msgstr "Operador erróneo"
 
-#: fortran/module.c:3671
+#: fortran/module.c:3673
 msgid "Bad type in constant expression"
 msgstr "Tipo erróneo en la expresión constante"
 
-#: fortran/module.c:7038
+#: fortran/module.c:7040
 msgid "Unexpected end of module"
 msgstr "Fin de módulo inesperado"
 
-#: fortran/parse.c:1757
+#: fortran/parse.c:1761
 msgid "arithmetic IF"
 msgstr "IF aritmético"
 
-#: fortran/parse.c:1766
+#: fortran/parse.c:1770
 msgid "attribute declaration"
 msgstr "declaración de atributo"
 
-#: fortran/parse.c:1802
+#: fortran/parse.c:1806
 msgid "data declaration"
 msgstr "declaración de datos"
 
-#: fortran/parse.c:1820
+#: fortran/parse.c:1824
 msgid "derived type declaration"
 msgstr "declaración de tipo derivado"
 
-#: fortran/parse.c:1947
+#: fortran/parse.c:1951
 msgid "block IF"
 msgstr "bloque IF"
 
-#: fortran/parse.c:1956
+#: fortran/parse.c:1960
 msgid "implied END DO"
 msgstr "END DO implícito"
 
-#: fortran/parse.c:2050 fortran/resolve.c:11199
+#: fortran/parse.c:2054 fortran/resolve.c:11219
 msgid "assignment"
 msgstr "asignación"
 
-#: fortran/parse.c:2053 fortran/resolve.c:11250 fortran/resolve.c:11253
+#: fortran/parse.c:2057 fortran/resolve.c:11270 fortran/resolve.c:11273
 msgid "pointer assignment"
 msgstr "asignación de puntero"
 
-#: fortran/parse.c:2071
+#: fortran/parse.c:2075
 msgid "simple IF"
 msgstr "IF simple"
 
@@ -5201,106 +5201,112 @@
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr "El operando del operador numérico unitario %%<%s%%> en %%L es %s"
 
-#: fortran/resolve.c:3878
+#: fortran/resolve.c:3879
+#, fuzzy, c-format
+#| msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
+msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
+msgstr "Los operandos del operador numérico binario %%<%s%%> en %%L son %s/%s"
+
+#: fortran/resolve.c:3884
 #, c-format
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr "Los operandos del operador numérico binario %%<%s%%> en %%L son %s/%s"
 
-#: fortran/resolve.c:3893
+#: fortran/resolve.c:3899
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr "Los operandos del operador de concatenación de cadenas en %%L son %s/%s"
 
-#: fortran/resolve.c:3926
+#: fortran/resolve.c:3932
 #, c-format
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr "Los operandos del operador lógico %%<%s%%> en %%L son %s/%s"
 
-#: fortran/resolve.c:3949
+#: fortran/resolve.c:3955
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr "El operando del operador .not. en %%L es %s"
 
-#: fortran/resolve.c:3963
+#: fortran/resolve.c:3969
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "Las cantidades COMPLEX no se pueden comparar en %L"
 
-#: fortran/resolve.c:4015
+#: fortran/resolve.c:4021
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr "Los lógicos en %%L se deben comparar con %s en lugar de %s"
 
-#: fortran/resolve.c:4021
+#: fortran/resolve.c:4027
 #, c-format
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr "Los operandos del operador de comparación %%<%s%%> en %%L son %s/%s"
 
-#: fortran/resolve.c:4034
+#: fortran/resolve.c:4040
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L; did you mean '%s'?"
 msgstr "Operador %%<%s%%> desconocido en %%L; ¿quiso decir '%s'?"
 
-#: fortran/resolve.c:4037
+#: fortran/resolve.c:4043
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr "Operador %%<%s%%> desconocido en %%L"
 
-#: fortran/resolve.c:4040
+#: fortran/resolve.c:4046
 #, c-format
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr "El operando del operador de usuario %%<%s%%>  en %%L es %s"
 
-#: fortran/resolve.c:4044
+#: fortran/resolve.c:4050
 #, c-format
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr "Los operandos del operador de usuario %%<%s%%> en %%L son %s/%s"
 
-#: fortran/resolve.c:4132
+#: fortran/resolve.c:4138
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "Rangos inconsistentes para el operador en %%L y %%L"
 
-#: fortran/resolve.c:6849
+#: fortran/resolve.c:6855
 msgid "Loop variable"
 msgstr "Variable de ciclo"
 
-#: fortran/resolve.c:6853
+#: fortran/resolve.c:6859
 msgid "iterator variable"
 msgstr "variable de iterador"
 
-#: fortran/resolve.c:6857
+#: fortran/resolve.c:6863
 msgid "Start expression in DO loop"
 msgstr "Expresión de inicio en el bucle DO"
 
-#: fortran/resolve.c:6861
+#: fortran/resolve.c:6867
 msgid "End expression in DO loop"
 msgstr "Expresión de fin en el bucle DO"
 
-#: fortran/resolve.c:6865
+#: fortran/resolve.c:6871
 msgid "Step expression in DO loop"
 msgstr "Expresión de paso en el bucle DO"
 
-#: fortran/resolve.c:7150 fortran/resolve.c:7153
+#: fortran/resolve.c:7156 fortran/resolve.c:7159
 msgid "DEALLOCATE object"
 msgstr "objeto DEALLOCATE"
 
-#: fortran/resolve.c:7525 fortran/resolve.c:7528
+#: fortran/resolve.c:7531 fortran/resolve.c:7534
 msgid "ALLOCATE object"
 msgstr "objeto ALLOCATE"
 
-#: fortran/resolve.c:7720 fortran/resolve.c:9417
+#: fortran/resolve.c:7726 fortran/resolve.c:9428
 msgid "STAT variable"
 msgstr "variable STAT"
 
-#: fortran/resolve.c:7764 fortran/resolve.c:9429
+#: fortran/resolve.c:7770 fortran/resolve.c:9440
 msgid "ERRMSG variable"
 msgstr "variable ERRMSG"
 
-#: fortran/resolve.c:9219
+#: fortran/resolve.c:9230
 msgid "item in READ"
 msgstr "elemento en READ"
 
-#: fortran/resolve.c:9441
+#: fortran/resolve.c:9452
 msgid "ACQUIRED_LOCK variable"
 msgstr "variable ACQUIRED_LOCK"
 
@@ -5333,7 +5339,7 @@
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr "El objetivo del remapeo de rango es demasiado pequeño (%ld < %ld)"
 
-#: fortran/trans-expr.c:10154
+#: fortran/trans-expr.c:10157
 msgid "Assignment of scalar to unallocated array"
 msgstr "Asignación de escalar a un array sin espacio asignado"
 
@@ -5342,12 +5348,12 @@
 msgid "Unequal character lengths (%ld/%ld) in %s"
 msgstr "Longitudes de caracteres desiguales (%ld/%ld) en %s"
 
-#: fortran/trans-intrinsic.c:8088
+#: fortran/trans-intrinsic.c:8090
 #, c-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative (its value is %ld)"
 msgstr "El argumento NCOPIES del intrínseco REPEAT es negativo (su valor es %ld)"
 
-#: fortran/trans-intrinsic.c:8120
+#: fortran/trans-intrinsic.c:8122
 msgid "Argument NCOPIES of REPEAT intrinsic is too large"
 msgstr "El argumento NCOPIES del intrínseco REPEAT es demasiado grande"
 
@@ -5368,15 +5374,15 @@
 msgid "Invalid image number %d in SYNC IMAGES"
 msgstr "Número de imagen %d no válido en SYNC IMAGES"
 
-#: fortran/trans-stmt.c:2180
+#: fortran/trans-stmt.c:2177
 msgid "Loop iterates infinitely"
 msgstr ""
 
-#: fortran/trans-stmt.c:2200 fortran/trans-stmt.c:2456
+#: fortran/trans-stmt.c:2197 fortran/trans-stmt.c:2453
 msgid "Loop variable has been modified"
 msgstr "Se modificó la variable de ciclo"
 
-#: fortran/trans-stmt.c:2309
+#: fortran/trans-stmt.c:2306
 msgid "DO step value is zero"
 msgstr "El valor de paso de DO es cero"
 
@@ -5949,10 +5955,10 @@
 msgid "Allow dollar signs in entity names."
 msgstr "Permite signos de dólar en nombres de entidades."
 
-#: fortran/lang.opt:485 config/alpha/alpha.opt:31 common.opt:783
-#: common.opt:985 common.opt:989 common.opt:993 common.opt:997 common.opt:1532
-#: common.opt:1588 common.opt:1712 common.opt:1716 common.opt:1946
-#: common.opt:2116 common.opt:2792
+#: fortran/lang.opt:485 config/alpha/alpha.opt:31 common.opt:649
+#: common.opt:783 common.opt:989 common.opt:993 common.opt:997 common.opt:1001
+#: common.opt:1536 common.opt:1592 common.opt:1716 common.opt:1720
+#: common.opt:1950 common.opt:2120 common.opt:2796
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr "No hace nada. Preservado por compatibilidad hacia atrás."
 
@@ -6171,12 +6177,12 @@
 msgstr "Agrega subrayado a los nombres visibles externamente."
 
 #: fortran/lang.opt:751 c-family/c.opt:1356 c-family/c.opt:1384
-#: c-family/c.opt:1634 config/pa/pa.opt:42 config/pa/pa.opt:70 common.opt:1154
-#: common.opt:1333 common.opt:1408 common.opt:1676 common.opt:1799
-#: common.opt:2169 common.opt:2205 common.opt:2298 common.opt:2302
-#: common.opt:2407 common.opt:2498 common.opt:2506 common.opt:2514
-#: common.opt:2522 common.opt:2623 common.opt:2675 common.opt:2755
-#: common.opt:2893 common.opt:2897 common.opt:2901 common.opt:2905
+#: c-family/c.opt:1634 config/pa/pa.opt:42 config/pa/pa.opt:70 common.opt:1158
+#: common.opt:1337 common.opt:1412 common.opt:1680 common.opt:1803
+#: common.opt:2173 common.opt:2209 common.opt:2302 common.opt:2306
+#: common.opt:2411 common.opt:2502 common.opt:2510 common.opt:2518
+#: common.opt:2526 common.opt:2627 common.opt:2679 common.opt:2759
+#: common.opt:2897 common.opt:2901 common.opt:2905 common.opt:2909
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr "No hace nada.  Se preserva por compatibilidad hacia atrás."
 
@@ -6226,7 +6232,7 @@
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:220 c-family/c.opt:224
 #: c-family/c.opt:236 c-family/c.opt:1855 c-family/c.opt:1863 brig/lang.opt:39
-#: config/darwin.opt:56 common.opt:338 common.opt:341 common.opt:3046
+#: config/darwin.opt:56 common.opt:338 common.opt:341 common.opt:3050
 #, c-format
 msgid "missing filename after %qs"
 msgstr "falta un nombre de fichero después de %qs"
@@ -6802,7 +6808,7 @@
 #: c-family/c.opt:1525 c-family/c.opt:1528 c-family/c.opt:1569
 #: c-family/c.opt:1704 c-family/c.opt:1731 c-family/c.opt:1771
 #: c-family/c.opt:1802 c-family/c.opt:1806 c-family/c.opt:1822
-#: config/ia64/ia64.opt:167 config/ia64/ia64.opt:170 c-family/c-opts.c:434
+#: config/ia64/ia64.opt:167 config/ia64/ia64.opt:170 c-family/c-opts.c:432
 #, gcc-internal-format
 msgid "switch %qs is no longer supported"
 msgstr "la opción %qs ya no se admite"
@@ -13868,10 +13874,6 @@
 msgid "Warn if dereferencing a NULL pointer may lead to erroneous or undefined behavior."
 msgstr "Avisa si la desreferencia de un puntero NULL puede llevar a un comportamiento erróneo o indefinido."
 
-#: common.opt:649
-msgid "Warn if the loop cannot be optimized due to nontrivial assumptions."
-msgstr "Avisa si el bucle no se puede optimizar debido a presunciones no triviales."
-
 #: common.opt:656
 msgid "Warn about some C++ One Definition Rule violations during link time optimization."
 msgstr "Advierto de algunas violaciones de la regla de una definición de C++ durante la optimización de tiempo de enlazado."
@@ -14040,1678 +14042,1678 @@
 msgid "-dumpdir <dir>\tSet the directory name to be used for dumps."
 msgstr "-dumpdir <dir>\tEstablece el nombre del directorio a usar para los volcados."
 
-#: common.opt:946
+#: common.opt:950
 msgid "The version of the C++ ABI in use."
 msgstr "La versión de la ABI de C++ que se está usando."
 
-#: common.opt:950
+#: common.opt:954
 msgid "Aggressively optimize loops using language constraints."
 msgstr "Optimiza los bucles de forma agresiva empleando restricciones del lenguaje."
 
-#: common.opt:954
+#: common.opt:958
 msgid "Align the start of functions."
 msgstr "Alinea el inicio de las funciones."
 
-#: common.opt:964
+#: common.opt:968
 msgid "Align labels which are only reached by jumping."
 msgstr "Alinea las etiquetas que solamente se alcanzan saltando."
 
-#: common.opt:971
+#: common.opt:975
 msgid "Align all labels."
 msgstr "Alinea todas las etiquetas."
 
-#: common.opt:978
+#: common.opt:982
 msgid "Align the start of loops."
 msgstr "Alinea el inicio de los bucles."
 
-#: common.opt:1001
+#: common.opt:1005
 msgid "Select what to sanitize."
 msgstr "Selecciona qué sanear."
 
-#: common.opt:1005
+#: common.opt:1009
 msgid "Select type of coverage sanitization."
 msgstr "Selecciona el tipo de saneamiento de cobertura."
 
-#: common.opt:1009
+#: common.opt:1013
 msgid "-fasan-shadow-offset=<number>\tUse custom shadow memory offset."
 msgstr ""
 
-#: common.opt:1013
+#: common.opt:1017
 msgid "-fsanitize-sections=<sec1,sec2,...>\tSanitize global variables in user-defined sections."
 msgstr "-fsanitize-sections=<sec1,sec2,...>\tSanea las variables globales en las secciones definidas por el usuario."
 
-#: common.opt:1018
+#: common.opt:1022
 msgid "After diagnosing undefined behavior attempt to continue execution."
 msgstr "Tras el diagnóstico de comportamiento indefinido intenta continuar la ejecución."
 
-#: common.opt:1022
+#: common.opt:1026
 msgid "This switch is deprecated; use -fsanitize-recover= instead."
 msgstr "Esta opción es obsoleta; utilice en su lugar -fsanitize-recover=."
 
-#: common.opt:1029
+#: common.opt:1033
 msgid "Use trap instead of a library function for undefined behavior sanitization."
 msgstr "Usa trap en lugar de una función de biblioteca para sanear el comportamiento indefinido."
 
-#: common.opt:1033
+#: common.opt:1037
 msgid "Generate unwind tables that are exact at each instruction boundary."
 msgstr "Genera tablas de desenredo que sean exactas en cada límite de instrucción."
 
-#: common.opt:1037
+#: common.opt:1041
 msgid "Generate auto-inc/dec instructions."
 msgstr "Genera instrucciones auto-inc/dec."
 
-#: common.opt:1041
+#: common.opt:1045
 msgid "Use sample profile information for call graph node weights. The default profile file is fbdata.afdo in 'pwd'."
 msgstr "Usa información de perfil de muestra para los pesos de los nodos de los grafos de llamadas. El fichero de perfil predeterminado es fbdata.afdo en 'pwd'."
 
-#: common.opt:1046
+#: common.opt:1050
 msgid "Use sample profile information for call graph node weights. The profile file is specified in the argument."
 msgstr "Usa la información de perfil de muestra para los pesos de los nodos de los grafos de llamadas. El fichero de perfil se especifica en el argumento."
 
-#: common.opt:1055
+#: common.opt:1059
 msgid "Generate code to check bounds before indexing arrays."
 msgstr "Genera código para revisar los límites antes de indexar matrices."
 
-#: common.opt:1059
+#: common.opt:1063
 msgid "Replace add, compare, branch with branch on count register."
 msgstr "Reemplaza add, compare, branch con branch en la cuenta de registros."
 
-#: common.opt:1063
+#: common.opt:1067
 msgid "Use profiling information for branch probabilities."
 msgstr "Usa la información de análisis de perfil para las probabilidades de ramificación."
 
-#: common.opt:1067
+#: common.opt:1071
 msgid "Perform branch target load optimization before prologue / epilogue threading."
 msgstr "Realiza optimización de carga de ramificación objetivo antes del hilo prólogo / epílogo."
 
-#: common.opt:1071
+#: common.opt:1075
 msgid "Perform branch target load optimization after prologue / epilogue threading."
 msgstr "Realiza optimización de carga de ramificación objetivo después del hilo prólogo / epílogo."
 
-#: common.opt:1075
+#: common.opt:1079
 msgid "Restrict target load migration not to re-use registers in any basic block."
 msgstr "Restringe que la migración de carga de objetivos no reuse registros en ningún bloque básico."
 
-#: common.opt:1079
+#: common.opt:1083
 msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions."
 msgstr "-fcall-saved-<registro>\tMarca el <registro> como preservado entre funciones."
 
-#: common.opt:1083
+#: common.opt:1087
 msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls."
 msgstr "-fcall-used-<registro>\tMarca el <registro> como corrupto por llamadas de función."
 
-#: common.opt:1090
+#: common.opt:1094
 msgid "Save registers around function calls."
 msgstr "Guarda registros alrededor de llamadas de función."
 
-#: common.opt:1094
+#: common.opt:1098
 msgid "This switch is deprecated; do not use."
 msgstr "Esta opción es obsoleta; no lo utilice."
 
-#: common.opt:1098
+#: common.opt:1102
 msgid "Check the return value of new in C++."
 msgstr "Revisa el valor de devolución de new en C++."
 
-#: common.opt:1102 common.opt:1106
+#: common.opt:1106 common.opt:1110
 msgid "Perform internal consistency checkings."
 msgstr "Realiza comprobaciones de consistencia internas."
 
-#: common.opt:1110
+#: common.opt:1114
 msgid "Enable code hoisting."
 msgstr "Activa la elevación de código."
 
-#: common.opt:1114
+#: common.opt:1118
 msgid "Looks for opportunities to reduce stack adjustments and stack references."
 msgstr "Busca oportunidades para reducir los ajustes de pila y las referencias de pila."
 
-#: common.opt:1118
+#: common.opt:1122
 msgid "Do not put uninitialized globals in the common section."
 msgstr "No pone globales sin inicializar en la sección común."
 
-#: common.opt:1126
+#: common.opt:1130
 msgid "-fcompare-debug[=<opts>]\tCompile with and without e.g. -gtoggle, and compare the final-insns dump."
 msgstr "-fcompare-debug[=<opts>]\tCompila con y sin p.e. -gtoggle, y compara el volcado de insns finales."
 
-#: common.opt:1130
+#: common.opt:1134
 msgid "Run only the second compilation of -fcompare-debug."
 msgstr "Ejecuta sólo la segunda compilación de -fcompare-debug."
 
-#: common.opt:1134
+#: common.opt:1138
 msgid "Perform comparison elimination after register allocation has finished."
 msgstr "Realiza la eliminación de comparaciones después de terminar el alojamiento de registros."
 
-#: common.opt:1138
+#: common.opt:1142
 msgid "Do not perform optimizations increasing noticeably stack usage."
 msgstr "No realizar optimizaciones que incrementan notablemente el uso de la pila."
 
-#: common.opt:1142
+#: common.opt:1146
 msgid "Perform a register copy-propagation optimization pass."
 msgstr "Realiza el paso de optimización de copia-propagación de registros."
 
-#: common.opt:1146
+#: common.opt:1150
 msgid "Perform cross-jumping optimization."
 msgstr "Realiza optimizaciones de saltos cruzados."
 
-#: common.opt:1150
+#: common.opt:1154
 msgid "When running CSE, follow jumps to their targets."
 msgstr "Cuando se esté ejecutando CSE, sigue los saltos a sus objetivos."
 
-#: common.opt:1158
+#: common.opt:1162
 msgid "Omit range reduction step when performing complex division."
 msgstr "Omite el paso de reducción de rango al realizar divisiones complejas."
 
-#: common.opt:1162
+#: common.opt:1166
 msgid "Complex multiplication and division follow Fortran rules."
 msgstr "La multiplicación y la división complejas siguen las reglas Fortran."
 
-#: common.opt:1166
+#: common.opt:1170
 msgid "Place data items into their own section."
 msgstr "Coloca los elementos de datos en su propia sección."
 
-#: common.opt:1170
+#: common.opt:1174
 msgid "List all available debugging counters with their limits and counts."
 msgstr "Enumera todos los contadores de depuración disponibles con sus límites y cuentas."
 
-#: common.opt:1174
+#: common.opt:1178
 msgid "-fdbg-cnt=<counter>:<limit>[,<counter>:<limit>,...]\tSet the debug counter limit."
 msgstr "-fdbg-cnt=<contador>:<límite>[,<contador>:<límite>,...]\tEstablece el límite del contador de depuración."
 
-#: common.opt:1178
+#: common.opt:1182
 msgid "-fdebug-prefix-map=<old>=<new> Map one directory name to another in debug information."
 msgstr "-fdebug-prefix-map=<antiguo>=<nuevo> Asocia un nombre de directorio a otro en la información de depuración."
 
-#: common.opt:1182
+#: common.opt:1186
 msgid "-ffile-prefix-map=<old>=<new> Map one directory name to another in compilation result."
 msgstr "-ffile-prefix-map=<antiguo>=<nuevo> Asocia un nombre de directorio a otro en la información de depuración."
 
-#: common.opt:1186
+#: common.opt:1190
 msgid "Output .debug_types section when using DWARF v4 debuginfo."
 msgstr "Muestra la sección .debug_types al usar la información de depuración DWARF v4."
 
-#: common.opt:1192
+#: common.opt:1196
 msgid "Defer popping functions args from stack until later."
 msgstr "Posterga la extracción de argumentos de funciones de la pila hasta más tarde."
 
-#: common.opt:1196
+#: common.opt:1200
 msgid "Attempt to fill delay slots of branch instructions."
 msgstr "Intenta rellenar las ranuras de retraso de las instrucciones de ramificación."
 
-#: common.opt:1200
+#: common.opt:1204
 msgid "Delete dead instructions that may throw exceptions."
 msgstr "Borra instrucciones muertas que pueden lanzar excepciones."
 
-#: common.opt:1204
+#: common.opt:1208
 msgid "Delete useless null pointer checks."
 msgstr "Borra las revisiones de punteros nulos sin uso."
 
-#: common.opt:1208
+#: common.opt:1212
 msgid "Stream extra data to support more aggressive devirtualization in LTO local transformation mode."
 msgstr "Hace fluir datos extra para permitir desvirtualización más agresiva en el modo de transformación local LTO."
 
-#: common.opt:1212
+#: common.opt:1216
 msgid "Perform speculative devirtualization."
 msgstr "Realiza desvirtualización especulativa."
 
-#: common.opt:1216
+#: common.opt:1220
 msgid "Try to convert virtual calls to direct ones."
 msgstr "Trata de convertir las llamadas virtuales a llamadas directas."
 
-#: common.opt:1220
+#: common.opt:1224
 msgid "-fdiagnostics-show-location=[once|every-line]\tHow often to emit source location at the beginning of line-wrapped diagnostics."
 msgstr "-fdiagnostics-show-location=[once|every-line]\tIndica la frecuencia con que se debe emitir la ubicación del código al inicio de los diagnósticos con corte de línea."
 
-#: common.opt:1237
+#: common.opt:1241
 msgid "Show the source line with a caret indicating the column."
 msgstr "Muestra la línea de código con un signo de intercalación para indicar la columna."
 
-#: common.opt:1245
+#: common.opt:1249
 msgid "-fdiagnostics-color=[never|always|auto]\tColorize diagnostics."
 msgstr "-fdiagnostics-color=[never|always|auto]\tColorea los diagnósticos."
 
-#: common.opt:1265
+#: common.opt:1269
 msgid "Print fix-it hints in machine-readable form."
 msgstr "Imprime indicaciones fix-it (arreglar) en formato legible por una máquina."
 
-#: common.opt:1269
+#: common.opt:1273
 msgid "Print fix-it hints to stderr in unified diff format."
 msgstr "Imprime indicaciones fix-it (arreglar) en stder en formato diff unificado."
 
-#: common.opt:1273
+#: common.opt:1277
 msgid "Amend appropriate diagnostic messages with the command line option that controls them."
 msgstr "Asocia adecuadamente los mensajes de diagnóstico con la opción de línea de orden que los controla."
 
-#: common.opt:1277
+#: common.opt:1281
 msgid "-fdisable-[tree|rtl|ipa]-<pass>=range1+range2 disables an optimization pass."
 msgstr "-fdisable-[tree|rtl|ipa]-<paso>=rango1+rango2 desactiva un paso de optimización."
 
-#: common.opt:1281
+#: common.opt:1285
 msgid "-fenable-[tree|rtl|ipa]-<pass>=range1+range2 enables an optimization pass."
 msgstr "-fenable-[tree|rtl|ipa]-<paso>=rango1+rango2 activa un paso de optimización."
 
-#: common.opt:1285
+#: common.opt:1289
 msgid "-fdump-<type>\tDump various compiler internals to a file."
 msgstr "-fdump-<tipo>\tVuelca varios internos del compilador a un fichero."
 
-#: common.opt:1292
+#: common.opt:1296
 msgid "-fdump-final-insns=filename\tDump to filename the insns at the end of translation."
 msgstr "-fdump-final-insns=fichero\tVuelca al fichero las insns al final de la traducción."
 
-#: common.opt:1296
+#: common.opt:1300
 msgid "-fdump-go-spec=filename\tWrite all declarations to file as Go code."
 msgstr "-fdump-go-spec=fichero\tEscribe todas las declaraciones al fichero como código Go."
 
-#: common.opt:1300
+#: common.opt:1304
 msgid "Suppress output of addresses in debugging dumps."
 msgstr "Suprime la salida de direcciones en los volcados de depuración."
 
-#: common.opt:1304
+#: common.opt:1308
 msgid "Collect and dump debug information into temporary file if ICE in C/C++ compiler occurred."
 msgstr "Recoge y vuelca información de depuración en un fichero temporal si ha ocurrido ICE en el compilador de C/C++."
 
-#: common.opt:1309
+#: common.opt:1313
 msgid "Dump detailed information on GCC's internal representation of source code locations."
 msgstr "Vuelca información detallada de las ubicaciones de código fuente en la representación interna de GCC."
 
-#: common.opt:1313
+#: common.opt:1317
 msgid "Dump optimization passes."
 msgstr "Vuelca pasadas de optimización."
 
-#: common.opt:1317
+#: common.opt:1321
 msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps."
 msgstr "Suprime la salida de números de instrucción, notas de números de linea y direcciones en los volcados de depuración."
 
-#: common.opt:1321
+#: common.opt:1325
 msgid "Suppress output of previous and next insn numbers in debugging dumps."
 msgstr "Suprime la salida de los números insn previos y siguientes en los volcados de depuración."
 
-#: common.opt:1325
+#: common.opt:1329
 msgid "Enable CFI tables via GAS assembler directives."
 msgstr "Activa las tablas CFI a través de directivas del ensamblador GAS."
 
-#: common.opt:1329
+#: common.opt:1333
 msgid "Perform early inlining."
 msgstr "Realiza la inclusión en línea temprana."
 
-#: common.opt:1337
+#: common.opt:1341
 msgid "Perform interprocedural reduction of aggregates."
 msgstr "Realiza la reducción interprocedural de los agregados."
 
-#: common.opt:1341
+#: common.opt:1345
 msgid "Perform unused symbol elimination in debug info."
 msgstr "Realiza la eliminación de símbolos sin uso en la información de depuración."
 
-#: common.opt:1345
+#: common.opt:1349
 msgid "Perform unused type elimination in debug info."
 msgstr "Realiza la eliminación de tipos sin uso en la información de depuración."
 
-#: common.opt:1349
+#: common.opt:1353
 msgid "Do not suppress C++ class debug information."
 msgstr "No suprime la información de depuración de clases C++."
 
-#: common.opt:1353
+#: common.opt:1357
 msgid "Enable exception handling."
 msgstr "Activa el manejo de excepciones."
 
-#: common.opt:1357
+#: common.opt:1361
 msgid "Perform a number of minor, expensive optimizations."
 msgstr "Realiza un número de optimizaciones menores y costosas."
 
-#: common.opt:1361
+#: common.opt:1365
 msgid "-fexcess-precision=[fast|standard]\tSpecify handling of excess floating-point precision."
 msgstr "-fexcess-precision=[fast|standard]\tEspecifica el manejo del exceso de precisión de coma flotante."
 
-#: common.opt:1364
+#: common.opt:1368
 #, c-format
 msgid "unknown excess precision style %qs"
 msgstr "estilo de exceso de precisión %qs desconocido"
 
-#: common.opt:1376
+#: common.opt:1380
 msgid "-fpermitted-flt-eval-methods=[c11|ts-18661]\tSpecify which values of FLT_EVAL_METHOD are permitted."
 msgstr "-fpermitted-flt-eval-methods=[c11|ts--18661]\tEspecifica qué valores de FLT_EVAL_METHOD están permitidos."
 
-#: common.opt:1379
+#: common.opt:1383
 #, c-format
 msgid "unknown specification for the set of FLT_EVAL_METHOD values to permit %qs"
 msgstr "especificación desconocida para el conjunto de valores de FLT_EVAL_METHOD a permitir %qs"
 
-#: common.opt:1392
+#: common.opt:1396
 msgid "Output lto objects containing both the intermediate language and binary output."
 msgstr "Muestra los objetos lto que contienen tanto el lenguaje intermedio como la salida binaria."
 
-#: common.opt:1396
+#: common.opt:1400
 msgid "Assume no NaNs or infinities are generated."
 msgstr "Asume que no se generan NaNs o infinitos."
 
-#: common.opt:1400
+#: common.opt:1404
 msgid "-ffixed-<register>\tMark <register> as being unavailable to the compiler."
 msgstr "-ffixed-<registro>\tMarca el <registro> como no disponible para el compilador."
 
-#: common.opt:1404
+#: common.opt:1408
 msgid "Don't allocate floats and doubles in extended-precision registers."
 msgstr "No aloja floats y doubles en registros de precisión extendida."
 
-#: common.opt:1412
+#: common.opt:1416
 msgid "Perform a forward propagation pass on RTL."
 msgstr "Realiza el paso de la propagación hacia adelante en RTL."
 
-#: common.opt:1416
+#: common.opt:1420
 msgid "-ffp-contract=[off|on|fast]\tPerform floating-point expression contraction."
 msgstr "-ffp-contract=[off|on|fast]\tRealiza contracción de expresión de coma flotante."
 
-#: common.opt:1419
+#: common.opt:1423
 #, c-format
 msgid "unknown floating point contraction style %qs"
 msgstr "estilo de contracción de coma flotante %qs desconocido"
 
-#: common.opt:1433
+#: common.opt:1437
 msgid "Allow built-in functions ceil, floor, round, trunc to raise \"inexact\" exceptions."
 msgstr "Permite a las funciones internas ceil, floor, round, trunc generar excepciones \"inexactas\"."
 
-#: common.opt:1440
+#: common.opt:1444
 msgid "Allow function addresses to be held in registers."
 msgstr "Permite que las direcciones de las funciones se conservern en registros."
 
-#: common.opt:1444
+#: common.opt:1448
 msgid "Place each function into its own section."
 msgstr "Coloca cada función en su propia sección."
 
-#: common.opt:1448
+#: common.opt:1452
 msgid "Perform global common subexpression elimination."
 msgstr "Realiza la eliminación de subexpresiones comunes globales."
 
-#: common.opt:1452
+#: common.opt:1456
 msgid "Perform enhanced load motion during global common subexpression elimination."
 msgstr "Realiza el movimiento de la carga mejorada durante la eliminación de subexpresiones comunes globales."
 
-#: common.opt:1456
+#: common.opt:1460
 msgid "Perform store motion after global common subexpression elimination."
 msgstr "Realiza el movimiento de guardado después de la eliminación de subexpresiones comunes globales."
 
-#: common.opt:1460
+#: common.opt:1464
 msgid "Perform redundant load after store elimination in global common subexpression elimination."
 msgstr "Realiza la carga redundante después de la eliminación de almacenamiento en la eliminación de subexpresiones comunes globales"
 
-#: common.opt:1465
+#: common.opt:1469
 msgid "Perform global common subexpression elimination after register allocation has finished."
 msgstr "Realiza la eliminación de subexpresiones comunes globales tras la finalización de la asignación de registros."
 
-#: common.opt:1482
+#: common.opt:1486
 msgid "-fgnat-encodings=[all|gdb|minimal]\tSelect the balance between GNAT encodings and standard DWARF emitted in the debug information"
 msgstr "-fgnat-encodings=[all|gdb|minimal]\tSelecciona el equilibrio entre codificaciones GNAT y DWARF estándar emitidos en la información de depuración."
 
-#: common.opt:1487
+#: common.opt:1491
 msgid "Enable in and out of Graphite representation."
 msgstr "Activa in y out de la representación Graphite."
 
-#: common.opt:1491
+#: common.opt:1495
 msgid "Enable Graphite Identity transformation."
 msgstr "Activa la transformación Graphite Identity."
 
-#: common.opt:1495
+#: common.opt:1499
 msgid "Enable hoisting adjacent loads to encourage generating conditional move instructions."
 msgstr "Activa las cargas de elevación adyacentes para fomentar la generación de instrucciones move condicionales."
 
-#: common.opt:1504
+#: common.opt:1508
 msgid "Mark all loops as parallel."
 msgstr "Marca todos los bucles como paralelos."
 
-#: common.opt:1508 common.opt:1516 common.opt:2587
+#: common.opt:1512 common.opt:1520 common.opt:2591
 msgid "Enable loop nest transforms.  Same as -floop-nest-optimize."
 msgstr "Activa las transformaciones anidadas de bucle.  Igual que -floop-nest-optimize."
 
-#: common.opt:1512
+#: common.opt:1516
 msgid "Enable loop interchange on trees."
 msgstr "Activa el intercambio de bucles en árboles."
 
-#: common.opt:1520
+#: common.opt:1524
 msgid "Perform unroll-and-jam on loops."
 msgstr "Realiza unroll-and-jam en los bucles."
 
-#: common.opt:1524
+#: common.opt:1528
 msgid "Enable support for GNU transactional memory."
 msgstr "Activa el soporte para la memoria transaccional de GNU."
 
-#: common.opt:1528
+#: common.opt:1532
 msgid "Use STB_GNU_UNIQUE if supported by the assembler."
 msgstr "Usa STB_GNU_UNIQUE si lo admite el ensamblador."
 
-#: common.opt:1536
+#: common.opt:1540
 msgid "Enable the loop nest optimizer."
 msgstr "Activa el optimizador de anidamiento de bucles."
 
-#: common.opt:1540
+#: common.opt:1544
 msgid "Force bitfield accesses to match their type width."
 msgstr "Fuerza que los accesos de campos de bit coincidan con su anchura de tipo."
 
-#: common.opt:1544
+#: common.opt:1548
 msgid "Merge adjacent stores."
 msgstr "Mezcla los almacenamientos adyacentes."
 
-#: common.opt:1548
+#: common.opt:1552
 msgid "Enable guessing of branch probabilities."
 msgstr "Activa la predicción de probabilidades de ramificación."
 
-#: common.opt:1556
+#: common.opt:1560
 msgid "Process #ident directives."
 msgstr "Procesa directivas #ident."
 
-#: common.opt:1560
+#: common.opt:1564
 msgid "Perform conversion of conditional jumps to branchless equivalents."
 msgstr "Realiza la conversión de saltos condicionales a equivalentes sin ramificación."
 
-#: common.opt:1564
+#: common.opt:1568
 msgid "Perform conversion of conditional jumps to conditional execution."
 msgstr "Realiza la conversión de saltos condicionales a ejecución condicional."
 
-#: common.opt:1568
+#: common.opt:1572
 msgid "-fstack-reuse=[all|named_vars|none]\tSet stack reuse level for local variables."
 msgstr "-fstack-reuse=[all|named_vars|none]\tEstablece el nivel de reúso de la pila para variables locales."
 
-#: common.opt:1571
+#: common.opt:1575
 #, c-format
 msgid "unknown Stack Reuse Level %qs"
 msgstr "nivel de reúso de la pila %qs desconocido"
 
-#: common.opt:1584
+#: common.opt:1588
 msgid "Convert conditional jumps in innermost loops to branchless equivalents."
 msgstr "Convierte saltos condicionales en los bucles más internos a equivalentes sin ramificación."
 
-#: common.opt:1596
+#: common.opt:1600
 msgid "Do not generate .size directives."
 msgstr "No genera directivas .size."
 
-#: common.opt:1600
+#: common.opt:1604
 msgid "Perform indirect inlining."
 msgstr "Realiza la inclusión en línea indirecta."
 
-#: common.opt:1606
+#: common.opt:1610
 msgid "Enable inlining of function declared \"inline\", disabling disables all inlining."
 msgstr "Activa la inclusión en línea de la la función declarada \"inline\", y desactiva todas las demás inclusiones en línea."
 
-#: common.opt:1610
+#: common.opt:1614
 msgid "Integrate functions into their callers when code size is known not to grow."
 msgstr "Integra las funciones en sus invocadores cuando se sabe que el tamaño del código no crece."
 
-#: common.opt:1614
+#: common.opt:1618
 msgid "Integrate functions not declared \"inline\" into their callers when profitable."
 msgstr "Integra las funciones que no se declaran \"inline\" en sus invocadores cuando es rentable."
 
-#: common.opt:1618
+#: common.opt:1622
 msgid "Integrate functions only required by their single caller."
 msgstr "Integra las funciones sólo requeridas por su invocador único."
 
-#: common.opt:1625
+#: common.opt:1629
 msgid "-finline-limit=<number>\tLimit the size of inlined functions to <number>."
 msgstr "-finline-limit=<número>\tLimita el tamaño de las funciones incluidas en línea a <número>."
 
-#: common.opt:1629
+#: common.opt:1633
 msgid "Inline __atomic operations when a lock free instruction sequence is available."
 msgstr "Coloca en línea las operaciones __atomic cuando una secuencia de instrucciones lock free está disponible"
 
-#: common.opt:1636
+#: common.opt:1640
 msgid "-fcf-protection=[full|branch|return|none]\tInstrument functions with checks to verify jump/call/return control-flow transfer instructions have valid targets."
 msgstr "-fcf-protection=[full|branch|return|none]\tInstrumenta las funciones con comprobaciones para verificar que las instrucciones de transferencia del flujo de control jump/call/return tienen objetivos válidos."
 
-#: common.opt:1640
+#: common.opt:1644
 #, c-format
 msgid "unknown Control-Flow Protection Level %qs"
 msgstr "nivel de protección del flujo de control %qs desconocido"
 
-#: common.opt:1656
+#: common.opt:1660
 msgid "Instrument function entry and exit with profiling calls."
 msgstr "Instrumenta funciones de entrada y salida con llamadas de análisis de perfil."
 
-#: common.opt:1660
+#: common.opt:1664
 msgid "-finstrument-functions-exclude-function-list=name,...  Do not instrument listed functions."
 msgstr "-finstrument-functions-exclude-functions-list=nombre,... No instrumenta las funciones enlistadas."
 
-#: common.opt:1664
+#: common.opt:1668
 msgid "-finstrument-functions-exclude-file-list=filename,...  Do not instrument functions listed in files."
 msgstr "-finstrument-functions-exclude-file-list=fichero,... No instrumenta las funciones enlistadas en ficheros."
 
-#: common.opt:1668
+#: common.opt:1672
 msgid "Perform interprocedural constant propagation."
 msgstr "Realiza la propagación interprocedural de las constantes."
 
-#: common.opt:1672
+#: common.opt:1676
 msgid "Perform cloning to make Interprocedural constant propagation stronger."
 msgstr "Realiza la clonación para hacer la propagación constante Interprocedural más fuerte."
 
-#: common.opt:1680
+#: common.opt:1684
 msgid "Perform interprocedural bitwise constant propagation."
 msgstr "Realiza la propagación interprocedural de las constantes por bits."
 
-#: common.opt:1684
+#: common.opt:1688
 msgid "Perform interprocedural profile propagation."
 msgstr "Realiza la propagación de perfil interprocedural."
 
-#: common.opt:1688
+#: common.opt:1692
 msgid "Perform interprocedural points-to analysis."
 msgstr "Realiza el análisis interprocedural de puntero-a."
 
-#: common.opt:1692
+#: common.opt:1696
 msgid "Discover pure and const functions."
 msgstr "Descubre funciones pure y const."
 
-#: common.opt:1696
+#: common.opt:1700
 msgid "Perform Identical Code Folding for functions and read-only variables."
 msgstr "Realiza plegamiento de código idéntico en funciones y variables de solo lectura."
 
-#: common.opt:1700
+#: common.opt:1704
 msgid "Perform Identical Code Folding for functions."
 msgstr "Realiza plegamiento de código idéntico en funciones."
 
-#: common.opt:1704
+#: common.opt:1708
 msgid "Perform Identical Code Folding for variables."
 msgstr "Realiza plegamiento de código idéntico en variables."
 
-#: common.opt:1708
+#: common.opt:1712
 msgid "Discover readonly and non addressable static variables."
 msgstr "Descubre variables estáticas de sólo lectura y no direccionables."
 
-#: common.opt:1720
+#: common.opt:1724
 msgid "Perform IPA Value Range Propagation."
 msgstr "Realiza la Propagación de Rango Valor IPA."
 
-#: common.opt:1724
+#: common.opt:1728
 msgid "-fira-algorithm=[CB|priority]\tSet the used IRA algorithm."
 msgstr "-fira-algorithm=[CB|priority]\tEstablece el algoritmo IRA a usar."
 
-#: common.opt:1727
+#: common.opt:1731
 #, c-format
 msgid "unknown IRA algorithm %qs"
 msgstr "algoritmo IRA %qs desconocido"
 
-#: common.opt:1737
+#: common.opt:1741
 msgid "-fira-region=[one|all|mixed]\tSet regions for IRA."
 msgstr "-fira-region=[one|all|mixed]\tEstablece las regiones para IRA."
 
-#: common.opt:1740
+#: common.opt:1744
 #, c-format
 msgid "unknown IRA region %qs"
 msgstr "región IRA %qs desconocida"
 
-#: common.opt:1753
+#: common.opt:1757
 msgid "Use IRA based register pressure calculation in RTL hoist optimizations."
 msgstr "Usa el cálculo de presión de registros basado en IRA en optimizaciones de izado RTL."
 
-#: common.opt:1758
+#: common.opt:1762
 msgid "Use IRA based register pressure calculation in RTL loop optimizations."
 msgstr "Usa el cálculo de presión de registros basado en IRA en optimizaciones de bucle RTL."
 
-#: common.opt:1763
+#: common.opt:1767
 msgid "Share slots for saving different hard registers."
 msgstr "Comparte ranuras para ahorrar registros hard diferentes."
 
-#: common.opt:1767
+#: common.opt:1771
 msgid "Share stack slots for spilled pseudo-registers."
 msgstr "Comparte ranuras de pila para pseudo-registros derramados."
 
-#: common.opt:1771
+#: common.opt:1775
 msgid "-fira-verbose=<number>\tControl IRA's level of diagnostic messages."
 msgstr "-fira-verbose=<número>\tControla el nivel de mensajes de diagnóstico de IRA."
 
-#: common.opt:1775
+#: common.opt:1779
 msgid "Optimize induction variables on trees."
 msgstr "Optimiza la inducción de variables en los árboles."
 
-#: common.opt:1779
+#: common.opt:1783
 msgid "Use jump tables for sufficiently large switch statements."
 msgstr "Usa tablas de salto para las declaraciones switch suficientemente grandes."
 
-#: common.opt:1783
+#: common.opt:1787
 msgid "Generate code for functions even if they are fully inlined."
 msgstr "Genera código para las funciones aún si están completamente incluidas en línea."
 
-#: common.opt:1787
+#: common.opt:1791
 msgid "Generate code for static functions even if they are never called."
 msgstr "Genera código para las funciones estáticas aunque nunca se las llame."
 
-#: common.opt:1791
+#: common.opt:1795
 msgid "Emit static const variables even if they are not used."
 msgstr "Emite variables static const aún si no se usan."
 
-#: common.opt:1795
+#: common.opt:1799
 msgid "Give external symbols a leading underscore."
 msgstr "Da a los símbolos externos un subrayado inicial."
 
-#: common.opt:1803
+#: common.opt:1807
 msgid "Do CFG-sensitive rematerialization in LRA."
 msgstr "Hacer rematerialización sensible a CFG en LRA."
 
-#: common.opt:1807
+#: common.opt:1811
 msgid "Enable link-time optimization."
 msgstr "Activa las optimizaciones de tiempo de enlace."
 
-#: common.opt:1811
+#: common.opt:1815
 msgid "Link-time optimization with number of parallel jobs or jobserver."
 msgstr "Optimización en tiempo de enlace con el número de trabajos paralelos o el servidor de trabajos."
 
-#: common.opt:1814
+#: common.opt:1818
 #, c-format
 msgid "unknown LTO partitioning model %qs"
 msgstr "modelo de partición LTO %qs desconocido"
 
-#: common.opt:1833
+#: common.opt:1837
 msgid "Specify the algorithm to partition symbols and vars at linktime."
 msgstr "Espcifica el algoritmo para particionar símbolos y variables en tiempo de enlazado."
 
-#: common.opt:1838
+#: common.opt:1842
 msgid "-flto-compression-level=<number>\tUse zlib compression level <number> for IL."
 msgstr "-flto-compression-level=<número>\tUsa el nivel de compresión de zlib <número> para IL."
 
-#: common.opt:1842
+#: common.opt:1846
 msgid "Merge C++ types using One Definition Rule."
 msgstr "Mezclar tipos C++ usando la regla de una sola definición."
 
-#: common.opt:1846
+#: common.opt:1850
 msgid "Report various link-time optimization statistics."
 msgstr "Reporta varias estadísticas de optimización de tiempo de enlace."
 
-#: common.opt:1850
+#: common.opt:1854
 msgid "Report various link-time optimization statistics for WPA only."
 msgstr "Reporta varias estadísticas de optimización de tiempo de enlace solo para WPA."
 
-#: common.opt:1854
+#: common.opt:1858
 msgid "Set errno after built-in math functions."
 msgstr "Establece errno después de las funciones matemáticas internas."
 
-#: common.opt:1858
+#: common.opt:1862
 msgid "-fmax-errors=<number>\tMaximum number of errors to report."
 msgstr "-fmax-errors=<número>\tNúmero máximo de errores a reportar."
 
-#: common.opt:1862
+#: common.opt:1866
 msgid "Report on permanent memory allocation."
 msgstr "Reporta el alojamiento en memoria permanente."
 
-#: common.opt:1866
+#: common.opt:1870
 msgid "Report on permanent memory allocation in WPA only."
 msgstr "Reporta el alojamiento en memoria permanente solo en WPA."
 
-#: common.opt:1873
+#: common.opt:1877
 msgid "Attempt to merge identical constants and constant variables."
 msgstr "Intenta mezclar constantes idénticas y variables constantes."
 
-#: common.opt:1877
+#: common.opt:1881
 msgid "Attempt to merge identical constants across compilation units."
 msgstr "Intenta mezclar constantes idénticas a través de las unidades de compilación."
 
-#: common.opt:1881
+#: common.opt:1885
 msgid "Attempt to merge identical debug strings across compilation units."
 msgstr "Intenta mezclar cadenas de depuración idénticas a través de las unidades de compilación."
 
-#: common.opt:1885
+#: common.opt:1889
 msgid "-fmessage-length=<number>\tLimit diagnostics to <number> characters per line.  0 suppresses line-wrapping."
 msgstr "-fmessage-length=<número>\tLimita los diagnósticos a <número> caracteres por línea.  0 suprime el corte de línea."
 
-#: common.opt:1889
+#: common.opt:1893
 msgid "Perform SMS based modulo scheduling before the first scheduling pass."
 msgstr "Realiza la planificación SMS basada en módulo antes del primer paso de calendarización."
 
-#: common.opt:1893
+#: common.opt:1897
 msgid "Perform SMS based modulo scheduling with register moves allowed."
 msgstr "Realiza la planificación módulo basada en SMS con movimientos permitidos de registros."
 
-#: common.opt:1897
+#: common.opt:1901
 msgid "Move loop invariant computations out of loops."
 msgstr "Mueve las computaciones invariantes de bucles fuera de los bucles."
 
-#: common.opt:1901
+#: common.opt:1905
 msgid "Use the RTL dead code elimination pass."
 msgstr "Usa el paso de eliminación de código muerto de RTL."
 
-#: common.opt:1905
+#: common.opt:1909
 msgid "Use the RTL dead store elimination pass."
 msgstr "Usa la eliminación de almacenamiento muerto de RTL."
 
-#: common.opt:1909
+#: common.opt:1913
 msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling."
 msgstr "Activa/Desactiva la planificación tradicional en bucles que ya pasaron la calendarización módulo."
 
-#: common.opt:1913
+#: common.opt:1917
 msgid "Support synchronous non-call exceptions."
 msgstr "Permite las excepciones síncronas que no son llamadas."
 
-#: common.opt:1916
+#: common.opt:1920
 #, c-format
 msgid "options or targets missing after %qs"
 msgstr "faltan opciones u objetivos después de %qs"
 
-#: common.opt:1917
+#: common.opt:1921
 msgid "-foffload=<targets>=<options>  Specify offloading targets and options for them."
 msgstr "-foffload=<targets>=<options>  Especifica objetivos de descarga y opciones para ellos."
 
-#: common.opt:1921
+#: common.opt:1925
 msgid "-foffload-abi=[lp64|ilp32]     Set the ABI to use in an offload compiler."
 msgstr "-foffload-abi=[lp64|ilp32]     Establece el ABI que usar en un compilador de descarga."
 
-#: common.opt:1924
+#: common.opt:1928
 #, c-format
 msgid "unknown offload ABI %qs"
 msgstr "descarga ABI %qs desconocida"
 
-#: common.opt:1934
+#: common.opt:1938
 msgid "When possible do not generate stack frames."
 msgstr "Cuando sea posible no genera marcos de pila."
 
-#: common.opt:1938
+#: common.opt:1942
 msgid "Enable all optimization info dumps on stderr."
 msgstr "Activa todos los volcados de información de optimización en stderr."
 
-#: common.opt:1942
+#: common.opt:1946
 msgid "-fopt-info[-<type>=filename]\tDump compiler optimization details."
 msgstr "-fopt-info[-<type>=filename]\tVuelca los detalles de optimización del compilador."
 
-#: common.opt:1950
+#: common.opt:1954
 msgid "Optimize sibling and tail recursive calls."
 msgstr "Optimiza las llamadas recursivas hermanadas y de extremo."
 
-#: common.opt:1954
+#: common.opt:1958
 msgid "Perform partial inlining."
 msgstr "Realiza la inclusión en línea parcial."
 
-#: common.opt:1958 common.opt:1962
+#: common.opt:1962 common.opt:1966
 msgid "Report on memory allocation before interprocedural optimization."
 msgstr "Reporta la ubicación de memoria antes de la optimización interprocedural."
 
-#: common.opt:1966
+#: common.opt:1970
 msgid "Pack structure members together without holes."
 msgstr "Empaqueta juntos a los miembros de la estructura sin agujeros."
 
-#: common.opt:1970
+#: common.opt:1974
 msgid "-fpack-struct=<number>\tSet initial maximum structure member alignment."
 msgstr "-fpack-struct=<número>\tEstablece la alineación inicial máxima de estructuras miembro."
 
-#: common.opt:1974
+#: common.opt:1978
 msgid "Return small aggregates in memory, not registers."
 msgstr "Devuelve los agregados small en memoria, no en registros."
 
-#: common.opt:1978
+#: common.opt:1982
 msgid "Perform loop peeling."
 msgstr "Realiza el pelado de bucles."
 
-#: common.opt:1982
+#: common.opt:1986
 msgid "Enable machine specific peephole optimizations."
 msgstr "Activa las optimizaciones de mirilla específicas de la máquina."
 
-#: common.opt:1986
+#: common.opt:1990
 msgid "Enable an RTL peephole pass before sched2."
 msgstr "Activa un paso de mirilla RTL antes de sched2."
 
-#: common.opt:1990
+#: common.opt:1994
 msgid "Generate position-independent code if possible (large mode)."
 msgstr "Genera código independiente de posición si es posible (modo large)."
 
-#: common.opt:1994
+#: common.opt:1998
 msgid "Generate position-independent code for executables if possible (large mode)."
 msgstr "Genera código independiente de posición para ejecutables si es posible (modo large)."
 
-#: common.opt:1998
+#: common.opt:2002
 msgid "Generate position-independent code if possible (small mode)."
 msgstr "Genera código independiente de posición si es posible (modo small)."
 
-#: common.opt:2002
+#: common.opt:2006
 msgid "Generate position-independent code for executables if possible (small mode)."
 msgstr "Genera código independiente de posición para ejecutables si es posible (modo small)."
 
-#: common.opt:2006
+#: common.opt:2010
 msgid "Use PLT for PIC calls (-fno-plt: load the address from GOT at call site)."
 msgstr "Usa PLT para llamadas PIC (-fno-plt: carga la dirección desde GOT en el sitio de la llamada)."
 
-#: common.opt:2010
+#: common.opt:2014
 msgid "Specify a plugin to load."
 msgstr "Especifica un plugin a cargar."
 
-#: common.opt:2014
+#: common.opt:2018
 msgid "-fplugin-arg-<name>-<key>[=<value>]\tSpecify argument <key>=<value> for plugin <name>."
 msgstr "-fplugin-arg-<nom>-<clave>[=<valor>]\tEspecifica el argumento <clave>=<valor> para el plugin <nom>bre."
 
-#: common.opt:2018
+#: common.opt:2022
 msgid "Run predictive commoning optimization."
 msgstr "Ejecuta la optimización comunizadora predictiva."
 
-#: common.opt:2022
+#: common.opt:2026
 msgid "Generate prefetch instructions, if available, for arrays in loops."
 msgstr "Genera instrucciones de precargado, si están disponibles, para matrices en bucles."
 
-#: common.opt:2026
+#: common.opt:2030
 msgid "Enable basic program profiling code."
 msgstr "Activa el código básico de análisis de perfil del programa."
 
-#: common.opt:2030
+#: common.opt:2034
 msgid "Generate absolute source path names for gcov."
 msgstr "Genera nombres de ruta de fuentes absolutos para gcov."
 
-#: common.opt:2034
+#: common.opt:2038
 msgid "Insert arc-based program profiling code."
 msgstr "Inserta el código de análisis de perfil de programa basado en arc."
 
-#: common.opt:2038
+#: common.opt:2042
 msgid "Set the top-level directory for storing the profile data. The default is 'pwd'."
 msgstr "Establece el directorio de nivel principal para almacenar los datos de perfilado. El predeterminado es 'pwd'."
 
-#: common.opt:2043
+#: common.opt:2047
 msgid "Enable correction of flow inconsistent profile data input."
 msgstr "Activa la corrección de datos de entrada de perfilado inconsistente de flujo."
 
-#: common.opt:2047
+#: common.opt:2051
 msgid "-fprofile-update=[single|atomic|prefer-atomic]\tSet the profile update method."
 msgstr "-fprofile-update=[single|atomic|prefer-atomic]\tEstablece el método de actualización del perfil."
 
-#: common.opt:2050
+#: common.opt:2054
 #, c-format
 msgid "unknown profile update method %qs"
 msgstr "método de actualización de perfil desconocido %qs"
 
-#: common.opt:2063
+#: common.opt:2067
 msgid "Enable common options for generating profile info for profile feedback directed optimizations."
 msgstr "Activa las opciones comunes para generar información de análisis de perfil para optimizaciones dirigidas por retroalimentación de perfil."
 
-#: common.opt:2067
+#: common.opt:2071
 msgid "Enable common options for generating profile info for profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr "Activa las opciones comunes para generar información de análisis de perfil para optimizaciones dirigidas por retroalimentación de perfili, y establece -fprofile-dir=."
 
-#: common.opt:2071
+#: common.opt:2075
 msgid "Enable common options for performing profile feedback directed optimizations."
 msgstr "Activa las opciones comunes para realizar optimizaciones dirigidas por retroalimentación de perfil."
 
-#: common.opt:2075
+#: common.opt:2079
 msgid "Enable common options for performing profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr "Activa las opciones comunes para realizar optimizaciones dirigidas por retroalimentación de perfil, y establece -fprofile-dir=."
 
-#: common.opt:2079
+#: common.opt:2083
 msgid "Insert code to profile values of expressions."
 msgstr "Inserta el código para perfilar valores de expresiones."
 
-#: common.opt:2083
+#: common.opt:2087
 msgid "Report on consistency of profile."
 msgstr "Informa sobre la coherencia del perfil."
 
-#: common.opt:2087
+#: common.opt:2091
 msgid "Enable function reordering that improves code placement."
 msgstr "Activa reordenación de funciones que mejora ubicación de código."
 
-#: common.opt:2091
+#: common.opt:2095
 msgid "Insert NOP instructions at each function entry."
 msgstr "Inserta instrucciones NOP en cada entrada de función."
 
-#: common.opt:2098
+#: common.opt:2102
 msgid "-frandom-seed=<string>\tMake compile reproducible using <string>."
 msgstr "-frandom-seed=<cadena>\tHace que se pueda reproducir la compilación utilizando la <cadena>."
 
-#: common.opt:2108
+#: common.opt:2112
 msgid "Record gcc command line switches in the object file."
 msgstr "Guarda las opciones de la línea de órdenes de gcc en el fichero objeto."
 
-#: common.opt:2112
+#: common.opt:2116
 msgid "Return small aggregates in registers."
 msgstr "Devuelve agregados small en registros."
 
-#: common.opt:2120
+#: common.opt:2124
 msgid "Tell DSE that the storage for a C++ object is dead when the constructor starts and when the destructor finishes."
 msgstr "Le dice al DSE que el almacenamiento para un objeto C++ está muerto cuando el constructor comienza y cuando el destructor termina."
 
-#: common.opt:2128
+#: common.opt:2132
 msgid "Relief of register pressure through live range shrinkage."
 msgstr "Alivio de la presión de registro a través del encogimiento de rango en vivo."
 
-#: common.opt:2132
+#: common.opt:2136
 msgid "Perform a register renaming optimization pass."
 msgstr "Realiza el paso de optimización de renombrado de registros."
 
-#: common.opt:2136
+#: common.opt:2140
 msgid "Perform a target dependent instruction fusion optimization pass."
 msgstr "Realiza paso de optimización por fusión de instrucciones dependiente de objetivo."
 
-#: common.opt:2140
+#: common.opt:2144
 msgid "Reorder basic blocks to improve code placement."
 msgstr "Reordena los bloques básicos para mejorar la ubicación del código."
 
-#: common.opt:2144
+#: common.opt:2148
 msgid "-freorder-blocks-algorithm=[simple|stc]\tSet the used basic block reordering algorithm."
 msgstr "-freorder-blocks-algorithm=[simple|stc]\tEstablece el algoritmo de ordenación de bloque básico usado."
 
-#: common.opt:2147
+#: common.opt:2151
 #, c-format
 msgid "unknown basic block reordering algorithm %qs"
 msgstr "algoritmo %qs de reordenación de bloque básico desconocido"
 
-#: common.opt:2157
+#: common.opt:2161
 msgid "Reorder basic blocks and partition into hot and cold sections."
 msgstr "Reordena los bloques básicos y particionar en secciones caliente y fría."
 
-#: common.opt:2161
+#: common.opt:2165
 msgid "Reorder functions to improve code placement."
 msgstr "Reordena las funciones para mejorar la ubicación del código."
 
-#: common.opt:2165
+#: common.opt:2169
 msgid "Add a common subexpression elimination pass after loop optimizations."
 msgstr "Ejecuta un paso de eliminación de subexpresión común después de las optimizaciones de bucles."
 
-#: common.opt:2173
+#: common.opt:2177
 msgid "Disable optimizations that assume default FP rounding behavior."
 msgstr "Desactiva las optimizaciones que asumen la conducta de un FP que redondea por defecto."
 
-#: common.opt:2177
+#: common.opt:2181
 msgid "Enable scheduling across basic blocks."
 msgstr "Activa la planificación entre bloques básicos."
 
-#: common.opt:2181
+#: common.opt:2185
 msgid "Enable register pressure sensitive insn scheduling."
 msgstr "Activa la planificación de insn sensible a la presión de registros."
 
-#: common.opt:2185
+#: common.opt:2189
 msgid "Allow speculative motion of non-loads."
 msgstr "Permite el movimiento especulativo de insn que no son load."
 
-#: common.opt:2189
+#: common.opt:2193
 msgid "Allow speculative motion of some loads."
 msgstr "Permite el movimiento especulativo de algunas loads."
 
-#: common.opt:2193
+#: common.opt:2197
 msgid "Allow speculative motion of more loads."
 msgstr "Permite el movimiento especulativo de más loads."
 
-#: common.opt:2197
+#: common.opt:2201
 msgid "-fsched-verbose=<number>\tSet the verbosity level of the scheduler."
 msgstr "-fsched-verbose=<número>\tEstablece el nivel de detalle del planificador."
 
-#: common.opt:2201
+#: common.opt:2205
 msgid "If scheduling post reload, do superblock scheduling."
 msgstr "Si se calendariza después de la recarga, hace la planificación de superbloque."
 
-#: common.opt:2209
+#: common.opt:2213
 msgid "Reschedule instructions before register allocation."
 msgstr "Recalendariza las instrucciones antes del alojamiento de registros."
 
-#: common.opt:2213
+#: common.opt:2217
 msgid "Reschedule instructions after register allocation."
 msgstr "Recalendariza las instrucciones después del alojamiento de registros."
 
-#: common.opt:2220
+#: common.opt:2224
 msgid "Schedule instructions using selective scheduling algorithm."
 msgstr "Calendariza instrucciones usando el algoritmo de planificación selectivo."
 
-#: common.opt:2224
+#: common.opt:2228
 msgid "Run selective scheduling after reload."
 msgstr "Ejecuta la planificación selectiva después de recargar."
 
-#: common.opt:2228
+#: common.opt:2232
 msgid "Run self-tests, using the given path to locate test files."
 msgstr "Corre autotests usando la ruta dada para localizar los ficheros de test."
 
-#: common.opt:2232
+#: common.opt:2236
 msgid "Perform software pipelining of inner loops during selective scheduling."
 msgstr "Realiza el `pipelining' de software de los bucles internos durante la planificación selectiva."
 
-#: common.opt:2236
+#: common.opt:2240
 msgid "Perform software pipelining of outer loops during selective scheduling."
 msgstr "Realiza el `pipelining' de software de los bucles externos durante la planificación selectiva."
 
-#: common.opt:2240
+#: common.opt:2244
 msgid "Reschedule pipelined regions without pipelining."
 msgstr "Recalendariza las regiones `pipelined' sin `pipelining'."
 
-#: common.opt:2244
+#: common.opt:2248
 msgid "Allow interposing function (or variables) by ones with different semantics (or initializer) respectively by dynamic linker."
 msgstr "Permite interponer función (o variables) por otras con semántica diferente (o inicializador) respectivamente por enlazador dinámico."
 
-#: common.opt:2250
+#: common.opt:2254
 msgid "Allow premature scheduling of queued insns."
 msgstr "Permite la planificación prematura de insns encoladas."
 
-#: common.opt:2254
+#: common.opt:2258
 msgid "-fsched-stalled-insns=<number>\tSet number of queued insns that can be prematurely scheduled."
 msgstr "-fsched-stalled-insns=<número>\tEstablece el número de insns encoladas que se pueden calendarizar prematuramente."
 
-#: common.opt:2262
+#: common.opt:2266
 msgid "Set dependence distance checking in premature scheduling of queued insns."
 msgstr "Establece la revisión de distancia de dependencias en la planificación prematura de insns encoladas."
 
-#: common.opt:2266
+#: common.opt:2270
 msgid "-fsched-stalled-insns-dep=<number>\tSet dependence distance checking in premature scheduling of queued insns."
 msgstr "-fsched-stalled-insns-dep=<número>\tEstablece la revisión de distancia de dependencias en la planificación prematura de insns encoladas."
 
-#: common.opt:2270
+#: common.opt:2274
 msgid "Enable the group heuristic in the scheduler."
 msgstr "Activa la heurística de grupo en el planificador."
 
-#: common.opt:2274
+#: common.opt:2278
 msgid "Enable the critical path heuristic in the scheduler."
 msgstr "Activa la heurística de ruta crítica en el planificador."
 
-#: common.opt:2278
+#: common.opt:2282
 msgid "Enable the speculative instruction heuristic in the scheduler."
 msgstr "Activa la heurística de instrucción especulativa en el planificador."
 
-#: common.opt:2282
+#: common.opt:2286
 msgid "Enable the rank heuristic in the scheduler."
 msgstr "Activa la heurística de rango en el planificador."
 
-#: common.opt:2286
+#: common.opt:2290
 msgid "Enable the last instruction heuristic in the scheduler."
 msgstr "Activa la heurística de última instrucción en el planificador."
 
-#: common.opt:2290
+#: common.opt:2294
 msgid "Enable the dependent count heuristic in the scheduler."
 msgstr "Activa la heurística de cuenta dependiente en el planificador."
 
-#: common.opt:2294
+#: common.opt:2298
 msgid "Access data in the same section from shared anchor points."
 msgstr "Accede datos en la misma sección que los puntos de anclaje compartidos."
 
-#: common.opt:2306
+#: common.opt:2310
 msgid "Turn on Redundant Extensions Elimination pass."
 msgstr "Activa el paso de Eliminación de Extensiones Redundantes."
 
-#: common.opt:2310
+#: common.opt:2314
 msgid "Show column numbers in diagnostics, when available.  Default on."
 msgstr "Muestra los números de columna en los diagnósticos, cuando estén disponible.  Activado por defecto."
 
-#: common.opt:2314
+#: common.opt:2318
 msgid "Emit function prologues only before parts of the function that need it, rather than at the top of the function."
 msgstr "Emite prólogos de función sólo después de que las partes de la función que los necesitan, en vez de al principio de la función."
 
-#: common.opt:2319
+#: common.opt:2323
 msgid "Shrink-wrap parts of the prologue and epilogue separately."
 msgstr "Estrecha-envuelve partes del prólogo y epílogo por separado."
 
-#: common.opt:2323
+#: common.opt:2327
 msgid "Disable optimizations observable by IEEE signaling NaNs."
 msgstr "Desactiva las optimizaciones observables con IEEE señalando NaNs."
 
-#: common.opt:2327
+#: common.opt:2331
 msgid "Disable floating point optimizations that ignore the IEEE signedness of zero."
 msgstr "Desactiva las optimizaciones de coma flotante que ignoran el signo de IEEE para cero."
 
-#: common.opt:2331
+#: common.opt:2335
 msgid "Convert floating point constants to single precision constants."
 msgstr "Convierte las constantes de coma flotante a constantes de precisión simple."
 
-#: common.opt:2335
+#: common.opt:2339
 msgid "Split lifetimes of induction variables when loops are unrolled."
 msgstr "Divide los tiempos de vida de las variables de inducción cuando se desenrollen los bucles."
 
-#: common.opt:2339
+#: common.opt:2343
 msgid "Generate discontiguous stack frames."
 msgstr "Genera marcos de pila discontiguos."
 
-#: common.opt:2343
+#: common.opt:2347
 msgid "Split wide types into independent registers."
 msgstr "Divide los tipos anchos en registros independientes."
 
-#: common.opt:2347
+#: common.opt:2351
 msgid "Enable backward propagation of use properties at the SSA level."
 msgstr "Activa la propagación hacia atrás de propiedades en uso a nivel SSA."
 
-#: common.opt:2351
+#: common.opt:2355
 msgid "Optimize conditional patterns using SSA PHI nodes."
 msgstr "Optimiza patrones condicionales usando nodos SSA PHI."
 
-#: common.opt:2355
+#: common.opt:2359
 msgid "Optimize amount of stdarg registers saved to stack at start of function."
 msgstr "Optimiza la cantidad de registros stdarg guardados en pila al principio de la función."
 
-#: common.opt:2359
+#: common.opt:2363
 msgid "Apply variable expansion when loops are unrolled."
 msgstr "Aplica la expansión de variables cuando se desenrollan los bucles."
 
-#: common.opt:2363
+#: common.opt:2367
 msgid "-fstack-check=[no|generic|specific]\tInsert stack checking code into the program."
 msgstr "-fstack-check=[no|generic|specific]\tInserta código de revisión de la pila en el programa."
 
-#: common.opt:2367
+#: common.opt:2371
 msgid "Insert stack checking code into the program.  Same as -fstack-check=specific."
 msgstr "Inserta código de revisión de la pila en el programai.  Igual que -fstach-check=specific."
 
-#: common.opt:2371
+#: common.opt:2375
 msgid "Insert code to probe each page of stack space as it is allocated to protect from stack-clash style attacks."
 msgstr ""
 
-#: common.opt:2379
+#: common.opt:2383
 msgid "-fstack-limit-register=<register>\tTrap if the stack goes past <register>."
 msgstr "-fstack-limit-register=<register>\tCaptura si la pila pasa del <registro>."
 
-#: common.opt:2383
+#: common.opt:2387
 msgid "-fstack-limit-symbol=<name>\tTrap if the stack goes past symbol <name>."
 msgstr "-fstack-limit-symbol=<nombre>\tCaptura si la pila pasa del símbolo <nombre>."
 
-#: common.opt:2387
+#: common.opt:2391
 msgid "Use propolice as a stack protection method."
 msgstr "Usa propolice como un método de protección de pila."
 
-#: common.opt:2391
+#: common.opt:2395
 msgid "Use a stack protection method for every function."
 msgstr "Usa un método de protección de pila para cada función."
 
-#: common.opt:2395
+#: common.opt:2399
 msgid "Use a smart stack protection method for certain functions."
 msgstr "Usa un método de protección de pila inteligente para ciertas funciones."
 
-#: common.opt:2399
+#: common.opt:2403
 msgid "Use stack protection method only for functions with the stack_protect attribute."
 msgstr "Usa método de protección de pila solo para funciones con el atributo stack_protect."
 
-#: common.opt:2403
+#: common.opt:2407
 msgid "Output stack usage information on a per-function basis."
 msgstr "Información de uso de pila de salida basada por función."
 
-#: common.opt:2415
+#: common.opt:2419
 msgid "Assume strict aliasing rules apply."
 msgstr "Asume que se aplican las reglas estrictas de alias."
 
-#: common.opt:2419
+#: common.opt:2423
 msgid "Treat signed overflow as undefined.  Negated as -fwrapv -fwrapv-pointer."
 msgstr "Trata el desbordamiento con signo como indefinido.  Negado como -fwrapv -fwrapv-pointer."
 
-#: common.opt:2423
+#: common.opt:2427
 msgid "Implement __atomic operations via libcalls to legacy __sync functions."
 msgstr "Implementa operaciones __atomic mediante llamadas de biblioteca a funciones __sync antiguas."
 
-#: common.opt:2427
+#: common.opt:2431
 msgid "Check for syntax errors, then stop."
 msgstr "Busca errores de sintaxis, y termina."
 
-#: common.opt:2431
+#: common.opt:2435
 msgid "Create data files needed by \"gcov\"."
 msgstr "Crea ficheros de datos necesarios para \"gcov\"."
 
-#: common.opt:2435
+#: common.opt:2439
 msgid "Perform jump threading optimizations."
 msgstr "Realiza optimizaciones de hilado de saltos."
 
-#: common.opt:2439
+#: common.opt:2443
 msgid "Report the time taken by each compiler pass."
 msgstr "Reporta el tiempo tomado por cada paso del compilador."
 
-#: common.opt:2443
+#: common.opt:2447
 msgid "Record times taken by sub-phases separately."
 msgstr "Registra los tiempos tomados por subfases por separado."
 
-#: common.opt:2447
+#: common.opt:2451
 msgid "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tSet the default thread-local storage code generation model."
 msgstr "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tEstablece el modelo de generación de código por defecto para almacenamiento thread-local."
 
-#: common.opt:2450
+#: common.opt:2454
 #, c-format
 msgid "unknown TLS model %qs"
 msgstr "modelo TLS %qs desconocido"
 
-#: common.opt:2466
+#: common.opt:2470
 msgid "Reorder top level functions, variables, and asms."
 msgstr "Reordena las funciones de nivel superior, variables y asms."
 
-#: common.opt:2470
+#: common.opt:2474
 msgid "Perform superblock formation via tail duplication."
 msgstr "Realiza la formación de superbloques a través de la duplicación de colas."
 
-#: common.opt:2474
+#: common.opt:2478
 msgid "For targets that normally need trampolines for nested functions, always generate them instead of using descriptors."
 msgstr "Para objetivos que normalmente necesitan trampolines para las funciones anidadas, siempre los genera en lugar de usar descriptores."
 
-#: common.opt:2482
+#: common.opt:2486
 msgid "Assume floating-point operations can trap."
 msgstr "Asume que las operaciones de coma flotante pueden atrapar."
 
-#: common.opt:2486
+#: common.opt:2490
 msgid "Trap for signed overflow in addition, subtraction and multiplication."
 msgstr "Atrapar desbordamientos signed en adición, sustracción y multiplicación."
 
-#: common.opt:2490
+#: common.opt:2494
 msgid "Enable SSA-CCP optimization on trees."
 msgstr "Activa la optimización SSA-CCP en árboles."
 
-#: common.opt:2494
+#: common.opt:2498
 msgid "Enable SSA-BIT-CCP optimization on trees."
 msgstr "Activa la optimización SSA-BIT-CCP en árboles."
 
-#: common.opt:2502
+#: common.opt:2506
 msgid "Enable loop header copying on trees."
 msgstr "Activa la copia de encabezado de bucles en árboles."
 
-#: common.opt:2510
+#: common.opt:2514
 msgid "Enable SSA coalescing of user variables."
 msgstr "Activa coalescencia SSA de variables de usuario."
 
-#: common.opt:2518
+#: common.opt:2522
 msgid "Enable copy propagation on trees."
 msgstr "Activa la propagación de copia en árboles."
 
-#: common.opt:2526
+#: common.opt:2530
 msgid "Transform condition stores into unconditional ones."
 msgstr "Transforma los almacenamientos condicionales a incondicionales."
 
-#: common.opt:2530
+#: common.opt:2534
 msgid "Perform conversions of switch initializations."
 msgstr "Realiza la conversión de las inicializaciones de switch."
 
-#: common.opt:2534
+#: common.opt:2538
 msgid "Enable SSA dead code elimination optimization on trees."
 msgstr "Activa la optimización de eliminación de código muerto SSA en árboles."
 
-#: common.opt:2538
+#: common.opt:2542
 msgid "Enable dominator optimizations."
 msgstr "Activa las optimizaciones dominadoras."
 
-#: common.opt:2542
+#: common.opt:2546
 msgid "Enable tail merging on trees."
 msgstr "Activa la mezcla de colas en árboles."
 
-#: common.opt:2546
+#: common.opt:2550
 msgid "Enable dead store elimination."
 msgstr "Activa la eliminación de almacenamiento muerto."
 
-#: common.opt:2550
+#: common.opt:2554
 msgid "Enable forward propagation on trees."
 msgstr "Activa la propagación hacia adelante en árboles."
 
-#: common.opt:2554
+#: common.opt:2558
 msgid "Enable Full Redundancy Elimination (FRE) on trees."
 msgstr "Activa la Eliminación de Redundancia Completa en árboles."
 
-#: common.opt:2558
+#: common.opt:2562
 msgid "Enable string length optimizations on trees."
 msgstr "Activa la optimizaciones de longitud de cadenas en árboles."
 
-#: common.opt:2562
+#: common.opt:2566
 msgid "Detect paths that trigger erroneous or undefined behavior due to dereferencing a null pointer.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr "Detecta rutas que disparan comportamiento erróneo o indefinido debido a desreferencia de puntero nulo.  Aisla esas rutas del flujo de control principal y convierte la sentencia con comportamiento erróneo o indefinido en una trampa."
 
-#: common.opt:2568
+#: common.opt:2572
 msgid "Detect paths that trigger erroneous or undefined behavior due to a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr "Detecta rutas que disparan comportamiento erróneo o indefinido debido a un uso indebido de un valor nuloen un atributo returns_nonnull o nonnull.  Aisla esas rutas del flujo de control principal y convierte la sentencia con comportamiento erróneo o indefinido en una trampa."
 
-#: common.opt:2575
+#: common.opt:2579
 msgid "Enable loop distribution on trees."
 msgstr "Activa la distribución de bucles en árboles."
 
-#: common.opt:2579
+#: common.opt:2583
 msgid "Enable loop distribution for patterns transformed into a library call."
 msgstr "Activa la distribución de bucles por patrones transformados en una llamada a biblioteca."
 
-#: common.opt:2583
+#: common.opt:2587
 msgid "Enable loop invariant motion on trees."
 msgstr "Permite el movimiento invariante de bucles en árboles."
 
-#: common.opt:2591
+#: common.opt:2595
 msgid "Create canonical induction variables in loops."
 msgstr "Crea variables de inducción canónica en los bucles."
 
-#: common.opt:2595
+#: common.opt:2599
 msgid "Enable loop optimizations on tree level."
 msgstr "Activa las optimizaciones de bucles a nivel de árbol."
 
-#: common.opt:2599
+#: common.opt:2603
 msgid "-ftree-parallelize-loops=<number>\tEnable automatic parallelization of loops."
 msgstr "-ftree-parallelize-loops=<número>\tActiva la paralelización automática de bucles."
 
-#: common.opt:2603
+#: common.opt:2607
 msgid "Enable hoisting loads from conditional pointers."
 msgstr "Activa las cargas de elevación de punteros condicionales."
 
-#: common.opt:2607
+#: common.opt:2611
 msgid "Enable SSA-PRE optimization on trees."
 msgstr "Activa las optimizaciones SSA-PRE en árboles."
 
-#: common.opt:2611
+#: common.opt:2615
 msgid "In SSA-PRE optimization on trees, enable partial-partial redundancy elimination."
 msgstr "En optimización SSA-PRE en árboles, activa eliminación de redundancia parcial-parcial."
 
-#: common.opt:2615
+#: common.opt:2619
 msgid "Perform function-local points-to analysis on trees."
 msgstr "Realiza el análisis puntero-a función-local en árboles."
 
-#: common.opt:2619
+#: common.opt:2623
 msgid "Enable reassociation on tree level."
 msgstr "Activa la reasociación a nivel de árbol."
 
-#: common.opt:2627
+#: common.opt:2631
 msgid "Enable SSA code sinking on trees."
 msgstr "Activa el hundimiento de código SSA en árboles."
 
-#: common.opt:2631
+#: common.opt:2635
 msgid "Perform straight-line strength reduction."
 msgstr "Realiza reducción de fuerza de línea directa."
 
-#: common.opt:2635
+#: common.opt:2639
 msgid "Perform scalar replacement of aggregates."
 msgstr "Realiza el reemplazo escalar de agregados."
 
-#: common.opt:2639
+#: common.opt:2643
 msgid "Replace temporary expressions in the SSA->normal pass."
 msgstr "Reemplaza expresiones temporales en el paso SSA->normal."
 
-#: common.opt:2643
+#: common.opt:2647
 msgid "Perform live range splitting during the SSA->normal pass."
 msgstr "Realizar la división de rango vivo durante el paso SSA->normal."
 
-#: common.opt:2647
+#: common.opt:2651
 msgid "Perform Value Range Propagation on trees."
 msgstr "Realiza la Propagación de Rango Valor en árboles."
 
-#: common.opt:2651
+#: common.opt:2655
 msgid "Split paths leading to loop backedges."
 msgstr "Divide las rutas que llevan a bordes traseros de bucle."
 
-#: common.opt:2655
+#: common.opt:2659
 msgid "Assume common declarations may be overridden with ones with a larger trailing array."
 msgstr "Asume que las declaraciones comunes pueden sustituirse por las que tienen un array postrero mayor."
 
-#: common.opt:2660
+#: common.opt:2664
 msgid "Compile whole compilation unit at a time."
 msgstr "Compila la unidad de compilación completa a la vez."
 
-#: common.opt:2664
+#: common.opt:2668
 msgid "Perform loop unrolling when iteration count is known."
 msgstr "Realiza el desenrollamiento del bucle cuando se conoce la cuenta de iteración."
 
-#: common.opt:2668
+#: common.opt:2672
 msgid "Perform loop unrolling for all loops."
 msgstr "Realiza el desenrollamiento del bucle para todos los bucles."
 
-#: common.opt:2679
+#: common.opt:2683
 msgid "Allow optimization for floating-point arithmetic which may change the result of the operation due to rounding."
 msgstr "Permite la optimización para la aritmética de coma flotante la cual puede cambiar el resultado de la operación debido a redondeo."
 
-#: common.opt:2684
+#: common.opt:2688
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr "Igual que -fassociative-math para las expresiones que incluyen división."
 
-#: common.opt:2692
+#: common.opt:2696
 msgid "Allow math optimizations that may violate IEEE or ISO standards."
 msgstr "Permite optimizaciones matemáticas que pueden violar los estándares IEEE ó ISO."
 
-#: common.opt:2696
+#: common.opt:2700
 msgid "Perform loop unswitching."
 msgstr "Realiza la eliminación de opciones de bucle."
 
-#: common.opt:2700
+#: common.opt:2704
 msgid "Perform loop splitting."
 msgstr "Realiza la división de bucles."
 
-#: common.opt:2704
+#: common.opt:2708
 msgid "Just generate unwind tables for exception handling."
 msgstr "Sólo genera tablas de desenredo para manejo de excepciones."
 
-#: common.opt:2708
+#: common.opt:2712
 msgid "Use the bfd linker instead of the default linker."
 msgstr "Usa el enlazador bfd eb lugar del predeterminado."
 
-#: common.opt:2712
+#: common.opt:2716
 msgid "Use the gold linker instead of the default linker."
 msgstr "Usa el enlazador de oro eb lugar del predeterminado."
 
-#: common.opt:2724
+#: common.opt:2728
 msgid "Perform variable tracking."
 msgstr "Realiza seguimiento de variables."
 
-#: common.opt:2732
+#: common.opt:2736
 msgid "Perform variable tracking by annotating assignments."
 msgstr "Realiza seguimiento de variables con asignación de anotaciones."
 
-#: common.opt:2738
+#: common.opt:2742
 msgid "Toggle -fvar-tracking-assignments."
 msgstr "Cambia -fvar-tracking-assignments."
 
-#: common.opt:2746
+#: common.opt:2750
 msgid "Perform variable tracking and also tag variables that are uninitialized."
 msgstr "Realiza el seguimiento de variables y también marca las variables que no se inicializaron."
 
-#: common.opt:2751
+#: common.opt:2755
 msgid "Enable vectorization on trees."
 msgstr "Activa la vectorización en árboles."
 
-#: common.opt:2759
+#: common.opt:2763
 msgid "Enable loop vectorization on trees."
 msgstr "Activa la vectorización de bucles en árboles."
 
-#: common.opt:2763
+#: common.opt:2767
 msgid "Enable basic block vectorization (SLP) on trees."
 msgstr "Activa la vectorización de bloque básico (SLP) en árboles."
 
-#: common.opt:2767
+#: common.opt:2771
 msgid "Specifies the cost model for vectorization. -fvect-cost-model=[unlimited|dynamic|cheap]\tSpecifies the cost model for vectorization."
 msgstr "Especifica el modelo de coste para vectorización. -fvect-cost-model=[unlimited|dynamic|cheap]\tEspecifica el modelo de coste para vectorización."
 
-#: common.opt:2772
+#: common.opt:2776
 msgid "-fsimd-cost-model=[unlimited|dynamic|cheap]\tSpecifies the vectorization cost model for code marked with a simd directive."
 msgstr "-fsimd-cost-model=[unlimited|dynamic|cheap]\tEspecifica el modelo de coste de la vectorización para código marcado con directiva simd."
 
-#: common.opt:2775
+#: common.opt:2779
 #, c-format
 msgid "unknown vectorizer cost model %qs"
 msgstr "modelo %qs de coste de vectorizador desconocido"
 
-#: common.opt:2788
+#: common.opt:2792
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr "Activa el modelo de coste de vectorizador dinámico.  Se preserva por compatibilidad hacia atrás."
 
-#: common.opt:2796
+#: common.opt:2800
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr "Activa la propagación de copia de la información escalar-evolución."
 
-#: common.opt:2806
+#: common.opt:2810
 msgid "Add extra commentary to assembler output."
 msgstr "Agrega comentarios extra a la salida de ensamblador."
 
-#: common.opt:2810
+#: common.opt:2814
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility."
 msgstr "-fvisibility=[default|internal|hidden|protected]\tEstablece la visibilidad de símbolos por defecto."
 
-#: common.opt:2813
+#: common.opt:2817
 #, c-format
 msgid "unrecognized visibility value %qs"
 msgstr "no se reconoce el valor de visibilidad %qs"
 
-#: common.opt:2829
+#: common.opt:2833
 msgid "Validate vtable pointers before using them."
 msgstr "Valida los punteros vtable antes de usarlos."
 
-#: common.opt:2832
+#: common.opt:2836
 #, c-format
 msgid "unknown vtable verify initialization priority %qs"
 msgstr "prioridad %qs de inicialización de verificación de vtable desconocida."
 
-#: common.opt:2845
+#: common.opt:2849
 msgid "Output vtable verification counters."
 msgstr "Contadores de verificación de vtable de salida."
 
-#: common.opt:2849
+#: common.opt:2853
 msgid "Output vtable verification pointer sets information."
 msgstr "Información sobre los conjuntos de vectores de verificación de vtable de salida."
 
-#: common.opt:2853
+#: common.opt:2857
 msgid "Use expression value profiles in optimizations."
 msgstr "Usa perfiles de valor de expresión en las optimizaciones."
 
-#: common.opt:2857
+#: common.opt:2861
 msgid "Construct webs and split unrelated uses of single variable."
 msgstr "Construye redes y divide usos no relacionados de una sola variable."
 
-#: common.opt:2861
+#: common.opt:2865
 msgid "Enable conditional dead code elimination for builtin calls."
 msgstr "Activa la eliminación de código muerto condicional para llamadas internas."
 
-#: common.opt:2865
+#: common.opt:2869
 msgid "Perform whole program optimizations."
 msgstr "Realiza optimizaciones del programa completo."
 
 # wraps around? No entiendo bien. cfuga
-#: common.opt:2869
+#: common.opt:2873
 msgid "Assume pointer overflow wraps around."
 msgstr "Asume que el desbordamiento de punteros se envuelve."
 
 # wraps around? No entiendo bien. cfuga
-#: common.opt:2873
+#: common.opt:2877
 msgid "Assume signed arithmetic overflow wraps around."
 msgstr "Asume que el desbordamiento aritmético con signo se envuelve."
 
-#: common.opt:2877
+#: common.opt:2881
 msgid "Put zero initialized data in the bss section."
 msgstr "Pone los datos inicializados a cero en la sección bss."
 
-#: common.opt:2881
+#: common.opt:2885
 msgid "Generate debug information in default format."
 msgstr "Genera información de depuración en el formato por defecto."
 
-#: common.opt:2885
+#: common.opt:2889
 msgid "Assume assembler support for (DWARF2+) .loc directives"
 msgstr "Asume soporte del ensamblador para las directivas .loc (DWARF2+)"
 
-#: common.opt:2889
+#: common.opt:2893
 msgid "Assume assembler support for view in (DWARF2+) .loc directives"
 msgstr "Asume soporte del ensamblador para visualización en las directivas .loc (DWARF2+)"
 
-#: common.opt:2892 common.opt:2896 common.opt:2900 common.opt:2904
+#: common.opt:2896 common.opt:2900 common.opt:2904 common.opt:2908
 #, c-format
 msgid "switch %qs no longer supported"
 msgstr "la opción %qs ya no se admite"
 
-#: common.opt:2909
+#: common.opt:2913
 msgid "Record DW_AT_decl_column and DW_AT_call_column in DWARF."
 msgstr "Registro DW_AT_decl_column y DW_AT_call_column en DWARF."
 
-#: common.opt:2913
+#: common.opt:2917
 msgid "Generate debug information in default version of DWARF format."
 msgstr "Genera información de depuración en la versión predeterminada del formato DWARF."
 
-#: common.opt:2917
+#: common.opt:2921
 msgid "Generate debug information in DWARF v2 (or later) format."
 msgstr "Genera información de depuración en el formato DWARF v2 (o posterior)."
 
-#: common.opt:2921
+#: common.opt:2925
 msgid "Generate debug information in default extended format."
 msgstr "Genera información de depuración en el formato extendido por defecto."
 
-#: common.opt:2925
+#: common.opt:2929
 msgid "Generate extended entry point information for inlined functions"
 msgstr "Genera información extendida sobre el punto de entrada para funciones en línea"
 
-#: common.opt:2929
+#: common.opt:2933
 msgid "Compute locview reset points based on insn length estimates"
 msgstr ""
 
-#: common.opt:2937
+#: common.opt:2941
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr "No genera nombres públicos DWARF y secciones de tipos públicos."
 
-#: common.opt:2941
+#: common.opt:2945
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr "Genera nombres públicos DWARF y secciones de tipos públicos."
 
-#: common.opt:2945
+#: common.opt:2949
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr "Genera nombres públicos DWARF y secciones de tipos públicos con extensiones GNU."
 
-#: common.opt:2949
+#: common.opt:2953
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr "Guarda las opciones de la línea de órdenes de gcc en DW_AT_producer de DWARF."
 
-#: common.opt:2953
+#: common.opt:2957
 msgid "Generate debug information in separate .dwo files."
 msgstr "Genera información de depuración en ficheros .dwo separados."
 
-#: common.opt:2957
+#: common.opt:2961
 msgid "Generate debug information in STABS format."
 msgstr "Genera información de depuración en el formato STABS."
 
-#: common.opt:2961
+#: common.opt:2965
 msgid "Generate debug information in extended STABS format."
 msgstr "Genera información de depuración en el formato STABS extendido."
 
-#: common.opt:2965
+#: common.opt:2969
 msgid "Emit progressive recommended breakpoint locations."
 msgstr ""
 
-#: common.opt:2969
+#: common.opt:2973
 msgid "Don't emit DWARF additions beyond selected version."
 msgstr "No emite adiciones DWARF más allá de la versión seleccionada."
 
-#: common.opt:2973
+#: common.opt:2977
 msgid "Toggle debug information generation."
 msgstr "Cambia la generación de información de depuración."
 
-#: common.opt:2977
+#: common.opt:2981
 msgid "Augment variable location lists with progressive views."
 msgstr ""
 
-#: common.opt:2984
+#: common.opt:2988
 msgid "Generate debug information in VMS format."
 msgstr "Genera información de depuración en el formato VMS."
 
-#: common.opt:2988
+#: common.opt:2992
 msgid "Generate debug information in XCOFF format."
 msgstr "Genera información de depuración en el formato XCOFF."
 
-#: common.opt:2992
+#: common.opt:2996
 msgid "Generate debug information in extended XCOFF format."
 msgstr "Genera información de depuración en el formato XCOFF extendido."
 
-#: common.opt:3010
+#: common.opt:3014
 msgid "Generate compressed debug sections."
 msgstr "Genera secciones de depuración comprimidas."
 
-#: common.opt:3014
+#: common.opt:3018
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>."
 msgstr "-gz=<formato>\tGenera secciones de depuración comprimidas en formato <formato>."
 
-#: common.opt:3021
+#: common.opt:3025
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory."
 msgstr "-iplugindir=<dir>\tDefine <dir> como el directorio de plugins por defecto."
 
-#: common.opt:3025
+#: common.opt:3029
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory."
 msgstr "-imultilib <dir>\tDefine <dir> como el subdirectorio de inclusión de multilib."
 
-#: common.opt:3047
+#: common.opt:3051
 msgid "-o <file>\tPlace output into <file>."
 msgstr "-o <fichero>\tColoca la salida en el <fichero>."
 
-#: common.opt:3051
+#: common.opt:3055
 msgid "Enable function profiling."
 msgstr "Activa el análisis de perfil de las funciones."
 
-#: common.opt:3061
+#: common.opt:3065
 msgid "Like -pedantic but issue them as errors."
 msgstr "Como -pedantic pero los muestra como errores."
 
-#: common.opt:3101
+#: common.opt:3105
 msgid "Do not display functions compiled or elapsed time."
 msgstr "No muestra las funciones compiladas o el tiempo transcurrido."
 
-#: common.opt:3133
+#: common.opt:3137
 msgid "Enable verbose output."
 msgstr "Activa la salida detallada."
 
-#: common.opt:3137
+#: common.opt:3141
 msgid "Display the compiler's version."
 msgstr "Muestra la versión del compilador."
 
-#: common.opt:3141
+#: common.opt:3145
 msgid "Suppress warnings."
 msgstr "Suprime avisos."
 
-#: common.opt:3151
+#: common.opt:3155
 msgid "Create a shared library."
 msgstr "Crea una biblioteca compartida."
 
-#: common.opt:3196
+#: common.opt:3200
 msgid "Don't create a dynamically linked position independent executable."
 msgstr "No genera un ejecutable independiente de posición enlazado dinámicamente."
 
-#: common.opt:3200
+#: common.opt:3204
 msgid "Create a dynamically linked position independent executable."
 msgstr "Genera un ejecutable independiente de posición enlazado dinámicamente."
 
-#: common.opt:3204
+#: common.opt:3208
 msgid "Create a static position independent executable."
 msgstr "Genera un ejecutable independiente de posición estático."
 
-#: common.opt:3211
+#: common.opt:3215
 msgid "Use caller save register across calls if possible."
 msgstr "Usa registro de guarda de invocador entre llamadas si es posible."
 
-#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:598 cp/cvt.c:1308
+#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:599 cp/cvt.c:1308
 #: cp/cvt.c:1561
 #, gcc-internal-format
 msgid "value computed is not used"
@@ -15738,7 +15740,7 @@
 msgstr "se esperaba un tipo booleano"
 
 #: go/gofrontend/expressions.cc:4331 c/c-parser.c:13477 c/c-parser.c:13484
-#: cp/parser.c:33264 cp/parser.c:33271
+#: cp/parser.c:33261 cp/parser.c:33268
 #, gcc-internal-format
 msgid "expected integer"
 msgstr "se esperaba un entero"
@@ -16155,14 +16157,14 @@
 msgid "ignoring attribute %qE because it conflicts with attribute %qs"
 msgstr "Se hace caso omiso del atributo %qE debido a un conflicto con el atributo %qs"
 
-#: attribs.c:449 c-family/c-attribs.c:1894 cp/decl.c:13690 cp/friend.c:302
-#: cp/tree.c:4559
+#: attribs.c:449 c-family/c-attribs.c:1905 cp/decl.c:13714 cp/friend.c:302
+#: cp/tree.c:4607
 #, gcc-internal-format
 msgid "previous declaration here"
 msgstr "declaración previa aquí"
 
 #. Warn about and ignore all others for now, but store them.
-#: attribs.c:564 c-family/c-attribs.c:2717 objc/objc-act.c:4963
+#: attribs.c:564 c-family/c-attribs.c:2728 objc/objc-act.c:4963
 #: objc/objc-act.c:6932 objc/objc-act.c:8119 objc/objc-act.c:8170
 #, gcc-internal-format
 msgid "%qE attribute directive ignored"
@@ -16181,17 +16183,17 @@
 #. This is a c++11 attribute that appertains to a
 #. type-specifier, outside of the definition of, a class
 #. type.  Ignore it.
-#: attribs.c:590 cp/decl.c:10999
+#: attribs.c:590 cp/decl.c:11023
 #, gcc-internal-format
 msgid "attribute ignored"
 msgstr "se descarta el atributo"
 
-#: attribs.c:592 cp/decl.c:11000
+#: attribs.c:592 cp/decl.c:11024
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr "un atributo que atañe a un especificador de tipo se descarta"
 
-#: attribs.c:610 c-family/c-attribs.c:3219
+#: attribs.c:610 c-family/c-attribs.c:3230
 #, gcc-internal-format
 msgid "%qE attribute does not apply to types"
 msgstr "el atributo %qE no se aplica a tipos"
@@ -16207,40 +16209,40 @@
 msgstr "se descartan los atributos de tipo después de que el tipo ya se definió"
 
 #: attribs.c:691 attribs.c:1622 attribs.c:1632 attribs.c:1642
-#: c-family/c-attribs.c:540 c-family/c-attribs.c:559 c-family/c-attribs.c:577
-#: c-family/c-attribs.c:607 c-family/c-attribs.c:628 c-family/c-attribs.c:649
-#: c-family/c-attribs.c:690 c-family/c-attribs.c:717 c-family/c-attribs.c:733
-#: c-family/c-attribs.c:750 c-family/c-attribs.c:766 c-family/c-attribs.c:792
-#: c-family/c-attribs.c:807 c-family/c-attribs.c:835 c-family/c-attribs.c:852
-#: c-family/c-attribs.c:870 c-family/c-attribs.c:893 c-family/c-attribs.c:931
-#: c-family/c-attribs.c:954 c-family/c-attribs.c:971 c-family/c-attribs.c:1000
-#: c-family/c-attribs.c:1021 c-family/c-attribs.c:1042
-#: c-family/c-attribs.c:1069 c-family/c-attribs.c:1099
-#: c-family/c-attribs.c:1136 c-family/c-attribs.c:1189
-#: c-family/c-attribs.c:1255 c-family/c-attribs.c:1313
-#: c-family/c-attribs.c:1402 c-family/c-attribs.c:1432
-#: c-family/c-attribs.c:1483 c-family/c-attribs.c:1998
-#: c-family/c-attribs.c:2035 c-family/c-attribs.c:2096
-#: c-family/c-attribs.c:2152 c-family/c-attribs.c:2230
-#: c-family/c-attribs.c:2312 c-family/c-attribs.c:2371
-#: c-family/c-attribs.c:2390 c-family/c-attribs.c:2498
-#: c-family/c-attribs.c:2514 c-family/c-attribs.c:2530
-#: c-family/c-attribs.c:2551 c-family/c-attribs.c:2608
-#: c-family/c-attribs.c:2635 c-family/c-attribs.c:2690
-#: c-family/c-attribs.c:2870 c-family/c-attribs.c:2891
-#: c-family/c-attribs.c:3004 c-family/c-attribs.c:3031
-#: c-family/c-attribs.c:3221 c-family/c-attribs.c:3239
-#: c-family/c-attribs.c:3262 c-family/c-attribs.c:3301
-#: c-family/c-attribs.c:3383 c-family/c-attribs.c:3439
-#: c-family/c-attribs.c:3455 c-family/c-attribs.c:3549
-#: c-family/c-common.c:5600 config/darwin.c:2072 config/arm/arm.c:6868
+#: c-family/c-attribs.c:547 c-family/c-attribs.c:566 c-family/c-attribs.c:584
+#: c-family/c-attribs.c:614 c-family/c-attribs.c:635 c-family/c-attribs.c:656
+#: c-family/c-attribs.c:697 c-family/c-attribs.c:728 c-family/c-attribs.c:744
+#: c-family/c-attribs.c:761 c-family/c-attribs.c:777 c-family/c-attribs.c:803
+#: c-family/c-attribs.c:818 c-family/c-attribs.c:846 c-family/c-attribs.c:863
+#: c-family/c-attribs.c:881 c-family/c-attribs.c:904 c-family/c-attribs.c:942
+#: c-family/c-attribs.c:965 c-family/c-attribs.c:982 c-family/c-attribs.c:1011
+#: c-family/c-attribs.c:1032 c-family/c-attribs.c:1053
+#: c-family/c-attribs.c:1080 c-family/c-attribs.c:1110
+#: c-family/c-attribs.c:1147 c-family/c-attribs.c:1200
+#: c-family/c-attribs.c:1266 c-family/c-attribs.c:1324
+#: c-family/c-attribs.c:1413 c-family/c-attribs.c:1443
+#: c-family/c-attribs.c:1494 c-family/c-attribs.c:2009
+#: c-family/c-attribs.c:2046 c-family/c-attribs.c:2107
+#: c-family/c-attribs.c:2163 c-family/c-attribs.c:2241
+#: c-family/c-attribs.c:2323 c-family/c-attribs.c:2382
+#: c-family/c-attribs.c:2401 c-family/c-attribs.c:2509
+#: c-family/c-attribs.c:2525 c-family/c-attribs.c:2541
+#: c-family/c-attribs.c:2562 c-family/c-attribs.c:2619
+#: c-family/c-attribs.c:2646 c-family/c-attribs.c:2701
+#: c-family/c-attribs.c:2881 c-family/c-attribs.c:2902
+#: c-family/c-attribs.c:3015 c-family/c-attribs.c:3042
+#: c-family/c-attribs.c:3232 c-family/c-attribs.c:3250
+#: c-family/c-attribs.c:3273 c-family/c-attribs.c:3312
+#: c-family/c-attribs.c:3394 c-family/c-attribs.c:3450
+#: c-family/c-attribs.c:3466 c-family/c-attribs.c:3560
+#: c-family/c-common.c:5598 config/darwin.c:2072 config/arm/arm.c:6868
 #: config/arm/arm.c:6896 config/arm/arm.c:6913 config/avr/avr.c:9698
-#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6497
-#: config/i386/i386.c:41520 config/ia64/ia64.c:788
-#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33056
-#: config/spu/spu.c:3743 ada/gcc-interface/utils.c:6244
-#: ada/gcc-interface/utils.c:6261 ada/gcc-interface/utils.c:6277
-#: ada/gcc-interface/utils.c:6303 brig/brig-lang.c:476 lto/lto-lang.c:283
+#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6500
+#: config/i386/i386.c:41514 config/ia64/ia64.c:788
+#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33112
+#: config/spu/spu.c:3743 ada/gcc-interface/utils.c:6249
+#: ada/gcc-interface/utils.c:6266 ada/gcc-interface/utils.c:6282
+#: ada/gcc-interface/utils.c:6308 brig/brig-lang.c:476 lto/lto-lang.c:283
 #, gcc-internal-format
 msgid "%qE attribute ignored"
 msgstr "se descarta el atributo %qE"
@@ -16608,88 +16610,106 @@
 msgid "%Kattempt to free a non-heap object"
 msgstr "%Kse intenta liberar un objeto que no es de pila"
 
-#: calls.c:1434
+#: calls.c:1291 file-prefix-map.c:50
 #, gcc-internal-format
+msgid "invalid argument %qs to %qs"
+msgstr "argumento %qs no válido para %qs"
+
+#: calls.c:1452
+#, gcc-internal-format
 msgid "%Kargument %i value %qE is negative"
 msgstr "%Kargumento %i, valor %qE, negativo"
 
-#: calls.c:1452
+#: calls.c:1470
 #, gcc-internal-format
 msgid "%Kargument %i value is zero"
 msgstr "el valor del %Kargumento %i es cero"
 
-#: calls.c:1469
+#: calls.c:1487
 #, gcc-internal-format
 msgid "%Kargument %i value %qE exceeds maximum object size %E"
 msgstr "%Kargumento %i, valor %qE, supera el tamaño máximo %E del objeto"
 
-#: calls.c:1483
+#: calls.c:1501
 #, gcc-internal-format
 msgid "%Kargument %i range [%E, %E] is negative"
 msgstr "el %Kargumento %i, rango [%E, %E], es negativo"
 
-#: calls.c:1490
+#: calls.c:1508
 #, gcc-internal-format
 msgid "%Kargument %i range [%E, %E] exceeds maximum object size %E"
 msgstr "%Kargumento %i, rango [%E, %E], supera el tamaño máximo %E del objeto"
 
-#: calls.c:1520
+#: calls.c:1538
 #, gcc-internal-format
 msgid "%Kproduct %<%E * %E%> of arguments %i and %i exceeds %<SIZE_MAX%>"
 msgstr "el %Kproducto %<%E * %E%> de los argumentos %i y %i supera %<SIZE_MAX%>"
 
-#: calls.c:1526
+#: calls.c:1544
 #, gcc-internal-format
 msgid "%Kproduct %<%E * %E%> of arguments %i and %i exceeds maximum object size %E"
 msgstr "el %Kproducto %<%E * %E%> de los argumentos %i y %i supera el tamaño máximo %E del objeto"
 
-#: calls.c:1537 calls.c:1540
+#: calls.c:1555 calls.c:1558
 #, gcc-internal-format
 msgid "argument %i in the range [%E, %E]"
 msgstr "el argumento %i está dentro del rango [%E, %E]"
 
-#: calls.c:1551
+#: calls.c:1569
 #, gcc-internal-format
 msgid "in a call to built-in allocation function %qD"
 msgstr "en una llamada a la función de reserva interna %qD"
 
-#: calls.c:1554
+#: calls.c:1572
 #, gcc-internal-format
 msgid "in a call to allocation function %qD declared here"
 msgstr "en una llamada a la función de reserva %qD declarada aquí"
 
-#: calls.c:1711
-#, gcc-internal-format
-msgid "%qD argument %i declared attribute %<nonstring%> is smaller than the specified bound %E"
-msgstr ""
+#: calls.c:1835
+#, fuzzy, gcc-internal-format
+#| msgid "%qD was not declared %<constexpr%>"
+msgid "%qD argument %i declared attribute %<nonstring%> is smaller than the specified bound %wu"
+msgstr "%qD no se declaró %<constexpr%>"
 
-#: calls.c:1716
+#: calls.c:1841
 #, fuzzy, gcc-internal-format
 #| msgid "%qD was not declared %<constexpr%>"
+msgid "%qD argument %i declared attribute %<nonstring%> is smaller than the specified bound [%E, %E]"
+msgstr "%qD no se declaró %<constexpr%>"
+
+#: calls.c:1847
+#, fuzzy, gcc-internal-format
+#| msgid "%qD was not declared %<constexpr%>"
+msgid "%qD argument %i declared attribute %<nonstring%> may be smaller than the specified bound [%E, %E]"
+msgstr "%qD no se declaró %<constexpr%>"
+
+#: calls.c:1857
+#, fuzzy, gcc-internal-format
+#| msgid "%qD was not declared %<constexpr%>"
 msgid "%qD argument %i declared attribute %<nonstring%>"
 msgstr "%qD no se declaró %<constexpr%>"
 
-#: calls.c:1721
+#: calls.c:1862
 #, gcc-internal-format
 msgid "argument %qD declared here"
 msgstr "el argumento %qD se declara aquí"
 
-#: calls.c:1735
+#: calls.c:1876
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot tail-call: %s"
 msgstr "llamada al extremo imposible: %s"
 
-#: calls.c:3365
+#: calls.c:3506
 #, gcc-internal-format
 msgid "function call has aggregate value"
 msgstr "la llamada a la función tiene valor agregado"
 
-#: calls.c:4059
+#: calls.c:4200
 #, gcc-internal-format
 msgid "passing too large argument on stack"
 msgstr "pasando argumento demasiado grande a la pila"
 
-#: cfgexpand.c:1665 function.c:1002 varasm.c:2231
+#: cfgexpand.c:1665 function.c:1002 varasm.c:2242
 #, gcc-internal-format
 msgid "size of variable %q+D is too large"
 msgstr "el tamaño de la variable %q+D es demasiado grande"
@@ -17261,237 +17281,237 @@
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr "el número de notas bb en la cadena insn (%d) != n_basic_blocks (%d)"
 
-#: cgraph.c:3051
+#: cgraph.c:3056
 #, gcc-internal-format
 msgid "caller edge count invalid"
 msgstr "la cuenta de borde llamador no es válida"
 
-#: cgraph.c:3135
+#: cgraph.c:3140
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr "campo aux establecido para el borde %s->%s"
 
-#: cgraph.c:3142
+#: cgraph.c:3147
 #, gcc-internal-format
 msgid "cgraph count invalid"
 msgstr "cuenta de cgraph no válida"
 
-#: cgraph.c:3147
+#: cgraph.c:3152
 #, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr "clon en línea en el mismo grupo comdat"
 
-#: cgraph.c:3152
+#: cgraph.c:3157
 #, gcc-internal-format
 msgid "local symbols must be defined"
 msgstr "los símbolos locales deben definirse"
 
-#: cgraph.c:3157
+#: cgraph.c:3162
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr "clon incluido en línea visible externamente"
 
-#: cgraph.c:3162
+#: cgraph.c:3167
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr "clon incluido en línea con dirección tomada"
 
-#: cgraph.c:3167
+#: cgraph.c:3172
 #, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr "se fuerza en la salida un clon incluido en línea"
 
-#: cgraph.c:3174
+#: cgraph.c:3179
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for indirect edge from %s"
 msgstr "se define el campo aux para el borde indirecto desde %s"
 
-#: cgraph.c:3181
+#: cgraph.c:3186
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr "Un borde indirecto de %s no está marcado como indirecto o tiene indirect_info asociado, la declaración correspondiente es: "
 
-#: cgraph.c:3196
+#: cgraph.c:3201
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr "función comdat-local llamada por %s fuera de su comdat"
 
-#: cgraph.c:3206
+#: cgraph.c:3211
 #, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr "el puntero inlined_to está mal"
 
-#: cgraph.c:3211
+#: cgraph.c:3216
 #, gcc-internal-format
 msgid "multiple inline callers"
 msgstr "múltiples llamantes inline"
 
-#: cgraph.c:3218
+#: cgraph.c:3223
 #, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr "se estableció el puntero inlined_to para llamantes no-inline"
 
-#: cgraph.c:3239
+#: cgraph.c:3244
 #, gcc-internal-format
 msgid "caller edge count does not match BB count"
 msgstr "la cuenta de borde llamador no coincide con la cuenta BB"
 
-#: cgraph.c:3261
+#: cgraph.c:3266
 #, gcc-internal-format
 msgid "indirect call count does not match BB count"
 msgstr "la cuenta de llamadas indirectas no coincide con la cuenta BB"
 
-#: cgraph.c:3272
+#: cgraph.c:3277
 #, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr "se estableció el puntero inlined_to, pero no se encontraron predecesores"
 
-#: cgraph.c:3277
+#: cgraph.c:3282
 #, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr "el puntero inlined_to se refiere a sí mismo"
 
-#: cgraph.c:3289
+#: cgraph.c:3294
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr "el cgraph_node tiene un clone_of erróneo"
 
-#: cgraph.c:3301
+#: cgraph.c:3306
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr "el cgraph_node tiene una lista de clones errónea"
 
-#: cgraph.c:3307
+#: cgraph.c:3312
 #, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr "el cgraph_node está en la lista de clones pero no es clon"
 
-#: cgraph.c:3312
+#: cgraph.c:3317
 #, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr "el cgraph_node tiene un puntero prev_clone erróneo"
 
-#: cgraph.c:3317
+#: cgraph.c:3322
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr "lista de clones doblemente ligada corrrupta"
 
-#: cgraph.c:3329
+#: cgraph.c:3334
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr "Alias tiene bordes de llamada"
 
-#: cgraph.c:3337
+#: cgraph.c:3342
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr "Alias tiene una referencia que no es alias"
 
-#: cgraph.c:3342
+#: cgraph.c:3347
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr "Alias tiene más de una referencia alias"
 
-#: cgraph.c:3349
+#: cgraph.c:3354
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr "El alias analizado no tiene referencia"
 
-#: cgraph.c:3358
+#: cgraph.c:3363
 #, gcc-internal-format
 msgid "Instrumentation clone does not reference original node"
 msgstr "El clon de instrumentación no hace referencia al nodo original"
 
-#: cgraph.c:3365
+#: cgraph.c:3370
 #, gcc-internal-format
 msgid "Not instrumented node has non-NULL original declaration"
 msgstr "Nodo no instrumentado tiene declaración original no NULL"
 
-#: cgraph.c:3375
+#: cgraph.c:3380
 #, gcc-internal-format
 msgid "Instrumented node has wrong original declaration"
 msgstr "Nodo instrumentado tiene declaración original incorrecta"
 
-#: cgraph.c:3393
+#: cgraph.c:3398
 #, gcc-internal-format
 msgid "Node has more than one chkp reference"
 msgstr "El nodo tiene más de una referencia chkp"
 
-#: cgraph.c:3398
+#: cgraph.c:3403
 #, gcc-internal-format
 msgid "Wrong node is referenced with chkp reference"
 msgstr "Nodo incorrecto referenciado con referencia chkp"
 
-#: cgraph.c:3406
+#: cgraph.c:3411
 #, gcc-internal-format
 msgid "Analyzed node has no reference to instrumented version"
 msgstr "El nodo analizado no tiene referencia a versión instrumentada"
 
-#: cgraph.c:3420
+#: cgraph.c:3425
 #, gcc-internal-format
 msgid "Alias chain for instrumented node is broken"
 msgstr "La cadena alias para el nodo instrumentado está rota"
 
-#: cgraph.c:3429
+#: cgraph.c:3434
 #, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr "No hay un borde fuera de un nodo thunk"
 
-#: cgraph.c:3434
+#: cgraph.c:3439
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr "Más de un borde fuera de un nodo thunk"
 
-#: cgraph.c:3439
+#: cgraph.c:3444
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr "No se supone que thunk tenga cuerpo"
 
-#: cgraph.c:3445
+#: cgraph.c:3450
 #, gcc-internal-format
 msgid "Instrumentation thunk has wrong edge callee"
 msgstr "El thunk de instrumentación tiene elemento invocado de borde incorrecto"
 
-#: cgraph.c:3481
+#: cgraph.c:3486
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr "call_stmt compartida:"
 
-#: cgraph.c:3489
+#: cgraph.c:3494
 #, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr "puntos de borde para una declaración errónea:"
 
-#: cgraph.c:3498
+#: cgraph.c:3503
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr "un borde indirecto con un llamante desconocido que corresponde a call_stmt con una declaración conocida:"
 
-#: cgraph.c:3508
+#: cgraph.c:3513
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr "falta el borde de callgraph para la llamada stmt:"
 
-#: cgraph.c:3518
+#: cgraph.c:3523
 #, gcc-internal-format
 msgid "reference to dead statement"
 msgstr "referencia a sentencia muerta"
 
-#: cgraph.c:3531
+#: cgraph.c:3536
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr "el borde %s->%s no tiene un call_stmt correspondiente"
 
-#: cgraph.c:3543
+#: cgraph.c:3548
 #, gcc-internal-format, gfc-internal-format
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr "un borde indirecto desde %s no tiene un call_stmt correspondiente"
 
-#: cgraph.c:3554
+#: cgraph.c:3559
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr "falló verify_cgraph_node"
 
-#: cgraph.c:3661 varpool.c:306
+#: cgraph.c:3666 varpool.c:306
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: section %s is missing"
 msgstr "%s: falta la sección %s"
@@ -17522,12 +17542,12 @@
 msgstr "se descarta el atributo %<weakref%> porque ya se inicializó la variable"
 
 #. include_self=
-#: cgraphunit.c:981 c/c-decl.c:11282
+#: cgraphunit.c:981 c/c-decl.c:11302
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "se usa %q+F pero nunca se define"
 
-#: cgraphunit.c:983 c/c-decl.c:11291
+#: cgraphunit.c:983 c/c-decl.c:11311
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "%q+F se declaró %<static%> pero nunca se define"
@@ -17648,12 +17668,12 @@
 msgid "cannot find '%s'"
 msgstr "no se puede encontrar '%s'"
 
-#: collect-utils.c:183 collect2.c:2361 collect2.c:2560 gcc.c:3080 gcc.c:6856
+#: collect-utils.c:183 collect2.c:2387 collect2.c:2586 gcc.c:3080 gcc.c:6856
 #, gcc-internal-format
 msgid "pex_init failed: %m"
 msgstr "falló pex_init: %m"
 
-#: collect-utils.c:192 collect2.c:2370 collect2.c:2568 gcc.c:8498
+#: collect-utils.c:192 collect2.c:2396 collect2.c:2594 gcc.c:8498
 #, gcc-internal-format
 msgid "%s: %m"
 msgstr "%s: %m"
@@ -17663,93 +17683,93 @@
 msgid "COLLECT_LTO_WRAPPER must be set"
 msgstr "se debe definir COLLECT_LTO_WRAPPER"
 
-#: collect2.c:966 gcc.c:7382 lto-wrapper.c:1666
+#: collect2.c:969 gcc.c:7382 lto-wrapper.c:1692
 #: config/i386/intelmic-mkoffload.c:556 config/nvptx/mkoffload.c:405
 #, gcc-internal-format
 msgid "atexit failed"
 msgstr "falló atexit"
 
-#: collect2.c:1064
+#: collect2.c:1067
 #, gcc-internal-format
 msgid "no arguments"
 msgstr "sin argumentos"
 
-#: collect2.c:1303 opts.c:904
+#: collect2.c:1311 opts.c:904
 #, gcc-internal-format
 msgid "LTO support has not been enabled in this configuration"
 msgstr "el soporte para LTO no se activó en esta configuración"
 
-#: collect2.c:1344
+#: collect2.c:1352
 #, gcc-internal-format
 msgid "can't open %s: %m"
 msgstr "no se puede abrir %s: %m"
 
-#: collect2.c:1450
+#: collect2.c:1472
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown demangling style '%s'"
 msgstr "se desconoce el estilo de desenredado '%s'"
 
-#: collect2.c:1546 collect2.c:1729 collect2.c:1769
+#: collect2.c:1574 collect2.c:1757 collect2.c:1797
 #, gcc-internal-format
 msgid "fopen %s: %m"
 msgstr "fopen %s: %m"
 
-#: collect2.c:1549 collect2.c:1734 collect2.c:1772
+#: collect2.c:1577 collect2.c:1762 collect2.c:1800
 #, gcc-internal-format
 msgid "fclose %s: %m"
 msgstr "fclose %s: %m"
 
-#: collect2.c:2335
+#: collect2.c:2361
 #, gcc-internal-format
 msgid "cannot find 'nm'"
 msgstr "no se puede encontrar 'nm'"
 
-#: collect2.c:2383
+#: collect2.c:2409
 #, gcc-internal-format
 msgid "can't open nm output: %m"
 msgstr "no se puede abrir la salida de nm: %m"
 
-#: collect2.c:2467
+#: collect2.c:2493
 #, gcc-internal-format, gfc-internal-format
 msgid "init function found in object %s"
 msgstr "se encontró la función init en el objeto %s"
 
-#: collect2.c:2478
+#: collect2.c:2504
 #, gcc-internal-format, gfc-internal-format
 msgid "fini function found in object %s"
 msgstr "se encontró la función fini en el objeto %s"
 
-#: collect2.c:2535
+#: collect2.c:2561
 #, gcc-internal-format
 msgid "cannot find 'ldd'"
 msgstr "no se puede encontrar 'ldd'"
 
-#: collect2.c:2581
+#: collect2.c:2607
 #, gcc-internal-format
 msgid "can't open ldd output: %m"
 msgstr "no se puede abrir la salida de ldd: %m"
 
-#: collect2.c:2599
+#: collect2.c:2625
 #, gcc-internal-format, gfc-internal-format
 msgid "dynamic dependency %s not found"
 msgstr "no se encontró la dependencia dinámica %s"
 
-#: collect2.c:2611
+#: collect2.c:2637
 #, gcc-internal-format, gfc-internal-format
 msgid "unable to open dynamic dependency '%s'"
 msgstr "no se puede abrir la dependencia dinámica '%s'"
 
-#: collect2.c:2765
+#: collect2.c:2791
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: not a COFF file"
 msgstr "%s: no es un fichero COFF"
 
-#: collect2.c:2930
+#: collect2.c:2961
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: cannot open as COFF file"
 msgstr "%s: no se puede abrir como un fichero COFF"
 
-#: collect2.c:2989
+#: collect2.c:3020
 #, gcc-internal-format, gfc-internal-format
 msgid "library lib%s not found"
 msgstr "no se encontró la biblioteca lib%s"
@@ -17959,12 +17979,12 @@
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr "sólo se admiten múltiples personalidades EH con ensambladores que admiten la directiva cfi.personality"
 
-#: dwarf2out.c:10901
+#: dwarf2out.c:10909
 #, gcc-internal-format
 msgid "-gdwarf-6 is output as version 5 with incompatibilities"
 msgstr ""
 
-#: dwarf2out.c:14415
+#: dwarf2out.c:14423
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr "se encontró UNSPEC %s (%d) que no está delegitimado la ubicación de variable"
@@ -18084,11 +18104,6 @@
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr "%Kla llamada a %qs se redecló con aviso de atributo: %s"
 
-#: file-prefix-map.c:50
-#, gcc-internal-format
-msgid "invalid argument %qs to %qs"
-msgstr "argumento %qs no válido para %qs"
-
 #: final.c:1868
 #, gcc-internal-format
 msgid "the frame size of %wd bytes is larger than %wd bytes"
@@ -18109,42 +18124,42 @@
 msgid "large fixed-point constant implicitly truncated to fixed-point type"
 msgstr "se truncó la constante de coma fija grande implícitamente al tipo de coma fija"
 
-#: fold-const.c:4151 fold-const.c:4161
+#: fold-const.c:4157 fold-const.c:4167
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d due to width of bit-field"
 msgstr "la comparación siempre es %d debido a la anchura del campo de bit"
 
-#: fold-const.c:5478 tree-ssa-reassoc.c:2374 tree-ssa-reassoc.c:3214
+#: fold-const.c:5484 tree-ssa-reassoc.c:2379 tree-ssa-reassoc.c:3219
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr "se asume que el desbordamiento con signo no sucede al simplificar la prueba de rango"
 
-#: fold-const.c:5928 fold-const.c:5942
+#: fold-const.c:5934 fold-const.c:5948
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr "la comparación siempre es %d"
 
-#: fold-const.c:6085
+#: fold-const.c:6091
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr "un %<or%> de pruebas no equivalentes sin coincidencia siempre es 1"
 
-#: fold-const.c:6090
+#: fold-const.c:6096
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr "un %<and%> de pruebas equivalentes mutuamente exclusivas siempre es 0"
 
-#: fold-const.c:8310
+#: fold-const.c:8316
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr "se asume que el desbordamiento con signo no sucede cuando se reduce la constante en comparación"
 
-#: fold-const.c:8710
+#: fold-const.c:8716
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr "se asume que el desbordamiento con signo no sucede cuando se combinan constantes alrededor de una comparación"
 
-#: fold-const.c:12063
+#: fold-const.c:12069
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr "fold check: el árbol original cambió por un pliegue"
@@ -18154,7 +18169,7 @@
 msgid "total size of local objects too large"
 msgstr "el tamaño total de los objetos locales es demasiado grande"
 
-#: function.c:1776 gimplify.c:6270
+#: function.c:1776 gimplify.c:6273
 #, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr "restricción imposible en %<asm%>"
@@ -18459,7 +18474,7 @@
 msgid "%s: linker input file unused because linking not done"
 msgstr "%s: no se usó el fichero de entrada del enlazador porque no se hizo enlace"
 
-#: gcc.c:8420 c-family/c-opts.c:770
+#: gcc.c:8420 c-family/c-opts.c:768
 #, gcc-internal-format
 msgid "cannot use %<-%> as input filename for a precompiled header"
 msgstr ""
@@ -18694,7 +18709,7 @@
 msgid "%G%qD destination unchanged after copying no bytes"
 msgstr "destino %G%qD intacto tras no copiar ningún byte"
 
-#: gimple-fold.c:2052 tree-ssa-strlen.c:2050
+#: gimple-fold.c:2052 tree-ssa-strlen.c:2074
 msgid "%G%qD specified bound %E equals destination size"
 msgstr "el límite de %G%qD especificado %E es igual al tamaño del destino"
 
@@ -18716,12 +18731,12 @@
 msgid "null pointer dereference"
 msgstr "desreferencia a puntero nulo"
 
-#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12451
-#: tree.c:12488 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10147
-#: c/c-typeck.c:10164 c/gimple-parser.c:1616 c/gimple-parser.c:1624
+#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12455
+#: tree.c:12492 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10152
+#: c/c-typeck.c:10169 c/gimple-parser.c:1616 c/gimple-parser.c:1624
 #: cp/call.c:6493 cp/call.c:8098 cp/constexpr.c:820 cp/constexpr.c:2309
-#: cp/cvt.c:1015 cp/cvt.c:1042 cp/decl.c:7334 cp/decl2.c:5256 cp/pt.c:8334
-#: cp/semantics.c:1836 cp/semantics.c:4053 cp/typeck.c:1700 cp/typeck.c:1895
+#: cp/cvt.c:1015 cp/cvt.c:1042 cp/decl.c:7355 cp/decl2.c:5246 cp/pt.c:8348
+#: cp/semantics.c:1836 cp/semantics.c:4056 cp/typeck.c:1700 cp/typeck.c:1895
 #: cp/typeck.c:3837
 #, gcc-internal-format
 msgid "declared here"
@@ -18732,27 +18747,27 @@
 msgid "nonnull argument %qD compared to NULL"
 msgstr "argumento %qD no nulo comparado con NULL"
 
-#: gimple-ssa-sprintf.c:2517 gimple-ssa-sprintf.c:2637
+#: gimple-ssa-sprintf.c:2555 gimple-ssa-sprintf.c:2675
 #, gcc-internal-format
 msgid "%qE output may be truncated before the last format character"
 msgstr "la salida %qE podría truncarse antes del último carácter de formato"
 
-#: gimple-ssa-sprintf.c:2519 gimple-ssa-sprintf.c:2639
+#: gimple-ssa-sprintf.c:2557 gimple-ssa-sprintf.c:2677
 #, gcc-internal-format
 msgid "%qE output truncated before the last format character"
 msgstr "la salida %qE podría truncarse antes del último carácter de formato"
 
-#: gimple-ssa-sprintf.c:2522 gimple-ssa-sprintf.c:2642
+#: gimple-ssa-sprintf.c:2560 gimple-ssa-sprintf.c:2680
 #, gcc-internal-format
 msgid "%qE may write a terminating nul past the end of the destination"
 msgstr "%qE podría escribir un nul al final del destino"
 
-#: gimple-ssa-sprintf.c:2524 gimple-ssa-sprintf.c:2644
+#: gimple-ssa-sprintf.c:2562 gimple-ssa-sprintf.c:2682
 #, gcc-internal-format
 msgid "%qE writing a terminating nul past the end of the destination"
 msgstr "%qE se escribe un nul al final del destino"
 
-#: gimple-ssa-sprintf.c:2534
+#: gimple-ssa-sprintf.c:2572
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size %wu"
@@ -18759,7 +18774,7 @@
 msgstr[0] "directiva %<%.*s%> escribiendo %wu byte en una región de tamaño %wu"
 msgstr[1] "directiva %<%.*s%> escribiendo %wu bytes en una región de tamaño %wu"
 
-#: gimple-ssa-sprintf.c:2541
+#: gimple-ssa-sprintf.c:2579
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size %wu"
@@ -18766,7 +18781,7 @@
 msgstr[0] "salida de la directiva %<%.*s%> podría truncarse escribiendo %wu byte en una región de tamaño %wu"
 msgstr[1] "salida de la directiva %<%.*s%> podría truncarse escribiendo %wu bytes en una región de tamaño %wu"
 
-#: gimple-ssa-sprintf.c:2548
+#: gimple-ssa-sprintf.c:2586
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size %wu"
@@ -18773,67 +18788,67 @@
 msgstr[0] "salida de la directiva %<%.*s%> truncada escribiendo %wu byte en una región de tamaño %wu"
 msgstr[1] "salida de la directiva %<%.*s%> truncada escribiendo %wu bytes en una región de tamaño %wu"
 
-#: gimple-ssa-sprintf.c:2559
+#: gimple-ssa-sprintf.c:2597
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size %wu"
 msgstr "la salida de la directiva %<%.*s%> podría truncarse al escribir hasta %wu bytes en una región de tamaño %wu"
 
-#: gimple-ssa-sprintf.c:2562
+#: gimple-ssa-sprintf.c:2600
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size %wu"
 msgstr "salida de la directiva %<%.*s%> truncada escribiendo hasta %wu bytes en una región de tamaño %wu"
 
-#: gimple-ssa-sprintf.c:2564
+#: gimple-ssa-sprintf.c:2602
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size %wu"
 msgstr "directiva %<%.*s%> escribiendo hasta %wu bytes en una región de tamaño %wu"
 
-#: gimple-ssa-sprintf.c:2576
+#: gimple-ssa-sprintf.c:2614
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr "la salida de la directiva %<%.*s%> podría truncarse escribiendo probablemente %wu o más bytes en una región de tamaño %wu"
 
-#: gimple-ssa-sprintf.c:2579
+#: gimple-ssa-sprintf.c:2617
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr "salida de la directiva %<%.*s%> truncada escribiendo probablemente %wu o más bytes en una región de tamaño %wu"
 
-#: gimple-ssa-sprintf.c:2582
+#: gimple-ssa-sprintf.c:2620
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size %wu"
 msgstr "directiva %<%.*s%> escribiendo probablemente %wu o más bytes en una región de tamaño %wu"
 
-#: gimple-ssa-sprintf.c:2591
+#: gimple-ssa-sprintf.c:2629
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr "la salida de la directiva %<%.*s%> podría truncarse escribiendo entre %wu y %wu bytes en una región de tamaño %wu"
 
-#: gimple-ssa-sprintf.c:2594
+#: gimple-ssa-sprintf.c:2632
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr "salida de la directiva %<%.*s%> truncada escribiendo entre %wu y %wu bytes en una región de tamaño %wu"
 
-#: gimple-ssa-sprintf.c:2597
+#: gimple-ssa-sprintf.c:2635
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size %wu"
 msgstr "directiva %<%.*s%> escribiendo entre %wu y %wu bytes en una región de tamaño %wu"
 
-#: gimple-ssa-sprintf.c:2606
+#: gimple-ssa-sprintf.c:2644
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size %wu"
 msgstr "la salida de la directiva %<%.*s%> podría truncarse escribiendo %wu o más bytes en una región de tamaño %wu"
 
-#: gimple-ssa-sprintf.c:2609
+#: gimple-ssa-sprintf.c:2647
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size %wu"
 msgstr "salida de la directiva %<%.*s%> truncada escribiendo %wu o más bytes en una región de tamaño %wu"
 
-#: gimple-ssa-sprintf.c:2611
+#: gimple-ssa-sprintf.c:2649
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size %wu"
 msgstr "directiva %<%.*s%> escribiendo %wu o más bytes en una región de tamaño %wu"
 
-#: gimple-ssa-sprintf.c:2653
+#: gimple-ssa-sprintf.c:2691
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size between %wu and %wu"
@@ -18840,7 +18855,7 @@
 msgstr[0] "directiva %<%.*s%> escribiendo %wu byte en una región de un tamaño entre %wu y %wu"
 msgstr[1] "directiva %<%.*s%> escribiendo %wu bytes en una región de un tamaño entre %wu y %wu"
 
-#: gimple-ssa-sprintf.c:2660
+#: gimple-ssa-sprintf.c:2698
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size between %wu and %wu"
@@ -18847,7 +18862,7 @@
 msgstr[0] "la salida de la directiva %<%.*s%> podría truncarse al escribir %wu byte en una región de un tamaño entre %wu y %wu"
 msgstr[1] "la salida de la directiva %<%.*s%> podría truncarse al escribir %wu bytes en una región de un tamaño entre %wu y %wu"
 
-#: gimple-ssa-sprintf.c:2668
+#: gimple-ssa-sprintf.c:2706
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size between %wu and %wu"
@@ -18854,102 +18869,102 @@
 msgstr[0] "salida de la directiva %<%.*s%> truncada escribiendo %wu byte en una región de un tamaño entre %wu y %wu"
 msgstr[1] "salida de la directiva %<%.*s%> truncada escribiendo %wu bytes en una región de un tamaño entre %wu y %wu"
 
-#: gimple-ssa-sprintf.c:2680
+#: gimple-ssa-sprintf.c:2718
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr "la salida de la directiva %<%.*s%> podría truncarse escribiendo hasta %wu bytes en una región de un tamaño entre %wu y %wu"
 
-#: gimple-ssa-sprintf.c:2683
+#: gimple-ssa-sprintf.c:2721
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr "salida de la directiva %<%.*s%> truncada escribiendo hasta %wu bytes en una región de un tamaño entre %wu y %wu"
 
-#: gimple-ssa-sprintf.c:2686
+#: gimple-ssa-sprintf.c:2724
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr "directiva %<%.*s%> escribiendo hasta %wu bytes en una región de un tamaño entre %wu y %wu"
 
-#: gimple-ssa-sprintf.c:2699
+#: gimple-ssa-sprintf.c:2737
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr "la salida de la directiva %<%.*s%> podría truncarse escribiendo probablemente %wu o más bytes en una región de un tamaño entre %wu y %wu"
 
-#: gimple-ssa-sprintf.c:2702
+#: gimple-ssa-sprintf.c:2740
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr "salida de la directiva %<%.*s%> truncada escribiendo probablemente %wu o más bytes en una región de un tamaño entre %wu y %wu"
 
-#: gimple-ssa-sprintf.c:2705
+#: gimple-ssa-sprintf.c:2743
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr "directiva %<%.*s%> escribiendo probablemente %wu o más bytes en una región de un tamaño entre %wu y %wu"
 
-#: gimple-ssa-sprintf.c:2715
+#: gimple-ssa-sprintf.c:2753
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr "la salida de la directiva %<%.*s%> podría truncarse escribiendo entre %wu y %wu bytes en una región de un tamaño entre %wu y %wu"
 
-#: gimple-ssa-sprintf.c:2718
+#: gimple-ssa-sprintf.c:2756
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr "salida de la directiva %<%.*s%> truncada escribiendo entre %wu y %wu bytes en una región de un tamaño entre %wu y %wu"
 
-#: gimple-ssa-sprintf.c:2721
+#: gimple-ssa-sprintf.c:2759
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr "directiva %<%.*s%> escribiendo entre %wu y %wu bytes en una región de un tamaño entre %wu y %wu"
 
-#: gimple-ssa-sprintf.c:2730
+#: gimple-ssa-sprintf.c:2768
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr "la salida de la directiva %<%.*s%> podría truncarse escribiendo %wu o más bytes en una región de un tamaño entre %wu y %wu"
 
-#: gimple-ssa-sprintf.c:2733
+#: gimple-ssa-sprintf.c:2771
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr "salida de la directiva %<%.*s%> truncada escribiendo %wu o más bytes en una región de un tamaño entre %wu y %wu"
 
-#: gimple-ssa-sprintf.c:2736
+#: gimple-ssa-sprintf.c:2774
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr "directiva %<%.*s%> escribiendo %wu o más bytes en una región de un tamaño entre %wu y %wu"
 
-#: gimple-ssa-sprintf.c:2825
+#: gimple-ssa-sprintf.c:2863
 #, gcc-internal-format
 msgid "%<%.*s%> directive argument is null"
 msgstr "el argumento de la directiva %<%.*s%> es nulo"
 
-#: gimple-ssa-sprintf.c:2890
+#: gimple-ssa-sprintf.c:2928
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes exceeds minimum required size of 4095"
 msgstr "la salida de la directiva %<%.*s%> de %wu bytes supera el tamaño mínimo requerido de 4095"
 
-#: gimple-ssa-sprintf.c:2897
+#: gimple-ssa-sprintf.c:2935
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may exceed minimum required size of 4095"
 msgstr "la salida de la directiva %<%.*s%> entre %wu y %wu bytes podría superar el tamaño mínimo requerido de 4095"
 
-#: gimple-ssa-sprintf.c:2900
+#: gimple-ssa-sprintf.c:2938
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes exceeds minimum required size of 4095"
 msgstr "la salida de la directiva %<%.*s%> entre %wu y %wu bytes supera el tamaño mínimo requerido de 4095"
 
-#: gimple-ssa-sprintf.c:2929
+#: gimple-ssa-sprintf.c:2967
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr "la salida de la directiva %<%.*s%> de %wu bytes provoca que el resultado supere %<INT_MAX%>"
 
-#: gimple-ssa-sprintf.c:2936
+#: gimple-ssa-sprintf.c:2974
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr "la salida de la directiva %<%.*s%> entre %wu y %wu bytes provoca que el resultado supere %<INT_MAX%>"
 
-#: gimple-ssa-sprintf.c:2939
+#: gimple-ssa-sprintf.c:2977
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may cause result to exceed %<INT_MAX%>"
 msgstr "la salida de la directiva %<%.*s%> entre %wu y %wu bytes podría provocar que el resultado supere %<INT_MAX%>"
 
-#: gimple-ssa-sprintf.c:2949
+#: gimple-ssa-sprintf.c:2987
 #, gcc-internal-format
 msgid "assuming directive output of %wu byte"
 msgid_plural "assuming directive output of %wu bytes"
@@ -18956,77 +18971,77 @@
 msgstr[0] "se asume salida de directiva de %wu byte"
 msgstr[1] "se asume salida de directiva de %wu bytes"
 
-#: gimple-ssa-sprintf.c:2956
+#: gimple-ssa-sprintf.c:2994
 #, gcc-internal-format
 msgid "directive argument %qE"
 msgstr "argumento de la directiva %qE"
 
-#: gimple-ssa-sprintf.c:2958
+#: gimple-ssa-sprintf.c:2996
 #, gcc-internal-format
 msgid "directive argument in the range [%E, %E]"
 msgstr "argumento de la directiva en el rango de [%E, %E]"
 
-#: gimple-ssa-sprintf.c:2962
+#: gimple-ssa-sprintf.c:3000
 #, gcc-internal-format
 msgid "using the range [%E, %E] for directive argument"
 msgstr "se utiliza el rango [%E, %E] para el argumento de la directiva"
 
-#: gimple-ssa-sprintf.c:2982
+#: gimple-ssa-sprintf.c:3020
 #, gcc-internal-format
 msgid "%qE output %wu byte into a destination of size %wu"
 msgstr "%qE manda %wu byte a un destino de tamaño %wu"
 
-#: gimple-ssa-sprintf.c:2983
+#: gimple-ssa-sprintf.c:3021
 #, gcc-internal-format
 msgid "%qE output %wu bytes into a destination of size %wu"
 msgstr "%qE manda %wu bytes a un destino de tamaño %wu"
 
-#: gimple-ssa-sprintf.c:2987
+#: gimple-ssa-sprintf.c:3025
 #, gcc-internal-format
 msgid "%qE output between %wu and %wu bytes into a destination of size %wu"
 msgstr "%qE manda entre %wu y %wu bytes a un destino de tamaño %wu"
 
-#: gimple-ssa-sprintf.c:2992
+#: gimple-ssa-sprintf.c:3030
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes (assuming %wu) into a destination of size %wu"
 msgstr "%qE manda %wu o más bytes (se asume %wu) a un destino de tamaño %wu"
 
-#: gimple-ssa-sprintf.c:2997
+#: gimple-ssa-sprintf.c:3035
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes into a destination of size %wu"
 msgstr "%qE manda %wu o más bytes a un destino de tamaño %wu"
 
-#: gimple-ssa-sprintf.c:3368
+#: gimple-ssa-sprintf.c:3406
 #, gcc-internal-format
 msgid "%<%.*s%> directive width out of range"
 msgstr "anchura de la directiva %<%.*s%> fuera de rango"
 
-#: gimple-ssa-sprintf.c:3402
+#: gimple-ssa-sprintf.c:3440
 #, gcc-internal-format
 msgid "%<%.*s%> directive precision out of range"
 msgstr "precisión de la directiva %<%.*s%> fuera de rango"
 
-#: gimple-ssa-sprintf.c:3893
+#: gimple-ssa-sprintf.c:3931
 #, gcc-internal-format
 msgid "specified bound %wu exceeds maximum object size %wu"
 msgstr "el límite especificado %wu supera el tamaño máximo del objeto %wu"
 
-#: gimple-ssa-sprintf.c:3899
+#: gimple-ssa-sprintf.c:3937
 #, gcc-internal-format
 msgid "specified bound %wu exceeds %<INT_MAX%>"
 msgstr "el límite especificado %wu supera %<INT_MAX%>"
 
-#: gimple-ssa-sprintf.c:3949
+#: gimple-ssa-sprintf.c:3987
 #, gcc-internal-format
 msgid "null destination pointer"
 msgstr "puntero de destino nulo"
 
-#: gimple-ssa-sprintf.c:3966
+#: gimple-ssa-sprintf.c:4004
 #, gcc-internal-format
 msgid "specified bound %wu exceeds the size %wu of the destination object"
 msgstr "el límite especificado %wu supera el tamaño %wu del objeto de destino"
 
-#: gimple-ssa-sprintf.c:3978
+#: gimple-ssa-sprintf.c:4016
 #, gcc-internal-format
 msgid "null format string"
 msgstr "cadena de formato nula"
@@ -19239,10 +19254,10 @@
 msgstr "el desplazamiento de %G%qD %s está fuera de los límites ] del objeto %qD con tipo %qT"
 
 #: gimple-ssa-warn-restrict.c:1678 c/c-decl.c:3603 c/c-decl.c:3874
-#: c/c-typeck.c:8345 cp/class.c:1346 cp/class.c:3098 cp/decl.c:3979
-#: cp/decl.c:10753 cp/decl.c:11151 cp/decl.c:11160 cp/friend.c:384
+#: c/c-typeck.c:8350 cp/class.c:1346 cp/class.c:3102 cp/decl.c:3979
+#: cp/decl.c:10777 cp/decl.c:11175 cp/decl.c:11184 cp/friend.c:384
 #: cp/friend.c:393 cp/parser.c:3275 cp/parser.c:3372 cp/parser.c:3422
-#: cp/parser.c:6327 cp/parser.c:21027
+#: cp/parser.c:6330 cp/parser.c:21024
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD se declara aquí"
@@ -19314,217 +19329,217 @@
 msgid "using result of function returning %<void%>"
 msgstr "se usa el resultado de una función que devuelve %<void%>"
 
-#: gimplify.c:6128
+#: gimplify.c:6131
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid lvalue in asm output %d"
 msgstr "l-valor no válido en la salida asm %d"
 
-#: gimplify.c:6271
+#: gimplify.c:6274
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr "la entrada que no es de memoria %d debe permanecer en memoria"
 
-#: gimplify.c:6311 gimplify.c:6320
+#: gimplify.c:6314 gimplify.c:6323
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr "la entrada de memoria %d no es directamente direccionable"
 
-#: gimplify.c:6928
+#: gimplify.c:6931
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in target region"
 msgstr "se usó la variable threadprivate %qE en una región objetivo"
 
-#: gimplify.c:6930
+#: gimplify.c:6933
 #, gcc-internal-format
 msgid "enclosing target region"
 msgstr "región objetivo contenedora"
 
-#: gimplify.c:6942
+#: gimplify.c:6945
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in untied task"
 msgstr "se usó la variable threadprivate %qE en una tarea sin atar"
 
-#: gimplify.c:6944
+#: gimplify.c:6947
 #, gcc-internal-format
 msgid "enclosing task"
 msgstr "tarea contenedora"
 
-#: gimplify.c:7016
+#: gimplify.c:7019
 #, gcc-internal-format
 msgid "%qE not specified in enclosing %qs"
 msgstr "no se especificó %qE en el %qs que lo contiene"
 
-#: gimplify.c:7018
+#: gimplify.c:7021
 #, gcc-internal-format
 msgid "enclosing %qs"
 msgstr "%qs contenedora"
 
-#: gimplify.c:7143
+#: gimplify.c:7146
 #, gcc-internal-format
 msgid "%qE not specified in enclosing OpenACC %qs construct"
 msgstr "no se especificó %qE en la construcción OpenACC %qs que lo contiene"
 
-#: gimplify.c:7145
+#: gimplify.c:7148
 #, gcc-internal-format
 msgid "enclosing OpenACC %qs construct"
 msgstr "construcción OpenACC %qs que lo contiene"
 
-#: gimplify.c:7198
+#: gimplify.c:7201
 #, gcc-internal-format
 msgid "%qE with %<link%> clause used in %<routine%> function"
 msgstr "%qE con cláusula %<link%> usada en la función %<routine%>"
 
-#: gimplify.c:7206
+#: gimplify.c:7209
 #, gcc-internal-format
 msgid "%qE requires a %<declare%> directive for use in a %<routine%> function"
 msgstr "%qE requiere una directiva %<declare%> para poder usarse en una función%<routine%>"
 
-#: gimplify.c:7272 gimplify.c:7872
+#: gimplify.c:7275 gimplify.c:7875
 #, gcc-internal-format
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr "la variable %qE se declaró en la región %<host_data%> que la contiene"
 
-#: gimplify.c:7293
+#: gimplify.c:7296
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr "%qD referenciada en la región de destino no tiene un tipo al que asociarla"
 
-#: gimplify.c:7411 gimplify.c:7443
+#: gimplify.c:7414 gimplify.c:7446
 #, gcc-internal-format
 msgid "iteration variable %qE is predetermined linear"
 msgstr "la variable de iteración %qE se predetermina lineal"
 
-#: gimplify.c:7414
+#: gimplify.c:7417
 #, gcc-internal-format
 msgid "iteration variable %qE should be private"
 msgstr "la variable de iteración %qE debe ser private"
 
-#: gimplify.c:7428
+#: gimplify.c:7431
 #, gcc-internal-format
 msgid "iteration variable %qE should not be firstprivate"
 msgstr "la variable de iteración %qE no debe ser firstprivate"
 
-#: gimplify.c:7431
+#: gimplify.c:7434
 #, gcc-internal-format
 msgid "iteration variable %qE should not be reduction"
 msgstr "la variable de iteración %qE no debe ser reduction"
 
-#: gimplify.c:7434
+#: gimplify.c:7437
 #, gcc-internal-format
 msgid "iteration variable %qE should not be linear"
 msgstr "la variable de iteración %qE no debe ser lineal"
 
-#: gimplify.c:7437
+#: gimplify.c:7440
 #, gcc-internal-format
 msgid "iteration variable %qE should not be lastprivate"
 msgstr "la variable de iteración %qE no debe ser lastprivate"
 
-#: gimplify.c:7440
+#: gimplify.c:7443
 #, gcc-internal-format
 msgid "iteration variable %qE should not be private"
 msgstr "la variable de iteración %qE no debe ser private"
 
-#: gimplify.c:7742
+#: gimplify.c:7745
 #, gcc-internal-format
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr "cláusula %<linear%> para una variable que no es iterador de bucle especificada en una construcción combinada con %<distribute%>"
 
-#: gimplify.c:7949
+#: gimplify.c:7952
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr "se asocia el campo %qE de una estructura de longitud variable"
 
-#: gimplify.c:8160
+#: gimplify.c:8163
 #, gcc-internal-format
 msgid "%qE appears more than once in map clauses"
 msgstr "%qE aparece más de una vez en las cláusulas map"
 
-#: gimplify.c:8464
+#: gimplify.c:8467
 #, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr "la variable copyprivate %qE no es threadprivate o private en el contexto externo"
 
-#: gimplify.c:8484
+#: gimplify.c:8487
 #, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr "la variable %s %qE es private en el contexto externo"
 
-#: gimplify.c:8510
+#: gimplify.c:8513
 #, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr "se esperaba el modificador de cláusula %qs %<if%> en vez de %qs"
 
-#: gimplify.c:8775
+#: gimplify.c:8778
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr "%<_Atomic%> %qD en cláusula %<map%> implícita"
 
-#: gimplify.c:8808
+#: gimplify.c:8811
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr "%<_Atomic%> %qD en cláusula %<firstprivate%> implícita en una construcción %<target%>"
 
-#: gimplify.c:9000
+#: gimplify.c:9003
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr "%<_Atomic%> %qD en cláusula %<firstprivate%> en una construcción %<target%>"
 
-#: gimplify.c:9051
+#: gimplify.c:9054
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr "se ha usado la misma variable en cláusulas %<firstprivate%> y %<lastprivate%> en una construcción %<distribute%>"
 
-#: gimplify.c:9133
+#: gimplify.c:9136
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to present_or_copy"
 msgstr "cláusula de datos incompatible con reducción en %qE; se promociona a present_or_copy"
 
-#: gimplify.c:9278
+#: gimplify.c:9281
 #, gcc-internal-format
 msgid "invalid private reduction on %qE"
 msgstr "reducción privada no válida en %qE"
 
-#: gimplify.c:11103 omp-low.c:2791
+#: gimplify.c:11106 omp-low.c:2791
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr "la construcción %<ordered%> con cláusula %<depend%> debe estar bien anidada dentro de un bucle con una cláusula %<ordered%> con un parámetro"
 
-#: gimplify.c:11121
+#: gimplify.c:11124
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr "la variable %qE no es una iteración del bucle más externo %d; se esperaba %qE"
 
-#: gimplify.c:11134
+#: gimplify.c:11137
 #, gcc-internal-format
 msgid "number of variables in %<depend(sink)%> clause does not match number of iteration variables"
 msgstr "el número de variables en la cláusula %<depend(sink)%> no coincide con el número de variables de iteración"
 
-#: gimplify.c:11147
+#: gimplify.c:11150
 #, gcc-internal-format
 msgid "more than one %<depend(source)%> clause on an %<ordered%> construct"
 msgstr "más de una cláusula %<depend(source)%> en una construcción %<ordered%>"
 
-#: gimplify.c:11158
+#: gimplify.c:11161
 #, gcc-internal-format
 msgid "%<depend(source)%> clause specified together with %<depend(sink:)%> clauses on the same construct"
 msgstr "cláusula %<depend(source)%> especificada junto con cláusulas %<depend(sink:)%> en la misma construcción"
 
-#: gimplify.c:12393
+#: gimplify.c:12396
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr "falló la gimplificación"
 
-#: gimplify.c:12936
+#: gimplify.c:12939
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr "%qT se promueve a %qT cuando pasa a través de %<...%>"
 
-#: gimplify.c:12941
+#: gimplify.c:12944
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr "(así que debe pasar %qT y no %qT a %<va_arg%>)"
 
-#: gimplify.c:12948
+#: gimplify.c:12951
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr "si se alcanza este código, el programa abortará"
@@ -19997,47 +20012,47 @@
 msgid "Max. number of generated reload insns per insn is achieved (%d)\n"
 msgstr "Se ha alcanzado el número máximo de insns de recarga generadas (%d)\n"
 
-#: lto-cgraph.c:1294
+#: lto-cgraph.c:1296
 #, gcc-internal-format, gfc-internal-format
 msgid "bytecode stream: found multiple instances of cgraph node with uid %d"
 msgstr "flujo de bytecode: se encontraron instancias múltiples del nodo cgraph con uid %d"
 
-#: lto-cgraph.c:1472
+#: lto-cgraph.c:1474
 #, gcc-internal-format
 msgid "bytecode stream: no caller found while reading edge"
 msgstr "flujo de bytecode: no se encontró un llamante al leer el borde"
 
-#: lto-cgraph.c:1478
+#: lto-cgraph.c:1480
 #, gcc-internal-format
 msgid "bytecode stream: no callee found while reading edge"
 msgstr "flujo de bytecode: no se encontró un llamado al leer el borde"
 
-#: lto-cgraph.c:1552
+#: lto-cgraph.c:1554
 #, gcc-internal-format
 msgid "bytecode stream: found empty cgraph node"
 msgstr "flujo de bytecode: se encontró un nodo cgraph vacío"
 
-#: lto-cgraph.c:1730
+#: lto-cgraph.c:1732
 #, gcc-internal-format, gfc-internal-format
 msgid "At most %i profile runs is supported. Perhaps corrupted profile?"
 msgstr "Por lo menos se admiten %i corridas de perfil. ¿Tal vez se corrompió el perfil?"
 
-#: lto-cgraph.c:1817
+#: lto-cgraph.c:1819
 #, gcc-internal-format, gfc-internal-format
 msgid "Profile information in %s corrupted"
 msgstr "La información de análisis de perfil en %s está corrupta"
 
-#: lto-cgraph.c:1855
+#: lto-cgraph.c:1857
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO cgraph in %s"
 msgstr "no se puede encontrar cgraph de LTO en %s"
 
-#: lto-cgraph.c:1865
+#: lto-cgraph.c:1867
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO section refs in %s"
 msgstr "no se pueden encontrar las referencias de sección LTO en %s"
 
-#: lto-cgraph.c:1946
+#: lto-cgraph.c:1948
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid offload table in %s"
 msgstr "tabla de descarga no válida en %s"
@@ -20108,81 +20123,87 @@
 msgid "bytecode stream in file %qs generated with LTO version %d.%d instead of the expected %d.%d"
 msgstr "flujo de bytecode en el fichero %qs generado con LTO versión %d.%d en lugar de la versión esperada %d.%d"
 
-#: lto-wrapper.c:117
+#: lto-wrapper.c:118
 #, gcc-internal-format
 msgid "deleting LTRANS file %s: %m"
 msgstr "se borra el fichero LTRANS %s: %m"
 
-#: lto-wrapper.c:154
+#: lto-wrapper.c:155
 #, gcc-internal-format
 msgid "malformed COLLECT_GCC_OPTIONS"
 msgstr "COLLECT_GCC_OPTIONS malformado"
 
-#: lto-wrapper.c:308
+#: lto-wrapper.c:309
 #, gcc-internal-format, gfc-internal-format
 msgid "Option %s with different values"
 msgstr "Opción %s con valores diferentes"
 
-#: lto-wrapper.c:392
+#: lto-wrapper.c:393
 #, gcc-internal-format, gfc-internal-format
 msgid "Option %s not used consistently in all LTO input files"
 msgstr "Opción %s no usada con coherencia en todos los ficheros de entrada LTO"
 
-#: lto-wrapper.c:832
+#: lto-wrapper.c:833
 #, gcc-internal-format, gfc-internal-format
 msgid "problem with building target image for %s\n"
 msgstr "problema al construir la imagen de destino para %s\n"
 
-#: lto-wrapper.c:852
+#: lto-wrapper.c:853
 #, gcc-internal-format
 msgid "reading input file"
 msgstr "leyendo fichero de entrada"
 
-#: lto-wrapper.c:857
+#: lto-wrapper.c:858
 #, gcc-internal-format
 msgid "writing output file"
 msgstr "escribiendo fichero de salida"
 
-#: lto-wrapper.c:889
+#: lto-wrapper.c:890
 #, gcc-internal-format
 msgid "installation error, can't find crtoffloadtable.o"
 msgstr "error de instalación, no se puede encontrar crtoffloadtable.o"
 
-#: lto-wrapper.c:1000 lto-wrapper.c:1012
+#: lto-wrapper.c:1001 lto-wrapper.c:1013
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: %s\n"
 msgstr "%s: %s\n"
 
-#: lto-wrapper.c:1056
+#: lto-wrapper.c:1064
 #, gcc-internal-format
 msgid "environment variable COLLECT_GCC must be set"
 msgstr "se debe establecer la variable de entorno COLLECT_GCC"
 
-#: lto-wrapper.c:1060 config/nvptx/mkoffload.c:363
+#: lto-wrapper.c:1068 config/nvptx/mkoffload.c:363
 #, gcc-internal-format
 msgid "environment variable COLLECT_GCC_OPTIONS must be set"
 msgstr "se debe establecer la variable de entorno COLLECT_GCC_OPTIONS"
 
-#: lto-wrapper.c:1229 lto-wrapper.c:1285
+#: lto-wrapper.c:1237 lto-wrapper.c:1293
 #, gcc-internal-format
 msgid "cannot open %s: %m"
 msgstr "no se puede abrir %s: %m"
 
-#: lto-wrapper.c:1232 lto-wrapper.c:1291
+#: lto-wrapper.c:1240 lto-wrapper.c:1299
 #, gcc-internal-format
 msgid "cannot read %s: %m"
 msgstr "no se puede leer %s: %m"
 
-#: lto-wrapper.c:1259
+#: lto-wrapper.c:1267
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid format of %s"
 msgstr "formato no válido de %s"
 
-#: lto-wrapper.c:1482
+#: lto-wrapper.c:1491
 #, gcc-internal-format
 msgid "fopen: %s: %m"
 msgstr "fopen: %s: %m"
 
+#: lto-wrapper.c:1508
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "Could not open output file '%s'\n"
+msgid "Corrupted ltrans output file %s"
+msgstr "No se puede abrir el fichero de salida '%s'\n"
+
 #: multiple_target.c:76
 #, gcc-internal-format
 msgid "the call requires ifunc, which is not supported by this target"
@@ -20535,12 +20556,12 @@
 msgid "unrecognized argument in option %qs"
 msgstr "no se reconoce el argumento en la opción %qs"
 
-#: opts-common.c:1198 config/i386/i386.c:3206
+#: opts-common.c:1198 config/i386/i386.c:3209
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "los argumentos válidos para %qs son: %s; ¿quiso decir %qs?"
 
-#: opts-common.c:1201 config/i386/i386.c:3209
+#: opts-common.c:1201 config/i386/i386.c:3212
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "los argumentos válidos para %qs son: %s"
@@ -21135,22 +21156,22 @@
 msgid "output operand %d must use %<&%> constraint"
 msgstr "el operando de salida %d debe usar la restricción %<&%>"
 
-#: regcprop.c:1187
+#: regcprop.c:1193
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad next_regno for empty chain (%u)"
 msgstr "validate_value_data: [%u] next_regno erróneo para la cadena vacía (%u)"
 
-#: regcprop.c:1199
+#: regcprop.c:1205
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: Loop in regno chain (%u)"
 msgstr "validate_value_data: Ciclo en la cadena regno (%u)"
 
-#: regcprop.c:1202
+#: regcprop.c:1208
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad oldest_regno (%u)"
 msgstr "validate_value_data: [%u] oldest_regno erróneo (%u)"
 
-#: regcprop.c:1214
+#: regcprop.c:1220
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Non-empty reg in chain (%s %u %i)"
 msgstr "validate_value_data: [%u] Registro no vacío en la cadena (%s %u %i)"
@@ -21194,7 +21215,7 @@
 msgstr "se usó el registro de %qD para múltiples variables de registro globales"
 
 #: reginfo.c:789 config/powerpcspe/powerpcspe.c:32259
-#: config/rs6000/rs6000.c:29453
+#: config/rs6000/rs6000.c:29530
 #, gcc-internal-format
 msgid "conflicts with %qD"
 msgstr "genera un conflicto con %qD"
@@ -21439,153 +21460,159 @@
 msgid "function symbol is not function"
 msgstr "el símbolo de función no es una función"
 
-#: symtab.c:1006
+#: symtab.c:1005
+#, fuzzy, gcc-internal-format
+#| msgid "inconsistent file architecture detected"
+msgid "inconsistent `ifunc' attribute"
+msgstr "se detectó una arquitectura de fichero inconsistente"
+
+#: symtab.c:1013
 #, gcc-internal-format
 msgid "variable symbol is not variable"
 msgstr "el símbolo de variable no es una variable"
 
-#: symtab.c:1012
+#: symtab.c:1019
 #, gcc-internal-format
 msgid "node has unknown type"
 msgstr "el nodo tiene un tipo desconocido"
 
-#: symtab.c:1021
+#: symtab.c:1028
 #, gcc-internal-format
 msgid "node not found node->decl->decl_with_vis.symtab_node"
 msgstr "nodo no encontrado node->decl->decl_with_vis.symtab_node"
 
-#: symtab.c:1029
+#: symtab.c:1036
 #, gcc-internal-format
 msgid "node differs from node->decl->decl_with_vis.symtab_node"
 msgstr "el nodo difiere de node->decl->decl_with_vis.symtab_node"
 
-#: symtab.c:1038
+#: symtab.c:1045
 #, gcc-internal-format
 msgid "assembler name hash list corrupted"
 msgstr "lista hash de nombres del ensamblador corrupta"
 
-#: symtab.c:1051
+#: symtab.c:1058
 #, fuzzy, gcc-internal-format
 #| msgid "node not found in cgraph_hash"
 msgid "node not found in symtab assembler name hash"
 msgstr "no se encontró un nodo en cgraph_hash"
 
-#: symtab.c:1058
+#: symtab.c:1065
 #, gcc-internal-format
 msgid "double linked list of assembler names corrupted"
 msgstr "lista doblemente enlazada de nombres del ensamblador corrrupta"
 
-#: symtab.c:1063
+#: symtab.c:1070
 #, gcc-internal-format
 msgid "node has body_removed but is definition"
 msgstr "el nodo tiene body_removed y sin embargo es una definición"
 
-#: symtab.c:1068
+#: symtab.c:1075
 #, gcc-internal-format
 msgid "node is analyzed but it is not a definition"
 msgstr "el nodo está analizado pero no es una definición"
 
-#: symtab.c:1073
+#: symtab.c:1080
 #, gcc-internal-format
 msgid "node is alias but not implicit alias"
 msgstr "el nodo es un alias pero no un alias implícito"
 
-#: symtab.c:1078
+#: symtab.c:1085
 #, gcc-internal-format
 msgid "node is alias but not definition"
 msgstr "el nodo es un alias pero no una definición"
 
-#: symtab.c:1083
+#: symtab.c:1090
 #, gcc-internal-format
 msgid "node is weakref but not an transparent_alias"
 msgstr "el nodo es una weakref pero no un transparent_alias"
 
-#: symtab.c:1088
+#: symtab.c:1095
 #, gcc-internal-format
 msgid "node is transparent_alias but not an alias"
 msgstr "el nodo es un transparent_alias pero no un alias"
 
-#: symtab.c:1097
+#: symtab.c:1104
 #, gcc-internal-format
 msgid "node is in same_comdat_group list but has no comdat_group"
 msgstr "el nodo está en la lista same_comdat_group no tiene comdat_group"
 
-#: symtab.c:1102
+#: symtab.c:1109
 #, gcc-internal-format
 msgid "same_comdat_group list across different groups"
 msgstr "list same_comdat_group con grupos diferentes"
 
-#: symtab.c:1107
+#: symtab.c:1114
 #, gcc-internal-format
 msgid "mixing different types of symbol in same comdat groups is not supported"
 msgstr "no se permite mezclar diferentes símbolos de tipos en los mismos grupos comdat"
 
-#: symtab.c:1112
+#: symtab.c:1119
 #, gcc-internal-format
 msgid "node is alone in a comdat group"
 msgstr "el nodo está solo en un grupo comdat"
 
-#: symtab.c:1119
+#: symtab.c:1126
 #, gcc-internal-format
 msgid "same_comdat_group is not a circular list"
 msgstr "same_comdat_group no es una lista circular"
 
-#: symtab.c:1134
+#: symtab.c:1141
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local symbol referred to by %s outside its comdat"
 msgstr "el símbolo comdat-local referenciado en %s fuera de su comdat"
 
-#: symtab.c:1144
+#: symtab.c:1151
 #, gcc-internal-format
 msgid "implicit_section flag is set but section isn't"
 msgstr "el indicador implicit_section está puesto pero la sección on lo es"
 
-#: symtab.c:1151
+#: symtab.c:1158
 #, gcc-internal-format
 msgid "Both section and comdat group is set"
 msgstr "Tanto la sección como el grupo comdat están puestos"
 
-#: symtab.c:1163
+#: symtab.c:1170
 #, gcc-internal-format
 msgid "Alias and target's section differs"
 msgstr "Alias y sección del objetivo difieren"
 
-#: symtab.c:1170
+#: symtab.c:1177
 #, gcc-internal-format
 msgid "Alias and target's comdat groups differs"
 msgstr "El alias y los grupos comdat del objetivo difieren"
 
-#: symtab.c:1185
+#: symtab.c:1192
 #, gcc-internal-format
 msgid "Transparent alias and target's assembler names differs"
 msgstr "El alias transparente y los nombres de ensamblador del objetivo difieren"
 
-#: symtab.c:1193
+#: symtab.c:1200
 #, gcc-internal-format
 msgid "Chained transparent aliases"
 msgstr "Alias transparentes encadenados"
 
-#: symtab.c:1216 symtab.c:1253
+#: symtab.c:1223 symtab.c:1260
 #, gcc-internal-format
 msgid "symtab_node::verify failed"
 msgstr "symtab_node::falló verify"
 
-#: symtab.c:1249
+#: symtab.c:1256
 #, gcc-internal-format
 msgid "Two symbols with same comdat_group are not linked by the same_comdat_group list."
 msgstr "Hay dos símbolos con el mismo comdat_group que no están vinculados a la lista same_comdat_group."
 
-#: symtab.c:1658
+#: symtab.c:1665
 #, gcc-internal-format
 msgid "function %q+D part of alias cycle"
 msgstr "la función %q+D es parte de un ciclo de alias"
 
-#: symtab.c:1660
+#: symtab.c:1667
 #, gcc-internal-format
 msgid "variable %q+D part of alias cycle"
 msgstr "la variable %q+D es parte de un ciclo de alias"
 
-#: symtab.c:1688
+#: symtab.c:1695
 #, gcc-internal-format
 msgid "section of alias %q+D must match section of its target"
 msgstr "la sección del alias %q+D debe cuadrar con la sección de su objetivo"
@@ -22390,7 +22417,7 @@
 msgid "the first argument of a VEC_COND_EXPR must be of a boolean vector type of the same number of elements as the result"
 msgstr "el primer argumento de una VEC_COND_EXPR debe ser de tipo vector de booleanos del mismo número de elementos que el resultado"
 
-#: tree-cfg.c:4395 c/c-typeck.c:5212
+#: tree-cfg.c:4395 c/c-typeck.c:5217
 #, gcc-internal-format
 msgid "type mismatch in conditional expression"
 msgstr "los tipos de datos no coinciden en la expresión condicional"
@@ -22740,22 +22767,22 @@
 msgid "missing edge %i->%i"
 msgstr "falta el borde %i->%i"
 
-#: tree-cfg.c:9379
+#: tree-cfg.c:9388
 #, gcc-internal-format
 msgid "%<noreturn%> function does return"
 msgstr "la función %<noreturn%> devuelve"
 
-#: tree-cfg.c:9400 tree-cfg.c:9432
+#: tree-cfg.c:9409 tree-cfg.c:9441
 #, gcc-internal-format
 msgid "control reaches end of non-void function"
 msgstr "el control alcanza el final de una función que no es void"
 
-#: tree-cfg.c:9498 cp/cvt.c:1039
+#: tree-cfg.c:9507 cp/cvt.c:1039
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgstr "se descarta el valor de devolución de %qD, se declaró con el atributo warn_unused_result"
 
-#: tree-cfg.c:9503 cp/cvt.c:1046
+#: tree-cfg.c:9512 cp/cvt.c:1046
 #, gcc-internal-format
 msgid "ignoring return value of function declared with attribute warn_unused_result"
 msgstr "se descarta el valor de devolución de la función declarada con atributo warn_unused_result"
@@ -23022,48 +23049,48 @@
 msgid "stmt volatile flag not up-to-date"
 msgstr "la opción volatile de stmt no está actualizada"
 
-#: tree-ssa-strlen.c:1975
+#: tree-ssa-strlen.c:1999
 msgid "%G%qD output truncated before terminating nul copying %E byte from a string of the same length"
 msgid_plural "%G%qD output truncated before terminating nul copying %E bytes from a string of the same length"
 msgstr[0] ""
 msgstr[1] ""
 
-#: tree-ssa-strlen.c:1989
+#: tree-ssa-strlen.c:2013
 msgid "%G%qD output truncated copying %E byte from a string of length %wu"
 msgid_plural "%G%qD output truncated copying %E bytes from a string of length %wu"
 msgstr[0] "salida de %G%qD truncada copiando %E byte desde una cadena de longitud %wu"
 msgstr[1] "salida de %G%qD truncada copiando %E bytes desde una cadena de longitud %wu"
 
-#: tree-ssa-strlen.c:1996
+#: tree-ssa-strlen.c:2020
 msgid "%G%qD output truncated copying between %wu and %wu bytes from a string of length %wu"
 msgstr "salida de %G%qD truncada copiando entre %wu y %wu bytes desde una cadena de longitud %wu"
 
-#: tree-ssa-strlen.c:2008
+#: tree-ssa-strlen.c:2032
 msgid "%G%qD output may be truncated copying %E byte from a string of length %wu"
 msgid_plural "%G%qD output may be truncated copying %E bytes from a string of length %wu"
 msgstr[0] "la salida de %G%qD puede truncarse copiando %E byte desde una cadena de longitud %wu"
 msgstr[1] "la salida de %G%qD puede truncarse copiando %E bytes desde una cadena de longitud %wu"
 
-#: tree-ssa-strlen.c:2015 tree-ssa-strlen.c:2029
+#: tree-ssa-strlen.c:2039 tree-ssa-strlen.c:2053
 msgid "%G%qD output may be truncated copying between %wu and %wu bytes from a string of length %wu"
 msgstr "la salida de %G%qD puede truncarse copiando entre %wu y %wu bytes desde una cadena de longitud %wu"
 
-#: tree-ssa-strlen.c:2150
+#: tree-ssa-strlen.c:2174
 #, fuzzy
 #| msgid "%qE output truncated before the last format character"
 msgid "%G%qD output truncated before terminating nul copying as many bytes from a string as its length"
 msgstr "la salida %qE podría truncarse antes del último carácter de formato"
 
-#: tree-ssa-strlen.c:2156
+#: tree-ssa-strlen.c:2180
 msgid "%G%qD specified bound depends on the length of the source argument"
 msgstr "%G%qD: el límite especificado depende de la longitud del argumento origen"
 
-#: tree-ssa-strlen.c:2163
+#: tree-ssa-strlen.c:2187
 #, gcc-internal-format
 msgid "length computed here"
 msgstr "la longitud se calcula aquí"
 
-#: tree-ssa-uninit.c:191 varasm.c:331
+#: tree-ssa-uninit.c:191 varasm.c:342
 #, gcc-internal-format
 msgid "%qD was declared here"
 msgstr "%qD se declaró aquí"
@@ -23238,27 +23265,27 @@
 msgid "target specific builtin not available"
 msgstr "no está disponible la orden interna específica del objetivo"
 
-#: tree-vect-generic.c:287
+#: tree-vect-generic.c:283
 #, gcc-internal-format
 msgid "vector operation will be expanded piecewise"
 msgstr "la operación vectorial se expandirá por piezas"
 
-#: tree-vect-generic.c:290
+#: tree-vect-generic.c:286
 #, gcc-internal-format
 msgid "vector operation will be expanded in parallel"
 msgstr "la operación vectorial se expandirá en paralelo"
 
-#: tree-vect-generic.c:341
+#: tree-vect-generic.c:337
 #, gcc-internal-format
 msgid "vector operation will be expanded with a single scalar operation"
 msgstr "la operación vectorial se expandirá con una sola operación escalar"
 
-#: tree-vect-generic.c:941
+#: tree-vect-generic.c:937
 #, gcc-internal-format
 msgid "vector condition will be expanded piecewise"
 msgstr "la condición vectorial se expandirá por piezas"
 
-#: tree-vect-generic.c:1373
+#: tree-vect-generic.c:1369
 #, gcc-internal-format
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr "la operación de ordenamiento vectorial se expandirá por piezas"
@@ -23268,27 +23295,27 @@
 msgid "vectorization did not happen for a simd loop"
 msgstr "no se ha producido vectorización para un bucle simd"
 
-#: tree-vrp.c:4930 tree-vrp.c:4974
+#: tree-vrp.c:4931 tree-vrp.c:4975
 #, gcc-internal-format
 msgid "array subscript %E is above array bounds of %qT"
 msgstr "el subíndice %E de la matriz está por encima de los límites de matriz de %qT"
 
-#: tree-vrp.c:4956
+#: tree-vrp.c:4957
 #, gcc-internal-format
 msgid "array subscript [%E, %E] is outside array bounds of %qT"
 msgstr "el subíndice [%E, %E] de la matriz está fuera de los límites de matriz de %qT"
 
-#: tree-vrp.c:4988
+#: tree-vrp.c:4989
 #, gcc-internal-format
 msgid "array subscript %E is below array bounds of %qT"
 msgstr "el subíndice %E de la matriz está por debajo de los límites de matriz de %qT"
 
-#: tree-vrp.c:5046
+#: tree-vrp.c:5047
 #, gcc-internal-format
 msgid "array subscript %wi is below array bounds of %qT"
 msgstr "el subíndice %wi de la matriz está por debajo de los límites de matriz de %qT"
 
-#: tree-vrp.c:5060
+#: tree-vrp.c:5061
 #, gcc-internal-format
 msgid "array subscript %wu is above array bounds of %qT"
 msgstr "el subíndice %wu de la matriz está por encima de los límites de matriz de %qT"
@@ -23303,92 +23330,92 @@
 msgid "side-effects element in no-side-effects CONSTRUCTOR"
 msgstr "elemento con efectos colaterales en CONSTRUCTOR sin efectos colaterales"
 
-#: tree.c:7852
+#: tree.c:7856
 #, gcc-internal-format
 msgid "arrays of functions are not meaningful"
 msgstr "las matrices de funciones no tienen significado"
 
-#: tree.c:8019
+#: tree.c:8023
 #, gcc-internal-format
 msgid "function return type cannot be function"
 msgstr "el tipo de devolución de función no puede ser función"
 
-#: tree.c:9327 tree.c:9412 tree.c:9473
+#: tree.c:9331 tree.c:9416 tree.c:9477
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: %s, have %s in %s, at %s:%d"
 msgstr "revisión de árbol: %s, se tiene %s en %s, en %s:%d"
 
-#: tree.c:9364
+#: tree.c:9368
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected none of %s, have %s in %s, at %s:%d"
 msgstr "revisión de árbol: no se esperaba ninguno de %s, se tiene %s en %s, en %s:%d"
 
-#: tree.c:9377
+#: tree.c:9381
 #, gcc-internal-format
 msgid "tree check: expected class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "revisión de árbol: se esperaba la clase %qs, se tiene %qs (%s) en %s, en %s:%d"
 
-#: tree.c:9426
+#: tree.c:9430
 #, gcc-internal-format
 msgid "tree check: did not expect class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "revisión de árbol: no se esperaba la clase %qs, se tiene %qs (%s) en %s, en %s:%d"
 
-#: tree.c:9439
+#: tree.c:9443
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected omp_clause %s, have %s in %s, at %s:%d"
 msgstr "revisión de árbol: se esperaba omp_clause %s, se tiene %s en %s, en %s:%d"
 
-#: tree.c:9499
+#: tree.c:9503
 #, gcc-internal-format
 msgid "tree check: expected tree that contains %qs structure, have %qs in %s, at %s:%d"
 msgstr "revisión de árbol: se esperaba un árbol que contenga la estructura %qs, se tiene %qs en %s, en %s:%d"
 
-#: tree.c:9513
+#: tree.c:9517
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_int_cst with %d elts in %s, at %s:%d"
 msgstr "revisión de árbol: acceso de elt %d de tree_int_cst con %d elts en %s, en %s:%d"
 
-#: tree.c:9525
+#: tree.c:9529
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_vec with %d elts in %s, at %s:%d"
 msgstr "revisión de árbol: acceso de elt %d de tree_vec con %d elts en %s, en %s:%d"
 
-#: tree.c:9538
+#: tree.c:9542
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of %s with %d operands in %s, at %s:%d"
 msgstr "revisión de árbol: acceso del operando %d de %s con %d operandos en %s, en %s:%d"
 
-#: tree.c:9551
+#: tree.c:9555
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of omp_clause %s with %d operands in %s, at %s:%d"
 msgstr "revisión de árbol: acceso del operando %d de omp_clause %s con %d operandos en %s, en %s:%d"
 
-#: tree.c:12446
+#: tree.c:12450
 #, gcc-internal-format
 msgid "%qD is deprecated: %s"
 msgstr "%qD es obsoleto: %s"
 
-#: tree.c:12449
+#: tree.c:12453
 #, gcc-internal-format
 msgid "%qD is deprecated"
 msgstr "%qD es obsoleto"
 
-#: tree.c:12473 tree.c:12495
+#: tree.c:12477 tree.c:12499
 #, gcc-internal-format
 msgid "%qE is deprecated: %s"
 msgstr "%qE es obsoleto: %s"
 
-#: tree.c:12476 tree.c:12498
+#: tree.c:12480 tree.c:12502
 #, gcc-internal-format
 msgid "%qE is deprecated"
 msgstr "%qE es obsoleto"
 
-#: tree.c:12482 tree.c:12503
+#: tree.c:12486 tree.c:12507
 #, gcc-internal-format, gfc-internal-format
 msgid "type is deprecated: %s"
 msgstr "el tipo es obsoleto: %s"
 
-#: tree.c:12485 tree.c:12506
+#: tree.c:12489 tree.c:12510
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr "el tipo es obsoleto"
@@ -23413,242 +23440,242 @@
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.c:13043
+#: tree.c:13047
 #, gcc-internal-format, gfc-internal-format
 msgid "type variant differs by %s"
 msgstr "tipo variante difiere en %s"
 
-#: tree.c:13084
+#: tree.c:13088
 #, gcc-internal-format
 msgid "type variant has different TYPE_SIZE_UNIT"
 msgstr "tipos variantes difieren en TYPE_SIZE_UNIT"
 
-#: tree.c:13086
+#: tree.c:13090
 #, gcc-internal-format
 msgid "type variant's TYPE_SIZE_UNIT"
 msgstr "TYPE_SIZE_UNIT del tipo variante"
 
-#: tree.c:13088
+#: tree.c:13092
 #, gcc-internal-format
 msgid "type's TYPE_SIZE_UNIT"
 msgstr "TYPE_SIZE_UNIT del tipo"
 
-#: tree.c:13108
+#: tree.c:13112
 #, gcc-internal-format
 msgid "type variant with TYPE_ALIAS_SET_KNOWN_P"
 msgstr "tipo variante con TYPE_ALIAS_SET_KNOWN_P"
 
-#: tree.c:13121
+#: tree.c:13125
 #, gcc-internal-format
 msgid "type variant has different TYPE_VFIELD"
 msgstr "tipo variante con diferente TYPE_VFIELD"
 
-#: tree.c:13157
+#: tree.c:13161
 #, gcc-internal-format
 msgid "type variant has different TYPE_BINFO"
 msgstr "tipo variante con diferente TYPE_BINFO"
 
-#: tree.c:13159
+#: tree.c:13163
 #, gcc-internal-format
 msgid "type variant's TYPE_BINFO"
 msgstr "TYPE_BINFO del tipo variante"
 
-#: tree.c:13161
+#: tree.c:13165
 #, gcc-internal-format
 msgid "type's TYPE_BINFO"
 msgstr "TYPE_BINFO del tipo"
 
-#: tree.c:13199
+#: tree.c:13203
 #, gcc-internal-format
 msgid "type variant has different TYPE_FIELDS"
 msgstr "tipo variante con diferente TYPE_FIELDS"
 
-#: tree.c:13201
+#: tree.c:13205
 #, gcc-internal-format
 msgid "first mismatch is field"
 msgstr "el primer descuadre es campo"
 
-#: tree.c:13203
+#: tree.c:13207
 #, gcc-internal-format
 msgid "and field"
 msgstr "y campo"
 
-#: tree.c:13220
+#: tree.c:13224
 #, gcc-internal-format
 msgid "type variant has different TREE_TYPE"
 msgstr "tipo variante con diferente TREE_TYPE"
 
-#: tree.c:13222 tree.c:13233
+#: tree.c:13226 tree.c:13237
 #, gcc-internal-format
 msgid "type variant's TREE_TYPE"
 msgstr "TREE_TYPE del tipo variante"
 
-#: tree.c:13224 tree.c:13235
+#: tree.c:13228 tree.c:13239
 #, gcc-internal-format
 msgid "type's TREE_TYPE"
 msgstr "TREE_TYPE del tipo"
 
-#: tree.c:13231
+#: tree.c:13235
 #, gcc-internal-format
 msgid "type is not compatible with its variant"
 msgstr "el tipo no es compatible con su variante"
 
-#: tree.c:13534
+#: tree.c:13538
 #, gcc-internal-format
 msgid "Main variant is not defined"
 msgstr "La variante principal no está definida"
 
-#: tree.c:13539
+#: tree.c:13543
 #, gcc-internal-format
 msgid "TYPE_MAIN_VARIANT has different TYPE_MAIN_VARIANT"
 msgstr "TYPE_MAIN_VARIANT tiene diferente TYPE_MAIN_VARIANT"
 
-#: tree.c:13551
+#: tree.c:13555
 #, gcc-internal-format
 msgid "TYPE_CANONICAL has different TYPE_CANONICAL"
 msgstr "TYPE_CANONICAL tiene diferente TYPE_CANONICAL"
 
-#: tree.c:13569
+#: tree.c:13573
 #, gcc-internal-format
 msgid "TYPE_CANONICAL is not compatible"
 msgstr "TYPE_CANONICAL no es compatible"
 
-#: tree.c:13577
+#: tree.c:13581
 #, gcc-internal-format
 msgid "TYPE_MODE of TYPE_CANONICAL is not compatible"
 msgstr "TYPE_MODE de TYPE_CANONICAL no es compatible"
 
-#: tree.c:13583
+#: tree.c:13587
 #, gcc-internal-format
 msgid "TYPE_CANONICAL of main variant is not main variant"
 msgstr ""
 
-#: tree.c:13599
+#: tree.c:13603
 #, gcc-internal-format
 msgid "TYPE_VFIELD is not FIELD_DECL nor TREE_LIST"
 msgstr "TYPE_VFIELD no es FIELD_DECL ni TREE_LIST"
 
-#: tree.c:13609
+#: tree.c:13613
 #, gcc-internal-format
 msgid "TYPE_NEXT_PTR_TO is not POINTER_TYPE"
 msgstr "TYPE_NEXT_PTR_TO no es POINTER_TYPE"
 
-#: tree.c:13619
+#: tree.c:13623
 #, gcc-internal-format
 msgid "TYPE_NEXT_REF_TO is not REFERENCE_TYPE"
 msgstr "TYPE_NEXT_REF_TO no es REFERENCE_TYPE"
 
-#: tree.c:13640
+#: tree.c:13644
 #, gcc-internal-format
 msgid "TYPE_BINFO is not TREE_BINFO"
 msgstr "TYPE_BINFO no es TREE_BINFO"
 
-#: tree.c:13646
+#: tree.c:13650
 #, gcc-internal-format
 msgid "TYPE_BINFO type is not TYPE_MAIN_VARIANT"
 msgstr "El tipo TYPE_BINFO no es TYPE_MAIN_VARIANT"
 
-#: tree.c:13657
+#: tree.c:13661
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not record nor union"
 msgstr "TYPE_METHOD_BASETYPE no es registro ni unión"
 
-#: tree.c:13668
+#: tree.c:13672
 #, gcc-internal-format
 msgid "TYPE_OFFSET_BASETYPE is not record nor union"
 msgstr "TYPE_OFFSET_BASETYPE no es registro ni unión"
 
-#: tree.c:13686
+#: tree.c:13690
 #, gcc-internal-format
 msgid "TYPE_ARRAY_MAX_SIZE not INTEGER_CST"
 msgstr "TYPE_ARRAY_MAX_SIZE no es INTEGER_CST"
 
-#: tree.c:13693
+#: tree.c:13697
 #, gcc-internal-format
 msgid "TYPE_MAX_VALUE_RAW non-NULL"
 msgstr "TYPE_MAX_VALUE_RAW no NULL"
 
-#: tree.c:13700
+#: tree.c:13704
 #, gcc-internal-format
 msgid "TYPE_LANG_SLOT_1 (binfo) field is non-NULL"
 msgstr "El campo TYPE_LANG_SLOT_1 (binfo) es no NULL"
 
-#: tree.c:13716
+#: tree.c:13720
 #, gcc-internal-format
 msgid "Enum value is not CONST_DECL or INTEGER_CST"
 msgstr "El valor enumerado no es CONST_DECL ni INTEGER_CST"
 
-#: tree.c:13724
+#: tree.c:13728
 #, gcc-internal-format
 msgid "Enum value type is not INTEGER_TYPE nor convertible to the enum"
 msgstr "El tipo de valor enumerado no es INTEGER_TYPE ni puede convertirse al enumerado"
 
-#: tree.c:13731
+#: tree.c:13735
 #, gcc-internal-format
 msgid "Enum value name is not IDENTIFIER_NODE"
 msgstr "El nombre de valor enumerado no es IDENTIFIER_NODE"
 
-#: tree.c:13741
+#: tree.c:13745
 #, gcc-internal-format
 msgid "Array TYPE_DOMAIN is not integer type"
 msgstr "El array TYPE_DOMAIN no es de un tipo entero"
 
-#: tree.c:13750
+#: tree.c:13754
 #, gcc-internal-format
 msgid "TYPE_FIELDS defined in incomplete type"
 msgstr "TYPE_FIELDS definidos en un tipo incompleto"
 
-#: tree.c:13772
+#: tree.c:13776
 #, gcc-internal-format
 msgid "Wrong tree in TYPE_FIELDS list"
 msgstr "Árbol incorrecto en una lista TYPE_FIELDS"
 
-#: tree.c:13787
+#: tree.c:13791
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is %i while TYPE_CACHED_VALUES is %p"
 msgstr "TYPE_CACHED_VALUES_P es %i mientras que TYPE_CACHED_VALUES es %p"
 
-#: tree.c:13793
+#: tree.c:13797
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES is not TREE_VEC"
 msgstr "TYPE_CACHED_VALUES no es TREE_VEC"
 
-#: tree.c:13806
+#: tree.c:13810
 #, gcc-internal-format
 msgid "wrong TYPE_CACHED_VALUES entry"
 msgstr "entrada TYPE_CACHED_VALUES incorrecta"
 
-#: tree.c:13819
+#: tree.c:13823
 #, gcc-internal-format
 msgid "TREE_PURPOSE is non-NULL in TYPE_ARG_TYPES list"
 msgstr "TREE_PURPOSE es no NULL en una lista TYPE_ARG_TYPES"
 
-#: tree.c:13825
+#: tree.c:13829
 #, gcc-internal-format
 msgid "Wrong entry in TYPE_ARG_TYPES list"
 msgstr "Entrada incorrecta en una lista TYPE_ARG_TYPES"
 
-#: tree.c:13832
+#: tree.c:13836
 #, gcc-internal-format
 msgid "TYPE_VALUES_RAW field is non-NULL"
 msgstr "El campo TYPE_VALUES_RAW es no NULL"
 
-#: tree.c:13844
+#: tree.c:13848
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is set while it should not"
 msgstr "TYPE_CACHED_VALUES_P está activado y no debería"
 
-#: tree.c:13850
+#: tree.c:13854
 #, gcc-internal-format
 msgid "TYPE_STRING_FLAG is set on wrong type code"
 msgstr "TYPE_STRING_FLAG está activado en un código de tipo incorrecto"
 
-#: tree.c:13860
+#: tree.c:13864
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not main variant"
 msgstr "TYPE_METHOD_BASETYPE no es una variante de main"
 
-#: tree.c:13867
+#: tree.c:13871
 #, gcc-internal-format
 msgid "verify_type failed"
 msgstr "falló verify_type"
@@ -23673,183 +23700,183 @@
 msgid "corrupted value profile: %s profile counter (%d out of %d) inconsistent with basic-block count (%d)"
 msgstr "valor de perfil corrupto: la cuenta del perfilador %s (%d de %d) es inconsistente con la cuenta bloque-básico (%d)"
 
-#: var-tracking.c:7166
+#: var-tracking.c:7184
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded with -fvar-tracking-assignments, retrying without"
 msgstr "se excedió el límite de tamaño de rastreo de variable con -fvar-tracking-assignments, se reintenta sin esa opción"
 
-#: var-tracking.c:7170
+#: var-tracking.c:7188
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded"
 msgstr "se excedió el límite de tamaño de rastreo de variable"
 
-#: varasm.c:326
+#: varasm.c:337
 #, gcc-internal-format
 msgid "%+qD causes a section type conflict with %qD"
 msgstr "%+qD causa un conflicto de tipo de sección con %qD"
 
-#: varasm.c:329
+#: varasm.c:340
 #, gcc-internal-format
 msgid "section type conflict with %qD"
 msgstr "conflicto de tipo de sección con %qD"
 
-#: varasm.c:334
+#: varasm.c:345
 #, gcc-internal-format
 msgid "%+qD causes a section type conflict"
 msgstr "%+qD causa un conflicto de tipo de sección"
 
-#: varasm.c:336
+#: varasm.c:347
 #, gcc-internal-format
 msgid "section type conflict"
 msgstr "conflicto de tipo de sección"
 
-#: varasm.c:1019
+#: varasm.c:1030
 #, gcc-internal-format
 msgid "alignment of %q+D is greater than maximum object file alignment %d"
 msgstr "la alineación de %q+D es mayor que la alineación máxima del fichero objeto %d"
 
-#: varasm.c:1172
+#: varasm.c:1183
 #, gcc-internal-format
 msgid "only zero initializers are allowed in section %qs"
 msgstr "solo se permiten inicializadores a cero en la sección %qs"
 
-#: varasm.c:1378 varasm.c:1387
+#: varasm.c:1389 varasm.c:1398
 #, gcc-internal-format
 msgid "register name not specified for %q+D"
 msgstr "no se especifica un nombre de registro para %q+D"
 
-#: varasm.c:1389
+#: varasm.c:1400
 #, gcc-internal-format
 msgid "invalid register name for %q+D"
 msgstr "nombre de registro no válido para %q+D"
 
-#: varasm.c:1391
+#: varasm.c:1402
 #, gcc-internal-format
 msgid "data type of %q+D isn%'t suitable for a register"
 msgstr "el tipo de datos de %q+D no es adecuado para un registro"
 
-#: varasm.c:1394
+#: varasm.c:1405
 #, gcc-internal-format
 msgid "the register specified for %q+D cannot be accessed by the current target"
 msgstr "no se puede acceder al registro especificado por %q+D en el objetivo actual"
 
-#: varasm.c:1397
+#: varasm.c:1408
 #, gcc-internal-format
 msgid "the register specified for %q+D is not general enough to be used as a register variable"
 msgstr "el registro especificado para %q+D no es lo suficientemente general para usarse como variable de registro"
 
-#: varasm.c:1400
+#: varasm.c:1411
 #, gcc-internal-format
 msgid "register specified for %q+D isn%'t suitable for data type"
 msgstr "el registro especificado por %q+D no es adecuado para el tipo de datos"
 
-#: varasm.c:1410
+#: varasm.c:1421
 #, gcc-internal-format
 msgid "global register variable has initial value"
 msgstr "la variable de registro global tiene valor inicial"
 
-#: varasm.c:1414
+#: varasm.c:1425
 #, gcc-internal-format
 msgid "optimization may eliminate reads and/or writes to register variables"
 msgstr "la optimización puede eliminar lecturas y/o escrituras a variables de registro"
 
-#: varasm.c:1460
+#: varasm.c:1471
 #, gcc-internal-format
 msgid "register name given for non-register variable %q+D"
 msgstr "nombre de registro dado para la variable %q+D que no es registro"
 
-#: varasm.c:1870
+#: varasm.c:1881
 #, fuzzy, gcc-internal-format
 #| msgid "Use alternate leaf function entries"
 msgid "Patchable function entry > size"
 msgstr "Usar entradas de función hojas alternadas"
 
-#: varasm.c:2069
+#: varasm.c:2080
 #, gcc-internal-format
 msgid "thread-local COMMON data not implemented"
 msgstr "los datos COMMON thread-local no están implementados"
 
-#: varasm.c:2102
+#: varasm.c:2113
 #, gcc-internal-format
 msgid "requested alignment for %q+D is greater than implemented alignment of %wu"
 msgstr "la alineación solicitada para %q+D es mayor que la alineación implementada de %wu"
 
-#: varasm.c:2205 c/c-decl.c:5027 c/c-parser.c:1534
+#: varasm.c:2216 c/c-decl.c:5027 c/c-parser.c:1534
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t known"
 msgstr "no se conoce el tamaño de almacenamiento de %q+D"
 
-#: varasm.c:4910
+#: varasm.c:4921
 #, gcc-internal-format
 msgid "initializer for integer/fixed-point value is too complicated"
 msgstr "el inicializador para un valor entero/coma fija es demasiado complicado"
 
-#: varasm.c:4915
+#: varasm.c:4926
 #, gcc-internal-format
 msgid "initializer for floating value is not a floating constant"
 msgstr "el inicializador para un valor de coma flotante no es una constante de coma flotante"
 
-#: varasm.c:5227
+#: varasm.c:5238
 #, gcc-internal-format
 msgid "invalid initial value for member %qE"
 msgstr "valor inicial no válido para el miembro %qE"
 
-#: varasm.c:5487
+#: varasm.c:5498
 #, gcc-internal-format
 msgid "%+qD declared weak after being used"
 msgstr "%+qD se declaró débil después de usarse"
 
-#: varasm.c:5539
+#: varasm.c:5550
 #, gcc-internal-format
 msgid "weak declaration of %q+D being applied to a already existing, static definition"
 msgstr "la declaración débil de %q+D se está aplicando a una definición estática que ya existe"
 
-#: varasm.c:5575
+#: varasm.c:5586
 #, gcc-internal-format
 msgid "weak declaration of %q+D must be public"
 msgstr "la declaración weak de %q+D debe ser public"
 
-#: varasm.c:5579
+#: varasm.c:5590
 #, gcc-internal-format
 msgid "weak declaration of %q+D not supported"
 msgstr "no se admite la declaración weak de %q+D"
 
-#: varasm.c:5608 varasm.c:5912
+#: varasm.c:5619 varasm.c:5926
 #, gcc-internal-format
 msgid "only weak aliases are supported in this configuration"
 msgstr "sólo se admiten los aliases weak en esta configuración"
 
-#: varasm.c:5802
+#: varasm.c:5813
 #, gcc-internal-format
 msgid "weakref is not supported in this configuration"
 msgstr "weakref no se admite en esta configuración"
 
-#: varasm.c:5834
+#: varasm.c:5846
 #, gcc-internal-format
 msgid "ifunc is not supported on this target"
 msgstr "no se admiten ifunc en este objetivo"
 
-#: varasm.c:5892
+#: varasm.c:5904
 #, gcc-internal-format
 msgid "weakref %q+D ultimately targets itself"
 msgstr "la referencia débil %q+D finalmente apunta a sí misma"
 
-#: varasm.c:5894
+#: varasm.c:5906
 #, gcc-internal-format
 msgid "weakref %q+D must have static linkage"
 msgstr "la referencia débil %q+D debe tener enlace estático"
 
-#: varasm.c:5901
+#: varasm.c:5913
 #, gcc-internal-format
 msgid "alias definitions not supported in this configuration"
 msgstr "no se admiten las definiciones de alias en esta configuración"
 
-#: varasm.c:5909
+#: varasm.c:5923
 #, gcc-internal-format
 msgid "ifunc is not supported in this configuration"
 msgstr "ifunc no se admite en esta configuración"
 
-#: varasm.c:6127 config/sol2.c:159 config/i386/winnt.c:265
+#: varasm.c:6141 config/sol2.c:159 config/i386/winnt.c:265
 #, gcc-internal-format
 msgid "visibility attribute not supported in this configuration; ignored"
 msgstr "no se admiten los atributos de visibilidad en esta configuración; descartados"
@@ -23925,467 +23952,473 @@
 msgid "bytecode stream: tag %s is not in the expected range [%s, %s]"
 msgstr "flujo de bytecode: la etiqueta %s no está en el rango esperado [%s, %s]"
 
-#: c-family/c-attribs.c:529
+#: c-family/c-attribs.c:524
+#, fuzzy, gcc-internal-format
+#| msgid "%qE attribute ignored for %qE"
+msgid "%qE attribute ignored for type %qT"
+msgstr "se descarta el atributo %qE para %qE"
+
+#: c-family/c-attribs.c:536
 #, gcc-internal-format
 msgid "%qE attribute ignored for field of type %qT"
 msgstr "se descarta el atributo %qE para el campo de tipo %qT"
 
-#: c-family/c-attribs.c:696
+#: c-family/c-attribs.c:706
 #, fuzzy, gcc-internal-format
 #| msgid "alias argument not a string"
 msgid "no_sanitize argument not a string"
 msgstr "el argumento de alias no es una cadena"
 
-#: c-family/c-attribs.c:826 ada/gcc-interface/utils.c:6235
+#: c-family/c-attribs.c:837 ada/gcc-interface/utils.c:6240
 #, gcc-internal-format
 msgid "%qE attribute ignored due to conflict with attribute %qs"
 msgstr "Se hace caso omiso del atributo %qE debido a un conflicto con el atributo %qs"
 
-#: c-family/c-attribs.c:875
+#: c-family/c-attribs.c:886
 #, gcc-internal-format
 msgid "%qE attribute ignored. Use -fcf-protection option to enable it"
 msgstr "Se descarta el atributo %qE. Utilice la opción -fcf-protection para activarlo"
 
-#: c-family/c-attribs.c:914 c-family/c-attribs.c:920 c-family/c-attribs.c:3388
-#: c-family/c-attribs.c:3423 c-family/c-attribs.c:3429
+#: c-family/c-attribs.c:925 c-family/c-attribs.c:931 c-family/c-attribs.c:3399
+#: c-family/c-attribs.c:3434 c-family/c-attribs.c:3440
 #, gcc-internal-format
 msgid "%qE attribute ignored due to conflict with %qs attribute"
 msgstr "Se hace caso omiso del atributo %qE debido a un conflicto con el atributo %qs"
 
-#: c-family/c-attribs.c:976 brig/brig-lang.c:482 lto/lto-lang.c:288
+#: c-family/c-attribs.c:987 brig/brig-lang.c:482 lto/lto-lang.c:288
 #, gcc-internal-format
 msgid "%qE attribute has no effect on unit local functions"
 msgstr "el atributo %qE no tiene efecto en funciones locales de unidad"
 
-#: c-family/c-attribs.c:1130
+#: c-family/c-attribs.c:1141
 #, gcc-internal-format
 msgid "%qE attribute have effect only on public objects"
 msgstr "el atributo %qE sólo tiene efecto en objetos públicos"
 
-#: c-family/c-attribs.c:1159
+#: c-family/c-attribs.c:1170
 #, gcc-internal-format
 msgid "%qE attribute only affects top level objects"
 msgstr "el atributo %qE solamente afecta a objetos de alto nivel"
 
-#: c-family/c-attribs.c:1198 c-family/c-attribs.c:2682
+#: c-family/c-attribs.c:1209 c-family/c-attribs.c:2693
 #, gcc-internal-format
 msgid "%qE attribute on function returning %<void%>"
 msgstr "atributo %qE en una función que devuelve %<void%>"
 
-#: c-family/c-attribs.c:1221 c-family/c-pragma.c:419
+#: c-family/c-attribs.c:1232 c-family/c-pragma.c:419
 #, gcc-internal-format
 msgid "scalar_storage_order is not supported because endianness is not uniform"
 msgstr "scalar_storage_order no se admite porque el endianess no es uniforme"
 
-#: c-family/c-attribs.c:1238
+#: c-family/c-attribs.c:1249
 #, gcc-internal-format
 msgid "scalar_storage_order argument must be one of \"big-endian\" or \"little-endian\""
 msgstr "el argumento scalar_storage_order solo puede ser \"big-endian\" o \"little-endian\""
 
-#: c-family/c-attribs.c:1334
+#: c-family/c-attribs.c:1345
 #, gcc-internal-format
 msgid "destructor priorities are not supported"
 msgstr "no se admiten las prioridades de destructor"
 
-#: c-family/c-attribs.c:1336
+#: c-family/c-attribs.c:1347
 #, gcc-internal-format
 msgid "constructor priorities are not supported"
 msgstr "no se admiten las prioridades de constructor"
 
-#: c-family/c-attribs.c:1358
+#: c-family/c-attribs.c:1369
 #, gcc-internal-format, gfc-internal-format
 msgid "destructor priorities from 0 to %d are reserved for the implementation"
 msgstr "las prioridades de destructor desde 0 hasta %d están reservadas para la implementación"
 
-#: c-family/c-attribs.c:1363
+#: c-family/c-attribs.c:1374
 #, gcc-internal-format, gfc-internal-format
 msgid "constructor priorities from 0 to %d are reserved for the implementation"
 msgstr "las prioridades de constructor desde 0 hasta %d están reservadas para la implementación"
 
-#: c-family/c-attribs.c:1371
+#: c-family/c-attribs.c:1382
 #, gcc-internal-format, gfc-internal-format
 msgid "destructor priorities must be integers from 0 to %d inclusive"
 msgstr "las prioridades de destructor deben ser enteros desde 0 hasta %d inclusive"
 
-#: c-family/c-attribs.c:1374
+#: c-family/c-attribs.c:1385
 #, gcc-internal-format, gfc-internal-format
 msgid "constructor priorities must be integers from 0 to %d inclusive"
 msgstr "las prioridades de constructor deben ser enteros desde 0 hasta %d inclusive"
 
-#: c-family/c-attribs.c:1527
+#: c-family/c-attribs.c:1538
 #, gcc-internal-format
 msgid "unknown machine mode %qE"
 msgstr "se desconoce el modo de máquina %qE"
 
-#: c-family/c-attribs.c:1557
+#: c-family/c-attribs.c:1568
 #, gcc-internal-format
 msgid "specifying vector types with __attribute__ ((mode)) is deprecated"
 msgstr "es obsoleto especificar tipos vectoriales con __attribute__ ((mode))"
 
-#: c-family/c-attribs.c:1560
+#: c-family/c-attribs.c:1571
 #, gcc-internal-format
 msgid "use __attribute__ ((vector_size)) instead"
 msgstr "utilice __attribute__ ((vector_size)) en su lugar"
 
-#: c-family/c-attribs.c:1569
+#: c-family/c-attribs.c:1580
 #, gcc-internal-format
 msgid "unable to emulate %qs"
 msgstr "no se puede emular %qs"
 
-#: c-family/c-attribs.c:1582
+#: c-family/c-attribs.c:1593
 #, gcc-internal-format
 msgid "invalid pointer mode %qs"
 msgstr "modo de puntero %qs no válido"
 
-#: c-family/c-attribs.c:1599
+#: c-family/c-attribs.c:1610
 #, gcc-internal-format
 msgid "signedness of type and machine mode %qs don%'t match"
 msgstr "no coinciden los signos del tipo y del modo de máquina %qs"
 
-#: c-family/c-attribs.c:1610
+#: c-family/c-attribs.c:1621
 #, gcc-internal-format
 msgid "no data type for mode %qs"
 msgstr "no hay tipo de datos para el modo %qs"
 
-#: c-family/c-attribs.c:1620
+#: c-family/c-attribs.c:1631
 #, gcc-internal-format
 msgid "cannot use mode %qs for enumeral types"
 msgstr "no se puede usar el modo %qs para tipos de enumeración"
 
-#: c-family/c-attribs.c:1647
+#: c-family/c-attribs.c:1658
 #, gcc-internal-format
 msgid "mode %qs applied to inappropriate type"
 msgstr "se aplicó el modo %qs a un tipo inapropiado"
 
-#: c-family/c-attribs.c:1669
+#: c-family/c-attribs.c:1680
 #, gcc-internal-format
 msgid "section attributes are not supported for this target"
 msgstr "no se admiten atributos de sección en este objetivo"
 
-#: c-family/c-attribs.c:1675
+#: c-family/c-attribs.c:1686
 #, gcc-internal-format
 msgid "section attribute not allowed for %q+D"
 msgstr "no se permite un atributo de sección para %q+D"
 
-#: c-family/c-attribs.c:1681
+#: c-family/c-attribs.c:1692
 #, gcc-internal-format
 msgid "section attribute argument not a string constant"
 msgstr "el argumento del atributo sección no es una constante de cadena"
 
-#: c-family/c-attribs.c:1690
+#: c-family/c-attribs.c:1701
 #, gcc-internal-format
 msgid "section attribute cannot be specified for local variables"
 msgstr "no se puede especificar el atributo de sección para las variables locales"
 
-#: c-family/c-attribs.c:1700 config/bfin/bfin.c:4806 config/bfin/bfin.c:4857
+#: c-family/c-attribs.c:1711 config/bfin/bfin.c:4806 config/bfin/bfin.c:4857
 #: config/bfin/bfin.c:4883 config/bfin/bfin.c:4896
 #, gcc-internal-format
 msgid "section of %q+D conflicts with previous declaration"
 msgstr "la sección de %q+D genera un conflicto con la declaración previa"
 
-#: c-family/c-attribs.c:1708
+#: c-family/c-attribs.c:1719
 #, gcc-internal-format
 msgid "section of %q+D cannot be overridden"
 msgstr "no se puede sobreescribir la sección de %q+D"
 
-#: c-family/c-attribs.c:1773
+#: c-family/c-attribs.c:1784
 #, gcc-internal-format, gfc-internal-format
 msgid "requested alignment %d is larger than %d"
 msgstr "la alineación solicitada %d es mayor que %d"
 
-#: c-family/c-attribs.c:1866
+#: c-family/c-attribs.c:1877
 #, gcc-internal-format
 msgid "alignment may not be specified for %q+D"
 msgstr "la alineación puede no estar especificada para %q+D"
 
-#: c-family/c-attribs.c:1886
+#: c-family/c-attribs.c:1897
 #, gcc-internal-format
 msgid "ignoring attribute %<%E (%u)%> because it conflicts with attribute %<%E (%u)%>"
 msgstr "Se descarta el atributo %<%E (%u)%> porque genera un conflicto con el atributo %<%E (%u)%>"
 
 #. Do not error out for attribute warn_if_not_aligned.
-#: c-family/c-attribs.c:1891 c-family/c-attribs.c:1920
+#: c-family/c-attribs.c:1902 c-family/c-attribs.c:1931
 #, gcc-internal-format
 msgid "alignment for %q+D must be at least %d"
 msgstr "la alineación para %q+D debe ser por lo menos %d"
 
-#: c-family/c-attribs.c:1916
+#: c-family/c-attribs.c:1927
 #, gcc-internal-format
 msgid "alignment for %q+D was previously specified as %d and may not be decreased"
 msgstr "la alineación para %q+D se especifió previamente como %d y no se puede decrementar"
 
-#: c-family/c-attribs.c:1943
+#: c-family/c-attribs.c:1954
 #, gcc-internal-format
 msgid "%<warn_if_not_aligned%> may not be specified for %q+D"
 msgstr "%<warn_if_not_aligned%>  puede no estar especificada para %q+D"
 
-#: c-family/c-attribs.c:1986
+#: c-family/c-attribs.c:1997
 #, gcc-internal-format
 msgid "inline function %q+D declared weak"
 msgstr "la función inline %q+D se declaró weak"
 
-#: c-family/c-attribs.c:1991
+#: c-family/c-attribs.c:2002
 #, gcc-internal-format
 msgid "indirect function %q+D cannot be declared weak"
 msgstr "la función indirecta %q+D no se puede declarar weak"
 
-#: c-family/c-attribs.c:2015
+#: c-family/c-attribs.c:2026
 #, gcc-internal-format
 msgid "%qE attribute is only applicable on functions"
 msgstr "el atributo %qE se aplica solamente a funciones"
 
-#: c-family/c-attribs.c:2046
+#: c-family/c-attribs.c:2057
 #, gcc-internal-format
 msgid "%q+D defined both normally and as %qE attribute"
 msgstr "se definió %q+D normalmente y como un atributo %qE al mismo tiempo"
 
-#: c-family/c-attribs.c:2054
+#: c-family/c-attribs.c:2065
 #, gcc-internal-format
 msgid "weak %q+D cannot be defined %qE"
 msgstr "weak %q+D no se puede definir como %qE"
 
-#: c-family/c-attribs.c:2071 c-family/c-attribs.c:2582
+#: c-family/c-attribs.c:2082 c-family/c-attribs.c:2593
 #, gcc-internal-format
 msgid "attribute %qE argument not a string"
 msgstr "el argumento del atributo %qE no es una cadena"
 
-#: c-family/c-attribs.c:2106
+#: c-family/c-attribs.c:2117
 #, gcc-internal-format
 msgid "%+qD declared alias after being used"
 msgstr "%+qD se declaró después de ser usado"
 
-#: c-family/c-attribs.c:2108
+#: c-family/c-attribs.c:2119
 #, gcc-internal-format
 msgid "%+qD declared ifunc after being used"
 msgstr "%+qD se declaró ifunc después de ser usado"
 
-#: c-family/c-attribs.c:2159
+#: c-family/c-attribs.c:2170
 #, gcc-internal-format
 msgid "indirect function %q+D cannot be declared weakref"
 msgstr "la función indirecta %q+D no se puede declarar weakref"
 
-#: c-family/c-attribs.c:2181
+#: c-family/c-attribs.c:2192
 #, gcc-internal-format
 msgid "weakref attribute must appear before alias attribute"
 msgstr "el atributo weakref debe aparecer antes de los atributos de alias"
 
-#: c-family/c-attribs.c:2193
+#: c-family/c-attribs.c:2204
 #, gcc-internal-format
 msgid "%+qD declared weakref after being used"
 msgstr "%+qD se declaró weakref después de ser usado"
 
-#: c-family/c-attribs.c:2217
+#: c-family/c-attribs.c:2228
 #, gcc-internal-format
 msgid "%qE attribute ignored on non-class types"
 msgstr "se descarta el atributo %qE en tipos que no son clases"
 
-#: c-family/c-attribs.c:2223
+#: c-family/c-attribs.c:2234
 #, gcc-internal-format
 msgid "%qE attribute ignored because %qT is already defined"
 msgstr "se descarta el atributo %qE porque %qT ya está definido"
 
-#: c-family/c-attribs.c:2236
+#: c-family/c-attribs.c:2247
 #, gcc-internal-format
 msgid "visibility argument not a string"
 msgstr "el argumento de visibilidad no es una cadena"
 
-#: c-family/c-attribs.c:2248
+#: c-family/c-attribs.c:2259
 #, gcc-internal-format
 msgid "%qE attribute ignored on types"
 msgstr "se descarta el atributo %qE en tipos"
 
-#: c-family/c-attribs.c:2264
+#: c-family/c-attribs.c:2275
 #, gcc-internal-format
 msgid "visibility argument must be one of \"default\", \"hidden\", \"protected\" or \"internal\""
 msgstr "el argumento de visibilidad debe ser \"default\", \"hidden\", \"protected\" o \"internal\""
 
-#: c-family/c-attribs.c:2275
+#: c-family/c-attribs.c:2286
 #, gcc-internal-format
 msgid "%qD redeclared with different visibility"
 msgstr "%qD se redeclaró con visibilidad diferente"
 
-#: c-family/c-attribs.c:2278 c-family/c-attribs.c:2282
+#: c-family/c-attribs.c:2289 c-family/c-attribs.c:2293
 #, gcc-internal-format
 msgid "%qD was declared %qs which implies default visibility"
 msgstr "%qD se declaró %qs lo cual implica visibilidad por defecto"
 
-#: c-family/c-attribs.c:2320
+#: c-family/c-attribs.c:2331
 #, gcc-internal-format
 msgid "tls_model argument not a string"
 msgstr "el argumento de tls_model no es una cadena"
 
-#: c-family/c-attribs.c:2333
+#: c-family/c-attribs.c:2344
 #, gcc-internal-format
 msgid "tls_model argument must be one of \"local-exec\", \"initial-exec\", \"local-dynamic\" or \"global-dynamic\""
 msgstr "el argumento de tls_model debe ser \"local-exec\", \"initial-exec\", \"local-dynamic\" o \"global-dynamic\""
 
-#: c-family/c-attribs.c:2353 c-family/c-attribs.c:2656
-#: c-family/c-attribs.c:3497 config/m32c/m32c.c:2944
+#: c-family/c-attribs.c:2364 c-family/c-attribs.c:2667
+#: c-family/c-attribs.c:3508 config/m32c/m32c.c:2944
 #, gcc-internal-format
 msgid "%qE attribute applies only to functions"
 msgstr "el atributo %qE se aplica solamente a funciones"
 
-#: c-family/c-attribs.c:2417
+#: c-family/c-attribs.c:2428
 #, gcc-internal-format
 msgid "alloc_size parameter outside range"
 msgstr "el parámetro de alloc_size está fuera de rango"
 
-#: c-family/c-attribs.c:2443
+#: c-family/c-attribs.c:2454
 #, gcc-internal-format
 msgid "alloc_align parameter outside range"
 msgstr "el parámetro de alloc_align está fuera de rango"
 
-#: c-family/c-attribs.c:2467
+#: c-family/c-attribs.c:2478
 #, gcc-internal-format
 msgid "assume_aligned parameter not integer constant"
 msgstr "el parámetro assume_aligned no es una constante entera"
 
-#: c-family/c-attribs.c:2595
+#: c-family/c-attribs.c:2606
 #, gcc-internal-format
 msgid "only %<inbranch%> and %<notinbranch%> flags are allowed for %<__simd__%> attribute"
 msgstr "%<inbranch%> y %<notinbranch%> son los únicos indicadores permitidos con el atributo %<__simd__%>"
 
-#: c-family/c-attribs.c:2662 c-family/c-attribs.c:3503
+#: c-family/c-attribs.c:2673 c-family/c-attribs.c:3514
 #, gcc-internal-format
 msgid "can%'t set %qE attribute after definition"
 msgstr "no se puede establecer el atributo %qE después de la definición"
 
-#: c-family/c-attribs.c:2727
+#: c-family/c-attribs.c:2738
 #, gcc-internal-format
 msgid "%qE attribute duplicated"
 msgstr "atributo %qE duplicado"
 
-#: c-family/c-attribs.c:2729
+#: c-family/c-attribs.c:2740
 #, gcc-internal-format
 msgid "%qE attribute follows %qE"
 msgstr "atributo %qE a continuación de %qE"
 
-#: c-family/c-attribs.c:2828
+#: c-family/c-attribs.c:2839
 #, gcc-internal-format
 msgid "type was previously declared %qE"
 msgstr "el tipo se declaró previamente %qE"
 
-#: c-family/c-attribs.c:2841 cp/class.c:4397
+#: c-family/c-attribs.c:2852 cp/class.c:4401
 #, gcc-internal-format
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
 msgstr "%<transaction_safe_dynamic%> solo se puede especificar para funciones virtuales"
 
-#: c-family/c-attribs.c:2899
+#: c-family/c-attribs.c:2910
 #, gcc-internal-format
 msgid "%qE argument not an identifier"
 msgstr "el argumento %qE no es un identificador"
 
-#: c-family/c-attribs.c:2910
+#: c-family/c-attribs.c:2921
 #, gcc-internal-format
 msgid "%qD is not compatible with %qD"
 msgstr "%qD no es compatible con %qD"
 
-#: c-family/c-attribs.c:2913
+#: c-family/c-attribs.c:2924
 #, gcc-internal-format
 msgid "%qE argument is not a function"
 msgstr "el argumento %qE no es una función"
 
-#: c-family/c-attribs.c:2961
+#: c-family/c-attribs.c:2972
 #, gcc-internal-format
 msgid "deprecated message is not a string"
 msgstr "el mensaje obsoleto no es una cadena"
 
-#: c-family/c-attribs.c:3002
+#: c-family/c-attribs.c:3013
 #, gcc-internal-format
 msgid "%qE attribute ignored for %qE"
 msgstr "se descarta el atributo %qE para %qE"
 
-#: c-family/c-attribs.c:3065
+#: c-family/c-attribs.c:3076
 #, gcc-internal-format
 msgid "invalid vector type for attribute %qE"
 msgstr "tipo de vector no válido para el atributo %qE"
 
-#: c-family/c-attribs.c:3071 ada/gcc-interface/utils.c:3896
+#: c-family/c-attribs.c:3082 ada/gcc-interface/utils.c:3899
 #, gcc-internal-format
 msgid "vector size not an integral multiple of component size"
 msgstr "el tamaño del vector no es un múltiplo integral del tamaño del componente"
 
-#: c-family/c-attribs.c:3077 ada/gcc-interface/utils.c:3903
+#: c-family/c-attribs.c:3088 ada/gcc-interface/utils.c:3906
 #, gcc-internal-format
 msgid "zero vector size"
 msgstr "vector de tamaño cero"
 
-#: c-family/c-attribs.c:3085
+#: c-family/c-attribs.c:3096
 #, gcc-internal-format
 msgid "number of components of the vector not a power of two"
 msgstr "el número de componentes del vector no es una potencia de dos"
 
-#: c-family/c-attribs.c:3118 ada/gcc-interface/utils.c:6092
+#: c-family/c-attribs.c:3129 ada/gcc-interface/utils.c:6098
 #, gcc-internal-format
 msgid "nonnull attribute without arguments on a non-prototype"
 msgstr "un atributo que no es nulo sin argumento es un atributo que no es prototipo"
 
-#: c-family/c-attribs.c:3137 ada/gcc-interface/utils.c:6106
+#: c-family/c-attribs.c:3148 ada/gcc-interface/utils.c:6112
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument has invalid operand number (argument %lu)"
 msgstr "un argumento que no es nulo tiene un número de operando no válido (argumento %lu)"
 
-#: c-family/c-attribs.c:3159 ada/gcc-interface/utils.c:6128
+#: c-family/c-attribs.c:3170 ada/gcc-interface/utils.c:6134
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument with out-of-range operand number (argument %lu, operand %lu)"
 msgstr "un argumento que no es nulo con número de operando fuera de rango (argumento %lu, operando %lu)"
 
-#: c-family/c-attribs.c:3168 ada/gcc-interface/utils.c:6137
+#: c-family/c-attribs.c:3179 ada/gcc-interface/utils.c:6143
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument references non-pointer operand (argument %lu, operand %lu)"
 msgstr "un argumento que no es nulo hace referencia a un operando que no es puntero (argumento %lu, operando %lu)"
 
-#: c-family/c-attribs.c:3208
+#: c-family/c-attribs.c:3219
 #, gcc-internal-format
 msgid "%qE attribute ignored on objects of type %qT"
 msgstr "se descarta el atributo %qE en objetos de tipo %qT"
 
-#: c-family/c-attribs.c:3216
+#: c-family/c-attribs.c:3227
 #, gcc-internal-format
 msgid "%qE attribute does not apply to functions"
 msgstr "el atributo %qE no se aplica a funciones"
 
-#: c-family/c-attribs.c:3273
+#: c-family/c-attribs.c:3284
 #, gcc-internal-format
 msgid "cleanup argument not an identifier"
 msgstr "el argumento de limpieza no es un identificador"
 
-#: c-family/c-attribs.c:3280
+#: c-family/c-attribs.c:3291
 #, gcc-internal-format
 msgid "cleanup argument not a function"
 msgstr "el argumento de limpieza no es una función"
 
-#: c-family/c-attribs.c:3317
+#: c-family/c-attribs.c:3328
 #, gcc-internal-format
 msgid "%qE attribute requires prototypes with named arguments"
 msgstr "el atributo %qE requiere prototipos con argumentos nombrados"
 
-#: c-family/c-attribs.c:3325
+#: c-family/c-attribs.c:3336
 #, gcc-internal-format
 msgid "%qE attribute only applies to variadic functions"
 msgstr "el atributo %qE se aplica solamente a funciones variadic"
 
-#: c-family/c-attribs.c:3341 ada/gcc-interface/utils.c:6179
+#: c-family/c-attribs.c:3352 ada/gcc-interface/utils.c:6185
 #, gcc-internal-format
 msgid "requested position is not an integer constant"
 msgstr "la posición solicitada no es una constante entera"
 
-#: c-family/c-attribs.c:3349 ada/gcc-interface/utils.c:6186
+#: c-family/c-attribs.c:3360 ada/gcc-interface/utils.c:6192
 #, gcc-internal-format
 msgid "requested position is less than zero"
 msgstr "la posición solicitada es menor a cero"
 
-#: c-family/c-attribs.c:3404
+#: c-family/c-attribs.c:3415
 #, gcc-internal-format
 msgid "empty string in attribute %<target%>"
 msgstr "cadena vacía en el atributo %<target%>"
 
-#: c-family/c-attribs.c:3520
+#: c-family/c-attribs.c:3531
 #, gcc-internal-format
 msgid "returns_nonnull attribute on a function not returning a pointer"
 msgstr "atributo returns_nonnull en una función que no devuelve puntero"
 
-#: c-family/c-attribs.c:3535
+#: c-family/c-attribs.c:3546
 #, gcc-internal-format
 msgid "%qE attribute is only valid on %<struct%> type"
 msgstr "el atributo %qE solo es válido con tipos %<struct%>"
@@ -24430,12 +24463,12 @@
 msgid "__builtin_shuffle argument vector(s) inner type must have the same size as inner type of the mask"
 msgstr "el tipo interno del vector (o vectores) argumento de __builtin_shuffle debe tener el mismo tamaño que el tipo interno de la máscara"
 
-#: c-family/c-common.c:1262 c-family/c-warn.c:1194
+#: c-family/c-common.c:1262 c-family/c-warn.c:1202
 #, gcc-internal-format
 msgid "unsigned conversion from %qT to %qT changes value from %qE to %qE"
 msgstr "la conversión sin signo de %qT a %qT cambia el valor de %qE a %qE"
 
-#: c-family/c-common.c:1267 c-family/c-warn.c:1202
+#: c-family/c-common.c:1267 c-family/c-warn.c:1210
 #, gcc-internal-format
 msgid "unsigned conversion from %qT to %qT changes the value of %qE"
 msgstr "la conversión sin signo de %qT a %qT cambia el valor de %qE"
@@ -24565,7 +24598,7 @@
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "se sugieren paréntesis alrededor de la asignación usada como valor verdadero"
 
-#: c-family/c-common.c:3518 c/c-decl.c:4325 c/c-decl.c:6430 c/c-typeck.c:14177
+#: c-family/c-common.c:3518 c/c-decl.c:4325 c/c-decl.c:6450 c/c-typeck.c:14182
 #, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr "uso no válido de %<restrict%>"
@@ -24645,7 +24678,7 @@
 msgid "duplicate case value"
 msgstr "valor de case duplicado"
 
-#: c-family/c-common.c:4867 c-family/c-warn.c:2216
+#: c-family/c-common.c:4867 c-family/c-warn.c:2225
 #, gcc-internal-format
 msgid "previously used here"
 msgstr "se usó previamente aquí"
@@ -24690,193 +24723,193 @@
 msgid "missing sentinel in function call"
 msgstr "falta un centinela en la llamada a la función"
 
-#: c-family/c-common.c:5411
+#: c-family/c-common.c:5409
 #, gcc-internal-format, gfc-internal-format
 msgid "null argument where non-null required (argument %lu)"
 msgstr "argumento nulo donde se requiere uno que no sea nulo (argumento %lu)"
 
-#: c-family/c-common.c:5506 c-family/c-common.c:5553
+#: c-family/c-common.c:5504 c-family/c-common.c:5551
 #, gcc-internal-format
 msgid "bad option %qs to attribute %<optimize%>"
 msgstr "opción %qs errónea para el atributo %<optimize%>"
 
-#: c-family/c-common.c:5509 c-family/c-common.c:5557
+#: c-family/c-common.c:5507 c-family/c-common.c:5555
 #, gcc-internal-format
 msgid "bad option %qs to pragma %<optimize%>"
 msgstr "opción %qs errónea para el pragma %<optimize%>"
 
-#: c-family/c-common.c:5589
+#: c-family/c-common.c:5587
 #, gcc-internal-format
 msgid "%<fallthrough%> attribute specified multiple times"
 msgstr "atributo %<fallthrough%> especificado múltiples veces"
 
-#: c-family/c-common.c:5593
+#: c-family/c-common.c:5591
 #, gcc-internal-format
 msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr "el atributo %<fallthrough%> se especificó con un parámetro"
 
-#: c-family/c-common.c:5733 c-family/c-common.c:6485 c-family/c-common.c:6558
+#: c-family/c-common.c:5731 c-family/c-common.c:6477 c-family/c-common.c:6550
 #: c/c-typeck.c:3555
 #, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr "faltan argumentos para la función %qE"
 
-#: c-family/c-common.c:5738 c-family/c-common.c:6584 c/c-typeck.c:3284
+#: c-family/c-common.c:5736 c-family/c-common.c:6576 c/c-typeck.c:3284
 #, gcc-internal-format
 msgid "too many arguments to function %qE"
 msgstr "demasiados argumentos para la función %qE"
 
-#: c-family/c-common.c:5769
+#: c-family/c-common.c:5767
 #, gcc-internal-format
 msgid "third argument to function %qE must be a constant integer"
 msgstr "el tercer argumento de la función %qEdebe ser una constante entera"
 
-#: c-family/c-common.c:5794
+#: c-family/c-common.c:5792
 #, gcc-internal-format
 msgid "second argument to function %qE must be a constant integer power of 2 between %qi and %qu bits"
 msgstr "el segundo argumento de la función %qE tiene que ser una potencia de 2 entera constante entre loss bits %qi y %qu"
 
-#: c-family/c-common.c:5815 c-family/c-common.c:5859
+#: c-family/c-common.c:5813 c-family/c-common.c:5857
 #, gcc-internal-format
 msgid "non-floating-point argument in call to function %qE"
 msgstr "argumento que no es de coma flotante en la llamada a la función %qE"
 
-#: c-family/c-common.c:5838
+#: c-family/c-common.c:5836
 #, gcc-internal-format
 msgid "non-floating-point arguments in call to function %qE"
 msgstr "argumentos que no son de coma flotante en la llamada a la función %qE"
 
-#: c-family/c-common.c:5852
+#: c-family/c-common.c:5850
 #, gcc-internal-format
 msgid "non-const integer argument %u in call to function %qE"
 msgstr "argumento %u entero que no es constante en la llamada a la función %qE"
 
-#: c-family/c-common.c:5872
+#: c-family/c-common.c:5870
 #, gcc-internal-format
 msgid "non-integer argument 3 in call to function %qE"
 msgstr "el argumento 3 no es entero en la llamada a la función %qE"
 
-#: c-family/c-common.c:5889 c-family/c-common.c:5925
+#: c-family/c-common.c:5887 c-family/c-common.c:5923
 #, gcc-internal-format
 msgid "argument %u in call to function %qE does not have integral type"
 msgstr "el argumento %u en la llamada a la función %qE no tiene un tipo entero"
 
-#: c-family/c-common.c:5896
+#: c-family/c-common.c:5894
 #, gcc-internal-format
 msgid "argument 3 in call to function %qE does not have pointer to integral type"
 msgstr "el argumento 3 en la llamada a la función %qE no tiene un puntero a un tipo entero"
 
-#: c-family/c-common.c:5902
+#: c-family/c-common.c:5900
 #, gcc-internal-format
 msgid "argument 3 in call to function %qE has pointer to enumerated type"
 msgstr "el argumento 3 en la llamada a la función %qE tiene un puntero a un tipo enumerado"
 
-#: c-family/c-common.c:5908
+#: c-family/c-common.c:5906
 #, gcc-internal-format
 msgid "argument 3 in call to function %qE has pointer to boolean type"
 msgstr "el argumento 3 en la llamada a la función %qE tiene un puntero a un tipo boolean"
 
-#: c-family/c-common.c:5931
+#: c-family/c-common.c:5929
 #, gcc-internal-format
 msgid "argument 3 in call to function %qE has enumerated type"
 msgstr "el argumento 3 en la llamada a la función %qE tiene un tipo enumerado"
 
-#: c-family/c-common.c:5937
+#: c-family/c-common.c:5935
 #, gcc-internal-format
 msgid "argument 3 in call to function %qE has boolean type"
 msgstr "el argumento 3 en la llamada a la función %qE tiene un tipo boolean"
 
-#: c-family/c-common.c:6184
+#: c-family/c-common.c:6183
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to static data member %qD"
 msgstr "no se puede aplicar %<offsetof%> al dato miembro static %qD"
 
-#: c-family/c-common.c:6189
+#: c-family/c-common.c:6188
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> when %<operator[]%> is overloaded"
 msgstr "no se puede aplicar %<offsetof%> cuando %<operator[]%> está sobrecargado"
 
-#: c-family/c-common.c:6196
+#: c-family/c-common.c:6195
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to a non constant address"
 msgstr "no se puede aplicar %<offsetof%> a una dirección que no es constante"
 
-#: c-family/c-common.c:6209
+#: c-family/c-common.c:6208
 #, gcc-internal-format
 msgid "attempt to take address of bit-field structure member %qD"
 msgstr "se intentó tomar la dirección del miembro de la estructura de campos de bits %qD"
 
-#: c-family/c-common.c:6261
+#: c-family/c-common.c:6260
 #, gcc-internal-format
 msgid "index %E denotes an offset greater than size of %qT"
 msgstr "el índice %E denota un desplazamiento mayor que el tamaño de %qT"
 
-#: c-family/c-common.c:6427 cp/init.c:3004 cp/init.c:3023
+#: c-family/c-common.c:6419 cp/init.c:3020 cp/init.c:3039
 #, gcc-internal-format
 msgid "size of array is too large"
 msgstr "el tamaño de la matriz es demasiado grande"
 
-#: c-family/c-common.c:6517
+#: c-family/c-common.c:6509
 #, gcc-internal-format
 msgid "operand type %qT is incompatible with argument %d of %qE"
 msgstr "el tipo %qT del operando es incompatible con el argumento %d de %qE"
 
-#: c-family/c-common.c:6651
+#: c-family/c-common.c:6643
 #, gcc-internal-format
 msgid "incorrect number of arguments to function %qE"
 msgstr "número incorrecto de argumentos para la función %qE"
 
-#: c-family/c-common.c:6665
+#: c-family/c-common.c:6657
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a non-void pointer type"
 msgstr "el argumento 1 de %qE debe ser un tipo puntero que no sea void"
 
-#: c-family/c-common.c:6674
+#: c-family/c-common.c:6666
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a constant size type"
 msgstr "el argumento 1 de %qE debe ser un puntero a un tipo de tamaño constante"
 
-#: c-family/c-common.c:6685
+#: c-family/c-common.c:6677
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a nonzero size object"
 msgstr "el argumento 1 de %qE debe ser un puntero a un objeto de tamaño diferente de cero"
 
-#: c-family/c-common.c:6706
+#: c-family/c-common.c:6698
 #, gcc-internal-format
 msgid "argument %d of %qE must be a pointer type"
 msgstr "el argumento %d de %qE debe ser un tipo puntero"
 
-#: c-family/c-common.c:6714
+#: c-family/c-common.c:6706
 #, gcc-internal-format
 msgid "argument %d of %qE must be a pointer to a constant size type"
 msgstr "el argumento %d de %qE debe ser un puntero a un tipo de tamaño constante"
 
-#: c-family/c-common.c:6720
+#: c-family/c-common.c:6712
 #, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a function"
 msgstr "el argumento %d de %qE no debe ser un puntero a función"
 
-#: c-family/c-common.c:6728
+#: c-family/c-common.c:6720
 #, gcc-internal-format
 msgid "size mismatch in argument %d of %qE"
 msgstr "no coincide el tamaño en el argumento %d de %qE"
 
-#: c-family/c-common.c:6740
+#: c-family/c-common.c:6732
 #, gcc-internal-format
 msgid "non-integer memory model argument %d of %qE"
 msgstr "argumento de modelo de memoria %d que no es entero de %qE"
 
-#: c-family/c-common.c:6753
+#: c-family/c-common.c:6745
 #, gcc-internal-format
 msgid "invalid memory model argument %d of %qE"
 msgstr "argumento de modelo de memoria %d no válido de %qE"
 
-#: c-family/c-common.c:7672
+#: c-family/c-common.c:7664
 #, gcc-internal-format
 msgid "index value is out of bound"
 msgstr "el valor del índice está fuera del límite"
 
-#: c-family/c-common.c:7714 c-family/c-common.c:7763 c-family/c-common.c:7779
+#: c-family/c-common.c:7706 c-family/c-common.c:7755 c-family/c-common.c:7771
 #, gcc-internal-format
 msgid "conversion of scalar %qT to vector %qT involves truncation"
 msgstr "la conversión del escalar %qT al vector %qT implica truncado"
@@ -24883,22 +24916,22 @@
 
 #. Reject arguments that are built-in functions with
 #. no library fallback.
-#: c-family/c-common.c:7867
+#: c-family/c-common.c:7859
 #, gcc-internal-format
 msgid "built-in function %qE must be directly called"
 msgstr "la función interna %qE ha de ser llamada directamente"
 
-#: c-family/c-common.c:7889 c/c-decl.c:6177
+#: c-family/c-common.c:7881 c/c-decl.c:6197
 #, gcc-internal-format
 msgid "size of array %qE is too large"
 msgstr "el tamaño de la matriz %qE es demasiado grande"
 
-#: c-family/c-common.c:7891 c/c-decl.c:6180
+#: c-family/c-common.c:7883 c/c-decl.c:6200
 #, gcc-internal-format
 msgid "size of unnamed array is too large"
 msgstr "el tamaño de la matriz sin nombre es demasiado grande"
 
-#: c-family/c-common.c:7921
+#: c-family/c-common.c:7913
 #, gcc-internal-format
 msgid "environment variable SOURCE_DATE_EPOCH must expand to a non-negative integer less than or equal to %wd"
 msgstr ""
@@ -25422,7 +25455,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr "%<#pragma omp atomic capture%> usa dos variables diferentes para la memoria"
 
-#: c-family/c-omp.c:557 cp/semantics.c:8186
+#: c-family/c-omp.c:557 cp/semantics.c:8189
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "tipo no válido para la variable de iteración %qE"
@@ -25437,22 +25470,22 @@
 msgid "%qE is not initialized"
 msgstr "%qE no está inicializado"
 
-#: c-family/c-omp.c:599 cp/semantics.c:8076
+#: c-family/c-omp.c:599 cp/semantics.c:8079
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "falta el predicado controlador"
 
-#: c-family/c-omp.c:704 cp/semantics.c:7732
+#: c-family/c-omp.c:704 cp/semantics.c:7735
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "predicado controlador no válido"
 
-#: c-family/c-omp.c:711 cp/semantics.c:8082
+#: c-family/c-omp.c:711 cp/semantics.c:8085
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "falta la expresión de incremento"
 
-#: c-family/c-omp.c:775 cp/semantics.c:7847
+#: c-family/c-omp.c:775 cp/semantics.c:7850
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "expresión de incremento no válida"
@@ -25507,112 +25540,127 @@
 msgid "%<-Wabi=1%> is not supported, using =2"
 msgstr "no se admite %<-Wabi=1%>; se usará =2"
 
-#: c-family/c-opts.c:612 fortran/cpp.c:350
+#: c-family/c-opts.c:610 fortran/cpp.c:350
 #, gcc-internal-format
 msgid "output filename specified twice"
 msgstr "se especificó dos veces el nombre del fichero de salida"
 
-#: c-family/c-opts.c:799
+#: c-family/c-opts.c:797
 #, gcc-internal-format
 msgid "-fexcess-precision=standard for C++"
 msgstr "-fexcess-precision=standard para C++"
 
-#: c-family/c-opts.c:834
+#: c-family/c-opts.c:832
 #, gcc-internal-format
 msgid "-fno-gnu89-inline is only supported in GNU99 or C99 mode"
 msgstr "-fno-gnu89-inline sólo se admite en modo GNU99 o C99"
 
-#: c-family/c-opts.c:880
+#: c-family/c-opts.c:878
 #, gcc-internal-format
 msgid "-Wformat-y2k ignored without -Wformat"
 msgstr "se descarta -Wformat-y2k sin -Wformat"
 
-#: c-family/c-opts.c:882
+#: c-family/c-opts.c:880
 #, gcc-internal-format
 msgid "-Wformat-extra-args ignored without -Wformat"
 msgstr "se descarta -Wformat-extra-args sin -Wformat"
 
-#: c-family/c-opts.c:884
+#: c-family/c-opts.c:882
 #, gcc-internal-format
 msgid "-Wformat-zero-length ignored without -Wformat"
 msgstr "se descarta -Wformat-zero-lenght sin -Wformat"
 
-#: c-family/c-opts.c:886
+#: c-family/c-opts.c:884
 #, gcc-internal-format
 msgid "-Wformat-nonliteral ignored without -Wformat"
 msgstr "se descarta -Wformat-nonliteral sin -Wformat"
 
-#: c-family/c-opts.c:888
+#: c-family/c-opts.c:886
 #, gcc-internal-format
 msgid "-Wformat-contains-nul ignored without -Wformat"
 msgstr "se descarta -Wformat-contains-nul sin -Wformat"
 
-#: c-family/c-opts.c:890
+#: c-family/c-opts.c:888
 #, gcc-internal-format
 msgid "-Wformat-security ignored without -Wformat"
 msgstr "se descarta -Wformat-security sin -Wformat"
 
-#: c-family/c-opts.c:928
+#: c-family/c-opts.c:918
 #, gcc-internal-format
 msgid "%<-fabi-compat-version=1%> is not supported, using =2"
 msgstr "no se admite %<-fabi-compat-version=1%>; se usará =2"
 
-#: c-family/c-opts.c:988
+#: c-family/c-opts.c:944
 #, gcc-internal-format
+msgid "-Wabi won't warn about anything"
+msgstr ""
+
+#: c-family/c-opts.c:946
+#, gcc-internal-format
+msgid "-Wabi warns about differences from the most up-to-date ABI, which is also used by default"
+msgstr ""
+
+#: c-family/c-opts.c:949
+#, gcc-internal-format
+msgid "use e.g. -Wabi=11 to warn about changes from GCC 7"
+msgstr ""
+
+#: c-family/c-opts.c:1003
+#, gcc-internal-format
 msgid "external TLS initialization functions not supported on this target"
 msgstr "no se admiten funciones de inicialización TLS externas en este objetivo"
 
-#: c-family/c-opts.c:1001
+#: c-family/c-opts.c:1016
 #, gcc-internal-format, gfc-internal-format
 msgid "too many filenames given.  Type %s --help for usage"
 msgstr "demasiados nombres de ficheros. Teclee %s --help para información de modo de empleo"
 
-#: c-family/c-opts.c:1016
+#: c-family/c-opts.c:1031
 #, gcc-internal-format
 msgid "opening output file %s: %m"
 msgstr "abriendo el fichero de salida %s: %m"
 
-#: c-family/c-opts.c:1036
+#: c-family/c-opts.c:1051
 #, gcc-internal-format, gfc-internal-format
 msgid "the \"%s\" debug format cannot be used with pre-compiled headers"
 msgstr ""
 
-#: c-family/c-opts.c:1190
+#: c-family/c-opts.c:1205
 #, gcc-internal-format
 msgid "opening dependency file %s: %m"
 msgstr "abriendo el fichero de dependencias %s: %m"
 
-#: c-family/c-opts.c:1201
+#: c-family/c-opts.c:1216
 #, gcc-internal-format
 msgid "closing dependency file %s: %m"
 msgstr "cerrando el fichero de dependencias %s: %m"
 
-#: c-family/c-opts.c:1204
+#: c-family/c-opts.c:1219
 #, gcc-internal-format
 msgid "when writing output to %s: %m"
 msgstr "al escribir la salida a %s: %m"
 
-#: c-family/c-opts.c:1284
+#: c-family/c-opts.c:1299
 #, gcc-internal-format
 msgid "to generate dependencies you must specify either -M or -MM"
 msgstr "para generar dependencias debe especificar -M ó -MM"
 
-#: c-family/c-opts.c:1307
+#: c-family/c-opts.c:1322
 #, gcc-internal-format
 msgid "-MG may only be used with -M or -MM"
 msgstr "-MG sólo se puede usar con -M ó -MM"
 
-#: c-family/c-opts.c:1340
+#: c-family/c-opts.c:1355
 #, gcc-internal-format
 msgid "-fdirectives-only is incompatible with -Wunused_macros"
 msgstr "-fdirectives-only es incompatible con -Wunused_macros"
 
-#: c-family/c-opts.c:1342
+#: c-family/c-opts.c:1357
 #, gcc-internal-format
 msgid "-fdirectives-only is incompatible with -traditional"
 msgstr "-fdirectives-only es incompatible con -traditional"
 
-#: c-family/c-opts.c:1534
+#: c-family/c-opts.c:1549
 #, gcc-internal-format
 msgid "too late for # directive to set debug directory"
 msgstr "demasiado tarde para que la directiva # establezca el directorio de depuración"
@@ -25997,128 +26045,128 @@
 msgid "wrong type argument to %s"
 msgstr "argumento de tipo erróneo para %s"
 
-#: c-family/c-warn.c:53 c-family/c-warn.c:66 cp/constexpr.c:1847
+#: c-family/c-warn.c:54 c-family/c-warn.c:67 cp/constexpr.c:1847
 #: cp/constexpr.c:4099
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "desbordamiento en la expresión constante"
 
-#: c-family/c-warn.c:93
+#: c-family/c-warn.c:94
 #, gcc-internal-format
 msgid "integer overflow in expression %qE of type %qT results in %qE"
 msgstr "desbordamiento entero en la expresión %qE de tipo %qT da %qE"
 
-#: c-family/c-warn.c:95
+#: c-family/c-warn.c:96
 #, gcc-internal-format
 msgid "integer overflow in expression of type %qT results in %qE"
 msgstr "desbordamiento entero en expresión de tipo %qT da como resultado %qE"
 
-#: c-family/c-warn.c:101
+#: c-family/c-warn.c:102
 #, gcc-internal-format
 msgid "floating point overflow in expression %qE of type %qT results in %qE"
 msgstr "desbordamiento de coma flotante en la expresión %qE de tipo %qT da como resultado %qE"
 
-#: c-family/c-warn.c:103
+#: c-family/c-warn.c:104
 #, gcc-internal-format
 msgid "floating point overflow in expression of type %qT results in %qE"
 msgstr "desbordamiento de coma flotante en expresión de tipo %qT da como resultado %qE"
 
-#: c-family/c-warn.c:109
+#: c-family/c-warn.c:110
 #, gcc-internal-format
 msgid "fixed-point overflow in expression %qE of type %qT results in %qE"
 msgstr "desbordamiento de coma fija en la expresión %qE de tipo %qT da como resultado %qE"
 
-#: c-family/c-warn.c:111
+#: c-family/c-warn.c:112
 #, gcc-internal-format
 msgid "fixed-point overflow in expression of type %qT results in %qE"
 msgstr "desbordamiento de coma fija en expresión de tipo %qT da como resultado %qE"
 
-#: c-family/c-warn.c:117
+#: c-family/c-warn.c:118
 #, gcc-internal-format
 msgid "vector overflow in expression %qE of type %qT results in %qE"
 msgstr "desbordamiento vectorial en la expresión %qE de tipo %qT da como resultado %qE"
 
-#: c-family/c-warn.c:119
+#: c-family/c-warn.c:120
 #, gcc-internal-format
 msgid "vector overflow in expression of type %qT results in %qE"
 msgstr "desbordamiento vectorial en expresión de tipo %qT da como resultado %qE"
 
-#: c-family/c-warn.c:126
+#: c-family/c-warn.c:127
 #, gcc-internal-format
 msgid "complex integer overflow in expression %qE of type %qT results in %qE"
 msgstr "desbordamiento de entero complejo en la expresión %qE de tipo %qT da como resultado %qE"
 
-#: c-family/c-warn.c:128
+#: c-family/c-warn.c:129
 #, gcc-internal-format
 msgid "complex integer overflow in expression of type %qT results in %qE"
 msgstr "desbordamiento de entero complejo en expresión de tipo %qT da como resultado %qE"
 
-#: c-family/c-warn.c:132
+#: c-family/c-warn.c:133
 #, gcc-internal-format
 msgid "complex floating point overflow in expression %qE of type %qT results in %qE"
 msgstr "desbordamiento de coma flotante compleja en la expresión %qE de tipo %qT da como resultado %qE"
 
-#: c-family/c-warn.c:134
+#: c-family/c-warn.c:135
 #, gcc-internal-format
 msgid "complex floating point overflow in expression of type %qT results in %qE"
 msgstr "desbordamiento de coma flotante compleja en expresión de tipo %qT da como resultado %qE"
 
-#: c-family/c-warn.c:216
+#: c-family/c-warn.c:217
 #, gcc-internal-format
 msgid "logical %<or%> applied to non-boolean constant"
 msgstr "se aplicó un %<or%> lógico a una constante que no es booleana"
 
-#: c-family/c-warn.c:219
+#: c-family/c-warn.c:220
 #, gcc-internal-format
 msgid "logical %<and%> applied to non-boolean constant"
 msgstr "se aplicó un %<and%> lógico a una constante que no es booleana"
 
-#: c-family/c-warn.c:289
+#: c-family/c-warn.c:290
 #, gcc-internal-format
 msgid "logical %<or%> of collectively exhaustive tests is always true"
 msgstr "un %<or%> lógico de pruebas colectivamente exhaustivas siempre es verdadero"
 
-#: c-family/c-warn.c:293
+#: c-family/c-warn.c:294
 #, gcc-internal-format
 msgid "logical %<and%> of mutually exclusive tests is always false"
 msgstr "un %<and%> de pruebas equivalentes mutuamente exclusivas siempre es falso"
 
-#: c-family/c-warn.c:303
+#: c-family/c-warn.c:304
 #, gcc-internal-format
 msgid "logical %<or%> of equal expressions"
 msgstr "%<or%> lógico de expresiones equivalentes"
 
-#: c-family/c-warn.c:306
+#: c-family/c-warn.c:307
 #, gcc-internal-format
 msgid "logical %<and%> of equal expressions"
 msgstr "un %<and%> de expresiones equivalentes"
 
-#: c-family/c-warn.c:384
+#: c-family/c-warn.c:385
 #, gcc-internal-format
 msgid "bitwise comparison always evaluates to false"
 msgstr "comparación de bits siempre falsa"
 
-#: c-family/c-warn.c:387
+#: c-family/c-warn.c:388
 #, gcc-internal-format
 msgid "bitwise comparison always evaluates to true"
 msgstr "comparación de bits siempre verdadera"
 
-#: c-family/c-warn.c:441
+#: c-family/c-warn.c:442
 #, gcc-internal-format
 msgid "self-comparison always evaluates to true"
 msgstr "autocomparación siempre verdadera"
 
-#: c-family/c-warn.c:444
+#: c-family/c-warn.c:445
 #, gcc-internal-format
 msgid "self-comparison always evaluates to false"
 msgstr "autocomparación siempre falsa"
 
-#: c-family/c-warn.c:494
+#: c-family/c-warn.c:495
 #, gcc-internal-format
 msgid "logical not is only applied to the left hand side of comparison"
 msgstr ""
 
-#: c-family/c-warn.c:502
+#: c-family/c-warn.c:503
 #, gcc-internal-format
 msgid "add parentheses around left hand side expression to silence this warning"
 msgstr ""
@@ -26125,7 +26173,7 @@
 
 # No existe una traducción para type-punning. Gracias a Jose María Pérez
 # por el comentario. cfuga
-#: c-family/c-warn.c:636
+#: c-family/c-warn.c:637
 #, gcc-internal-format
 msgid "type-punning to incomplete type might break strict-aliasing rules"
 msgstr "el uso de %<type punning%> sobre un tipo incompleto puede romper las reglas de alias estricto"
@@ -26132,7 +26180,7 @@
 
 # No existe una traducción para type-punning. Gracias a Jose María Pérez
 # por el comentario. cfuga
-#: c-family/c-warn.c:654
+#: c-family/c-warn.c:655
 #, gcc-internal-format
 msgid "dereferencing type-punned pointer will break strict-aliasing rules"
 msgstr "la dereferencia de punteros %<type-punned%> romperá las reglas de alias estricto"
@@ -26139,573 +26187,573 @@
 
 # No existe una traducción para type-punning. Gracias a Jose María Pérez
 # por el comentario. cfuga
-#: c-family/c-warn.c:662 c-family/c-warn.c:680
+#: c-family/c-warn.c:663 c-family/c-warn.c:681
 #, gcc-internal-format
 msgid "dereferencing type-punned pointer might break strict-aliasing rules"
 msgstr "la dereferencia de punteros %<type-punned%>  puede romper las reglas de alias estricto"
 
-#: c-family/c-warn.c:803
+#: c-family/c-warn.c:811
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to use the size of the destination?"
 msgstr "el argumento de %<sizeof%> en la llamada %qD es la misma expresión que el origen; ¿pretendía usar el tamaño del destino?"
 
-#: c-family/c-warn.c:834
+#: c-family/c-warn.c:842
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the destination; did you mean to remove the addressof?"
 msgstr "el argumento de %<sizeof%> en la llamada %qD es la misma expresión que el destino; ¿pretendía quitar el addressof?"
 
-#: c-family/c-warn.c:841
+#: c-family/c-warn.c:849
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the destination; did you mean to provide an explicit length?"
 msgstr "el argumento de %<sizeof%> en la llamada %qD es la misma expresión que el destino; ¿pretendía proporcionar una longitud explícita?"
 
-#: c-family/c-warn.c:846
+#: c-family/c-warn.c:854
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the destination; did you mean to dereference it?"
 msgstr "el argumento de %<sizeof%> en la llamada %qD es la misma expresión que el destino; ¿pretendía desreferenciarla?"
 
-#: c-family/c-warn.c:858
+#: c-family/c-warn.c:866
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the destination; expected %qT or an explicit length"
 msgstr "el argumento de %<sizeof%> en la llamada %qD es el mismo tipo de puntero %qT que el destino; se esperaba %qT o una longitud explícita"
 
-#: c-family/c-warn.c:874
+#: c-family/c-warn.c:882
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to remove the addressof?"
 msgstr "el argumento de %<sizeof%> en la llamada %qD es la misma expresión que el origen; ¿pretendía quitar la dirección de?"
 
-#: c-family/c-warn.c:881
+#: c-family/c-warn.c:889
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to provide an explicit length?"
 msgstr "el argumento de %<sizeof%> en la llamada %qD es la misma expresión que el origen; ¿pretendía indicar una longitud explícita?"
 
-#: c-family/c-warn.c:886
+#: c-family/c-warn.c:894
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to dereference it?"
 msgstr "el argumento de %<sizeof%> en la llamada %qD es la misma expresión que el origen; ¿pretendía desreferenciarla?"
 
-#: c-family/c-warn.c:898
+#: c-family/c-warn.c:906
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the source; expected %qT or an explicit length"
 msgstr "el argumento de %<sizeof%> en la llamada %qD es el mismo tipo de puntero %qT que el origen; se esperaba %qT o una longitud explícita"
 
-#: c-family/c-warn.c:914
+#: c-family/c-warn.c:922
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the first source; did you mean to remove the addressof?"
 msgstr "el argumento de %<sizeof%> en la llamada %qD es la misma expresión que el primer origen; ¿pretendía quitar la dirección de?"
 
-#: c-family/c-warn.c:921
+#: c-family/c-warn.c:929
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the first source; did you mean to provide an explicit length?"
 msgstr "el argumento de %<sizeof%> en la llamada %qD es la misma expresión que el primer origen; ¿pretendía indicar una longitud explícita?"
 
-#: c-family/c-warn.c:926
+#: c-family/c-warn.c:934
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the first source; did you mean to dereference it?"
 msgstr "el argumento de %<sizeof%> en la llamada %qD es la misma expresión que el primer origen; ¿pretendía desreferenciarla?"
 
-#: c-family/c-warn.c:938
+#: c-family/c-warn.c:946
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the first source; expected %qT or an explicit length"
 msgstr "el argumento de %<sizeof%> en la llamada %qD es el mismo tipo de puntero %qT que el primer origen; se esperaba %qT o una longitud explícita"
 
-#: c-family/c-warn.c:954
+#: c-family/c-warn.c:962
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the second source; did you mean to remove the addressof?"
 msgstr "el argumento de %<sizeof%> en la llamada %qD es la misma expresión que el segundo origen; ¿pretendía quitar la dirección de?"
 
-#: c-family/c-warn.c:961
+#: c-family/c-warn.c:969
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the second source; did you mean to provide an explicit length?"
 msgstr "el argumento de %<sizeof%> en la llamada %qD es la misma expresión que el segundo origen; ¿pretendía indicar una longitud explícita?"
 
-#: c-family/c-warn.c:966
+#: c-family/c-warn.c:974
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the second source; did you mean to dereference it?"
 msgstr "el argumento de %<sizeof%> en la llamada %qD es la misma expresión que el segundo origen; ¿pretendía desreferenciarla?"
 
-#: c-family/c-warn.c:978
+#: c-family/c-warn.c:986
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the second source; expected %qT or an explicit length"
 msgstr "el argumento de %<sizeof%> en la llamada %qD es el mismo tipo de puntero %qT que el segundo origen; se esperaba %qT o una longitud explícita"
 
-#: c-family/c-warn.c:1007 c-family/c-warn.c:1014
+#: c-family/c-warn.c:1015 c-family/c-warn.c:1022
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified parameter type %qT of %q+D"
 msgstr "tipo de parámetro cualificado %<_Atomic%> %qT de %q+D"
 
-#: c-family/c-warn.c:1024
+#: c-family/c-warn.c:1032
 #, gcc-internal-format
 msgid "first argument of %q+D should be %<int%>"
 msgstr "el primer argumento de %q+D debe ser %<int%>"
 
-#: c-family/c-warn.c:1033
+#: c-family/c-warn.c:1041
 #, gcc-internal-format
 msgid "second argument of %q+D should be %<char **%>"
 msgstr "el segundo argumento de %q+D debe ser %<char **%>"
 
-#: c-family/c-warn.c:1042
+#: c-family/c-warn.c:1050
 #, gcc-internal-format
 msgid "third argument of %q+D should probably be %<char **%>"
 msgstr "el tercer argumento de %q+D debería ser %<char **%>"
 
-#: c-family/c-warn.c:1053
+#: c-family/c-warn.c:1061
 #, gcc-internal-format
 msgid "%q+D takes only zero or two arguments"
 msgstr "%q+D sólo toma cero o dos argumentos"
 
-#: c-family/c-warn.c:1057
+#: c-family/c-warn.c:1065
 #, gcc-internal-format
 msgid "%q+D declared as variadic function"
 msgstr "%q+D declarado como función variádica"
 
-#: c-family/c-warn.c:1099
+#: c-family/c-warn.c:1107
 #, gcc-internal-format
 msgid "conversion to %qT from boolean expression"
 msgstr "la conversión de %qT desde la expresión booleana"
 
-#: c-family/c-warn.c:1117 c-family/c-warn.c:1192
+#: c-family/c-warn.c:1125 c-family/c-warn.c:1200
 #, gcc-internal-format
 msgid "conversion from %qT to %qT changes value from %qE to %qE"
 msgstr "la conversión de %qT a %qT cambia el valor de %qE a %qE"
 
-#: c-family/c-warn.c:1121 c-family/c-warn.c:1200
+#: c-family/c-warn.c:1129 c-family/c-warn.c:1208
 #, gcc-internal-format
 msgid "conversion from %qT to %qT changes the value of %qE"
 msgstr "la conversión de %qT a %qT cambia el valor de %qE"
 
-#: c-family/c-warn.c:1141
+#: c-family/c-warn.c:1149
 #, gcc-internal-format
 msgid "conversion from %qT to %qT discards imaginary component"
 msgstr "la conversión de %qT a %qT descarta la componente imaginaria"
 
-#: c-family/c-warn.c:1153
+#: c-family/c-warn.c:1161
 #, gcc-internal-format
 msgid "conversion from %qT to %qT may change value"
 msgstr "la conversión de %qT a %qT puede cambiar el valor"
 
-#: c-family/c-warn.c:1213 c-family/c-warn.c:1230 c-family/c-warn.c:1247
+#: c-family/c-warn.c:1221 c-family/c-warn.c:1238 c-family/c-warn.c:1255
 #, gcc-internal-format
 msgid "overflow in conversion from %qT to %qT changes value from %qE to %qE"
 msgstr "el desbordamiento en la conversión de %qT a %qT cambia el valor de %qE a %qE"
 
-#: c-family/c-warn.c:1218 c-family/c-warn.c:1235 c-family/c-warn.c:1252
+#: c-family/c-warn.c:1226 c-family/c-warn.c:1243 c-family/c-warn.c:1260
 #, gcc-internal-format
 msgid "overflow in conversion from %qT to %qT changes the value of %qE"
 msgstr "el desbordamiento en la conversión de %qT a %qT cambia el valor de %qE"
 
-#: c-family/c-warn.c:1282
+#: c-family/c-warn.c:1290
 #, gcc-internal-format
 msgid "case value %qs not in enumerated type"
 msgstr "el valor de case %qs no es un tipo enumerado"
 
-#: c-family/c-warn.c:1287
+#: c-family/c-warn.c:1295
 #, gcc-internal-format
 msgid "case value %qs not in enumerated type %qT"
 msgstr "el valor de case %qs no es un tipo enumerado %qT"
 
-#: c-family/c-warn.c:1348
+#: c-family/c-warn.c:1356
 #, gcc-internal-format
 msgid "switch missing default case"
 msgstr "falta el case por defecto para un switch"
 
-#: c-family/c-warn.c:1393
+#: c-family/c-warn.c:1401
 #, gcc-internal-format
 msgid "switch condition has boolean value"
 msgstr "la condición de switch tiene valor boolean"
 
-#: c-family/c-warn.c:1466
+#: c-family/c-warn.c:1474
 #, gcc-internal-format
 msgid "enumeration value %qE not handled in switch"
 msgstr "el valor de enumeración %qE no se maneja en un switch"
 
-#: c-family/c-warn.c:1494
+#: c-family/c-warn.c:1502
 #, gcc-internal-format
 msgid "the omitted middle operand in ?: will always be %<true%>, suggest explicit middle operand"
 msgstr "el operando medio omitido en ?: siempre será %<true%>, se sugiere un operando medio explícito"
 
-#: c-family/c-warn.c:1515
+#: c-family/c-warn.c:1523
 #, gcc-internal-format
 msgid "assignment of member %qD in read-only object"
 msgstr "asignación de miembro %qD en objeto de sólo-lectura"
 
-#: c-family/c-warn.c:1517
+#: c-family/c-warn.c:1525
 #, gcc-internal-format
 msgid "increment of member %qD in read-only object"
 msgstr "incremento de miembro %qD en objeto de sólo lectura"
 
-#: c-family/c-warn.c:1519
+#: c-family/c-warn.c:1527
 #, gcc-internal-format
 msgid "decrement of member %qD in read-only object"
 msgstr "decremento de miembro %qD en objeto de sólo lectura"
 
-#: c-family/c-warn.c:1521
+#: c-family/c-warn.c:1529
 #, gcc-internal-format
 msgid "member %qD in read-only object used as %<asm%> output"
 msgstr "se usó el miembro %qD en un objeto de sólo lectura como salida %<asm%>"
 
-#: c-family/c-warn.c:1525
+#: c-family/c-warn.c:1533
 #, gcc-internal-format
 msgid "assignment of read-only member %qD"
 msgstr "asignación del miembro de sólo lectura %qD"
 
-#: c-family/c-warn.c:1526
+#: c-family/c-warn.c:1534
 #, gcc-internal-format
 msgid "increment of read-only member %qD"
 msgstr "incremento del miembro de sólo lectura %qD"
 
-#: c-family/c-warn.c:1527
+#: c-family/c-warn.c:1535
 #, gcc-internal-format
 msgid "decrement of read-only member %qD"
 msgstr "decremento del miembro de sólo lectura %qD"
 
-#: c-family/c-warn.c:1528
+#: c-family/c-warn.c:1536
 #, gcc-internal-format
 msgid "read-only member %qD used as %<asm%> output"
 msgstr "se usó el miembro de sólo lectura %qD como salida %<asm%>"
 
-#: c-family/c-warn.c:1532
+#: c-family/c-warn.c:1540
 #, gcc-internal-format
 msgid "assignment of read-only variable %qD"
 msgstr "asignación de la variable de sólo lectura %qD"
 
-#: c-family/c-warn.c:1533
+#: c-family/c-warn.c:1541
 #, gcc-internal-format
 msgid "increment of read-only variable %qD"
 msgstr "incremento de la variable de sólo lectura %qD"
 
-#: c-family/c-warn.c:1534
+#: c-family/c-warn.c:1542
 #, gcc-internal-format
 msgid "decrement of read-only variable %qD"
 msgstr "decremento de la variable de sólo lectura %qD"
 
-#: c-family/c-warn.c:1535
+#: c-family/c-warn.c:1543
 #, gcc-internal-format
 msgid "read-only variable %qD used as %<asm%> output"
 msgstr "se usó la variable de sólo lectura %qD como salida %<asm%>"
 
-#: c-family/c-warn.c:1538
+#: c-family/c-warn.c:1546
 #, gcc-internal-format
 msgid "assignment of read-only parameter %qD"
 msgstr "asignación del parámetro de sólo-lectura %qD"
 
-#: c-family/c-warn.c:1539
+#: c-family/c-warn.c:1547
 #, gcc-internal-format
 msgid "increment of read-only parameter %qD"
 msgstr "incremento del parámetro de sólo lectura %qD"
 
-#: c-family/c-warn.c:1540
+#: c-family/c-warn.c:1548
 #, gcc-internal-format
 msgid "decrement of read-only parameter %qD"
 msgstr "decremento del parámetro de sólo lectura %qD"
 
-#: c-family/c-warn.c:1541
+#: c-family/c-warn.c:1549
 #, gcc-internal-format
 msgid "read-only parameter %qD use as %<asm%> output"
 msgstr "se usó el parámetro de sólo lectura %qD como salida %<asm%>"
 
-#: c-family/c-warn.c:1546
+#: c-family/c-warn.c:1554
 #, gcc-internal-format
 msgid "assignment of read-only named return value %qD"
 msgstr "asignación del valor de devolución nombrado de sólo lectura %qD"
 
-#: c-family/c-warn.c:1548
+#: c-family/c-warn.c:1556
 #, gcc-internal-format
 msgid "increment of read-only named return value %qD"
 msgstr "incremento del valor de devolución nombrado de sólo lectura %qD"
 
-#: c-family/c-warn.c:1550
+#: c-family/c-warn.c:1558
 #, gcc-internal-format
 msgid "decrement of read-only named return value %qD"
 msgstr "decremento del valor de devolución nombrado de sólo lectura %qD"
 
-#: c-family/c-warn.c:1552
+#: c-family/c-warn.c:1560
 #, gcc-internal-format
 msgid "read-only named return value %qD used as %<asm%>output"
 msgstr "se usó el valor de devolución nombrado de sólo lectura %qD como salida %<asm%>"
 
-#: c-family/c-warn.c:1557
+#: c-family/c-warn.c:1565
 #, gcc-internal-format
 msgid "assignment of function %qD"
 msgstr "asignación de la función %qD"
 
-#: c-family/c-warn.c:1558
+#: c-family/c-warn.c:1566
 #, gcc-internal-format
 msgid "increment of function %qD"
 msgstr "incremento de la función %qD"
 
-#: c-family/c-warn.c:1559
+#: c-family/c-warn.c:1567
 #, gcc-internal-format
 msgid "decrement of function %qD"
 msgstr "decremento de la función %qD"
 
-#: c-family/c-warn.c:1560
+#: c-family/c-warn.c:1568
 #, gcc-internal-format
 msgid "function %qD used as %<asm%> output"
 msgstr "se usó la función %qD como salida %<asm%>"
 
-#: c-family/c-warn.c:1563 c/c-typeck.c:4762
+#: c-family/c-warn.c:1571 c/c-typeck.c:4767
 #, gcc-internal-format
 msgid "assignment of read-only location %qE"
 msgstr "asignación de la ubicación de sólo lectura %qE"
 
-#: c-family/c-warn.c:1564 c/c-typeck.c:4765
+#: c-family/c-warn.c:1572 c/c-typeck.c:4770
 #, gcc-internal-format
 msgid "increment of read-only location %qE"
 msgstr "incremento de la ubicación de sólo lectura %qE"
 
-#: c-family/c-warn.c:1565 c/c-typeck.c:4768
+#: c-family/c-warn.c:1573 c/c-typeck.c:4773
 #, gcc-internal-format
 msgid "decrement of read-only location %qE"
 msgstr "decremento de la ubicación de sólo lectura %qE"
 
-#: c-family/c-warn.c:1566
+#: c-family/c-warn.c:1574
 #, gcc-internal-format
 msgid "read-only location %qE used as %<asm%> output"
 msgstr "se usó la ubicación de sólo lectura %qE como salida %<asm%>"
 
-#: c-family/c-warn.c:1580
+#: c-family/c-warn.c:1588
 #, gcc-internal-format
 msgid "lvalue required as left operand of assignment"
 msgstr "se requiere un l-valor como operando izquierdo de la asignación"
 
-#: c-family/c-warn.c:1583
+#: c-family/c-warn.c:1591
 #, gcc-internal-format
 msgid "lvalue required as increment operand"
 msgstr "se requiere un l-valor como un operando de incremento"
 
-#: c-family/c-warn.c:1586
+#: c-family/c-warn.c:1594
 #, gcc-internal-format
 msgid "lvalue required as decrement operand"
 msgstr "se requiere un l-valor como un operando de decremento"
 
-#: c-family/c-warn.c:1589
+#: c-family/c-warn.c:1597
 #, gcc-internal-format
 msgid "lvalue required as unary %<&%> operand"
 msgstr "se requiere un l-valor como un operador unario %<&%>"
 
-#: c-family/c-warn.c:1592
+#: c-family/c-warn.c:1600
 #, gcc-internal-format
 msgid "lvalue required in asm statement"
 msgstr "se requiere un l-valor en la declaración asm"
 
-#: c-family/c-warn.c:1609
+#: c-family/c-warn.c:1617
 #, gcc-internal-format
 msgid "invalid type argument (have %qT)"
 msgstr "argumento de tipo no válido (se tiene %qT)"
 
-#: c-family/c-warn.c:1613
+#: c-family/c-warn.c:1621
 #, gcc-internal-format
 msgid "invalid type argument of array indexing (have %qT)"
 msgstr "argumento de tipo no válido de índice de matriz (se tiene %qT)"
 
-#: c-family/c-warn.c:1618
+#: c-family/c-warn.c:1626
 #, gcc-internal-format
 msgid "invalid type argument of unary %<*%> (have %qT)"
 msgstr "argumento de tipo no válido del unario %<*%> (se tiene %qT)"
 
-#: c-family/c-warn.c:1623
+#: c-family/c-warn.c:1631
 #, gcc-internal-format
 msgid "invalid type argument of %<->%> (have %qT)"
 msgstr "argumento de tipo no válido de %<->%> (se tiene %qT)"
 
-#: c-family/c-warn.c:1628
+#: c-family/c-warn.c:1636
 #, gcc-internal-format
 msgid "invalid type argument of %<->*%> (have %qT)"
 msgstr "argumento de tipo no válido de %<->*%> (se tiene %qT)"
 
-#: c-family/c-warn.c:1633
+#: c-family/c-warn.c:1641
 #, gcc-internal-format
 msgid "invalid type argument of implicit conversion (have %qT)"
 msgstr "argumento de tipo no válido en la conversión implícita (se tiene %qT)"
 
-#: c-family/c-warn.c:1654
+#: c-family/c-warn.c:1662
 #, gcc-internal-format
 msgid "array subscript has type %<char%>"
 msgstr "el subíndice de la matriz es de tipo %<char%>"
 
-#: c-family/c-warn.c:1689 c-family/c-warn.c:1692
+#: c-family/c-warn.c:1697 c-family/c-warn.c:1700
 #, gcc-internal-format
 msgid "suggest parentheses around %<+%> inside %<<<%>"
 msgstr "se sugieren paréntesis alrededor de %<+%> dentro de %<<<%>"
 
-#: c-family/c-warn.c:1695 c-family/c-warn.c:1698
+#: c-family/c-warn.c:1703 c-family/c-warn.c:1706
 #, gcc-internal-format
 msgid "suggest parentheses around %<-%> inside %<<<%>"
 msgstr "se sugieren paréntesis alrededor de %<-%> dentro de %<<<%>"
 
-#: c-family/c-warn.c:1704 c-family/c-warn.c:1707
+#: c-family/c-warn.c:1712 c-family/c-warn.c:1715
 #, gcc-internal-format
 msgid "suggest parentheses around %<+%> inside %<>>%>"
 msgstr "se sugieren paréntesis alrededor de %<+%> dentro de %<>>%>"
 
-#: c-family/c-warn.c:1710 c-family/c-warn.c:1713
+#: c-family/c-warn.c:1718 c-family/c-warn.c:1721
 #, gcc-internal-format
 msgid "suggest parentheses around %<-%> inside %<>>%>"
 msgstr "se sugieren paréntesis alrededor de %<-%> dentro de %<>>%>"
 
-#: c-family/c-warn.c:1719 c-family/c-warn.c:1722
+#: c-family/c-warn.c:1727 c-family/c-warn.c:1730
 #, gcc-internal-format
 msgid "suggest parentheses around %<&&%> within %<||%>"
 msgstr "se sugieren paréntesis alrededor de %<&&%> junto con %<||%>"
 
-#: c-family/c-warn.c:1729 c-family/c-warn.c:1733
+#: c-family/c-warn.c:1737 c-family/c-warn.c:1741
 #, gcc-internal-format
 msgid "suggest parentheses around arithmetic in operand of %<|%>"
 msgstr "se sugieren paréntesis alrededor de la aritmética para un operando de %<|%>"
 
-#: c-family/c-warn.c:1737 c-family/c-warn.c:1740
+#: c-family/c-warn.c:1745 c-family/c-warn.c:1748
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<|%>"
 msgstr "se sugieren paréntesis alrededor de la comparación para un operando de %<|%>"
 
-#: c-family/c-warn.c:1745
+#: c-family/c-warn.c:1753
 #, gcc-internal-format
 msgid "suggest parentheses around operand of %<!%> or change %<|%> to %<||%> or %<!%> to %<~%>"
 msgstr "se sugieren paréntesis alrededor del operando de %<!%> o cambie %<|%> a %<||%> o %<!%> a %<~%>"
 
-#: c-family/c-warn.c:1753 c-family/c-warn.c:1757
+#: c-family/c-warn.c:1761 c-family/c-warn.c:1765
 #, gcc-internal-format
 msgid "suggest parentheses around arithmetic in operand of %<^%>"
 msgstr "se sugieren paréntesis alrededor de la aritmética para un operando de %<^%>"
 
-#: c-family/c-warn.c:1761 c-family/c-warn.c:1764
+#: c-family/c-warn.c:1769 c-family/c-warn.c:1772
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<^%>"
 msgstr "se sugieren paréntesis alrededor de la comparación para un operando de %<^%>"
 
-#: c-family/c-warn.c:1770 c-family/c-warn.c:1773
+#: c-family/c-warn.c:1778 c-family/c-warn.c:1781
 #, gcc-internal-format
 msgid "suggest parentheses around %<+%> in operand of %<&%>"
 msgstr "se sugieren paréntesis alrededor de %<+%> para un operando de %<&%>"
 
-#: c-family/c-warn.c:1776 c-family/c-warn.c:1779
+#: c-family/c-warn.c:1784 c-family/c-warn.c:1787
 #, gcc-internal-format
 msgid "suggest parentheses around %<-%> in operand of %<&%>"
 msgstr "se sugieren paréntesis alrededor de %<-%> para un operando de %<&%>"
 
-#: c-family/c-warn.c:1783 c-family/c-warn.c:1786
+#: c-family/c-warn.c:1791 c-family/c-warn.c:1794
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<&%>"
 msgstr "se sugieren paréntesis alrededor de la comparación para un operando de %<&%>"
 
-#: c-family/c-warn.c:1791
+#: c-family/c-warn.c:1799
 #, gcc-internal-format
 msgid "suggest parentheses around operand of %<!%> or change %<&%> to %<&&%> or %<!%> to %<~%>"
 msgstr "se sugieren paréntesis alrededor de un operando de %<!%> o cambie %<&%> a %<&&%> o %<!%> a %<~%>"
 
-#: c-family/c-warn.c:1798 c-family/c-warn.c:1801
+#: c-family/c-warn.c:1806 c-family/c-warn.c:1809
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<==%>"
 msgstr "se sugieren paréntesis alrededor de la comparación en un operando de %<==%>"
 
-#: c-family/c-warn.c:1806 c-family/c-warn.c:1809
+#: c-family/c-warn.c:1814 c-family/c-warn.c:1817
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<!=%>"
 msgstr "se sugieren paréntesis alrededor de la comparación en un operando de %<!=%>"
 
-#: c-family/c-warn.c:1819 c-family/c-warn.c:1825
+#: c-family/c-warn.c:1827 c-family/c-warn.c:1833
 #, gcc-internal-format
 msgid "comparisons like %<X<=Y<=Z%> do not have their mathematical meaning"
 msgstr "las comparaciones como %<X<=Y<=Z%> no tienen su significado matemático"
 
-#: c-family/c-warn.c:1841
+#: c-family/c-warn.c:1849
 #, gcc-internal-format
 msgid "label %q+D defined but not used"
 msgstr "se define la etiqueta %q+D pero no se usa"
 
-#: c-family/c-warn.c:1843
+#: c-family/c-warn.c:1851
 #, gcc-internal-format
 msgid "label %q+D declared but not defined"
 msgstr "se declara la etiqueta %q+D pero no está definida"
 
-#: c-family/c-warn.c:1866
+#: c-family/c-warn.c:1874
 #, gcc-internal-format
 msgid "division by zero"
 msgstr "división por cero"
 
-#: c-family/c-warn.c:1886
+#: c-family/c-warn.c:1894
 #, gcc-internal-format
 msgid "%<memset%> used with constant zero length parameter; this could be due to transposed parameters"
 msgstr ""
 
-#: c-family/c-warn.c:1909
+#: c-family/c-warn.c:1918
 #, gcc-internal-format
 msgid "%<memset%> used with length equal to number of elements without multiplication by element size"
 msgstr ""
 
-#: c-family/c-warn.c:1948 c/c-typeck.c:11499 c/c-typeck.c:11667
+#: c-family/c-warn.c:1957 c/c-typeck.c:11504 c/c-typeck.c:11672
 #: cp/typeck.c:5048
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr "comparación entre los tipos %qT y %qT"
 
-#: c-family/c-warn.c:1998
+#: c-family/c-warn.c:2007
 #, gcc-internal-format
 msgid "comparison of integer expressions of different signedness: %qT and %qT"
 msgstr ""
 
-#: c-family/c-warn.c:2051
+#: c-family/c-warn.c:2060
 #, gcc-internal-format
 msgid "promoted ~unsigned is always non-zero"
 msgstr "el ~unsigned promovido es siempre diferente de cero"
 
-#: c-family/c-warn.c:2054
+#: c-family/c-warn.c:2063
 #, gcc-internal-format
 msgid "comparison of promoted ~unsigned with constant"
 msgstr "comparación de un ~unsigned promovido con una constante"
 
-#: c-family/c-warn.c:2064
+#: c-family/c-warn.c:2073
 #, gcc-internal-format
 msgid "comparison of promoted ~unsigned with unsigned"
 msgstr "comparación de un ~unsigned promovido con unsigned"
 
-#: c-family/c-warn.c:2118
+#: c-family/c-warn.c:2127
 #, gcc-internal-format
 msgid "unused parameter %qD"
 msgstr "parámetro %qD sin uso"
 
-#: c-family/c-warn.c:2180
+#: c-family/c-warn.c:2189
 #, gcc-internal-format
 msgid "typedef %qD locally defined but not used"
 msgstr "se define tipo %qD localmente pero no se usa"
 
-#: c-family/c-warn.c:2215
+#: c-family/c-warn.c:2224
 #, gcc-internal-format
 msgid "duplicated %<if%> condition"
 msgstr "condición %<if%> duplicada"
 
-#: c-family/c-warn.c:2244
+#: c-family/c-warn.c:2253
 #, gcc-internal-format
 msgid "optimization attribute on %qD follows definition but the attribute doesn%'t match"
 msgstr "el atributo de optimización en %qD después de la definición pero el atributo no concuerda"
 
-#: c-family/c-warn.c:2254
+#: c-family/c-warn.c:2261
 #, gcc-internal-format
 msgid "inline declaration of %qD follows declaration with attribute %qs"
 msgstr "declaración inline de %qD después de una declaración con atributo %qs"
 
-#: c-family/c-warn.c:2259
+#: c-family/c-warn.c:2266
 #, gcc-internal-format
 msgid "declaration of %q+D with attribute %qs follows inline declaration"
 msgstr "declaración de %q+D con atributo %qs después de declaración inline"
 
-#: c-family/c-warn.c:2306
+#: c-family/c-warn.c:2313
 #, gcc-internal-format
 msgid "result of %qE requires %u bits to represent, but %qT only has %u bits"
 msgstr "el resultado de %qE requiere %u bits para representarlo, pero %qT solo tiene %u bits"
 
-#: c-family/c-warn.c:2344 c-family/c-warn.c:2368
+#: c-family/c-warn.c:2351 c-family/c-warn.c:2375
 #, gcc-internal-format
 msgid "comparison of constant %qE with boolean expression is always false"
 msgstr "la comparación de una constante %qE con una expresión boolean siempre es falsa"
 
-#: c-family/c-warn.c:2347 c-family/c-warn.c:2365
+#: c-family/c-warn.c:2354 c-family/c-warn.c:2372
 #, gcc-internal-format
 msgid "comparison of constant %qE with boolean expression is always true"
 msgstr "la comparación de una constante %qE con una expresión boolean siempre es verdadera"
 
-#: c-family/c-warn.c:2415
+#: c-family/c-warn.c:2422
 #, fuzzy
 #| msgid "passing argument %d of %qE discards %qv qualifier from pointer target type"
 msgid "passing argument %i to restrict-qualified parameter aliases with argument %Z"
@@ -26713,17 +26761,17 @@
 msgstr[0] "el paso del argumento %d de %qE descarta el calificador %qv del tipo del destino del puntero"
 msgstr[1] "el paso del argumento %d de %qE descarta el calificador %qv del tipo del destino del puntero"
 
-#: c-family/c-warn.c:2480 c/c-typeck.c:5288 cp/call.c:5365
+#: c-family/c-warn.c:2487 c/c-typeck.c:5293 cp/call.c:5365
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr "esta condición tiene bifurcaciones idénticas"
 
-#: c-family/c-warn.c:2586
+#: c-family/c-warn.c:2593
 #, gcc-internal-format
 msgid "macro expands to multiple statements"
 msgstr "la macro se expande en múltiples sentencias"
 
-#: c-family/c-warn.c:2587
+#: c-family/c-warn.c:2594
 #, gcc-internal-format
 msgid "some parts of macro expansion are not guarded by this %qs clause"
 msgstr "algunas partes de la expansión de macro no están flanqueadas por esta cláusula %qs"
@@ -26738,7 +26786,7 @@
 msgid "too many input files"
 msgstr "demasiados ficheros de entrada"
 
-#: common/config/aarch64/aarch64-common.c:319 config/aarch64/aarch64.c:10686
+#: common/config/aarch64/aarch64-common.c:319 config/aarch64/aarch64.c:10702
 #, gcc-internal-format
 msgid "unknown value %qs for -mcpu"
 msgstr "valor %qs desconocido para -mcpu"
@@ -26769,13 +26817,13 @@
 msgstr "se pasa opción no reconocida a %%:target_mode_check"
 
 #: common/config/arm/arm-common.c:322 common/config/arm/arm-common.c:376
-#: common/config/arm/arm-common.c:423 config/aarch64/aarch64.c:10639
+#: common/config/arm/arm-common.c:423 config/aarch64/aarch64.c:10655
 #, gcc-internal-format
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr "los argumentos válidos son: %s; ¿quiso decir %qs?"
 
 #: common/config/arm/arm-common.c:325 common/config/arm/arm-common.c:379
-#: common/config/arm/arm-common.c:426 config/aarch64/aarch64.c:10642
+#: common/config/arm/arm-common.c:426 config/aarch64/aarch64.c:10658
 #, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s"
 msgstr "los argumentos válidos son: %s"
@@ -27248,12 +27296,12 @@
 msgid "profiler support for VxWorks"
 msgstr "soporte de análisis de perfil para VxWorks"
 
-#: config/aarch64/aarch64-builtins.c:1109 config/arm/arm-builtins.c:2262
+#: config/aarch64/aarch64-builtins.c:1109 config/arm/arm-builtins.c:2272
 #, gcc-internal-format
 msgid "%Kargument %d must be a constant immediate"
 msgstr "el %Kargumento %d debe ser un inmediato constante"
 
-#: config/aarch64/aarch64-builtins.c:1180 config/arm/arm-builtins.c:2492
+#: config/aarch64/aarch64-builtins.c:1180 config/arm/arm-builtins.c:2502
 #, gcc-internal-format
 msgid "%Klane index must be a constant immediate"
 msgstr "el índice %Klane debe ser un inmediato constante"
@@ -27263,175 +27311,175 @@
 msgid "%Ktotal size and element size must be a non-zero constant immediate"
 msgstr "el tamaño %Ktotal y el tamaño de elemento han de ser un inmediato constante distinto de cero"
 
-#: config/aarch64/aarch64.c:1053
+#: config/aarch64/aarch64.c:1069
 #, gcc-internal-format
 msgid "%qs is incompatible with %s %s"
 msgstr "%qs es incompatible con %s %s"
 
-#: config/aarch64/aarch64.c:1055
+#: config/aarch64/aarch64.c:1071
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with %s %s"
 msgstr "el modificador de característica %qs es incompatible con %s %s"
 
-#: config/aarch64/aarch64.c:3772
+#: config/aarch64/aarch64.c:3788
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10287
+#: config/aarch64/aarch64.c:10303
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown flag passed in -moverride=%s (%s)"
 msgstr "indicador pasado en -moverride=%s (%s) desconocido"
 
-#: config/aarch64/aarch64.c:10331
+#: config/aarch64/aarch64.c:10347
 #, gcc-internal-format, gfc-internal-format
 msgid "%s string ill-formed\n"
 msgstr "cadena %s mal formada\n"
 
-#: config/aarch64/aarch64.c:10388
+#: config/aarch64/aarch64.c:10404
 #, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr "falta la cadena de ajuste en la opción (%s)"
 
-#: config/aarch64/aarch64.c:10406
+#: config/aarch64/aarch64.c:10422
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown tuning option (%s)"
 msgstr "opción de cadena de ajuste desconocida (%s)"
 
-#: config/aarch64/aarch64.c:10683
+#: config/aarch64/aarch64.c:10699
 #, gcc-internal-format
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr "falta el nombre de la cpu en %<-mcpu=%s%>"
 
-#: config/aarch64/aarch64.c:10690
+#: config/aarch64/aarch64.c:10706
 #, gcc-internal-format
 msgid "invalid feature modifier in %<-mcpu=%s%>"
 msgstr "modificador de característica no válido en %<-mcpu=%s%>"
 
-#: config/aarch64/aarch64.c:10717
+#: config/aarch64/aarch64.c:10733
 #, gcc-internal-format
 msgid "missing arch name in %<-march=%s%>"
 msgstr "falta el nombre de la arquitectura en %<-march=%s%>"
 
-#: config/aarch64/aarch64.c:10720
+#: config/aarch64/aarch64.c:10736
 #, gcc-internal-format
 msgid "unknown value %qs for -march"
 msgstr "valor %qs desconocido para -march"
 
-#: config/aarch64/aarch64.c:10724
+#: config/aarch64/aarch64.c:10740
 #, gcc-internal-format
 msgid "invalid feature modifier in %<-march=%s%>"
 msgstr "modificador de característica no válido en %<-march=%s%>"
 
-#: config/aarch64/aarch64.c:10750
+#: config/aarch64/aarch64.c:10766
 #, gcc-internal-format
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr "falta el nombre de la cpu en %<-mtune=%s%>"
 
-#: config/aarch64/aarch64.c:10753
+#: config/aarch64/aarch64.c:10769
 #, gcc-internal-format
 msgid "unknown value %qs for -mtune"
 msgstr "valor %qs desconocido para -mtune"
 
-#: config/aarch64/aarch64.c:10871 config/arm/arm.c:3173
+#: config/aarch64/aarch64.c:10887 config/arm/arm.c:3173
 #, gcc-internal-format, gfc-internal-format
 msgid "switch -mcpu=%s conflicts with -march=%s switch"
 msgstr "la opción -mcpu=%s genera un conflicto con la opción -march=%s"
 
-#: config/aarch64/aarch64.c:10906
+#: config/aarch64/aarch64.c:10922
 #, gcc-internal-format
 msgid "assembler does not support -mabi=ilp32"
 msgstr "el ensamblador no tiene soporte para -mabi=ilp32"
 
-#: config/aarch64/aarch64.c:10913
+#: config/aarch64/aarch64.c:10929
 #, gcc-internal-format
 msgid "return address signing is only supported for -mabi=lp64"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10975
+#: config/aarch64/aarch64.c:10991
 #, gcc-internal-format
 msgid "code model %qs with -f%s"
 msgstr "modelo de código %qs con -f%s"
 
-#: config/aarch64/aarch64.c:11138
+#: config/aarch64/aarch64.c:11154
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr "falta el nombre en atributo %<target(\"arch=\")%>"
 
-#: config/aarch64/aarch64.c:11141
+#: config/aarch64/aarch64.c:11157
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"arch=\")%> pragma or attribute"
 msgstr "nombre no válido (\"%s\") en el pragma o atributo %<target(\"arch=\")%>"
 
-#: config/aarch64/aarch64.c:11145 config/aarch64/aarch64.c:11184
-#: config/aarch64/aarch64.c:11257
+#: config/aarch64/aarch64.c:11161 config/aarch64/aarch64.c:11200
+#: config/aarch64/aarch64.c:11273
 #, gcc-internal-format
 msgid "invalid value (\"%s\") in %<target()%> pragma or attribute"
 msgstr "valor no válido (\"%s\") en el pragma o atributo %<target()%>"
 
-#: config/aarch64/aarch64.c:11177
+#: config/aarch64/aarch64.c:11193
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr "falta el nombre en el pragma o atributo %<target(\"cpu=\")%>"
 
-#: config/aarch64/aarch64.c:11180
+#: config/aarch64/aarch64.c:11196
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"cpu=\")%> pragma or attribute"
 msgstr "nombre no válido (\"%s\") en el pragma o atributo %<target(\"cpu=\")%>"
 
-#: config/aarch64/aarch64.c:11213
+#: config/aarch64/aarch64.c:11229
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"tune=\")%> pragma or attribute"
 msgstr "nombre no válido (\"%s\") en el pragma o atributo %<target(\"tune=\")%>"
 
-#: config/aarch64/aarch64.c:11253
+#: config/aarch64/aarch64.c:11269
 #, gcc-internal-format
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr "falta el valor en el pragma o atributo %<target()%>"
 
-#: config/aarch64/aarch64.c:11306 config/aarch64/aarch64.c:11483
+#: config/aarch64/aarch64.c:11322 config/aarch64/aarch64.c:11499
 #, gcc-internal-format
 msgid "malformed %<target()%> pragma or attribute"
 msgstr "pragma o atributo %<target()%> mal formado"
 
-#: config/aarch64/aarch64.c:11354
+#: config/aarch64/aarch64.c:11370
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr "el pragma o atributo %<target(\"%s\")%> no acepta un argumento"
 
-#: config/aarch64/aarch64.c:11362
+#: config/aarch64/aarch64.c:11378
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr "el pragma o atributo %<target(\"%s\")%> no acepta forma negada"
 
-#: config/aarch64/aarch64.c:11416
+#: config/aarch64/aarch64.c:11432
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr "el pragma o atributo %<target(\"%s=%s\")%> no es válido"
 
-#: config/aarch64/aarch64.c:11473 config/arm/arm.c:30742
-#: config/i386/i386.c:5440 config/powerpcspe/powerpcspe.c:39760
-#: config/rs6000/rs6000.c:36904 config/s390/s390.c:15746
+#: config/aarch64/aarch64.c:11489 config/arm/arm.c:30742
+#: config/i386/i386.c:5443 config/powerpcspe/powerpcspe.c:39760
+#: config/rs6000/rs6000.c:36960 config/s390/s390.c:15746
 #, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "el argumento del atributo %<target%> no es una cadena"
 
-#: config/aarch64/aarch64.c:11500
+#: config/aarch64/aarch64.c:11516
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr "el pragma o atributo %<target(\"%s\")%> no es válido"
 
-#: config/aarch64/aarch64.c:11509
+#: config/aarch64/aarch64.c:11525
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr "pragma o atributo %<target(\"%s\")%> mal formado"
 
-#: config/aarch64/aarch64.c:13571
+#: config/aarch64/aarch64.c:13587
 #, gcc-internal-format
 msgid "%Klane %wd out of range %wd - %wd"
 msgstr "%Klane %wd fuera de rango %wd - %wd"
 
-#: config/aarch64/aarch64.c:13573
+#: config/aarch64/aarch64.c:13589
 #, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr "vía %wd fuera de rango %wd - %wd"
@@ -27491,8 +27539,8 @@
 msgid "bad value %qs for -mmemory-latency"
 msgstr "valor %qs erróneo para -mmemory-latency"
 
-#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6526
-#: config/arc/arc.c:6800 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
+#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6517
+#: config/arc/arc.c:6791 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
 #: config/tilepro/tilepro.c:3108
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -27601,11 +27649,11 @@
 #: config/arm/arm.c:7029 config/avr/avr.c:9718 config/avr/avr.c:9734
 #: config/bfin/bfin.c:4705 config/bfin/bfin.c:4766 config/bfin/bfin.c:4795
 #: config/epiphany/epiphany.c:491 config/h8300/h8300.c:5459
-#: config/i386/i386.c:6452 config/i386/i386.c:12479 config/i386/i386.c:41424
-#: config/i386/i386.c:41474 config/i386/i386.c:41544 config/m68k/m68k.c:780
+#: config/i386/i386.c:6455 config/i386/i386.c:12482 config/i386/i386.c:41418
+#: config/i386/i386.c:41468 config/i386/i386.c:41538 config/m68k/m68k.c:780
 #: config/mcore/mcore.c:3070 config/nvptx/nvptx.c:4611
 #: config/powerpcspe/powerpcspe.c:35785 config/riscv/riscv.c:2698
-#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:32982
+#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:33038
 #: config/rx/rx.c:2719 config/rx/rx.c:2745 config/s390/s390.c:1056
 #: config/s390/s390.c:1143 config/sh/sh.c:8428 config/sh/sh.c:8446
 #: config/sh/sh.c:8470 config/sh/sh.c:8541 config/sh/sh.c:8564
@@ -27615,134 +27663,134 @@
 msgid "%qE attribute only applies to functions"
 msgstr "el atributo %qE se aplica solamente a funciones"
 
-#: config/arc/arc.c:6425
+#: config/arc/arc.c:6416
 #, gcc-internal-format
 msgid "__builtin_arc_aligned with non-constant alignment"
 msgstr "__builtin_arc_aligned con alineamiento no constante"
 
-#: config/arc/arc.c:6433
+#: config/arc/arc.c:6424
 #, gcc-internal-format
 msgid "invalid alignment value for __builtin_arc_aligned"
 msgstr "valor de argumento no válido para __builtin_arc_aligned"
 
-#: config/arc/arc.c:6596
+#: config/arc/arc.c:6587
 #, gcc-internal-format
 msgid "operand 1 should be an unsigned 3-bit immediate"
 msgstr "el operando 1 debería ser un inmediato de 3 bits sin signo"
 
-#: config/arc/arc.c:6637 config/arc/arc.c:6734
+#: config/arc/arc.c:6628 config/arc/arc.c:6725
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (I0-I7)"
 msgstr "el operando 2 debería ser un valor de 3 bits sin signo (10-17)"
 
-#: config/arc/arc.c:6670 config/arc/arc.c:6702
+#: config/arc/arc.c:6661 config/arc/arc.c:6693
 #, gcc-internal-format
 msgid "operand 1 should be an unsigned 3-bit value (I0-I7)"
 msgstr "el operando 1 debería ser un valor de 3 bits sin signo (10-17)"
 
-#: config/arc/arc.c:6674 config/arc/arc.c:6706
+#: config/arc/arc.c:6665 config/arc/arc.c:6697
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 8-bit value"
 msgstr "el operando 2 debería ser un valor de 8 bits sin signo"
 
-#: config/arc/arc.c:6738
+#: config/arc/arc.c:6729
 #, gcc-internal-format
 msgid "operand 3 should be an unsigned 8-bit value"
 msgstr "el operando 3 debería ser un valor de 8 bits sin signo"
 
-#: config/arc/arc.c:6771
+#: config/arc/arc.c:6762
 #, gcc-internal-format
 msgid "operand 4 should be an unsigned 8-bit value (0-255)"
 msgstr "el operando 4 debería ser un valor de 8 bits sin signo (0-255)"
 
-#: config/arc/arc.c:6775
+#: config/arc/arc.c:6766
 #, gcc-internal-format
 msgid "operand 3 should be an unsigned 3-bit value (I0-I7)"
 msgstr "el operando 3 debería ser un valor de 3 bits sin signo (10-17)"
 
-#: config/arc/arc.c:6782
+#: config/arc/arc.c:6773
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (subreg 0-7)"
 msgstr "el operando 2 debería ser un valor de 3 bits sin signo (0-7)"
 
-#: config/arc/arc.c:6785
+#: config/arc/arc.c:6776
 #, gcc-internal-format
 msgid "operand 2 should be an even 3-bit value (subreg 0,2,4,6)"
 msgstr "el operando 2 debería ser un valor de 3 bits par (subreg 0,2,4,6)"
 
-#: config/arc/arc.c:6832
+#: config/arc/arc.c:6823
 #, gcc-internal-format, gfc-internal-format
 msgid "builtin requires an immediate for operand %d"
 msgstr "el interno requiere un inmediato para el operando %d"
 
-#: config/arc/arc.c:6837
+#: config/arc/arc.c:6828
 #, gcc-internal-format, gfc-internal-format
 msgid "operand %d should be a 6 bit unsigned immediate"
 msgstr "el operando %d debería ser un inmediato sin signo de 6 bits"
 
-#: config/arc/arc.c:6841
+#: config/arc/arc.c:6832
 #, gcc-internal-format, gfc-internal-format
 msgid "operand %d should be a 8 bit unsigned immediate"
 msgstr "el operando %d debería ser un inmediato sin signo de 8 bits"
 
-#: config/arc/arc.c:6845
+#: config/arc/arc.c:6836
 #, gcc-internal-format, gfc-internal-format
 msgid "operand %d should be a 3 bit unsigned immediate"
 msgstr "el operando %d debería ser un inmediato sin signo de 3 bits"
 
-#: config/arc/arc.c:6848
+#: config/arc/arc.c:6839
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown builtin immediate operand type for operand %d"
 msgstr ""
 
-#: config/arc/arc.c:6899
+#: config/arc/arc.c:6890
 #, gcc-internal-format
 msgid "register number must be a compile-time constant. Try giving higher optimization levels"
 msgstr "el número de registro debe ser una constante en tiempo de compilación. Pruebe a poner niveles de optimización más altos"
 
-#: config/arc/arc.c:7685
+#: config/arc/arc.c:7747
 #, gcc-internal-format
 msgid "Insn addresses not set after shorten_branches"
 msgstr "Direcciones de insn no establecidas después de shorten_branches"
 
-#: config/arc/arc.c:7894
+#: config/arc/arc.c:7956
 #, gcc-internal-format
 msgid "insn addresses not freed"
 msgstr "direcciones de insn no liberadas"
 
-#: config/arc/arc.c:10682
+#: config/arc/arc.c:10670
 #, gcc-internal-format
 msgid "%qE attribute only valid for ARCv2 architecture"
 msgstr "el atributo %qE solamente es válido para la arquitectura ARCv2"
 
-#: config/arc/arc.c:10690 config/arc/arc.c:10729
+#: config/arc/arc.c:10678 config/arc/arc.c:10717
 #, gcc-internal-format
 msgid "argument of %qE attribute is missing"
 msgstr "falta el argumento del atributo %qE"
 
-#: config/arc/arc.c:10701 config/arc/arc.c:10740 config/arc/arc.c:10842
+#: config/arc/arc.c:10689 config/arc/arc.c:10728 config/arc/arc.c:10830
 #: config/avr/avr.c:9790
 #, gcc-internal-format
 msgid "%qE attribute allows only an integer constant argument"
 msgstr "el atributo %qE sólo permite una constante entera como argumento"
 
-#: config/arc/arc.c:10721
+#: config/arc/arc.c:10709
 #, gcc-internal-format
 msgid "%qE attribute only valid for ARC EM architecture"
 msgstr "el atributo %qE solo es válido para la arquitectura ARC EM"
 
-#: config/arc/arc.c:10776
+#: config/arc/arc.c:10764
 #, gcc-internal-format
 msgid "%qE attribute only applies to types"
 msgstr "el atributo %qE se aplica solamente a tipos"
 
-#: config/arc/arc.c:10782
+#: config/arc/arc.c:10770
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qE attribute is missing"
 msgid "argument of %qE attribute ignored"
 msgstr "falta el argumento del atributo %qE"
 
-#: config/arc/arc.c:10832 config/avr/avr.c:9777 config/bfin/bfin.c:4827
+#: config/arc/arc.c:10820 config/avr/avr.c:9777 config/bfin/bfin.c:4827
 #: config/i386/winnt.c:63 config/msp430/msp430.c:2018
 #: config/nvptx/nvptx.c:4634
 #, gcc-internal-format
@@ -27749,174 +27797,174 @@
 msgid "%qE attribute only applies to variables"
 msgstr "el atributo %qE solamente se aplica a variables"
 
-#: config/arm/arm-builtins.c:2370
+#: config/arm/arm-builtins.c:2380
 #, gcc-internal-format
 msgid "this builtin is not supported for this target"
 msgstr "no se admite este interno para este objetivo"
 
-#: config/arm/arm-builtins.c:2475
+#: config/arm/arm-builtins.c:2485
 #, gcc-internal-format
 msgid "You must enable NEON instructions (e.g. -mfloat-abi=softfp -mfpu=neon) to use these intrinsics."
 msgstr "Debe activar las instrucciones NEON (e.g. -mfloat-abi=softfp -mfpu=neon) para usar estos intrínsecos."
 
-#: config/arm/arm-builtins.c:2513
+#: config/arm/arm-builtins.c:2523
 #, gcc-internal-format
 msgid "You must enable VFP instructions to use these intrinsics."
 msgstr "Debe activar las instrucciones VFP para usar estos intrínsecos."
 
-#: config/arm/arm-builtins.c:2573
+#: config/arm/arm-builtins.c:2583
 #, gcc-internal-format
 msgid "You must enable crypto instructions (e.g. include -mfloat-abi=softfp -mfpu=crypto-neon...) to use these intrinsics."
 msgstr "Debe activar las instrucciones crypto (e.g. include -mfloat-abi=softfp -mfpu=crypto-neon...) para usar estos intrínsecos."
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:2633 config/arm/arm-builtins.c:2737
+#: config/arm/arm-builtins.c:2643 config/arm/arm-builtins.c:2747
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr "el selector debe ser un inmediato"
 
-#: config/arm/arm-builtins.c:2641 config/arm/arm-builtins.c:2686
-#: config/arm/arm-builtins.c:2744 config/arm/arm-builtins.c:2753
+#: config/arm/arm-builtins.c:2651 config/arm/arm-builtins.c:2696
+#: config/arm/arm-builtins.c:2754 config/arm/arm-builtins.c:2763
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr "el rango del selector debe estar entre 0 y 7"
 
-#: config/arm/arm-builtins.c:2646 config/arm/arm-builtins.c:2755
+#: config/arm/arm-builtins.c:2656 config/arm/arm-builtins.c:2765
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr "el rango del selector debe estar entre 0 y 3"
 
-#: config/arm/arm-builtins.c:2651 config/arm/arm-builtins.c:2757
+#: config/arm/arm-builtins.c:2661 config/arm/arm-builtins.c:2767
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr "el rango del selector debe estar entre 0 y 1"
 
-#: config/arm/arm-builtins.c:2823
+#: config/arm/arm-builtins.c:2833
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr "la máscara debe ser un inmediato"
 
-#: config/arm/arm-builtins.c:2828
+#: config/arm/arm-builtins.c:2838
 #, gcc-internal-format
 msgid "the range of mask should be in 0 to 255"
 msgstr "el rango de la máscara debe estar entre 0 y 255"
 
-#: config/arm/arm-builtins.c:3016
+#: config/arm/arm-builtins.c:3026
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3018
+#: config/arm/arm-builtins.c:3028
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3020
+#: config/arm/arm-builtins.c:3030
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3022
+#: config/arm/arm-builtins.c:3032
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3028
+#: config/arm/arm-builtins.c:3038
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3030
+#: config/arm/arm-builtins.c:3040
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3035
+#: config/arm/arm-builtins.c:3045
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3037
+#: config/arm/arm-builtins.c:3047
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3039
+#: config/arm/arm-builtins.c:3049
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3041
+#: config/arm/arm-builtins.c:3051
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3043
+#: config/arm/arm-builtins.c:3053
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3045
+#: config/arm/arm-builtins.c:3055
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3047
+#: config/arm/arm-builtins.c:3057
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3049
+#: config/arm/arm-builtins.c:3059
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3051
+#: config/arm/arm-builtins.c:3061
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3053
+#: config/arm/arm-builtins.c:3063
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3055
+#: config/arm/arm-builtins.c:3065
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3057
+#: config/arm/arm-builtins.c:3067
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3059
+#: config/arm/arm-builtins.c:3069
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3061
+#: config/arm/arm-builtins.c:3071
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3063
+#: config/arm/arm-builtins.c:3073
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3065
+#: config/arm/arm-builtins.c:3075
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3067
+#: config/arm/arm-builtins.c:3077
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3069
+#: config/arm/arm-builtins.c:3079
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr ""
@@ -28824,551 +28872,551 @@
 msgid "can%'t set position in PCH file: %m"
 msgstr "no se puede establecer la posición en el fichero PCH: %m"
 
-#: config/i386/i386.c:3177
+#: config/i386/i386.c:3180
 #, gcc-internal-format
 msgid "wrong argument %qs to option %qs"
 msgstr "argumento %qs incorrecto para la opción %qs"
 
-#: config/i386/i386.c:3183
+#: config/i386/i386.c:3186
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr "los rangos de tamaño de la opción %qs deberían ser crecientes"
 
-#: config/i386/i386.c:3193
+#: config/i386/i386.c:3196
 #, gcc-internal-format
 msgid "wrong strategy name %qs specified for option %qs"
 msgstr "se especificó un nombre de estrategia %qs incorrecto para la opción %qs"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3219
+#: config/i386/i386.c:3222
 #, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr "no se admite el nombre de estrategia %qs especificado para la opción %qs para código de 32 bits"
 
-#: config/i386/i386.c:3232
+#: config/i386/i386.c:3235
 #, gcc-internal-format
 msgid "unknown alignment %qs specified for option %qs"
 msgstr "se especificó una alineación %qs desconocida para la opción %qs"
 
-#: config/i386/i386.c:3242
+#: config/i386/i386.c:3245
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr "el valor máximo para el último rango de tamaños debería ser -1 para la opción %qs"
 
-#: config/i386/i386.c:3249
+#: config/i386/i386.c:3252
 #, gcc-internal-format
 msgid "too many size ranges specified in option %qs"
 msgstr "se especificaron demasiados rangos de tamaños en la opción %qs"
 
-#: config/i386/i386.c:3302
+#: config/i386/i386.c:3305
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown parameter to option -mtune-ctrl: %s"
 msgstr "parámetro desconocido para la opción -mtune-ctrl: %s"
 
-#: config/i386/i386.c:3726
+#: config/i386/i386.c:3729
 #, gcc-internal-format
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "no se admite Intel MCU psABI en el modo %s"
 
-#: config/i386/i386.c:3775
+#: config/i386/i386.c:3778
 #, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "%<-mtune=x86-64%> es obsoleto; use en su lugar %<-mtune=k8%> o %<-mtune=generic%> como sea adecuado"
 
-#: config/i386/i386.c:3777
+#: config/i386/i386.c:3780
 #, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr "%<target(\"tune=x86-64\")%> es obsoleto; use %<target(\"tune=k8\")%> o %<target(\"tune=generic\")%> en su lugar como convenga"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3804
+#: config/i386/i386.c:3807
 #, gcc-internal-format
 msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgstr "no se admite -mstringop-stategy=rep_8byte para código de 32-bit"
 
-#: config/i386/i386.c:3821
+#: config/i386/i386.c:3824
 #, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "el modelo de direcciones %qs no se admite en el modo de bit %s"
 
-#: config/i386/i386.c:3833
+#: config/i386/i386.c:3836
 #, gcc-internal-format
 msgid "-mabi=ms not supported with X32 ABI"
 msgstr "no se admite -mabi=ms con X32 ABI"
 
-#: config/i386/i386.c:3851 config/i386/i386.c:3860 config/i386/i386.c:3872
-#: config/i386/i386.c:3883 config/i386/i386.c:3894
+#: config/i386/i386.c:3854 config/i386/i386.c:3863 config/i386/i386.c:3875
+#: config/i386/i386.c:3886 config/i386/i386.c:3897
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "el modelo de código %qs no se admite en el modo de bit %s"
 
-#: config/i386/i386.c:3863 config/i386/i386.c:3875
+#: config/i386/i386.c:3866 config/i386/i386.c:3878
 #, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "el modelo de código %qs no se admite en modo x32"
 
-#: config/i386/i386.c:3881 config/i386/i386.c:3890 config/i386/i386.c:5213
+#: config/i386/i386.c:3884 config/i386/i386.c:3893 config/i386/i386.c:5216
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "el modelo de código %s no admite el modo PIC"
 
-#: config/i386/i386.c:3918
+#: config/i386/i386.c:3921
 #, gcc-internal-format
 msgid "-masm=intel not supported in this configuration"
 msgstr "no se admite -masm=intel en esta configuración"
 
-#: config/i386/i386.c:3923
+#: config/i386/i386.c:3926
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "no está compilado el modo bit-%i"
 
-#: config/i386/i386.c:3932
+#: config/i386/i386.c:3935
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr "la CPU %<generic%> solo se puede usar para el ajuste %<-tune=%>"
 
-#: config/i386/i386.c:3934
+#: config/i386/i386.c:3937
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "la CPU %<generic%> solo se puede usar para el atributo %<target(\"tune=\")%>"
 
-#: config/i386/i386.c:3941
+#: config/i386/i386.c:3944
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr "la CPU %<intal%> solo se puede usar para el ajuste %<-mtune=%>"
 
-#: config/i386/i386.c:3943
+#: config/i386/i386.c:3946
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "la CPU %<intel%> solo se puede usar para el atributo %<target(\"tune=\")%>"
 
-#: config/i386/i386.c:3951 config/i386/i386.c:4265
+#: config/i386/i386.c:3954 config/i386/i386.c:4268
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "el CPU que seleccionó no admite el conjunto de instrucciones x86-64"
 
-#: config/i386/i386.c:4197 config/i386/i386.c:4200
+#: config/i386/i386.c:4200 config/i386/i386.c:4203
 #, gcc-internal-format
 msgid "Intel MPX does not support x32"
 msgstr "Intel MPX no tiene soporte para x32"
 
-#: config/i386/i386.c:4205
+#: config/i386/i386.c:4208
 #, gcc-internal-format
 msgid "bad value (%qs) for %<-march=%> switch"
 msgstr "valor erróneo (%qs) para la opción %<-march=%>"
 
-#: config/i386/i386.c:4206
+#: config/i386/i386.c:4209
 #, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"arch=\")%> attribute"
 msgstr "valor erróneo (%qs) para el atributo %<target(\"arch=\")%>"
 
-#: config/i386/i386.c:4228
+#: config/i386/i386.c:4231
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "los argumentos válidos para la opción %<-march=%> son: %s; ¿quiso decir %qs?"
 
-#: config/i386/i386.c:4230
+#: config/i386/i386.c:4233
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr "los argumentos válidos para el atributo %<target(\"arch=\")%> son: %s; ¿qiuso decir %qs?"
 
-#: config/i386/i386.c:4235
+#: config/i386/i386.c:4238
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "los argumentos válidos para la opción %<-march=%> son: %s"
 
-#: config/i386/i386.c:4236
+#: config/i386/i386.c:4239
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "los argumentos válidos para el atributo %<target(\"arch=\")%> son: %s"
 
-#: config/i386/i386.c:4284
+#: config/i386/i386.c:4287
 #, gcc-internal-format
 msgid "bad value (%qs) for %<-mtune=%> switch"
 msgstr "valor erróneo (%qs) para la opción %<-mtune=%>"
 
-#: config/i386/i386.c:4285
+#: config/i386/i386.c:4288
 #, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"tune=\")%> attribute"
 msgstr "valor erróneo (%qs) para el atributo %<target(\"tune=\")%>"
 
-#: config/i386/i386.c:4305
+#: config/i386/i386.c:4308
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "los argumentos válidos para la opción %<-mtune=%> son: %s; ¿quiso decir %qs?"
 
-#: config/i386/i386.c:4307
+#: config/i386/i386.c:4310
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr "los argumentos válidos para el atributo %<target(\"tune=\")%> son: %s; ¿quiso decir %qs?"
 
-#: config/i386/i386.c:4312
+#: config/i386/i386.c:4315
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "los argumentos válidos para la opción %<-mtune=%> son: %s"
 
-#: config/i386/i386.c:4313
+#: config/i386/i386.c:4316
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "los argumentos válidos para el atributo %<target(\"tune=\")%> son: %s"
 
-#: config/i386/i386.c:4379
+#: config/i386/i386.c:4382
 #, gcc-internal-format
 msgid "-mregparm is ignored in 64-bit mode"
 msgstr "se descarta -mregparm en modo de 64-bit"
 
-#: config/i386/i386.c:4381
+#: config/i386/i386.c:4384
 #, gcc-internal-format
 msgid "-mregparm is ignored for Intel MCU psABI"
 msgstr "se descarta -mregparm para Intel MCU psABI"
 
-#: config/i386/i386.c:4384
+#: config/i386/i386.c:4387
 #, gcc-internal-format, gfc-internal-format
 msgid "-mregparm=%d is not between 0 and %d"
 msgstr "-mregparm=%d no está entre 0 y %d"
 
-#: config/i386/i386.c:4417
+#: config/i386/i386.c:4420
 #, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "se descarta %<-mrtd%> en el modo de 64bit"
 
-#: config/i386/i386.c:4418
+#: config/i386/i386.c:4421
 #, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "se descarta %<target(\"rtd\")%> en el modo de 64bit"
 
-#: config/i386/i386.c:4497
+#: config/i386/i386.c:4500
 #, gcc-internal-format
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "no se admite -mpreferred-stack-boundary en este objetivo"
 
-#: config/i386/i386.c:4500
+#: config/i386/i386.c:4503
 #, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d no está entre %d y %d"
 
-#: config/i386/i386.c:4523
+#: config/i386/i386.c:4526
 #, gcc-internal-format, gfc-internal-format
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr "-mincoming-stack-boundary=%d no está entre %d y 12"
 
-#: config/i386/i386.c:4536
+#: config/i386/i386.c:4539
 #, gcc-internal-format
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "-mnop-mcount no es compatible con este objetivo"
 
-#: config/i386/i386.c:4539
+#: config/i386/i386.c:4542
 #, gcc-internal-format
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr "-mnop-mcount no está implementada para -fPIC"
 
-#: config/i386/i386.c:4545
+#: config/i386/i386.c:4548
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "se usó %<-msseregparm%> sin SSE activado"
 
-#: config/i386/i386.c:4546
+#: config/i386/i386.c:4549
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "se usó %<target(\"ssseregparm\")%> sin SSE activado"
 
-#: config/i386/i386.c:4556
+#: config/i386/i386.c:4559
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "el conjunto de instrucciones SSE está desactivado, usando la aritmética 387"
 
-#: config/i386/i386.c:4563
+#: config/i386/i386.c:4566
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "el conjunto de instrucciones 387 está desactivado, usando la aritmética SSE"
 
-#: config/i386/i386.c:4613
+#: config/i386/i386.c:4616
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr "la prueba de pila requiere %<-maccumulate-outgoing-args%> para ser correcta"
 
-#: config/i386/i386.c:4615
+#: config/i386/i386.c:4618
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr "la prueba de pila requiere %<target(\"accumulate-outgoing-args\"%> para ser correcta"
 
-#: config/i386/i386.c:4629
+#: config/i386/i386.c:4632
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr "el registro ebp fijo requiere %<-maccumulate-outgoing-args%>"
 
-#: config/i386/i386.c:4631
+#: config/i386/i386.c:4634
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr "el registro ebp fijo requiere %<target(\"accumulate-outgoing-args\")%>"
 
-#: config/i386/i386.c:4741
+#: config/i386/i386.c:4744
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr "-mfentry no se admite para 32-bit en combinación con -fpic"
 
-#: config/i386/i386.c:4744
+#: config/i386/i386.c:4747
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr "-mno-fentry no es compatible con SEH"
 
-#: config/i386/i386.c:4748
+#: config/i386/i386.c:4751
 #, gcc-internal-format
 msgid "-mcall-ms2sysv-xlogues isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386.c:4813 config/powerpcspe/powerpcspe.c:5663
+#: config/i386/i386.c:4816 config/powerpcspe/powerpcspe.c:5663
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown option for -mrecip=%s"
 msgstr "opción desconocida para -mrecip=%s"
 
-#: config/i386/i386.c:4870 config/powerpcspe/powerpcspe.c:5339
+#: config/i386/i386.c:4873 config/powerpcspe/powerpcspe.c:5339
 #, gcc-internal-format
 msgid "%qs is not a valid number in -mstack-protector-guard-offset="
 msgstr "%qs no es un número válido en -mstack-protector-guard-offset="
 
-#: config/i386/i386.c:4875 config/powerpcspe/powerpcspe.c:5344
+#: config/i386/i386.c:4878 config/powerpcspe/powerpcspe.c:5344
 #, gcc-internal-format
 msgid "%qs is not a valid offset in -mstack-protector-guard-offset="
 msgstr "%qs no es un desplazamiento válido en -mstack-protector-guard-offset="
 
-#: config/i386/i386.c:4907 config/powerpcspe/powerpcspe.c:5356
+#: config/i386/i386.c:4910 config/powerpcspe/powerpcspe.c:5356
 #, gcc-internal-format
 msgid "%qs is not a valid base register in -mstack-protector-guard-reg="
 msgstr "%qs no es un registro base válido en -mstack-protector-guard-reg="
 
-#: config/i386/i386.c:5506 config/i386/i386.c:5553 config/s390/s390.c:15812
+#: config/i386/i386.c:5509 config/i386/i386.c:5556 config/s390/s390.c:15812
 #: config/s390/s390.c:15862 config/s390/s390.c:15879
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr "se desconoce attribute(target(\"%s\"))"
 
-#: config/i386/i386.c:5534
+#: config/i386/i386.c:5537
 #, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr "ya se había especificado option(\"%s\")"
 
-#: config/i386/i386.c:5837
+#: config/i386/i386.c:5840
 #, gcc-internal-format
 msgid "interrupt and naked attributes are not compatible"
 msgstr "interrupción y atributos desnudos no es compatible"
 
-#: config/i386/i386.c:5852
+#: config/i386/i386.c:5855
 #, gcc-internal-format
 msgid "Only DWARF debug format is supported for interrupt service routine."
 msgstr "Solo se admite el formato de depuración DWARF para la rutina de servicio de interrupciones."
 
-#: config/i386/i386.c:5901
+#: config/i386/i386.c:5904
 #, gcc-internal-format
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "%<-mindirect-branch=%s%> y %<-mcmodel=large%> no son compatibles"
 
-#: config/i386/i386.c:5913
+#: config/i386/i386.c:5916
 #, gcc-internal-format
 msgid "%<-mindirect-branch=thunk-extern%>, %<-fcf-protection=branch%> and %<-fcheck-pointer-bounds%> are not compatible"
 msgstr "%<-mindirect-branch=thunk-extern%>, %<-fcf-protection=branch%> y %<-fcheck-pointer-bounds%> no son compatibles"
 
-#: config/i386/i386.c:5949
+#: config/i386/i386.c:5952
 #, gcc-internal-format
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "%<-mfunction-return=%s%> y %<-mcmodel=large%> no son compatibles"
 
-#: config/i386/i386.c:6047
+#: config/i386/i386.c:6050
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in %s service routine"
 msgstr "las instrucciones %s no se permiten en la rutina de servicio %s"
 
-#: config/i386/i386.c:6051
+#: config/i386/i386.c:6054
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in function with no_caller_saved_registers attribute"
 msgstr "Las instrucciones %s no están permitidas en funciones con el atributo no_caller_saved_registers"
 
-#: config/i386/i386.c:6465 config/i386/i386.c:6516
+#: config/i386/i386.c:6468 config/i386/i386.c:6519
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "los atributos fastcall y regparm no son compatibles"
 
-#: config/i386/i386.c:6470
+#: config/i386/i386.c:6473
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "los atributos regparam y thiscall no son compatibles"
 
-#: config/i386/i386.c:6477 config/i386/i386.c:41444
+#: config/i386/i386.c:6480 config/i386/i386.c:41438
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "el atributo %qE requiere un argumento constante entero"
 
-#: config/i386/i386.c:6483
+#: config/i386/i386.c:6486
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "el argumento para el atributo %qE es más grande que %d"
 
-#: config/i386/i386.c:6508 config/i386/i386.c:6551
+#: config/i386/i386.c:6511 config/i386/i386.c:6554
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "los atributos fastcall y cdecl no son compatibles"
 
-#: config/i386/i386.c:6512
+#: config/i386/i386.c:6515
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "los atributos fastcall y stdcall no son compatibles"
 
-#: config/i386/i386.c:6520 config/i386/i386.c:6569
+#: config/i386/i386.c:6523 config/i386/i386.c:6572
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "los atributos fastcall y thiscall no son compatibles"
 
-#: config/i386/i386.c:6530 config/i386/i386.c:6547
+#: config/i386/i386.c:6533 config/i386/i386.c:6550
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "los atributos stdcall y cdecl no son compatibles"
 
-#: config/i386/i386.c:6534
+#: config/i386/i386.c:6537
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "los atributos stdcall y fastcall no son compatibles"
 
-#: config/i386/i386.c:6538 config/i386/i386.c:6565
+#: config/i386/i386.c:6541 config/i386/i386.c:6568
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "los atributos stdcall y thiscall no son compatibles"
 
-#: config/i386/i386.c:6555 config/i386/i386.c:6573
+#: config/i386/i386.c:6558 config/i386/i386.c:6576
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "los atributos cdecl y thiscall no son compatibles"
 
-#: config/i386/i386.c:6561
+#: config/i386/i386.c:6564
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "se usó el atributo %qE para método no de clase"
 
-#: config/i386/i386.c:6805
+#: config/i386/i386.c:6808
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "se llama a %qD con el atributo sseregparm sin activar SSE/SSE2"
 
-#: config/i386/i386.c:6808
+#: config/i386/i386.c:6811
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "se llama a %qT con el atributo sseregparm sin activar SSE/SSE2"
 
-#: config/i386/i386.c:7126
+#: config/i386/i386.c:7129
 #, gcc-internal-format
 msgid "X32 does not support ms_abi attribute"
 msgstr "X32 no admite el atributo ms_abi"
 
-#: config/i386/i386.c:7160
+#: config/i386/i386.c:7163
 #, gcc-internal-format
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr "ms_hook_prologue no es compatible con la función anidada"
 
-#: config/i386/i386.c:7502
+#: config/i386/i386.c:7505
 #, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr "el argumento de vector AVX512F sin AVX512F activado cambia la ABI"
 
-#: config/i386/i386.c:7508
+#: config/i386/i386.c:7511
 #, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr "el retorno de vector AVX512F sin AVX512F activado cambia la ABI"
 
-#: config/i386/i386.c:7522
+#: config/i386/i386.c:7525
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr "el argumento de vector AVX sin AVX activado cambia la ABI"
 
-#: config/i386/i386.c:7528
+#: config/i386/i386.c:7531
 #, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr "el retorno de vector AVX sin AVX activado cambia la ABI"
 
-#: config/i386/i386.c:7544
+#: config/i386/i386.c:7547
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr "el argumento de vector SSE sin SSE activado cambia la ABI"
 
-#: config/i386/i386.c:7550
+#: config/i386/i386.c:7553
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr "la devolución de vector SSE sin SSE activado cambia la ABI"
 
-#: config/i386/i386.c:7566
+#: config/i386/i386.c:7569
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr "el argumento de vector MMX sin MMX activado cambia la ABI"
 
-#: config/i386/i386.c:7572
+#: config/i386/i386.c:7575
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr "la devolución de vector MMX sin MMX activado cambia la ABI"
 
-#: config/i386/i386.c:7754
+#: config/i386/i386.c:7757
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr "la ABI para pasar un struct con un miembro de matriz flexible cambió en GCC 4.4"
 
-#: config/i386/i386.c:7871
+#: config/i386/i386.c:7874
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr "la ABI para pasar un union con long double cambió en GCC 4.4"
 
-#: config/i386/i386.c:7989
+#: config/i386/i386.c:7992
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr "la ABI para pasar una estructura con un miembro de coma flotante compleja cambió en GCC 4.4"
 
-#: config/i386/i386.c:8152
+#: config/i386/i386.c:8155
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr "se devuelve el registro SSE con SSE desactivado"
 
-#: config/i386/i386.c:8158
+#: config/i386/i386.c:8161
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr "argumento de registro SSE con SSE desactivado"
 
-#: config/i386/i386.c:8174
+#: config/i386/i386.c:8177
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr "se devuelve el registro x87 con x87 desactivado"
 
-#: config/i386/i386.c:8471 config/i386/i386.c:8750 config/i386/i386.c:9276
+#: config/i386/i386.c:8474 config/i386/i386.c:8753 config/i386/i386.c:9279
 #, gcc-internal-format
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr "se llama a %qD con el convenio de llamadas SSE sin activar SSE/SSE2"
 
-#: config/i386/i386.c:8473 config/i386/i386.c:8752 config/i386/i386.c:9278
+#: config/i386/i386.c:8476 config/i386/i386.c:8755 config/i386/i386.c:9281
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr "esto es un error de GCC que se puede sortear añadiendo el atributo usado a la función llamada"
 
-#: config/i386/i386.c:9178
+#: config/i386/i386.c:9181
 #, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr "La ABI para pasar parámetros con alineación de %d-bytes cambió en GCC 4.6"
 
-#: config/i386/i386.c:11601
+#: config/i386/i386.c:11604
 #, gcc-internal-format, gfc-internal-format
 msgid "-mcall-ms2sysv-xlogues is not compatible with %s"
 msgstr "-mcall-ms2sysv-xlogues no es compatible con %s"
 
-#: config/i386/i386.c:13593
+#: config/i386/i386.c:13596
 #, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr "el atributo ms_hook_prologue no es compatible con -mfentry para 32-bit"
 
-#: config/i386/i386.c:13683
+#: config/i386/i386.c:13686
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr "No se admite Puntero de Argumento de Realineamiento Dinámico (DRAP) en la rutina de servicio de interrupciones.  Esto puede sortearse evitando funciones con retorno agregado."
 
-#: config/i386/i386.c:14970
+#: config/i386/i386.c:14973
 #, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr "-fsplit-stack no admite fastcall con funciones anidadas"
 
-#: config/i386/i386.c:14990
+#: config/i386/i386.c:14993
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
 msgstr "-fsplit-stack no admite 2 parámetros de registro para una función anidada"
@@ -29375,311 +29423,311 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:15001
+#: config/i386/i386.c:15004
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr "-fsplit-stack no admite 3 parámetros de registro"
 
-#: config/i386/i386.c:17939
+#: config/i386/i386.c:17942
 #, gcc-internal-format
 msgid "'V' modifier on non-integer register"
 msgstr "modificador 'V' en registro no entero"
 
-#: config/i386/i386.c:17950 config/i386/i386.c:17964
+#: config/i386/i386.c:17953 config/i386/i386.c:17967
 #, gcc-internal-format
 msgid "unsupported size for integer register"
 msgstr "no se admite el tamaño para registro de enteros"
 
-#: config/i386/i386.c:17996
+#: config/i386/i386.c:17999
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr "los registros extendidos no tiene mitades superiores"
 
-#: config/i386/i386.c:18011
+#: config/i386/i386.c:18014
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr "no se admite el tamaño de operando para el registro extendido"
 
-#: config/i386/i386.c:18202
+#: config/i386/i386.c:18205
 #, gcc-internal-format
 msgid "non-integer operand used with operand code 'z'"
 msgstr "se usó un operando que no es entero con el código de operando 'z'"
 
-#: config/i386/i386.c:28467
+#: config/i386/i386.c:28470
 #, gcc-internal-format
 msgid "interrupt service routine can't be called directly"
 msgstr "no se puede llamar directamente a la rutina de servicio de interrupciones"
 
-#: config/i386/i386.c:29995
+#: config/i386/i386.c:29998
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in -fabi-version=12 (GCC 8)"
 msgstr ""
 
-#: config/i386/i386.c:32435
+#: config/i386/i386.c:32438
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr "No se ha encontrado despachador para los atributos de versión"
 
-#: config/i386/i386.c:32485
+#: config/i386/i386.c:32488
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for %s"
 msgstr "No se encontró despachador para %s"
 
-#: config/i386/i386.c:32495
+#: config/i386/i386.c:32498
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr "No se encontró despachador para los atributos de versión : %s"
 
-#: config/i386/i386.c:32657
+#: config/i386/i386.c:32660
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr "Las versiones de funciones no pueden marcarse como gnu_inline; hay que generar cuerpos"
 
-#: config/i386/i386.c:32662 config/i386/i386.c:32938
-#: config/rs6000/rs6000.c:37850
+#: config/i386/i386.c:32665 config/i386/i386.c:32941
+#: config/rs6000/rs6000.c:37906
 #, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "No se admiten versiones múltiples de funciones virtuales"
 
-#: config/i386/i386.c:32795 config/rs6000/rs6000.c:37607
+#: config/i386/i386.c:32798 config/rs6000/rs6000.c:37663
 #, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "el versionado múltiple necesita ifunc, que no se admite en este objetivo"
 
-#: config/i386/i386.c:33207
+#: config/i386/i386.c:33210
 #, gcc-internal-format
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr "El parámetro para la función interna debe ser una cadena constante o literal"
 
-#: config/i386/i386.c:33232 config/i386/i386.c:33282
+#: config/i386/i386.c:33235 config/i386/i386.c:33285
 #, gcc-internal-format, gfc-internal-format
 msgid "Parameter to builtin not valid: %s"
 msgstr "El parámetro para la función interna no es válido: %s"
 
-#: config/i386/i386.c:33975 config/i386/i386.c:35415
+#: config/i386/i386.c:33978 config/i386/i386.c:35418
 #, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "el tercer argumento debe ser un inmediato de 2-bit"
 
-#: config/i386/i386.c:34370
+#: config/i386/i386.c:34373
 #, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "el quinto argumento debe ser un inmediato de 8-bit"
 
-#: config/i386/i386.c:34465
+#: config/i386/i386.c:34468
 #, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "el tercer argumento debe ser un inmediato de 8-bit"
 
-#: config/i386/i386.c:35346
+#: config/i386/i386.c:35349
 #, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "el último argumento debe ser un inmediato de 1-bit"
 
-#: config/i386/i386.c:35361
+#: config/i386/i386.c:35364
 #, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "el último argumento debe ser un inmediato de 3-bit"
 
-#: config/i386/i386.c:35394
+#: config/i386/i386.c:35397
 #, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "el último argumento debe ser un inmediato de 4-bit"
 
-#: config/i386/i386.c:35434
+#: config/i386/i386.c:35437
 #, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "el último argumento debe ser un inmediato de 1-bit"
 
-#: config/i386/i386.c:35447
+#: config/i386/i386.c:35450
 #, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "el tercer argumento debe ser un inmediato de 5-bit"
 
-#: config/i386/i386.c:35457
+#: config/i386/i386.c:35460
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "el penúltimo argumento debe ser un inmediato de 8-bit"
 
-#: config/i386/i386.c:35462 config/i386/i386.c:36249
+#: config/i386/i386.c:35465 config/i386/i386.c:36252
 #, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "el último argumento debe ser un inmediato de 8-bit"
 
-#: config/i386/i386.c:35596
+#: config/i386/i386.c:35599
 #, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr "el tercer argumento debe ser una constante de comparación"
 
-#: config/i386/i386.c:35601
+#: config/i386/i386.c:35604
 #, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr "modo de comparación incorrecto"
 
-#: config/i386/i386.c:35607 config/i386/i386.c:35814
+#: config/i386/i386.c:35610 config/i386/i386.c:35817
 #, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr "operando de redondeo incorrecto"
 
-#: config/i386/i386.c:35796
+#: config/i386/i386.c:35799
 #, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "el argumento inmediato debe ser un inmediato de 4-bit"
 
-#: config/i386/i386.c:35802
+#: config/i386/i386.c:35805
 #, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "el argumento inmediato debe ser un inmediato de 5-bit"
 
-#: config/i386/i386.c:35805
+#: config/i386/i386.c:35808
 #, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "el argumento inmediato debe ser un inmediato de 8-bit"
 
-#: config/i386/i386.c:36247
+#: config/i386/i386.c:36250
 #, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "el último argumento debe ser un inmediato de 32-bit"
 
-#: config/i386/i386.c:36329 config/powerpcspe/powerpcspe.c:16219
-#: config/rs6000/rs6000.c:15304
+#: config/i386/i386.c:36332 config/powerpcspe/powerpcspe.c:16219
+#: config/rs6000/rs6000.c:15348
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr "el selector debe ser una constante entera en el rango 0..%wi"
 
-#: config/i386/i386.c:36539
+#: config/i386/i386.c:36542
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr "%qE necesita la opción isa desconocida"
 
-#: config/i386/i386.c:36543
+#: config/i386/i386.c:36546
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "%qE necesita la opción isa %s"
 
-#: config/i386/i386.c:37381
+#: config/i386/i386.c:37375
 #, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "el último argumento debe ser un inmediato"
 
-#: config/i386/i386.c:38108 config/i386/i386.c:38290
+#: config/i386/i386.c:38102 config/i386/i386.c:38284
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "el último argumento debe ser un escalar 1, 2, 4, 8"
 
-#: config/i386/i386.c:38343
+#: config/i386/i386.c:38337
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "el argumento delantero debe ser un escalar 1, 2, 4, 8"
 
-#: config/i386/i386.c:38349
+#: config/i386/i386.c:38343
 #, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr "operando de pista incorrecto"
 
-#: config/i386/i386.c:38368
+#: config/i386/i386.c:38362
 #, gcc-internal-format
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr "el argumento de xabort debe ser un inmediato de 8-bit"
 
-#: config/i386/i386.c:41431
+#: config/i386/i386.c:41425
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "el atributo %qE solamente está disponible para 64-bit"
 
-#: config/i386/i386.c:41452
+#: config/i386/i386.c:41446
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "el argumento del atributo %qE no es cero ni uno"
 
-#: config/i386/i386.c:41485 config/i386/i386.c:41494
+#: config/i386/i386.c:41479 config/i386/i386.c:41488
 #, gcc-internal-format
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr "los atributos ms_abi y sysv_abi no son compatibles"
 
-#: config/i386/i386.c:41530 config/powerpcspe/powerpcspe.c:35868
-#: config/rs6000/rs6000.c:33065
+#: config/i386/i386.c:41524 config/powerpcspe/powerpcspe.c:35868
+#: config/rs6000/rs6000.c:33121
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "se descarta el atributo incompatible %qE"
 
-#: config/i386/i386.c:41555 config/i386/i386.c:41577 config/ia64/ia64.c:815
+#: config/i386/i386.c:41549 config/i386/i386.c:41571 config/ia64/ia64.c:815
 #: config/s390/s390.c:1153
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "el atributo %qE requiere una constante entera como argumento"
 
-#: config/i386/i386.c:41565 config/i386/i386.c:41587 config/s390/s390.c:1182
+#: config/i386/i386.c:41559 config/i386/i386.c:41581 config/s390/s390.c:1182
 #, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "el argumento del atributo %qE no es (keep|thunk|thunk-inline|thunk-extern)"
 
-#: config/i386/i386.c:41619
+#: config/i386/i386.c:41613
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr "la rutina de servicio de interrupciones debería tener un puntero como primer argumento"
 
-#: config/i386/i386.c:41626
+#: config/i386/i386.c:41620
 #, gcc-internal-format, gfc-internal-format
 msgid "interrupt service routine should have unsigned %sint as the second argument"
 msgstr "la rutina de atención de interrupciones debería tener como segundo argumento un unsigned %sint"
 
-#: config/i386/i386.c:41636
+#: config/i386/i386.c:41630
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr "la rutina de servicio de interrupciones solo puede tener un argumento puntero y un argumento entero opcional"
 
-#: config/i386/i386.c:41639
+#: config/i386/i386.c:41633
 #, gcc-internal-format
 msgid "interrupt service routine can't have non-void return value"
 msgstr "ls rutina de servicio de interrupción no puede tener valor de retorno que no sea void"
 
-#: config/i386/i386.c:44676
+#: config/i386/i386.c:44670
 #, gcc-internal-format
 msgid "alternatives not allowed in asm flag output"
 msgstr "no se permiten alternativas en la salida del indicador asm"
 
-#: config/i386/i386.c:44740
+#: config/i386/i386.c:44734
 #, gcc-internal-format
 msgid "unknown asm flag output %qs"
 msgstr "salida del indicador asm %qs desconocida"
 
-#: config/i386/i386.c:44769
+#: config/i386/i386.c:44763
 #, gcc-internal-format
 msgid "invalid type for asm flag output"
 msgstr "tipo no válido para la salida del indicador asm"
 
-#: config/i386/i386.c:50634
+#: config/i386/i386.c:50628
 #, gcc-internal-format
 msgid "unknown architecture specific memory model"
 msgstr "modelo de memoria específico de la arquitectura desconocido"
 
-#: config/i386/i386.c:50641
+#: config/i386/i386.c:50635
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr "HLE_ACQUIRE no se usa con ACQUIRE o modelos de memoria más fuertes"
 
-#: config/i386/i386.c:50647
+#: config/i386/i386.c:50641
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr "HLE_RELEASE no se usa con RELEASE o modelos de memoria más fuertes"
 
-#: config/i386/i386.c:50671 config/i386/i386.c:50787
+#: config/i386/i386.c:50665 config/i386/i386.c:50781
 #, gcc-internal-format, gfc-internal-format
 msgid "unsupported simdlen %d"
 msgstr "simdlen %d no admitido"
 
-#: config/i386/i386.c:50690
+#: config/i386/i386.c:50684
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd"
 msgstr "no se admite el tipo de retorno %qT para simd"
 
-#: config/i386/i386.c:50712
+#: config/i386/i386.c:50706
 #, gcc-internal-format
 msgid "unsupported argument type %qT for simd"
 msgstr "no se admite el tipo de argumento %qT para simd"
 
-#: config/i386/i386.c:51033
+#: config/i386/i386.c:51027
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr "El Comprobador de Punteros requiere suporte MPX en este objetivo. Utilice las opciones -mmpx para activar MPX."
@@ -29900,7 +29948,7 @@
 msgstr "interrupt_thread sólo está disponible en fido"
 
 #: config/m68k/m68k.c:1128 config/powerpcspe/powerpcspe.c:28512
-#: config/rs6000/rs6000.c:25791
+#: config/rs6000/rs6000.c:25868
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "no se admite la expresión del límite de la pila"
@@ -30475,58 +30523,58 @@
 
 #. Trampoline is not supported on reduced-set registers yet.
 #: config/nds32/nds32.c:2327 config/nds32/nds32.c:2381
-#: config/nds32/nds32.c:3127 config/nds32/nds32.c:3201
-#: config/nds32/nds32.c:3216 config/nds32/nds32.c:3222
-#: config/nds32/nds32.c:3284 config/nds32/nds32.c:3290
-#: config/nds32/nds32.c:3322
+#: config/nds32/nds32.c:3128 config/nds32/nds32.c:3202
+#: config/nds32/nds32.c:3217 config/nds32/nds32.c:3223
+#: config/nds32/nds32.c:3285 config/nds32/nds32.c:3291
+#: config/nds32/nds32.c:3323
 #, gcc-internal-format
 msgid "a nested function is not supported for reduced registers"
 msgstr "no se admiten funciones anidadas para registros reducidos"
 
 #. The enum index value for array size is out of range.
-#: config/nds32/nds32.c:3025
+#: config/nds32/nds32.c:3026
 #, gcc-internal-format
 msgid "intrinsic register index is out of range"
 msgstr "el índice de registro intrínseco está fuera de rango"
 
-#: config/nds32/nds32.c:3041 config/nds32/nds32.c:3048
-#: config/nds32/nds32.c:3055 config/nds32/nds32.c:3062
-#: config/nds32/nds32.c:3069
+#: config/nds32/nds32.c:3042 config/nds32/nds32.c:3049
+#: config/nds32/nds32.c:3056 config/nds32/nds32.c:3063
+#: config/nds32/nds32.c:3070
 #, gcc-internal-format
 msgid "CCTL intrinsic function subtype out of range!"
 msgstr "el subtipo de la función intrínseca CCTLestá fuera de rango"
 
-#: config/nds32/nds32.c:3508
+#: config/nds32/nds32.c:3509
 #, gcc-internal-format
 msgid "invalid id value for interrupt/exception attribute"
 msgstr "valor de id no válido para atributo de interrupción/excepción"
 
-#: config/nds32/nds32.c:3536
+#: config/nds32/nds32.c:3537
 #, gcc-internal-format
 msgid "invalid id value for reset attribute"
 msgstr "valor de id no válido atributo reset"
 
-#: config/nds32/nds32.c:3552
+#: config/nds32/nds32.c:3553
 #, gcc-internal-format
 msgid "invalid nmi function for reset attribute"
 msgstr "función nmi no válida para atributo reset"
 
-#: config/nds32/nds32.c:3565
+#: config/nds32/nds32.c:3566
 #, gcc-internal-format
 msgid "invalid warm function for reset attribute"
 msgstr "función warm no válida para atributo reset"
 
-#: config/nds32/nds32.c:3638
+#: config/nds32/nds32.c:3639
 #, gcc-internal-format
 msgid "Disable FPU ISA, the ABI option must be enable '-mfloat-abi=soft'"
 msgstr "desactiva ISA de FPU, la opción de ABI debe ser activar '-mfloat-abit=soft'"
 
-#: config/nds32/nds32.c:3641
+#: config/nds32/nds32.c:3642
 #, gcc-internal-format
 msgid "'-mabi=2fp+' option only support when FPU available, must be enable '-mext-fpu-sp' or '-mext-fpu-dp'"
 msgstr ""
 
-#: config/nds32/nds32.c:3647
+#: config/nds32/nds32.c:3648
 #, gcc-internal-format
 msgid "position-independent code not supported"
 msgstr "no se admite código independiente de posición"
@@ -30861,12 +30909,12 @@
 msgid "junk at end of #pragma longcall"
 msgstr "basura al final de #pragma longcall"
 
-#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6154
+#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6152
 #, gcc-internal-format
 msgid "vec_lvsl is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr "vec_lvsl está obsoleta para little endian; utilize asignación para cargas y almacenajes no alineados"
 
-#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6158
+#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6156
 #, gcc-internal-format
 msgid "vec_lvsr is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr "vec_lvsr está obsoleta para little endian; utilize asignación para cargas y almacenajes no alineados"
@@ -30916,7 +30964,7 @@
 msgid "vec_insert only accepts 3 arguments"
 msgstr "vec_insert sólo acepta 3 argumentos"
 
-#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6868
+#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6866
 #, gcc-internal-format
 msgid "passing arg %d of %qE discards qualifiers from pointer target type"
 msgstr "el paso del argumento %d de %qE descarta los calificadores del tipo del destino del puntero"
@@ -31001,7 +31049,7 @@
 msgid "target attribute or pragma changes SPE ABI"
 msgstr "el atributo o pragma target cabia la ABI SPE"
 
-#: config/powerpcspe/powerpcspe.c:4351 config/rs6000/rs6000.c:4223
+#: config/powerpcspe/powerpcspe.c:4351 config/rs6000/rs6000.c:4243
 #, gcc-internal-format
 msgid "AltiVec not supported in this target"
 msgstr "no se admite AltiVec en este objetivo"
@@ -31147,7 +31195,7 @@
 msgid "-mvsx-small-integer requires -mpower8-vector, -mupper-regs-di, and -mdirect-move"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4959 config/rs6000/rs6000.c:4601
+#: config/powerpcspe/powerpcspe.c:4959 config/rs6000/rs6000.c:4628
 #, gcc-internal-format
 msgid "target attribute or pragma changes long double size"
 msgstr "el atributo o pragma target cambia el tamaño de double long"
@@ -31188,22 +31236,22 @@
 msgstr "tipo de ABI de biblioteca de vectorización desconocida (%s) para la opción -mveclibabi="
 
 #: config/powerpcspe/powerpcspe.c:5140 config/powerpcspe/powerpcspe.c:5155
-#: config/rs6000/rs6000.c:4766 config/rs6000/rs6000.c:4781
+#: config/rs6000/rs6000.c:4791 config/rs6000/rs6000.c:4806
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr "el atributo o pragma target cambia la ABI Altivec"
 
-#: config/powerpcspe/powerpcspe.c:5168 config/rs6000/rs6000.c:4794
+#: config/powerpcspe/powerpcspe.c:5168 config/rs6000/rs6000.c:4819
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr "el atributo o pragma target cambia la ABI darwin64"
 
-#: config/powerpcspe/powerpcspe.c:5234 config/rs6000/rs6000.c:4828
+#: config/powerpcspe/powerpcspe.c:5234 config/rs6000/rs6000.c:4853
 #, gcc-internal-format
 msgid "target attribute or pragma changes single precision floating point"
 msgstr "el atributo o pragma target cambia la coma flotante de precisión sencilla"
 
-#: config/powerpcspe/powerpcspe.c:5237 config/rs6000/rs6000.c:4831
+#: config/powerpcspe/powerpcspe.c:5237 config/rs6000/rs6000.c:4856
 #, gcc-internal-format
 msgid "target attribute or pragma changes double precision floating point"
 msgstr "el atributo o pragma target cambia la coma flotante de precisión doble"
@@ -31213,12 +31261,12 @@
 msgid "-mstack-protector-guard=tls needs a valid base register"
 msgstr "-mstack-protector-guard==tls necesita un registro bae válido"
 
-#: config/powerpcspe/powerpcspe.c:8415 config/rs6000/rs6000.c:7925
+#: config/powerpcspe/powerpcspe.c:8415 config/rs6000/rs6000.c:7950
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr "la disposición de los agregados que contienen vectores con alineamiento de %d bytes cambió en GCC 5"
 
-#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11237
+#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11269
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "Se devolvió un vector GCC por referencia: extensión de ABI no estándar sin garantía de compatibilidad"
@@ -31228,7 +31276,7 @@
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "no se puede devolver un valor en el registro vector porque las instrucciones altivec están desactivadas, use -maltivec para activarlas"
 
-#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11595
+#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11633
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr "la ABI para pasar agregados con alineación de %d bytes cambió en GCC 5"
@@ -31238,12 +31286,12 @@
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "no se puede pasar argumentos en el registro vector porque las instrucciones altivec están desactivadas, use -maltivec para activarlas"
 
-#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12604
+#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12648
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr "la ABI para pasar agregados flotantes homogéneos cambió en GCC 5"
 
-#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12779
+#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12823
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "vector GCC pasado por referencia: extensión ABI que no es estándar sin garantía de compatibilidad"
@@ -31253,28 +31301,28 @@
 msgid "internal error: builtin function %s already processed"
 msgstr "error interno: la función interna %s ya se procesó"
 
-#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:13971
+#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:14015
 #, gcc-internal-format
 msgid "argument 1 must be an 8-bit field value"
 msgstr "el argumento 1 debe ser un valor de un campo de 8 bits"
 
-#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14015
+#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14059
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "el argumento 1 debe ser un literal con signo de 5 bits"
 
 #: config/powerpcspe/powerpcspe.c:14934 config/powerpcspe/powerpcspe.c:16803
-#: config/rs6000/rs6000.c:14101
+#: config/rs6000/rs6000.c:14145
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "el argumento 2 debe ser un literal sin signo de 5 bits"
 
-#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14119
+#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14163
 #, gcc-internal-format
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "el argumento 1 debe ser un literal sin signo de 6 bits"
 
-#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14135
+#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14179
 #, gcc-internal-format
 msgid "argument 2 must be a 7-bit unsigned literal"
 msgstr "el argumento 2 debe ser un literal sin signo de 7 bits"
@@ -31294,12 +31342,12 @@
 msgid "builtin %s is only valid in 64-bit mode"
 msgstr "el interno %s solo es válido en modo de 64 bits"
 
-#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14791
+#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14835
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %d must be an unsigned literal"
 msgstr "el argumento %d debe ser un literal sin signo"
 
-#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14793
+#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14837
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "el argumento %d es un literal sin signo fuera de rango"
@@ -31321,53 +31369,53 @@
 msgid "hwcap %s is an invalid argument to builtin %s"
 msgstr "la hwcap %s es un argumento no válido para el interno %s"
 
-#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15065
+#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15109
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "el argumento 3 debe ser una literal sin signo de 4-bit"
 
-#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15090
+#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15134
 #, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "el argumento 3 debe ser una literal sin signo de 2-bit"
 
-#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15110
+#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15154
 #, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "el argumento 3 debe ser una literal sin signo de 1-bit"
 
-#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15122
+#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15166
 #, gcc-internal-format
 msgid "argument 1 must be 0 or 2"
 msgstr "el argumento 1 debe ser 0 o 2"
 
-#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15134
+#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15178
 #, gcc-internal-format
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "el argumento 1 debe ser un literal sin signo de 1 bit"
 
-#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15148
+#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15192
 #, gcc-internal-format
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "el argumento 2 debe ser un literal sin signo de 6 bits"
 
-#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15160
+#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15204
 #, gcc-internal-format
 msgid "argument 2 must be 0 or 1"
 msgstr "el argumento 2 debe ser 0 ó 1"
 
-#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15168
+#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15212
 #, gcc-internal-format
 msgid "argument 3 must be in the range 0..15"
 msgstr "el argumento d de debe estar dentro del rango 0..15"
 
-#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15237
-#: config/rs6000/rs6000.c:15569
+#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15281
+#: config/rs6000/rs6000.c:15613
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "el argumento para %qs debe ser una literal sin signo de 2-bit"
 
-#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15394
+#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15438
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr "sobrecarga sin resolver para el interno Altivec %qF"
@@ -31493,7 +31541,7 @@
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr "error interno: función interna %s, el argumento %d tiene el tipo de argumento inesperado %s"
 
-#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25758
+#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25835
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr "marco de pila demasiado grande"
@@ -31503,12 +31551,12 @@
 msgid "-fsplit-stack uses register r29"
 msgstr "-fsplit-stack utiliza el registro r29"
 
-#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29459
+#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29536
 #, gcc-internal-format
 msgid "Stack frame larger than 2G is not supported for -fsplit-stack"
 msgstr "No se admite un marco de pila mayor de 2G con -fsplit-stack"
 
-#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30447
+#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30524
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "no hay análisis de perfil del código de 64-bit para esta ABI"
@@ -31518,22 +31566,22 @@
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr "No se puede tomar la dirección de una función anindada si se usa la opción -mno-pointers-to-nested-functions."
 
-#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32830
+#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32907
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "el uso de %<long double%> en tipos AltiVec es no válido"
 
-#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32832
+#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32909
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "el uso de tipos booleanos en tipos AltiVec es no válido"
 
-#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32834
+#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32911
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "el uso de %<complex%> en tipos AltiVec es no válido"
 
-#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32836
+#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32913
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr "el uso de tipos de coma flotante decimal en tipos AltiVec es no válido"
@@ -31543,7 +31591,7 @@
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr "el uso de %<long%> en tipos AltiVec es no válido para código de 64 bit sin -mvsx"
 
-#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32845
+#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32922
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "el uso de %<long%> en tipos AltiVec es obsoleto; use %<int%>"
@@ -32085,71 +32133,71 @@
 "Please use an explicit cpu name.  Valid cpu names are: %s"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6168 config/rs6000/rs6000-c.c:6219
-#: config/rs6000/rs6000-c.c:6489 config/rs6000/rs6000-c.c:6555
-#: config/rs6000/rs6000-c.c:6916 config/rs6000/rs6000-c.c:6963
+#: config/rs6000/rs6000-c.c:6166 config/rs6000/rs6000-c.c:6217
+#: config/rs6000/rs6000-c.c:6487 config/rs6000/rs6000-c.c:6553
+#: config/rs6000/rs6000-c.c:6914 config/rs6000/rs6000-c.c:6961
 #, gcc-internal-format
 msgid "builtin %qs only accepts 2 arguments"
 msgstr "el interno %qs sólo acepta 2 argumentos"
 
-#: config/rs6000/rs6000-c.c:6292 config/rs6000/rs6000-c.c:6375
-#: config/rs6000/rs6000-c.c:6736
+#: config/rs6000/rs6000-c.c:6290 config/rs6000/rs6000-c.c:6373
+#: config/rs6000/rs6000-c.c:6734
 #, gcc-internal-format
 msgid "builtin %qs only accepts 3 arguments"
 msgstr "el interno %qs solo acepta 3 argumentos"
 
-#: config/rs6000/rs6000-c.c:6484
+#: config/rs6000/rs6000-c.c:6482
 #, gcc-internal-format
 msgid "builtin %qs only accepts 1 argument"
 msgstr "el interno %qs solo acepta 1 argumento"
 
-#: config/rs6000/rs6000-c.c:7054
+#: config/rs6000/rs6000-c.c:7052
 #, gcc-internal-format
 msgid "builtin %qs requires builtin %qs"
 msgstr "la función interna %qs requiere la función interna %qs"
 
-#: config/rs6000/rs6000-c.c:7058
+#: config/rs6000/rs6000-c.c:7056
 #, gcc-internal-format
 msgid "builtin function %qs not supported in this compiler configuration"
 msgstr "no se admite la función interna %s en esta configuración del compilador"
 
-#: config/rs6000/rs6000-c.c:7068
+#: config/rs6000/rs6000-c.c:7066
 #, gcc-internal-format
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr "combinación de parámetros no válida para el intrínseco AltiVec %qs"
 
-#: config/rs6000/rs6000.c:3754 config/rs6000/rs6000.c:3757
-#: config/rs6000/rs6000.c:3760
+#: config/rs6000/rs6000.c:3772 config/rs6000/rs6000.c:3775
+#: config/rs6000/rs6000.c:3778
 #, gcc-internal-format
 msgid "%qs requires %qs or %qs"
 msgstr "%qs requiere %qs o %qs"
 
-#: config/rs6000/rs6000.c:3861
+#: config/rs6000/rs6000.c:3879
 #, gcc-internal-format
 msgid "%qs requires PowerPC64 architecture, enabling"
 msgstr "%qs requiere la arquitectura PowerPC64, activando"
 
-#: config/rs6000/rs6000.c:4037
+#: config/rs6000/rs6000.c:4057
 #, gcc-internal-format
 msgid "%qs command-line option is deprecated"
 msgstr "la opción de la línea de órdenes %qs es obsoleta"
 
-#: config/rs6000/rs6000.c:4048
+#: config/rs6000/rs6000.c:4068
 #, gcc-internal-format
 msgid "%qs is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr "no se admite %qs para Darwin de 64 bits; es incompatible con las bibliotecas C y C++ instaladas"
 
-#: config/rs6000/rs6000.c:4147
+#: config/rs6000/rs6000.c:4167
 #, gcc-internal-format
 msgid "will not generate %qs instructions because assembler lacks %qs support"
 msgstr "no generará instrucciones %qsporque el ensamblador no admite %qs"
 
-#: config/rs6000/rs6000.c:4240
+#: config/rs6000/rs6000.c:4260
 #, gcc-internal-format
 msgid "%qs is not supported on little endian systems"
 msgstr "no se admite %qs en sistemas little endian"
 
-#: config/rs6000/rs6000.c:4333
+#: config/rs6000/rs6000.c:4353
 #, gcc-internal-format
 msgid "power9 target option is incompatible with %<%s=<xxx>%> for <xxx> less than power9"
 msgstr "la opción del objetivo power9 es incompatible con %<%s=<xxx%> para <xxx> menor que power9"
@@ -32156,7 +32204,7 @@
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:4341
+#: config/rs6000/rs6000.c:4361
 #, gcc-internal-format
 msgid "%qs incompatible with explicitly disabled options"
 msgstr "%qs es incompatible con las opciones desactivadas explícitamente"
@@ -32165,240 +32213,241 @@
 #. error messages.  However, if users have managed to select
 #. power9-fusion without selecting power8-fusion, they
 #. already know about undocumented flags.
-#: config/rs6000/rs6000.c:4366 config/rs6000/rs6000.c:4373
-#: config/rs6000/rs6000.c:4380 config/rs6000/rs6000.c:4388
-#: config/rs6000/rs6000.c:4407 config/rs6000/rs6000.c:4464
-#: config/rs6000/rs6000.c:4468 config/rs6000/rs6000.c:4485
-#: config/rs6000/rs6000.c:4538 config/rs6000/rs6000.c:4565
-#: config/rs6000/rs6000.c:4580 config/rs6000/rs6000.c:4588
-#: config/rs6000/rs6000.c:4684
+#: config/rs6000/rs6000.c:4386 config/rs6000/rs6000.c:4393
+#: config/rs6000/rs6000.c:4400 config/rs6000/rs6000.c:4408
+#: config/rs6000/rs6000.c:4427 config/rs6000/rs6000.c:4484
+#: config/rs6000/rs6000.c:4488 config/rs6000/rs6000.c:4505
+#: config/rs6000/rs6000.c:4558 config/rs6000/rs6000.c:4585
+#: config/rs6000/rs6000.c:4600 config/rs6000/rs6000.c:4608
+#: config/rs6000/rs6000.c:4709
 #, gcc-internal-format
 msgid "%qs requires %qs"
 msgstr "%qs requiere %qs"
 
-#: config/rs6000/rs6000.c:4625
+#: config/rs6000/rs6000.c:4650
 #, gcc-internal-format
 msgid "Using IEEE extended precision long double"
 msgstr "Se usa long double de precisión extendida de IEEE"
 
-#: config/rs6000/rs6000.c:4627
+#: config/rs6000/rs6000.c:4652
 #, gcc-internal-format
 msgid "Using IBM extended precision long double"
 msgstr "Se usa long double de precisión extendida de IBM"
 
-#: config/rs6000/rs6000.c:4644
+#: config/rs6000/rs6000.c:4669
 #, gcc-internal-format
 msgid "%qs requires VSX support"
 msgstr "%qs necesita soporte para VSX"
 
-#: config/rs6000/rs6000.c:4653
+#: config/rs6000/rs6000.c:4678
 #, gcc-internal-format
 msgid "The -mfloat128 option may not be fully supported"
 msgstr "Es posible que la opción -mfloat128 no funcione perfectamente"
 
-#: config/rs6000/rs6000.c:4676
+#: config/rs6000/rs6000.c:4701
 #, gcc-internal-format
 msgid "%qs requires full ISA 3.0 support"
 msgstr "%qs requiere suporte pleno de ISA 3.0"
 
-#: config/rs6000/rs6000.c:4743
+#: config/rs6000/rs6000.c:4768
 #, gcc-internal-format
 msgid "unknown vectorization library ABI type (%qs) for %qs switch"
 msgstr "tipo de ABI de biblioteca de vectorización desconocida (%qs) para la opción %qs"
 
-#: config/rs6000/rs6000.c:4930
+#: config/rs6000/rs6000.c:4955
 #, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr "%qs no es un número válido en %qs"
 
-#: config/rs6000/rs6000.c:4935
+#: config/rs6000/rs6000.c:4960
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr "%qs no es un desplazamiento válido en %qs"
 
-#: config/rs6000/rs6000.c:4947
+#: config/rs6000/rs6000.c:4972
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %qs"
 msgstr "%qs no es un registro base válido en %qs"
 
-#: config/rs6000/rs6000.c:4955
+#: config/rs6000/rs6000.c:4980
 #, gcc-internal-format
 msgid "%qs needs a valid base register"
 msgstr "%qs necesita un registro bae válido"
 
-#: config/rs6000/rs6000.c:5253
+#: config/rs6000/rs6000.c:5278
 #, gcc-internal-format
 msgid "unknown option for %<%s=%s%>"
 msgstr "opción desconocida para %<%s=%s%>"
 
-#: config/rs6000/rs6000.c:5290
+#: config/rs6000/rs6000.c:5315
 #, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr "%qs está obsoleto y no está recomendada bajo ninguna circunstancia"
 
-#: config/rs6000/rs6000.c:11401
+#: config/rs6000/rs6000.c:11439
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr "no se puede devolver un valor en el registro vector porque las instrucciones altivec están desactivadas, use %qs para activarlas"
 
-#: config/rs6000/rs6000.c:11862
+#: config/rs6000/rs6000.c:11906
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr "no se puede pasar argumentos en el registro vector porque las instrucciones altivec están desactivadas, use %qs para activarlas"
 
-#: config/rs6000/rs6000.c:13572
+#: config/rs6000/rs6000.c:13616
 #, gcc-internal-format
 msgid "internal error: builtin function %qs already processed"
 msgstr "error interno: la función interna %qs ya se procesó"
 
-#: config/rs6000/rs6000.c:14150
+#: config/rs6000/rs6000.c:14194
 #, gcc-internal-format
 msgid "argument 2 must be a 1-bit unsigned literal"
 msgstr "el argumento 2 debe ser un literal sin signo de 1 bit"
 
-#: config/rs6000/rs6000.c:14189
+#: config/rs6000/rs6000.c:14233
 #, gcc-internal-format
 msgid "argument 1 of %qs must be a constant"
 msgstr "el argumento 1 de %qs debe ser constante"
 
-#: config/rs6000/rs6000.c:14247 config/rs6000/rs6000.c:15898
+#: config/rs6000/rs6000.c:14291 config/rs6000/rs6000.c:15942
 #, gcc-internal-format
 msgid "argument 1 of %qs is out of range"
 msgstr "el argumento 1 de %qs está fuera de rango"
 
-#: config/rs6000/rs6000.c:14742
+#: config/rs6000/rs6000.c:14786
 #, gcc-internal-format
 msgid "builtin %qs is only valid in 64-bit mode"
 msgstr "el interno %qs solo es válido en el modo de 64 bits"
 
-#: config/rs6000/rs6000.c:14939
+#: config/rs6000/rs6000.c:14983
 #, gcc-internal-format
 msgid "builtin %qs only accepts a string argument"
 msgstr "el interno %qs sólo acepta un argumento de cadena"
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000.c:14958
+#: config/rs6000/rs6000.c:15002
 #, gcc-internal-format
 msgid "cpu %qs is an invalid argument to builtin %qs"
 msgstr "la cpu %qs es un argumento no válido para el interno %qs"
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000.c:14986
+#: config/rs6000/rs6000.c:15030
 #, gcc-internal-format
 msgid "%s %qs is an invalid argument to builtin %qs"
 msgstr "%s %qs es un argumento no válido para el interno %qs"
 
-#: config/rs6000/rs6000.c:15012
+#: config/rs6000/rs6000.c:15056
 #, gcc-internal-format
 msgid "builtin %qs needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15616
+#: config/rs6000/rs6000.c:15660
 #, gcc-internal-format
 msgid "second argument to %qs must be 0..12"
 msgstr "el segundo argumento de %qs debe estar en 0..12"
 
-#: config/rs6000/rs6000.c:15631
+#: config/rs6000/rs6000.c:15675
 #, gcc-internal-format
 msgid "third argument to %qs must be 0..12"
 msgstr "el tercer argumento de %qs debe estar en 0..12"
 
-#: config/rs6000/rs6000.c:15850
+#: config/rs6000/rs6000.c:15894
 #, gcc-internal-format, gfc-internal-format
 msgid "argument 1 of %s must be a constant"
 msgstr "el argumento 1 de %s debe ser una constante"
 
-#: config/rs6000/rs6000.c:15932
+#: config/rs6000/rs6000.c:15976
 #, gcc-internal-format
 msgid "builtin function %qs is only valid for the cell processor"
 msgstr "la función interna %qs solo es válida para el procesador cell"
 
-#: config/rs6000/rs6000.c:15934 config/rs6000/rs6000.c:15936
-#: config/rs6000/rs6000.c:15938 config/rs6000/rs6000.c:15940
-#: config/rs6000/rs6000.c:15946 config/rs6000/rs6000.c:15948
-#: config/rs6000/rs6000.c:15955 config/rs6000/rs6000.c:15962
-#: config/rs6000/rs6000.c:15969 config/rs6000/rs6000.c:15975
+#: config/rs6000/rs6000.c:15978 config/rs6000/rs6000.c:15980
+#: config/rs6000/rs6000.c:15982 config/rs6000/rs6000.c:15984
+#: config/rs6000/rs6000.c:15990 config/rs6000/rs6000.c:15992
+#: config/rs6000/rs6000.c:15999 config/rs6000/rs6000.c:16006
+#: config/rs6000/rs6000.c:16011 config/rs6000/rs6000.c:16014
+#: config/rs6000/rs6000.c:16018 config/rs6000/rs6000.c:16024
 #, gcc-internal-format
 msgid "builtin function %qs requires the %qs option"
 msgstr "la función interna %qs requiere la opción %qs"
 
-#: config/rs6000/rs6000.c:15943 config/rs6000/rs6000.c:15952
-#: config/rs6000/rs6000.c:15959 config/rs6000/rs6000.c:15966
+#: config/rs6000/rs6000.c:15987 config/rs6000/rs6000.c:15996
+#: config/rs6000/rs6000.c:16003
 #, gcc-internal-format
 msgid "builtin function %qs requires the %qs and %qs options"
 msgstr "la función interna %qs requiere las opciones %qs y %qs"
 
-#: config/rs6000/rs6000.c:15972
+#: config/rs6000/rs6000.c:16021
 #, gcc-internal-format
 msgid "builtin function %qs requires ISA 3.0 IEEE 128-bit floating point"
 msgstr "la función interna %qs requiere requiere coma flotante de 128 bits del IEEE de ISA 3.0"
 
-#: config/rs6000/rs6000.c:15978
+#: config/rs6000/rs6000.c:16027
 #, gcc-internal-format
 msgid "builtin function %qs requires the %qs (or newer), and %qs or %qs options"
 msgstr "la función interna %qs requiere las opciones %qs (o más reciente), y %qs o %qs"
 
-#: config/rs6000/rs6000.c:15982
+#: config/rs6000/rs6000.c:16031
 #, gcc-internal-format
 msgid "builtin function %qs is not supported with the current options"
 msgstr "la función interna %qs no se admite con las opciones actuales"
 
-#: config/rs6000/rs6000.c:18218
+#: config/rs6000/rs6000.c:18290
 #, gcc-internal-format
 msgid "internal error: builtin function %qs had an unexpected return type %qs"
 msgstr "error interno: la función interna %qs tiene un tipo de devolución inesperado %qs"
 
-#: config/rs6000/rs6000.c:18235
+#: config/rs6000/rs6000.c:18307
 #, gcc-internal-format
 msgid "internal error: builtin function %qs, argument %d had unexpected argument type %qs"
 msgstr "error interno: función interna %qs, el argumento %d tiene el tipo de argumento inesperado %qs"
 
-#: config/rs6000/rs6000.c:29451
+#: config/rs6000/rs6000.c:29528
 #, gcc-internal-format
 msgid "%qs uses register r29"
 msgstr "%qs usa el registro r29"
 
-#: config/rs6000/rs6000.c:32748
+#: config/rs6000/rs6000.c:32825
 #, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "no se puede tomar la dirección de una función anindada si se usa la opción %qs"
 
-#: config/rs6000/rs6000.c:32842
+#: config/rs6000/rs6000.c:32919
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "el uso de %<long%> en tipos AltiVec no es válido para código de 64 bits sin %qs"
 
-#: config/rs6000/rs6000.c:32850
+#: config/rs6000/rs6000.c:32927
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "el uso de %<long long%> en tipos AltiVec no es válido sin %qs"
 
-#: config/rs6000/rs6000.c:32853
+#: config/rs6000/rs6000.c:32930
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "el uso de %<double%> en tipos AltiVec no es válido sin %qs"
 
-#: config/rs6000/rs6000.c:36876
+#: config/rs6000/rs6000.c:36932
 #, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "cpu %qs no válida para %s%qs%s"
 
-#: config/rs6000/rs6000.c:36879
+#: config/rs6000/rs6000.c:36935
 #, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr "%s%qs%s no está permitido"
 
-#: config/rs6000/rs6000.c:36881
+#: config/rs6000/rs6000.c:36937
 #, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr "%s%qs%s no es válido"
 
-#: config/rs6000/rs6000.c:37416
+#: config/rs6000/rs6000.c:37472
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr "%<-mno=%s%> anula %<-m%s%>"
 
-#: config/rs6000/rs6000.c:37575
+#: config/rs6000/rs6000.c:37631
 #, gcc-internal-format
 msgid "target_clones attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
@@ -33138,49 +33187,49 @@
 msgid "subprogram %q+F not marked Inline"
 msgstr "el subprograma %q+F no está marcado Inline"
 
-#: ada/gcc-interface/trans.c:6404
+#: ada/gcc-interface/trans.c:6401
 #, gcc-internal-format
 msgid "out-of-bounds access may be optimized away"
 msgstr ""
 
-#: ada/gcc-interface/trans.c:6406
+#: ada/gcc-interface/trans.c:6403
 #, fuzzy, gcc-internal-format
 #| msgid "%<continue%> must be in loop"
 msgid "containing loop"
 msgstr "%<continue%> debe estar dentro de un bucle"
 
-#: ada/gcc-interface/utils.c:3887
+#: ada/gcc-interface/utils.c:3890
 #, gcc-internal-format
 msgid "invalid element type for attribute %qs"
 msgstr "tipo de elemento no válido para el atributo %qs"
 
-#: ada/gcc-interface/utils.c:3911
+#: ada/gcc-interface/utils.c:3914
 #, gcc-internal-format
 msgid "number of components of vector not a power of two"
 msgstr "el número de componentes de vector no es una potencia de dos"
 
-#: ada/gcc-interface/utils.c:6037 ada/gcc-interface/utils.c:6215
-#: ada/gcc-interface/utils.c:6322
+#: ada/gcc-interface/utils.c:6043 ada/gcc-interface/utils.c:6220
+#: ada/gcc-interface/utils.c:6327
 #, gcc-internal-format
 msgid "%qs attribute ignored"
 msgstr "se descarta el atributo %qs"
 
-#: ada/gcc-interface/utils.c:6158
+#: ada/gcc-interface/utils.c:6164
 #, gcc-internal-format
 msgid "%qs attribute requires prototypes with named arguments"
 msgstr "el atributo %qs requiere prototipos con argumentos nombrados"
 
-#: ada/gcc-interface/utils.c:6167
+#: ada/gcc-interface/utils.c:6173
 #, gcc-internal-format
 msgid "%qs attribute only applies to variadic functions"
 msgstr "el atributo %qs se aplica solamente a funciones variadic"
 
-#: ada/gcc-interface/utils.c:6282
+#: ada/gcc-interface/utils.c:6287
 #, gcc-internal-format
 msgid "%qE attribute has no effect"
 msgstr "el atributo %qE no tiene efecto"
 
-#: ada/gcc-interface/utils.c:6406
+#: ada/gcc-interface/utils.c:6411
 #, gcc-internal-format
 msgid "attribute %qs applies to array types only"
 msgstr "el atributo %qs solamente se aplica a tipos de matriz"
@@ -33195,7 +33244,7 @@
 #. an unprototyped function, it is compile-time undefined;
 #. making it a constraint in that case was rejected in
 #. DR#252.
-#: c/c-convert.c:101 c/c-typeck.c:2175 c/c-typeck.c:6507 c/c-typeck.c:12138
+#: c/c-convert.c:101 c/c-typeck.c:2175 c/c-typeck.c:6512 c/c-typeck.c:12143
 #: cp/typeck.c:2027 cp/typeck.c:7977 cp/typeck.c:8742
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
@@ -33256,7 +33305,7 @@
 msgid "type of array %q+D completed incompatibly with implicit initialization"
 msgstr "el tipo de la matriz %q+D se completó de forma incompatible con la inicialización implícita"
 
-#: c/c-decl.c:1567 c/c-decl.c:6701 c/c-decl.c:7574 c/c-decl.c:8381
+#: c/c-decl.c:1567 c/c-decl.c:6721 c/c-decl.c:7594 c/c-decl.c:8401
 #, gcc-internal-format
 msgid "originally defined here"
 msgstr "se definió originalmente aquí"
@@ -33661,16 +33710,11 @@
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.c:4548 c/c-decl.c:7147
+#: c/c-decl.c:4548 c/c-decl.c:7167
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr "no se permite %<[*]%> en otro lugar que no sea el ámbido de prototipo de función"
 
-#: c/c-decl.c:4635 cp/decl2.c:1520
-#, gcc-internal-format
-msgid "%q+D in declare target directive does not have mappable type"
-msgstr ""
-
 #: c/c-decl.c:4693
 #, gcc-internal-format
 msgid "%q+D is usually a function"
@@ -33696,7 +33740,7 @@
 #. of VLAs themselves count as VLAs, it does not make
 #. sense to permit them to be initialized given that
 #. ordinary VLAs may not be initialized.
-#: c/c-decl.c:4732 c/c-decl.c:4747 c/c-typeck.c:7630
+#: c/c-decl.c:4732 c/c-decl.c:4747 c/c-typeck.c:7635
 #, gcc-internal-format
 msgid "variable-sized object may not be initialized"
 msgstr "un objeto de tamaño variable puede no ser inicializado"
@@ -33756,203 +33800,208 @@
 msgid "uninitialized const %qD is invalid in C++"
 msgstr "const %qD sin inicializar es no válida en C++"
 
-#: c/c-decl.c:5268
+#: c/c-decl.c:5224 cp/decl.c:7318
 #, gcc-internal-format
+msgid "%q+D in declare target directive does not have mappable type"
+msgstr ""
+
+#: c/c-decl.c:5288
+#, gcc-internal-format
 msgid "ISO C forbids forward parameter declarations"
 msgstr "ISO C prohíbe declaraciones adelantadas de parámetros"
 
-#: c/c-decl.c:5371
+#: c/c-decl.c:5391
 #, gcc-internal-format
 msgid "defining a type in a compound literal is invalid in C++"
 msgstr "definir un tipo en una literal compuesta es no válido en C++"
 
-#: c/c-decl.c:5425 c/c-decl.c:5440
+#: c/c-decl.c:5445 c/c-decl.c:5460
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant"
 msgstr "la anchura del campo de bits %qs no es una constante entera"
 
-#: c/c-decl.c:5435
+#: c/c-decl.c:5455
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant expression"
 msgstr "la anchura del campo de bits %qs no es una expresión constante entera"
 
-#: c/c-decl.c:5446
+#: c/c-decl.c:5466
 #, gcc-internal-format
 msgid "negative width in bit-field %qs"
 msgstr "anchura negativa en el campo de bit %qs"
 
-#: c/c-decl.c:5451
+#: c/c-decl.c:5471
 #, gcc-internal-format
 msgid "zero width for bit-field %qs"
 msgstr "anchura cero para el campo de bits %qs"
 
-#: c/c-decl.c:5461
+#: c/c-decl.c:5481
 #, gcc-internal-format
 msgid "bit-field %qs has invalid type"
 msgstr "el campo de bits %qs tiene un tipo no válido"
 
-#: c/c-decl.c:5467
+#: c/c-decl.c:5487
 #, gcc-internal-format
 msgid "cannot declare bit-field %qs with %<warn_if_not_aligned%> type"
 msgstr "no se puede declarar el campo de bits %qs con un tipo %<warn_if_not_aligned%>"
 
-#: c/c-decl.c:5478
+#: c/c-decl.c:5498
 #, gcc-internal-format
 msgid "type of bit-field %qs is a GCC extension"
 msgstr "el tipo de campo de bits %qs es una extensión de GCC"
 
-#: c/c-decl.c:5484
+#: c/c-decl.c:5504
 #, gcc-internal-format
 msgid "width of %qs exceeds its type"
 msgstr "la anchura de %qs excede su tipo"
 
-#: c/c-decl.c:5497
+#: c/c-decl.c:5517
 #, gcc-internal-format
 msgid "%qs is narrower than values of its type"
 msgstr "%qs es más estrecho que los valores de su tipo"
 
-#: c/c-decl.c:5512
+#: c/c-decl.c:5532
 #, gcc-internal-format
 msgid "ISO C90 forbids array %qE whose size can%'t be evaluated"
 msgstr "ISO C90 prohíbe la matriz %qE cuyo tamaño no se puede evaluar"
 
-#: c/c-decl.c:5515
+#: c/c-decl.c:5535
 #, gcc-internal-format
 msgid "ISO C90 forbids array whose size can%'t be evaluated"
 msgstr "ISO C90 prohíbe la matriz cuyo tamaño no se puede evaluar"
 
-#: c/c-decl.c:5522
+#: c/c-decl.c:5542
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array %qE"
 msgstr "ISO C90 prohíbe la matriz de longitud variable %qE"
 
-#: c/c-decl.c:5524
+#: c/c-decl.c:5544
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array"
 msgstr "ISO C90 prohíbe la matriz de longitud variable"
 
-#: c/c-decl.c:5733 c/c-decl.c:6107 c/c-decl.c:6117
+#: c/c-decl.c:5753 c/c-decl.c:6127 c/c-decl.c:6137
 #, gcc-internal-format
 msgid "variably modified %qE at file scope"
 msgstr "%qE variablemente modificado en el ámbito del fichero"
 
-#: c/c-decl.c:5735
+#: c/c-decl.c:5755
 #, gcc-internal-format
 msgid "variably modified field at file scope"
 msgstr "campo variablemente modificado en el ámbito del fichero"
 
-#: c/c-decl.c:5755
+#: c/c-decl.c:5775
 #, gcc-internal-format
 msgid "type defaults to %<int%> in declaration of %qE"
 msgstr "el tipo de dato por defecto es %<int%> en la declaración de %qE"
 
-#: c/c-decl.c:5759
+#: c/c-decl.c:5779
 #, gcc-internal-format
 msgid "type defaults to %<int%> in type name"
 msgstr "el tipo de dato por defecto es %<int%> en el nombre de tipo"
 
-#: c/c-decl.c:5791
+#: c/c-decl.c:5811
 #, gcc-internal-format
 msgid "duplicate %<const%>"
 msgstr "%<const%> duplicado"
 
-#: c/c-decl.c:5793
+#: c/c-decl.c:5813
 #, gcc-internal-format
 msgid "duplicate %<restrict%>"
 msgstr "%<restrict%> duplicado"
 
-#: c/c-decl.c:5795
+#: c/c-decl.c:5815
 #, gcc-internal-format
 msgid "duplicate %<volatile%>"
 msgstr "%<volatile%> duplicado"
 
-#: c/c-decl.c:5797
+#: c/c-decl.c:5817
 #, gcc-internal-format
 msgid "duplicate %<_Atomic%>"
 msgstr "%<_Atomic%> duplicado"
 
-#: c/c-decl.c:5800
+#: c/c-decl.c:5820
 #, gcc-internal-format, gfc-internal-format
 msgid "conflicting named address spaces (%s vs %s)"
 msgstr "espacios de direcciones nombrados generan un conflicto (%s vs %s)"
 
-#: c/c-decl.c:5823 c/c-parser.c:2821
+#: c/c-decl.c:5843 c/c-parser.c:2821
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified array type"
 msgstr "tipo matriz cualificado %<_Atomic%>"
 
-#: c/c-decl.c:5837
+#: c/c-decl.c:5857
 #, gcc-internal-format
 msgid "function definition declared %<auto%>"
 msgstr "la definición de la función se declaró como %<auto%>"
 
-#: c/c-decl.c:5839
+#: c/c-decl.c:5859
 #, gcc-internal-format
 msgid "function definition declared %<register%>"
 msgstr "la definición de la función se declaró como %<register%>"
 
-#: c/c-decl.c:5841
+#: c/c-decl.c:5861
 #, gcc-internal-format
 msgid "function definition declared %<typedef%>"
 msgstr "la definición de la función se declaró como %<typedef%>"
 
-#: c/c-decl.c:5843
+#: c/c-decl.c:5863
 #, fuzzy, gcc-internal-format
 #| msgid "function definition declared %<auto%>"
 msgid "function definition declared %qs"
 msgstr "la definición de la función se declaró como %<auto%>"
 
-#: c/c-decl.c:5861
+#: c/c-decl.c:5881
 #, gcc-internal-format
 msgid "storage class specified for structure field %qE"
 msgstr "se especificó una clase de almacenamiento para el campo de la estructura %qE"
 
-#: c/c-decl.c:5864
+#: c/c-decl.c:5884
 #, gcc-internal-format
 msgid "storage class specified for structure field"
 msgstr "se especificó una clase de almacenamiento para el campo de la estructura"
 
-#: c/c-decl.c:5868
+#: c/c-decl.c:5888
 #, gcc-internal-format
 msgid "storage class specified for parameter %qE"
 msgstr "se especificó una clase de almacenamiento para el parámetro %qE"
 
-#: c/c-decl.c:5871
+#: c/c-decl.c:5891
 #, gcc-internal-format
 msgid "storage class specified for unnamed parameter"
 msgstr "se especificó una clase de almacenamiento para un parámetro sin nombre"
 
-#: c/c-decl.c:5874 cp/decl.c:10935
+#: c/c-decl.c:5894 cp/decl.c:10959
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "se especificó una clase de almacenamiento para el nombre de tipo"
 
-#: c/c-decl.c:5891
+#: c/c-decl.c:5911
 #, gcc-internal-format
 msgid "%qE initialized and declared %<extern%>"
 msgstr "%qE se inicializó y declaró como %<extern%>"
 
-#: c/c-decl.c:5895
+#: c/c-decl.c:5915
 #, gcc-internal-format
 msgid "%qE has both %<extern%> and initializer"
 msgstr "%qE tiene %<extern%> e inicializador al mismo tiempo"
 
-#: c/c-decl.c:5900
+#: c/c-decl.c:5920
 #, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<auto%>"
 msgstr "la declaración del ámbito de fichero de %qE especifica %<auto%>"
 
-#: c/c-decl.c:5904
+#: c/c-decl.c:5924
 #, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<register%>"
 msgstr "la declaración del ámbito de fichero de %qE especifica %<register%>"
 
-#: c/c-decl.c:5909
+#: c/c-decl.c:5929
 #, gcc-internal-format
 msgid "nested function %qE declared %<extern%>"
 msgstr "la función anidada %qE se declaró %<extern%>"
 
-#: c/c-decl.c:5912
+#: c/c-decl.c:5932
 #, gcc-internal-format
 msgid "function-scope %qE implicitly auto and declared %qs"
 msgstr "el ámbito de la función %qE es implícitamente auto y declarado %qs"
@@ -33960,702 +34009,702 @@
 #. Only the innermost declarator (making a parameter be of
 #. array type which is converted to pointer type)
 #. may have static or type qualifiers.
-#: c/c-decl.c:5959 c/c-decl.c:6328
+#: c/c-decl.c:5979 c/c-decl.c:6348
 #, gcc-internal-format
 msgid "static or type qualifiers in non-parameter array declarator"
 msgstr "static o calificadores de tipo en un declarador de matriz que no es parámetro"
 
-#: c/c-decl.c:6007
+#: c/c-decl.c:6027
 #, gcc-internal-format
 msgid "declaration of %qE as array of voids"
 msgstr "la declaración de %qE como una matriz de voids"
 
-#: c/c-decl.c:6009
+#: c/c-decl.c:6029
 #, gcc-internal-format
 msgid "declaration of type name as array of voids"
 msgstr "declaración de nombre de tipo como una matriz de voids"
 
-#: c/c-decl.c:6016
+#: c/c-decl.c:6036
 #, gcc-internal-format
 msgid "declaration of %qE as array of functions"
 msgstr "declaración de %qE como una matriz de funciones"
 
-#: c/c-decl.c:6019
+#: c/c-decl.c:6039
 #, gcc-internal-format
 msgid "declaration of type name as array of functions"
 msgstr "declaración de nombre de tipo como una matriz de funciones"
 
-#: c/c-decl.c:6027 c/c-decl.c:8085
+#: c/c-decl.c:6047 c/c-decl.c:8105
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr "uso no válido de una estructura con un miembro de matriz flexible"
 
-#: c/c-decl.c:6053
+#: c/c-decl.c:6073
 #, gcc-internal-format
 msgid "size of array %qE has non-integer type"
 msgstr "el tamaño de la matriz %qE es de un tipo no entero"
 
-#: c/c-decl.c:6057
+#: c/c-decl.c:6077
 #, gcc-internal-format
 msgid "size of unnamed array has non-integer type"
 msgstr "el tamaño de la matriz sin nombre es de un tipo no entero"
 
-#: c/c-decl.c:6064
+#: c/c-decl.c:6084
 #, gcc-internal-format
 msgid "size of array %qE has incomplete type"
 msgstr "el tamaño de la matriz %qE es de un tipo incompleto"
 
-#: c/c-decl.c:6067
+#: c/c-decl.c:6087
 #, gcc-internal-format
 msgid "size of unnamed array has incomplete type"
 msgstr "el tamaño de la matriz sin nombre es de un tipo incompleto"
 
-#: c/c-decl.c:6078
+#: c/c-decl.c:6098
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array %qE"
 msgstr "ISO C prohíbe la matriz %qE de tamaño cero"
 
-#: c/c-decl.c:6081
+#: c/c-decl.c:6101
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array"
 msgstr "ISO C prohíbe matrices de tamaño cero"
 
-#: c/c-decl.c:6090
+#: c/c-decl.c:6110
 #, gcc-internal-format
 msgid "size of array %qE is negative"
 msgstr "el tamaño de la matriz %qE es negativo"
 
-#: c/c-decl.c:6092
+#: c/c-decl.c:6112
 #, gcc-internal-format
 msgid "size of unnamed array is negative"
 msgstr "el tamaño de la matriz sin nombre es negativo"
 
-#: c/c-decl.c:6216 c/c-decl.c:6871
+#: c/c-decl.c:6236 c/c-decl.c:6891
 #, gcc-internal-format
 msgid "ISO C90 does not support flexible array members"
 msgstr "ISO C90 no admite miembros de matriz flexibles"
 
 #. C99 6.7.5.2p4
-#: c/c-decl.c:6238
+#: c/c-decl.c:6258
 #, gcc-internal-format
 msgid "%<[*]%> not in a declaration"
 msgstr "%<[*]%> fuera de una declaración"
 
-#: c/c-decl.c:6251
+#: c/c-decl.c:6271
 #, gcc-internal-format
 msgid "array type has incomplete element type %qT"
 msgstr "el tipo matriz tiene tipo de elemento %qT incompleto"
 
-#: c/c-decl.c:6257
+#: c/c-decl.c:6277
 #, gcc-internal-format
 msgid "declaration of %qE as multidimensional array must have bounds for all dimensions except the first"
 msgstr "la declaración de %qE como una matriz multidimensional debe tener límites para todas las dimensiones excepto la primera"
 
-#: c/c-decl.c:6261
+#: c/c-decl.c:6281
 #, gcc-internal-format
 msgid "declaration of multidimensional array must have bounds for all dimensions except the first"
 msgstr "la declaración de una matriz multidimensional debe tener límites para todas las dimensiones excepto la primera"
 
-#: c/c-decl.c:6364
+#: c/c-decl.c:6384
 #, gcc-internal-format
 msgid "%qE declared as function returning a function"
 msgstr "%qE que se declaró como función devuelve una función"
 
-#: c/c-decl.c:6367
+#: c/c-decl.c:6387
 #, gcc-internal-format
 msgid "type name declared as function returning a function"
 msgstr "el nombre de tipo que se declaró como función devuelve una función"
 
-#: c/c-decl.c:6374
+#: c/c-decl.c:6394
 #, gcc-internal-format
 msgid "%qE declared as function returning an array"
 msgstr "%qE que se declaró como función devuelve una matriz"
 
-#: c/c-decl.c:6377
+#: c/c-decl.c:6397
 #, gcc-internal-format
 msgid "type name declared as function returning an array"
 msgstr "el nombre de tipo que se declaró como función devuelve una matriz"
 
-#: c/c-decl.c:6418
+#: c/c-decl.c:6438
 #, gcc-internal-format
 msgid "function definition has qualified void return type"
 msgstr "la definición de la función tiene un tipo de devolución void calificado"
 
-#: c/c-decl.c:6421 cp/decl.c:11201
+#: c/c-decl.c:6441 cp/decl.c:11225
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "se descartan los calificadores de tipo en el tipo de devolución de la función"
 
-#: c/c-decl.c:6459 c/c-decl.c:6668 c/c-decl.c:6721 c/c-decl.c:6805
-#: c/c-decl.c:6926 c/c-parser.c:2823
+#: c/c-decl.c:6479 c/c-decl.c:6688 c/c-decl.c:6741 c/c-decl.c:6825
+#: c/c-decl.c:6946 c/c-parser.c:2823
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified function type"
 msgstr "tipo de función calificada %<_Atomic%>"
 
-#: c/c-decl.c:6465 c/c-decl.c:6674 c/c-decl.c:6810 c/c-decl.c:6931
+#: c/c-decl.c:6485 c/c-decl.c:6694 c/c-decl.c:6830 c/c-decl.c:6951
 #, gcc-internal-format
 msgid "ISO C forbids qualified function types"
 msgstr "ISO C prohíbe los tipos de función calificados"
 
-#: c/c-decl.c:6559
+#: c/c-decl.c:6579
 #, gcc-internal-format
 msgid "%qs combined with %<auto%> qualifier for %qE"
 msgstr "%qs combinado con el calificador %<auto%> para %qE"
 
-#: c/c-decl.c:6563
+#: c/c-decl.c:6583
 #, gcc-internal-format
 msgid "%qs combined with %<register%> qualifier for %qE"
 msgstr "%qs combinado con el calificador %<register%> para %qE"
 
-#: c/c-decl.c:6569
+#: c/c-decl.c:6589
 #, gcc-internal-format
 msgid "%qs specified for auto variable %qE"
 msgstr "se especificó %qs para la variable auto %qE"
 
-#: c/c-decl.c:6585
+#: c/c-decl.c:6605
 #, gcc-internal-format
 msgid "%qs specified for parameter %qE"
 msgstr "se especificó %qs para el parámetro %qE"
 
-#: c/c-decl.c:6588
+#: c/c-decl.c:6608
 #, gcc-internal-format
 msgid "%qs specified for unnamed parameter"
 msgstr "se especificó %qs para el parámetro sin nombre"
 
-#: c/c-decl.c:6594
+#: c/c-decl.c:6614
 #, gcc-internal-format
 msgid "%qs specified for structure field %qE"
 msgstr "se especificó %qs para el campo de estructura %qE"
 
-#: c/c-decl.c:6597
+#: c/c-decl.c:6617
 #, gcc-internal-format
 msgid "%qs specified for structure field"
 msgstr "se especificó %qs para el campo de estructura"
 
-#: c/c-decl.c:6612
+#: c/c-decl.c:6632
 #, gcc-internal-format
 msgid "bit-field %qE has atomic type"
 msgstr "el campo de bits %qE tiene un tipo atómico"
 
-#: c/c-decl.c:6614
+#: c/c-decl.c:6634
 #, gcc-internal-format
 msgid "bit-field has atomic type"
 msgstr "el campo de bits tiene un tipo no atómico"
 
-#: c/c-decl.c:6623
+#: c/c-decl.c:6643
 #, gcc-internal-format
 msgid "alignment specified for typedef %qE"
 msgstr "se especificó la alineación para la definición de tipo %qE"
 
-#: c/c-decl.c:6625
+#: c/c-decl.c:6645
 #, gcc-internal-format
 msgid "alignment specified for %<register%> object %qE"
 msgstr "se especificó la alineación para el objeto %<register%> %qE"
 
-#: c/c-decl.c:6630
+#: c/c-decl.c:6650
 #, gcc-internal-format
 msgid "alignment specified for parameter %qE"
 msgstr "se especificó la alineación para el parámetro %qE"
 
-#: c/c-decl.c:6632
+#: c/c-decl.c:6652
 #, gcc-internal-format
 msgid "alignment specified for unnamed parameter"
 msgstr "se especificó la alineación para el parámetro sin nombre"
 
-#: c/c-decl.c:6637
+#: c/c-decl.c:6657
 #, gcc-internal-format
 msgid "alignment specified for bit-field %qE"
 msgstr "se especificó la alineación para el campo de bits %qE"
 
-#: c/c-decl.c:6639
+#: c/c-decl.c:6659
 #, gcc-internal-format
 msgid "alignment specified for unnamed bit-field"
 msgstr "se especificó la alineación para el campo de bits sin nombre"
 
-#: c/c-decl.c:6642
+#: c/c-decl.c:6662
 #, gcc-internal-format
 msgid "alignment specified for function %qE"
 msgstr "se especificó la alineación para la función %qE"
 
-#: c/c-decl.c:6649
+#: c/c-decl.c:6669
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of %qE"
 msgstr "los especificadores %<_Alignas%> no pueden reducir la alineación de %qE"
 
-#: c/c-decl.c:6652
+#: c/c-decl.c:6672
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of unnamed field"
 msgstr "los especificadores %<_Alignas%> no pueden reducir la alineación del campo sin nombre"
 
-#: c/c-decl.c:6683
+#: c/c-decl.c:6703
 #, gcc-internal-format
 msgid "typedef %q+D declared %<inline%>"
 msgstr "la definición de tipo %q+D se declaró como %<inline%>"
 
-#: c/c-decl.c:6685
+#: c/c-decl.c:6705
 #, gcc-internal-format
 msgid "typedef %q+D declared %<_Noreturn%>"
 msgstr "la definición de tipo %q+D se declaró como %<_Noreturn%>"
 
-#: c/c-decl.c:6727
+#: c/c-decl.c:6747
 #, gcc-internal-format
 msgid "ISO C forbids const or volatile function types"
 msgstr "ISO C prohíbe los tipos de función const o volatile"
 
 #. C99 6.7.2.1p8
-#: c/c-decl.c:6738
+#: c/c-decl.c:6758
 #, gcc-internal-format
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "un miembro de una estructura o union no puede tener un tipo modificado variablemente"
 
-#: c/c-decl.c:6755 cp/decl.c:9989
+#: c/c-decl.c:6775 cp/decl.c:10010
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "se declaró la variable o campo %qE como void"
 
-#: c/c-decl.c:6795
+#: c/c-decl.c:6815
 #, gcc-internal-format
 msgid "attributes in parameter array declarator ignored"
 msgstr "se descartan los atributos en los declaradores de parámetros de matriz"
 
-#: c/c-decl.c:6837
+#: c/c-decl.c:6857
 #, gcc-internal-format
 msgid "parameter %q+D declared %<inline%>"
 msgstr "el parámetro %q+D se declaró %<inline%>"
 
-#: c/c-decl.c:6839
+#: c/c-decl.c:6859
 #, gcc-internal-format
 msgid "parameter %q+D declared %<_Noreturn%>"
 msgstr "el parámetro %q+D se declaró %<_Noreturn%>"
 
-#: c/c-decl.c:6852
+#: c/c-decl.c:6872
 #, gcc-internal-format
 msgid "field %qE declared as a function"
 msgstr "el campo %qE se declaró como una función"
 
-#: c/c-decl.c:6859
+#: c/c-decl.c:6879
 #, gcc-internal-format
 msgid "field %qE has incomplete type"
 msgstr "el campo %qE tiene tipo de dato incompleto"
 
-#: c/c-decl.c:6861
+#: c/c-decl.c:6881
 #, gcc-internal-format
 msgid "unnamed field has incomplete type"
 msgstr "el campo sin nombre tiene tipo de dato incompleto"
 
-#: c/c-decl.c:6897 c/c-decl.c:6908 c/c-decl.c:6911
+#: c/c-decl.c:6917 c/c-decl.c:6928 c/c-decl.c:6931
 #, gcc-internal-format
 msgid "invalid storage class for function %qE"
 msgstr "clase de almacenamiento no válida para la función %qE"
 
-#: c/c-decl.c:6968
+#: c/c-decl.c:6988
 #, gcc-internal-format
 msgid "cannot inline function %<main%>"
 msgstr "no se puede incluir en línea la función %<main%>"
 
-#: c/c-decl.c:6970
+#: c/c-decl.c:6990
 #, gcc-internal-format
 msgid "%<main%> declared %<_Noreturn%>"
 msgstr "%<main%> se declaró como %<_Noreturn%>"
 
-#: c/c-decl.c:6981
+#: c/c-decl.c:7001
 #, gcc-internal-format
 msgid "ISO C99 does not support %<_Noreturn%>"
 msgstr "ISO C99 no admite %<_Noreturn%>"
 
-#: c/c-decl.c:6984
+#: c/c-decl.c:7004
 #, gcc-internal-format
 msgid "ISO C90 does not support %<_Noreturn%>"
 msgstr "ISO C90 no admite %<_Noreturn%>"
 
-#: c/c-decl.c:7013
+#: c/c-decl.c:7033
 #, gcc-internal-format
 msgid "variable previously declared %<static%> redeclared %<extern%>"
 msgstr "una variable previamente declarada como %<static%> se redeclara como %<extern%>"
 
-#: c/c-decl.c:7023
+#: c/c-decl.c:7043
 #, gcc-internal-format
 msgid "variable %q+D declared %<inline%>"
 msgstr "la variable %q+D se declaró como %<inline%>"
 
-#: c/c-decl.c:7025
+#: c/c-decl.c:7045
 #, gcc-internal-format
 msgid "variable %q+D declared %<_Noreturn%>"
 msgstr "la variable %q+D se declaró como %<_Noreturn%>"
 
-#: c/c-decl.c:7060
+#: c/c-decl.c:7080
 #, gcc-internal-format
 msgid "non-nested function with variably modified type"
 msgstr "función no anidada con tipo modificado variablemente"
 
-#: c/c-decl.c:7062
+#: c/c-decl.c:7082
 #, gcc-internal-format
 msgid "object with variably modified type must have no linkage"
 msgstr "un objeto con tipo modificado variablemente no debe tener enlace"
 
-#: c/c-decl.c:7153 c/c-decl.c:8821
+#: c/c-decl.c:7173 c/c-decl.c:8841
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr "la declaración de la función no es un prototipo"
 
-#: c/c-decl.c:7163
+#: c/c-decl.c:7183
 #, gcc-internal-format
 msgid "parameter names (without types) in function declaration"
 msgstr "nombres de parámetros (sin tipos) en la declaración de la función"
 
-#: c/c-decl.c:7201
+#: c/c-decl.c:7221
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has incomplete type"
 msgstr "el parámetro %u (%q+D) tiene tipo incompleto"
 
-#: c/c-decl.c:7205
+#: c/c-decl.c:7225
 #, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has incomplete type"
 msgstr "el parámetro %u tiene tipo incompleto"
 
-#: c/c-decl.c:7216
+#: c/c-decl.c:7236
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has void type"
 msgstr "el parámetro %u (%q+D) tiene tipo void"
 
-#: c/c-decl.c:7220
+#: c/c-decl.c:7240
 #, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has void type"
 msgstr "el parámetro %u tiene tipo void"
 
-#: c/c-decl.c:7294
+#: c/c-decl.c:7314
 #, gcc-internal-format
 msgid "%<void%> as only parameter may not be qualified"
 msgstr "no se puede calificar %<void%> si es el único parámetro"
 
-#: c/c-decl.c:7298 c/c-decl.c:7334
+#: c/c-decl.c:7318 c/c-decl.c:7354
 #, gcc-internal-format
 msgid "%<void%> must be the only parameter"
 msgstr "%<void%> debe ser el único parámetro"
 
-#: c/c-decl.c:7328
+#: c/c-decl.c:7348
 #, gcc-internal-format
 msgid "parameter %q+D has just a forward declaration"
 msgstr "el parámetro %q+D sólo tiene una declaración posterior"
 
-#: c/c-decl.c:7374
+#: c/c-decl.c:7394
 #, gcc-internal-format
 msgid "%<%s %E%> declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr ""
 
-#: c/c-decl.c:7380
+#: c/c-decl.c:7400
 #, gcc-internal-format, gfc-internal-format
 msgid "anonymous %s declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr ""
 
-#: c/c-decl.c:7482
+#: c/c-decl.c:7502
 #, gcc-internal-format
 msgid "enum type defined here"
 msgstr "se definió el tipo enum aquí"
 
-#: c/c-decl.c:7488
+#: c/c-decl.c:7508
 #, gcc-internal-format
 msgid "struct defined here"
 msgstr "se definió struct aquí"
 
-#: c/c-decl.c:7494
+#: c/c-decl.c:7514
 #, gcc-internal-format
 msgid "union defined here"
 msgstr "se definió union aquí"
 
-#: c/c-decl.c:7570
+#: c/c-decl.c:7590
 #, gcc-internal-format
 msgid "redefinition of %<union %E%>"
 msgstr "redefinición de %<union %E%>"
 
-#: c/c-decl.c:7572
+#: c/c-decl.c:7592
 #, gcc-internal-format
 msgid "redefinition of %<struct %E%>"
 msgstr "redefinición de %<struct %E%>"
 
-#: c/c-decl.c:7581
+#: c/c-decl.c:7601
 #, gcc-internal-format
 msgid "nested redefinition of %<union %E%>"
 msgstr "redefinición anidada de %<union %E%>"
 
-#: c/c-decl.c:7583
+#: c/c-decl.c:7603
 #, gcc-internal-format
 msgid "nested redefinition of %<struct %E%>"
 msgstr "redefinición anidada de %<struct %E%>"
 
-#: c/c-decl.c:7613 c/c-decl.c:8400
+#: c/c-decl.c:7633 c/c-decl.c:8420
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr "la definición de tipo en %qs es no válida en C++"
 
-#: c/c-decl.c:7680 cp/decl.c:4802
+#: c/c-decl.c:7700 cp/decl.c:4802
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "la declaración no declara nada"
 
-#: c/c-decl.c:7685
+#: c/c-decl.c:7705
 #, gcc-internal-format
 msgid "ISO C99 doesn%'t support unnamed structs/unions"
 msgstr "ISO C99 no admite structs/unions sin nombre"
 
-#: c/c-decl.c:7688
+#: c/c-decl.c:7708
 #, gcc-internal-format
 msgid "ISO C90 doesn%'t support unnamed structs/unions"
 msgstr "ISO C90 no admite structs/unions sin nombre"
 
-#: c/c-decl.c:7781 c/c-decl.c:7799 c/c-decl.c:7860
+#: c/c-decl.c:7801 c/c-decl.c:7819 c/c-decl.c:7880
 #, gcc-internal-format
 msgid "duplicate member %q+D"
 msgstr "miembro %q+D duplicado"
 
-#: c/c-decl.c:7886
+#: c/c-decl.c:7906
 #, gcc-internal-format
 msgid "empty struct has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.c:7889
+#: c/c-decl.c:7909
 #, gcc-internal-format
 msgid "empty union has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.c:7994
+#: c/c-decl.c:8014
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr "union no tiene miembros nombrados"
 
-#: c/c-decl.c:7996
+#: c/c-decl.c:8016
 #, gcc-internal-format
 msgid "union has no members"
 msgstr "union no tiene miembros"
 
-#: c/c-decl.c:8001
+#: c/c-decl.c:8021
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr "struct no tiene miembros nombrados"
 
-#: c/c-decl.c:8003
+#: c/c-decl.c:8023
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr "struct no tiene miembros"
 
-#: c/c-decl.c:8064 cp/decl.c:12069
+#: c/c-decl.c:8084 cp/decl.c:12093
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "miembro de matriz flexible en union"
 
-#: c/c-decl.c:8070
+#: c/c-decl.c:8090
 #, gcc-internal-format
 msgid "flexible array member not at end of struct"
 msgstr "el miembro de matriz flexible no está al final del struct"
 
-#: c/c-decl.c:8076
+#: c/c-decl.c:8096
 #, gcc-internal-format
 msgid "flexible array member in a struct with no named members"
 msgstr "miembro de matriz flexible en estructura sin miembros con nombre"
 
-#: c/c-decl.c:8107
+#: c/c-decl.c:8127
 #, gcc-internal-format
 msgid "type %qT is too large"
 msgstr "el tipo %qT es demasiado grande"
 
-#: c/c-decl.c:8230
+#: c/c-decl.c:8250
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr "union no se puede hacer transparente"
 
-#: c/c-decl.c:8372
+#: c/c-decl.c:8392
 #, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr "redefinición anidada de %<enum %E%>"
 
 #. This enum is a named one that has been declared already.
-#: c/c-decl.c:8379
+#: c/c-decl.c:8399
 #, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr "redeclaración de %<enum %E%>"
 
-#: c/c-decl.c:8458 cp/decl.c:14423
+#: c/c-decl.c:8478 cp/decl.c:14447
 #, gcc-internal-format
 msgid "specified mode too small for enumeral values"
 msgstr "el modo especificado es demasiado pequeño para valores enumerados"
 
-#: c/c-decl.c:8473
+#: c/c-decl.c:8493
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr "los valores de enumeración exceden el rango del entero más grande"
 
-#: c/c-decl.c:8587 c/c-decl.c:8603
+#: c/c-decl.c:8607 c/c-decl.c:8623
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr "el valor de enumerador para %qE no es una constante entera"
 
-#: c/c-decl.c:8598
+#: c/c-decl.c:8618
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr "el valor de enumerador para %qE no es una expresión constante entera"
 
-#: c/c-decl.c:8622
+#: c/c-decl.c:8642
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr "desbordamiento en valores de enumeración"
 
-#: c/c-decl.c:8630
+#: c/c-decl.c:8650
 #, gcc-internal-format
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "ISO C restringe los valores de enumeración al rango de %<int%>"
 
-#: c/c-decl.c:8715 cp/decl.c:5104 cp/decl.c:14955
+#: c/c-decl.c:8735 cp/decl.c:5104 cp/decl.c:14979
 #, gcc-internal-format
 msgid "inline function %qD given attribute noinline"
 msgstr "se le dió a la función incluida en línea %qD un atributo noinline"
 
-#: c/c-decl.c:8733
+#: c/c-decl.c:8753
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr "el tipo de devolución es un tipo de dato incompleto"
 
-#: c/c-decl.c:8744
+#: c/c-decl.c:8764
 #, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr "el tipo de devolución por defecto es %<int%>"
 
-#: c/c-decl.c:8771
+#: c/c-decl.c:8791
 #, fuzzy, gcc-internal-format
 #| msgid "Warn about global functions without prototypes"
 msgid "%q+D defined as variadic function without prototype"
 msgstr "Avisa sobre funciones globales sin prototipos"
 
-#: c/c-decl.c:8830
+#: c/c-decl.c:8850
 #, gcc-internal-format
 msgid "no previous prototype for %qD"
 msgstr "no hay un prototipo previo para %qD"
 
-#: c/c-decl.c:8839
+#: c/c-decl.c:8859
 #, gcc-internal-format
 msgid "%qD was used with no prototype before its definition"
 msgstr "se usó %qD sin prototipo antes de su definición"
 
-#: c/c-decl.c:8847 cp/decl.c:15090
+#: c/c-decl.c:8867 cp/decl.c:15114
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "no hay declaración previa para %qD"
 
-#: c/c-decl.c:8857
+#: c/c-decl.c:8877
 #, gcc-internal-format
 msgid "%qD was used with no declaration before its definition"
 msgstr "se usó %qD sin declaración antes de su definición"
 
-#: c/c-decl.c:8876
+#: c/c-decl.c:8896
 #, gcc-internal-format
 msgid "return type of %qD is not %<int%>"
 msgstr "el tipo de devolución de %qD no es %<int%>"
 
-#: c/c-decl.c:8878
+#: c/c-decl.c:8898
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr ""
 
-#: c/c-decl.c:8885
+#: c/c-decl.c:8905
 #, gcc-internal-format
 msgid "%qD is normally a non-static function"
 msgstr "%qD generalmente es una función que no es static"
 
-#: c/c-decl.c:8922
+#: c/c-decl.c:8942
 #, gcc-internal-format
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr "declaraciones de parámetros de estilo antiguo en la definición de una función prototipo"
 
-#: c/c-decl.c:8937
+#: c/c-decl.c:8957
 #, gcc-internal-format
 msgid "traditional C rejects ISO C style function definitions"
 msgstr "C tradicional rechaza la definición de funciones de estilo ISO C"
 
-#: c/c-decl.c:8953
+#: c/c-decl.c:8973
 #, gcc-internal-format
 msgid "parameter name omitted"
 msgstr "se omitió el nombre del parámetro"
 
-#: c/c-decl.c:8990
+#: c/c-decl.c:9010
 #, gcc-internal-format
 msgid "old-style function definition"
 msgstr "definición de función de estilo antiguo"
 
-#: c/c-decl.c:8999
+#: c/c-decl.c:9019
 #, gcc-internal-format
 msgid "parameter name missing from parameter list"
 msgstr "falta el nombre del parámetro de la lista de parámetros"
 
-#: c/c-decl.c:9015
+#: c/c-decl.c:9035
 #, gcc-internal-format
 msgid "%qD declared as a non-parameter"
 msgstr "%qD se declaró como un no-parámetro"
 
-#: c/c-decl.c:9023
+#: c/c-decl.c:9043
 #, gcc-internal-format
 msgid "multiple parameters named %qD"
 msgstr "múltiples parámetros nombrados %qD"
 
-#: c/c-decl.c:9032
+#: c/c-decl.c:9052
 #, gcc-internal-format
 msgid "parameter %qD declared with void type"
 msgstr "el parámetro %qD se declaró con tipo void"
 
-#: c/c-decl.c:9061 c/c-decl.c:9066
+#: c/c-decl.c:9081 c/c-decl.c:9086
 #, gcc-internal-format
 msgid "type of %qD defaults to %<int%>"
 msgstr "el tipo de %qD es %<int%> por defecto"
 
-#: c/c-decl.c:9086
+#: c/c-decl.c:9106
 #, gcc-internal-format
 msgid "parameter %qD has incomplete type"
 msgstr "el parámetro %qD tiene tipo incompleto"
 
-#: c/c-decl.c:9093
+#: c/c-decl.c:9113
 #, gcc-internal-format
 msgid "declaration for parameter %qD but no such parameter"
 msgstr "existe la declaración para el parámetro %qD pero no hay tal parámetro"
 
-#: c/c-decl.c:9146
+#: c/c-decl.c:9166
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr "el número de argumentos no coinciden con el prototipo interno"
 
-#: c/c-decl.c:9157
+#: c/c-decl.c:9177
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr "el número de argumentos no coinciden con el prototipo"
 
-#: c/c-decl.c:9160 c/c-decl.c:9207 c/c-decl.c:9221
+#: c/c-decl.c:9180 c/c-decl.c:9227 c/c-decl.c:9241
 #, gcc-internal-format
 msgid "prototype declaration"
 msgstr "declaración de prototipo"
 
-#: c/c-decl.c:9199
+#: c/c-decl.c:9219
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr "el argumento promovido %qD no coincide con el prototipo interno"
 
-#: c/c-decl.c:9204
+#: c/c-decl.c:9224
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr "el argumento promovido %qD no coincide con el prototipo"
 
-#: c/c-decl.c:9214
+#: c/c-decl.c:9234
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr "el argumento %qD no coincide con el prototipo interno"
 
-#: c/c-decl.c:9219
+#: c/c-decl.c:9239
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr "el argumento %qD no coincide con el prototipo"
 
-#: c/c-decl.c:9470 cp/decl.c:15873
+#: c/c-decl.c:9490 cp/decl.c:15897
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "no hay una declaración de devolución en la función que no devuelve void"
 
-#: c/c-decl.c:9490 cp/decl.c:15905
+#: c/c-decl.c:9510 cp/decl.c:15929
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "se definió el parámetro %qD pero no se usa"
@@ -34663,247 +34712,247 @@
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:9586
+#: c/c-decl.c:9606
 #, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "sólo se permiten las declaraciones iniciales del bucle %<for%> en modo C99 o C11"
 
-#: c/c-decl.c:9591
+#: c/c-decl.c:9611
 #, gcc-internal-format
 msgid "use option -std=c99, -std=gnu99, -std=c11 or -std=gnu11 to compile your code"
 msgstr "use la opción -std=c99, -std=gnu99, -std=c11 o -std=gnu11 para compilar su código"
 
-#: c/c-decl.c:9626
+#: c/c-decl.c:9646
 #, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "declaración de la variable static %qD en la declaración inicial del bucle %<for%>"
 
-#: c/c-decl.c:9630
+#: c/c-decl.c:9650
 #, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "declaración de la variable %<extern%> %qD en la declaración inicial del bucle %<for%>"
 
-#: c/c-decl.c:9637
+#: c/c-decl.c:9657
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "%<struct %E%> se declaró en la declaración inicial del bucle %<for%>"
 
-#: c/c-decl.c:9642
+#: c/c-decl.c:9662
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "%<union %E%> se declaró en la declaración inicial del bucle %<for%>"
 
-#: c/c-decl.c:9646
+#: c/c-decl.c:9666
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "%<enum %E%> se declaró en la declaración inicial del bucle %<for%>"
 
-#: c/c-decl.c:9650
+#: c/c-decl.c:9670
 #, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "declaración de %qD que no es variable en la declaración inicial del bucle %<for%>"
 
-#: c/c-decl.c:9900
+#: c/c-decl.c:9920
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr "calificadores de espacio de direcciones incompatibles %qs y %qs"
 
-#: c/c-decl.c:9958 c/c-decl.c:9965
+#: c/c-decl.c:9978 c/c-decl.c:9985
 #, gcc-internal-format
 msgid "duplicate %qE declaration specifier"
 msgstr "especificador %qE de declaración duplicado"
 
-#: c/c-decl.c:9992 c/c-decl.c:10376 c/c-decl.c:10766
+#: c/c-decl.c:10012 c/c-decl.c:10396 c/c-decl.c:10786
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr "dos o más tipos de datos en los especificadores de la declaración"
 
-#: c/c-decl.c:10004 cp/parser.c:28261
+#: c/c-decl.c:10024 cp/parser.c:28258
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> es demasiado largo para GCC"
 
-#: c/c-decl.c:10017
+#: c/c-decl.c:10037
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C90 no admite %<long long%>"
 
-#: c/c-decl.c:10246 c/c-parser.c:8848
+#: c/c-decl.c:10266 c/c-parser.c:8848
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C90 no admite tipos complejos"
 
-#: c/c-decl.c:10292
+#: c/c-decl.c:10312
 #, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr "ISO C no admite tipos saturantes"
 
-#: c/c-decl.c:10363 c/c-decl.c:10923
+#: c/c-decl.c:10383 c/c-decl.c:10943
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "%qE duplicado"
 
-#: c/c-decl.c:10419
+#: c/c-decl.c:10439
 #, gcc-internal-format
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C no admite los tipos %<__int%d%>"
 
-#: c/c-decl.c:10441
+#: c/c-decl.c:10461
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr "no se admite %<__int%d%> para este objetivo"
 
-#: c/c-decl.c:10484
+#: c/c-decl.c:10504
 #, gcc-internal-format
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C90 no admite tipos booleanos"
 
-#: c/c-decl.c:10603
+#: c/c-decl.c:10623
 #, gcc-internal-format
 msgid "ISO C does not support the %<_Float%d%s%> type"
 msgstr "ISO C no admite el tipo %<_float%d%s%>"
 
-#: c/c-decl.c:10653
+#: c/c-decl.c:10673
 #, gcc-internal-format
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "no se admite %<_float%d%s%> para este objetivo"
 
-#: c/c-decl.c:10724
+#: c/c-decl.c:10744
 #, gcc-internal-format
 msgid "ISO C does not support decimal floating point"
 msgstr "ISO C no admite coma flotante decimal"
 
-#: c/c-decl.c:10747 c/c-decl.c:11013 c/c-parser.c:7842
+#: c/c-decl.c:10767 c/c-decl.c:11033 c/c-parser.c:7842
 #, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "no se admiten tipos de coma fija para este objetivo"
 
-#: c/c-decl.c:10749
+#: c/c-decl.c:10769
 #, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C no admite tipos de coma fija"
 
-#: c/c-decl.c:10784
+#: c/c-decl.c:10804
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr "la búsqueda en C++ de %qD devolvería un campo, no un tipo"
 
-#: c/c-decl.c:10797
+#: c/c-decl.c:10817
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr "%qE falla al ser un typedef o un tipo interno del compilador"
 
-#: c/c-decl.c:10845
+#: c/c-decl.c:10865
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qE no está al inicio de la declaración"
 
-#: c/c-decl.c:10866
+#: c/c-decl.c:10886
 #, gcc-internal-format
 msgid "%qE used with %<auto%>"
 msgstr "se usó %qE con %<auto%>"
 
-#: c/c-decl.c:10868
+#: c/c-decl.c:10888
 #, gcc-internal-format
 msgid "%qE used with %<register%>"
 msgstr "se usó %qE con %<register%>"
 
-#: c/c-decl.c:10870
+#: c/c-decl.c:10890
 #, gcc-internal-format
 msgid "%qE used with %<typedef%>"
 msgstr "se usó %qE con %<typedef%>"
 
-#: c/c-decl.c:10884 c/c-parser.c:7360
+#: c/c-decl.c:10904 c/c-parser.c:7360
 #, gcc-internal-format
 msgid "ISO C99 does not support %qE"
 msgstr "ISO C99 no admite %qE"
 
-#: c/c-decl.c:10887 c/c-parser.c:7363
+#: c/c-decl.c:10907 c/c-parser.c:7363
 #, gcc-internal-format
 msgid "ISO C90 does not support %qE"
 msgstr "ISO C90 no admite %qE"
 
-#: c/c-decl.c:10899
+#: c/c-decl.c:10919
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<__thread%> antes de %<extern%>"
 
-#: c/c-decl.c:10908
+#: c/c-decl.c:10928
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<__thread%> antes de %<static%>"
 
-#: c/c-decl.c:10921
+#: c/c-decl.c:10941
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr "%<_Thread_local%> o %<__thread%> duplicado"
 
-#: c/c-decl.c:10929
+#: c/c-decl.c:10949
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr "múltiples clases de almacenamiento en los especificadores de declaración"
 
-#: c/c-decl.c:10937
+#: c/c-decl.c:10957
 #, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr "se usó %qs con %qE"
 
-#: c/c-decl.c:11010
+#: c/c-decl.c:11030
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "se usó %<_Sat%> sin %<_Fract%> o %<_Accum%>"
 
-#: c/c-decl.c:11025
+#: c/c-decl.c:11045
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C no admite %<complex%> simples que significan %<double complex%>"
 
-#: c/c-decl.c:11076 c/c-decl.c:11092 c/c-decl.c:11118
+#: c/c-decl.c:11096 c/c-decl.c:11112 c/c-decl.c:11138
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C no admite tipos enteros complejos"
 
-#: c/c-decl.c:11514 cp/semantics.c:5348
+#: c/c-decl.c:11534 cp/semantics.c:5351
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr "el combinador %<#pragma omp declare reduction%> hace referencia a la variable %qD, la cual no es %<omp_out%> ni %<omp_in%>"
 
-#: c/c-decl.c:11518 cp/semantics.c:5352
+#: c/c-decl.c:11538 cp/semantics.c:5355
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr "el nicializador %<#pragma omp declare reduction%> hace referencia a la variable %qD, la cual no es %<omp_priv%> ni %<omp_orig%>"
 
-#: c/c-fold.c:385 c/c-typeck.c:11426 cp/typeck.c:4680
+#: c/c-fold.c:385 c/c-typeck.c:11431 cp/typeck.c:4680
 #, gcc-internal-format
 msgid "left shift of negative value"
 msgstr "desplazamiento a la izquierda o valor negativo"
 
-#: c/c-fold.c:395 c/c-typeck.c:11435 cp/typeck.c:4688
+#: c/c-fold.c:395 c/c-typeck.c:11440 cp/typeck.c:4688
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "la cuenta de desplazamiento a la izquierda es negativa"
 
-#: c/c-fold.c:396 c/c-typeck.c:11365 cp/typeck.c:4633
+#: c/c-fold.c:396 c/c-typeck.c:11370 cp/typeck.c:4633
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "la cuenta de desplazamiento a la derecha es negativa"
 
-#: c/c-fold.c:404 c/c-typeck.c:11454 cp/typeck.c:4696
+#: c/c-fold.c:404 c/c-typeck.c:11459 cp/typeck.c:4696
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "cuenta de desplazamiento a la izquierda >= anchura del tipo"
 
-#: c/c-fold.c:405 c/c-typeck.c:11389 cp/typeck.c:4641
+#: c/c-fold.c:405 c/c-typeck.c:11394 cp/typeck.c:4641
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "cuenta de desplazamiento a la derecha >= anchura del tipo"
 
-#: c/c-fold.c:412 c/c-typeck.c:11446
+#: c/c-fold.c:412 c/c-typeck.c:11451
 #, gcc-internal-format
 msgid "left shift count >= width of vector element"
 msgstr "cuenta de desplazamiento a la izquierda >= anchura del elemento del vector"
 
-#: c/c-fold.c:413 c/c-typeck.c:11376
+#: c/c-fold.c:413 c/c-typeck.c:11381
 #, gcc-internal-format
 msgid "right shift count >= width of vector element"
 msgstr "cuenta de desplazamiento a la derecha >= anchura del elemento del vector"
@@ -34924,7 +34973,7 @@
 msgid "to match this %qs"
 msgstr "%J  otro tipo aquí"
 
-#: c/c-parser.c:1216 cp/parser.c:28484
+#: c/c-parser.c:1216 cp/parser.c:28481
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr "se esperaba fin de línea"
@@ -34965,7 +35014,7 @@
 msgstr "nombre de tipo %qE desconocido"
 
 #: c/c-parser.c:1848 c/c-parser.c:11129 c/c-parser.c:16147 c/c-parser.c:16585
-#: c/c-parser.c:17061 cp/parser.c:36007 cp/parser.c:38993
+#: c/c-parser.c:17061 cp/parser.c:36004 cp/parser.c:38990
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "se esperaban especificadores de declaración"
@@ -34980,7 +35029,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "se esperaba %<;>, identificador o %<(%>"
 
-#: c/c-parser.c:1906 cp/parser.c:30161 cp/parser.c:30235
+#: c/c-parser.c:1906 cp/parser.c:30158 cp/parser.c:30232
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "se descartan los atributos de prefijo para los métodos"
@@ -35034,7 +35083,7 @@
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr "%<__auto_type%> sólo se puede utilizar con una declaración simple"
 
-#: c/c-parser.c:2220 cp/parser.c:13002 cp/parser.c:13159
+#: c/c-parser.c:2220 cp/parser.c:12999 cp/parser.c:13156
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "se esperaba %<,%> o %<;%>"
@@ -35062,7 +35111,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C90 no admite %<_Static_assert%>"
 
-#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38634
+#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38631
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr "se esperaba una cadena literal"
@@ -35126,13 +35175,13 @@
 #: c/c-parser.c:10745 c/c-parser.c:10798 c/c-parser.c:10814 c/c-parser.c:10860
 #: c/c-parser.c:11496 c/c-parser.c:11537 c/c-parser.c:13445 c/c-parser.c:13681
 #: c/c-parser.c:15544 c/c-parser.c:18218 c/gimple-parser.c:1058
-#: c/gimple-parser.c:1096 cp/parser.c:28487 cp/parser.c:31013
-#: cp/parser.c:31043 cp/parser.c:31113 cp/parser.c:33230 cp/parser.c:38350
+#: c/gimple-parser.c:1096 cp/parser.c:28484 cp/parser.c:31010
+#: cp/parser.c:31040 cp/parser.c:31110 cp/parser.c:33227 cp/parser.c:38347
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "se esperaba un identificador"
 
-#: c/c-parser.c:2995 cp/parser.c:18384
+#: c/c-parser.c:2995 cp/parser.c:18381
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "coma al final de la lista de enumeradores"
@@ -35301,12 +35350,12 @@
 msgid "expected statement"
 msgstr "se esperaba una declaración"
 
-#: c/c-parser.c:5639 cp/parser.c:12516
+#: c/c-parser.c:5639 cp/parser.c:12513
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "se sugieren llaves alrededor del cuerpo vacío en una declaración %<if%>"
 
-#: c/c-parser.c:5681 cp/parser.c:12519
+#: c/c-parser.c:5681 cp/parser.c:12516
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "se sugieren llaves alrededor del cuerpo vacío en una declaración %<else%>"
@@ -35657,7 +35706,7 @@
 msgid "%<__builtin_complex%> operands of different types"
 msgstr "los operandos de %<__builtin_complex%> son de tipos diferentes"
 
-#: c/c-parser.c:8891 cp/parser.c:6918
+#: c/c-parser.c:8891 cp/parser.c:6921
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_shuffle%>"
 msgstr "número erróneo de argumentos para %<__builtin_shuffle%>"
@@ -35717,76 +35766,76 @@
 msgid "no type or storage class may be specified here,"
 msgstr "ninguna clase de almacenamiento o tipo se puede especificar aquí,"
 
-#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31073
+#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31070
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "atributo de propiedad desconocido"
 
-#: c/c-parser.c:10682 cp/parser.c:31033
+#: c/c-parser.c:10682 cp/parser.c:31030
 #, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "falta un %<=%> (después del atributo %<getter%>)"
 
-#: c/c-parser.c:10685 cp/parser.c:31036
+#: c/c-parser.c:10685 cp/parser.c:31033
 #, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "falta un %<=%> (después del atributo %<setter%>)"
 
-#: c/c-parser.c:10699 cp/parser.c:31051
+#: c/c-parser.c:10699 cp/parser.c:31048
 #, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "el atributo %<setter%> sólo se puede especificar una vez"
 
-#: c/c-parser.c:10704 cp/parser.c:31057
+#: c/c-parser.c:10704 cp/parser.c:31054
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr "el nombre del setter debe terminar con %<:%>"
 
-#: c/c-parser.c:10711 cp/parser.c:31065
+#: c/c-parser.c:10711 cp/parser.c:31062
 #, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "el atributo %<getter%> sólo se puede especificar una vez"
 
-#: c/c-parser.c:10905 cp/parser.c:38674
+#: c/c-parser.c:10905 cp/parser.c:38671
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr "%<#pragma GCC unroll%> requiere una expresión de asignación que evaluada dé una constante entera no negativa menor que %u"
 
 #: c/c-parser.c:10949 c/c-parser.c:16582 c/c-parser.c:16840 c/c-parser.c:16899
-#: c/c-parser.c:16983 cp/parser.c:36004 cp/parser.c:36298 cp/parser.c:36386
-#: cp/parser.c:36457 cp/parser.c:38721 cp/parser.c:38736 cp/parser.c:38752
-#: cp/parser.c:38768 cp/parser.c:38784 cp/parser.c:38811 cp/parser.c:38824
-#: cp/parser.c:38847 cp/parser.c:38860
+#: c/c-parser.c:16983 cp/parser.c:36001 cp/parser.c:36295 cp/parser.c:36383
+#: cp/parser.c:36454 cp/parser.c:38718 cp/parser.c:38733 cp/parser.c:38749
+#: cp/parser.c:38765 cp/parser.c:38781 cp/parser.c:38808 cp/parser.c:38821
+#: cp/parser.c:38844 cp/parser.c:38857
 #, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<#pragma %s%> sólo se puede usar en declaraciones compuestas"
 
-#: c/c-parser.c:10972 cp/parser.c:38837
+#: c/c-parser.c:10972 cp/parser.c:38834
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<#pragma acc routine%> debe estar en el alcance del fichero"
 
-#: c/c-parser.c:11050 cp/parser.c:38918
+#: c/c-parser.c:11050 cp/parser.c:38915
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<#pragma omp section%> sólo se puede usar en construcciones %<#pragma omp sections%>"
 
-#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38947 cp/parser.c:38980
+#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38944 cp/parser.c:38977
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "se esperaba una declaración for, while o do"
 
-#: c/c-parser.c:11111 cp/parser.c:38711
+#: c/c-parser.c:11111 cp/parser.c:38708
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%> debe ser primero"
 
-#: c/c-parser.c:11421 cp/parser.c:31457
+#: c/c-parser.c:11421 cp/parser.c:31454
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "demasiadas cláusulas %qs"
 
-#: c/c-parser.c:11443 cp/parser.c:31994
+#: c/c-parser.c:11443 cp/parser.c:31991
 #, gcc-internal-format
 msgid "expected integer expression before ')'"
 msgstr "se esperaba una expresión entera delante de ')'"
@@ -35801,53 +35850,53 @@
 msgid "%qD is not a variable"
 msgstr "%qD no es una variable"
 
-#: c/c-parser.c:11746 cp/semantics.c:6808
+#: c/c-parser.c:11746 cp/semantics.c:6811
 #, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "%qD no es una variable puntero"
 
-#: c/c-parser.c:11788 cp/parser.c:32073
+#: c/c-parser.c:11788 cp/parser.c:32070
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr "el argumento de collapse necesita una expresión entera constante positiva"
 
-#: c/c-parser.c:11865 cp/parser.c:32137
+#: c/c-parser.c:11865 cp/parser.c:32134
 #, gcc-internal-format
 msgid "expected %<none%> or %<present%>"
 msgstr "se esperaba %<none%> o %<present%>"
 
-#: c/c-parser.c:11867 cp/parser.c:32139
+#: c/c-parser.c:11867 cp/parser.c:32136
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "se esperaba %<none%> o %<shared%>"
 
-#: c/c-parser.c:11968 cp/parser.c:32242
+#: c/c-parser.c:11968 cp/parser.c:32239
 #, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "se esperaba %<data%>, %<update%>, %<enter%> o %<exit%>"
 
-#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32260
-#: cp/parser.c:36290 cp/parser.c:36378
+#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32257
+#: cp/parser.c:36287 cp/parser.c:36375
 #, gcc-internal-format
 msgid "expected %<data%>"
 msgstr "se esperaba %<data%>"
 
-#: c/c-parser.c:12035 cp/parser.c:32313
+#: c/c-parser.c:12035 cp/parser.c:32310
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr "demasiadas cláusulas %<if%> con el modificador %qs"
 
-#: c/c-parser.c:12042 cp/parser.c:32320
+#: c/c-parser.c:12042 cp/parser.c:32317
 #, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr "demasiadas cláusulas %<if%>"
 
-#: c/c-parser.c:12044 cp/parser.c:32322
+#: c/c-parser.c:12044 cp/parser.c:32319
 #, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr "demasiadas cláusulas %<if%> sin modificador"
 
-#: c/c-parser.c:12050 cp/parser.c:32328
+#: c/c-parser.c:12050 cp/parser.c:32325
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr "si alguna cláusula %<if%> tiene modificador, entonces todas las cláusulas %<if%> tienen que usar modificador"
@@ -35869,84 +35918,84 @@
 msgid "%<num_tasks%> value must be positive"
 msgstr "el valor de %<num_tasks%> debe ser positivo"
 
-#: c/c-parser.c:12229 cp/semantics.c:6992
+#: c/c-parser.c:12229 cp/semantics.c:6995
 #, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr "el valor de %<grainsize%> debe ser positivo"
 
-#: c/c-parser.c:12276 cp/semantics.c:7021
+#: c/c-parser.c:12276 cp/semantics.c:7024
 #, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr "el valor de %<priority%> debe ser no negativo"
 
-#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32545 cp/parser.c:32552
+#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32542 cp/parser.c:32549
 #, gcc-internal-format
 msgid "expected %<tofrom%>"
 msgstr "se esperaba %<tofrom%>"
 
-#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32561 cp/parser.c:32568
+#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32558 cp/parser.c:32565
 #, gcc-internal-format
 msgid "expected %<scalar%>"
 msgstr "se esperaba %<scalar%>"
 
-#: c/c-parser.c:12425 cp/semantics.c:6299
+#: c/c-parser.c:12425 cp/semantics.c:6302
 #, gcc-internal-format
 msgid "%qs expression must be integral"
 msgstr "la expresión %qs debe ser integral"
 
-#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6331
+#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6334
 #, gcc-internal-format
 msgid "%qs value must be positive"
 msgstr "el valor de %qs debe ser positivo"
 
-#: c/c-parser.c:12499 cp/parser.c:31853
+#: c/c-parser.c:12499 cp/parser.c:31850
 #, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "demasiados argumentos %<static%>"
 
-#: c/c-parser.c:12533 cp/parser.c:31886
+#: c/c-parser.c:12533 cp/parser.c:31883
 #, gcc-internal-format
 msgid "unexpected argument"
 msgstr "argumento inesperado"
 
-#: c/c-parser.c:12699 cp/semantics.c:7120
+#: c/c-parser.c:12699 cp/semantics.c:7123
 #, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "el argumento de %<tile%> necesita una constante entera positiva"
 
-#: c/c-parser.c:12765 cp/parser.c:32626
+#: c/c-parser.c:12765 cp/parser.c:32623
 #, fuzzy, gcc-internal-format
 #| msgid "collapse argument needs positive constant integer expression"
 msgid "ordered argument needs positive constant integer expression"
 msgstr "el argumento de collapse necesita una expresión entera constante positiva"
 
-#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37643
+#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37640
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "se esperaba %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> o identificador"
 
-#: c/c-parser.c:12967 cp/parser.c:32840
+#: c/c-parser.c:12967 cp/parser.c:32837
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "se usaron al mismo tiempo los modificadores %<monotonic%> y %<nonmonotonic%>"
 
-#: c/c-parser.c:13021 cp/parser.c:32856
+#: c/c-parser.c:13021 cp/parser.c:32853
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "el planificador %<runtime%> no toma un parámetro %<chunk_size%>"
 
-#: c/c-parser.c:13025 cp/parser.c:32859
+#: c/c-parser.c:13025 cp/parser.c:32856
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "el planificador %<auto%> no toma un parámetro %<chunk_size%>"
 
-#: c/c-parser.c:13037 cp/semantics.c:6389
+#: c/c-parser.c:13037 cp/semantics.c:6392
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "chunk size value must be positive"
 msgstr "el valor de %<num_threads%> debe ser positivo"
 
-#: c/c-parser.c:13060 cp/parser.c:32879
+#: c/c-parser.c:13060 cp/parser.c:32876
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "género de planificador no válido"
@@ -35956,12 +36005,12 @@
 msgid "%<num_teams%> value must be positive"
 msgstr "el valor de %<num_teams%> debe ser positivo"
 
-#: c/c-parser.c:13226 cp/semantics.c:6479
+#: c/c-parser.c:13226 cp/semantics.c:6482
 #, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr "el valor de %<thread_limit%> debe ser positivo"
 
-#: c/c-parser.c:13271 cp/semantics.c:6589
+#: c/c-parser.c:13271 cp/semantics.c:6592
 #, fuzzy, gcc-internal-format
 #| msgid "%Hcollapse argument needs positive constant integer expression"
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
@@ -35985,17 +36034,17 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr "%Hel argumento de collapse necesita ser una expresión entera constante positiva"
 
-#: c/c-parser.c:13584 cp/parser.c:33374 cp/parser.c:33599
+#: c/c-parser.c:13584 cp/parser.c:33371 cp/parser.c:33596
 #, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "tipo de dependencia no válida"
 
-#: c/c-parser.c:13669 cp/parser.c:33447
+#: c/c-parser.c:13669 cp/parser.c:33444
 #, gcc-internal-format
 msgid "invalid map kind"
 msgstr "tipo de mapa no válida"
 
-#: c/c-parser.c:13767 cp/parser.c:33546
+#: c/c-parser.c:13767 cp/parser.c:33543
 #, fuzzy, gcc-internal-format
 #| msgid "invalid schedule kind"
 msgid "invalid dist_schedule kind"
@@ -36007,67 +36056,67 @@
 msgid "invalid proc_bind kind"
 msgstr "género de planificador no válido"
 
-#: c/c-parser.c:14059 cp/parser.c:33825
+#: c/c-parser.c:14059 cp/parser.c:33822
 #, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr "se esperaba una cláusula %<#pragma acc%>"
 
-#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33836 cp/parser.c:34143
+#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33833 cp/parser.c:34140
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs no es válido para %qs"
 
-#: c/c-parser.c:14214 cp/parser.c:34010
+#: c/c-parser.c:14214 cp/parser.c:34007
 #, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "%qs debe ser la primera cláusula de %qs"
 
-#: c/c-parser.c:14334 cp/parser.c:34132
+#: c/c-parser.c:14334 cp/parser.c:34129
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "se esperaba una cláusula %<#pragma omp%>"
 
-#: c/c-parser.c:14472 cp/parser.c:36803
+#: c/c-parser.c:14472 cp/parser.c:36800
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr "no hay cláusulas válidas especificadas en %<#pragma acc declare%>"
 
-#: c/c-parser.c:14482 cp/parser.c:36813
+#: c/c-parser.c:14482 cp/parser.c:36810
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr "sección de matriz en %<#pragma acc declare%>"
 
-#: c/c-parser.c:14502 cp/parser.c:36833
+#: c/c-parser.c:14502 cp/parser.c:36830
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr "%qD debe ser una variable global en %<#pragma acc declare link%>"
 
-#: c/c-parser.c:14513 cp/parser.c:36844
+#: c/c-parser.c:14513 cp/parser.c:36841
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr "cláusula OpenACC no válida en el alcance del fichero"
 
-#: c/c-parser.c:14520 cp/parser.c:36851
+#: c/c-parser.c:14520 cp/parser.c:36848
 #, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "uso no válido de la variable %<extern%> %qD en %<#pragma acc declare%>"
 
-#: c/c-parser.c:14528 cp/parser.c:36859
+#: c/c-parser.c:14528 cp/parser.c:36856
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "uso no válido de la variable %<global%> %qD en %<#pragma acc declare%>"
 
-#: c/c-parser.c:14540 cp/parser.c:36871
+#: c/c-parser.c:14540 cp/parser.c:36868
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr "La variable %qD se usa más de una vez con %<#pragma acc declare%>"
 
-#: c/c-parser.c:14632 cp/parser.c:36957
+#: c/c-parser.c:14632 cp/parser.c:36954
 #, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "se esperaba %<data%> después de %<#pragma acc %s%>"
 
-#: c/c-parser.c:14648 cp/parser.c:36974
+#: c/c-parser.c:14648 cp/parser.c:36971
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr "%<#pragma acc %s data%> no tiene cláusula de movimiento de datos"
@@ -36082,7 +36131,7 @@
 msgid "expected function name"
 msgstr "se esperaba nombre de función"
 
-#: c/c-parser.c:14893 cp/parser.c:38064
+#: c/c-parser.c:14893 cp/parser.c:38061
 #, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr "%qD no hace referencia a una función"
@@ -36092,42 +36141,42 @@
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr "%<#pragma acc routine%> no está inmediatamente seguido de una declaración o definición de función"
 
-#: c/c-parser.c:14953 cp/parser.c:38118 cp/parser.c:38160
+#: c/c-parser.c:14953 cp/parser.c:38115 cp/parser.c:38157
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr "%<#pragma acc routine%> no está inmediatamente seguido de una única declaración o definición de función"
 
-#: c/c-parser.c:14970 cp/parser.c:38174
+#: c/c-parser.c:14970 cp/parser.c:38171
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> already applied to %qD"
 msgstr "%<#pragma acc routine%> ya se le aplicó a %qD"
 
-#: c/c-parser.c:14979 cp/parser.c:38183
+#: c/c-parser.c:14979 cp/parser.c:38180
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr "%<#pragma acc routine%> debe aplicarse antes de uso"
 
-#: c/c-parser.c:14980 cp/parser.c:38184
+#: c/c-parser.c:14980 cp/parser.c:38181
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<#pragma acc routine%> debe aplicarse antes de definición"
 
-#: c/c-parser.c:15023 cp/parser.c:37152
+#: c/c-parser.c:15023 cp/parser.c:37149
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr "%<#pragma acc update%> debe contener al menos una cláusula %<device%>, %<host%> o %<self%>"
 
-#: c/c-parser.c:15435 cp/parser.c:34511 cp/parser.c:34537
+#: c/c-parser.c:15435 cp/parser.c:34508 cp/parser.c:34534
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "forma no válida de %<#pragma omp atomic%>"
 
-#: c/c-parser.c:15439 cp/parser.c:34568 cp/parser.c:34584
+#: c/c-parser.c:15439 cp/parser.c:34565 cp/parser.c:34581
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "operador no válido para %<#pragma omp atomic%>"
 
-#: c/c-parser.c:15488 cp/semantics.c:8401 cp/semantics.c:8411
+#: c/c-parser.c:15488 cp/semantics.c:8404 cp/semantics.c:8414
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr "%<#pragma omp atomic capture%> usa dos expresiones diferentes para la memoria"
@@ -36137,22 +36186,22 @@
 msgid "expected %<(%> or end of line"
 msgstr "se esperaba %<(%> o fin de línea"
 
-#: c/c-parser.c:15619 cp/parser.c:35103
+#: c/c-parser.c:15619 cp/parser.c:35100
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr "el parámetro de la cláusula %<ordered%> es menor que %<collapse%>"
 
-#: c/c-parser.c:15630 cp/parser.c:35114
+#: c/c-parser.c:15630 cp/parser.c:35111
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr "la cláusula %<linear%> no puede especificarse junto con la cláusula %<ordered%> con un parámetro"
 
-#: c/c-parser.c:15648 cp/parser.c:35141
+#: c/c-parser.c:15648 cp/parser.c:35138
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "se esperaba una declaración for"
 
-#: c/c-parser.c:15718 cp/semantics.c:8066 cp/semantics.c:8153
+#: c/c-parser.c:15718 cp/semantics.c:8069 cp/semantics.c:8156
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "se esperaba una declaración de iteración o una inicialización"
@@ -36162,73 +36211,73 @@
 msgid "not enough perfectly nested loops"
 msgstr "no hay suficientes bucles perfectamente anidados"
 
-#: c/c-parser.c:15862 cp/parser.c:35364
+#: c/c-parser.c:15862 cp/parser.c:35361
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr "los bucles colapsados no están perfectamente anidados"
 
-#: c/c-parser.c:15909 cp/parser.c:35184 cp/parser.c:35226 cp/pt.c:16385
+#: c/c-parser.c:15909 cp/parser.c:35181 cp/parser.c:35223 cp/pt.c:16407
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "la variable de iteración %qD no debe ser firstprivate"
 
-#: c/c-parser.c:16000 cp/parser.c:35437
+#: c/c-parser.c:16000 cp/parser.c:35434
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "la cláusula %<ordered%> con parámetro no se puede especificar en la construcción %qs"
 
-#: c/c-parser.c:16166 cp/parser.c:35600
+#: c/c-parser.c:16166 cp/parser.c:35597
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr "%<#pragma omp barrier%> sólo se puede usar en declaraciones compuestas"
 
-#: c/c-parser.c:16374 cp/parser.c:35799
+#: c/c-parser.c:16374 cp/parser.c:35796
 #, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "se esperaba %<fork%> después de %qs"
 
-#: c/c-parser.c:16573 cp/parser.c:35995
+#: c/c-parser.c:16573 cp/parser.c:35992
 #, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "se esperaba %<point%>"
 
-#: c/c-parser.c:16793 cp/parser.c:36232
+#: c/c-parser.c:16793 cp/parser.c:36229
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target data%> con map-type distinto de %<to%>, %<from%>, %<tofrom%> y %<alloc%> en la cláusula %<map%>"
 
-#: c/c-parser.c:16806 cp/parser.c:36245
+#: c/c-parser.c:16806 cp/parser.c:36242
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp target data%> debe contener al menos una cláusula %<map%>"
 
-#: c/c-parser.c:16853 cp/parser.c:36470
+#: c/c-parser.c:16853 cp/parser.c:36467
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr "%<#pragma omp target update%> debe contener al menos una cláusula %<from%> o %<to%>"
 
-#: c/c-parser.c:16925 cp/parser.c:36325
+#: c/c-parser.c:16925 cp/parser.c:36322
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target enter data%> con map-type distinto de %<to%> y %<alloc%> en la cláusula %<map%>"
 
-#: c/c-parser.c:16937 cp/parser.c:36337
+#: c/c-parser.c:16937 cp/parser.c:36334
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp target enter data%> debe contener al menos una cláusula %<map%>"
 
-#: c/c-parser.c:17011 cp/parser.c:36414
+#: c/c-parser.c:17011 cp/parser.c:36411
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr "%<#pragma omp target exit data%> con map-type distinto de %<from%>, %<release%> y %<delete%> en la cláusula %<map%>"
 
-#: c/c-parser.c:17024 cp/parser.c:36427
+#: c/c-parser.c:17024 cp/parser.c:36424
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp target exit data%> debe contener al menos una cláusula %<map%>"
 
-#: c/c-parser.c:17238 cp/parser.c:36680
+#: c/c-parser.c:17238 cp/parser.c:36677
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target%> con map-type distinto de %<to%>, %<from%>, %<tofrom%> y %<alloc%> en la cláusula %<map%>"
@@ -36248,32 +36297,32 @@
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr "%<#pragma omp declare simd%> no inmediatamente seguida de una declaración o definición de función"
 
-#: c/c-parser.c:17395 cp/parser.c:37273
+#: c/c-parser.c:17395 cp/parser.c:37270
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr "%<#pragma omp declare simd%> no inmediatamente seguida de una declaración o definición de función sencilla"
 
-#: c/c-parser.c:17474 cp/parser.c:37343
+#: c/c-parser.c:17474 cp/parser.c:37340
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> with clauses in between %<#pragma omp declare target%> without clauses and %<#pragma omp end declare target%>"
 msgstr "%<#pragma omp declare simd%> con cláusulas en medio de %<#pragma omp declare target%> sin cláusulas y %<#pragma omp end declare target%>"
 
-#: c/c-parser.c:17493 cp/parser.c:37362
+#: c/c-parser.c:17493 cp/parser.c:37359
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17534 cp/parser.c:37409
+#: c/c-parser.c:17534 cp/parser.c:37406
 #, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "se esperaba %<target%>"
 
-#: c/c-parser.c:17541 cp/parser.c:37416
+#: c/c-parser.c:17541 cp/parser.c:37413
 #, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "se esperaba %<declare%>"
 
-#: c/c-parser.c:17547 cp/parser.c:37423
+#: c/c-parser.c:17547 cp/parser.c:37420
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr "%<#pragma omp end declare target%> sin su correspondiente %<#pragma omp declare target%>"
@@ -36328,47 +36377,47 @@
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:17947 cp/parser.c:37868
+#: c/c-parser.c:17947 cp/parser.c:37865
 #, gcc-internal-format
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr "se esperaba %<simd%>, %<reduction%> o %<target%>"
 
-#: c/c-parser.c:18162 cp/semantics.c:7531
+#: c/c-parser.c:18162 cp/semantics.c:7534
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE se declaró %<threadprivate%> después del primer uso"
 
-#: c/c-parser.c:18164 cp/semantics.c:7533
+#: c/c-parser.c:18164 cp/semantics.c:7536
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "la variable automática %qE no puede ser %<threadprivate%>"
 
-#: c/c-parser.c:18168 cp/semantics.c:7535
+#: c/c-parser.c:18168 cp/semantics.c:7538
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%<threadprivate%> %qE tiene tipo incompleto"
 
-#: c/c-parser.c:18368 cp/parser.c:38565
+#: c/c-parser.c:18368 cp/parser.c:38562
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr "%<__transaction_cancel%> sin activar el soporte para memoria transaccional"
 
-#: c/c-parser.c:18374 cp/parser.c:38571
+#: c/c-parser.c:18374 cp/parser.c:38568
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr "%<__transaction_cancel%> dentro de un %<__transaction_relaxed%>"
 
-#: c/c-parser.c:18383 cp/parser.c:38580
+#: c/c-parser.c:18383 cp/parser.c:38577
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr "%<__transaction_cancel%> más externo no está dentro del %<__transaction_atomic%> más externo"
 
-#: c/c-parser.c:18385 cp/parser.c:38583
+#: c/c-parser.c:18385 cp/parser.c:38580
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr "  o una función %<transaction_may_cancel_outer%>"
 
-#: c/c-parser.c:18391 cp/parser.c:38589
+#: c/c-parser.c:18391 cp/parser.c:38586
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr "%<__transaction_cancel%> no está dentro de %<__transaction_atomic%>"
@@ -36383,7 +36432,7 @@
 msgid "%qD has an incomplete type %qT"
 msgstr "%qD tiene un tipo de dato incompleto %qT"
 
-#: c/c-typeck.c:237 c/c-typeck.c:9994 c/c-typeck.c:10036 cp/call.c:4147
+#: c/c-typeck.c:237 c/c-typeck.c:9999 c/c-typeck.c:10041 cp/call.c:4147
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "uso no válido de la expresión void"
@@ -36459,12 +36508,12 @@
 msgid "converting an array compound literal to a pointer is ill-formed in C++"
 msgstr "la conversión de una literal compuesta de matriz a un puntero está malformada en C++"
 
-#: c/c-typeck.c:2417 c/c-typeck.c:8641
+#: c/c-typeck.c:2417 c/c-typeck.c:8646
 #, gcc-internal-format
 msgid "%qT has no member named %qE; did you mean %qE?"
 msgstr "%qT no tiene un miembro llamado %qE; ¿quiso decir %qE?"
 
-#: c/c-typeck.c:2421 c/c-typeck.c:8645
+#: c/c-typeck.c:2421 c/c-typeck.c:8650
 #, gcc-internal-format
 msgid "%qT has no member named %qE"
 msgstr "%qT no tiene un miembro llamado %qE"
@@ -36664,460 +36713,460 @@
 msgid "pointer to a function used in subtraction"
 msgstr "se utilizó un puntero a una función en la sustracción"
 
-#: c/c-typeck.c:3847
+#: c/c-typeck.c:3852
 #, gcc-internal-format
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "aritmética en puntero a un tipo de dato incompleto"
 
-#: c/c-typeck.c:3852 cp/typeck.c:5562
+#: c/c-typeck.c:3857 cp/typeck.c:5562
 #, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr "aritmética en puntero a un agregado vacío"
 
-#: c/c-typeck.c:4283
+#: c/c-typeck.c:4288
 #, gcc-internal-format
 msgid "%<~%> on a boolean expression"
 msgstr "%<~%> en una expresión booleana"
 
-#: c/c-typeck.c:4287
+#: c/c-typeck.c:4292
 #, gcc-internal-format
 msgid "did you mean to use logical not?"
 msgstr "¿pretendía utilizar la negación lógica?"
 
-#: c/c-typeck.c:4296
+#: c/c-typeck.c:4301
 #, gcc-internal-format
 msgid "ISO C does not support %<~%> for complex conjugation"
 msgstr "ISO C no admite %<~%> para conjugaciones complejas"
 
-#: c/c-typeck.c:4335
+#: c/c-typeck.c:4340
 #, gcc-internal-format
 msgid "wrong type argument to unary exclamation mark"
 msgstr "argumento de tipo erróneo para el signo de exclamación unario"
 
-#: c/c-typeck.c:4393
+#: c/c-typeck.c:4398
 #, gcc-internal-format
 msgid "increment of enumeration value is invalid in C++"
 msgstr "el incremento de un valor de enumeración es no válido en C++"
 
-#: c/c-typeck.c:4396
+#: c/c-typeck.c:4401
 #, gcc-internal-format
 msgid "decrement of enumeration value is invalid in C++"
 msgstr "el decremento de un valor de enumeración es no válido en C++"
 
-#: c/c-typeck.c:4403
+#: c/c-typeck.c:4408
 #, gcc-internal-format
 msgid "increment of a boolean expression"
 msgstr "incremento de una expresión booleana"
 
-#: c/c-typeck.c:4406
+#: c/c-typeck.c:4411
 #, gcc-internal-format
 msgid "decrement of a boolean expression"
 msgstr "decremento de una expresión booleana"
 
-#: c/c-typeck.c:4422
+#: c/c-typeck.c:4427
 #, gcc-internal-format
 msgid "ISO C does not support %<++%> and %<--%> on complex types"
 msgstr "ISO C no admite %<++%> y %<--%> en tipos complejos"
 
-#: c/c-typeck.c:4447 c/c-typeck.c:4481
+#: c/c-typeck.c:4452 c/c-typeck.c:4486
 #, gcc-internal-format
 msgid "wrong type argument to increment"
 msgstr "argumento de tipo erróneo para el incremento"
 
-#: c/c-typeck.c:4449 c/c-typeck.c:4484
+#: c/c-typeck.c:4454 c/c-typeck.c:4489
 #, gcc-internal-format
 msgid "wrong type argument to decrement"
 msgstr "argumento de tipo erróneo para el decremento"
 
-#: c/c-typeck.c:4469
+#: c/c-typeck.c:4474
 #, gcc-internal-format
 msgid "increment of pointer to an incomplete type %qT"
 msgstr "incremento de puntero a un tipo incompleto %qT"
 
-#: c/c-typeck.c:4473
+#: c/c-typeck.c:4478
 #, gcc-internal-format
 msgid "decrement of pointer to an incomplete type %qT"
 msgstr "decremento de puntero a un tipo incompleto %qT"
 
-#: c/c-typeck.c:4577
+#: c/c-typeck.c:4582
 #, gcc-internal-format
 msgid "taking address of expression of type %<void%>"
 msgstr "se toma la dirección de la expresión de tipo %<id%>"
 
-#: c/c-typeck.c:4636
+#: c/c-typeck.c:4641
 #, gcc-internal-format
 msgid "cannot take address of bit-field %qD"
 msgstr "no se puede tomar la dirección del campo de bits %qD"
 
-#: c/c-typeck.c:4649
+#: c/c-typeck.c:4654
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take the address of an unaligned member"
 msgid "cannot take address of scalar with reverse storage order"
 msgstr "no se puede tomar la dirección de un miembro desalineado"
 
-#: c/c-typeck.c:4657
+#: c/c-typeck.c:4662
 #, fuzzy, gcc-internal-format
 #| msgid "address of register variable %qD requested"
 msgid "address of array with reverse scalar storage order requested"
 msgstr "se solicitó la dirección de la variable de registro %qD"
 
-#: c/c-typeck.c:4838
+#: c/c-typeck.c:4843
 #, gcc-internal-format
 msgid "global register variable %qD used in nested function"
 msgstr "se usó la variable de registro global %qD en la función anidada"
 
-#: c/c-typeck.c:4841
+#: c/c-typeck.c:4846
 #, gcc-internal-format
 msgid "register variable %qD used in nested function"
 msgstr "se usó la variable de registro %qD en la función anidada"
 
-#: c/c-typeck.c:4846
+#: c/c-typeck.c:4851
 #, gcc-internal-format
 msgid "address of global register variable %qD requested"
 msgstr "se solicitó la dirección de la variable de registro global %qD"
 
-#: c/c-typeck.c:4848
+#: c/c-typeck.c:4853
 #, gcc-internal-format
 msgid "address of register variable %qD requested"
 msgstr "se solicitó la dirección de la variable de registro %qD"
 
-#: c/c-typeck.c:4951
+#: c/c-typeck.c:4956
 #, gcc-internal-format
 msgid "non-lvalue array in conditional expression"
 msgstr "matriz no-lvaluada en la expresión condicional"
 
-#: c/c-typeck.c:5033
+#: c/c-typeck.c:5038
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other result of conditional"
 msgstr "conversión implícita de %qT a %qT para coincidir con otro resultado del condicional"
 
-#: c/c-typeck.c:5092 c/c-typeck.c:5098
+#: c/c-typeck.c:5097 c/c-typeck.c:5103
 #, gcc-internal-format
 msgid "operand of ?: changes signedness from %qT to %qT due to unsignedness of other operand"
 msgstr ""
 
-#: c/c-typeck.c:5115
+#: c/c-typeck.c:5120
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr with only one void side"
 msgstr "ISO C prohíbe una expresión condicional con sólo un lado void"
 
-#: c/c-typeck.c:5132
+#: c/c-typeck.c:5137
 #, gcc-internal-format
 msgid "pointers to disjoint address spaces used in conditional expression"
 msgstr "se usaron punteros a espacios de direcciones discontinuos en la expresión condicional"
 
-#: c/c-typeck.c:5143 c/c-typeck.c:5160
+#: c/c-typeck.c:5148 c/c-typeck.c:5165
 #, gcc-internal-format
 msgid "pointer to array loses qualifier in conditional expression"
 msgstr "el puntero a matriz pierde el calificador en la expresión condicional"
 
-#: c/c-typeck.c:5148 c/c-typeck.c:5165
+#: c/c-typeck.c:5153 c/c-typeck.c:5170
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr between %<void *%> and function pointer"
 msgstr "ISO C prohíbe expresiones condicionales entre %<void *%> y punteros de función"
 
-#: c/c-typeck.c:5178
+#: c/c-typeck.c:5183
 #, gcc-internal-format
 msgid "pointer type mismatch in conditional expression"
 msgstr "los tipos de datos punteros no coinciden en la expresión condicional"
 
-#: c/c-typeck.c:5187 c/c-typeck.c:5198
+#: c/c-typeck.c:5192 c/c-typeck.c:5203
 #, gcc-internal-format
 msgid "pointer/integer type mismatch in conditional expression"
 msgstr "los tipos de datos punteros/enteros no coinciden en la expresión condicional"
 
-#: c/c-typeck.c:5336
+#: c/c-typeck.c:5341
 #, gcc-internal-format
 msgid "left-hand operand of comma expression has no effect"
 msgstr "el operador del lado izquierdo de la expresión coma no tiene efecto"
 
-#: c/c-typeck.c:5354 c/c-typeck.c:10636
+#: c/c-typeck.c:5359 c/c-typeck.c:10641
 #, gcc-internal-format
 msgid "right-hand operand of comma expression has no effect"
 msgstr "el operador del lado derecho de la expresión coma no tiene efecto"
 
-#: c/c-typeck.c:5423
+#: c/c-typeck.c:5428
 msgid "cast adds %q#v qualifier to function type"
 msgstr "la conversión agrega el calificador %q#v al tipo de función"
 
-#: c/c-typeck.c:5429
+#: c/c-typeck.c:5434
 msgid "cast discards %qv qualifier from pointer target type"
 msgstr "la conversión descarta el calificador %qv del tipo del destino del puntero"
 
-#: c/c-typeck.c:5464
+#: c/c-typeck.c:5469
 #, gcc-internal-format
 msgid "to be safe all intermediate pointers in cast from %qT to %qT must be %<const%> qualified"
 msgstr "para estar seguro todos los punteros intermedios en la conversión de %qT a %qT se deben calificar como %<const%>"
 
-#: c/c-typeck.c:5554
+#: c/c-typeck.c:5559
 #, gcc-internal-format
 msgid "cast specifies array type"
 msgstr "la conversión especifica el tipo matriz"
 
-#: c/c-typeck.c:5560
+#: c/c-typeck.c:5565
 #, gcc-internal-format
 msgid "cast specifies function type"
 msgstr "la conversión especifica el tipo función"
 
-#: c/c-typeck.c:5575
+#: c/c-typeck.c:5580
 #, gcc-internal-format
 msgid "ISO C forbids casting nonscalar to the same type"
 msgstr "ISO C prohíbe la conversión de un no escalar al mismo tipo"
 
-#: c/c-typeck.c:5595
+#: c/c-typeck.c:5600
 #, gcc-internal-format
 msgid "ISO C forbids casts to union type"
 msgstr "ISO C prohíbe la conversión al tipo union"
 
-#: c/c-typeck.c:5605
+#: c/c-typeck.c:5610
 #, gcc-internal-format
 msgid "cast to union type from type not present in union"
 msgstr "conversión a tipo union desde un tipo no presente en union"
 
-#: c/c-typeck.c:5640
+#: c/c-typeck.c:5645
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint generic address space pointer"
 msgstr "conversión al puntero de espacio de direcciones %s desde un puntero de espacio de direcciones genérico discontinuo"
 
-#: c/c-typeck.c:5645
+#: c/c-typeck.c:5650
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to generic address space pointer from disjoint %s address space pointer"
 msgstr "conversión a un puntero de espacio de direcciones genérico desde un puntero de espacio de direcciones %s discontinuo"
 
-#: c/c-typeck.c:5650
+#: c/c-typeck.c:5655
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint %s address space pointer"
 msgstr "conversión a un puntero de espacio de direcciones %s desde un puntero de espacio de direcciones %s discontinuo"
 
-#: c/c-typeck.c:5670
+#: c/c-typeck.c:5675
 #, gcc-internal-format
 msgid "cast increases required alignment of target type"
 msgstr "la conversión incrementa la alineación requerida del tipo del destino"
 
-#: c/c-typeck.c:5681
+#: c/c-typeck.c:5686
 #, gcc-internal-format
 msgid "cast from pointer to integer of different size"
 msgstr "conversión de puntero a entero de tamaño diferente"
 
-#: c/c-typeck.c:5686
+#: c/c-typeck.c:5691
 #, gcc-internal-format
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "conversión desde una llamada a función de tipo %qT al tipo %qT que no coincide"
 
-#: c/c-typeck.c:5695 cp/typeck.c:7811
+#: c/c-typeck.c:5700 cp/typeck.c:7811
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "conversión a puntero desde un entero de tamaño diferente"
 
-#: c/c-typeck.c:5709
+#: c/c-typeck.c:5714
 #, gcc-internal-format
 msgid "ISO C forbids conversion of function pointer to object pointer type"
 msgstr "ISO C prohíbe la conversión de un apuntador a función a un tipo de objeto apuntador"
 
-#: c/c-typeck.c:5718
+#: c/c-typeck.c:5723
 #, gcc-internal-format
 msgid "ISO C forbids conversion of object pointer to function pointer type"
 msgstr "ISO C prohíbe la conversión de objeto apuntador a un tipo de apuntador a función"
 
-#: c/c-typeck.c:5728
+#: c/c-typeck.c:5733
 #, gcc-internal-format
 msgid "cast between incompatible function types from %qT to %qT"
 msgstr "conversión entre tipos de función incompatibles desde %qT a %qT"
 
-#: c/c-typeck.c:5815
+#: c/c-typeck.c:5820
 #, gcc-internal-format
 msgid "defining a type in a cast is invalid in C++"
 msgstr "definir un tipo en una conversión es no válido en C++"
 
-#: c/c-typeck.c:5856
+#: c/c-typeck.c:5861
 #, gcc-internal-format
 msgid "assignment to expression with array type"
 msgstr "asignación a expresión con tipo matriz"
 
-#: c/c-typeck.c:5982
+#: c/c-typeck.c:5987
 #, gcc-internal-format
 msgid "enum conversion in assignment is invalid in C++"
 msgstr "conversión de enum en una asignación es no válido en C++"
 
-#: c/c-typeck.c:6180 c/c-typeck.c:6202 c/c-typeck.c:6226
+#: c/c-typeck.c:6185 c/c-typeck.c:6207 c/c-typeck.c:6231
 #, gcc-internal-format
 msgid "(near initialization for %qs)"
 msgstr "(cerca de la inicialización de %qs)"
 
-#: c/c-typeck.c:6241
+#: c/c-typeck.c:6246
 #, gcc-internal-format
 msgid "array initialized from parenthesized string constant"
 msgstr "matriz inicializada con una constante de cadena entre paréntesis"
 
-#: c/c-typeck.c:6284 c/c-typeck.c:6476 c/c-typeck.c:6908
+#: c/c-typeck.c:6289 c/c-typeck.c:6481 c/c-typeck.c:6913
 #, gcc-internal-format
 msgid "expected %qT but argument is of type %qT"
 msgstr "se esperaba %qT pero el argumento es de tipo %qT"
 
-#: c/c-typeck.c:6471
+#: c/c-typeck.c:6476
 #, gcc-internal-format
 msgid "enum conversion when passing argument %d of %qE is invalid in C++"
 msgstr "la conversión de enum al pasar el argumento %d de %qE es no válido en C++"
 
-#: c/c-typeck.c:6480
+#: c/c-typeck.c:6485
 #, gcc-internal-format
 msgid "enum conversion from %qT to %qT in assignment is invalid in C++"
 msgstr "la conversión de enum desde %qT a %qT en una asignación no es válida en C++"
 
-#: c/c-typeck.c:6484
+#: c/c-typeck.c:6489
 #, gcc-internal-format
 msgid "enum conversion from %qT to %qT in initialization is invalid in C++"
 msgstr "la conversión de enum desde %qT a %qT en una inicialización no es válida en C++"
 
-#: c/c-typeck.c:6489
+#: c/c-typeck.c:6494
 #, gcc-internal-format
 msgid "enum conversion from %qT to %qT in return is invalid in C++"
 msgstr "la conversión de enum desde %qT a %qT en un return no es válida en C++"
 
-#: c/c-typeck.c:6523
+#: c/c-typeck.c:6528
 #, gcc-internal-format
 msgid "cannot pass rvalue to reference parameter"
 msgstr "no se puede pasar un valor-r a un parámetro de referencia"
 
-#: c/c-typeck.c:6656 c/c-typeck.c:6942
+#: c/c-typeck.c:6661 c/c-typeck.c:6947
 msgid "passing argument %d of %qE makes %q#v qualified function pointer from unqualified"
 msgstr "el paso del argumento %d de %qE hace que la función calificada con %q#v apunte desde una no calificada"
 
-#: c/c-typeck.c:6659 c/c-typeck.c:6945
+#: c/c-typeck.c:6664 c/c-typeck.c:6950
 msgid "assignment makes %q#v qualified function pointer from unqualified"
 msgstr "la asignación hace que la función calificada con %q#v apunte desde una no calificada"
 
-#: c/c-typeck.c:6662 c/c-typeck.c:6947
+#: c/c-typeck.c:6667 c/c-typeck.c:6952
 msgid "initialization makes %q#v qualified function pointer from unqualified"
 msgstr "la inicialización hace que la función calificada con %q#v apunte desde una no calificada"
 
-#: c/c-typeck.c:6665 c/c-typeck.c:6949
+#: c/c-typeck.c:6670 c/c-typeck.c:6954
 msgid "return makes %q#v qualified function pointer from unqualified"
 msgstr "la devolución hace que la función calificada con %q#v apunte desde una no calificada"
 
-#: c/c-typeck.c:6673 c/c-typeck.c:6840 c/c-typeck.c:6883
+#: c/c-typeck.c:6678 c/c-typeck.c:6845 c/c-typeck.c:6888
 msgid "passing argument %d of %qE discards %qv qualifier from pointer target type"
 msgstr "el paso del argumento %d de %qE descarta el calificador %qv del tipo del destino del puntero"
 
-#: c/c-typeck.c:6675 c/c-typeck.c:6842 c/c-typeck.c:6885
+#: c/c-typeck.c:6680 c/c-typeck.c:6847 c/c-typeck.c:6890
 msgid "assignment discards %qv qualifier from pointer target type"
 msgstr "la asignación descarta el calificador %qv del tipo del destino del puntero"
 
-#: c/c-typeck.c:6677 c/c-typeck.c:6844 c/c-typeck.c:6887
+#: c/c-typeck.c:6682 c/c-typeck.c:6849 c/c-typeck.c:6892
 msgid "initialization discards %qv qualifier from pointer target type"
 msgstr "la inicialización descarta el calificador %qv del tipo del destino del puntero"
 
-#: c/c-typeck.c:6679 c/c-typeck.c:6846 c/c-typeck.c:6889
+#: c/c-typeck.c:6684 c/c-typeck.c:6851 c/c-typeck.c:6894
 msgid "return discards %qv qualifier from pointer target type"
 msgstr "la devolución descarta el calificador %qv del tipo del destino del puntero"
 
-#: c/c-typeck.c:6688
+#: c/c-typeck.c:6693
 #, gcc-internal-format
 msgid "ISO C prohibits argument conversion to union type"
 msgstr "ISO C prohíbe la conversión de argumentos a tipo union"
 
-#: c/c-typeck.c:6750
+#: c/c-typeck.c:6755
 #, gcc-internal-format
 msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgstr "no se permite la petición para la conversión implícita de %qT a %qT en C++"
 
-#: c/c-typeck.c:6762
+#: c/c-typeck.c:6767
 #, gcc-internal-format
 msgid "passing argument %d of %qE from pointer to non-enclosed address space"
 msgstr "se pasa el argumento %d de %qE desde un puntero a espacio de direcciones no contenido"
 
-#: c/c-typeck.c:6766
+#: c/c-typeck.c:6771
 #, gcc-internal-format
 msgid "assignment from pointer to non-enclosed address space"
 msgstr "asignación desde puntero a espacio de direcciones no contenido"
 
-#: c/c-typeck.c:6770
+#: c/c-typeck.c:6775
 #, gcc-internal-format
 msgid "initialization from pointer to non-enclosed address space"
 msgstr "inicialización desde puntero a espacio de direcciones no contenido"
 
-#: c/c-typeck.c:6774
+#: c/c-typeck.c:6779
 #, gcc-internal-format
 msgid "return from pointer to non-enclosed address space"
 msgstr "devolución desde puntero a espacio de direcciones no contenido"
 
-#: c/c-typeck.c:6792
+#: c/c-typeck.c:6797
 #, gcc-internal-format
 msgid "argument %d of %qE might be a candidate for a format attribute"
 msgstr "el argumento %d de %qE puede ser un candidato para un atributo de formato"
 
-#: c/c-typeck.c:6798
+#: c/c-typeck.c:6803
 #, gcc-internal-format
 msgid "assignment left-hand side might be a candidate for a format attribute"
 msgstr "el lado izquierdo de la asignación puede ser un candidato para un atributo de formato"
 
-#: c/c-typeck.c:6803
+#: c/c-typeck.c:6808
 #, gcc-internal-format
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "el lado izquierdo de la inicialización puede ser un candidato para un atributo de formato"
 
-#: c/c-typeck.c:6808 cp/typeck.c:8891
+#: c/c-typeck.c:6813 cp/typeck.c:8891
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "el tipo de devolución puede ser un candidato para un atributo de formato"
 
-#: c/c-typeck.c:6857
+#: c/c-typeck.c:6862
 #, gcc-internal-format
 msgid "ISO C forbids passing argument %d of %qE between function pointer and %<void *%>"
 msgstr "ISO C prohíbe el paso del argumento %d de %qE entre un puntero a función y %<void *%>"
 
-#: c/c-typeck.c:6860
+#: c/c-typeck.c:6865
 #, gcc-internal-format
 msgid "ISO C forbids assignment between function pointer and %<void *%>"
 msgstr "ISO C prohíbe la asignación entre un puntero a función y %<void *%>"
 
-#: c/c-typeck.c:6862
+#: c/c-typeck.c:6867
 #, gcc-internal-format
 msgid "ISO C forbids initialization between function pointer and %<void *%>"
 msgstr "ISO C prohíbe la inicialización entre un puntero a función y %<void *%>"
 
-#: c/c-typeck.c:6864
+#: c/c-typeck.c:6869
 #, gcc-internal-format
 msgid "ISO C forbids return between function pointer and %<void *%>"
 msgstr "ISO C prohíbe la devolución entre un puntero a función y %<void *%>"
 
-#: c/c-typeck.c:6904
+#: c/c-typeck.c:6909
 #, gcc-internal-format
 msgid "pointer targets in passing argument %d of %qE differ in signedness"
 msgstr "el puntero que apunta en el paso del argumento %d de %qE difiere en signo"
 
-#: c/c-typeck.c:6913
+#: c/c-typeck.c:6918
 #, gcc-internal-format
 msgid "pointer targets in assignment from %qT to %qT differ in signedness"
 msgstr "el puntero que apunta en la asignación de %qT a %qT difiere en signo"
 
-#: c/c-typeck.c:6918
+#: c/c-typeck.c:6923
 #, gcc-internal-format
 msgid "pointer targets in initialization of %qT from %qT differ in signedness"
 msgstr "el puntero que apunta en la inicialización de %qT a %qT difiere en signo"
 
-#: c/c-typeck.c:6923
+#: c/c-typeck.c:6928
 #, fuzzy, gcc-internal-format
 #| msgid "pointer targets in passing argument %d of %qE differ in signedness"
 msgid "pointer targets in returning %qT from a function with return type %qT differ in signedness"
 msgstr "el puntero que apunta en el paso del argumento %d de %qE difiere en signo"
 
-#: c/c-typeck.c:6961
+#: c/c-typeck.c:6966
 #, gcc-internal-format
 msgid "passing argument %d of %qE from incompatible pointer type"
 msgstr "se pasa el argumento %d de %qE desde un tipo de puntero incompatible"
 
-#: c/c-typeck.c:6967
+#: c/c-typeck.c:6972
 #, gcc-internal-format
 msgid "assignment to %qT from incompatible pointer type %qT"
 msgstr "asignación a %qT desde un tipo de puntero %qT incompatible"
 
-#: c/c-typeck.c:6972
+#: c/c-typeck.c:6977
 #, gcc-internal-format
 msgid "initialization of %qT from incompatible pointer type %qT"
 msgstr "inicialización de %qT desde un tipo de puntero %qT incompatible"
 
-#: c/c-typeck.c:6977
+#: c/c-typeck.c:6982
 #, gcc-internal-format
 msgid "returning %qT from a function with incompatible return type %qT"
 msgstr "se devuelve %qT desde una función con tipo de devolución %qT incompatible"
@@ -37124,803 +37173,803 @@
 
 #. ??? This should not be an error when inlining calls to
 #. unprototyped functions.
-#: c/c-typeck.c:6991 c/c-typeck.c:7514 cp/typeck.c:2063
+#: c/c-typeck.c:6996 c/c-typeck.c:7519 cp/typeck.c:2063
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "uso no válido de matriz no-lvaluada"
 
-#: c/c-typeck.c:7004
+#: c/c-typeck.c:7009
 #, gcc-internal-format
 msgid "passing argument %d of %qE makes pointer from integer without a cast"
 msgstr "el paso del argumento %d de %qE crea un puntero desde un entero sin una conversión"
 
-#: c/c-typeck.c:7010
+#: c/c-typeck.c:7015
 #, gcc-internal-format
 msgid "assignment to %qT from %qT makes pointer from integer without a cast"
 msgstr "la asignación a %qT desde %qT crea un puntero desde un entero sin una conversión"
 
-#: c/c-typeck.c:7015
+#: c/c-typeck.c:7020
 #, gcc-internal-format
 msgid "initialization of %qT from %qT makes pointer from integer without a cast"
 msgstr "la inicialización de %qT desde %qT crea un puntero desde un entero sin una conversión"
 
-#: c/c-typeck.c:7019
+#: c/c-typeck.c:7024
 #, gcc-internal-format
 msgid "returning %qT from a function with return type %qT makes pointer from integer without a cast"
 msgstr "el retorno de %qT desde una función con tipo de retorno %qT crea un puntero desde un entero sin una conversión"
 
-#: c/c-typeck.c:7035
+#: c/c-typeck.c:7040
 #, gcc-internal-format
 msgid "passing argument %d of %qE makes integer from pointer without a cast"
 msgstr "el paso del argumento %d de %qE crea un entero desde un puntero sin una conversión"
 
-#: c/c-typeck.c:7041
+#: c/c-typeck.c:7046
 #, gcc-internal-format
 msgid "assignment to %qT from %qT makes integer from pointer without a cast"
 msgstr "la asignación a %qT desde %qT crea un entero desde un puntero sin una conversión"
 
-#: c/c-typeck.c:7046
+#: c/c-typeck.c:7051
 #, gcc-internal-format
 msgid "initialization of %qT from %qT makes integer from pointer without a cast"
 msgstr "la inicialización de %qT desde %qT crea un entero desde un puntero sin una conversión"
 
-#: c/c-typeck.c:7050
+#: c/c-typeck.c:7055
 #, gcc-internal-format
 msgid "returning %qT from a function with return type %qT makes integer from pointer without a cast"
 msgstr "el retorno de %qT desde una función con tipo de retorno %qT crea un entero desde un puntero sin una conversión"
 
-#: c/c-typeck.c:7073
+#: c/c-typeck.c:7078
 #, gcc-internal-format
 msgid "incompatible type for argument %d of %qE"
 msgstr "tipo incompatible para el argumento %d de %qE"
 
-#: c/c-typeck.c:7078
+#: c/c-typeck.c:7083
 #, gcc-internal-format
 msgid "incompatible types when assigning to type %qT from type %qT"
 msgstr "tipos incompatible en la asignación al tipo %qT del tipo %qT"
 
-#: c/c-typeck.c:7083
+#: c/c-typeck.c:7088
 #, gcc-internal-format
 msgid "incompatible types when initializing type %qT using type %qT"
 msgstr "tipos incompatibles en la inicialización del tipo %qT usando el tipo %qT"
 
-#: c/c-typeck.c:7088
+#: c/c-typeck.c:7093
 #, gcc-internal-format
 msgid "incompatible types when returning type %qT but %qT was expected"
 msgstr "tipos incompatible al devolver el tipo %qT pero se esperaba %qT"
 
-#: c/c-typeck.c:7152
+#: c/c-typeck.c:7157
 #, gcc-internal-format
 msgid "traditional C rejects automatic aggregate initialization"
 msgstr "C tradicional rechaza la inicialización automática de agregados"
 
-#: c/c-typeck.c:7388 c/c-typeck.c:8284 cp/typeck2.c:1045
+#: c/c-typeck.c:7393 c/c-typeck.c:8289 cp/typeck2.c:1045
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "inicialización de un miembro de matriz flexible"
 
-#: c/c-typeck.c:7398 cp/typeck2.c:1059
+#: c/c-typeck.c:7403 cp/typeck2.c:1059
 #, gcc-internal-format
 msgid "char-array initialized from wide string"
 msgstr "matriz de tipo char inicializada con una cadena ancha"
 
-#: c/c-typeck.c:7407
+#: c/c-typeck.c:7412
 #, gcc-internal-format
 msgid "wide character array initialized from non-wide string"
 msgstr "matriz de caracteres anchos inicializada con una cadena que no es ancha"
 
-#: c/c-typeck.c:7413
+#: c/c-typeck.c:7418
 #, gcc-internal-format
 msgid "wide character array initialized from incompatible wide string"
 msgstr "matriz de caracteres anchos inicializada con una cadena ancha incompatible"
 
-#: c/c-typeck.c:7446
+#: c/c-typeck.c:7451
 #, gcc-internal-format
 msgid "array of inappropriate type initialized from string constant"
 msgstr "matriz de tipo inapropiado inicializada con una constante de cadena"
 
-#: c/c-typeck.c:7533 c/c-typeck.c:7557 c/c-typeck.c:7560 c/c-typeck.c:7568
-#: c/c-typeck.c:7608 c/c-typeck.c:9131 c/c-typeck.c:9181
+#: c/c-typeck.c:7538 c/c-typeck.c:7562 c/c-typeck.c:7565 c/c-typeck.c:7573
+#: c/c-typeck.c:7613 c/c-typeck.c:9136 c/c-typeck.c:9186
 #, gcc-internal-format
 msgid "initializer element is not constant"
 msgstr "el elemento inicializador no es una constante"
 
-#: c/c-typeck.c:7542
+#: c/c-typeck.c:7547
 #, gcc-internal-format
 msgid "array initialized from non-constant array expression"
 msgstr "matriz inicializada con una expresión matrizal que no es constante"
 
-#: c/c-typeck.c:7573 c/c-typeck.c:7621 c/c-typeck.c:9191
+#: c/c-typeck.c:7578 c/c-typeck.c:7626 c/c-typeck.c:9196
 #, gcc-internal-format
 msgid "initializer element is not a constant expression"
 msgstr "el elemento inicializador no es una expresión constante"
 
-#: c/c-typeck.c:7615 c/c-typeck.c:9186
+#: c/c-typeck.c:7620 c/c-typeck.c:9191
 #, gcc-internal-format
 msgid "initializer element is not computable at load time"
 msgstr "el elemento inicializador no es calculable al momento de la carga"
 
-#: c/c-typeck.c:7634
+#: c/c-typeck.c:7639
 #, gcc-internal-format
 msgid "invalid initializer"
 msgstr "inicializador no válido"
 
-#: c/c-typeck.c:7912 cp/decl.c:6396
+#: c/c-typeck.c:7917 cp/decl.c:6396
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "no se pueden inicializar los tipos de vector opacos"
 
-#: c/c-typeck.c:8132
+#: c/c-typeck.c:8137
 #, gcc-internal-format
 msgid "extra brace group at end of initializer"
 msgstr "grupo extra de llaves al final del inicializador"
 
-#: c/c-typeck.c:8215
+#: c/c-typeck.c:8220
 #, gcc-internal-format
 msgid "braces around scalar initializer"
 msgstr "llaves alrededor del inicializador escalar"
 
-#: c/c-typeck.c:8281 c/c-typeck.c:9615 cp/typeck2.c:1084 cp/typeck2.c:1297
+#: c/c-typeck.c:8286 c/c-typeck.c:9620 cp/typeck2.c:1084 cp/typeck2.c:1297
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "inicialización de un miembro de matriz flexible en un contexto anidado"
 
-#: c/c-typeck.c:8318
+#: c/c-typeck.c:8323
 #, gcc-internal-format
 msgid "missing braces around initializer"
 msgstr "faltan llaves alrededor del inicializador"
 
-#: c/c-typeck.c:8341
+#: c/c-typeck.c:8346
 #, gcc-internal-format
 msgid "missing initializer for field %qD of %qT"
 msgstr "falta el inicializador para el campo %qD de %qT"
 
-#: c/c-typeck.c:8365
+#: c/c-typeck.c:8370
 #, gcc-internal-format
 msgid "empty scalar initializer"
 msgstr "inicializador escalar vacío"
 
-#: c/c-typeck.c:8370
+#: c/c-typeck.c:8375
 #, gcc-internal-format
 msgid "extra elements in scalar initializer"
 msgstr "elementos extras en el inicializador escalar"
 
-#: c/c-typeck.c:8483 c/c-typeck.c:8565
+#: c/c-typeck.c:8488 c/c-typeck.c:8570
 #, gcc-internal-format
 msgid "array index in non-array initializer"
 msgstr "índice de matriz en el inicializador que no es matriz"
 
-#: c/c-typeck.c:8488 c/c-typeck.c:8627
+#: c/c-typeck.c:8493 c/c-typeck.c:8632
 #, gcc-internal-format
 msgid "field name not in record or union initializer"
 msgstr "el nombre del campo no está en el inicializador de record o union"
 
-#: c/c-typeck.c:8538
+#: c/c-typeck.c:8543
 #, gcc-internal-format
 msgid "array index in initializer not of integer type"
 msgstr "el índice de matriz en el inicializador no es de tipo entero"
 
-#: c/c-typeck.c:8547 c/c-typeck.c:8556
+#: c/c-typeck.c:8552 c/c-typeck.c:8561
 #, gcc-internal-format
 msgid "array index in initializer is not an integer constant expression"
 msgstr "el índice de matriz en el inicializador no es una expresión constante entera"
 
-#: c/c-typeck.c:8561 c/c-typeck.c:8563
+#: c/c-typeck.c:8566 c/c-typeck.c:8568
 #, gcc-internal-format
 msgid "nonconstant array index in initializer"
 msgstr "el índice de matriz no es una constante en el inicializador"
 
-#: c/c-typeck.c:8567 c/c-typeck.c:8570
+#: c/c-typeck.c:8572 c/c-typeck.c:8575
 #, gcc-internal-format
 msgid "array index in initializer exceeds array bounds"
 msgstr "el índice de matriz en el inicializador excede los límites de la matriz"
 
-#: c/c-typeck.c:8589
+#: c/c-typeck.c:8594
 #, gcc-internal-format
 msgid "empty index range in initializer"
 msgstr "rango de índices vacío en el inicializador"
 
-#: c/c-typeck.c:8598
+#: c/c-typeck.c:8603
 #, gcc-internal-format
 msgid "array index range in initializer exceeds array bounds"
 msgstr "el rango de índices de la matriz en el inicializador excede los límites de la matriz"
 
-#: c/c-typeck.c:8700 c/c-typeck.c:8730 c/c-typeck.c:9274
+#: c/c-typeck.c:8705 c/c-typeck.c:8735 c/c-typeck.c:9279
 #, gcc-internal-format
 msgid "initialized field with side-effects overwritten"
 msgstr "campo inicializado con efectos colaterales sobreescritos"
 
-#: c/c-typeck.c:8704 c/c-typeck.c:8734 c/c-typeck.c:9277
+#: c/c-typeck.c:8709 c/c-typeck.c:8739 c/c-typeck.c:9282
 #, gcc-internal-format
 msgid "initialized field overwritten"
 msgstr "campo inicializado sobreescrito"
 
-#: c/c-typeck.c:9208
+#: c/c-typeck.c:9213
 #, gcc-internal-format
 msgid "enum conversion in initialization is invalid in C++"
 msgstr "la conversión de enum en la inicialización es no válida en C++"
 
-#: c/c-typeck.c:9496
+#: c/c-typeck.c:9501
 #, gcc-internal-format
 msgid "excess elements in char array initializer"
 msgstr "exceso de elementos en el inicializador de matriz de caracteres"
 
-#: c/c-typeck.c:9503 c/c-typeck.c:9574
+#: c/c-typeck.c:9508 c/c-typeck.c:9579
 #, gcc-internal-format
 msgid "excess elements in struct initializer"
 msgstr "exceso de elementos en el inicializador de struct"
 
-#: c/c-typeck.c:9518
+#: c/c-typeck.c:9523
 #, gcc-internal-format
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr ""
 
-#: c/c-typeck.c:9589
+#: c/c-typeck.c:9594
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr "inicialización no estática de un miembro de matriz flexible"
 
-#: c/c-typeck.c:9687
+#: c/c-typeck.c:9692
 #, gcc-internal-format
 msgid "excess elements in union initializer"
 msgstr "exceso de elementos en el inicializador de union"
 
-#: c/c-typeck.c:9709
+#: c/c-typeck.c:9714
 #, gcc-internal-format
 msgid "traditional C rejects initialization of unions"
 msgstr "C tradicional rechaza la inicialización de unions"
 
-#: c/c-typeck.c:9777
+#: c/c-typeck.c:9782
 #, gcc-internal-format
 msgid "excess elements in array initializer"
 msgstr "exceso de elementos en el inicializador de matriz"
 
-#: c/c-typeck.c:9811
+#: c/c-typeck.c:9816
 #, gcc-internal-format
 msgid "excess elements in vector initializer"
 msgstr "exceso de elementos en el inicializador de vector"
 
-#: c/c-typeck.c:9843
+#: c/c-typeck.c:9848
 #, gcc-internal-format
 msgid "excess elements in scalar initializer"
 msgstr "exceso de elementos en el inicializador de escalar"
 
-#: c/c-typeck.c:10086
+#: c/c-typeck.c:10091
 #, gcc-internal-format
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C prohíbe %<goto *expr;%>"
 
-#: c/c-typeck.c:10113 c/gimple-parser.c:1604 cp/typeck.c:9113
+#: c/c-typeck.c:10118 c/gimple-parser.c:1604 cp/typeck.c:9113
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "la función declarada %<noreturn%> tiene una declaración %<return%>"
 
-#: c/c-typeck.c:10139 c/c-typeck.c:10143
+#: c/c-typeck.c:10144 c/c-typeck.c:10148
 #, gcc-internal-format
 msgid "%<return%> with no value, in function returning non-void"
 msgstr "%<return%> sin valores, en una función que no devuelve void"
 
-#: c/c-typeck.c:10157 c/gimple-parser.c:1614
+#: c/c-typeck.c:10162 c/gimple-parser.c:1614
 #, gcc-internal-format
 msgid "%<return%> with a value, in function returning void"
 msgstr "%<return%> con valor, en una función que devuelve void"
 
-#: c/c-typeck.c:10160
+#: c/c-typeck.c:10165
 #, gcc-internal-format
 msgid "ISO C forbids %<return%> with expression, in function returning void"
 msgstr "ISO C prohíbe %<return%> con expresión, en una función que devuelve void"
 
-#: c/c-typeck.c:10236
+#: c/c-typeck.c:10241
 #, gcc-internal-format
 msgid "function returns address of label"
 msgstr "la función devuelve la dirección de una etiqueta"
 
-#: c/c-typeck.c:10327 cp/semantics.c:1171
+#: c/c-typeck.c:10332 cp/semantics.c:1171
 #, gcc-internal-format
 msgid "switch quantity not an integer"
 msgstr "la cantidad de switch no es un entero"
 
-#: c/c-typeck.c:10352
+#: c/c-typeck.c:10357
 #, gcc-internal-format
 msgid "%<long%> switch expression not converted to %<int%> in ISO C"
 msgstr "no se convierte la expresión de switch %<long%> a %<int%> en ISO C"
 
-#: c/c-typeck.c:10390 c/c-typeck.c:10398
+#: c/c-typeck.c:10395 c/c-typeck.c:10403
 #, gcc-internal-format
 msgid "case label is not an integer constant expression"
 msgstr "la etiqueta de case no es una expresion constante entera"
 
-#: c/c-typeck.c:10404 cp/parser.c:11067
+#: c/c-typeck.c:10409 cp/parser.c:11067
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "la etiqueta case no se encuentra dentro de una declaración switch"
 
-#: c/c-typeck.c:10406
+#: c/c-typeck.c:10411
 #, gcc-internal-format
 msgid "%<default%> label not within a switch statement"
 msgstr "la etiqueta %<default%> no está dentro de una declaración switch"
 
-#: c/c-typeck.c:10578 cp/parser.c:12356
+#: c/c-typeck.c:10583 cp/parser.c:12353
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "la declaración break no está dentro de un bucle o switch"
 
-#: c/c-typeck.c:10580 cp/parser.c:12379
+#: c/c-typeck.c:10585 cp/parser.c:12376
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "la declaración continue no está dentro de un bucle"
 
-#: c/c-typeck.c:10585 cp/parser.c:12369
+#: c/c-typeck.c:10590 cp/parser.c:12366
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr "se usó la declaración break en un bucle for de OpenMP"
 
-#: c/c-typeck.c:10590
+#: c/c-typeck.c:10595
 #, gcc-internal-format
 msgid "break statement within %<#pragma simd%> loop body"
 msgstr "la declaración break está dentro de un bucle %<#pragma simd%>"
 
-#: c/c-typeck.c:10592
+#: c/c-typeck.c:10597
 #, gcc-internal-format
 msgid "continue statement within %<#pragma simd%> loop body"
 msgstr "la declaración continue está dentro de un bucle %<#pragma simd%>"
 
-#: c/c-typeck.c:10618 cp/cp-gimplify.c:432
+#: c/c-typeck.c:10623 cp/cp-gimplify.c:432
 #, gcc-internal-format
 msgid "statement with no effect"
 msgstr "declaración sin efecto"
 
-#: c/c-typeck.c:10662
+#: c/c-typeck.c:10667
 #, gcc-internal-format
 msgid "expression statement has incomplete type"
 msgstr "la declaración de la expresión tiene tipo de dato incompleto"
 
-#: c/c-typeck.c:11476 c/c-typeck.c:11644 cp/typeck.c:5017
+#: c/c-typeck.c:11481 c/c-typeck.c:11649 cp/typeck.c:5017
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr "se comparan vectores con tipos de elemento diferentes"
 
-#: c/c-typeck.c:11484 c/c-typeck.c:11652 cp/typeck.c:5030
+#: c/c-typeck.c:11489 c/c-typeck.c:11657 cp/typeck.c:5030
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr "se comparan vectores con números de elementos diferentes"
 
-#: c/c-typeck.c:11509 c/c-typeck.c:11677 cp/typeck.c:5058
+#: c/c-typeck.c:11514 c/c-typeck.c:11682 cp/typeck.c:5058
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr "no se puede encontrar un tipo entero del mismo tamaño que %qT"
 
-#: c/c-typeck.c:11523 cp/typeck.c:4743
+#: c/c-typeck.c:11528 cp/typeck.c:4743
 #, gcc-internal-format
 msgid "comparing floating point with == or != is unsafe"
 msgstr "no es segura la comparacion de coma flotante con == o !="
 
-#: c/c-typeck.c:11541 c/c-typeck.c:11562
+#: c/c-typeck.c:11546 c/c-typeck.c:11567
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<false%> for the address of %qD will never be NULL"
 msgstr "la comparación siempre se evalúa como %<false%> para la dirección de %qD que nunca será NULL"
 
-#: c/c-typeck.c:11547 c/c-typeck.c:11568
+#: c/c-typeck.c:11552 c/c-typeck.c:11573
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<true%> for the address of %qD will never be NULL"
 msgstr "la comparación siempre se evalúa como %<true%> para la dirección de %qD que nunca será NULL"
 
-#: c/c-typeck.c:11589 c/c-typeck.c:11718
+#: c/c-typeck.c:11594 c/c-typeck.c:11723
 #, gcc-internal-format
 msgid "comparison of pointers to disjoint address spaces"
 msgstr "la comparación de punteros a espacios de direcciones discontinuos"
 
-#: c/c-typeck.c:11596 c/c-typeck.c:11602
+#: c/c-typeck.c:11601 c/c-typeck.c:11607
 #, gcc-internal-format
 msgid "ISO C forbids comparison of %<void *%> with function pointer"
 msgstr "ISO C prohíbe la comparación de %<void *%> con un puntero de función"
 
-#: c/c-typeck.c:11609 c/c-typeck.c:11728
+#: c/c-typeck.c:11614 c/c-typeck.c:11733
 #, gcc-internal-format
 msgid "comparison of distinct pointer types lacks a cast"
 msgstr "la comparación de diferentes tipos de puntero carece de una conversión"
 
-#: c/c-typeck.c:11621 c/c-typeck.c:11626 c/c-typeck.c:11754 c/c-typeck.c:11759
+#: c/c-typeck.c:11626 c/c-typeck.c:11631 c/c-typeck.c:11759 c/c-typeck.c:11764
 #, gcc-internal-format
 msgid "comparison between pointer and integer"
 msgstr "comparación entre puntero y entero"
 
-#: c/c-typeck.c:11706
+#: c/c-typeck.c:11711
 #, gcc-internal-format
 msgid "comparison of complete and incomplete pointers"
 msgstr "comparación de punteros completos e incompletos"
 
-#: c/c-typeck.c:11708
+#: c/c-typeck.c:11713
 #, gcc-internal-format
 msgid "ISO C forbids ordered comparisons of pointers to functions"
 msgstr "ISO C prohíbe la comparación entre punteros a funciones"
 
-#: c/c-typeck.c:11713
+#: c/c-typeck.c:11718
 #, gcc-internal-format
 msgid "ordered comparison of pointer with null pointer"
 msgstr "comparación ordenada de puntero con un puntero nulo"
 
-#: c/c-typeck.c:11736 c/c-typeck.c:11739 c/c-typeck.c:11746 c/c-typeck.c:11749
+#: c/c-typeck.c:11741 c/c-typeck.c:11744 c/c-typeck.c:11751 c/c-typeck.c:11754
 #: cp/typeck.c:5081 cp/typeck.c:5088
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "comparación ordenada de puntero con el entero cero"
 
-#: c/c-typeck.c:11811
+#: c/c-typeck.c:11816
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
 msgstr "conversión implícita de %qT a %qT para coincidir con otro operando de la expresión binaria"
 
-#: c/c-typeck.c:12126
+#: c/c-typeck.c:12131
 #, gcc-internal-format
 msgid "used array that cannot be converted to pointer where scalar is required"
 msgstr "se usa un valor de tipo matriz que no se puede cambiar a puntero cuando se requiere un escalar"
 
-#: c/c-typeck.c:12130
+#: c/c-typeck.c:12135
 #, gcc-internal-format
 msgid "used struct type value where scalar is required"
 msgstr "se usa un valor de tipo struct cuando se requiere un escalar"
 
-#: c/c-typeck.c:12134
+#: c/c-typeck.c:12139
 #, gcc-internal-format
 msgid "used union type value where scalar is required"
 msgstr "se usa un valor de tipo union cuando se requiere un escalar"
 
-#: c/c-typeck.c:12150
+#: c/c-typeck.c:12155
 #, gcc-internal-format
 msgid "used vector type where scalar is required"
 msgstr "se usa un tipo vector cuando se requiere un escalar"
 
-#: c/c-typeck.c:12340 cp/semantics.c:8508
+#: c/c-typeck.c:12345 cp/semantics.c:8511
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp cancel%> debe especificar una de las cláusulas %<parallel%>, %<for%>, %<sections%> o %<taskgroup%>"
 
-#: c/c-typeck.c:12379 cp/semantics.c:8545
+#: c/c-typeck.c:12384 cp/semantics.c:8548
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp cancellation point%> debe especificar una de las cláusulas %<parallel%>, %<for%>, %<sections%> o %<taskgroup%>"
 
-#: c/c-typeck.c:12423 c/c-typeck.c:13581 c/c-typeck.c:13642 c/c-typeck.c:13704
+#: c/c-typeck.c:12428 c/c-typeck.c:13586 c/c-typeck.c:13647 c/c-typeck.c:13709
 #, gcc-internal-format
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "%<_Atomic%> %qE en cláusula %qs"
 
-#: c/c-typeck.c:12436 c/c-typeck.c:13628 cp/semantics.c:4546
-#: cp/semantics.c:6717
+#: c/c-typeck.c:12441 c/c-typeck.c:13633 cp/semantics.c:4549
+#: cp/semantics.c:6720
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr "campo de bits %qE en cláusula %qs"
 
-#: c/c-typeck.c:12445 c/c-typeck.c:13652 cp/semantics.c:4556
-#: cp/semantics.c:6735
+#: c/c-typeck.c:12450 c/c-typeck.c:13657 cp/semantics.c:4559
+#: cp/semantics.c:6738
 #, gcc-internal-format
 msgid "%qE is a member of a union"
 msgstr "%qE no es un miembro de una unión"
 
-#: c/c-typeck.c:12455 cp/semantics.c:4570 cp/semantics.c:6760
+#: c/c-typeck.c:12460 cp/semantics.c:4573 cp/semantics.c:6763
 #, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD no es una variable en la cláusula %qs"
 
-#: c/c-typeck.c:12459 c/c-typeck.c:13669 cp/semantics.c:4574
-#: cp/semantics.c:6763
+#: c/c-typeck.c:12464 c/c-typeck.c:13674 cp/semantics.c:4577
+#: cp/semantics.c:6766
 #, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qE no es una variable en la cláusula %qs"
 
-#: c/c-typeck.c:12466
+#: c/c-typeck.c:12471
 #, fuzzy, gcc-internal-format
 #| msgid "%Htoo many %qs clauses"
 msgid "%<_Atomic%> %qD in %qs clause"
 msgstr "%Hdemasiadas cláusulas %qs"
 
-#: c/c-typeck.c:12475 c/c-typeck.c:13676 c/c-typeck.c:13778
-#: cp/semantics.c:4591 cp/semantics.c:6769 cp/semantics.c:6931
+#: c/c-typeck.c:12480 c/c-typeck.c:13681 c/c-typeck.c:13783
+#: cp/semantics.c:4594 cp/semantics.c:6772 cp/semantics.c:6934
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD no es una variable en la cláusula %qs"
 
-#: c/c-typeck.c:12511 cp/semantics.c:4623
+#: c/c-typeck.c:12516 cp/semantics.c:4626
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "low bound %qE of array section does not have integral type"
 msgstr "el tamaño de la matriz nueva debe tener un tipo integral"
 
-#: c/c-typeck.c:12518 cp/semantics.c:4630
+#: c/c-typeck.c:12523 cp/semantics.c:4633
 #, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr "la longitud %qE de la sección de matriz no es de tipo integral"
 
-#: c/c-typeck.c:12545 c/c-typeck.c:12609 c/c-typeck.c:12867
-#: cp/semantics.c:4666 cp/semantics.c:4730
+#: c/c-typeck.c:12550 c/c-typeck.c:12614 c/c-typeck.c:12872
+#: cp/semantics.c:4669 cp/semantics.c:4733
 #, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr "sección de matriz de longitud cero en la cláusula %qs"
 
-#: c/c-typeck.c:12564 cp/semantics.c:4685
+#: c/c-typeck.c:12569 cp/semantics.c:4688
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12572 cp/semantics.c:4693
+#: c/c-typeck.c:12577 cp/semantics.c:4696
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12581 c/c-typeck.c:12691 cp/semantics.c:4702
-#: cp/semantics.c:4812
+#: c/c-typeck.c:12586 c/c-typeck.c:12696 cp/semantics.c:4705
+#: cp/semantics.c:4815
 #, fuzzy, gcc-internal-format
 #| msgid "variable length array is used"
 msgid "negative length in array section in %qs clause"
 msgstr "se usó la matriz de longitud variable"
 
-#: c/c-typeck.c:12598 cp/semantics.c:4719
+#: c/c-typeck.c:12603 cp/semantics.c:4722
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12635 cp/semantics.c:4756
+#: c/c-typeck.c:12640 cp/semantics.c:4759
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12650 cp/semantics.c:4771
+#: c/c-typeck.c:12655 cp/semantics.c:4774
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12683 cp/semantics.c:4804
+#: c/c-typeck.c:12688 cp/semantics.c:4807
 #, fuzzy, gcc-internal-format
 #| msgid "for increment expression has no effect"
 msgid "for pointer type length expression must be specified"
 msgstr "la expresión de incremento for no tiene efecto"
 
-#: c/c-typeck.c:12701 c/c-typeck.c:12810 cp/semantics.c:4822
-#: cp/semantics.c:4934
+#: c/c-typeck.c:12706 c/c-typeck.c:12815 cp/semantics.c:4825
+#: cp/semantics.c:4937
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr "la sección de matriz no es contigua en la cláusula %qs"
 
-#: c/c-typeck.c:12709 cp/semantics.c:4830
+#: c/c-typeck.c:12714 cp/semantics.c:4833
 #, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr "%qE no es de tipo puntero o matriz"
 
-#: c/c-typeck.c:13103 c/c-typeck.c:13113
+#: c/c-typeck.c:13108 c/c-typeck.c:13118
 #, gcc-internal-format
 msgid "%qD in %<reduction%> clause is a zero size array"
 msgstr "%qD en la cláusula %<reduction%> es una matriz de tamaño cero"
 
-#: c/c-typeck.c:13130
+#: c/c-typeck.c:13135
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids qualified function types"
 msgid "%<_Atomic%> %qE in %<reduction%> clause"
 msgstr "ISO C prohíbe los tipos de función calificados"
 
-#: c/c-typeck.c:13178
+#: c/c-typeck.c:13183
 #, gcc-internal-format
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "%qE tiene tipo no válido para %<reduction(%s)%>"
 
-#: c/c-typeck.c:13187 cp/semantics.c:5755
+#: c/c-typeck.c:13192 cp/semantics.c:5758
 #, fuzzy, gcc-internal-format
 #| msgid "No label definition found for %qs"
 msgid "user defined reduction not found for %qE"
 msgstr "No se encontró una definición de etiqueta para %qs"
 
-#: c/c-typeck.c:13275
+#: c/c-typeck.c:13280
 #, fuzzy, gcc-internal-format
 #| msgid "variable length array is used"
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "se usó la matriz de longitud variable"
 
-#: c/c-typeck.c:13293 c/c-typeck.c:13836 cp/semantics.c:7249
+#: c/c-typeck.c:13298 c/c-typeck.c:13841 cp/semantics.c:7252
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr "la cláusula %<nowait%> no debe utilizarse junto con %<copyprivate%>"
 
-#: c/c-typeck.c:13305 cp/semantics.c:7289
+#: c/c-typeck.c:13310 cp/semantics.c:7292
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE debe ser %<threadprivate%> para %<copin%>"
 
-#: c/c-typeck.c:13319 cp/semantics.c:5929
+#: c/c-typeck.c:13324 cp/semantics.c:5932
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr ""
 
-#: c/c-typeck.c:13327
+#: c/c-typeck.c:13332
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with type %qT"
 msgstr "cláusula lineal aplicada a variable no puntero no integral con tipo %qT"
 
-#: c/c-typeck.c:13335
+#: c/c-typeck.c:13340
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13354 cp/semantics.c:5999
+#: c/c-typeck.c:13359 cp/semantics.c:6002
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
-#: c/c-typeck.c:13384 c/c-typeck.c:13771 cp/semantics.c:6083
-#: cp/semantics.c:6924
+#: c/c-typeck.c:13389 c/c-typeck.c:13776 cp/semantics.c:6086
+#: cp/semantics.c:6927
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE no es una variable en la cláusula %qs"
 
-#: c/c-typeck.c:13393 cp/semantics.c:6092
+#: c/c-typeck.c:13398 cp/semantics.c:6095
 #, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr "%qD aparece más de una vez en las cláusulas de reducción"
 
-#: c/c-typeck.c:13404 c/c-typeck.c:13434 c/c-typeck.c:13463
+#: c/c-typeck.c:13409 c/c-typeck.c:13439 c/c-typeck.c:13468
 #, gcc-internal-format
 msgid "%qE appears more than once in data clauses"
 msgstr "%qE aparece más de una vez en las cláusulas de datos"
 
-#: c/c-typeck.c:13411 c/c-typeck.c:13440 c/c-typeck.c:13600 c/c-typeck.c:13714
-#: c/c-typeck.c:13720 c/c-typeck.c:13733 c/c-typeck.c:13742
-#: cp/semantics.c:6102 cp/semantics.c:6109 cp/semantics.c:6160
-#: cp/semantics.c:6166 cp/semantics.c:6203 cp/semantics.c:6680
-#: cp/semantics.c:6817 cp/semantics.c:6823 cp/semantics.c:6836
-#: cp/semantics.c:6845
+#: c/c-typeck.c:13416 c/c-typeck.c:13445 c/c-typeck.c:13605 c/c-typeck.c:13719
+#: c/c-typeck.c:13725 c/c-typeck.c:13738 c/c-typeck.c:13747
+#: cp/semantics.c:6105 cp/semantics.c:6112 cp/semantics.c:6163
+#: cp/semantics.c:6169 cp/semantics.c:6206 cp/semantics.c:6683
+#: cp/semantics.c:6820 cp/semantics.c:6826 cp/semantics.c:6839
+#: cp/semantics.c:6848
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr "%qD aparece más de una vez en las cláusulas de datos"
 
-#: c/c-typeck.c:13413 c/c-typeck.c:13442 c/c-typeck.c:13722 c/c-typeck.c:13744
-#: cp/semantics.c:6111 cp/semantics.c:6168 cp/semantics.c:6825
-#: cp/semantics.c:6847
+#: c/c-typeck.c:13418 c/c-typeck.c:13447 c/c-typeck.c:13727 c/c-typeck.c:13749
+#: cp/semantics.c:6114 cp/semantics.c:6171 cp/semantics.c:6828
+#: cp/semantics.c:6850
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears both in data and map clauses"
 msgstr "%qD aparece más de una vez en las cláusulas de datos"
 
-#: c/c-typeck.c:13427 cp/semantics.c:6154
+#: c/c-typeck.c:13432 cp/semantics.c:6157
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "%qE no es una variable en la cláusula %<firstprivate%>"
 
-#: c/c-typeck.c:13456 cp/semantics.c:6197
+#: c/c-typeck.c:13461 cp/semantics.c:6200
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "%qE no es una variable en la cláusula %<lastprivate%>"
 
-#: c/c-typeck.c:13475 cp/semantics.c:6545
+#: c/c-typeck.c:13480 cp/semantics.c:6548
 #, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "%qE no es una variable en la cláusula %<saligned%>"
 
-#: c/c-typeck.c:13482
+#: c/c-typeck.c:13487
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array"
 msgstr "%qE en la cláusula %<aligned%> no es un puntero ni una matriz"
 
-#: c/c-typeck.c:13489
+#: c/c-typeck.c:13494
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%<_Atomic%> %qD in %<aligned%> clause"
 msgstr "%qD no es una variable en la cláusula %qs"
 
-#: c/c-typeck.c:13496
+#: c/c-typeck.c:13501
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr "%qE aparece más de una vez en las cláusulas de datos"
 
-#: c/c-typeck.c:13551 cp/semantics.c:6627
+#: c/c-typeck.c:13556 cp/semantics.c:6630
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr "%qE no es una variable en la cláusula %qs"
 
-#: c/c-typeck.c:13573 cp/semantics.c:6658
+#: c/c-typeck.c:13578 cp/semantics.c:6661
 #, fuzzy, gcc-internal-format
 #| msgid "Array section not permitted in '%s' call at %L"
 msgid "array section does not have mappable type in %qs clause"
 msgstr "No se permite una sección de matriz en la llamada '%s' en %L"
 
-#: c/c-typeck.c:13597 c/c-typeck.c:13731 cp/semantics.c:6677
-#: cp/semantics.c:6834
+#: c/c-typeck.c:13602 c/c-typeck.c:13736 cp/semantics.c:6680
+#: cp/semantics.c:6837
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD aparece más de una vez en las cláusulas de datos"
 
-#: c/c-typeck.c:13603 c/c-typeck.c:13735 cp/semantics.c:6683
-#: cp/semantics.c:6838
+#: c/c-typeck.c:13608 c/c-typeck.c:13740 cp/semantics.c:6686
+#: cp/semantics.c:6841
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD aparece más de una vez en las cláusulas de datos"
 
-#: c/c-typeck.c:13635 cp/semantics.c:6724
+#: c/c-typeck.c:13640 cp/semantics.c:6727
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qE no es una variable en la cláusula %qs"
 
-#: c/c-typeck.c:13695 c/c-typeck.c:13785 cp/semantics.c:6799
-#: cp/semantics.c:6938
+#: c/c-typeck.c:13700 c/c-typeck.c:13790 cp/semantics.c:6802
+#: cp/semantics.c:6941
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD no es una variable en la cláusula %qs"
 
-#: c/c-typeck.c:13766 cp/semantics.c:6918
+#: c/c-typeck.c:13771 cp/semantics.c:6921
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE no es una variable en la cláusula %qs"
 
-#: c/c-typeck.c:13794 cp/semantics.c:6947
+#: c/c-typeck.c:13799 cp/semantics.c:6950
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qE aparece más de una vez en las cláusulas de datos"
 
-#: c/c-typeck.c:13808 cp/semantics.c:6962
+#: c/c-typeck.c:13813 cp/semantics.c:6965
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD no es una variable en la cláusula %qs"
 
-#: c/c-typeck.c:13811 cp/semantics.c:6964
+#: c/c-typeck.c:13816 cp/semantics.c:6967
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qE no es una variable en la cláusula %qs"
 
-#: c/c-typeck.c:13826
+#: c/c-typeck.c:13831
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "la variable %qs no es un puntero ni una matriz"
 
-#: c/c-typeck.c:13900 cp/semantics.c:6359
+#: c/c-typeck.c:13905 cp/semantics.c:6362
 #, gcc-internal-format
 msgid "%<nonmonotonic%> modifier specified for %qs schedule kind"
 msgstr ""
 
-#: c/c-typeck.c:13931 cp/semantics.c:7141
+#: c/c-typeck.c:13936 cp/semantics.c:7144
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr "la cláusula %<inbranch%> es incompatible con %<notinbranch%>"
 
-#: c/c-typeck.c:13981 cp/semantics.c:7332
+#: c/c-typeck.c:13986 cp/semantics.c:7335
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE está predeterminado como %qs para %qs"
 
-#: c/c-typeck.c:14001 cp/semantics.c:7223
+#: c/c-typeck.c:14006 cp/semantics.c:7226
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr "el valor de la cláusula %<simdlen%> es mayor que el valor de la cláusula %<safelen%>"
 
-#: c/c-typeck.c:14013 cp/semantics.c:7236
+#: c/c-typeck.c:14018 cp/semantics.c:7239
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14031 cp/semantics.c:7203
+#: c/c-typeck.c:14036 cp/semantics.c:7206
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14204
+#: c/c-typeck.c:14209
 #, gcc-internal-format
 msgid "cannot use %<va_arg%> with reverse storage order"
 msgstr "no se puede utilizar %<va_arg%> con orden de almacenamiento inverso"
 
-#: c/c-typeck.c:14209
+#: c/c-typeck.c:14214
 #, gcc-internal-format
 msgid "second argument to %<va_arg%> is of incomplete type %qT"
 msgstr "el segundo argumento para %<va_arg%> es del tipo incompleto %qT"
 
-#: c/c-typeck.c:14215
+#: c/c-typeck.c:14220
 #, gcc-internal-format
 msgid "C++ requires promoted type, not enum type, in %<va_arg%>"
 msgstr "C++ requiere un tipo promovido, no un tipo enum, en %<va_arg%>"
@@ -38042,7 +38091,7 @@
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "  no hay una conversión conocida para el argumento %d de %qH a %qI"
 
-#: cp/call.c:3441 cp/pt.c:6495
+#: cp/call.c:3441 cp/pt.c:6509
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -38338,7 +38387,7 @@
 msgid "%q#D is private within this context"
 msgstr "desde este contexto"
 
-#: cp/call.c:6478 cp/decl.c:7343
+#: cp/call.c:6478 cp/decl.c:7364
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "declared private here"
@@ -38350,7 +38399,7 @@
 msgid "%q#D is protected within this context"
 msgstr "desde este contexto"
 
-#: cp/call.c:6486 cp/decl.c:7344
+#: cp/call.c:6486 cp/decl.c:7365
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "declared protected here"
@@ -38684,7 +38733,7 @@
 msgid "call to non-function %qD"
 msgstr "llamada a %qD que no es función"
 
-#: cp/call.c:9119 cp/pt.c:15053 cp/typeck.c:2901
+#: cp/call.c:9119 cp/pt.c:15075 cp/typeck.c:2901
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "no se puede llamar directamente al constructor %<%T::%D%>"
@@ -38921,285 +38970,285 @@
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr "no se puede derivar de la base %<final%> %qT al tipo derivado %qT"
 
-#: cp/class.c:2098
+#: cp/class.c:2103
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr "todos las funciones miembros en la clase %qT son privadas"
 
-#: cp/class.c:2110
+#: cp/class.c:2115
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr "%q#T solamente define un destructor privado y no tiene friends"
 
-#: cp/class.c:2152
+#: cp/class.c:2156
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr "%q#T solamente define constructores privados y no tiene friends"
 
-#: cp/class.c:2156
+#: cp/class.c:2160
 #, gcc-internal-format
 msgid "%q#D is public, but requires an existing %q#T object"
 msgstr ""
 
 # Ojo, no es impostor, sino impositor, el que impone. cfuga
-#: cp/class.c:2430
+#: cp/class.c:2434
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr "no hay un impositor único final para %qD en %qT"
 
-#: cp/class.c:2785
+#: cp/class.c:2789
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D cannot be overloaded"
 msgid "%qD can be marked override"
 msgstr "no se puede sobrecargar %q+#D"
 
-#: cp/class.c:2797
+#: cp/class.c:2801
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D marked final, but is not virtual"
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr "se marca %q+#D como final, pero no es virtual"
 
-#: cp/class.c:2799
+#: cp/class.c:2803
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D marked override, but does not override"
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr "%q+#D se marca como override, pero no hace override"
 
-#: cp/class.c:2861
+#: cp/class.c:2865
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was hidden"
 msgid "%qD was hidden"
 msgstr "%q+D estaba escondido"
 
-#: cp/class.c:2863
+#: cp/class.c:2867
 #, fuzzy, gcc-internal-format
 #| msgid "  by %q+D"
 msgid "  by %qD"
 msgstr "  por %q+D"
 
-#: cp/class.c:2896
+#: cp/class.c:2900
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D invalid; an anonymous union can only have non-static data members"
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "%q+#D no válido; un union anónimo sólo puede tener miembros con datos no estáticos"
 
-#: cp/class.c:2906 cp/name-lookup.c:3293 cp/parser.c:19720
+#: cp/class.c:2910 cp/name-lookup.c:3293 cp/parser.c:19717
 #, fuzzy, gcc-internal-format
 #| msgid "-traditional is deprecated and may be removed"
 msgid "this flexibility is deprecated and will be removed"
 msgstr "-traditional es obsoleto y será eliminado"
 
-#: cp/class.c:3097
+#: cp/class.c:3101
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr ""
 
-#: cp/class.c:3213
+#: cp/class.c:3217
 #, gcc-internal-format
 msgid "bit-field %q+#D with non-integral type"
 msgstr "campo de bits %q+#D con tipo no entero"
 
-#: cp/class.c:3229
+#: cp/class.c:3233
 #, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr "la anchura del campo de bits %q+D no es una constante entera"
 
-#: cp/class.c:3234
+#: cp/class.c:3238
 #, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr "anchura negativa en el campo de bits %q+D"
 
-#: cp/class.c:3239
+#: cp/class.c:3243
 #, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr "anchura cero para el campo de bits %q+D"
 
-#: cp/class.c:3249
+#: cp/class.c:3253
 #, fuzzy, gcc-internal-format
 #| msgid "width of %q+D exceeds its type"
 msgid "width of %qD exceeds its type"
 msgstr "la anchura de %q+D excede su tipo"
 
-#: cp/class.c:3255
+#: cp/class.c:3259
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is too small to hold all values of %q#T"
 msgid "%qD is too small to hold all values of %q#T"
 msgstr "%q+D es demasiado pequeño para contener todos los valores de %q#T"
 
-#: cp/class.c:3316
+#: cp/class.c:3320
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr "no se permite el miembro %q+#D con constructor en la union"
 
-#: cp/class.c:3319
+#: cp/class.c:3323
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr "no se permite el miembro %q+#D con destructor en la union"
 
-#: cp/class.c:3321
+#: cp/class.c:3325
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr "no se permite el miembro %q+#D con operador de asignación de copia en la union"
 
-#: cp/class.c:3325
+#: cp/class.c:3329
 #, gcc-internal-format
 msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgstr "las uniones sin restricción sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/class.c:3453
+#: cp/class.c:3457
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D may not be static because it is a member of a union"
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr "%q+D no debe ser static porque es el miembro de una unión"
 
-#: cp/class.c:3460
+#: cp/class.c:3464
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qD has Java class type"
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr "el dato miembro que no es estático %qD tiene un tipo de clase Java"
 
-#: cp/class.c:3470
+#: cp/class.c:3474
 #, gcc-internal-format
 msgid "field %q+D invalidly declared function type"
 msgstr "el campo %q+D no válidamente se declara como un tipo de función"
 
-#: cp/class.c:3476
+#: cp/class.c:3480
 #, gcc-internal-format
 msgid "field %q+D invalidly declared method type"
 msgstr "el campo %q+D no válidamente se declara como un tipo de método"
 
-#: cp/class.c:3536
+#: cp/class.c:3540
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring packed attribute because of unpacked non-POD field %q+#D"
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr "se descartan los atributos packed por el campo %q+#D sin empacar que no es POD"
 
-#: cp/class.c:3585
+#: cp/class.c:3589
 #, fuzzy, gcc-internal-format
 #| msgid "non-member %qs cannot be declared %<mutable%>"
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr "el no-miembro %qs no se puede declarar %<mutable%>"
 
-#: cp/class.c:3591
+#: cp/class.c:3595
 #, fuzzy, gcc-internal-format
 #| msgid "non-member %qs cannot be declared %<mutable%>"
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr "el no-miembro %qs no se puede declarar %<mutable%>"
 
-#: cp/class.c:3617
+#: cp/class.c:3621
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr "múltiples campos inicializados en la unión %qT"
 
-#: cp/class.c:3658
+#: cp/class.c:3662
 #, fuzzy, gcc-internal-format
 #| msgid "field %q+#D with same name as class"
 msgid "field %q#D with same name as class"
 msgstr "campo %q+#D con el mismo nombre que la clase"
 
-#: cp/class.c:3681
+#: cp/class.c:3685
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr "%q#T tiene miembros punteros a datos"
 
-#: cp/class.c:3686
+#: cp/class.c:3690
 #, gcc-internal-format
 msgid "  but does not override %<%T(const %T&)%>"
 msgstr "  pero no se impone a %<%T(const %T&)%>"
 
-#: cp/class.c:3688
+#: cp/class.c:3692
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr "  o a %<operator=(cont %T&)%>"
 
-#: cp/class.c:3692
+#: cp/class.c:3696
 #, gcc-internal-format
 msgid "  but does not override %<operator=(const %T&)%>"
 msgstr "  pero no se impone a %<operator=(const %T&)%>"
 
-#: cp/class.c:4097
+#: cp/class.c:4101
 #, gcc-internal-format
 msgid "alignment of %qD increased in -fabi-version=9 (GCC 5.2)"
 msgstr ""
 
-#: cp/class.c:4100
+#: cp/class.c:4104
 #, fuzzy, gcc-internal-format
 #| msgid "alignment of %qD is bigger than original declaration"
 msgid "alignment of %qD will increase in -fabi-version=9"
 msgstr "la alineación de %qD es más grande que la declaración original"
 
-#: cp/class.c:4378
+#: cp/class.c:4382
 #, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "se especificó un inicializador para el método %q+D que no es virtual"
 
-#: cp/class.c:4813
+#: cp/class.c:4817
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr "el método anula tanto %<transaction_pure%> como los métodos %qE"
 
-#: cp/class.c:4834
+#: cp/class.c:4838
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr "el método declarado como %qE anula el método %qE"
 
-#: cp/class.c:5350 cp/constexpr.c:237
+#: cp/class.c:5367 cp/constexpr.c:237
 #, fuzzy, gcc-internal-format
 #| msgid "enclosing class of constexpr non-static member function %q+#D is not a literal type"
 msgid "enclosing class of %<constexpr%> non-static member function %q+#D is not a literal type"
 msgstr "la clase envolvente de la función miembro que no es estática constexpr %q+#D no es un tipo literal"
 
-#: cp/class.c:5374
+#: cp/class.c:5391
 #, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr "%q+T no es literal porque:"
 
-#: cp/class.c:5377
+#: cp/class.c:5394
 #, gcc-internal-format
 msgid "  %qT is a closure type, which is only literal in C++17 and later"
 msgstr ""
 
-#: cp/class.c:5380
+#: cp/class.c:5397
 #, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr "  %q+T tiene un destructor que no es trivial"
 
-#: cp/class.c:5387
+#: cp/class.c:5404
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no constexpr constructor that is not a copy or move constructor"
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no %<constexpr%> constructor that is not a copy or move constructor"
 msgstr "  %q+T no es un agregado, no tiene un constructor trivial por defecto y no tiene un constructor constexpr que no es un constructor copy o move"
 
-#: cp/class.c:5420
+#: cp/class.c:5437
 #, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "  la clase base %qT de %q+T no es literal"
 
-#: cp/class.c:5435
+#: cp/class.c:5452
 #, fuzzy, gcc-internal-format
 #| msgid "  non-static data member %q+D has non-literal type"
 msgid "  non-static data member %qD has non-literal type"
 msgstr "  el dato miembro que no es estático %q+D tiene un tipo que no es literal"
 
-#: cp/class.c:5442
+#: cp/class.c:5459
 #, fuzzy, gcc-internal-format
 #| msgid "  non-static data member %q+D has non-literal type"
 msgid "  non-static data member %qD has volatile type"
 msgstr "  el dato miembro que no es estático %q+D tiene un tipo que no es literal"
 
-#: cp/class.c:5561
+#: cp/class.c:5578
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "la clase base %q#T tiene un destructor no virtual"
 
-#: cp/class.c:5590
+#: cp/class.c:5607
 #, fuzzy, gcc-internal-format
 #| msgid "non-static reference %q+#D in class without a constructor"
 msgid "non-static reference %q#D in class without a constructor"
 msgstr "referencia %q+#D que no es static en una clase sin un constructor"
 
-#: cp/class.c:5596
+#: cp/class.c:5613
 #, fuzzy, gcc-internal-format
 #| msgid "non-static const member %q+#D in class without a constructor"
 msgid "non-static const member %q#D in class without a constructor"
@@ -39207,165 +39256,165 @@
 
 #. If the function is defaulted outside the class, we just
 #. give the synthesis error.
-#: cp/class.c:5624
+#: cp/class.c:5641
 #, gcc-internal-format
 msgid "%q+D declared to take const reference, but implicit declaration would take non-const"
 msgstr "se declaró %q+D para tomar referencia const, pero la declaración implícita tomaría algo que no es const"
 
-#: cp/class.c:5898
+#: cp/class.c:5915
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr "base directa %qT inaccesible en %qT debido a ambigüedad"
 
-#: cp/class.c:5910
+#: cp/class.c:5927
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr "base virtual %qT inaccesible en %qT debido a ambigüedad"
 
-#: cp/class.c:6133
+#: cp/class.c:6150
 #, fuzzy, gcc-internal-format
 #| msgid "offset of %q+D is not ABI-compliant and may change in a future version of GCC"
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr "el desplazamiento de %q+D no cumple con la ABI y puede cambiar en una versión futura de GCC"
 
-#: cp/class.c:6291
+#: cp/class.c:6308
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qE is too large"
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr "el tamaño de la matriz %qE es demasiado grande"
 
-#: cp/class.c:6576
+#: cp/class.c:6593
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<...%> with non-slice"
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr "uso no válido de %<...%> con algo que no es rebanada"
 
-#: cp/class.c:6578
+#: cp/class.c:6595
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of structure with flexible array member"
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr "uso no válido de una estructura con un miembro de matriz flexible"
 
-#: cp/class.c:6583
+#: cp/class.c:6600
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "array member %q#D declared here"
 msgstr "  %q+#D se declaró aquí"
 
-#: cp/class.c:6610
+#: cp/class.c:6627
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member not at end of struct"
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr "el miembro de matriz flexible no está al final del struct"
 
-#: cp/class.c:6612
+#: cp/class.c:6629
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member in otherwise empty struct"
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr "el miembro de matriz flexible sería de otra manera un struct vacío"
 
-#: cp/class.c:6620 cp/class.c:6650
+#: cp/class.c:6637 cp/class.c:6667
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %q#T"
 msgid "in the definition of %q#T"
 msgstr "redefinición de %q#T"
 
-#: cp/class.c:6628
+#: cp/class.c:6645
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member not at end of struct"
 msgid "flexible array member %qD not at end of %q#T"
 msgstr "el miembro de matriz flexible no está al final del struct"
 
-#: cp/class.c:6630
+#: cp/class.c:6647
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member in otherwise empty struct"
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr "el miembro de matriz flexible sería de otra manera un struct vacío"
 
-#: cp/class.c:6648
+#: cp/class.c:6665
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "next member %q#D declared here"
 msgstr "  %q+#D se declaró aquí"
 
-#: cp/class.c:6760 cp/parser.c:23239
+#: cp/class.c:6777 cp/parser.c:23236
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "redefinición de %q#T"
 
-#: cp/class.c:6897
+#: cp/class.c:6914
 #, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "%q#T tiene funciones virtuales y destructor no virtual accesible"
 
-#: cp/class.c:6925
+#: cp/class.c:6942
 #, fuzzy, gcc-internal-format
 #| msgid "type transparent class %qT does not have any fields"
 msgid "type transparent %q#T does not have any fields"
 msgstr "la clase transparente tipo %qT no tiene ningún campo"
 
-#: cp/class.c:6931
+#: cp/class.c:6948
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr "la clase transparente tipo %qT tiene clases base"
 
-#: cp/class.c:6935
+#: cp/class.c:6952
 #, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr "la clase transparente tipo %qT tiene funciones virtuales"
 
-#: cp/class.c:6941
+#: cp/class.c:6958
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:7071
+#: cp/class.c:7088
 #, fuzzy, gcc-internal-format
 #| msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
 msgid "definition of %qD does not match %<#include <initializer_list>%>"
 msgstr "la deducción de una lista inicializadora encerrada entre llaves requiere #include <initializer_list>"
 
-#: cp/class.c:7082
+#: cp/class.c:7099
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr "se trató de terminar struct, pero fue sacado debido a errores previos de decodificación"
 
-#: cp/class.c:7582
+#: cp/class.c:7599
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "no se reconoce la cadena de lenguaje %<\"%E\"%>"
 
-#: cp/class.c:7672
+#: cp/class.c:7689
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr "no se puede resolver la función sobrecargada %qD basándose en la conversión al tipo %qT"
 
-#: cp/class.c:7817
+#: cp/class.c:7834
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr "no hay coincidencias al convertir la función %qD al tipo %q#T"
 
-#: cp/class.c:7844
+#: cp/class.c:7861
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "la conversión de la función sobrecargada %qD al tipo %q#T es ambigua"
 
-#: cp/class.c:7870
+#: cp/class.c:7887
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "asumiendo el puntero a miembro %qD"
 
-#: cp/class.c:7873
+#: cp/class.c:7890
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(un puntero a miembro solamente se puede formar con %<&%E%>)"
 
-#: cp/class.c:7948 cp/class.c:7990
+#: cp/class.c:7965 cp/class.c:8007
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "no hay suficiente información de tipo"
 
-#: cp/class.c:7968
+#: cp/class.c:7985
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "no se puede convertir %qE desde el tipo %qT al tipo %qT"
@@ -39375,12 +39424,12 @@
 #. A name N used in a class S shall refer to the same declaration
 #. in its context and when re-evaluated in the completed scope of
 #. S.
-#: cp/class.c:8235
+#: cp/class.c:8252
 #, gcc-internal-format
 msgid "declaration of %q#D"
 msgstr "la declaración de %q#D"
 
-#: cp/class.c:8237
+#: cp/class.c:8254
 #, fuzzy, gcc-internal-format
 #| msgid "changes meaning of %qD from %q+#D"
 msgid "changes meaning of %qD from %q#D"
@@ -39820,17 +39869,17 @@
 msgid "unexpected AST of kind %s"
 msgstr "AST inesperado de género %s"
 
-#: cp/cp-gimplify.c:1415
+#: cp/cp-gimplify.c:1416
 #, gcc-internal-format
 msgid "throw will always call terminate()"
 msgstr ""
 
-#: cp/cp-gimplify.c:1418
+#: cp/cp-gimplify.c:1419
 #, gcc-internal-format
 msgid "in C++11 destructors default to noexcept"
 msgstr ""
 
-#: cp/cp-gimplify.c:1429
+#: cp/cp-gimplify.c:1430
 #, gcc-internal-format
 msgid "in C++11 this throw will terminate because destructors default to noexcept"
 msgstr ""
@@ -40257,7 +40306,7 @@
 msgid "redeclaration %qD differs in %<constexpr%> from previous declaration"
 msgstr "la redeclaración de %qD difiere en %<constexpr%>"
 
-#: cp/decl.c:1304 cp/decl.c:13843
+#: cp/decl.c:1304 cp/decl.c:13867
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D"
 msgid "previous declaration %qD"
@@ -40617,7 +40666,7 @@
 msgid "  enters OpenMP structured block"
 msgstr "  entra al bloque estructurado OpenMP"
 
-#: cp/decl.c:3434 cp/parser.c:12366 cp/parser.c:12387
+#: cp/decl.c:3434 cp/parser.c:12363 cp/parser.c:12384
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr "salida no válida de un bloque estructurado OpenMP"
@@ -40627,7 +40676,7 @@
 msgid "%qD is not a type"
 msgstr "%qD no es un tipo"
 
-#: cp/decl.c:3838 cp/parser.c:6366
+#: cp/decl.c:3838 cp/parser.c:6369
 #, gcc-internal-format
 msgid "%qD used without template parameters"
 msgstr "se usa %qD sin parámetros de plantilla"
@@ -41028,8 +41077,8 @@
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr "asignador C99 %qE fuera del inicializador agregado"
 
-#: cp/decl.c:6011 cp/decl.c:6234 cp/typeck2.c:1310 cp/typeck2.c:1590
-#: cp/typeck2.c:1638 cp/typeck2.c:1685
+#: cp/decl.c:6011 cp/decl.c:6234 cp/typeck2.c:1310 cp/typeck2.c:1593
+#: cp/typeck2.c:1641 cp/typeck2.c:1688
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "demasiados inicializadores para %qT"
@@ -41106,13 +41155,13 @@
 msgid "assignment (not initialization) in declaration"
 msgstr "asignación (no inicialización) en la declaración"
 
-#: cp/decl.c:6873 cp/decl.c:12605
+#: cp/decl.c:6873 cp/decl.c:12629
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C++ no permite inicializadores designados"
 
-#: cp/decl.c:6877 cp/decl.c:12609
+#: cp/decl.c:6877 cp/decl.c:12633
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for %qs"
 msgid "%<register%> storage class specifier used"
@@ -41140,46 +41189,46 @@
 msgid "function %q#D is initialized like a variable"
 msgstr "la función %q#D se inicializa como una variable"
 
-#: cp/decl.c:7329
+#: cp/decl.c:7350
 #, fuzzy, gcc-internal-format
 #| msgid "  cannot use obsolete binding at %q+D because it has a destructor"
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "  no se puede usar la asignación obsoleta en %q+D porque tiene un destructor"
 
-#: cp/decl.c:7332
+#: cp/decl.c:7353
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.c:7339
+#: cp/decl.c:7360
 #, fuzzy, gcc-internal-format
 #| msgid "cannot form pointer to member of non-class %q#T"
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "no se puede formar un puntero al miembro de %q#T que no es clase"
 
-#: cp/decl.c:7365
+#: cp/decl.c:7386
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:7374
+#: cp/decl.c:7395
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:7592
+#: cp/decl.c:7613
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing pointer to incomplete type"
 msgid "structured binding refers to incomplete type %qT"
 msgstr "puntero deferenciado a tipo de dato incompleto"
 
-#: cp/decl.c:7608
+#: cp/decl.c:7629
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable length array %qE"
 msgid "cannot decompose variable length array %qT"
 msgstr "ISO C90 prohíbe la matriz de longitud variable %qE"
 
-#: cp/decl.c:7617 cp/decl.c:7702
+#: cp/decl.c:7638 cp/decl.c:7723
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qs specified for structure field"
 msgid "%u name provided for structured binding"
@@ -41187,7 +41236,7 @@
 msgstr[0] "se especificó %qs para el campo de estructura"
 msgstr[1] "se especificó %qs para el campo de estructura"
 
-#: cp/decl.c:7621
+#: cp/decl.c:7642
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid initializer for bit string"
 msgid "only %u name provided for structured binding"
@@ -41195,7 +41244,7 @@
 msgstr[0] "inicializador no válido para la cadena de bits"
 msgstr[1] "inicializador no válido para la cadena de bits"
 
-#: cp/decl.c:7624
+#: cp/decl.c:7645
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
@@ -41202,264 +41251,264 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:7669
+#: cp/decl.c:7690
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable length array %qE"
 msgid "cannot decompose variable length vector %qT"
 msgstr "ISO C90 prohíbe la matriz de longitud variable %qE"
 
-#: cp/decl.c:7695
+#: cp/decl.c:7716
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "el tamaño de la matriz no es una expresion constante integral"
 
-#: cp/decl.c:7704
+#: cp/decl.c:7725
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.c:7725
+#: cp/decl.c:7746
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type for iteration variable %qE"
 msgid "in initialization of structured binding variable %qD"
 msgstr "tipo no válido para la variable de iteración %qE"
 
-#: cp/decl.c:7751
+#: cp/decl.c:7772
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to qualified function type %qT"
 msgid "cannot decompose union type %qT"
 msgstr "no se puede declarar el puntero para el tipo de función calificado %qT"
 
-#: cp/decl.c:7756
+#: cp/decl.c:7777
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "se crea un puntero al miembro del tipo %qT que no es clase"
 
-#: cp/decl.c:7761
+#: cp/decl.c:7782
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to qualified function type %qT"
 msgid "cannot decompose lambda closure type %qT"
 msgstr "no se puede declarar el puntero para el tipo de función calificado %qT"
 
-#: cp/decl.c:7765
+#: cp/decl.c:7786
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing pointer to incomplete type"
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "puntero deferenciado a tipo de dato incompleto"
 
-#: cp/decl.c:7774
+#: cp/decl.c:7795
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply %<offsetof%> to static data member %qD"
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "no se puede aplicar %<offsetof%> al dato miembro static %qD"
 
-#: cp/decl.c:8213
+#: cp/decl.c:8234
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:8216
+#: cp/decl.c:8237
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+T has a non-trivial destructor"
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr "  %q+T tiene un destructor que no es trivial"
 
-#: cp/decl.c:8222
+#: cp/decl.c:8243
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:8450
+#: cp/decl.c:8471
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "el inicializador no puede determinar el tamaño de %qT"
 
-#: cp/decl.c:8454
+#: cp/decl.c:8475
 #, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "falta el tamaño de la matriz en %qT"
 
-#: cp/decl.c:8457
+#: cp/decl.c:8478
 #, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "matriz %qT de tamaño cero"
 
-#: cp/decl.c:8473
+#: cp/decl.c:8494
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "el destructor para la clase extranjera %qT no puede ser un miembro"
 
-#: cp/decl.c:8475
+#: cp/decl.c:8496
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "el constructor para la clase extranjera %qT no puede ser un miembro"
 
-#: cp/decl.c:8499
+#: cp/decl.c:8520
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD se declaró como una variable %<virtual%>"
 
-#: cp/decl.c:8501
+#: cp/decl.c:8522
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "los especificadores de función %<const%> y %<volatile%> en %qD son no válidos en la declaración de variable"
 
-#: cp/decl.c:8506
+#: cp/decl.c:8527
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD se declaró como un parámetro %<virtual%>"
 
-#: cp/decl.c:8508
+#: cp/decl.c:8529
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD se declaró como un parámetro %<inline%>"
 
-#: cp/decl.c:8510
+#: cp/decl.c:8531
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "los especificadores de función %<const%> y %<volatile%> en %qD son no válidos en la declaración de parámetro"
 
-#: cp/decl.c:8515
+#: cp/decl.c:8536
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD se declaró como un tipo %<virtual%>"
 
-#: cp/decl.c:8517
+#: cp/decl.c:8538
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD se declaró como un tipo %<inline%>"
 
-#: cp/decl.c:8519
+#: cp/decl.c:8540
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "los especificadores de función %<const%> y %<volatile%> en %qD son no válidos en la declaración de tipo"
 
-#: cp/decl.c:8524
+#: cp/decl.c:8545
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD se declaró como un campo %<virtual%>"
 
-#: cp/decl.c:8526
+#: cp/decl.c:8547
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD se declaró como un campo %<inline%>"
 
-#: cp/decl.c:8528
+#: cp/decl.c:8549
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "los especificadores de función %<const%> y %<volatile%> en %qD son no válidos en la declaración de campo"
 
-#: cp/decl.c:8535
+#: cp/decl.c:8556
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D se declaró como friend"
 
-#: cp/decl.c:8542
+#: cp/decl.c:8563
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D se declaró con una especificación de excepción"
 
-#: cp/decl.c:8574
+#: cp/decl.c:8595
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "la definición de %qD no está en un espacio de nombres que contenga a %qT"
 
-#: cp/decl.c:8614
+#: cp/decl.c:8635
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "la función miembro static %q#D se declara con calificadores de tipo"
 
-#: cp/decl.c:8624
+#: cp/decl.c:8645
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a non-parameter"
 msgid "concept %q#D declared with function parameters"
 msgstr "%qD se declaró como un no-parámetro"
 
-#: cp/decl.c:8630
+#: cp/decl.c:8651
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD declared with void type"
 msgid "concept %q#D declared with a deduced return type"
 msgstr "el parámetro %qD se declaró con tipo void"
 
-#: cp/decl.c:8632
+#: cp/decl.c:8653
 #, fuzzy, gcc-internal-format
 #| msgid "Java method %qD has non-Java return type %qT"
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "el método Java %qD tiene un tipo de devolución %qT que no es de Java"
 
-#: cp/decl.c:8703
+#: cp/decl.c:8724
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%> after union definition"
 msgid "concept %qD has no definition"
 msgstr "se esperaba %<;%> después de la definición de union"
 
-#: cp/decl.c:8772
+#: cp/decl.c:8793
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "definiendo la especialización explícita %qD en la declaración friend"
 
 #. Something like `template <class T> friend void f<T>()'.
-#: cp/decl.c:8782
+#: cp/decl.c:8803
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "uso no válido del id de plantilla %qD en la declaración de la plantilla primaria"
 
-#: cp/decl.c:8800
+#: cp/decl.c:8821
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "no se permiten los argumentos por defecto en la declaración de la especialización friend de la plantilla %qD"
 
-#: cp/decl.c:8808
+#: cp/decl.c:8829
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "no se permite %<inline%> en la declaración de la especialización friend de la plantilla %qD"
 
-#: cp/decl.c:8857
+#: cp/decl.c:8878
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "no se puede declarar %<::main%> como plantilla"
 
-#: cp/decl.c:8859
+#: cp/decl.c:8880
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "no se puede declarar %<::main%> como inline"
 
-#: cp/decl.c:8861
+#: cp/decl.c:8882
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be inline"
 msgid "cannot declare %<::main%> to be %<constexpr%>"
 msgstr "no se puede declarar %<::main%> como inline"
 
-#: cp/decl.c:8863
+#: cp/decl.c:8884
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "no se puede declarar %<::main%> como static"
 
-#: cp/decl.c:8920
+#: cp/decl.c:8941
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "la función miembro static %qD no puede tener calificador-cv"
 
-#: cp/decl.c:8921
+#: cp/decl.c:8942
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "la función que no es miembro %qD no puede tener calificador-cv"
 
-#: cp/decl.c:8929
+#: cp/decl.c:8950
 #, fuzzy, gcc-internal-format
 #| msgid "static member function %qD cannot have cv-qualifier"
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "la función miembro static %qD no puede tener calificador-cv"
 
-#: cp/decl.c:8930
+#: cp/decl.c:8951
 #, fuzzy, gcc-internal-format
 #| msgid "non-member function %qD cannot have cv-qualifier"
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "la función que no es miembro %qD no puede tener calificador-cv"
 
-#: cp/decl.c:8940
+#: cp/decl.c:8961
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %qD must appear at namespace scope"
 msgid "deduction guide %qD must be declared at namespace scope"
@@ -41466,672 +41515,672 @@
 msgstr "la especialización de %qD debe aparecer en un ámbito de espacio de nombres"
 
 #  FIXME traducción
-#: cp/decl.c:8946
+#: cp/decl.c:8967
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "deduction guide %qD must not have a function body"
 msgstr "la declaración de %qD como algo que no es función"
 
-#: cp/decl.c:8959
+#: cp/decl.c:8980
 #, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr "operador literal con enlace C"
 
-#: cp/decl.c:8969
+#: cp/decl.c:8990
 #, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "%qD tien una lista de argumentos no válida"
 
-#: cp/decl.c:8977
+#: cp/decl.c:8998
 #, fuzzy, gcc-internal-format
 #| msgid "integer suffix %<%s%> shadowed by implementation"
 msgid "integer suffix %qs shadowed by implementation"
 msgstr "se oscurece el sufijo entero %<%s%> por la implementación"
 
-#: cp/decl.c:8983
+#: cp/decl.c:9004
 #, fuzzy, gcc-internal-format
 #| msgid "floating point suffix %<%s%> shadowed by implementation"
 msgid "floating point suffix %qs shadowed by implementation"
 msgstr "se oscurece el sufijo de coma flotante %<%s%> por la implementación"
 
-#: cp/decl.c:8991
+#: cp/decl.c:9012
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr "los sufijos de operador literal que no están precedidos por %<_%> están reservados para estandarización futura"
 
-#: cp/decl.c:8996
+#: cp/decl.c:9017
 #, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "%qD debe ser una función que no sea miembro"
 
-#: cp/decl.c:9076
+#: cp/decl.c:9097
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> debe devolver %<int%>"
 
-#: cp/decl.c:9116
+#: cp/decl.c:9137
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "la definición de %qD declarado implícitamente"
 
-#: cp/decl.c:9121
+#: cp/decl.c:9142
 #, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "la definición de %qD explícitamente por defecto"
 
-#: cp/decl.c:9123
+#: cp/decl.c:9144
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D explicitly defaulted here"
 msgid "%q#D explicitly defaulted here"
 msgstr "%q+#D explícitamente por defecto aquí"
 
-#: cp/decl.c:9140
+#: cp/decl.c:9161
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "no hay una función miembro %q#D declarada en la clase %qT"
 
-#: cp/decl.c:9329
+#: cp/decl.c:9350
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be a template"
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "no se puede declarar %<::main%> como plantilla"
 
-#: cp/decl.c:9337
+#: cp/decl.c:9358
 #, fuzzy, gcc-internal-format
 #| msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "la variable automática %qE no puede ser %<threadprivate%>"
 
-#: cp/decl.c:9344
+#: cp/decl.c:9365
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.c:9464
+#: cp/decl.c:9485
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "inicialización en la clase del miembro de datos static %q#D de tipo incompleto"
 
-#: cp/decl.c:9468
+#: cp/decl.c:9489
 #, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "se necesita %<constexpr%> para la inicialización en la clase no válida del miembro de datos static %q#D de tipo que no es integral"
 
-#: cp/decl.c:9472
+#: cp/decl.c:9493
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "inicialización en la clase del miembro de datos static %q#D de tipo que no es literal"
 
-#: cp/decl.c:9486
+#: cp/decl.c:9507
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "inicialización en la clase no válida para el miembro de datos static de tipo %qT que no es integral"
 
-#: cp/decl.c:9493
+#: cp/decl.c:9514
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ISO C++ prohíbe la inicialización en la clase del miembro static %qD que no es constante"
 
-#: cp/decl.c:9498
+#: cp/decl.c:9519
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO C++ prohíbe la inicialización de la constante miembro %qD del tipo %qT que no es entero"
 
-#: cp/decl.c:9598
+#: cp/decl.c:9619
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "el tamaño de la matriz %qD tiene un tipo %qT que no es integral"
 
-#: cp/decl.c:9600
+#: cp/decl.c:9621
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "el tamaño de la matriz tiene un tipo %qT que no es integral"
 
-#: cp/decl.c:9630 cp/decl.c:9680
+#: cp/decl.c:9651 cp/decl.c:9701
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "el tamaño de la matriz no es una expresion constante integral"
 
-#: cp/decl.c:9646
+#: cp/decl.c:9667
 #, gcc-internal-format
 msgid "size of array %qD is negative"
 msgstr "el tamaño de la matriz %qD es negativo"
 
-#: cp/decl.c:9648 cp/init.c:3651
+#: cp/decl.c:9669 cp/init.c:3667
 #, gcc-internal-format
 msgid "size of array is negative"
 msgstr "el tamaño de la matriz es negativo"
 
-#: cp/decl.c:9662
+#: cp/decl.c:9683
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C++ prohíbe la matriz %qD de tamaño cero"
 
-#: cp/decl.c:9664
+#: cp/decl.c:9685
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++ prohíbe matrices de tamaño cero"
 
-#: cp/decl.c:9677
+#: cp/decl.c:9698
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "el tamaño de la matriz %qD no es una expresion constante integral"
 
-#: cp/decl.c:9686
+#: cp/decl.c:9707
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++ prohíbe la matriz %qD de longitud variable"
 
-#: cp/decl.c:9688
+#: cp/decl.c:9709
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++ prohíbe las matrices de longitud variable"
 
-#: cp/decl.c:9694
+#: cp/decl.c:9715
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr "se usa la matriz de longitud variable %qD"
 
-#: cp/decl.c:9697
+#: cp/decl.c:9718
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr "se usó la matriz de longitud variable"
 
-#: cp/decl.c:9746
+#: cp/decl.c:9767
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "desbordamiento en la dimensión de la matriz"
 
-#: cp/decl.c:9799
+#: cp/decl.c:9820
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "%qD declared as array of %qT"
 msgstr "%q+D se declaró como friend"
 
-#: cp/decl.c:9809
+#: cp/decl.c:9830
 #, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "la declaración de %qD como una matriz de voids"
 
-#: cp/decl.c:9811
+#: cp/decl.c:9832
 #, gcc-internal-format
 msgid "creating array of void"
 msgstr "se crea la matriz de voids"
 
-#: cp/decl.c:9816
+#: cp/decl.c:9837
 #, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "la declaración de %qD como una matriz de funciones"
 
-#: cp/decl.c:9818
+#: cp/decl.c:9839
 #, gcc-internal-format
 msgid "creating array of functions"
 msgstr "se crea la matriz de funciones"
 
-#: cp/decl.c:9823
+#: cp/decl.c:9844
 #, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "la declaración de %qD como una matriz de referencias"
 
-#: cp/decl.c:9825
+#: cp/decl.c:9846
 #, gcc-internal-format
 msgid "creating array of references"
 msgstr "se crea la matriz de referencias"
 
-#: cp/decl.c:9830
+#: cp/decl.c:9851
 #, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "la declaración de %qD como una matriz de miembros de función"
 
-#: cp/decl.c:9832
+#: cp/decl.c:9853
 #, gcc-internal-format
 msgid "creating array of function members"
 msgstr "se crea la matriz de miembros de función"
 
-#: cp/decl.c:9846
+#: cp/decl.c:9867
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "la declaración de %qD como una matriz multidimensional debe tener límites para todas las dimensiones excepto la primera"
 
-#: cp/decl.c:9850
+#: cp/decl.c:9871
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "una matriz multidimensional debe tener límites para todas las dimensiones excepto para la primera"
 
-#: cp/decl.c:9909
+#: cp/decl.c:9930
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "la especificación del tipo de devolución para el constructor es no válida"
 
-#: cp/decl.c:9912
+#: cp/decl.c:9933
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "no se permiten calificadores en la declaración de %<operator %T%>"
 
-#: cp/decl.c:9922
+#: cp/decl.c:9943
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "la especificación del tipo de devolución para el destructor es no válida"
 
-#: cp/decl.c:9925
+#: cp/decl.c:9946
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "no se permiten calificadores en la declaración de %<operator %T%>"
 
-#: cp/decl.c:9937
+#: cp/decl.c:9958
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "se especificó un tipo de devolución para %<operator %T%>"
 
-#: cp/decl.c:9940
+#: cp/decl.c:9961
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "no se permiten calificadores en la declaración de %<operator %T%>"
 
-#: cp/decl.c:9948
+#: cp/decl.c:9969
 #, fuzzy, gcc-internal-format
 #| msgid "return type specification for destructor invalid"
 msgid "return type specified for deduction guide"
 msgstr "la especificación del tipo de devolución para el destructor es no válida"
 
-#: cp/decl.c:9951
+#: cp/decl.c:9972
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "no se permiten calificadores en la declaración de %<operator %T%>"
 
-#: cp/decl.c:9955
+#: cp/decl.c:9976
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting specifiers in declaration of %qs"
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "especificadores en conflicto en la declaración de %qs"
 
-#: cp/decl.c:9964
+#: cp/decl.c:9985
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting specifiers in declaration of %qs"
 msgid "decl-specifier in declaration of deduction guide"
 msgstr "especificadores en conflicto en la declaración de %qs"
 
-#: cp/decl.c:9985
+#: cp/decl.c:10006
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "se declaró la variable o campo sin nombre como void"
 
-#: cp/decl.c:9992
+#: cp/decl.c:10013
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "se declaró la variable o campo como void"
 
-#: cp/decl.c:10007
+#: cp/decl.c:10028
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "el especificador %<inline%> es no válido para la función %qs declarada fuera del ámbito global"
 
-#: cp/decl.c:10013
+#: cp/decl.c:10034
 #, fuzzy, gcc-internal-format
 #| msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgid "inline variables are only available with -std=c++17 or -std=gnu++17"
 msgstr "los nombres de espacio incluidos en línea sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/decl.c:10268
+#: cp/decl.c:10292
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "uso no válido del nombre calificado %<::%D%>"
 
-#: cp/decl.c:10271 cp/decl.c:10291
+#: cp/decl.c:10295 cp/decl.c:10315
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "uso no válido del nombre calificado %<%T::%D%>"
 
-#: cp/decl.c:10274
+#: cp/decl.c:10298
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "uso no válido del nombre calificado %<%D::%D%>"
 
-#: cp/decl.c:10283
+#: cp/decl.c:10307
 #, gcc-internal-format
 msgid "%q#T is not a class or a namespace"
 msgstr "%q#T no es una clase o un espacio de nombres"
 
 #  FIXME traducción
-#: cp/decl.c:10305 cp/decl.c:10398 cp/decl.c:10407 cp/decl.c:11970
+#: cp/decl.c:10329 cp/decl.c:10422 cp/decl.c:10431 cp/decl.c:11994
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "la declaración de %qD como algo que no es función"
 
 #  FIXME traducción
-#: cp/decl.c:10311
+#: cp/decl.c:10335
 #, gcc-internal-format
 msgid "declaration of %qD as non-member"
 msgstr "declaración de %qD como algo que no es miembro"
 
-#: cp/decl.c:10339
+#: cp/decl.c:10363
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "falta el id del declarador; se utiliza la palabra reservada %qD"
 
-#: cp/decl.c:10390
+#: cp/decl.c:10414
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "la definición de la función no declara parámetros"
 
-#: cp/decl.c:10415
+#: cp/decl.c:10439
 #, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "declaración de %qD como %<typedef%>"
 
-#: cp/decl.c:10420
+#: cp/decl.c:10444
 #, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "la declaración de %qD como parámetro"
 
-#: cp/decl.c:10454
+#: cp/decl.c:10478
 #, fuzzy, gcc-internal-format
 #| msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgid "%<concept%> cannot appear in a typedef declaration"
 msgstr "%<constexpr%> no puede aparecer en una declaración typedef"
 
-#: cp/decl.c:10460
+#: cp/decl.c:10484
 #, gcc-internal-format
 msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgstr "%<constexpr%> no puede aparecer en una declaración typedef"
 
-#: cp/decl.c:10468
+#: cp/decl.c:10492
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "dos o más tipos de datos en la declaración de %qs"
 
-#: cp/decl.c:10474
+#: cp/decl.c:10498
 #, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr "especificadores en conflicto en la declaración de %qs"
 
-#: cp/decl.c:10515
+#: cp/decl.c:10539
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C no admite %<complex%> simples que significan %<double complex%>"
 
-#: cp/decl.c:10564 cp/decl.c:10567 cp/decl.c:10570
+#: cp/decl.c:10588 cp/decl.c:10591 cp/decl.c:10594
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ prohíbe la declaración de %qs sin tipo"
 
-#: cp/decl.c:10586
+#: cp/decl.c:10610
 #, fuzzy, gcc-internal-format
 #| msgid "%<__int128%> is not supported by this target"
 msgid "%<__int%d%> is not supported by this target"
 msgstr "no se admite %<__int128%> en este objetivo"
 
-#: cp/decl.c:10592
+#: cp/decl.c:10616
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not support %<__int128%> for %qs"
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ no admite %<__int128%> para %qs"
 
-#: cp/decl.c:10614 cp/decl.c:10634
+#: cp/decl.c:10638 cp/decl.c:10658
 #, gcc-internal-format
 msgid "%<signed%> or %<unsigned%> invalid for %qs"
 msgstr "%<signed%> o %<unsigned%> no válido para %qs"
 
-#: cp/decl.c:10616
+#: cp/decl.c:10640
 #, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgstr "%<signed%> y %<unsigned%> se especificaron juntos para %qs"
 
-#: cp/decl.c:10618
+#: cp/decl.c:10642
 #, gcc-internal-format
 msgid "%<long long%> invalid for %qs"
 msgstr "%<long long%> no válido para %qs"
 
-#: cp/decl.c:10620
+#: cp/decl.c:10644
 #, gcc-internal-format
 msgid "%<long%> invalid for %qs"
 msgstr "%<long%> no válido para %qs"
 
-#: cp/decl.c:10622
+#: cp/decl.c:10646
 #, gcc-internal-format
 msgid "%<short%> invalid for %qs"
 msgstr "%<short%> no válido para %qs"
 
-#: cp/decl.c:10624
+#: cp/decl.c:10648
 #, gcc-internal-format
 msgid "%<long%> or %<short%> invalid for %qs"
 msgstr "%<long%> o %<short%> no válidos para %qs"
 
-#: cp/decl.c:10626
+#: cp/decl.c:10650
 #, gcc-internal-format
 msgid "%<long%>, %<int%>, %<short%>, or %<char%> invalid for %qs"
 msgstr "%<long%>, %<int%>, %<short%>, o %<char%> no válido para %qs"
 
-#: cp/decl.c:10628
+#: cp/decl.c:10652
 #, gcc-internal-format
 msgid "%<long%> or %<short%> specified with char for %qs"
 msgstr "se especificó %<long%> o %<short%> con char para %qs"
 
-#: cp/decl.c:10630
+#: cp/decl.c:10654
 #, gcc-internal-format
 msgid "%<long%> and %<short%> specified together for %qs"
 msgstr "%<long%> y %<short%>  se especificaron juntos para %qs"
 
-#: cp/decl.c:10636
+#: cp/decl.c:10660
 #, gcc-internal-format
 msgid "%<short%> or %<long%> invalid for %qs"
 msgstr "%<short%> o %<long%> no válidos para %qs"
 
-#: cp/decl.c:10644
+#: cp/decl.c:10668
 #, gcc-internal-format
 msgid "long, short, signed or unsigned used invalidly for %qs"
 msgstr "uso no válido de long, short, signed ó unsigned para %qs"
 
-#: cp/decl.c:10712
+#: cp/decl.c:10736
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "complex no válido para %qs"
 
-#: cp/decl.c:10751
+#: cp/decl.c:10775
 #, gcc-internal-format
 msgid "template placeholder type %qT must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.c:10769
+#: cp/decl.c:10793
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "el miembro %qD no se puede declarar como virtual y static al mismo tiempo"
 
-#: cp/decl.c:10775
+#: cp/decl.c:10799
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD cannot be declared both %<virtual%> and %<constexpr%>"
 msgstr "el miembro %qD no se puede declarar como virtual y static al mismo tiempo"
 
-#: cp/decl.c:10785
+#: cp/decl.c:10809
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "declaración typedef no válida en la declaración de parámetros"
 
-#: cp/decl.c:10790
+#: cp/decl.c:10814
 #, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "se especificó una clase de almacenamiento para el parámetro de plantilla %qs"
 
-#: cp/decl.c:10796
+#: cp/decl.c:10820
 #, gcc-internal-format
 msgid "storage class specifiers invalid in parameter declarations"
 msgstr "especificadores de clase de almacenamiento no válidos en las declaraciones de parámetros"
 
-#: cp/decl.c:10800
+#: cp/decl.c:10824
 #, fuzzy, gcc-internal-format
 #| msgid "a parameter cannot be declared %<constexpr%>"
 msgid "a parameter cannot be declared %<concept%>"
 msgstr "un parámetro no se puede declarar %<constexpr%>"
 
-#: cp/decl.c:10805
+#: cp/decl.c:10829
 #, gcc-internal-format
 msgid "a parameter cannot be declared %<constexpr%>"
 msgstr "un parámetro no se puede declarar %<constexpr%>"
 
-#: cp/decl.c:10815
+#: cp/decl.c:10839
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "declaración de clase fuera de %<virtual%>"
 
-#: cp/decl.c:10825
+#: cp/decl.c:10849
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "structured binding declaration cannot be %<inline%>"
 msgstr "los constructores no se pueden declarar virtual"
 
-#: cp/decl.c:10828
+#: cp/decl.c:10852
 #, fuzzy, gcc-internal-format
 #| msgid "function definition declared %<typedef%>"
 msgid "structured binding declaration cannot be %<typedef%>"
 msgstr "la definición de la función se declaró como %<typedef%>"
 
-#: cp/decl.c:10830
+#: cp/decl.c:10854
 #, fuzzy, gcc-internal-format
 #| msgid "a parameter cannot be declared %<constexpr%>"
 msgid "structured binding declaration cannot be %<constexpr%>"
 msgstr "un parámetro no se puede declarar %<constexpr%>"
 
-#: cp/decl.c:10834
+#: cp/decl.c:10858
 #, fuzzy, gcc-internal-format
 #| msgid "attribute ignored in declaration of %q#T"
 msgid "structured binding declaration cannot be %qs"
 msgstr "se descarta el atributo en la declaración de %q#T"
 
-#: cp/decl.c:10839
+#: cp/decl.c:10863
 #, fuzzy, gcc-internal-format
 #| msgid "a parameter cannot be declared %<constexpr%>"
 msgid "structured binding declaration cannot be %<concept%>"
 msgstr "un parámetro no se puede declarar %<constexpr%>"
 
-#: cp/decl.c:10845
+#: cp/decl.c:10869
 #, fuzzy, gcc-internal-format
 #| msgid "function definition declared %<register%>"
 msgid "structured binding declaration cannot be %<register%>"
 msgstr "la definición de la función se declaró como %<register%>"
 
-#: cp/decl.c:10849
+#: cp/decl.c:10873
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "structured binding declaration cannot be %<static%>"
 msgstr "los constructores no se pueden declarar virtual"
 
-#: cp/decl.c:10853
+#: cp/decl.c:10877
 #, fuzzy, gcc-internal-format
 #| msgid "function %qs cannot be declared %<mutable%>"
 msgid "structured binding declaration cannot be %<extern%>"
 msgstr "la función %qs no se puede declarar %<mutable%>"
 
-#: cp/decl.c:10857
+#: cp/decl.c:10881
 #, fuzzy, gcc-internal-format
 #| msgid "const %qs cannot be declared %<mutable%>"
 msgid "structured binding declaration cannot be %<mutable%>"
 msgstr "const %qs no se puede declarar %<mutable%>"
 
-#: cp/decl.c:10861
+#: cp/decl.c:10885
 #, fuzzy, gcc-internal-format
 #| msgid "function %qs cannot be declared %<mutable%>"
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr "la función %qs no se puede declarar %<mutable%>"
 
-#: cp/decl.c:10872
+#: cp/decl.c:10896
 #, fuzzy, gcc-internal-format
 #| msgid "indirect function %q+D cannot be declared weak"
 msgid "structured binding declaration cannot have type %qT"
 msgstr "la función indirecta %q+D no se puede declarar weak"
 
-#: cp/decl.c:10875
+#: cp/decl.c:10899
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10906
+#: cp/decl.c:10930
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "múltiples clases de almacenamiento en la declaración de %qs"
 
-#: cp/decl.c:10929
+#: cp/decl.c:10953
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "se especificó una clase de almacenamiento para %qs"
 
-#: cp/decl.c:10933
+#: cp/decl.c:10957
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "se especificó una clase de almacenamiento para el parámetro %qs"
 
-#: cp/decl.c:10946
+#: cp/decl.c:10970
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "la función anidada %qs se declaró %<extern%>"
 
-#: cp/decl.c:10950
+#: cp/decl.c:10974
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "la declaración del nivel superior de %qs especifica %<auto%>"
 
-#: cp/decl.c:10957
+#: cp/decl.c:10981
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "el ámbito de la función %qs es implícitamente auto y declarado %<__thread%>"
 
-#: cp/decl.c:10969
+#: cp/decl.c:10993
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "especificadores de clase de almacenamiento no válidos en las declaraciones de funciones friend"
 
-#: cp/decl.c:11050
+#: cp/decl.c:11074
 #, fuzzy, gcc-internal-format
 #| msgid "multiple storage classes in declaration of %qs"
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "múltiples clases de almacenamiento en la declaración de %qs"
 
-#: cp/decl.c:11098
+#: cp/decl.c:11122
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.c:11118
+#: cp/decl.c:11142
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr "la función %qs usa el especificador de tipo %<auto%> sin un tipo de devolución trailing"
 
-#: cp/decl.c:11121
+#: cp/decl.c:11145
 #, fuzzy, gcc-internal-format
 #| msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgstr "el tipo de devolución trailing sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/decl.c:11127
+#: cp/decl.c:11151
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual function cannot have deduced return type"
 msgstr "las funciones virtual no pueden ser friend"
 
-#: cp/decl.c:11134
+#: cp/decl.c:11158
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr "la función %qs con tipo de devolución trailing tiene %qT como su tipo en lugar de un simple %<auto%>"
 
-#: cp/decl.c:11147
+#: cp/decl.c:11171
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "deduced class type %qD in function return type"
 msgstr "se descartan los calificadores de tipo en el tipo de devolución de la función"
 
-#: cp/decl.c:11156
+#: cp/decl.c:11180
 #, fuzzy, gcc-internal-format
 #| msgid "%qs function cannot have arguments"
 msgid "deduction guide for %qT must have trailing return type"
 msgstr "la función %qs no puede tener argumentos"
 
-#: cp/decl.c:11169
+#: cp/decl.c:11193
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
@@ -42138,59 +42187,59 @@
 
 #. Not using maybe_warn_cpp0x because this should
 #. always be an error.
-#: cp/decl.c:11180
+#: cp/decl.c:11204
 #, gcc-internal-format
 msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgstr "el tipo de devolución trailing sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/decl.c:11183
+#: cp/decl.c:11207
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr "no se declaró la función %qs con tipo de devolución trailing con el especificador de tipo %<auto%>"
 
-#: cp/decl.c:11212
+#: cp/decl.c:11236
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs que se declaró como función devuelve una función"
 
-#: cp/decl.c:11218
+#: cp/decl.c:11242
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs que se declaró como función devuelve una matriz"
 
-#: cp/decl.c:11247
+#: cp/decl.c:11271
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "el destructor no puede ser una función miembro de tipo static"
 
-#: cp/decl.c:11248
+#: cp/decl.c:11272
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "el constructor no puede ser una función miembro de tipo static"
 
-#: cp/decl.c:11252
+#: cp/decl.c:11276
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "los destructores no pueden ser cv-calificados"
 
-#: cp/decl.c:11253
+#: cp/decl.c:11277
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "los constructores tal vez no sean cv-calificados"
 
-#: cp/decl.c:11261
+#: cp/decl.c:11285
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "destructors may not be ref-qualified"
 msgstr "los destructores no pueden ser cv-calificados"
 
-#: cp/decl.c:11262
+#: cp/decl.c:11286
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "constructors may not be ref-qualified"
 msgstr "los destructores no pueden ser cv-calificados"
 
-#: cp/decl.c:11280
+#: cp/decl.c:11304
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructors cannot be declared %<virtual%>"
@@ -42197,257 +42246,257 @@
 msgstr "los constructores no se pueden declarar virtual"
 
 #. Cannot be both friend and virtual.
-#: cp/decl.c:11295
+#: cp/decl.c:11319
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "las funciones virtual no pueden ser friend"
 
-#: cp/decl.c:11299
+#: cp/decl.c:11323
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "la declaración friend no está en una definición de clase"
 
-#: cp/decl.c:11301
+#: cp/decl.c:11325
 #, gcc-internal-format
 msgid "can%'t define friend function %qs in a local class definition"
 msgstr "no se puede definir la función friend %qs en una definición de clase local"
 
-#: cp/decl.c:11313
+#: cp/decl.c:11337
 #, fuzzy, gcc-internal-format
 #| msgid "%qs function cannot have arguments"
 msgid "a conversion function cannot have a trailing return type"
 msgstr "la función %qs no puede tener argumentos"
 
-#: cp/decl.c:11339
+#: cp/decl.c:11363
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "los destructores no pueden tener parámetros"
 
-#: cp/decl.c:11379
+#: cp/decl.c:11403
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "no se puede declarar el puntero a %q#T"
 
-#: cp/decl.c:11392 cp/decl.c:11399
+#: cp/decl.c:11416 cp/decl.c:11423
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "no se puede declarar la referencia a %q#T"
 
-#: cp/decl.c:11401
+#: cp/decl.c:11425
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "no se puede declarar el puntero al miembro %q#T"
 
-#: cp/decl.c:11430
+#: cp/decl.c:11454
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "no se puede declarar la referencia para el tipo de función calificado %qT"
 
-#: cp/decl.c:11431
+#: cp/decl.c:11455
 #, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "no se puede declarar el puntero para el tipo de función calificado %qT"
 
-#: cp/decl.c:11504
+#: cp/decl.c:11528
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr "no se puede declarar la referencia a %q#T, el cual no es una definición de tipo o un argumento de tipo de plantilla"
 
-#: cp/decl.c:11574
+#: cp/decl.c:11598
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "el id de plantilla %qD se usa como un declarador"
 
-#: cp/decl.c:11599
+#: cp/decl.c:11623
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "las funciones miembros son implícitamente friends de su clase"
 
-#: cp/decl.c:11605
+#: cp/decl.c:11629
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "calificación extra %<%T::%> en el miembro %qs"
 
-#: cp/decl.c:11635
+#: cp/decl.c:11659
 #, fuzzy, gcc-internal-format
 #| msgid "cannot define member function %<%T::%s%> within %<%T%>"
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "no se puede definir la función miembro %<%T::%s%> dentro de %<%T%>"
 
-#: cp/decl.c:11637
+#: cp/decl.c:11661
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member function %<%T::%s%> within %<%T%>"
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "no se puede declarar la función miembro %<%T::%s%> dentro de %<%T%>"
 
-#: cp/decl.c:11645
+#: cp/decl.c:11669
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "no se puede declarar el miembro %<%T::%s%> dentro de %qT"
 
-#: cp/decl.c:11685
+#: cp/decl.c:11709
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "%qs que no es parámetro no puede ser un paquete de parámetro"
 
-#: cp/decl.c:11693
+#: cp/decl.c:11717
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "los datos miembro pueden no tener el tipo modificado variablemente %qT"
 
-#: cp/decl.c:11695
+#: cp/decl.c:11719
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "el parámetro puede no tener el tipo modificado variablemente %qT"
 
-#: cp/decl.c:11706
+#: cp/decl.c:11730
 #, fuzzy, gcc-internal-format
 #| msgid "%<virtual%> outside class declaration"
 msgid "%<explicit%> outside class declaration"
 msgstr "declaración de clase fuera de %<virtual%>"
 
-#: cp/decl.c:11709
+#: cp/decl.c:11733
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<explicit%> in friend declaration"
 msgstr "%<inline%> en una declaración vacía"
 
-#: cp/decl.c:11712
+#: cp/decl.c:11736
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be %<explicit%>"
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "solamente las declaraciones de constructores pueden ser %<explicit%>"
 
-#: cp/decl.c:11721
+#: cp/decl.c:11745
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "el no-miembro %qs no se puede declarar %<mutable%>"
 
-#: cp/decl.c:11726
+#: cp/decl.c:11750
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "el miembro que no es objeto %qs no se puede declarar %<mutable%>"
 
-#: cp/decl.c:11732
+#: cp/decl.c:11756
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "la función %qs no se puede declarar %<mutable%>"
 
-#: cp/decl.c:11737
+#: cp/decl.c:11761
 #, gcc-internal-format
 msgid "static %qs cannot be declared %<mutable%>"
 msgstr "static %qs no se puede declarar %<mutable%>"
 
-#: cp/decl.c:11742
+#: cp/decl.c:11766
 #, gcc-internal-format
 msgid "const %qs cannot be declared %<mutable%>"
 msgstr "const %qs no se puede declarar %<mutable%>"
 
-#: cp/decl.c:11747
+#: cp/decl.c:11771
 #, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "la referencia %qs no se puede declarar %<mutable%>"
 
-#: cp/decl.c:11778
+#: cp/decl.c:11802
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "la definición de tipo se declaró %<auto%>"
 
-#: cp/decl.c:11783
+#: cp/decl.c:11807
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.c:11787
+#: cp/decl.c:11811
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "el nombre del typedef puede no ser un especificador-de-nombre-anidado"
 
-#: cp/decl.c:11813
+#: cp/decl.c:11837
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ISO C++ prohíbe el tipo anidado %qD con el mismo nombre que la clase que lo contiene"
 
-#: cp/decl.c:11900
+#: cp/decl.c:11924
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "se especificó %<inline%> para la declaración de clase friend"
 
-#: cp/decl.c:11908
+#: cp/decl.c:11932
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "los parámetros de la plantilla no pueden ser friends"
 
-#: cp/decl.c:11910
+#: cp/decl.c:11934
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "la declaración friend requere una llave de clase, p.e. %<friend class %T::%D%>"
 
-#: cp/decl.c:11914
+#: cp/decl.c:11938
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "la declaración friend requiere una llave de clase, p.e. %<friend %#T%>"
 
-#: cp/decl.c:11927
+#: cp/decl.c:11951
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "se intenta hacer que la clase %qT sea un friend de ámbito global"
 
-#: cp/decl.c:11947
+#: cp/decl.c:11971
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "calificadores no válidos en el tipo de función que no es miembro"
 
-#: cp/decl.c:11951
+#: cp/decl.c:11975
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.c:11961
+#: cp/decl.c:11985
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "el declarador abstracto %qT se usó como declaración"
 
-#: cp/decl.c:11976
+#: cp/decl.c:12000
 #, fuzzy, gcc-internal-format
 #| msgid "value-initialization of function type %qT"
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "inicialización por valor del tipo de función %qT"
 
-#: cp/decl.c:11995
+#: cp/decl.c:12019
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "no se puede usar %<::%>  en la declaración de parámetros"
 
-#: cp/decl.c:12001
+#: cp/decl.c:12025
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "no se puede usar %<this%> en este contexto"
 
-#: cp/decl.c:12003
+#: cp/decl.c:12027
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "el parámetro se declaró %<auto%>"
 
-#: cp/decl.c:12052 cp/parser.c:3270
+#: cp/decl.c:12076 cp/parser.c:3270
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "uso no válido del nombre-de-plantilla %qE sin una lista de argumentos"
 
-#: cp/decl.c:12056
+#: cp/decl.c:12080
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member declared %<auto%>"
 msgid "non-static data member declared with placeholder %qT"
 msgstr "se declaró el miembro dato que no es static como %<auto%>"
 
-#: cp/decl.c:12080
+#: cp/decl.c:12104
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C90 no admite miembros de matriz flexibles"
 
-#: cp/decl.c:12083
+#: cp/decl.c:12107
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array members"
@@ -42454,170 +42503,170 @@
 msgstr "ISO C90 no admite miembros de matriz flexibles"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:12099
+#: cp/decl.c:12123
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "uso no válido de %<::%>"
 
-#: cp/decl.c:12121
+#: cp/decl.c:12145
 #, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "declaración de la función %qD en un contexto no válido"
 
-#: cp/decl.c:12130
+#: cp/decl.c:12154
 #, fuzzy, gcc-internal-format
 #| msgid "function %qD declared virtual inside a union"
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "la función %qD se declaró virtual dentro de un union"
 
-#: cp/decl.c:12139
+#: cp/decl.c:12163
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be declared virtual, since it is always static"
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%qD no se puede declarar virtual, ya que siempre es static"
 
-#: cp/decl.c:12153
+#: cp/decl.c:12177
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "se esperaba un nombre calificado en la declaración friend para el destructor %qD"
 
-#: cp/decl.c:12160
+#: cp/decl.c:12184
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "declaración de %qD como miembro de %qT"
 
-#: cp/decl.c:12166
+#: cp/decl.c:12190
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "a destructor cannot be %<concept%>"
 msgstr "un destructor no puede ser %<constexpr%>"
 
-#: cp/decl.c:12171
+#: cp/decl.c:12195
 #, gcc-internal-format
 msgid "a destructor cannot be %<constexpr%>"
 msgstr "un destructor no puede ser %<constexpr%>"
 
-#: cp/decl.c:12177
+#: cp/decl.c:12201
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "se esperaba un nombre calificado en la declaración friend para el constructor %qD"
 
-#: cp/decl.c:12185
+#: cp/decl.c:12209
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "a constructor cannot be %<concept%>"
 msgstr "un destructor no puede ser %<constexpr%>"
 
-#: cp/decl.c:12190
+#: cp/decl.c:12214
 #, fuzzy, gcc-internal-format
 #| msgid "constructor cannot be static member function"
 msgid "a concept cannot be a member function"
 msgstr "el constructor no puede ser una función miembro de tipo static"
 
-#: cp/decl.c:12199
+#: cp/decl.c:12223
 #, fuzzy, gcc-internal-format
 #| msgid "variable %qD redeclared as function"
 msgid "specialization of variable template %qD declared as function"
 msgstr "la variable %qD se redeclaró como función"
 
-#: cp/decl.c:12202
+#: cp/decl.c:12226
 #, fuzzy, gcc-internal-format
 #| msgid "original type declared here"
 msgid "variable template declared here"
 msgstr "el tipo original se definió aquí"
 
-#: cp/decl.c:12257
+#: cp/decl.c:12281
 #, fuzzy, gcc-internal-format
 #| msgid "field %qD has incomplete type"
 msgid "field %qD has incomplete type %qT"
 msgstr "el campo %qD tiene tipo de dato incompleto"
 
-#: cp/decl.c:12262
+#: cp/decl.c:12286
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "el nombre %qT tiene tipo de dato incompleto"
 
-#: cp/decl.c:12272
+#: cp/decl.c:12296
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE no es ni función ni función miembro; no se puede declarar friend"
 
-#: cp/decl.c:12318
+#: cp/decl.c:12342
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qE declared %<constexpr%>"
 msgid "static data member %qE declared %<concept%>"
 msgstr "se declaró el miembro dato que no es static %qE como %<constexpr%>"
 
-#: cp/decl.c:12322
+#: cp/decl.c:12346
 #, fuzzy, gcc-internal-format
 #| msgid "constexpr static data member %qD must have an initializer"
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "el miembro dato static constexpr %qD debe tener un inicializador"
 
-#: cp/decl.c:12350
+#: cp/decl.c:12374
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qE declared %<constexpr%>"
 msgid "non-static data member %qE declared %<concept%>"
 msgstr "se declaró el miembro dato que no es static %qE como %<constexpr%>"
 
-#: cp/decl.c:12354
+#: cp/decl.c:12378
 #, gcc-internal-format
 msgid "non-static data member %qE declared %<constexpr%>"
 msgstr "se declaró el miembro dato que no es static %qE como %<constexpr%>"
 
-#: cp/decl.c:12409
+#: cp/decl.c:12433
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "la clase de almacenamiento %<auto%> es no válida para la función %qs"
 
-#: cp/decl.c:12411
+#: cp/decl.c:12435
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "la clase de almacenamiento %<register%> es no válida para la función %qs"
 
-#: cp/decl.c:12415
+#: cp/decl.c:12439
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "la clase de almacenamiento %<__thread%> es no válida para la función %qs"
 
-#: cp/decl.c:12418
+#: cp/decl.c:12442
 #, fuzzy, gcc-internal-format
 #| msgid "storage class %<__thread%> invalid for function %qs"
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "la clase de almacenamiento %<__thread%> es no válida para la función %qs"
 
-#: cp/decl.c:12423
+#: cp/decl.c:12447
 #, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "no se permiten los especificadores-virt en %qs fuera de una definición de clase"
 
-#: cp/decl.c:12434
+#: cp/decl.c:12458
 #, fuzzy, gcc-internal-format
 #| msgid "%<static%> specified invalid for function %qs declared out of global scope"
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "el especificador %<static%> es no válido para la función %qs declarada fuera del ámbito global"
 
-#: cp/decl.c:12438
+#: cp/decl.c:12462
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "el especificador %<inline%> es no válido para la función %qs declarada fuera del ámbito global"
 
-#: cp/decl.c:12446
+#: cp/decl.c:12470
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "función virtual %qs que no es clase"
 
-#: cp/decl.c:12453
+#: cp/decl.c:12477
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "se definió %qs en un ámbito que no es una clase"
 
-#: cp/decl.c:12454
+#: cp/decl.c:12478
 #, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "se declaró %qs en un ámbito que no es una clase"
 
-#: cp/decl.c:12489
+#: cp/decl.c:12513
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "no se puede declarar que la función miembro %qD tenga enlace estático"
@@ -42624,80 +42673,80 @@
 
 #. 7.1.1: There can be no static function declarations within a
 #. block.
-#: cp/decl.c:12497
+#: cp/decl.c:12521
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "no se puede declarar una función static dentro de otra función"
 
-#: cp/decl.c:12533
+#: cp/decl.c:12557
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "%<static%> puede no ser utilizado cuando se define (opuesto a la declaración) un dato miembro static"
 
-#: cp/decl.c:12540
+#: cp/decl.c:12564
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "se declaró el miembro static %qD como %<register%>"
 
-#: cp/decl.c:12546
+#: cp/decl.c:12570
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "no se puede declarar explícitamente que el miembro %q#D tenga un enlace externo"
 
-#: cp/decl.c:12553
+#: cp/decl.c:12577
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of constexpr variable %qD is not a definition"
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "la declaración de la variable constexpr %qD no es una definición"
 
-#: cp/decl.c:12574
+#: cp/decl.c:12598
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "la declaración de %q#D no tiene inicializadores"
 
-#: cp/decl.c:12585
+#: cp/decl.c:12609
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs inicializado y declarado como %<extern%>"
 
-#: cp/decl.c:12589
+#: cp/decl.c:12613
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs tiene %<extern%> e inicializador al mismo tiempo"
 
-#: cp/decl.c:12754
+#: cp/decl.c:12778
 #, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "el argumento por defecto %qE usa %qD"
 
-#: cp/decl.c:12757
+#: cp/decl.c:12781
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "el argumento por defecto %qE usa la variable local %qD"
 
-#: cp/decl.c:12841
+#: cp/decl.c:12865
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<virtual%> in template declaration of %q#D"
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "uso no válido de %<virtual%> en la declaración de plantilla de %q#D"
 
-#: cp/decl.c:12845
+#: cp/decl.c:12869
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<virtual%> in template declaration of %q#D"
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "uso no válido de %<virtual%> en la declaración de plantilla de %q#D"
 
-#: cp/decl.c:12868
+#: cp/decl.c:12892
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "el parámetro %qD se declaró no válidamente como tipo de método"
 
-#: cp/decl.c:12895
+#: cp/decl.c:12919
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "el parámetro %qD incluye un puntero a matriz %qT de límite desconocido"
 
-#: cp/decl.c:12897
+#: cp/decl.c:12921
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "el parámetro %qD incluye una referencia a matriz %qT de límite desconocido"
@@ -42717,126 +42766,126 @@
 #. or implicitly defined), there's no need to worry about their
 #. existence.  Theoretically, they should never even be
 #. instantiated, but that's hard to forestall.
-#: cp/decl.c:13150
+#: cp/decl.c:13174
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "constructor no válido; tal vez quiso decir %<%T (const %T&)%>"
 
-#: cp/decl.c:13228
+#: cp/decl.c:13252
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD no se puede declarar dentro de un espacio de nombres"
 
-#: cp/decl.c:13234
+#: cp/decl.c:13258
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD no se puede declarar como static"
 
-#: cp/decl.c:13261
+#: cp/decl.c:13285
 #, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr "%qD debe ser una función miembro que no sea static"
 
-#: cp/decl.c:13267
+#: cp/decl.c:13291
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD debe ser una función miembro que no sea static o una función que no sea miembro"
 
-#: cp/decl.c:13277
+#: cp/decl.c:13301
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD debe tener un argumento de tipo clase o enumerado"
 
 #. 13.4.0.3
-#: cp/decl.c:13303
+#: cp/decl.c:13327
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading operator ?:"
 msgstr "ISO C++ prohíbe la sobrecarga del operador ?:"
 
 #. Variadic.
-#: cp/decl.c:13314
+#: cp/decl.c:13338
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD no debe tener un número variable de argumentos"
 
-#: cp/decl.c:13338
+#: cp/decl.c:13362
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either zero or one argument"
 msgid "%qD must have either zero or one argument"
 msgstr "%qD debe tomar cero o un argumentos"
 
-#: cp/decl.c:13339
+#: cp/decl.c:13363
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either one or two arguments"
 msgid "%qD must have either one or two arguments"
 msgstr "%qD debe tomar uno o dos argumentos"
 
-#: cp/decl.c:13350
+#: cp/decl.c:13374
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its argument"
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "el postfijo %qD debe tomar %<int%> como su argumento"
 
-#: cp/decl.c:13351
+#: cp/decl.c:13375
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its second argument"
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "el postfijo %qD debe tomar %<int%> como su segundo argumento"
 
-#: cp/decl.c:13361
+#: cp/decl.c:13385
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have no arguments"
 msgstr "%qD debe tomar dos argumentos exactamente"
 
-#: cp/decl.c:13362 cp/decl.c:13371
+#: cp/decl.c:13386 cp/decl.c:13395
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly one argument"
 msgid "%qD must have exactly one argument"
 msgstr "%qD debe tomar un argumento exactamente"
 
-#: cp/decl.c:13372
+#: cp/decl.c:13396
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have exactly two arguments"
 msgstr "%qD debe tomar dos argumentos exactamente"
 
-#: cp/decl.c:13389 cp/decl.c:13392
+#: cp/decl.c:13413 cp/decl.c:13416
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD no puede tener argumentos por defecto"
 
-#: cp/decl.c:13419
+#: cp/decl.c:13443
 #, gcc-internal-format
 msgid "conversion to a reference to void will never use a type conversion operator"
 msgstr "la conversión a una referencia a void nunca usará un operador de conversión de tipo"
 
-#: cp/decl.c:13421
+#: cp/decl.c:13445
 #, gcc-internal-format
 msgid "conversion to void will never use a type conversion operator"
 msgstr "la conversión a void nunca usará un operador de conversión de tipo"
 
-#: cp/decl.c:13428
+#: cp/decl.c:13452
 #, gcc-internal-format
 msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgstr "la conversión a una referencia al mismo tipo nunca usará un operador de conversión de tipo"
 
-#: cp/decl.c:13430
+#: cp/decl.c:13454
 #, gcc-internal-format
 msgid "conversion to the same type will never use a type conversion operator"
 msgstr "la conversión al mismo tipo nunca usará un operador de conversión de tipo"
 
-#: cp/decl.c:13438
+#: cp/decl.c:13462
 #, gcc-internal-format
 msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgstr "la conversión a una referencia a una clase base nunca usará un operador de conversión de tipo"
 
-#: cp/decl.c:13440
+#: cp/decl.c:13464
 #, gcc-internal-format
 msgid "conversion to a base class will never use a type conversion operator"
 msgstr "la conversión a una clase base nunca usará un operador de conversión de tipo"
 
-#: cp/decl.c:13455
+#: cp/decl.c:13479
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "el %qD definido por el usuario siempre evalúa ambos argumentos"
@@ -42843,53 +42892,53 @@
 
 #  En esta traducción se emplea 'devolver' por 'return'. Si embargo, aquí
 #  se cambió por cacofonía: no es agradable escuchar 'debe devolver'. cfuga
-#: cp/decl.c:13474
+#: cp/decl.c:13498
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "el prefijo %qD debe regresar %qT"
 
-#: cp/decl.c:13480
+#: cp/decl.c:13504
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "el postfijo %qD debe regresar %qT"
 
-#: cp/decl.c:13492
+#: cp/decl.c:13516
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD debe devolver por valor"
 
-#: cp/decl.c:13547
+#: cp/decl.c:13571
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "usando el parámetro de tipo plantilla %qT después de %qs"
 
-#: cp/decl.c:13570
+#: cp/decl.c:13594
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "se usa especialización de plantilla %qT alias después de %qs"
 
-#: cp/decl.c:13573
+#: cp/decl.c:13597
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "se usó el nombre de definición de tipo %qD después de %qs"
 
-#: cp/decl.c:13575
+#: cp/decl.c:13599
 #, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "%qD tiene una declaración previa aquí"
 
-#: cp/decl.c:13583
+#: cp/decl.c:13607
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "se refirió a %qT como %qs"
 
-#: cp/decl.c:13584 cp/decl.c:13591
+#: cp/decl.c:13608 cp/decl.c:13615
 #, fuzzy, gcc-internal-format
 #| msgid "%q+T has a previous declaration here"
 msgid "%qT has a previous declaration here"
 msgstr "%q+T tiene una declaración previa aquí"
 
-#: cp/decl.c:13590
+#: cp/decl.c:13614
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "se refirió a %qT como un enum"
@@ -42901,54 +42950,54 @@
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:13605
+#: cp/decl.c:13629
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "se requiere un argumento de plantilla para %<%s %T%>"
 
-#: cp/decl.c:13659 cp/name-lookup.c:4652
+#: cp/decl.c:13683 cp/name-lookup.c:4652
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD tiene el mismo nombre que la clase en la cual se declaró"
 
-#: cp/decl.c:13689 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6425
-#: cp/pt.c:9209
+#: cp/decl.c:13713 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6428
+#: cp/pt.c:9223
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT no es una plantilla"
 
-#: cp/decl.c:13694
+#: cp/decl.c:13718
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:13703 cp/name-lookup.c:4079 cp/name-lookup.c:4086
-#: cp/name-lookup.c:4939 cp/parser.c:6376 cp/parser.c:26300
+#: cp/decl.c:13727 cp/name-lookup.c:4079 cp/name-lookup.c:4086
+#: cp/name-lookup.c:4939 cp/parser.c:6379 cp/parser.c:26297
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "la referencia a %qD es ambigua"
 
-#: cp/decl.c:13806
+#: cp/decl.c:13830
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "uso del enum %q#D sin declaración previa"
 
-#: cp/decl.c:13842
+#: cp/decl.c:13866
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "redeclaración de %qT como algo que no es plantilla"
 
-#: cp/decl.c:13982
+#: cp/decl.c:14006
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "union derivada %qT no válida"
 
-#: cp/decl.c:13989
+#: cp/decl.c:14013
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr ""
 
-#: cp/decl.c:14000
+#: cp/decl.c:14024
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not a direct or virtual base of %qT"
 msgid "%qT defined with direct virtual base"
@@ -42956,42 +43005,42 @@
 
 #  No me gusta mucho esta traducción. Creo que es mejor
 #  "el tipo base %qT no es de tipo struct o clase". cfuga
-#: cp/decl.c:14025
+#: cp/decl.c:14049
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "el tipo base %qT falla en ser un tipo struct o clase"
 
-#: cp/decl.c:14055
+#: cp/decl.c:14079
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "tipo recursivo %qT sin definir"
 
-#: cp/decl.c:14057
+#: cp/decl.c:14081
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "tipo base duplicado %qT no válido"
 
-#: cp/decl.c:14202
+#: cp/decl.c:14226
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr "no coinciden scoped/unscoped en el enum %q#T"
 
-#: cp/decl.c:14205 cp/decl.c:14213 cp/decl.c:14225 cp/parser.c:18284
+#: cp/decl.c:14229 cp/decl.c:14237 cp/decl.c:14249 cp/parser.c:18281
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "la definición previa está aquí"
 
-#: cp/decl.c:14210
+#: cp/decl.c:14234
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr "no coincide el tipo subyacente en el enum %q#T"
 
-#: cp/decl.c:14222
+#: cp/decl.c:14246
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr "tipos subyacentes diferentes en el enum %q#T"
 
-#: cp/decl.c:14300
+#: cp/decl.c:14324
 #, fuzzy, gcc-internal-format
 #| msgid "underlying type %<%T%> of %<%T%> must be an integral type"
 msgid "underlying type %qT of %qT must be an integral type"
@@ -43001,82 +43050,82 @@
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:14447
+#: cp/decl.c:14471
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "ningún tipo integral puede representar todos los valores de enumerador de %qT"
 
-#: cp/decl.c:14619
+#: cp/decl.c:14643
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qD is not an integer constant"
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "el valor de enumerador para %qD no es una constante entera"
 
-#: cp/decl.c:14629
+#: cp/decl.c:14653
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "el valor de enumerador para %qD no es una constante entera"
 
-#: cp/decl.c:14678
+#: cp/decl.c:14702
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "el valor del enumerador incrementado es demasiado grande para %<unsigned long%>"
 
-#: cp/decl.c:14679
+#: cp/decl.c:14703
 #, fuzzy, gcc-internal-format
 #| msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "el valor del enumerador incrementado es demasiado grande para %<unsigned long%>"
 
-#: cp/decl.c:14690
+#: cp/decl.c:14714
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "desbordamiento en valores de enumeración en %qD"
 
-#: cp/decl.c:14710
+#: cp/decl.c:14734
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value %E is too large for underlying type %<%T%>"
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "el valor de enumerador %E es demasiado grande para el tipo subyacente %<%T%>"
 
-#: cp/decl.c:14821
+#: cp/decl.c:14845
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "el tipo de devolución %q#T es un tipo de dato incompleto"
 
-#: cp/decl.c:14999 cp/typeck.c:9286
+#: cp/decl.c:15023 cp/typeck.c:9286
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> debe devolver una referencia a %<*this%>"
 
-#: cp/decl.c:15344
+#: cp/decl.c:15368
 #, gcc-internal-format
 msgid "invalid function declaration"
 msgstr "declaración de función no válida"
 
-#: cp/decl.c:15786
+#: cp/decl.c:15810
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statements in function returning %qT"
 msgstr "no hay una declaración de devolución en la función que no devuelve void"
 
-#: cp/decl.c:15788 cp/typeck.c:9166
+#: cp/decl.c:15812 cp/typeck.c:9166
 #, fuzzy, gcc-internal-format
 #| msgid "function return types not compatible due to %<volatile%>"
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "los tipos de devolución de función no son compatibles debido a %<volatile%>"
 
-#: cp/decl.c:15996
+#: cp/decl.c:16020
 #, gcc-internal-format
 msgid "invalid member function declaration"
 msgstr "declaración de la función miembro no válida"
 
-#: cp/decl.c:16010
+#: cp/decl.c:16034
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD ya se definió en la clase %qT"
 
-#: cp/decl.c:16386
+#: cp/decl.c:16410
 #, fuzzy, gcc-internal-format
 #| msgid "type of %qD defaults to %<int%>"
 msgid "use of %qD before deduction of %<auto%>"
@@ -43118,7 +43167,7 @@
 msgid "deleting %qT is undefined"
 msgstr "el borrado de %qT está indefinido"
 
-#: cp/decl2.c:585 cp/pt.c:5552
+#: cp/decl2.c:585 cp/pt.c:5566
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "declaración plantilla de %q#D"
@@ -43131,7 +43180,7 @@
 #. [temp.mem]
 #.
 #. A destructor shall not be a member template.
-#: cp/decl2.c:640 cp/pt.c:5511
+#: cp/decl2.c:640 cp/pt.c:5525
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "se declaró el destructor %qD como una plantilla miembro"
@@ -43316,51 +43365,51 @@
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "%<operator delete%> toma el tipo %qT como primer argumento"
 
-#: cp/decl2.c:2660
+#: cp/decl2.c:2650
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgid "%qT has a field %qD whose type has no linkage"
 msgstr "%qT tiene un campo %qD cuyo tipo usa el espacio de nombres anónimo"
 
-#: cp/decl2.c:2664
+#: cp/decl2.c:2654
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr "%qT tiene un campo %qD cuyo tipo usa el espacio de nombres anónimo"
 
-#: cp/decl2.c:2669
+#: cp/decl2.c:2659
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr "%qT tiene un campo %qD cuyo tipo usa el espacio de nombres anónimo"
 
-#: cp/decl2.c:2677
+#: cp/decl2.c:2667
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr "%qT se declaró con mayor visibilidad que el tipo de su campo %qD"
 
-#: cp/decl2.c:2695
+#: cp/decl2.c:2685
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgid "%qT has a base %qT whose type has no linkage"
 msgstr "%qT tiene una base %qT cuyo tipo usa el espacio de nombres anónimo"
 
-#: cp/decl2.c:2699
+#: cp/decl2.c:2689
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgid "%qT has a base %qT whose type depends on the type %qT which has no linkage"
 msgstr "%qT tiene una base %qT cuyo tipo usa el espacio de nombres anónimo"
 
-#: cp/decl2.c:2704
+#: cp/decl2.c:2694
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr "%qT tiene una base %qT cuyo tipo usa el espacio de nombres anónimo"
 
-#: cp/decl2.c:2711
+#: cp/decl2.c:2701
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr "%qT se declaró con mayor visibilidad que su base %qT"
 
-#: cp/decl2.c:4309
+#: cp/decl2.c:4299
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D, declared using anonymous type, is used but never defined"
 msgid "%q#D, declared using unnamed type, is used but never defined"
@@ -43370,70 +43419,70 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4318
+#: cp/decl2.c:4308
 #, fuzzy, gcc-internal-format
 #| msgid "anonymous type with no linkage used to declare variable %q#D with linkage"
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr "se usó un tipo anónimo sin enlace para declarar la variable %q#D sin enlace"
 
-#: cp/decl2.c:4322
+#: cp/decl2.c:4312
 #, fuzzy, gcc-internal-format
 #| msgid "anonymous type with no linkage used to declare function %q#D with linkage"
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr "se usó un tipo anónimo sin enlace para declarar la función %q#D con enlace"
 
-#: cp/decl2.c:4326
+#: cp/decl2.c:4316
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D does not refer to the unqualified type, so it is not used for linkage"
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr "%q+#D no se refiere al tipo sin calificar, así que no se usa para el enlace"
 
-#: cp/decl2.c:4334
+#: cp/decl2.c:4324
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D, declared using local type %qT, is used but never defined"
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "%q+#D, declarada usando el tipo local %qT, se usa pero nunca se define"
 
-#: cp/decl2.c:4338
+#: cp/decl2.c:4328
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr "se usó el tipo %qT sin enlace para declarar la variable %q#D con enlace"
 
-#: cp/decl2.c:4341
+#: cp/decl2.c:4331
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "se usó el tipo %qT sin enlace para declarar la función %q#D con enlace"
 
-#: cp/decl2.c:4529
+#: cp/decl2.c:4519
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D conflicts with a previous declaration"
 msgid "mangling of %q#D as %qE conflicts with a previous mangle"
 msgstr "%q#D genera un conflicto con una declaración previa"
 
-#: cp/decl2.c:4532
+#: cp/decl2.c:4522
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D"
 msgid "previous mangling %q#D"
 msgstr "declaración previa de %q+#D"
 
-#: cp/decl2.c:4534
+#: cp/decl2.c:4524
 #, fuzzy, gcc-internal-format
 #| msgid "-fabi-version=6 (or =0) avoids this error with a change in mangling"
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr "-fabi-version=6 (o =0) evita este error con un cambio en la decodificación"
 
-#: cp/decl2.c:4606 cp/decl2.c:4609
+#: cp/decl2.c:4596 cp/decl2.c:4599
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.c:4956
+#: cp/decl2.c:4946
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D used but never defined"
 msgid "inline function %qD used but never defined"
 msgstr "se usa la función inline %q+D pero nunca se define"
 
-#: cp/decl2.c:5143
+#: cp/decl2.c:5133
 #, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr "falta el argumento por defecto para el parámetro %P de %q+#D"
@@ -43440,18 +43489,18 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5251
+#: cp/decl2.c:5241
 #, fuzzy, gcc-internal-format
 #| msgid "converting lambda which uses %<...%> to function pointer"
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr "se convierte lambda la cual usa %<...%> a un puntero de función"
 
-#: cp/decl2.c:5254
+#: cp/decl2.c:5244
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "se usó la función borrada %q+D"
 
-#: cp/decl2.c:5307
+#: cp/decl2.c:5297
 #, fuzzy, gcc-internal-format
 #| msgid "using %<typename%> outside of template"
 msgid "use of built-in parameter pack %qD outside of a template"
@@ -43749,44 +43798,44 @@
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr "los inicializadores de los datos miembro no son estáticos"
 
-#: cp/init.c:613
+#: cp/init.c:629
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr ""
 
-#: cp/init.c:615
+#: cp/init.c:631
 #, fuzzy, gcc-internal-format
 #| msgid "union defined here"
 msgid "defined here"
 msgstr "se definió union aquí"
 
-#: cp/init.c:673
+#: cp/init.c:689
 #, fuzzy, gcc-internal-format
 #| msgid "initialization of a flexible array member"
 msgid "initializer for flexible array member %q#D"
 msgstr "inicialización de un miembro de matriz flexible"
 
-#: cp/init.c:699
+#: cp/init.c:715
 #, gcc-internal-format
 msgid "%qD should be initialized in the member initialization list"
 msgstr "%qD se debe inicializar en la lista de inicialización de miembros"
 
-#: cp/init.c:720
+#: cp/init.c:736
 #, gcc-internal-format
 msgid "%qD is initialized with itself"
 msgstr "%qD se inicializa con sí mismo"
 
-#: cp/init.c:831
+#: cp/init.c:847
 #, gcc-internal-format
 msgid "invalid initializer for array member %q#D"
 msgstr "inicializador no válido para la matriz miembro %q#D"
 
-#: cp/init.c:845 cp/init.c:869 cp/init.c:2410 cp/method.c:1368
+#: cp/init.c:861 cp/init.c:885 cp/init.c:2427 cp/method.c:1368
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr "miembro const sin inicializar en %q#T"
 
-#: cp/init.c:847 cp/init.c:864 cp/init.c:871 cp/init.c:2395 cp/init.c:2423
+#: cp/init.c:863 cp/init.c:880 cp/init.c:887 cp/init.c:2412 cp/init.c:2440
 #: cp/method.c:1371 cp/method.c:1382
 #, fuzzy, gcc-internal-format
 #| msgid "%qD should be initialized"
@@ -43793,307 +43842,307 @@
 msgid "%q#D should be initialized"
 msgstr "%qD se debe inicializar"
 
-#: cp/init.c:862 cp/init.c:2382 cp/method.c:1379
+#: cp/init.c:878 cp/init.c:2399 cp/method.c:1379
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr "miembro referencia sin inicializar en %q#T"
 
-#: cp/init.c:1041
+#: cp/init.c:1057
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D will be initialized after"
 msgid "%qD will be initialized after"
 msgstr "%q+D se inicializará después de"
 
-#: cp/init.c:1044
+#: cp/init.c:1060
 #, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr "la base %qT se inicializará después de"
 
-#: cp/init.c:1048
+#: cp/init.c:1064
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D"
 msgid "  %q#D"
 msgstr "  %q+#D"
 
-#: cp/init.c:1050
+#: cp/init.c:1066
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr "  base %qT"
 
-#: cp/init.c:1052
+#: cp/init.c:1068
 #, gcc-internal-format
 msgid "  when initialized here"
 msgstr "  cuando se inicializó aquí"
 
-#: cp/init.c:1069
+#: cp/init.c:1085
 #, gcc-internal-format
 msgid "multiple initializations given for %qD"
 msgstr "se dieron inicializaciones múltiples para %qD"
 
-#: cp/init.c:1073
+#: cp/init.c:1089
 #, gcc-internal-format
 msgid "multiple initializations given for base %qT"
 msgstr "se dieron inicializaciones múltiples para la base %qT"
 
-#: cp/init.c:1158
+#: cp/init.c:1174
 #, gcc-internal-format
 msgid "initializations for multiple members of %qT"
 msgstr "inicializaciones para múltiples miembros de %qT"
 
-#: cp/init.c:1255
+#: cp/init.c:1271
 #, gcc-internal-format
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr "la clase base %q#T debe ser inicializada explícitamente en la copia del constructor"
 
-#: cp/init.c:1482 cp/init.c:1501
+#: cp/init.c:1498 cp/init.c:1517
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr "la clase %qT no tiene ningún campo llamado %qD"
 
-#: cp/init.c:1488
+#: cp/init.c:1504
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr "%q#D es un dato miembro static; sólo se puede inicializar en su definición"
 
-#: cp/init.c:1495
+#: cp/init.c:1511
 #, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr "%q#D no es un dato miembro no static de %qT"
 
-#: cp/init.c:1534
+#: cp/init.c:1550
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr "inicializador sin nombre para %qT, el cual no tiene clases base"
 
-#: cp/init.c:1542
+#: cp/init.c:1558
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr "inicializador sin nombre para %qT, el cual usa herencia múltiple"
 
-#: cp/init.c:1589
+#: cp/init.c:1605
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr "%qD es tanto una base directa como una base virtual indirecta"
 
-#: cp/init.c:1597
+#: cp/init.c:1613
 #, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr "el tipo %qT no es una base directa o virtual de %qT"
 
-#: cp/init.c:1600
+#: cp/init.c:1616
 #, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr "el tipo %qT no es una base directa de %qT"
 
-#: cp/init.c:1710 cp/init.c:4386 cp/typeck2.c:1175
+#: cp/init.c:1727 cp/init.c:4402 cp/typeck2.c:1175
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "la matriz se debe inicializar con un inicializador dentro de llaves"
 
-#: cp/init.c:2019 cp/semantics.c:3268
+#: cp/init.c:2036 cp/semantics.c:3271
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qT no es un tipo de clase"
 
-#: cp/init.c:2075
+#: cp/init.c:2092
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr "el tipo incompleto %qT no tiene al miembro %qD"
 
-#: cp/init.c:2089
+#: cp/init.c:2106
 #, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr "puntero no válido al campo de bits %qD"
 
-#: cp/init.c:2175 cp/typeck.c:1893
+#: cp/init.c:2192 cp/typeck.c:1893
 #, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "uso no válido de la función miembro no static %qD"
 
-#: cp/init.c:2182 cp/semantics.c:1835
+#: cp/init.c:2199 cp/semantics.c:1835
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "uso no válido del dato miembro no static %qD"
 
-#: cp/init.c:2379
+#: cp/init.c:2396
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr "un miembro referencia sin inicializar en %q#T usa %<new%> sin un inicializador new"
 
-#: cp/init.c:2387
+#: cp/init.c:2404
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "un miembro referencia sin inicializar en %q#T usa %<new%> sin un inicializador new"
 
-#: cp/init.c:2391
+#: cp/init.c:2408
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized reference member in %q#T"
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr "miembro referencia sin inicializar en %q#T"
 
-#: cp/init.c:2407
+#: cp/init.c:2424
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr "un miembro const sin inicializar en %q#T usa %<new%> sin un inicializador new"
 
-#: cp/init.c:2415
+#: cp/init.c:2432
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "un miembro const sin inicializar en %q#T usa %<new%> sin un inicializador new"
 
-#: cp/init.c:2419
+#: cp/init.c:2436
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const member in %q#T"
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr "miembro const sin inicializar en %q#T"
 
-#: cp/init.c:2710
+#: cp/init.c:2727
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2721
+#: cp/init.c:2738
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2732
+#: cp/init.c:2749
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2880
+#: cp/init.c:2896
 #, fuzzy, gcc-internal-format
 #| msgid "integer overflow in expression"
 msgid "integer overflow in array size"
 msgstr "desbordamiento entero en la expresión"
 
-#: cp/init.c:2890
+#: cp/init.c:2906
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "array size in new-expression must be constant"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/init.c:2904
+#: cp/init.c:2920
 #, fuzzy, gcc-internal-format
 #| msgid "double quoted strings not allowed in #if expressions"
 msgid "variably modified type not allowed in new-expression"
 msgstr "no se permite cadenas con comillas dobles en expresiones #if"
 
-#: cp/init.c:2920
+#: cp/init.c:2936
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by typedef"
 msgstr ""
 
-#: cp/init.c:2922
+#: cp/init.c:2938
 #, fuzzy, gcc-internal-format
 #| msgid "try removing the parentheses around the type-id"
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr "intente borrar los paréntesis alrededor del id-de-tipo"
 
-#: cp/init.c:2932
+#: cp/init.c:2948
 #, gcc-internal-format
 msgid "invalid type %<void%> for new"
 msgstr "tipo %<void%> no válido para new"
 
-#: cp/init.c:2975
+#: cp/init.c:2991
 #, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr "const sin inicializar en %<new%> de %q#T"
 
-#: cp/init.c:3101
+#: cp/init.c:3117
 #, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr "no se encontró un %qD adecuado en la clase %qT"
 
-#: cp/init.c:3108 cp/search.c:1023
+#: cp/init.c:3124 cp/search.c:1026
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "la petición para el miembro %qD es ambigua"
 
-#: cp/init.c:3181
+#: cp/init.c:3197
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr ""
 
-#: cp/init.c:3184
+#: cp/init.c:3200
 #, fuzzy, gcc-internal-format
 #| msgid "class %qT does not have any field named %qD"
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr "la clase %qT no tiene ningún campo llamado %qD"
 
-#: cp/init.c:3187
+#: cp/init.c:3203
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr ""
 
-#: cp/init.c:3370
+#: cp/init.c:3386
 #, gcc-internal-format
 msgid "parenthesized initializer in array new"
 msgstr "inicializador entre paréntesis en la matriz new"
 
-#: cp/init.c:3633
+#: cp/init.c:3649
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr "el tamaño de la matriz nueva debe tener un tipo integral"
 
-#: cp/init.c:3665
+#: cp/init.c:3681
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr "new no se puede aplicar a un tipo de referencia"
 
-#: cp/init.c:3674
+#: cp/init.c:3690
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr "new no se puede aplicar a un tipo de función"
 
-#: cp/init.c:3743
+#: cp/init.c:3759
 #, fuzzy, gcc-internal-format
 #| msgid "possible problem detected in invocation of delete operator:"
 msgid "possible problem detected in invocation of delete [] operator:"
 msgstr "se detectó un posible problema en la invocación del operador delete:"
 
-#: cp/init.c:3747
+#: cp/init.c:3763
 #, fuzzy, gcc-internal-format
 #| msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
 msgid "neither the destructor nor the class-specific operator delete [] will be called, even if they are declared when the class is defined"
 msgstr "no se llamará ni al destructor ni al operador delete específico de la clase, aún si se declaran cuando se defina la clase"
 
-#: cp/init.c:4295
+#: cp/init.c:4311
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "el inicializador termina prematuramente"
 
-#: cp/init.c:4599
+#: cp/init.c:4615
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr "tamaño de matriz desconocida en delete"
 
-#: cp/init.c:4623
+#: cp/init.c:4639
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete operator:"
 msgstr "se detectó un posible problema en la invocación del operador delete:"
 
-#: cp/init.c:4628
+#: cp/init.c:4644
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
 msgstr "no se llamará ni al destructor ni al operador delete específico de la clase, aún si se declaran cuando se defina la clase"
 
-#: cp/init.c:4642
+#: cp/init.c:4658
 #, fuzzy, gcc-internal-format
 #| msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behaviour"
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr "si borra un objeto de tipo de clase abstracta %qT que tiene un destructor que no es virtual, puede causar conducta indefinida"
 
-#: cp/init.c:4647
+#: cp/init.c:4663
 #, fuzzy, gcc-internal-format
 #| msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behaviour"
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr "si borra un objeto de tipo de clase polimórfica %qT que tiene un destructor que no es virtual, puede causar conducta indefinida"
 
-#: cp/init.c:4954
+#: cp/init.c:4970
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "el tipo de vector delete no es del tipo puntero ni matriz"
@@ -44600,7 +44649,7 @@
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "se descartan los atributos en el argumento de plantilla %qT"
 
-#: cp/name-lookup.c:5111 cp/name-lookup.c:7065
+#: cp/name-lookup.c:5111 cp/name-lookup.c:7073
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "se descarta la directiva de atributo %qD"
@@ -44652,60 +44701,60 @@
 msgid "it was later defined here"
 msgstr "se definió struct aquí"
 
-#: cp/name-lookup.c:6687
+#: cp/name-lookup.c:6695
 #, fuzzy, gcc-internal-format
 #| msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn't a template"
 msgstr "la deducción de una lista inicializadora encerrada entre llaves requiere #include <initializer_list>"
 
-#: cp/name-lookup.c:7059
+#: cp/name-lookup.c:7067
 #, fuzzy, gcc-internal-format
 #| msgid "switch %qs is no longer supported"
 msgid "strong using directive no longer supported"
 msgstr "la opción %qs ya no se admite"
 
-#: cp/name-lookup.c:7062
+#: cp/name-lookup.c:7070
 #, fuzzy, gcc-internal-format
 #| msgid "This switch is deprecated; use -fsanitize-recover= instead."
 msgid "you may use an inline namespace instead"
 msgstr "Esta opción es obsoleta; utilice en su lugar -fsanitize-recover=."
 
-#: cp/name-lookup.c:7079
+#: cp/name-lookup.c:7087
 #, fuzzy, gcc-internal-format
 #| msgid "attributes ignored on uninstantiated type"
 msgid "attributes ignored on local using directive"
 msgstr "se descartan los atributos en el tipo sin instanciar"
 
-#: cp/name-lookup.c:7163
+#: cp/name-lookup.c:7171
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "no se permite aquí el alias del espacio de nombres %qD, se asume que es %qD"
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:7183
+#: cp/name-lookup.c:7191
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qD may not be declared within a namespace"
 msgid "cannot nest more than %d namespaces"
 msgstr "%qD no se puede declarar dentro de un espacio de nombres"
 
-#: cp/name-lookup.c:7218
+#: cp/name-lookup.c:7226
 #, fuzzy, gcc-internal-format
 #| msgid "method attributes must be specified at the end only"
 msgid "inline namespace must be specified at initial definition"
 msgstr "los atributos de método sólo se deben especificar al final"
 
-#: cp/name-lookup.c:7219
+#: cp/name-lookup.c:7227
 #, fuzzy, gcc-internal-format
 #| msgid "label %qD defined here"
 msgid "%qD defined here"
 msgstr "la etiqueta %qD se define aquí"
 
-#: cp/name-lookup.c:7292
+#: cp/name-lookup.c:7300
 #, gcc-internal-format
 msgid "XXX entering pop_everything ()\n"
 msgstr "XXX entrando a pop_everything ()\n"
 
-#: cp/name-lookup.c:7301
+#: cp/name-lookup.c:7309
 #, gcc-internal-format
 msgid "XXX leaving pop_everything ()\n"
 msgstr "XXX saliendo de pop_everything ()\n"
@@ -44725,7 +44774,7 @@
 msgid "LEXER_DEBUGGING_ENABLED_P is not set to true"
 msgstr ""
 
-#: cp/parser.c:1352 cp/parser.c:37254
+#: cp/parser.c:1352 cp/parser.c:37251
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -44750,7 +44799,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr "solicitud por el miembro %qE en el tipo %qT que no es clase"
 
-#: cp/parser.c:2949 cp/parser.c:18221
+#: cp/parser.c:2949 cp/parser.c:18218
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "%<%T::%E%> no se ha declarado"
@@ -44832,7 +44881,7 @@
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "una literal de coma flotante no puede aparecer en una expresión constante"
 
-#: cp/parser.c:3143 cp/pt.c:17853
+#: cp/parser.c:3143 cp/pt.c:17890
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr "una conversión a un tipo diferente de un tipo integral o de enumeración no puede aparecer en una expresión constante"
@@ -45065,7 +45114,7 @@
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr "no se puede encontrar un operador literal de cadena %qD con argumentos %qT, %qT"
 
-#: cp/parser.c:4587 cp/parser.c:12940
+#: cp/parser.c:4587 cp/parser.c:12937
 #, gcc-internal-format
 msgid "expected declaration"
 msgstr "se esperaba una declaración"
@@ -45121,7 +45170,7 @@
 msgid "fold-expressions only available with -std=c++17 or -std=gnu++17"
 msgstr "las expresiones lambda sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:5275 cp/parser.c:5452 cp/parser.c:5630 cp/semantics.c:3612
+#: cp/parser.c:5275 cp/parser.c:5452 cp/parser.c:5633 cp/semantics.c:3615
 #, gcc-internal-format
 msgid "expected primary-expression"
 msgstr "se esperaba una expresión primaria"
@@ -45141,97 +45190,97 @@
 msgid "local variable %qD may not appear in this context"
 msgstr "la variable local %qD no puede aparecer en este contexto"
 
-#: cp/parser.c:5787
+#: cp/parser.c:5790
 #, gcc-internal-format
 msgid "expected id-expression"
 msgstr "se esperaba una expresión id"
 
-#: cp/parser.c:5919
+#: cp/parser.c:5922
 #, gcc-internal-format
 msgid "scope %qT before %<~%> is not a class-name"
 msgstr "el ámbito %qT antes de %<~%> no es un nombre-de-clase"
 
-#: cp/parser.c:5948 cp/parser.c:7860
+#: cp/parser.c:5951 cp/parser.c:7860
 #, fuzzy, gcc-internal-format
 #| msgid "C++0x auto only available with -std=c++11 or -std=gnu++11"
 msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgstr "C++0x automático sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:6059
+#: cp/parser.c:6062
 #, gcc-internal-format
 msgid "declaration of %<~%T%> as member of %qT"
 msgstr "declaración de %<~%T%> como miembro de %qT"
 
-#: cp/parser.c:6074
+#: cp/parser.c:6077
 #, gcc-internal-format
 msgid "typedef-name %qD used as destructor declarator"
 msgstr "se usa el nombre-de-definición-de-tipo %qD como un declarador de destructor"
 
-#: cp/parser.c:6111 cp/parser.c:20249
+#: cp/parser.c:6114 cp/parser.c:20246
 #, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr "se esperaba un id sin calificar"
 
-#: cp/parser.c:6220
+#: cp/parser.c:6223
 #, gcc-internal-format
 msgid "found %<:%> in nested-name-specifier, expected %<::%>"
 msgstr "se encontró %<:%> en un especificador de nombre anidado, se esperaba %<::%>"
 
-#: cp/parser.c:6288
+#: cp/parser.c:6291
 #, gcc-internal-format
 msgid "decltype evaluates to %qT, which is not a class or enumeration type"
 msgstr "el tipo de declaración evalúa a %qT, el cual no es una clase o un tipo enumerado"
 
-#: cp/parser.c:6314
+#: cp/parser.c:6317
 #, fuzzy, gcc-internal-format
 #| msgid "incomplete type %qT used in nested name specifier"
 msgid "function template-id %qD in nested-name-specifier"
 msgstr "se utilizó el tipo incompleto %qT en un especificador de nombre anidado"
 
-#: cp/parser.c:6322
+#: cp/parser.c:6325
 #, fuzzy, gcc-internal-format
 #| msgid "expected nested-name-specifier"
 msgid "variable template-id %qD in nested-name-specifier"
 msgstr "se esperaban especificadores de nombre anidados"
 
-#: cp/parser.c:6426 cp/typeck.c:2684 cp/typeck.c:2687 cp/typeck.c:2704
+#: cp/parser.c:6429 cp/typeck.c:2684 cp/typeck.c:2687 cp/typeck.c:2704
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD no es una plantilla"
 
-#: cp/parser.c:6504
+#: cp/parser.c:6507
 #, gcc-internal-format
 msgid "expected nested-name-specifier"
 msgstr "se esperaban especificadores de nombre anidados"
 
-#: cp/parser.c:6711 cp/parser.c:8950
+#: cp/parser.c:6714 cp/parser.c:8950
 #, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr "los tipos no se pueden definir en conversiones"
 
-#: cp/parser.c:6797
+#: cp/parser.c:6800
 #, gcc-internal-format
 msgid "types may not be defined in a %<typeid%> expression"
 msgstr "no se pueden definir tipos en una expresión %<typeid%>"
 
-#: cp/parser.c:6889
+#: cp/parser.c:6892
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments to %<__builtin_shuffle%>"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "número erróneo de argumentos para %<__builtin_shuffle%>"
 
-#: cp/parser.c:6901 cp/pt.c:18416
+#: cp/parser.c:6904 cp/pt.c:18453
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments to %<__builtin_complex%>"
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "número erróneo de argumentos para %<__builtin_complex%>"
 
-#: cp/parser.c:6995
+#: cp/parser.c:6998
 #, gcc-internal-format
 msgid "ISO C++ forbids compound-literals"
 msgstr "ISO C++ prohíbe las literales compuestas"
 
-#: cp/parser.c:7054
+#: cp/parser.c:7057
 #, gcc-internal-format
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
@@ -45369,7 +45418,7 @@
 msgid "capture of non-variable %qE"
 msgstr "captura de %qD que no es variable "
 
-#: cp/parser.c:10391 cp/parser.c:10401 cp/semantics.c:3453 cp/semantics.c:3465
+#: cp/parser.c:10391 cp/parser.c:10401 cp/semantics.c:3456 cp/semantics.c:3468
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D declared here"
 msgid "%q#D declared here"
@@ -45463,7 +45512,7 @@
 msgid "init-statement in selection statements only available with -std=c++17 or -std=gnu++17"
 msgstr "los nombres de espacio incluidos en línea sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:11546 cp/parser.c:28490
+#: cp/parser.c:11546 cp/parser.c:28487
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "se esperaba una declaración de selección"
@@ -45483,18 +45532,18 @@
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr "tipos begin/end inconsistentes para la declaración %<for%> basada en rango: %qT y %qT"
 
-#: cp/parser.c:12250 cp/parser.c:28493
+#: cp/parser.c:12250 cp/parser.c:28490
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "se esperaba una declaración de iteración"
 
-#: cp/parser.c:12298
+#: cp/parser.c:12297
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
 msgstr "las uniones sin restricción sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:12426
+#: cp/parser.c:12423
 #, fuzzy, gcc-internal-format
 #| msgid "compound-statement in constexpr function"
 msgid "%<goto%> in %<constexpr%> function"
@@ -45501,576 +45550,576 @@
 msgstr "declaración compuesta en una función constexpr"
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:12434
+#: cp/parser.c:12431
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ prohíbe los gotos calculados"
 
-#: cp/parser.c:12447 cp/parser.c:28496
+#: cp/parser.c:12444 cp/parser.c:28493
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "se esperaba una declaración de salto"
 
-#: cp/parser.c:12620 cp/parser.c:23584
+#: cp/parser.c:12617 cp/parser.c:23581
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "<;%> extra"
 
-#: cp/parser.c:12863
+#: cp/parser.c:12860
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr "%<__label%> no está al inicio de un bloque"
 
-#: cp/parser.c:13083
+#: cp/parser.c:13080
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:13103
+#: cp/parser.c:13100
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr "deducción inconsistente para %qT: %qT y después %qT"
 
-#: cp/parser.c:13124
+#: cp/parser.c:13121
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr "se prohíbe mezclar declaraciones y definiciones-de-función"
 
-#: cp/parser.c:13148
+#: cp/parser.c:13145
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in exception-declarations"
 msgid "types may not be defined in a for-range-declaration"
 msgstr "no se pueden definir tipos en declaraciones de excepción"
 
-#: cp/parser.c:13203
+#: cp/parser.c:13200
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in range-based for loops"
 msgid "initializer in range-based %<for%> loop"
 msgstr "no se pueden definir tipos en bucles for basados en rango"
 
-#: cp/parser.c:13206
+#: cp/parser.c:13203
 #, fuzzy, gcc-internal-format
 #| msgid "multiple declarations `%T' and `%T'"
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr "declaraciones múltiples `%T' y `%T'"
 
-#: cp/parser.c:13257
+#: cp/parser.c:13254
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgid "structured bindings only available with -std=c++17 or -std=gnu++17"
 msgstr "las uniones sin restricción sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:13306
+#: cp/parser.c:13303
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer for bit string"
 msgid "empty structured binding declaration"
 msgstr "inicializador no válido para la cadena de bits"
 
-#: cp/parser.c:13324
+#: cp/parser.c:13321
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer for bit string"
 msgid "invalid initializer for structured binding declaration"
 msgstr "inicializador no válido para la cadena de bits"
 
-#: cp/parser.c:13491
+#: cp/parser.c:13488
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr "se usó %<friend%> fuera de la clase"
 
-#: cp/parser.c:13558
+#: cp/parser.c:13555
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr "%<auto%> cambiará su significado en C++11; por favor bórrelo"
 
-#: cp/parser.c:13594
+#: cp/parser.c:13591
 #, gcc-internal-format
 msgid "decl-specifier invalid in condition"
 msgstr "especificador-decl no válido en la condición"
 
-#: cp/parser.c:13600
+#: cp/parser.c:13597
 #, fuzzy, gcc-internal-format
 #| msgid "%qD invalid in %qT"
 msgid "%qD invalid in lambda"
 msgstr "%qD no válido en %qT"
 
-#: cp/parser.c:13693
+#: cp/parser.c:13690
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "la definición de clase no se puede declarar como friend"
 
-#: cp/parser.c:13763 cp/parser.c:24064
+#: cp/parser.c:13760 cp/parser.c:24061
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr "las plantillas no pueden ser %<virtual%>"
 
-#: cp/parser.c:13805
+#: cp/parser.c:13802
 #, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr "especificación de enlace no válida"
 
-#: cp/parser.c:13909
+#: cp/parser.c:13906
 #, fuzzy, gcc-internal-format
 #| msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgid "static_assert without a message only available with -std=c++17 or -std=gnu++17"
 msgstr "los nombres de espacio incluidos en línea sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:14111
+#: cp/parser.c:14108
 #, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr "no se pueden definir tipos en expresiones %<decltype%>"
 
-#: cp/parser.c:14264
+#: cp/parser.c:14261
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in a new-type-id"
 msgid "types may not be defined in a conversion-type-id"
 msgstr "no se pueden definir tipos en un id-tipo-nuevo"
 
-#: cp/parser.c:14291
+#: cp/parser.c:14288
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "uso no válido de %<auto%> en el operador de conversión"
 
-#: cp/parser.c:14295
+#: cp/parser.c:14292
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%> in conversion operator"
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr "uso no válido de %<auto%> en el operador de conversión"
 
-#: cp/parser.c:14379
+#: cp/parser.c:14376
 #, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr "solamente los constructores toman inicializadores miembro"
 
-#: cp/parser.c:14406
+#: cp/parser.c:14403
 #, fuzzy, gcc-internal-format
 #| msgid "cannot expand initializer for member %<%D%>"
 msgid "cannot expand initializer for member %qD"
 msgstr "no se puede expandir el inicializador para el miembro %<%D%>"
 
-#: cp/parser.c:14418 cp/pt.c:24255
+#: cp/parser.c:14415 cp/pt.c:24333
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "inicializador mem para %qD después de una delegación de constructor"
 
-#: cp/parser.c:14430 cp/pt.c:24267
+#: cp/parser.c:14427 cp/pt.c:24345
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr "delegación de constructor después de un inicializador mem para %qD"
 
-#: cp/parser.c:14482
+#: cp/parser.c:14479
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr "inicializador de clase base de estilo antiguo anacrónico"
 
-#: cp/parser.c:14552
+#: cp/parser.c:14549
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr "no se permite la palabra clave %<typename%> en este contexto (un inicializador de miembro calificado es implícitamente un tipo)"
 
-#: cp/parser.c:14927
+#: cp/parser.c:14924
 #, fuzzy, gcc-internal-format
 #| msgid "missing space between %<\"\"%> and suffix identifier"
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr "falta un espacio entre %<\"\"%> y el identificador sufijo"
 
-#: cp/parser.c:14933
+#: cp/parser.c:14930
 #, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr "se esperaba un identificador sufijo"
 
-#: cp/parser.c:14942
+#: cp/parser.c:14939
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr "se esperaba una cadena vacía después de la palabra clave %<operator%>"
 
-#: cp/parser.c:14948
+#: cp/parser.c:14945
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands in ternary operation"
 msgid "invalid encoding prefix in literal operator"
 msgstr "operandos no válidos en la operación terniaria"
 
-#: cp/parser.c:14975
+#: cp/parser.c:14972
 #, gcc-internal-format
 msgid "expected operator"
 msgstr "operador inesperado"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:15020
+#: cp/parser.c:15017
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "no se admite la palabra clave %<export%>, y se descartará"
 
-#: cp/parser.c:15190
+#: cp/parser.c:15187
 #, fuzzy, gcc-internal-format
 #| msgid "invalid template non-type parameter"
 msgid "invalid constrained type parameter"
 msgstr "parámetro que no es tipo plantilla no válido"
 
-#: cp/parser.c:15198
+#: cp/parser.c:15195
 #, fuzzy, gcc-internal-format
 #| msgid "invalid catch parameter"
 msgid "cv-qualified type parameter"
 msgstr "parámetro de captura no válido"
 
-#: cp/parser.c:15283
+#: cp/parser.c:15280
 #, gcc-internal-format
 msgid "variadic constraint introduced without %<...%>"
 msgstr ""
 
-#: cp/parser.c:15347
+#: cp/parser.c:15344
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of '%E' as a non-type template-argument"
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "uso no válido de '%E' como un argumento de plantilla que no es tipo"
 
-#: cp/parser.c:15582 cp/parser.c:15668 cp/parser.c:21694
+#: cp/parser.c:15579 cp/parser.c:15665 cp/parser.c:21691
 #, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "el paquete de parámetros plantilla %qD no puede tener un argumento por defecto"
 
-#: cp/parser.c:15586 cp/parser.c:15672
+#: cp/parser.c:15583 cp/parser.c:15669
 #, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr "los paquetes de parámetro de plantilla no pueden tener argumentos por defecto"
 
-#: cp/parser.c:15738
+#: cp/parser.c:15735
 #, gcc-internal-format
 msgid "expected template-id"
 msgstr "se esperaba un id de plantilla"
 
-#: cp/parser.c:15798
+#: cp/parser.c:15795
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "%<<::%> no puede iniciar una lista de argumentos de plantilla"
 
-#: cp/parser.c:15802
+#: cp/parser.c:15799
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr "%<<:%> es una forma alternativa para %<[%>. Inserte espacios en blanco entre %<<%> y %<::%>"
 
-#: cp/parser.c:15806
+#: cp/parser.c:15803
 #, fuzzy, gcc-internal-format
 #| msgid "(if you use %<-fpermissive%> G++ will accept your code)"
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr "(si utiliza %<-fpermissive%>, G++ aceptará su código)"
 
-#: cp/parser.c:15924
+#: cp/parser.c:15921
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "error de decodificación en la lista de argumentos de plantilla"
 
 #. The name does not name a template.
-#: cp/parser.c:15992 cp/parser.c:16122 cp/parser.c:16337
+#: cp/parser.c:15989 cp/parser.c:16119 cp/parser.c:16334
 #, gcc-internal-format
 msgid "expected template-name"
 msgstr "se esperaba un nombre de plantilla"
 
 #. Explain what went wrong.
-#: cp/parser.c:16038
+#: cp/parser.c:16035
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr "se usó %qD que no es plantilla como plantilla"
 
-#: cp/parser.c:16040
+#: cp/parser.c:16037
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr "utilice %<%T::template %D%> para indicar que es una plantilla"
 
-#: cp/parser.c:16189
+#: cp/parser.c:16186
 #, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr "se esperaba el parámetro pack antes de %<...%>"
 
-#: cp/parser.c:16298 cp/parser.c:16316 cp/parser.c:16483
+#: cp/parser.c:16295 cp/parser.c:16313 cp/parser.c:16480
 #, gcc-internal-format
 msgid "expected template-argument"
 msgstr "se esperaba un argumento de plantilla"
 
-#: cp/parser.c:16458
+#: cp/parser.c:16455
 #, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr "argumento de plantilla que no es tipo no válido"
 
-#: cp/parser.c:16585
+#: cp/parser.c:16582
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "la instanciación explícita no debe usar el especificador %<inline%>"
 
-#: cp/parser.c:16589
+#: cp/parser.c:16586
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "la instanciación explícita no debe usar el especificador %<constexpr%>"
 
-#: cp/parser.c:16648
+#: cp/parser.c:16645
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr "especialización de plantilla con enlace C"
 
-#: cp/parser.c:16869
+#: cp/parser.c:16866
 #, gcc-internal-format
 msgid "expected type specifier"
 msgstr "se esperaba un specificador de tipo"
 
-#: cp/parser.c:17053
+#: cp/parser.c:17050
 #, fuzzy, gcc-internal-format
 #| msgid "defaulted and deleted functions only available with -std=c++11 or -std=gnu++11"
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "las funciones por defecto y borradas sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:17059
+#: cp/parser.c:17056
 #, fuzzy, gcc-internal-format
 #| msgid "defaulted and deleted functions only available with -std=c++11 or -std=gnu++11"
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "las funciones por defecto y borradas sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:17064
+#: cp/parser.c:17061
 #, fuzzy, gcc-internal-format
 #| msgid "defaulted and deleted functions only available with -std=c++11 or -std=gnu++11"
 msgid "use of %<auto%> in parameter declaration only available with -fconcepts"
 msgstr "las funciones por defecto y borradas sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:17209
+#: cp/parser.c:17206
 #, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "se esperaba un id de plantilla para el tipo"
 
-#: cp/parser.c:17278
+#: cp/parser.c:17275
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr "se esperaba un nombre de tipo"
 
-#: cp/parser.c:17631
+#: cp/parser.c:17628
 #, fuzzy, gcc-internal-format
 #| msgid "elaborated-type-specifier for a scoped enum must not use the %<%D%> keyword"
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr "el especificador de tipo elaborado para un ámbito enumerado no debe usar la palabra clave %<%D%>"
 
-#: cp/parser.c:17854
+#: cp/parser.c:17851
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "la declaración %qD no declara nada"
 
-#: cp/parser.c:17942
+#: cp/parser.c:17939
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "se descartan los atributos en el tipo sin instanciar"
 
-#: cp/parser.c:17946
+#: cp/parser.c:17943
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "se descartan los atributos en la instanciación de una plantilla"
 
-#: cp/parser.c:17951
+#: cp/parser.c:17948
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr "se descartan los atributos en un especificador de tipo elaborado que no es una declaración adelantada"
 
-#: cp/parser.c:18085
+#: cp/parser.c:18082
 #, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "%qD es una plantilla de enumeración"
 
-#: cp/parser.c:18096
+#: cp/parser.c:18093
 #, fuzzy, gcc-internal-format
 #| msgid "%qD does not have integral or enumeration type"
 msgid "%qD does not name an enumeration in %qT"
 msgstr "%qD no tiene tipo integral o de enumeración"
 
-#: cp/parser.c:18111
+#: cp/parser.c:18108
 #, fuzzy, gcc-internal-format
 #| msgid "%<namespace%> definition is not allowed here"
 msgid "unnamed scoped enum is not allowed"
 msgstr "la definición %<namespace%> no se permite aquí"
 
-#: cp/parser.c:18166
+#: cp/parser.c:18163
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "se esperaba %<;%> o %<{%>"
 
-#: cp/parser.c:18215
+#: cp/parser.c:18212
 #, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "no se puede agregar una lista de enumerador a una instanciación de plantilla"
 
-#: cp/parser.c:18229
+#: cp/parser.c:18226
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration does not name a class or function"
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "la declaración friend no nombra una clase o función"
 
-#: cp/parser.c:18241 cp/parser.c:23070
+#: cp/parser.c:18238 cp/parser.c:23067
 #, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "la declaración de %qD en el espacio de nombres %qD el cual no incluye a %qD"
 
-#: cp/parser.c:18246 cp/parser.c:23075
+#: cp/parser.c:18243 cp/parser.c:23072
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "la declaración de %qD en %qD la cual no incluye a %qD"
 
-#: cp/parser.c:18258 cp/parser.c:23089
+#: cp/parser.c:18255 cp/parser.c:23086
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr "no se permite la calificación extra"
 
-#: cp/parser.c:18282
+#: cp/parser.c:18279
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "definición múltiple de %q#T"
 
-#: cp/parser.c:18295
+#: cp/parser.c:18292
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids incrementing an enum"
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO C++ prohíbe incrementar un enum"
 
-#: cp/parser.c:18315
+#: cp/parser.c:18312
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr "especificador enumerador opaco sin nombre"
 
-#: cp/parser.c:18318
+#: cp/parser.c:18315
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr "el especificador enumerador opaco debe usar un identificador simple"
 
-#: cp/parser.c:18497
+#: cp/parser.c:18494
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD no es un nombre-de-espacio-de-nombres"
 
-#: cp/parser.c:18503
+#: cp/parser.c:18500
 #, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "se esperaba un nombre de espacio"
 
-#: cp/parser.c:18570
+#: cp/parser.c:18567
 #, fuzzy, gcc-internal-format
 #| msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgid "nested namespace definitions only available with -std=c++17 or -std=gnu++17"
 msgstr "los nombres de espacio incluidos en línea sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:18578
+#: cp/parser.c:18575
 #, fuzzy, gcc-internal-format
 #| msgid "expected namespace-name"
 msgid "nested namespace name required"
 msgstr "se esperaba un nombre de espacio"
 
-#: cp/parser.c:18583
+#: cp/parser.c:18580
 #, fuzzy, gcc-internal-format
 #| msgid "namespace %qT undeclared"
 msgid "namespace name required"
 msgstr "espacio de nombres %qT sin declarar"
 
-#: cp/parser.c:18587
+#: cp/parser.c:18584
 #, fuzzy, gcc-internal-format
 #| msgid "Enumerator cannot have attributes %C"
 msgid "a nested namespace definition cannot have attributes"
 msgstr "El enumerador no puede tener atributos %C"
 
-#: cp/parser.c:18590
+#: cp/parser.c:18587
 #, fuzzy, gcc-internal-format
 #| msgid "varargs function cannot be inline"
 msgid "a nested namespace definition cannot be inline"
 msgstr "la función varargs no puede ser inline"
 
-#: cp/parser.c:18597
+#: cp/parser.c:18594
 #, fuzzy, gcc-internal-format
 #| msgid "namespace %qT undeclared"
 msgid "namespace %qD entered"
 msgstr "espacio de nombres %qT sin declarar"
 
-#: cp/parser.c:18652
+#: cp/parser.c:18649
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "la definición %<namespace%> no se permite aquí"
 
-#: cp/parser.c:18803
+#: cp/parser.c:18800
 #, fuzzy, gcc-internal-format
 #| msgid "lambda expressions only available with -std=c++11 or -std=gnu++11"
 msgid "pack expansion in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr "las expresiones lambda sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:18818
+#: cp/parser.c:18815
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "un id-de-plantilla no puede aparecer en una declaración-using"
 
-#: cp/parser.c:18865
+#: cp/parser.c:18862
 #, fuzzy, gcc-internal-format
 #| msgid "lambda expressions only available with -std=c++11 or -std=gnu++11"
 msgid "comma-separated list in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr "las expresiones lambda sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:18875
+#: cp/parser.c:18872
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr "las declaraciones access son obsoletas en favor de las declaraciones using: sugerencia: use la palabra clave %<using%>"
 
-#: cp/parser.c:18940
+#: cp/parser.c:18937
 #, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "no se pueden definir tipos en declaraciones de plantilla alias"
 
-#: cp/parser.c:19106
+#: cp/parser.c:19103
 #, fuzzy, gcc-internal-format
 #| msgid "compound-statement in constexpr function"
 msgid "%<asm%> in %<constexpr%> function"
 msgstr "declaración compuesta en una función constexpr"
 
-#: cp/parser.c:19493
+#: cp/parser.c:19490
 #, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "una definición de función no se permite aquí"
 
-#: cp/parser.c:19504
+#: cp/parser.c:19501
 #, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr "no se permite una especificación-asm en una definición-de-función"
 
-#: cp/parser.c:19508
+#: cp/parser.c:19505
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "no se permiten atributos en una definición-de-función"
 
-#: cp/parser.c:19559
+#: cp/parser.c:19556
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr "se esperaba un constructor, un destructor, o una conversión de tipo"
 
 #. Anything else is an error.
-#: cp/parser.c:19598 cp/parser.c:21906
+#: cp/parser.c:19595 cp/parser.c:21903
 #, gcc-internal-format
 msgid "expected initializer"
 msgstr "se esperaba un inicializador"
 
-#: cp/parser.c:19679
+#: cp/parser.c:19676
 #, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "se proporcionó un inicializador para la función"
 
-#: cp/parser.c:19713
+#: cp/parser.c:19710
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "se descartan los atributos después del inicializador entre paréntesis"
 
-#: cp/parser.c:19727
+#: cp/parser.c:19724
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared as inline"
 msgid "non-function %qD declared as implicit template"
 msgstr "se redeclara la función %q+D como inline"
 
-#: cp/parser.c:20169
+#: cp/parser.c:20166
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "el límite de la matriz no es una constante entera"
 
-#: cp/parser.c:20295
+#: cp/parser.c:20292
 #, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr "no se puede definir el miembro de la definición de tipo dependiente %qT"
 
-#: cp/parser.c:20299
+#: cp/parser.c:20296
 #, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "%<%T::%E%> no es un tipo"
@@ -46079,17 +46128,17 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:20328
+#: cp/parser.c:20325
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr "declarador no válido"
 
-#: cp/parser.c:20336
+#: cp/parser.c:20333
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "uso no válido del constructor como una plantilla"
 
-#: cp/parser.c:20338
+#: cp/parser.c:20335
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr "use %<%T::%D%> en lugar de %<%T::%D%> para nombrar el constructor en un nombre calificado"
@@ -46096,409 +46145,409 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:20410
+#: cp/parser.c:20407
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type in declaration"
 msgid "qualified-id in declaration"
 msgstr "tipo no válido en la declaración"
 
-#: cp/parser.c:20435
+#: cp/parser.c:20432
 #, gcc-internal-format
 msgid "expected declarator"
 msgstr "se esperaba un declarador"
 
-#: cp/parser.c:20554
+#: cp/parser.c:20551
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD es un espacio de nombres"
 
-#: cp/parser.c:20556
+#: cp/parser.c:20553
 #, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "no se puede formar un puntero al miembro de %q#T que no es clase"
 
-#: cp/parser.c:20577
+#: cp/parser.c:20574
 #, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "se esperaba un operador puntero"
 
-#: cp/parser.c:20638
+#: cp/parser.c:20635
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "calificador-cv duplicado"
 
-#: cp/parser.c:20692
+#: cp/parser.c:20689
 #, fuzzy, gcc-internal-format
 #| msgid "multiple `virtual' specifiers"
 msgid "multiple ref-qualifiers"
 msgstr "especificadores `virtual' múltiples"
 
-#: cp/parser.c:20729
+#: cp/parser.c:20726
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr "--resource requiere -o"
 
-#: cp/parser.c:20787
+#: cp/parser.c:20784
 #, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "especificador-virt duplicado"
 
-#: cp/parser.c:21025
+#: cp/parser.c:21022
 #, fuzzy, gcc-internal-format
 #| msgid "in template argument for type %qT "
 msgid "missing template arguments after %qT"
 msgstr "en el argumento de plantilla para el tipo %qT "
 
-#: cp/parser.c:21031 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2090
+#: cp/parser.c:21028 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2093
 #, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr "uso no válido de %qT"
 
-#: cp/parser.c:21052
+#: cp/parser.c:21049
 #, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "no se pueden definir tipos en argumentos de plantilla"
 
-#: cp/parser.c:21057
+#: cp/parser.c:21054
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of '%E' as a non-type template-argument"
 msgid "invalid use of %<auto%> in template argument"
 msgstr "uso no válido de '%E' como un argumento de plantilla que no es tipo"
 
-#: cp/parser.c:21145
+#: cp/parser.c:21142
 #, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "se esperaba un especificador de tipo"
 
-#: cp/parser.c:21429
+#: cp/parser.c:21426
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "se esperaba %<,%> o %<...%>"
 
-#: cp/parser.c:21504
+#: cp/parser.c:21501
 #, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr "no se pueden definir tipos en tipos de parámetro"
 
-#: cp/parser.c:21678
+#: cp/parser.c:21675
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "los argumentos por defecto sólo se permiten para parámetros de función"
 
-#: cp/parser.c:21696
+#: cp/parser.c:21693
 #, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "el paquete de parámetros %qD no puede tener un argumento por defecto"
 
-#: cp/parser.c:21702
+#: cp/parser.c:21699
 #, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr "el paquete de parámetros plantilla no puede tener un argumento por defecto"
 
-#: cp/parser.c:21704
+#: cp/parser.c:21701
 #, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr "el paquete de parámetros no puede tener un argumento por defecto"
 
-#: cp/parser.c:22131
+#: cp/parser.c:22128
 #, fuzzy, gcc-internal-format
 #| msgid "extended initializer lists only available with -std=c++11 or -std=gnu++11"
 msgid "C++ designated initializers only available with -std=c++2a or -std=gnu++2a"
 msgstr "las listas de inicializador extendidas sólo está disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:22151
+#: cp/parser.c:22148
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr "ISO C++ no permite inicializadores designados"
 
-#: cp/parser.c:22189
+#: cp/parser.c:22186
 #, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C++ no permite inicializadores designados de C99"
 
-#: cp/parser.c:22203
+#: cp/parser.c:22200
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr ""
 
-#: cp/parser.c:22228
+#: cp/parser.c:22225
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "%<...%> not allowed in designated initializer list"
 msgstr "ISO C++ no permite inicializadores designados"
 
-#: cp/parser.c:22266
+#: cp/parser.c:22263
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr ""
 
-#: cp/parser.c:22322 cp/parser.c:22448
+#: cp/parser.c:22319 cp/parser.c:22445
 #, gcc-internal-format
 msgid "expected class-name"
 msgstr "se esperaba un nombre de clase"
 
-#: cp/parser.c:22650
+#: cp/parser.c:22647
 #, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "se esperaba %<;%> después de la definición de clase"
 
-#: cp/parser.c:22653
+#: cp/parser.c:22650
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "se esperaba %<;%> después de la definición de struct"
 
-#: cp/parser.c:22656
+#: cp/parser.c:22653
 #, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "se esperaba %<;%> después de la definición de union"
 
-#: cp/parser.c:23012
+#: cp/parser.c:23009
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "se esperaba %<{%> o %<:%>"
 
-#: cp/parser.c:23023
+#: cp/parser.c:23020
 #, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "no se puede especificar %<override%> para una clase"
 
-#: cp/parser.c:23031
+#: cp/parser.c:23028
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr "la calificación global del nombre de clase es no válida"
 
-#: cp/parser.c:23038
+#: cp/parser.c:23035
 #, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "el nombre calificado no nombra una clase"
 
-#: cp/parser.c:23050
+#: cp/parser.c:23047
 #, fuzzy, gcc-internal-format
 #| msgid "keyword %<typename%> not allowed outside of templates"
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr "no se permite la palabra clave %<typename%> fuera de las plantillas"
 
-#: cp/parser.c:23056
+#: cp/parser.c:23053
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "nombre de clase no válido en la declaración de %qD"
 
-#: cp/parser.c:23114
+#: cp/parser.c:23111
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "una especialización explícita se debe preceder con %<template <>%>"
 
-#: cp/parser.c:23146
+#: cp/parser.c:23143
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "la plantilla de función %qD se redeclaró commo una plantilla de clase"
 
-#: cp/parser.c:23182
+#: cp/parser.c:23179
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr "no se puede resolver el tipo typename"
 
-#: cp/parser.c:23241
+#: cp/parser.c:23238
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+#T"
 msgid "previous definition of %q#T"
 msgstr "definición previa de %q+#T"
 
-#: cp/parser.c:23331 cp/parser.c:28499
+#: cp/parser.c:23328 cp/parser.c:28496
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr "se esperaba una llave de clase"
 
-#: cp/parser.c:23355
+#: cp/parser.c:23352
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:23359
+#: cp/parser.c:23356
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<class%> or %<typename%>"
 msgstr "se esperaba %<class%>, %<typename%> o %<template%>"
 
-#: cp/parser.c:23605
+#: cp/parser.c:23602
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr "en C++03 se debe usar una llave-clase cuando se declara un friend"
 
-#: cp/parser.c:23623
+#: cp/parser.c:23620
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "la declaración friend no nombra una clase o función"
 
-#: cp/parser.c:23641
+#: cp/parser.c:23638
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:23738
+#: cp/parser.c:23735
 #, fuzzy, gcc-internal-format
 #| msgid "extended initializer lists only available with -std=c++11 or -std=gnu++11"
 msgid "default member initializers for bit-fields only available with -std=c++2a or -std=gnu++2a"
 msgstr "las listas de inicializador extendidas sólo está disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:23745
+#: cp/parser.c:23742
 #, fuzzy, gcc-internal-format
 #| msgid "alignment specified for unnamed bit-field"
 msgid "default member initializer for unnamed bit-field"
 msgstr "se especificó la alineación para el campo de bits sin nombre"
 
-#: cp/parser.c:23758
+#: cp/parser.c:23755
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr ""
 
-#: cp/parser.c:23903
+#: cp/parser.c:23900
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr "especificador-pure en la definición-de-función"
 
-#: cp/parser.c:23923
+#: cp/parser.c:23920
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%> after class definition"
 msgid "extra %<;%> after in-class function definition"
 msgstr "se esperaba %<;%> después de la definición de clase"
 
-#: cp/parser.c:23970
+#: cp/parser.c:23967
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%> at end of member declaration"
 msgid "stray %<,%> at end of member declaration"
 msgstr "se esperaba %<;%> al final de la declaración miembro"
 
-#: cp/parser.c:23984
+#: cp/parser.c:23981
 #, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "se esperaba %<;%> al final de la declaración miembro"
 
-#: cp/parser.c:24058
+#: cp/parser.c:24055
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr "especificador pure no válido (sólo se permite %<= 0%>)"
 
-#: cp/parser.c:24093
+#: cp/parser.c:24090
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "un inicializador dentro de llaves no se permite aquí"
 
-#: cp/parser.c:24223
+#: cp/parser.c:24220
 #, fuzzy, gcc-internal-format
 #| msgid "%<virtual%> specified more than once in base-specified"
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr "se especificó %<virtual%> más de una vez en la base especificada"
 
-#: cp/parser.c:24243
+#: cp/parser.c:24240
 #, fuzzy, gcc-internal-format
 #| msgid "more than one access specifier in base-specified"
 msgid "more than one access specifier in base-specifier"
 msgstr "más de un especificador de acceso en la base especificada"
 
-#: cp/parser.c:24267
+#: cp/parser.c:24264
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "no se permite la palabra clave %<typename%> fuera de las plantillas"
 
-#: cp/parser.c:24270
+#: cp/parser.c:24267
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "no se permite la palabra clave %<typename%> en este contexto (la clase base es implícitamente un tipo)"
 
-#: cp/parser.c:24364 cp/parser.c:24442
+#: cp/parser.c:24361 cp/parser.c:24439
 #, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "no se pueden definir tipos en una especificación de excepción"
 
-#: cp/parser.c:24450
+#: cp/parser.c:24447
 #, fuzzy, gcc-internal-format
 #| msgid "due to different exception specifications"
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "debido a diferentes especificaciones de excepciones"
 
-#: cp/parser.c:24456
+#: cp/parser.c:24453
 #, fuzzy, gcc-internal-format
 #| msgid "dynamic exception specifications are deprecated in C++0x; use %<noexcept%> instead"
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr "las especificaciones de excepción dinámicas son obsoletas en C++0x; utilice %<noexcept%> en su lugar"
 
-#: cp/parser.c:24500
+#: cp/parser.c:24497
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%> in conversion operator"
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "uso no válido de %<auto%> en el operador de conversión"
 
-#: cp/parser.c:24539
+#: cp/parser.c:24536
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not %<constexpr%>"
 msgid "%<try%> in %<constexpr%> function"
 msgstr "%qD no es %<constexpr%>"
 
-#: cp/parser.c:24650
+#: cp/parser.c:24647
 #, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr "no se pueden definir tipos en declaraciones de excepción"
 
-#: cp/parser.c:25203
+#: cp/parser.c:25200
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr "El atributo %qE genera un conflicto con el atributo %s"
 
-#: cp/parser.c:25217
+#: cp/parser.c:25214
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier or %<(%>"
 msgid "expected an identifier for the attribute name"
 msgstr "se esperaba un identificador o %<(%>"
 
-#: cp/parser.c:25301
+#: cp/parser.c:25298
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:25305
+#: cp/parser.c:25302
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:25342
+#: cp/parser.c:25339
 #, fuzzy, gcc-internal-format
 #| msgid "expected parameter pack before %<...%>"
 msgid "expected attribute before %<...%>"
 msgstr "se esperaba el parámetro pack antes de %<...%>"
 
-#: cp/parser.c:25403
+#: cp/parser.c:25400
 #, fuzzy, gcc-internal-format
 #| msgid "C++0x auto only available with -std=c++11 or -std=gnu++11"
 msgid "attribute using prefix only available with -std=c++17 or -std=gnu++17"
 msgstr "C++0x automático sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:25721
+#: cp/parser.c:25718
 #, fuzzy, gcc-internal-format
 #| msgid "%<@required%> is not available in Objective-C 1.0"
 msgid "%<requires%> only available with -fconcepts"
 msgstr "%<@required%> no está disponible en Objective-C 1.0"
 
-#: cp/parser.c:25753
+#: cp/parser.c:25750
 #, fuzzy, gcc-internal-format
 #| msgid "a transaction expression cannot appear in a constant-expression"
 msgid "a requires expression cannot appear outside a template"
 msgstr "una expresión de transacción no puede aparecer en una expresión constante"
 
-#: cp/parser.c:26467
+#: cp/parser.c:26464
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr "el miembro especializado %<%T::%E%> requiere sintaxis %<template<>%>"
 
-#: cp/parser.c:26472
+#: cp/parser.c:26469
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "declaración no válida de %<%T::%E%>"
 
-#: cp/parser.c:26476
+#: cp/parser.c:26473
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "faltan listas-de-parámetros-de-plantilla"
@@ -46507,421 +46556,421 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:26483
+#: cp/parser.c:26480
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "demasiadas listas-de-parámetros-de-plantilla"
 
-#: cp/parser.c:26832
+#: cp/parser.c:26829
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "ya no se admiten los valores de devolución nombrados"
 
-#: cp/parser.c:26991
+#: cp/parser.c:26988
 #, fuzzy, gcc-internal-format
 #| msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr "la plantilla de operador literal %qD tiene una lista de parámetros no válida.  Se esperaba un paquete de argumentos de plantilla que no sean de tipo <char...>"
 
-#: cp/parser.c:26996
+#: cp/parser.c:26993
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr "la plantilla de operador literal %qD tiene una lista de parámetros no válida.  Se esperaba un paquete de argumentos de plantilla que no sean de tipo <char...>"
 
-#: cp/parser.c:27066
+#: cp/parser.c:27063
 #, fuzzy, gcc-internal-format
 #| msgid "Enable multiply instructions"
 msgid "empty introduction-list"
 msgstr "Activa las instrucciones multiply"
 
-#: cp/parser.c:27090
+#: cp/parser.c:27087
 #, fuzzy, gcc-internal-format
 #| msgid "no matching template for %qD found"
 msgid "no matching concept for template-introduction"
 msgstr "no se encontró una plantilla coincidente para %qD"
 
-#: cp/parser.c:27112
+#: cp/parser.c:27109
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "declaración no válida de plantilla miembro en la clase local"
 
-#: cp/parser.c:27121
+#: cp/parser.c:27118
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "plantilla con enlace C"
 
-#: cp/parser.c:27141
+#: cp/parser.c:27138
 #, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "especialización explícita no válida"
 
-#: cp/parser.c:27245
+#: cp/parser.c:27242
 #, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "declaración plantilla de %<typedef%>"
 
-#: cp/parser.c:27296
+#: cp/parser.c:27293
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "a class template declaration must not declare anything else"
 msgstr "la declaración no declara nada"
 
-#: cp/parser.c:27342
+#: cp/parser.c:27339
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "la especialización de plantilla explícita no puede tener una clase de almacenamiento"
 
-#: cp/parser.c:27650
+#: cp/parser.c:27647
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%<>>%> debe ser %<> >%> dentro de una lista de argumentos de plantilla anidada"
 
-#: cp/parser.c:27663
+#: cp/parser.c:27660
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "%<>>%> sobrante, use %<>%> para terminar una lista de argumentos de plantilla"
 
-#: cp/parser.c:27958
+#: cp/parser.c:27955
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:28118
+#: cp/parser.c:28115
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "uso no válido de %qD en la especificación de enlace"
 
-#: cp/parser.c:28133
+#: cp/parser.c:28130
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> antes de %qD"
 
-#: cp/parser.c:28267
+#: cp/parser.c:28264
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ 1998 no admite %<long long%>"
 
-#: cp/parser.c:28275
+#: cp/parser.c:28272
 #, fuzzy, gcc-internal-format
 #| msgid "both %<_Sat%> and %<char%> in declaration specifiers"
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "se usaron al mismo tiempo %<_Sat%> y %<char%> en los especificadores de declaración"
 
-#: cp/parser.c:28280
+#: cp/parser.c:28277
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %qE"
 msgid "duplicate %qD"
 msgstr "%qE duplicado"
 
-#: cp/parser.c:28304
+#: cp/parser.c:28301
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "%qs duplicado"
 
-#: cp/parser.c:28356
+#: cp/parser.c:28353
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "se esperaba %<new%>"
 
-#: cp/parser.c:28359
+#: cp/parser.c:28356
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "se esperaba %<delete%>"
 
-#: cp/parser.c:28362
+#: cp/parser.c:28359
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "se esperaba %<return%>"
 
-#: cp/parser.c:28368
+#: cp/parser.c:28365
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "se esperaba %<extern%>"
 
-#: cp/parser.c:28371
+#: cp/parser.c:28368
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "se esperaba %<static_assert%>"
 
-#: cp/parser.c:28374
+#: cp/parser.c:28371
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "se esperaba %<decltype%>"
 
-#: cp/parser.c:28377
+#: cp/parser.c:28374
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "se esperaba %<operator%>"
 
-#: cp/parser.c:28380
+#: cp/parser.c:28377
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "se esperaba %<class%>"
 
-#: cp/parser.c:28383
+#: cp/parser.c:28380
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "se esperaba %<template%>"
 
-#: cp/parser.c:28386
+#: cp/parser.c:28383
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "se esperaba %<namespace%>"
 
-#: cp/parser.c:28389
+#: cp/parser.c:28386
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "se esperaba %<using%>"
 
-#: cp/parser.c:28392
+#: cp/parser.c:28389
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "se esperaba %<asm%>"
 
-#: cp/parser.c:28395
+#: cp/parser.c:28392
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "se esperaba %<try%>"
 
-#: cp/parser.c:28398
+#: cp/parser.c:28395
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "se esperaba %<catch%>"
 
-#: cp/parser.c:28401
+#: cp/parser.c:28398
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "se esperaba %<throw%>"
 
-#: cp/parser.c:28404
+#: cp/parser.c:28401
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "se esperaba %<__label__%>"
 
-#: cp/parser.c:28407
+#: cp/parser.c:28404
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "se esperaba %<@try%>"
 
-#: cp/parser.c:28410
+#: cp/parser.c:28407
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "se esperaba %<@synchronized%>"
 
-#: cp/parser.c:28413
+#: cp/parser.c:28410
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "se esperaba %<@throw%>"
 
-#: cp/parser.c:28416
+#: cp/parser.c:28413
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "se esperaba %<__transaction_atomic%>"
 
-#: cp/parser.c:28419
+#: cp/parser.c:28416
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "se esperaba %<__transaction_relaxed%>"
 
-#: cp/parser.c:28451
+#: cp/parser.c:28448
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "se esperaba %<::%>"
 
-#: cp/parser.c:28463
+#: cp/parser.c:28460
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "se esperaba %<...%>"
 
-#: cp/parser.c:28466
+#: cp/parser.c:28463
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "se esperaba %<*%>"
 
-#: cp/parser.c:28469
+#: cp/parser.c:28466
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "se esperaba %<~%>"
 
-#: cp/parser.c:28475
+#: cp/parser.c:28472
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "se esperaba %<:%> o %<::%>"
 
-#: cp/parser.c:28502
+#: cp/parser.c:28499
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "se esperaba %<class%>, %<typename%> o %<template%>"
 
-#: cp/parser.c:28772
+#: cp/parser.c:28769
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "se usó la etiqueta %qs al nombrar a %q#T"
 
-#: cp/parser.c:28777
+#: cp/parser.c:28774
 #, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "%q#T se declaró previamente aquí"
 
-#: cp/parser.c:28798
+#: cp/parser.c:28795
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD se redeclaró con acceso diferente"
 
-#: cp/parser.c:28819
+#: cp/parser.c:28816
 #, fuzzy, gcc-internal-format
 #| msgid "%<template%> (as a disambiguator) is only allowed within templates"
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "%<template%> (como desambiguador) sólo se permite dentro de plantillas"
 
-#: cp/parser.c:29062
+#: cp/parser.c:29059
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "el fichero termina en el argumento por defecto"
 
-#: cp/parser.c:29303 cp/parser.c:30620 cp/parser.c:30808
+#: cp/parser.c:29300 cp/parser.c:30617 cp/parser.c:30805
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "construct Objective-C++ %<@%D%> mal ubicado"
 
-#: cp/parser.c:29372
+#: cp/parser.c:29369
 #, fuzzy, gcc-internal-format
 #| msgid "objective-c++ message argument(s) are expected"
 msgid "objective-c++ message receiver expected"
 msgstr "se esperaba(n) argumento(s) de mensaje de objective-c++"
 
-#: cp/parser.c:29442
+#: cp/parser.c:29439
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr "se esperaba(n) argumento(s) de mensaje de objective-c++"
 
-#: cp/parser.c:29473
+#: cp/parser.c:29470
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "%<@encode%> debe especificar un tipo como un argumento"
 
-#: cp/parser.c:29883
+#: cp/parser.c:29880
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "nombre de selector Objective-C++ no válido"
 
-#: cp/parser.c:29958 cp/parser.c:29976
+#: cp/parser.c:29955 cp/parser.c:29973
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr "se esperaba una declaración de método de objective-c++"
 
-#: cp/parser.c:29970 cp/parser.c:30035
+#: cp/parser.c:29967 cp/parser.c:30032
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "los atributos de método se deben especificar al final"
 
-#: cp/parser.c:30078
+#: cp/parser.c:30075
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr "%qs sobrante después de los métodos Objective-C++"
 
-#: cp/parser.c:30284 cp/parser.c:30291 cp/parser.c:30298
+#: cp/parser.c:30281 cp/parser.c:30288 cp/parser.c:30295
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "tipo no válido para la variable de de instancia"
 
-#: cp/parser.c:30413
+#: cp/parser.c:30410
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "se esperaba un identificador después de %<@protocol%>"
 
-#: cp/parser.c:30585
+#: cp/parser.c:30582
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr "los atributos no se pueden especificar antes de la palabra clave de Objective-C++ %<@%D%>"
 
-#: cp/parser.c:30592
+#: cp/parser.c:30589
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "se descartan los atributos de prefijo antes de %<@%D%>"
 
-#: cp/parser.c:30867 cp/parser.c:30874 cp/parser.c:30881
+#: cp/parser.c:30864 cp/parser.c:30871 cp/parser.c:30878
 #, gcc-internal-format
 msgid "invalid type for property"
 msgstr "tipo no válido para la propiedad"
 
-#: cp/parser.c:32011
+#: cp/parser.c:32008
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<wait%> expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/parser.c:32724
+#: cp/parser.c:32721
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid reduction-identifier"
 msgstr "inicializador no válido"
 
-#: cp/parser.c:34911
+#: cp/parser.c:34908
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr "no se permite la inicialización entre paréntesis para el bucle %<for%> en OpenMP"
 
-#: cp/parser.c:35231 cp/pt.c:16392
+#: cp/parser.c:35228 cp/pt.c:16414
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "la variable de iteración %qD no debe ser reduction"
 
-#: cp/parser.c:35316
+#: cp/parser.c:35313
 #, fuzzy, gcc-internal-format
 #| msgid "not enough DO loops for collapsed !$OMP DO at %L"
 msgid "not enough for loops to collapse"
 msgstr "no hay suficientes bucles DO para los !$OMP DO colapsados en %L"
 
-#: cp/parser.c:37521
+#: cp/parser.c:37518
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer clause"
 msgstr "inicializador no válido"
 
-#: cp/parser.c:37549
+#: cp/parser.c:37546
 #, fuzzy, gcc-internal-format
 #| msgid "expected id-expression"
 msgid "expected id-expression (arguments)"
 msgstr "se esperaba una expresión id"
 
-#: cp/parser.c:37561
+#: cp/parser.c:37558
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:37662
+#: cp/parser.c:37659
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in declare reduction type list"
 msgstr "no se pueden definir tipos nuevos en un tipo de devolución"
 
-#: cp/parser.c:37682 cp/semantics.c:5405
+#: cp/parser.c:37679 cp/semantics.c:5408
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37687 cp/semantics.c:5414
+#: cp/parser.c:37684 cp/semantics.c:5417
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37690 cp/pt.c:12944 cp/semantics.c:5420
+#: cp/parser.c:37687 cp/pt.c:12966 cp/semantics.c:5423
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37693 cp/semantics.c:5426
+#: cp/parser.c:37690 cp/semantics.c:5429
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:38047
+#: cp/parser.c:38044
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:38057
+#: cp/parser.c:38054
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qD does not refer to a namespace scope function"
@@ -46928,50 +46977,50 @@
 msgstr "%qD no es una función plantilla miembro"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:38392
+#: cp/parser.c:38389
 #, gcc-internal-format
 msgid "atomic_cancel"
 msgstr ""
 
-#: cp/parser.c:38435 cp/semantics.c:8575
+#: cp/parser.c:38432 cp/semantics.c:8578
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr "%<__transaction_relaxed%> sin activar el soporte de memoria transaccional"
 
-#: cp/parser.c:38437 cp/semantics.c:8577
+#: cp/parser.c:38434 cp/semantics.c:8580
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr "%<__transaction_atomic%> sin activar el soporte de memoria transaccional"
 
-#: cp/parser.c:38631
+#: cp/parser.c:38628
 #, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "basura al final de %<#pragma GCC pch_preprocess%>"
 
-#: cp/parser.c:38927
+#: cp/parser.c:38924
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "no se permite #pragma GCC optimize dentro de funciones"
 
-#: cp/parser.c:38959
+#: cp/parser.c:38956
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr "no se permite #pragma GCC optimize dentro de funciones"
 
-#: cp/parser.c:39039
+#: cp/parser.c:39036
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "no se han implementado las optimizaciones intermódulos para C++"
 
-#: cp/parser.c:39295
+#: cp/parser.c:39292
 #, fuzzy, gcc-internal-format
 #| msgid "templates may not be %<virtual%>"
 msgid "implicit templates may not be %<virtual%>"
 msgstr "las plantillas no pueden ser %<virtual%>"
 
-#: cp/parser.c:39351
+#: cp/parser.c:39348
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
@@ -47060,7 +47109,7 @@
 msgid "specialization of %qD after instantiation"
 msgstr "especialización de %qD después de la instanciación"
 
-#: cp/pt.c:1954 cp/semantics.c:5274
+#: cp/pt.c:1954 cp/semantics.c:5277
 #, fuzzy, gcc-internal-format
 #| msgid "%s %+#D"
 msgid "%s %#qD"
@@ -47242,120 +47291,120 @@
 msgid "argument to __integer_pack must be between 0 and %d"
 msgstr "El argumento de ACOS en %L debe estar entre -1 y 1"
 
-#: cp/pt.c:3942
+#: cp/pt.c:3955
 #, fuzzy, gcc-internal-format
 #| msgid "base initializer expansion %<%T%> contains no parameter packs"
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr "la expansión del inicializador base %<%T%> no contiene paquetes de parámetro"
 
-#: cp/pt.c:4010
+#: cp/pt.c:4023
 #, fuzzy, gcc-internal-format
 #| msgid "expansion pattern %<%T%> contains no argument packs"
 msgid "expansion pattern %qT contains no argument packs"
 msgstr "el patrón de expansión %<%T%> no contiene paquetes de argumento"
 
-#: cp/pt.c:4012
+#: cp/pt.c:4025
 #, fuzzy, gcc-internal-format
 #| msgid "expansion pattern %<%E%> contains no argument packs"
 msgid "expansion pattern %qE contains no argument packs"
 msgstr "el patrón de expansión %<%E%> no contiene paquetes de argumento"
 
-#: cp/pt.c:4063
+#: cp/pt.c:4077
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr "no se expanden los paquetes de parámetro con %<...%>"
 
-#: cp/pt.c:4080 cp/pt.c:4835
+#: cp/pt.c:4094 cp/pt.c:4849
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
 
-#: cp/pt.c:4082
+#: cp/pt.c:4096
 #, gcc-internal-format
 msgid "        <anonymous>"
 msgstr "        <anónimo>"
 
-#: cp/pt.c:4208
+#: cp/pt.c:4222
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr "la declaración de %q+D oscurece un parámetro"
 
-#: cp/pt.c:4211
+#: cp/pt.c:4225
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of %q+#D shadows template parameter"
 msgstr "la declaración de %q+D oscurece un parámetro"
 
-#: cp/pt.c:4213
+#: cp/pt.c:4227
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter type %qT declared %<friend%>"
 msgid "template parameter %qD declared here"
 msgstr "el tipo de parámetro de plantilla %qT se declaró %<friend%>"
 
-#: cp/pt.c:4771
+#: cp/pt.c:4785
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization of alias template %qD"
 msgid "specialization of variable concept %q#D"
 msgstr "especialización parcial de la plantilla alias %qD"
 
-#: cp/pt.c:4830
+#: cp/pt.c:4844
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "template parameters not deducible in partial specialization:"
 msgstr "no se usan los parámetros de plantilla en la especialización parcial:"
 
-#: cp/pt.c:4854
+#: cp/pt.c:4868
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr "la especialización parcial %qT no especializa ningún argumento de plantilla"
 
-#: cp/pt.c:4858
+#: cp/pt.c:4872
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr "la especialización parcial %qT no especializa ningún argumento de plantilla"
 
-#: cp/pt.c:4862 cp/pt.c:4873
+#: cp/pt.c:4876 cp/pt.c:4887
 #, fuzzy, gcc-internal-format
 #| msgid "previously declared here"
 msgid "primary template here"
 msgstr "se declaró previamente aquí"
 
-#: cp/pt.c:4870
+#: cp/pt.c:4884
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:4885
+#: cp/pt.c:4899
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "partial specialization %qD is not more specialized than"
 msgstr "la especialización parcial %qT no especializa ningún argumento de plantilla"
 
-#: cp/pt.c:4887
+#: cp/pt.c:4901
 #, fuzzy, gcc-internal-format
 #| msgid "previously declared here"
 msgid "primary template %qD"
 msgstr "se declaró previamente aquí"
 
-#: cp/pt.c:4934
+#: cp/pt.c:4948
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr "el argumento de paquete de parámetro %qE debe estar al final de la lista de argumentos de plantilla"
 
-#: cp/pt.c:4937
+#: cp/pt.c:4951
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr "el argumento de paquete de parámetro %qT debe estar al final de la lista de argumentos de plantilla"
 
-#: cp/pt.c:4958
+#: cp/pt.c:4972
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr "el argumento de plantilla %qE involucra a el(los) parámetro(s) de plantilla"
 
-#: cp/pt.c:5004
+#: cp/pt.c:5018
 #, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
@@ -47362,19 +47411,19 @@
 msgstr[0] "el tipo %qT del argumento de plantilla %qE depende de un parámetro de plantilla"
 msgstr[1] "el tipo %qT del argumento de plantilla %qE depende de parámetros de plantilla"
 
-#: cp/pt.c:5066
+#: cp/pt.c:5080
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "instanciación de plantilla clase ambigua para %q#T"
 
-#: cp/pt.c:5070
+#: cp/pt.c:5084
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization of %qT after instantiation of %qT"
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "especialización parcial de %qT después de la instanciación %qT"
 
-#: cp/pt.c:5247
+#: cp/pt.c:5261
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "no hay un argumento por defecto para %qD"
@@ -47382,50 +47431,50 @@
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5269
+#: cp/pt.c:5283
 #, fuzzy, gcc-internal-format
 #| msgid "parameter pack %qE must be at the end of the template parameter list"
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "el parámetro de paquete %qE debe estar al final de la lista de parámetros de plantilla"
 
-#: cp/pt.c:5305
+#: cp/pt.c:5319
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "no se pueden usar los argumentos de plantilla por defecto en la re-declaración friend de la plantilla de función"
 
-#: cp/pt.c:5308
+#: cp/pt.c:5322
 #, fuzzy, gcc-internal-format
 #| msgid "default template arguments may not be used in function template friend declarations"
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "no se pueden usar los argumentos de plantilla por defecto en las declaraciones friend de la plantilla de función"
 
-#: cp/pt.c:5311
+#: cp/pt.c:5325
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without -std=c++11 or -std=gnu++11"
 msgstr "los argumentos de plantilla por defecto no se pueden usar en las plantillas de función sin -std=c++11 o -std=gnu++11"
 
-#: cp/pt.c:5314
+#: cp/pt.c:5328
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr "no se pueden usar los argumentos de plantilla por defecto en las especializaciones parciales"
 
-#: cp/pt.c:5317 cp/pt.c:5375
+#: cp/pt.c:5331 cp/pt.c:5389
 #, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "argumento por defecto para el parámetro de plantilla para la clase incluyente %qD"
 
-#: cp/pt.c:5489
+#: cp/pt.c:5503
 #, fuzzy, gcc-internal-format
 #| msgid "namespace %qT undeclared"
 msgid "template %qD declared"
 msgstr "espacio de nombres %qT sin declarar"
 
-#: cp/pt.c:5496
+#: cp/pt.c:5510
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "clase de plantilla sin nombre"
 
-#: cp/pt.c:5504
+#: cp/pt.c:5518
 #, fuzzy, gcc-internal-format
 #| msgid "non-member function %qD cannot have cv-qualifier"
 msgid "member template %qD may not have virt-specifiers"
@@ -47436,58 +47485,58 @@
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5526
+#: cp/pt.c:5540
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "declaración de la plantilla de %qD no válida"
 
-#: cp/pt.c:5669
+#: cp/pt.c:5683
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "definición de plantilla de %q#D que no es plantilla"
 
-#: cp/pt.c:5712
+#: cp/pt.c:5726
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "se esperaban %d niveles de parámetros de plantilla para %q#D, se obtuvieron %d"
 
-#: cp/pt.c:5726
+#: cp/pt.c:5740
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "se obtuvieron %d parámetros de plantilla para %q#D"
 
-#: cp/pt.c:5729
+#: cp/pt.c:5743
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "se obtuvieron %d parámetros de plantilla para %q#T"
 
-#: cp/pt.c:5731
+#: cp/pt.c:5745
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  pero se requieren %d"
 
-#: cp/pt.c:5752
+#: cp/pt.c:5766
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "los argumentos de plantilla para %qD no coinciden con la plantilla original %qD"
 
-#: cp/pt.c:5755
+#: cp/pt.c:5769
 #, fuzzy, gcc-internal-format
 #| msgid "use template<> for an explicit specialization"
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "utilice template<> para una especialización explícita"
 
-#: cp/pt.c:5882
+#: cp/pt.c:5896
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT no es un tipo plantilla"
 
-#: cp/pt.c:5895
+#: cp/pt.c:5909
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "no se especificaron los especificadores de plantilla en la declaración de %qD"
 
-#: cp/pt.c:5906
+#: cp/pt.c:5920
 #, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
@@ -47494,7 +47543,7 @@
 msgstr[0] "se redeclaró con %d parámetro de plantilla"
 msgstr[1] "se redeclaró con %d parámetros de plantilla"
 
-#: cp/pt.c:5910
+#: cp/pt.c:5924
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D used %d template parameter"
 #| msgid_plural "previous declaration %q+D used %d template parameters"
@@ -47503,12 +47552,12 @@
 msgstr[0] "la declaración previa de %q+#D usó %d parámetro de plantilla"
 msgstr[1] "la declaración previa de %q+#D usó %d parámetros de plantilla"
 
-#: cp/pt.c:5947
+#: cp/pt.c:5961
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "parámetro de plantilla %q+#D"
 
-#: cp/pt.c:5948
+#: cp/pt.c:5962
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "redeclarado aquí como %q#D"
@@ -47517,121 +47566,121 @@
 #.
 #. A template-parameter may not be given default arguments
 #. by two different declarations in the same scope.
-#: cp/pt.c:5958
+#: cp/pt.c:5972
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "redefinición del argumento por defecto para %q#D"
 
-#: cp/pt.c:5960
+#: cp/pt.c:5974
 #, gcc-internal-format
 msgid "original definition appeared here"
 msgstr "la definición original apareció aquí"
 
-#: cp/pt.c:5988
+#: cp/pt.c:6002
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration %qD differs in %<constexpr%>"
 msgid "redeclaration %q#D with different constraints"
 msgstr "la redeclaración de %qD difiere en %<constexpr%>"
 
-#: cp/pt.c:5991
+#: cp/pt.c:6005
 #, fuzzy, gcc-internal-format
 #| msgid "original definition appeared here"
 msgid "original declaration appeared here"
 msgstr "la definición original apareció aquí"
 
-#: cp/pt.c:6250 cp/pt.c:6318
+#: cp/pt.c:6264 cp/pt.c:6332
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%qE no es un argumento de plantilla válido para el tipo %qT"
 
-#: cp/pt.c:6253
+#: cp/pt.c:6267
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr "debe ser la dirección de una función con enlace externo"
 
-#: cp/pt.c:6256
+#: cp/pt.c:6270
 #, fuzzy, gcc-internal-format
 #| msgid "it must be the address of a function with external linkage"
 msgid "it must be the name of a function with external linkage"
 msgstr "debe ser la dirección de una función con enlace externo"
 
-#: cp/pt.c:6268
+#: cp/pt.c:6282
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%qE no es un argumento válido de plantilla para el tipo %qT porque %qD no tiene enlace"
 
-#: cp/pt.c:6272
+#: cp/pt.c:6286
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%qE no es un argumento válido de plantilla para el tipo %qT porque %qD no tiene enlace externo"
 
-#: cp/pt.c:6321
+#: cp/pt.c:6335
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "debe ser un puntero-a-miembro de la forma %<&X::Y%>"
 
-#: cp/pt.c:6323
+#: cp/pt.c:6337
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qT"
 msgid "because it is a member of %qT"
 msgstr "%qD no es un miembro de %qT"
 
-#: cp/pt.c:6383
+#: cp/pt.c:6397
 #, gcc-internal-format
 msgid "  couldn't deduce template parameter %qD"
 msgstr "  no se puede deducir el parámetro de plantilla %qD"
 
-#: cp/pt.c:6392
+#: cp/pt.c:6406
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr "  los tipos %qT y %qT tiene calificadores-cv incompatibles"
 
-#: cp/pt.c:6401
+#: cp/pt.c:6415
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr "  no coinciden los tipos %qT y %qT"
 
-#: cp/pt.c:6410
+#: cp/pt.c:6424
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr "  el parámetro de plantilla %qD no es un paquete de parámetro, pero el argumento %qD sí"
 
-#: cp/pt.c:6421
+#: cp/pt.c:6435
 #, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "  el argumento de plantilla %qE no coincide con la constante puntero-a-miembro %qE"
 
-#: cp/pt.c:6431
+#: cp/pt.c:6445
 #, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr "  %qE no es equivalente a %qE"
 
-#: cp/pt.c:6440
+#: cp/pt.c:6454
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr "  deducción de paquete de parámetros inconsistente con %qT y %qT"
 
-#: cp/pt.c:6452
+#: cp/pt.c:6466
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr "  se deducen tipos en conflicto para el parámetro %qT (%qT y %qT)"
 
-#: cp/pt.c:6456
+#: cp/pt.c:6470
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr "  se deducen valores en conflicto para el parámetro %qE que no es tipo (%qE y %qE)"
 
-#: cp/pt.c:6467
+#: cp/pt.c:6481
 #, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "  el tipo matriz de tamaño variable %qT no es un argumento de plantilla válido"
 
-#: cp/pt.c:6478
+#: cp/pt.c:6492
 #, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr "  el tipo de función miembro %qT no es un argumento de plantilla válido"
 
-#: cp/pt.c:6490
+#: cp/pt.c:6504
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "  candidate expects %d argument, %d provided"
 #| msgid_plural "  candidate expects %d arguments, %d provided"
@@ -47640,315 +47689,315 @@
 msgstr[0] "  el candidato espera %d argumento, se proporcionaron %d"
 msgstr[1] "  el candidato espera %d argumentos, se proporcionaron %d"
 
-#: cp/pt.c:6521
+#: cp/pt.c:6535
 #, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "  no se puede convertir %qE (tipo %qT) al tipo %qT"
 
-#: cp/pt.c:6534
+#: cp/pt.c:6548
 #, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "  %qT es una clase base ambigua de %qT"
 
-#: cp/pt.c:6538
+#: cp/pt.c:6552
 #, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "  %qT no es derivado de %qT"
 
-#: cp/pt.c:6549
+#: cp/pt.c:6563
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr "  los parámetros de plantilla de un argumento de plantilla plantilla son inconsistentes con otros argumentos de plantilla deducidos"
 
-#: cp/pt.c:6559
+#: cp/pt.c:6573
 #, gcc-internal-format
 msgid "  can't deduce a template for %qT from non-template type %qT"
 msgstr "  no se puede deducir una plantilla para %qT del tipo %qT que no es plantilla"
 
-#: cp/pt.c:6569
+#: cp/pt.c:6583
 #, fuzzy, gcc-internal-format
 #| msgid "  template argument %qE does not match %qD"
 msgid "  template argument %qE does not match %qE"
 msgstr "  el argumento de plantilla %qE no coincide con %qD"
 
-#: cp/pt.c:6609
+#: cp/pt.c:6623
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "%qE no es un argumento válido de plantilla para el tipo %qT porque las literales de cadena nunca se pueden usar en este contexto"
 
-#: cp/pt.c:6758
+#: cp/pt.c:6772
 #, fuzzy, gcc-internal-format
 #| msgid "in template argument for type %qT "
 msgid "in template argument for type %qT"
 msgstr "en el argumento de plantilla para el tipo %qT "
 
-#: cp/pt.c:6772
+#: cp/pt.c:6786
 #, fuzzy, gcc-internal-format
 #| msgid "in template argument for type %qT "
 msgid "template argument %qE for type %qT not a constant integer"
 msgstr "en el argumento de plantilla para el tipo %qT "
 
-#: cp/pt.c:6833
+#: cp/pt.c:6847
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qD no es un argumento válido de plantilla porque %qD es una variable, no la dirección de una variable"
 
-#: cp/pt.c:6841
+#: cp/pt.c:6855
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qD no es un argumento válido de plantilla porque %qD es una variable, no la dirección de una variable"
 
-#: cp/pt.c:6857
+#: cp/pt.c:6871
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "%qE no es un argumento válido de plantilla de tipo %qT porque %qE no es una variable"
 
-#: cp/pt.c:6864
+#: cp/pt.c:6878
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr "%qE no es un argumento válido de plantilla de tipo %qT porque %qD no tiene enlace externo"
 
-#: cp/pt.c:6873
+#: cp/pt.c:6887
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE no es un argumento válido de plantilla de tipo %qT porque %qD no tiene enlace"
 
-#: cp/pt.c:6888
+#: cp/pt.c:6902
 #, fuzzy, gcc-internal-format
 #| msgid "  variable-sized array type %qT is not a valid template argument"
 msgid "the address of %qD is not a valid template argument"
 msgstr "  el tipo matriz de tamaño variable %qT no es un argumento de plantilla válido"
 
-#: cp/pt.c:6897
+#: cp/pt.c:6911
 #, fuzzy, gcc-internal-format
 #| msgid "  variable-sized array type %qT is not a valid template argument"
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr "  el tipo matriz de tamaño variable %qT no es un argumento de plantilla válido"
 
-#: cp/pt.c:6904
+#: cp/pt.c:6918
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "%qE no es un argumento válido de plantilla de tipo %qT porque %qD no tiene enlace externo"
 
-#: cp/pt.c:6933
+#: cp/pt.c:6947
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "%qE no es un argumento de plantilla válido para el tipo %qT debido a conflictos en la calificación cv"
 
-#: cp/pt.c:6941
+#: cp/pt.c:6955
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE no es un argumento válido de plantilla para el tipo %qT porque no es un l-valor"
 
-#: cp/pt.c:6959
+#: cp/pt.c:6973
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%q#D no es un argumento válido de plantilla para el tipo %qT porque una referencia variable no tiene una dirección constante"
 
-#: cp/pt.c:6975
+#: cp/pt.c:6989
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is not an object with external linkage"
 msgid "%qE is not a valid template argument for type %qT because it is not an object with linkage"
 msgstr "%qE no es un argumento válido de plantilla para el tipo %qT porque no es un objeto con enlace externo"
 
-#: cp/pt.c:6986
+#: cp/pt.c:7000
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "%qE is not a valid template argument for type %qT because object %qD does not have linkage"
 msgstr "%qE no es un argumento válido de plantilla para el tipo %qT porque el objeto %qD no tiene enlace externo"
 
-#: cp/pt.c:7036
+#: cp/pt.c:7050
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE no es un argumento de plantilla válido para el tipo %qT porque es un puntero"
 
-#: cp/pt.c:7038
+#: cp/pt.c:7052
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "intente utilizar %qE en su lugar"
 
-#: cp/pt.c:7092
+#: cp/pt.c:7106
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE no es un argumento de plantilla válido para el tipo %qT porque es de tipo %qT"
 
-#: cp/pt.c:7654
+#: cp/pt.c:7668
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "se descartan los atributos en el argumento de plantilla %qT"
 
-#: cp/pt.c:7670
+#: cp/pt.c:7684
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes on template argument %qT"
 msgid "ignoring attributes in template argument %qE"
 msgstr "se descartan los atributos en el argumento de plantilla %qT"
 
-#: cp/pt.c:7805
+#: cp/pt.c:7819
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "se usó el nombre-de-clase-inyectada %qD como un argumento de plantilla plantilla"
 
-#: cp/pt.c:7834
+#: cp/pt.c:7848
 #, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "uso no válido del destructor %qE como un tipo"
 
-#: cp/pt.c:7839
+#: cp/pt.c:7853
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "para hacer referencia a un tipo miembro de un parámetro de plantilla, use %<typename %E%>"
 
-#: cp/pt.c:7855 cp/pt.c:7877 cp/pt.c:7931
+#: cp/pt.c:7869 cp/pt.c:7891 cp/pt.c:7945
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "no coincide el tipo/valor en el argumento %d en la lista de parámetros de plantilla para %qD"
 
-#: cp/pt.c:7860
+#: cp/pt.c:7874
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  se esperaba una constante de tipo %qT, se obtuvo %qT"
 
-#: cp/pt.c:7865
+#: cp/pt.c:7879
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  se esperaba una plantilla de clase, se obtuvo %qE"
 
-#: cp/pt.c:7868
+#: cp/pt.c:7882
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  se esperaba un tipo, se obtuvo %qE"
 
-#: cp/pt.c:7882
+#: cp/pt.c:7896
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  se esperaba un tipo, se obtuvo %qT"
 
-#: cp/pt.c:7885
+#: cp/pt.c:7899
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  se esperaba una plantilla de clase, se obtuvo %qT"
 
-#: cp/pt.c:7935
+#: cp/pt.c:7949
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  se esperaba una plantilla de tipo %qD, se obtuvo %qT"
 
-#: cp/pt.c:7949
+#: cp/pt.c:7963
 #, fuzzy, gcc-internal-format
 #| msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "no coincide el tipo/valor en el argumento %d en la lista de parámetros de plantilla para %qD"
 
-#: cp/pt.c:7952
+#: cp/pt.c:7966
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a type, got %qE"
 msgid "  expected %qD but got %qD"
 msgstr "  se esperaba un tipo, se obtuvo %qE"
 
-#: cp/pt.c:8012
+#: cp/pt.c:8026
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert template argument %qE to %qT"
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "no se puede convertir el argumento de plantilla %qE a %qT"
 
-#: cp/pt.c:8149 cp/pt.c:8465
+#: cp/pt.c:8163 cp/pt.c:8479
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "el argumento de plantilla %d es no válido"
 
-#: cp/pt.c:8164 cp/pt.c:8298
+#: cp/pt.c:8178 cp/pt.c:8312
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "número erróneo de argumentos de plantilla (%d, debe ser %d)"
 
-#: cp/pt.c:8294
+#: cp/pt.c:8308
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "número erróneo de argumentos de plantilla (%d, debe ser %d)"
 
-#: cp/pt.c:8303
+#: cp/pt.c:8317
 #, fuzzy, gcc-internal-format
 #| msgid "provided for %q+D"
 msgid "provided for %qD"
 msgstr "provisto por %q+D"
 
-#: cp/pt.c:8328
+#: cp/pt.c:8342
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for template parameter for class enclosing %qD"
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr "argumento por defecto para el parámetro de plantilla para la clase incluyente %qD"
 
-#: cp/pt.c:8332
+#: cp/pt.c:8346
 #, fuzzy, gcc-internal-format
 #| msgid "default argument given for parameter %d of %q#D"
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "argumento por defecto dado para el parámetro %d de %q#D"
 
-#: cp/pt.c:8431
+#: cp/pt.c:8445
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:9054
+#: cp/pt.c:9068
 #, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%q#D no es una plantilla de función"
 
-#: cp/pt.c:9221
+#: cp/pt.c:9235
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "se usa el tipo %qT que no es plantilla como una plantilla"
 
-#: cp/pt.c:9223
+#: cp/pt.c:9237
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "para la declaración de plantilla %q+D"
 
-#: cp/pt.c:9346
+#: cp/pt.c:9360
 #, fuzzy, gcc-internal-format
 #| msgid "internal consistency failure"
 msgid "template constraint failure"
 msgstr "falla interna de consistencia"
 
-#: cp/pt.c:9697
+#: cp/pt.c:9718
 #, fuzzy, gcc-internal-format
 #| msgid "use of %qs in template"
 msgid "use of invalid variable template %qE"
 msgstr "uso de %qs en la plantilla"
 
-#: cp/pt.c:10125
+#: cp/pt.c:10148
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum) substituting %qS"
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr "la profundidad de instanciación de la plantilla excede el máximo de %d (use -ftemplate-depth= para incrementar el máximo) al sustituir %qS"
 
-#: cp/pt.c:11202
+#: cp/pt.c:11225
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member in union"
 msgid "flexible array member %qD in union"
 msgstr "miembro de matriz flexible en union"
 
-#: cp/pt.c:11691
+#: cp/pt.c:11713
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:12160
+#: cp/pt.c:12182
 #, fuzzy, gcc-internal-format
 #| msgid "mismatched argument pack lengths while expanding %<%T%>"
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr "no coinciden las longitudes de los paquetes de argumentos al expandir %<%T%>"
 
-#: cp/pt.c:12163
+#: cp/pt.c:12185
 #, fuzzy, gcc-internal-format
 #| msgid "mismatched argument pack lengths while expanding %<%E%>"
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr "no coinciden las longitudes de los paquetes de argumentos al expandir %<%E%>"
 
-#: cp/pt.c:12747
+#: cp/pt.c:12769
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for %q#D"
 msgid "  when instantiating default argument for call to %qD"
@@ -47967,285 +48016,285 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:13708
+#: cp/pt.c:13730
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "la variable %qD tiene tipo de función"
 
-#: cp/pt.c:13881
+#: cp/pt.c:13903
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "tipo de parámetro %qT no válido"
 
-#: cp/pt.c:13883
+#: cp/pt.c:13905
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "en la declaración %q+D"
 
-#: cp/pt.c:14001
+#: cp/pt.c:14023
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "la función devuelve una matriz"
 
-#: cp/pt.c:14003
+#: cp/pt.c:14025
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "la función devuelve una función"
 
-#: cp/pt.c:14043
+#: cp/pt.c:14065
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "se crea un puntero a función miembro del tipo %qT que no es clase"
 
-#: cp/pt.c:14637
+#: cp/pt.c:14659
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "se forma la referencia a void"
 
-#: cp/pt.c:14639
+#: cp/pt.c:14661
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "se forma un puntero para referenciar al tipo %qT"
 
-#: cp/pt.c:14641
+#: cp/pt.c:14663
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "se forma una referencia para referenciar al tipo %qT"
 
-#: cp/pt.c:14654
+#: cp/pt.c:14676
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to qualified function type %qT"
 msgid "forming pointer to qualified function type %qT"
 msgstr "no se puede declarar el puntero para el tipo de función calificado %qT"
 
-#: cp/pt.c:14657
+#: cp/pt.c:14679
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to qualified function type %qT"
 msgid "forming reference to qualified function type %qT"
 msgstr "no se puede declarar la referencia para el tipo de función calificado %qT"
 
-#: cp/pt.c:14705
+#: cp/pt.c:14727
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "se crea un puntero al miembro del tipo %qT que no es clase"
 
-#: cp/pt.c:14711
+#: cp/pt.c:14733
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "se crea un puntero al miembro de referencia de tipo %qT"
 
-#: cp/pt.c:14717
+#: cp/pt.c:14739
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "se crea un puntero al miembro de tipo void"
 
-#: cp/pt.c:14783
+#: cp/pt.c:14805
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "se crea la matriz de %qT"
 
-#: cp/pt.c:14816
+#: cp/pt.c:14838
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT no es de tipo clase, struct o union"
 
-#: cp/pt.c:14853
+#: cp/pt.c:14875
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT resuelve a %qT, el cual no es un tipo enumerado"
 
-#: cp/pt.c:14861
+#: cp/pt.c:14883
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr "%qT resuelve a %qT, el cual no es un tipo de clase"
 
-#: cp/pt.c:14925
+#: cp/pt.c:14947
 #, fuzzy, gcc-internal-format
 #| msgid "non-empty initializer for array of empty elements"
 msgid "empty initializer in lambda init-capture"
 msgstr "inicializador no-vacío para una matriz de elementos vacíos"
 
-#: cp/pt.c:15000
+#: cp/pt.c:15022
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "uso de %qs en la plantilla"
 
-#: cp/pt.c:15178
+#: cp/pt.c:15200
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "el tipo calificador %qT no coincide con el nombre del destructor ~%qT"
 
-#: cp/pt.c:15193
+#: cp/pt.c:15215
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "el nombre dependiente %qE se decodifica como un no tipo, pero la instanciación genera un tipo"
 
-#: cp/pt.c:15195
+#: cp/pt.c:15217
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "escriba %<typename %E%> si quiere un tipo"
 
-#: cp/pt.c:15394
+#: cp/pt.c:15416
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "se usa el campo no válido %qD"
 
-#: cp/pt.c:15883 cp/pt.c:17386
+#: cp/pt.c:15905 cp/pt.c:17408
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "uso no válido de la expresión de expansión de paquete"
 
-#: cp/pt.c:15887 cp/pt.c:17390
+#: cp/pt.c:15909 cp/pt.c:17412
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "use %<...%> para expandir el paquete de argumentos"
 
-#: cp/pt.c:18334
+#: cp/pt.c:18371
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr "%qD no se declaró en este ámbito, y no se encontraron declaraciones en la búsqueda dependiente de argumentos en el punto de la instanciación"
 
-#: cp/pt.c:18362
+#: cp/pt.c:18399
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr "no se encontraron declaraciones en la base dependiente %qT pur la búsqueda no calificada"
 
-#: cp/pt.c:18367
+#: cp/pt.c:18404
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "use %<this->%D%> en su lugar"
 
-#: cp/pt.c:18370
+#: cp/pt.c:18407
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "use %<%T::%D%> en su lugar"
 
-#: cp/pt.c:18375
+#: cp/pt.c:18412
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here, later in the translation unit"
 msgid "%qD declared here, later in the translation unit"
 msgstr "%q+D se declaró aquí, después en la unidad de translación"
 
-#: cp/pt.c:18712
+#: cp/pt.c:18752
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT no es una clase o un espacio de nombres"
 
-#: cp/pt.c:18715
+#: cp/pt.c:18755
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD no es una clase o un espacio de nombres"
 
-#: cp/pt.c:19026
+#: cp/pt.c:19066
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is/uses anonymous type"
 msgid "%qT is/uses unnamed type"
 msgstr "%qT es/usa un tipo anónimo"
 
-#: cp/pt.c:19028
+#: cp/pt.c:19068
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "el argumento de plantilla para %qD usa el tipo local %qT"
 
-#: cp/pt.c:19038
+#: cp/pt.c:19078
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT es un tipo modificado variablemente"
 
-#: cp/pt.c:19053
+#: cp/pt.c:19093
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "la expresión integral %qE no es una constante"
 
-#: cp/pt.c:19071
+#: cp/pt.c:19111
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  se trata de instanciar %qD"
 
-#: cp/pt.c:22972
+#: cp/pt.c:23050
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#T"
 msgstr "instanciación de plantilla clase ambigua para %q#T"
 
-#: cp/pt.c:22974
+#: cp/pt.c:23052
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#D"
 msgstr "instanciación de plantilla clase ambigua para %q#T"
 
-#: cp/pt.c:22980
+#: cp/pt.c:23058
 #, fuzzy
 #| msgid "%s %+#D"
 msgid "%s %#qS"
 msgstr "%s %+#D"
 
-#: cp/pt.c:23004 cp/pt.c:23091
+#: cp/pt.c:23082 cp/pt.c:23169
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "instanciación explícita de %q#D que no es plantilla"
 
-#: cp/pt.c:23023
+#: cp/pt.c:23101
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD no es un dato miembro static de una plantilla de clase"
 
-#: cp/pt.c:23029 cp/pt.c:23086
+#: cp/pt.c:23107 cp/pt.c:23164
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "no se encontró una plantilla coincidente para %qD"
 
-#: cp/pt.c:23034
+#: cp/pt.c:23112
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "el tipo %qT para la instanciación explícita %qD no coincide con el tipo declarado %qT"
 
-#: cp/pt.c:23042
+#: cp/pt.c:23120
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "instanciación explícita de %q#D"
 
-#: cp/pt.c:23078
+#: cp/pt.c:23156
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "instanciación explícita duplicada de %q#D"
 
-#: cp/pt.c:23101 cp/pt.c:23187
+#: cp/pt.c:23179 cp/pt.c:23265
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ 1998 prohíbe el uso de %<extern%> en instanciaciones explícitas"
 
-#: cp/pt.c:23106 cp/pt.c:23204
+#: cp/pt.c:23184 cp/pt.c:23282
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "clase de almacenamiento %qD aplicada a la instanciación de una plantilla"
 
-#: cp/pt.c:23163
+#: cp/pt.c:23241
 #, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "instanciación explícita de la plantilla %qD que no es clase"
 
-#: cp/pt.c:23165
+#: cp/pt.c:23243
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "instanciación explícita del tipo %qT que no es plantilla"
 
-#: cp/pt.c:23174
+#: cp/pt.c:23252
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "instanciación explícita de %q#T antes de la definición de la plantilla"
 
-#: cp/pt.c:23192
+#: cp/pt.c:23270
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ prohíbe el uso de %qE en las instanciaciones explícitas"
 
-#: cp/pt.c:23238
+#: cp/pt.c:23316
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "instanciación explícita duplicada de %q#T"
 
-#: cp/pt.c:23536
+#: cp/pt.c:23614
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "exception specification of %qD depends on itself"
@@ -48258,117 +48307,117 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:23842
+#: cp/pt.c:23920
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "instanciación explícita de %qD pero no hay una definición disponible"
 
-#: cp/pt.c:24043
+#: cp/pt.c:24121
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr "la profundidad de instanciación de la plantilla excede el máximo de %d al instanciar %q+D, posiblemente de la generación de tabla virtual (use -ftemplate-depth= para incrementar el máximo)"
 
-#: cp/pt.c:24418
+#: cp/pt.c:24496
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "parámetro que no es tipo plantilla no válido"
 
-#: cp/pt.c:24420
+#: cp/pt.c:24498
 #, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T no es un tipo válido para un parámetro que no es tipo plantilla"
 
-#: cp/pt.c:25723
+#: cp/pt.c:25802
 #, fuzzy, gcc-internal-format
 #| msgid "keyword %<typename%> not allowed outside of templates"
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "no se permite la palabra clave %<typename%> fuera de las plantillas"
 
-#: cp/pt.c:25961
+#: cp/pt.c:26040
 #, fuzzy, gcc-internal-format
 #| msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr "la deducción de una lista inicializadora encerrada entre llaves requiere #include <initializer_list>"
 
-#: cp/pt.c:26440
+#: cp/pt.c:26519
 #, fuzzy, gcc-internal-format
 #| msgid "non-template %qD used as template"
 msgid "non-class template %qT used without template arguments"
 msgstr "se usó %qD que no es plantilla como plantilla"
 
-#: cp/pt.c:26586
+#: cp/pt.c:26665
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:26593
+#: cp/pt.c:26672
 #, fuzzy, gcc-internal-format
 #| msgid "in template argument for type %qT "
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "en el argumento de plantilla para el tipo %qT "
 
-#: cp/pt.c:26607
+#: cp/pt.c:26686
 #, fuzzy, gcc-internal-format
 #| msgid "  template argument deduction/substitution failed:"
 msgid "class template argument deduction failed:"
 msgstr "  falló la deducción/sustitución del argumento de plantilla:"
 
-#: cp/pt.c:26614
+#: cp/pt.c:26693
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "la función no se consideró para la inclusión en línea"
 
-#: cp/pt.c:26676
+#: cp/pt.c:26755
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:26679
+#: cp/pt.c:26758
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:26711
+#: cp/pt.c:26790
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/pt.c:26746
+#: cp/pt.c:26825
 #, fuzzy, gcc-internal-format
 #| msgid "unable to deduce %qT from %qE"
 msgid "unable to deduce lambda return type from %qE"
 msgstr "no se puede deducir %qT de %qE"
 
-#: cp/pt.c:26748
+#: cp/pt.c:26827
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "no se puede deducir %qT de %qE"
 
-#: cp/pt.c:26781
+#: cp/pt.c:26860
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:26785
+#: cp/pt.c:26864
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "la insn no satisface sus restricciones:"
 
-#: cp/pt.c:26789
+#: cp/pt.c:26868
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "la insn no satisface sus restricciones:"
 
-#: cp/pt.c:26793
+#: cp/pt.c:26872
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "la insn no satisface sus restricciones:"
 
-#: cp/pt.c:26912
+#: cp/pt.c:26991
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of '%E' as a non-type template-argument"
 msgid "invalid use of %qT in template argument"
@@ -48427,85 +48476,85 @@
 msgid "cannot dynamic_cast %qE (of type %q#T) to type %q#T (%s)"
 msgstr "no se puede hacer dynamic_cast %qE (de tipo %q#T) al tipo %q#T (%s)"
 
-#: cp/search.c:240
+#: cp/search.c:243
 #, gcc-internal-format
 msgid "%qT is an ambiguous base of %qT"
 msgstr "%qT es una base ambigua de %qT"
 
-#: cp/search.c:256
+#: cp/search.c:259
 #, gcc-internal-format
 msgid "%qT is an inaccessible base of %qT"
 msgstr "%qT es una base inaccesible de %qT"
 
-#: cp/search.c:1905
+#: cp/search.c:1908
 #, fuzzy, gcc-internal-format
 #| msgid "invalid covariant return type for %q+#D"
 msgid "invalid covariant return type for %q#D"
 msgstr "tipo de devolución covariante no válido para %q+#D"
 
-#: cp/search.c:1907 cp/search.c:1922 cp/search.c:1928 cp/search.c:1957
+#: cp/search.c:1910 cp/search.c:1925 cp/search.c:1931 cp/search.c:1960
 #, fuzzy, gcc-internal-format
 #| msgid "overriding deleted function %q+D"
 msgid "overridden function is %q#D"
 msgstr "se sobreescribe la función borrada %q+D"
 
-#: cp/search.c:1920
+#: cp/search.c:1923
 #, gcc-internal-format
 msgid "invalid covariant return type for %q+#D"
 msgstr "tipo de devolución covariante no válido para %q+#D"
 
-#: cp/search.c:1926
+#: cp/search.c:1929
 #, gcc-internal-format
 msgid "conflicting return type specified for %q+#D"
 msgstr "se especificaron tipos de devolución en conflicto para %q+#D"
 
-#: cp/search.c:1942
+#: cp/search.c:1945
 #, gcc-internal-format
 msgid "looser throw specifier for %q+#F"
 msgstr "especificador throw más flexible para %q+#F"
 
-#: cp/search.c:1944
+#: cp/search.c:1947
 #, fuzzy, gcc-internal-format
 #| msgid "overriding deleted function %q+D"
 msgid "overridden function is %q#F"
 msgstr "se sobreescribe la función borrada %q+D"
 
-#: cp/search.c:1955
+#: cp/search.c:1958
 #, gcc-internal-format
 msgid "conflicting type attributes specified for %q+#D"
 msgstr "se especificaron atributos de tipo en conflicto para %q+#D"
 
-#: cp/search.c:1972
+#: cp/search.c:1975
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<__transaction_atomic%>"
 msgid "%qD declared %<transaction_safe_dynamic%>"
 msgstr "se esperaba %<__transaction_atomic%>"
 
-#: cp/search.c:1974
+#: cp/search.c:1977
 #, fuzzy, gcc-internal-format
 #| msgid "variable %q+D declared %<inline%>"
 msgid "overriding %qD declared %<transaction_safe%>"
 msgstr "la variable %q+D se declaró como %<inline%>"
 
-#: cp/search.c:1981
+#: cp/search.c:1984
 #, fuzzy, gcc-internal-format
 #| msgid "overriding non-deleted function %q+D"
 msgid "deleted function %q+D overriding non-deleted function"
 msgstr "se sobreescribe la función %q+D que no se borró"
 
-#: cp/search.c:1984 cp/search.c:1992 cp/search.c:2000
+#: cp/search.c:1987 cp/search.c:1995 cp/search.c:2003
 #, fuzzy, gcc-internal-format
 #| msgid "overriding deleted function %q+D"
 msgid "overridden function is %qD"
 msgstr "se sobreescribe la función borrada %q+D"
 
-#: cp/search.c:1989
+#: cp/search.c:1992
 #, fuzzy, gcc-internal-format
 #| msgid "non-deleted function %q+D"
 msgid "non-deleted function %q+D overriding deleted function"
 msgstr "la función %q+D que no se borró"
 
-#: cp/search.c:1998
+#: cp/search.c:2001
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "virtual function %q+D overriding final function"
@@ -48513,12 +48562,12 @@
 
 #. A static member function cannot match an inherited
 #. virtual member function.
-#: cp/search.c:2082
+#: cp/search.c:2085
 #, gcc-internal-format
 msgid "%q+#D cannot be declared"
 msgstr "%q+#D no se puede declarar"
 
-#: cp/search.c:2083
+#: cp/search.c:2086
 #, gcc-internal-format
 msgid "  since %q+#D declared in base class"
 msgstr "  ya que se declaró %q+#D en la clase base"
@@ -48560,633 +48609,649 @@
 msgid "invalid use of member %qD in static member function"
 msgstr "uso no válido del miembro %q+D en la función miembro static"
 
-#: cp/semantics.c:2153
+#: cp/semantics.c:2156
 #, gcc-internal-format
 msgid "a statement expression is an insufficient context for overload resolution"
 msgstr ""
 
-#: cp/semantics.c:2540
+#: cp/semantics.c:2543
 #, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr "no se permiten argumentos para el destructor"
 
-#: cp/semantics.c:2622
+#: cp/semantics.c:2625
 #, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr "%<this%> no está disponible para funciones miembro static"
 
-#: cp/semantics.c:2624
+#: cp/semantics.c:2627
 #, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr "uso no válido de %<this%> en la función que no es miembro"
 
-#: cp/semantics.c:2626
+#: cp/semantics.c:2629
 #, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr "uso no válido de %<this%> en el nivel principal"
 
-#: cp/semantics.c:2648
+#: cp/semantics.c:2651
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "ámbito calificador no válido en el nombre del seudo-destructor"
 
-#: cp/semantics.c:2656 cp/typeck.c:2604
+#: cp/semantics.c:2659 cp/typeck.c:2604
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "el tipo calificado %qT no coincide con el nombre del destructor ~%qT"
 
-#: cp/semantics.c:2678
+#: cp/semantics.c:2681
 #, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr "%qE no es de tipo %qT"
 
-#: cp/semantics.c:2751
+#: cp/semantics.c:2754
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr "la literal compuesta del tipo %qT que no es objeto"
 
-#: cp/semantics.c:2892
+#: cp/semantics.c:2895
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr "los parámetros de tipo plantilla debe usar la palabra clave %<class%> o %<typename%>"
 
-#: cp/semantics.c:2942
+#: cp/semantics.c:2945
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr "uso no válido del tipo %qT como un valor por defecto para una plantilla de parámetro de plantilla"
 
-#: cp/semantics.c:2945
+#: cp/semantics.c:2948
 #, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr "argumento por defecto no válido para una plantilla de parámetro de plantilla"
 
-#: cp/semantics.c:2962
+#: cp/semantics.c:2965
 #, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr "la definición de %q#T dentro de la lista de parámetros de plantilla"
 
-#: cp/semantics.c:2993
+#: cp/semantics.c:2996
 #, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr "definición no válida del tipo calificado %qT"
 
-#: cp/semantics.c:3263
+#: cp/semantics.c:3266
 #, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "especificación de clase base no válida"
 
-#: cp/semantics.c:3423
+#: cp/semantics.c:3426
 #, fuzzy, gcc-internal-format
 #| msgid "protected member %q+#D in anonymous union"
 msgid "cannot capture member %qD of anonymous union"
 msgstr "miembro protegido %q+#D en union anónima"
 
-#: cp/semantics.c:3443 cp/semantics.c:9269
+#: cp/semantics.c:3446 cp/semantics.c:9272
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qD no se capturó"
 
-#: cp/semantics.c:3448
+#: cp/semantics.c:3451
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.c:3450
+#: cp/semantics.c:3453
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.c:3462
+#: cp/semantics.c:3465
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<auto%> variable from containing function"
 msgid "use of local variable with automatic storage from containing function"
 msgstr "uso de la variable %<auto%> desde la función contenedora"
 
-#: cp/semantics.c:3464
+#: cp/semantics.c:3467
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr "uso de parámetro desde la función contenedora"
 
-#: cp/semantics.c:3596
+#: cp/semantics.c:3599
 #, fuzzy, gcc-internal-format
 #| msgid "use of parameter %qD outside function body"
 msgid "use of parameter outside function body"
 msgstr "se usó el parámetro %qD fuera del cuerpo de la función"
 
-#: cp/semantics.c:3606
+#: cp/semantics.c:3609
 #, fuzzy, gcc-internal-format
 #| msgid "in template argument for type %qT "
 msgid "missing template arguments"
 msgstr "en el argumento de plantilla para el tipo %qT "
 
-#: cp/semantics.c:3633
+#: cp/semantics.c:3636
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr "no se permite el parámetro de plantilla %qD de tipo %qT en una expresión integral constante porque no es de tipo integral o de enumeración"
 
-#: cp/semantics.c:3664
+#: cp/semantics.c:3667
 #, gcc-internal-format
 msgid "use of namespace %qD as expression"
 msgstr "uso del espacio de nombres %qD como expresión"
 
-#: cp/semantics.c:3669
+#: cp/semantics.c:3672
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr "uso de la plantilla de clase %qT como expresión"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:3675
+#: cp/semantics.c:3678
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "la petición por el miembro %qD es ambigua en la red de herencia múltiple"
 
-#: cp/semantics.c:3702
+#: cp/semantics.c:3705
 #, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "%qD no puede aparecer en una expresion constante"
 
-#: cp/semantics.c:3841
+#: cp/semantics.c:3844
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "el tipo de %qE es desconocido"
 
-#: cp/semantics.c:3870
+#: cp/semantics.c:3873
 #, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr "%qT no es un tipo de enumeración"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4009
+#: cp/semantics.c:4012
 #, gcc-internal-format
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr "Los paquetes de parámetros __bases sólo son válidos en la declaración de plantilla"
 
-#: cp/semantics.c:4038
+#: cp/semantics.c:4041
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr "no se puede aplicar %<offsetof%> al destructor %<~%T%>"
 
-#: cp/semantics.c:4052
+#: cp/semantics.c:4055
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "no se puede aplicar %<offsetof%> a la función miembro %qD"
 
-#: cp/semantics.c:4056
+#: cp/semantics.c:4059
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply %<offsetof%> to member function %qD"
 msgid "cannot apply %<offsetof%> to member function"
 msgstr "no se puede aplicar %<offsetof%> a la función miembro %qD"
 
-#: cp/semantics.c:4061
+#: cp/semantics.c:4064
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply %<offsetof%> to member function %qD"
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr "no se puede aplicar %<offsetof%> a la función miembro %qD"
 
-#: cp/semantics.c:4072
+#: cp/semantics.c:4075
 #, fuzzy, gcc-internal-format
 #| msgid "cannot receive objects of non-trivially-copyable type %q#T through %<...%>; "
 msgid "offsetof within non-standard-layout type %qT is conditionally-supported"
 msgstr "no se puede recibir objetos de tipo no-copiable-trivialmente q%#T a través de %<...%>"
 
-#: cp/semantics.c:4583 cp/semantics.c:6069 cp/semantics.c:6140
-#: cp/semantics.c:6183 cp/semantics.c:6533 cp/semantics.c:6632
-#: cp/semantics.c:6775
+#: cp/semantics.c:4586 cp/semantics.c:6072 cp/semantics.c:6143
+#: cp/semantics.c:6186 cp/semantics.c:6536 cp/semantics.c:6635
+#: cp/semantics.c:6778
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5271
+#: cp/semantics.c:5274
 #, fuzzy, gcc-internal-format
 #| msgid "reference to %qD is ambiguous"
 msgid "user defined reduction lookup is ambiguous"
 msgstr "la referencia a %qD es ambigua"
 
-#: cp/semantics.c:5544
+#: cp/semantics.c:5547
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: cp/semantics.c:5592
+#: cp/semantics.c:5595
 #, fuzzy, gcc-internal-format
 #| msgid "%qE has invalid type for %<reduction%>"
 msgid "%qE has const type for %<reduction%>"
 msgstr "%qE tiene tipo no válido para %<reduction%>"
 
-#: cp/semantics.c:5707
+#: cp/semantics.c:5710
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:5941
+#: cp/semantics.c:5944
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5955
+#: cp/semantics.c:5958
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5977
+#: cp/semantics.c:5980
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "linear step expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.c:6080
+#: cp/semantics.c:6083
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD no es una variable en la cláusula %qs"
 
-#: cp/semantics.c:6152
+#: cp/semantics.c:6155
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "%qD no es una variable en la cláusula %<firstprivate%>"
 
-#: cp/semantics.c:6195
+#: cp/semantics.c:6198
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "%qD no es una variable en la cláusula %<lastprivate%>"
 
-#: cp/semantics.c:6240
+#: cp/semantics.c:6243
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<gang%> static expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.c:6254
+#: cp/semantics.c:6257
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<gang%> static value must be positive"
 msgstr "el valor de %<num_threads%> debe ser positivo"
 
-#: cp/semantics.c:6288
+#: cp/semantics.c:6291
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<gang%> num expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.c:6291
+#: cp/semantics.c:6294
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<vector%> length expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.c:6295
+#: cp/semantics.c:6298
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<worker%> num expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.c:6317
+#: cp/semantics.c:6320
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<gang%> num value must be positive"
 msgstr "el valor de %<num_threads%> debe ser positivo"
 
-#: cp/semantics.c:6321
+#: cp/semantics.c:6324
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<vector%> length value must be positive"
 msgstr "el valor de %<num_threads%> debe ser positivo"
 
-#: cp/semantics.c:6326
+#: cp/semantics.c:6329
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<worker%> num value must be positive"
 msgstr "el valor de %<num_threads%> debe ser positivo"
 
-#: cp/semantics.c:6376
+#: cp/semantics.c:6379
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr "la expresión schedule chunk size debe ser integral"
 
-#: cp/semantics.c:6406
+#: cp/semantics.c:6409
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%qs length expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.c:6419
+#: cp/semantics.c:6422
 #, fuzzy, gcc-internal-format
 #| msgid "%Hcollapse argument needs positive constant integer expression"
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "%Hel argumento de collapse necesita ser una expresión entera constante positiva"
 
-#: cp/semantics.c:6438
+#: cp/semantics.c:6441
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<async%> expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.c:6466
+#: cp/semantics.c:6469
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<thread_limit%> expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.c:6495
+#: cp/semantics.c:6498
 #, fuzzy, gcc-internal-format
 #| msgid "slice end must be integer"
 msgid "%<device%> id must be integral"
 msgstr "el final de la rebanada debe ser entero"
 
-#: cp/semantics.c:6516
+#: cp/semantics.c:6519
 #, fuzzy, gcc-internal-format
 #| msgid "schedule chunk size expression must be integral"
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr "la expresión schedule chunk size debe ser integral"
 
-#: cp/semantics.c:6543
+#: cp/semantics.c:6546
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qD no es una variable en la cláusula %qs"
 
-#: cp/semantics.c:6557
+#: cp/semantics.c:6560
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:6563
+#: cp/semantics.c:6566
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr "%qD aparece más de una vez en las cláusulas de datos"
 
-#: cp/semantics.c:6576
+#: cp/semantics.c:6579
 #, fuzzy, gcc-internal-format
 #| msgid "schedule chunk size expression must be integral"
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr "la expresión schedule chunk size debe ser integral"
 
-#: cp/semantics.c:6625
+#: cp/semantics.c:6628
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr "%qD no es una variable en la cláusula %qs"
 
-#: cp/semantics.c:6910
+#: cp/semantics.c:6913
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "template %qE in clause %qs"
 msgstr "demasiadas cláusulas %qs"
 
-#: cp/semantics.c:6914
+#: cp/semantics.c:6917
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6979
+#: cp/semantics.c:6982
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<grainsize%> expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.c:7008
+#: cp/semantics.c:7011
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<priority%> expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.c:7037
+#: cp/semantics.c:7040
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<num_tasks%> expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.c:7066
+#: cp/semantics.c:7069
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr "el tipo de vector delete no es del tipo puntero ni matriz"
 
-#: cp/semantics.c:7105
+#: cp/semantics.c:7108
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<tile%> argument needs integral type"
 msgstr "el valor de %<num_threads%> debe ser positivo"
 
-#: cp/semantics.c:7524
+#: cp/semantics.c:7527
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr "%<threadprivate%> %qD no es un fichero, espacio de nombres o variable de ámbito de bloque"
 
-#: cp/semantics.c:7538
+#: cp/semantics.c:7541
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "la directiva %<threadprivate%> %qE no está en la definición %qT"
 
-#: cp/semantics.c:7743
+#: cp/semantics.c:7746
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr "la diferencia entre %qE y %qD no tiene tipo entero"
 
-#: cp/semantics.c:8171
+#: cp/semantics.c:8174
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp atomic update%> uses two different variables for memory"
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr "%<#pragma omp atomic update%> usa dos variables diferentes para la memoria"
 
-#: cp/semantics.c:8398 cp/semantics.c:8408
+#: cp/semantics.c:8401 cp/semantics.c:8411
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp atomic update%> uses two different variables for memory"
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr "%<#pragma omp atomic update%> usa dos variables diferentes para la memoria"
 
-#: cp/semantics.c:8702
+#: cp/semantics.c:8705
 #, fuzzy, gcc-internal-format
 #| msgid "static assertion failed: %E"
 msgid "static assertion failed"
 msgstr "falló la aserción estática: %E"
 
-#: cp/semantics.c:8704
+#: cp/semantics.c:8707
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr "falló la aserción estática: %s"
 
-#: cp/semantics.c:8709
+#: cp/semantics.c:8712
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "condición que no es constante para una aserción estática"
 
-#: cp/semantics.c:8739
+#: cp/semantics.c:8742
 #, gcc-internal-format
 msgid "argument to decltype must be an expression"
 msgstr "el argumento para decltype debe ser una expresión"
 
-#: cp/semantics.c:8767
+#: cp/semantics.c:8770
 #, gcc-internal-format
 msgid "decltype cannot resolve address of overloaded function"
 msgstr "el tipo de declaración no puede resolver la dirección de la función sobrecargada"
 
-#: cp/semantics.c:9308
+#: cp/semantics.c:9311
 #, fuzzy, gcc-internal-format
 #| msgid "third operand of conditional expression has no effect"
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "el tercer operando de la expresión condicional no tiene efecto"
 
-#: cp/semantics.c:9361
+#: cp/semantics.c:9364
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %qE involves template parameter(s)"
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "el argumento de plantilla %qE involucra a el(los) parámetro(s) de plantilla"
 
-#: cp/semantics.c:9363
+#: cp/semantics.c:9366
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:9381
+#: cp/semantics.c:9384
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %<__builtin_return_address%>"
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "argumento no admitido para %<__builtin_return_address%>"
 
-#: cp/tree.c:1276
+#: cp/tree.c:1295
 #, gcc-internal-format
 msgid "%qV qualifiers cannot be applied to %qT"
 msgstr "los calificadores %qV no se pueden aplicar a %qT"
 
-#: cp/tree.c:1788
+#: cp/tree.c:1807
 #, fuzzy, gcc-internal-format
 #| msgid "expression %qE is not a constant-expression"
 msgid "lambda-expression in a constant expression"
 msgstr "la expresión %qE no es una expresión constante"
 
-#: cp/tree.c:1792
+#: cp/tree.c:1811
 #, fuzzy, gcc-internal-format
 #| msgid "expression %qE is not a constant-expression"
 msgid "statement-expression in a constant expression"
 msgstr "la expresión %qE no es una expresión constante"
 
-#: cp/tree.c:4050
+#: cp/tree.c:4083
+#, gcc-internal-format
+msgid "-fabi-version=13 (GCC 8.2) fixes the calling convention for %qT, which was accidentally changed in 8.1"
+msgstr ""
+
+#: cp/tree.c:4087
+#, gcc-internal-format
+msgid "-fabi-version=12 (GCC 8.1) accidentally changes the calling convention for %qT"
+msgstr ""
+
+#: cp/tree.c:4090
 #, fuzzy, gcc-internal-format
+#| msgid "declared here"
+msgid " declared here"
+msgstr "se declara aquí"
+
+#: cp/tree.c:4094
+#, fuzzy, gcc-internal-format
 #| msgid "alignment of %qD is bigger than original declaration"
-msgid "the calling convention for %qT changes in -fabi-version=12 (GCC 8)"
+msgid "the calling convention for %qT changes in -fabi-version=13 (GCC 8.2)"
 msgstr "la alineación de %qD es más grande que la declaración original"
 
-#: cp/tree.c:4055
+#: cp/tree.c:4096
 #, gcc-internal-format
 msgid " because all of its copy and move constructors are deleted"
 msgstr ""
 
-#: cp/tree.c:4416
+#: cp/tree.c:4464
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on types"
 msgid "%qE attribute applied to %qD with void return type"
 msgstr "se descarta el atributo %qE en tipos"
 
-#: cp/tree.c:4423
+#: cp/tree.c:4471
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr "el atributo %qE sólo se puede aplicar a definiciones de clase"
 
-#: cp/tree.c:4475
+#: cp/tree.c:4523
 #, gcc-internal-format
 msgid "requested init_priority is not an integer constant"
 msgstr "la init_priority solicitada no es una constante entera"
 
-#: cp/tree.c:4497
+#: cp/tree.c:4545
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr "solo se puede usar el atributo %qE en definiciones de rango de fichero de objetos de tipo class"
 
-#: cp/tree.c:4505
+#: cp/tree.c:4553
 #, gcc-internal-format
 msgid "requested init_priority is out of range"
 msgstr "la init_priority solicitada está fuera de rango"
 
-#: cp/tree.c:4515
+#: cp/tree.c:4563
 #, gcc-internal-format
 msgid "requested init_priority is reserved for internal use"
 msgstr "la init_priority solicitada está reservada para uso interno"
 
-#: cp/tree.c:4526
+#: cp/tree.c:4574
 #, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr "el atributo %qE no se admite en esta plataforma"
 
-#: cp/tree.c:4553
+#: cp/tree.c:4601
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as member of %qT"
 msgid "redeclaration of %qD adds abi tag %qE"
 msgstr "declaración de %qD como miembro de %qT"
 
-#: cp/tree.c:4573
+#: cp/tree.c:4621
 #, fuzzy, gcc-internal-format
 #| msgid "%qD attribute requires a single NTBS argument"
 msgid "the %qE attribute requires arguments"
 msgstr "el atributo %qD requiere un solo argumento NTBS"
 
-#: cp/tree.c:4584
+#: cp/tree.c:4632
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qE attribute is not a string constant"
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "el argumento del atributo %qE no es una cadena constante"
 
-#: cp/tree.c:4597 cp/tree.c:4610
+#: cp/tree.c:4645 cp/tree.c:4658
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qE attribute is not a string constant"
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "el argumento del atributo %qE no es una cadena constante"
 
-#: cp/tree.c:4599
+#: cp/tree.c:4647
 #, fuzzy, gcc-internal-format
 #| msgid "%.*s is not a valid universal character"
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "%.*s no es un carácter universal válido"
 
-#: cp/tree.c:4612
+#: cp/tree.c:4660
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a valid declarator"
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "%<%T::%D%> no es un declarador válido"
 
-#: cp/tree.c:4636
+#: cp/tree.c:4684
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "se descarta el atributo %qE en tipos que no son clases"
 
-#: cp/tree.c:4642
+#: cp/tree.c:4690
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes applied to %qT after definition"
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "se descartan los atributos aplicados al %qT después de la definición"
 
-#: cp/tree.c:4649
+#: cp/tree.c:4697
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes applied to %qT after definition"
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "se descartan los atributos aplicados al %qT después de la definición"
 
-#: cp/tree.c:4656
+#: cp/tree.c:4704
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes applied to %qT after definition"
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "se descartan los atributos aplicados al %qT después de la definición"
 
-#: cp/tree.c:4678
+#: cp/tree.c:4726
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to functions, not %s"
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "el atributo %qE se aplica solamente a funciones, no a %s"
 
-#: cp/tree.c:4684
+#: cp/tree.c:4732
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute applied to %s %s at %L"
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "El atributo %s se aplica a %s %s en %L"
 
-#: cp/tree.c:5440
+#: cp/tree.c:5488
 #, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "cero como constante de puntero nulo"
 
-#: cp/tree.c:5453
+#: cp/tree.c:5501
 #, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr "revisión lang_*: falló en %s, en %s:%d"
@@ -50339,113 +50404,113 @@
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "no se puede inicializar el agregado del tipo %qT con una literal compuesta"
 
-#: cp/typeck2.c:1496 cp/typeck2.c:1523
+#: cp/typeck2.c:1499 cp/typeck2.c:1526
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "falta el inicializador para el miembro %qD"
 
-#: cp/typeck2.c:1504
+#: cp/typeck2.c:1507
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "el miembro %qD es una referencia sin inicializar"
 
-#: cp/typeck2.c:1511
+#: cp/typeck2.c:1514
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD is uninitialized reference"
 msgid "member %qD with uninitialized reference fields"
 msgstr "el miembro %qD es una referencia sin inicializar"
 
-#: cp/typeck2.c:1587
+#: cp/typeck2.c:1590
 #, fuzzy, gcc-internal-format
 #| msgid "type of %qD does not match original declaration"
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "el tipo de %qD no coincide con la declaración original"
 
-#: cp/typeck2.c:1660
+#: cp/typeck2.c:1663
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "no existe el campo %qD en la union que se está inicializando"
 
-#: cp/typeck2.c:1671
+#: cp/typeck2.c:1674
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "valor de índice en lugar del nombre del campo en el inicializador de union"
 
-#: cp/typeck2.c:1858
+#: cp/typeck2.c:1861
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "se detectó una delegación de puntero circular"
 
-#: cp/typeck2.c:1872
+#: cp/typeck2.c:1875
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "el operando base de %<->%> tiene el tipo %qT que no es puntero"
 
-#: cp/typeck2.c:1898
+#: cp/typeck2.c:1901
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "el resultado de %<operator->()%> produce un resultado que no es puntero"
 
-#: cp/typeck2.c:1900
+#: cp/typeck2.c:1903
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "el operando base de %<->%> no es un puntero"
 
-#: cp/typeck2.c:1927
+#: cp/typeck2.c:1930
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "no se puede usar %qE como un puntero miembro, porque es de tipo %qT"
 
-#: cp/typeck2.c:1936
+#: cp/typeck2.c:1939
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "no se puede aplicar el puntero a miembro %qE a %qE, el cual es del tipo %qT que no es clase"
 
-#: cp/typeck2.c:1958
+#: cp/typeck2.c:1961
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "el tipo de puntero a miembro %qT es incompatible con el tipo objeto %qT"
 
-#: cp/typeck2.c:2018
+#: cp/typeck2.c:2021
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "se usó un puntero a una función miembro en la aritmética"
 
-#: cp/typeck2.c:2029
+#: cp/typeck2.c:2032
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "se usó un puntero a una función miembro en la aritmética"
 
-#: cp/typeck2.c:2037
+#: cp/typeck2.c:2040
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue before C++2a"
 msgstr "se usó un puntero a una función miembro en la aritmética"
 
-#: cp/typeck2.c:2080
+#: cp/typeck2.c:2083
 #, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "conversión funcional al tipo de matriz %qT"
 
-#: cp/typeck2.c:2096
+#: cp/typeck2.c:2099
 #, fuzzy, gcc-internal-format
 #| msgid "in template argument for type %qT "
 msgid "cannot deduce template arguments for %qT from ()"
 msgstr "en el argumento de plantilla para el tipo %qT "
 
-#: cp/typeck2.c:2114
+#: cp/typeck2.c:2117
 #, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "inicialización por valor no válida del tipo de referencia"
 
-#: cp/typeck2.c:2341
+#: cp/typeck2.c:2344
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "llamada a la función %qD la cual arroja el tipo incompleto %q#T"
 
-#: cp/typeck2.c:2344
+#: cp/typeck2.c:2347
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "llamada a una función la cual arroja el tipo incompleto %q#T"
@@ -50675,11 +50740,11 @@
 msgstr "La referencia a matriz en %C no puede tener más de %d dimensiones"
 
 #: fortran/array.c:221 fortran/array.c:661 fortran/check.c:2849
-#: fortran/check.c:5222 fortran/check.c:5260 fortran/check.c:5302
-#: fortran/check.c:5329 fortran/check.c:5529 fortran/match.c:1821
+#: fortran/check.c:5225 fortran/check.c:5263 fortran/check.c:5305
+#: fortran/check.c:5332 fortran/check.c:5532 fortran/match.c:1821
 #: fortran/match.c:3174 fortran/match.c:3516 fortran/match.c:3712
-#: fortran/simplify.c:2909 fortran/simplify.c:2939 fortran/simplify.c:5764
-#: fortran/simplify.c:7658
+#: fortran/simplify.c:2909 fortran/simplify.c:2939 fortran/simplify.c:5769
+#: fortran/simplify.c:7663
 #, fuzzy, gcc-internal-format
 #| msgid "Coarrays disabled at %C, use -fcoarray= to enable"
 msgid "Coarrays disabled at %C, use %<-fcoarray=%> to enable"
@@ -50825,129 +50890,135 @@
 msgid "DO-iterator %qs at %L is inside iterator of the same name"
 msgstr "El iterador-DO '%s' en %L está dentro de un iterador del mismo nombre"
 
-#: fortran/array.c:1073 fortran/array.c:1255
+#: fortran/array.c:1073 fortran/array.c:1264
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in array constructor at %C"
 msgstr "Error sintáctico en el constructor de matriz en %C"
 
-#: fortran/array.c:1129
+#: fortran/array.c:1105
 #, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "ENTRY statement at %C cannot appear in a contained procedure"
+msgid "NULL() at %C cannot appear in an array constructor"
+msgstr "La declaración ENTRY en %C no puede aparecer dentro de un procedimiento contenido"
+
+#: fortran/array.c:1138
+#, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: [...] style array constructors at %C"
 msgid "[...] style array constructors at %C"
 msgstr "Fortran 2003: Constructores de matriz de estilo [...] en %C"
 
-#: fortran/array.c:1149
+#: fortran/array.c:1158
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: Array constructor including type specification at %C"
 msgid "Array constructor including type specification at %C"
 msgstr "Fortran 2003: Los constructores de matriz incluyen especificación de tipo en %C"
 
-#: fortran/array.c:1155 fortran/match.c:4148
+#: fortran/array.c:1164 fortran/match.c:4148
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-spec at %L cannot contain a deferred type parameter"
 msgstr "La especificación de tipo en %L no puede tener un parámetro de tipo diferido"
 
-#: fortran/array.c:1163
+#: fortran/array.c:1172
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Type-spec at %L cannot contain a deferred type parameter"
 msgid "Type-spec at %L cannot contain an asterisk for a type parameter"
 msgstr "La especificación de tipo en %L no puede tener un parámetro de tipo diferido"
 
-#: fortran/array.c:1181
+#: fortran/array.c:1190
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty array constructor at %C is not allowed"
 msgstr "No se permite un constructor de matriz vacío en %C"
 
-#: fortran/array.c:1218 fortran/array.c:1228
+#: fortran/array.c:1227 fortran/array.c:1237
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Incompatible type for array. %s convert %qs to %qs"
 msgid "Incompatible typespec for array element at %L"
 msgstr "Tipo incompatible para matriz. %s convierte %qs a %qs"
 
-#: fortran/array.c:1302
+#: fortran/array.c:1311
 #, gcc-internal-format, gfc-internal-format
 msgid "Element in %s array constructor at %L is %s"
 msgstr "El elemento en el constructor de matriz %s en %L es %s"
 
-#: fortran/array.c:1633
+#: fortran/array.c:1642
 #, gcc-internal-format, gfc-internal-format
 msgid "Iterator step at %L cannot be zero"
 msgstr "El paso de iterador en %L no puede ser cero"
 
-#: fortran/array.c:1770
+#: fortran/array.c:1779
 #, fuzzy, gcc-internal-format
 #| msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit.   See -fmax-array-constructor option"
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit.   See %<-fmax-array-constructor%> option"
 msgstr "El número de elementos en el constructor de matriz en %L requiere un incremento del límite superior %d permitido.  Vea la opción -fmax-array-constructor"
 
-#: fortran/array.c:1940
+#: fortran/array.c:1949
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "expression reference type error at %L"
 msgid "AC-IMPLIED-DO initial expression references control variable at %L"
 msgstr "error de expresión de tipo de referencia en %L"
 
-#: fortran/array.c:1947
+#: fortran/array.c:1956
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "expression reference type error at %L"
 msgid "AC-IMPLIED-DO final expression references control variable at %L"
 msgstr "error de expresión de tipo de referencia en %L"
 
-#: fortran/array.c:1954
+#: fortran/array.c:1963
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "expression reference type error at %L"
 msgid "AC-IMPLIED-DO step expression references control variable at %L"
 msgstr "error de expresión de tipo de referencia en %L"
 
-#: fortran/array.c:1966
+#: fortran/array.c:1975
 #, gcc-internal-format, gfc-internal-format
 msgid "Array constructor value at %L shall not be unlimited polymorphic [F2008: C4106]"
 msgstr ""
 
-#: fortran/array.c:2055
+#: fortran/array.c:2067
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Different CHARACTER lengths (%d/%d) in array constructor at %L"
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor at %L"
 msgstr "Longitudes de CHARACTER diferentes (%d/%d) en el constructor de matriz en %L"
 
-#: fortran/array.c:2174
+#: fortran/array.c:2186
 #, gcc-internal-format
 msgid "spec_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2233
+#: fortran/array.c:2245
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2237
+#: fortran/array.c:2249
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad array reference at %L"
 msgid "Bad array dimension at %L"
 msgstr "Referencia de matriz errónea en %L"
 
-#: fortran/array.c:2264 fortran/data.c:552 fortran/data.c:571
-#: fortran/data.c:585 fortran/data.c:714
+#: fortran/array.c:2276 fortran/data.c:563 fortran/data.c:582
+#: fortran/data.c:596 fortran/data.c:725
 #, fuzzy, gcc-internal-format
 #| msgid "gimplification failed"
 msgid "Simplification error"
 msgstr "falló la gimplificación"
 
-#: fortran/array.c:2376
+#: fortran/array.c:2388
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimen_type"
 msgstr ""
 
-#: fortran/array.c:2427
+#: fortran/array.c:2439
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2472
+#: fortran/array.c:2484
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad EXPR_ARRAY expr"
 msgstr ""
 
-#: fortran/array.c:2620
+#: fortran/array.c:2632
 #, gcc-internal-format
 msgid "gfc_find_array_ref(): No ref found"
 msgstr ""
@@ -51006,7 +51077,7 @@
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or PROCEDURE"
 msgstr "El argumento '%s' del intrínseco '%s' en %L debe ser INTEGER o PROCEDURE"
 
-#: fortran/check.c:205 fortran/check.c:6658
+#: fortran/check.c:205 fortran/check.c:6661
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a constant"
 msgid "%qs argument of %qs intrinsic at %L must be a constant"
@@ -51144,7 +51215,7 @@
 msgid "Unequal character lengths (%ld/%ld) in %s at %L"
 msgstr "Longitudes de caracteres desiguales (%ld/%ld) en %s en %L"
 
-#: fortran/check.c:946 fortran/check.c:6602
+#: fortran/check.c:946 fortran/check.c:6605
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' and '%s' arguments of '%s' intrinsic at %L must have the same type"
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have the same type"
@@ -51406,9 +51477,9 @@
 msgstr "El argumento '%s' del intrínseco '%s' en %L no debe ser coindizado"
 
 #: fortran/check.c:1939 fortran/check.c:2525 fortran/check.c:2628
-#: fortran/check.c:2835 fortran/check.c:2880 fortran/check.c:4256
-#: fortran/check.c:4390 fortran/check.c:4445 fortran/check.c:5515
-#: fortran/check.c:5644
+#: fortran/check.c:2835 fortran/check.c:2880 fortran/check.c:4259
+#: fortran/check.c:4393 fortran/check.c:4448 fortran/check.c:5518
+#: fortran/check.c:5647
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: '%s' intrinsic with KIND argument at %L"
 msgid "%qs intrinsic with KIND argument at %L"
@@ -51637,7 +51708,7 @@
 msgid "NULL intrinsic with allocatable MOLD at %L"
 msgstr "Fortran 2003: Intrínseco NULL con MOLD alojable en %L"
 
-#: fortran/check.c:3768 fortran/check.c:5591
+#: fortran/check.c:3768 fortran/check.c:5594
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must provide at least as many elements as there are .TRUE. values in '%s' (%ld/%d)"
 msgid "%qs argument of %qs intrinsic at %L must provide at least as many elements as there are .TRUE. values in %qs (%ld/%d)"
@@ -51661,417 +51732,417 @@
 msgid "%qs argument of %qs intrinsic at %L must not be a subobject of %qs"
 msgstr "El argumento '%s' del intrínseco '%s' en %L no debe ser un subobjeto de '%s'"
 
-#: fortran/check.c:3901
+#: fortran/check.c:3904
 #, gcc-internal-format, gfc-internal-format
 msgid "The argument of the RANK intrinsic at %L must be a data object"
 msgstr "El argumento del intrínseco RANK en %L debe ser objeto de datos"
 
-#: fortran/check.c:4005
+#: fortran/check.c:4008
 #, fuzzy, gcc-internal-format
 #| msgid "'shape' argument of 'reshape' intrinsic at %L must be an array of constant size"
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L must be an array of constant size"
 msgstr "El argumento 'shape' del intrínseco 'reshape' en %L debe ser una matriz de tamaño constante"
 
-#: fortran/check.c:4015
+#: fortran/check.c:4018
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L is empty"
 msgid "%qs argument of %qs intrinsic at %L is empty"
 msgstr "El argumento '%s' del intrínseco '%s' en %L debe estar vacío"
 
-#: fortran/check.c:4022
+#: fortran/check.c:4025
 #, fuzzy, gcc-internal-format
 #| msgid "'shape' argument of 'reshape' intrinsic at %L has more than %d elements"
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L has more than %d elements"
 msgstr "El argumento 'shape' del intrínseco 'reshape' en %L tiene más de %d elementos"
 
-#: fortran/check.c:4039
+#: fortran/check.c:4042
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L has negative element (%d)"
 msgid "%qs argument of %qs intrinsic at %L has negative element (%d)"
 msgstr "El argumento '%s' del intrínseco '%s' en %L tiene un elemento negativo (%d)"
 
-#: fortran/check.c:4071
+#: fortran/check.c:4074
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Complex argument of LOG at %L cannot be zero"
 msgid "Element %d of actual argument of RESHAPE at %L cannot be negative"
 msgstr "El argumento complejo de LOG en %L no puede ser cero"
 
-#: fortran/check.c:4109
+#: fortran/check.c:4112
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L has wrong number of elements (%d/%d)"
 msgid "%qs argument of %qs intrinsic at %L has wrong number of elements (%d/%d)"
 msgstr "El argumento '%s' del intrínseco '%s' en %L tiene el número erróneo de elementos (%d/%d)"
 
-#: fortran/check.c:4127
+#: fortran/check.c:4130
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L has out-of-range dimension (%d)"
 msgid "%qs argument of %qs intrinsic at %L has out-of-range dimension (%d)"
 msgstr "el argumento '%s' del intrínseco '%s' en %L tiene una dimensión fuera de rango (%d)"
 
-#: fortran/check.c:4136
+#: fortran/check.c:4139
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L has invalid permutation of dimensions (dimension '%d' duplicated)"
 msgid "%qs argument of %qs intrinsic at %L has invalid permutation of dimensions (dimension %qd duplicated)"
 msgstr "el argumento '%s' del intrínseco '%s' en %L tiene una permutación no válida de dimensiones (dimensión '%d' duplicada)"
 
-#: fortran/check.c:4172
+#: fortran/check.c:4175
 #, gcc-internal-format, gfc-internal-format
 msgid "Without padding, there are not enough elements in the intrinsic RESHAPE source at %L to match the shape"
 msgstr "Sin relleno, no hay suficientes elementos en el intrínseco RESHAPE fuente en %L para coincidir con la forma"
 
-#: fortran/check.c:4189 fortran/check.c:4208
+#: fortran/check.c:4192 fortran/check.c:4211
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be %s"
 msgid "%qs argument of %qs intrinsic at %L cannot be of type %s"
 msgstr "El argumento '%s' del intrínseco '%s' en %L debe ser %s"
 
-#: fortran/check.c:4199 fortran/check.c:4218
+#: fortran/check.c:4202 fortran/check.c:4221
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be of an extensible type"
 msgid "%qs argument of %qs intrinsic at %L must be of an extensible type"
 msgstr "El argumento '%s' del intrínseco '%s' en %L debe ser un tipo extensible"
 
-#: fortran/check.c:4317
+#: fortran/check.c:4320
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2008: SELECTED_REAL_KIND with neither 'P' nor 'R' argument at %L"
 msgid "SELECTED_REAL_KIND with neither %<P%> nor %<R%> argument at %L"
 msgstr "Fortran 2008: SELECTED_REAL_KIND sin un argumento 'P' ni 'R' en %L"
 
-#: fortran/check.c:4348
+#: fortran/check.c:4351
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2008: '%s' intrinsic with RADIX argument at %L"
 msgid "%qs intrinsic with RADIX argument at %L"
 msgstr "Fortran 2008: Intrínseco '%s' con argumento RADIX en %L"
 
-#: fortran/check.c:4383
+#: fortran/check.c:4386
 #, fuzzy, gcc-internal-format
 #| msgid "'source' argument of 'shape' intrinsic at %L must not be an assumed size array"
 msgid "%<source%> argument of %<shape%> intrinsic at %L must not be an assumed size array"
 msgstr "El argumento 'source' del intrínseco 'shape' en %L no debe ser una matriz de tamaño asumido"
 
-#: fortran/check.c:4460 fortran/check.c:6641
+#: fortran/check.c:4463 fortran/check.c:6644
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L may not be a procedure"
 msgid "%qs argument of %qs intrinsic at %L shall not be a procedure"
 msgstr "El argumento '%s' del intrínseco '%s' en %L no puede ser un procedimiento"
 
-#: fortran/check.c:4473 fortran/check.c:4612 fortran/check.c:6633
+#: fortran/check.c:4476 fortran/check.c:4615 fortran/check.c:6636
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L shall not be coindexed"
 msgid "%qs argument of %qs intrinsic at %L shall not be TYPE(*)"
 msgstr "El argumento '%s' del intrínseco '%s' en %L no debe ser coindizado"
 
-#: fortran/check.c:4484 fortran/check.c:4624
+#: fortran/check.c:4487 fortran/check.c:4627
 #, fuzzy, gcc-internal-format
 #| msgid "'source' argument of 'shape' intrinsic at %L must not be an assumed size array"
 msgid "%qs argument of %qs intrinsic at %L shall not be an assumed-size array"
 msgstr "El argumento 'source' del intrínseco 'shape' en %L no debe ser una matriz de tamaño asumido"
 
-#: fortran/check.c:4554
+#: fortran/check.c:4557
 #, gcc-internal-format
 msgid "is_c_interoperable(): gfc_simplify_expr failed"
 msgstr ""
 
-#: fortran/check.c:4603
+#: fortran/check.c:4606
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be an interoperable data entity"
 msgid "%qs argument of %qs intrinsic at %L must be an interoperable data entity: %s"
 msgstr "El argumento '%s' del intrínseco '%s' en %L debe ser una entidad de datos interoperables"
 
-#: fortran/check.c:4642
+#: fortran/check.c:4645
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_1 at %L to C_ASSOCIATED shall have the type TYPE(C_PTR) or TYPE(C_FUNPTR)"
 msgstr ""
 
-#: fortran/check.c:4656
+#: fortran/check.c:4659
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_2 at %L to C_ASSOCIATED shall have the same type as C_PTR_1: %s instead of %s"
 msgstr ""
 
-#: fortran/check.c:4680
+#: fortran/check.c:4683
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_POINTER shall have the type TYPE(C_PTR)"
 msgstr ""
 
-#: fortran/check.c:4692
+#: fortran/check.c:4695
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument %d of %qE must be a pointer type"
 msgid "Argument FPTR at %L to C_F_POINTER must be a pointer"
 msgstr "el argumento %d de %qE debe ser un tipo puntero"
 
-#: fortran/check.c:4699
+#: fortran/check.c:4702
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Actual argument to '%s' at %L must be polymorphic"
 msgid "FPTR argument at %L to C_F_POINTER shall not be polymorphic"
 msgstr "El argumento actual para '%s' en %L debe ser polimórfico"
 
-#: fortran/check.c:4706
+#: fortran/check.c:4709
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer object at %C shall not be coindexed"
 msgid "Argument FPTR at %L to C_F_POINTER shall not be coindexed"
 msgstr "El objeto puntero en %C no debe tener un coíndice"
 
-#: fortran/check.c:4713
+#: fortran/check.c:4716
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected SHAPE argument at %L to C_F_POINTER with scalar FPTR"
 msgstr ""
 
-#: fortran/check.c:4719
+#: fortran/check.c:4722
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected SHAPE argument to C_F_POINTER with array FPTR at %L"
 msgstr ""
 
-#: fortran/check.c:4738
+#: fortran/check.c:4741
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FIELD argument at %L of UNPACK must have the same rank as MASK or be a scalar"
 msgid "SHAPE argument at %L to C_F_POINTER must have the same size as the RANK of FPTR"
 msgstr "El argumento FIELD en %L de UNPACK debe tener el mismo rango que MASK o ser un escalar"
 
-#: fortran/check.c:4748
+#: fortran/check.c:4751
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic FPTR at %L to C_F_POINTER"
 msgstr ""
 
-#: fortran/check.c:4753
+#: fortran/check.c:4756
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array FPTR at %L to C_F_POINTER: %s"
 msgstr ""
 
-#: fortran/check.c:4769
+#: fortran/check.c:4772
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_PROCPOINTER shall have the type TYPE(C_FUNPTR)"
 msgstr ""
 
-#: fortran/check.c:4781
+#: fortran/check.c:4784
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall be a procedure pointer"
 msgstr ""
 
-#: fortran/check.c:4788
+#: fortran/check.c:4791
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer object at %C shall not be coindexed"
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall not be coindexed"
 msgstr "El objeto puntero en %C no debe tener un coíndice"
 
-#: fortran/check.c:4794
+#: fortran/check.c:4797
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure pointer at %L to C_F_PROCPOINTER"
 msgstr ""
 
-#: fortran/check.c:4808
+#: fortran/check.c:4811
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer object at %C shall not be coindexed"
 msgid "Argument X at %L to C_FUNLOC shall not be coindexed"
 msgstr "El objeto puntero en %C no debe tener un coíndice"
 
-#: fortran/check.c:4823
+#: fortran/check.c:4826
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L has no IMPLICIT type"
 msgid "Function result %qs at %L is invalid as X argument to C_FUNLOC"
 msgstr "El resultado de la función '%s' en %L no es de tipo IMPLICIT"
 
-#: fortran/check.c:4831
+#: fortran/check.c:4834
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall be a procedure or a procedure pointer"
 msgstr ""
 
-#: fortran/check.c:4837
+#: fortran/check.c:4840
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "User operator procedure '%s' at %L must be a FUNCTION"
 msgid "Noninteroperable procedure at %L to C_FUNLOC"
 msgstr "El procedimiento de operador de usuario '%s' en %L debe ser FUNCTION"
 
-#: fortran/check.c:4851
+#: fortran/check.c:4854
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer object at %C shall not be coindexed"
 msgid "Argument X at %L to C_LOC shall not be coindexed"
 msgstr "El objeto puntero en %C no debe tener un coíndice"
 
-#: fortran/check.c:4857
+#: fortran/check.c:4860
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Actual argument to '%s' at %L must be polymorphic"
 msgid "X argument at %L to C_LOC shall not be polymorphic"
 msgstr "El argumento actual para '%s' en %L debe ser polimórfico"
 
-#: fortran/check.c:4868
+#: fortran/check.c:4871
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Component at %C must have the POINTER attribute"
 msgid "Argument X at %L to C_LOC shall have either the POINTER or the TARGET attribute"
 msgstr "El componente en %C debe tener el atributo POINTER"
 
-#: fortran/check.c:4876
+#: fortran/check.c:4879
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument 'S' of NEAREST at %L shall not be zero"
 msgid "Argument X at %L to C_LOC shall be not be a zero-sized string"
 msgstr "El argumento 'S' de NEAREST en %L no puede ser cero"
 
-#: fortran/check.c:4885
+#: fortran/check.c:4888
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Actual argument to '%s' at %L must be polymorphic"
 msgid "Argument at %L to C_LOC shall not be polymorphic"
 msgstr "El argumento actual para '%s' en %L debe ser polimórfico"
 
-#: fortran/check.c:4892
+#: fortran/check.c:4895
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array at %L as argument to C_LOC: %s"
 msgstr ""
 
-#: fortran/check.c:4903
+#: fortran/check.c:4906
 #, gcc-internal-format, gfc-internal-format
 msgid "Array of interoperable type at %L to C_LOC which is nonallocatable and neither assumed size nor explicit size"
 msgstr ""
 
-#: fortran/check.c:4908
+#: fortran/check.c:4911
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array section in '%s' call at %L"
 msgid "Array section at %L to C_LOC"
 msgstr "Sección de matriz en la llamada '%s' en %L"
 
-#: fortran/check.c:4936
+#: fortran/check.c:4939
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "GNU extension: non double precision REAL argument to %s intrinsic at %L"
 msgid "non double precision REAL argument to %s intrinsic at %L"
 msgstr "Extensión de GNU: argumento de precisión REAL que no es doble para el intrínseco %s en %L"
 
-#: fortran/check.c:4949
+#: fortran/check.c:4952
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be less than rank %d"
 msgid "%qs argument of %qs intrinsic at %L must be less than rank %d"
 msgstr "El argumento '%s' del intrínseco '%s' en %L debe ser menor que el rango %d"
 
-#: fortran/check.c:4968
+#: fortran/check.c:4971
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L is not a valid dimension index"
 msgid "%qs argument of %qs intrinsic at %L is not a valid dimension index"
 msgstr "el argumento '%s' del intrínseco '%s' en %L no es un índice de dimensión válido"
 
-#: fortran/check.c:5231
+#: fortran/check.c:5234
 #, gcc-internal-format, gfc-internal-format
 msgid "%s argument to IMAGE_INDEX must be a rank one array at %L"
 msgstr "El argumento %s para IMAGE_INDEX debe ser una matriz de rango uno en %L"
 
-#: fortran/check.c:5242
+#: fortran/check.c:5245
 #, gcc-internal-format, gfc-internal-format
 msgid "The number of array elements of the SUB argument to IMAGE_INDEX at %L shall be %d (corank) not %d"
 msgstr "El número de elementos de matriz del argumento SUB para IMAGE_INDEX en %L debe ser %d (corango) y no %d"
 
-#: fortran/check.c:5275
+#: fortran/check.c:5278
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to NUM_IMAGES at %L"
 msgstr ""
 
-#: fortran/check.c:5288
+#: fortran/check.c:5291
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "MOLD argument to NULL required at %L"
 msgid "FAILED= argument to NUM_IMAGES at %L"
 msgstr "se requiere el argumento MOLD para NULL en %L"
 
-#: fortran/check.c:5312
+#: fortran/check.c:5315
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L shall not be coindexed"
 msgid "TEAM argument at %L to the intrinsic TEAM_NUMBER shall be of type TEAM_TYPE"
 msgstr "El argumento '%s' del intrínseco '%s' en %L no debe ser coindizado"
 
-#: fortran/check.c:5338
+#: fortran/check.c:5341
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "DIM argument without ARRAY argument not allowed for THIS_IMAGE intrinsic at %L"
 msgid "DIM argument without COARRAY argument not allowed for THIS_IMAGE intrinsic at %L"
 msgstr "No se permite el argumento DIM sin un argumento ARRAY para el intrínseco THIS_IMAGE en %L"
 
-#: fortran/check.c:5345
+#: fortran/check.c:5348
 #, gcc-internal-format, gfc-internal-format
 msgid "The DISTANCE argument may not be specified together with the COARRAY or DIM argument in intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:5356
+#: fortran/check.c:5359
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk in formal argument list at %C"
 msgid "Unexpected DIM argument with noncoarray argument at %L"
 msgstr "Basura inesperada en la lista de argumentos formales en %C"
 
-#: fortran/check.c:5374
+#: fortran/check.c:5377
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to THIS_IMAGE at %L"
 msgstr ""
 
-#: fortran/check.c:5454
+#: fortran/check.c:5457
 #, fuzzy, gcc-internal-format
 #| msgid "'MOLD' argument of 'TRANSFER' intrinsic at %L must not be %s"
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L must not be %s"
 msgstr "El argumento 'MOLD' del intrínseco 'TRANSFER' en %L no debe ser %s"
 
-#: fortran/check.c:5483
+#: fortran/check.c:5486
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic TRANSFER at %L has partly undefined result: source size %ld < result size %ld"
 msgstr "El TRANSFER intrínseco en %L tiene un resultado parcialmente indefinido: tamaño de la fuente %ld < tamaño del resultado %ld"
 
-#: fortran/check.c:5605
+#: fortran/check.c:5608
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must have the same rank as '%s' or be a scalar"
 msgid "%qs argument of %qs intrinsic at %L must have the same rank as %qs or be a scalar"
 msgstr "El argumento '%s' del intrínseco '%s' en %L debe ser del mismo rango que '%s' o ser un escalar"
 
-#: fortran/check.c:5618
+#: fortran/check.c:5621
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' and '%s' arguments of '%s' intrinsic at %L must have identical shape."
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have identical shape."
 msgstr "Los argumentos '%s' y '%s' del intrínseco '%s' en %L deben tener forma idéntica."
 
-#: fortran/check.c:5861 fortran/check.c:5893
+#: fortran/check.c:5864 fortran/check.c:5896
 #, fuzzy, gcc-internal-format
 #| msgid "Size of '%s' argument of '%s' intrinsic at %L too small (%i/%i)"
 msgid "Size of %qs argument of %qs intrinsic at %L too small (%i/%i)"
 msgstr "El tamaño del argumento '%s' del intrínseco '%s' en %L es demasiado pequeño (%i/%i)"
 
-#: fortran/check.c:5901
+#: fortran/check.c:5904
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many arguments to %s at %L"
 msgstr "Demasiados argumentos para %s en %L"
 
-#: fortran/check.c:5919
+#: fortran/check.c:5922
 #, gcc-internal-format
 msgid "fe_runtime_error string must be null terminated"
 msgstr ""
 
-#: fortran/check.c:5931
+#: fortran/check.c:5934
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "fe_runtime_error: Wrong number of arguments (%d instead of %d)"
 msgstr "número erróneo de argumentos de plantilla (%d, debe ser %d)"
 
-#: fortran/check.c:5971
+#: fortran/check.c:5974
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:5990
+#: fortran/check.c:5993
 #, gcc-internal-format, gfc-internal-format
 msgid "Real COUNT_RATE argument to SYSTEM_CLOCK at %L"
 msgstr ""
 
-#: fortran/check.c:6000
+#: fortran/check.c:6003
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT_RATE argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:6017
+#: fortran/check.c:6020
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT_MAX argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:6234
+#: fortran/check.c:6237
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be of a kind not wider than the default kind (%d)"
 msgid "%qs argument of %qs intrinsic at %L must be of a kind not wider than the default kind (%d)"
 msgstr "El argumento '%s' del intrínseco '%s' en %L debe ser de un género que no sea más ancho que el género por defecto (%d)"
 
-#: fortran/check.c:6586 fortran/check.c:6594
+#: fortran/check.c:6589 fortran/check.c:6597
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be INTEGER or LOGICAL"
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or LOGICAL"
 msgstr "El argumento '%s' del intrínseco '%s' en %L debe ser INTEGER o LOGICAL"
 
-#: fortran/check.c:6625
+#: fortran/check.c:6628
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic function NULL at %L cannot be an actual argument to STORAGE_SIZE, because it returns a disassociated pointer"
 msgstr ""
@@ -52083,7 +52154,7 @@
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:727 fortran/decl.c:3636 fortran/decl.c:10066
+#: fortran/class.c:727 fortran/decl.c:3655 fortran/decl.c:10091
 #, fuzzy, gcc-internal-format
 #| msgid "Maximum extension level reached with type '%s' at %L"
 msgid "Maximum extension level reached with type %qs at %L"
@@ -52112,45 +52183,51 @@
 msgid "non-constant array in DATA statement %L"
 msgstr "matriz no constante en la declaración DATA %L"
 
-#: fortran/data.c:137
+#: fortran/data.c:140
 #, gcc-internal-format, gfc-internal-format
 msgid "failure to simplify substring reference in DATA statement at %L"
 msgstr "falla al simplificar la referencia de subcadena en la declaración DATA en %L"
 
-#: fortran/data.c:170
+#: fortran/data.c:173
 #, gcc-internal-format, gfc-internal-format
 msgid "Unused initialization string at %L because variable has zero length"
 msgstr ""
 
-#: fortran/data.c:176
+#: fortran/data.c:179
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Initialization string starting at %L was truncated to fit the variable (%d/%d)"
 msgid "Initialization string at %L was truncated to fit the variable (%ld/%ld)"
 msgstr "Se truncó la cadena de inicialización que inicia en %L para coincidir con la variable (%d%d)"
 
-#: fortran/data.c:265
+#: fortran/data.c:268
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L already is initialized at %L"
 msgid "%qs at %L already is initialized at %L"
 msgstr "'%s' en %L ya se inicializó en %L"
 
-#: fortran/data.c:289
+#: fortran/data.c:292
 #, gcc-internal-format, gfc-internal-format
 msgid "Data element below array lower bound at %L"
 msgstr "Elemeto de datos debajo del límite inferior de la matriz en %L"
 
-#: fortran/data.c:306 fortran/data.c:395
+#: fortran/data.c:309 fortran/data.c:398
 #, gcc-internal-format, gfc-internal-format
 msgid "Data element above array upper bound at %L"
 msgstr "Elemento de datos arriba del límite superior en %L"
 
-#: fortran/data.c:336 fortran/data.c:505
+#: fortran/data.c:339 fortran/data.c:496
 #, fuzzy, gcc-internal-format
 #| msgid "Extension: re-initialization of '%s' at %L"
 msgid "re-initialization of %qs at %L"
 msgstr "Extensión: reinicialización de '%s' en %L"
 
-#: fortran/data.c:727
+#: fortran/data.c:515
+#, fuzzy, gcc-internal-format
+#| msgid "Variable '%s' at %C with an initializer already appears in a DATA statement"
+msgid "Nonpointer object %qs with default initialization shall not appear in a DATA statement at %L"
+msgstr "La variable '%s' en %C con un inicializador ya aparecía en una declaración DATA"
+
+#: fortran/data.c:738
 #, gcc-internal-format
 msgid "TODO: Vector sections in data statements"
 msgstr ""
@@ -52178,394 +52255,394 @@
 msgid "Invalid initializer %s in Data statement at %C"
 msgstr "Inicializador %s no válido en la declaración Data en %C"
 
-#: fortran/decl.c:536
+#: fortran/decl.c:537
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C is not allowed in a PURE procedure"
 msgstr "No se permite la inicialización de %C en un procedimiento PURE"
 
-#: fortran/decl.c:573
+#: fortran/decl.c:574
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgid "DATA statement at %C cannot appear within an INTERFACE"
 msgstr "La declaración ENTRY en %C no puede aparecer dentro de un INTERFACE"
 
-#: fortran/decl.c:597
+#: fortran/decl.c:598
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid initializer %s in Data statement at %C"
 msgid "Invalid substring in data-implied-do at %L in DATA statement"
 msgstr "Inicializador %s no válido en la declaración Data en %C"
 
-#: fortran/decl.c:619
+#: fortran/decl.c:620
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %C is not allowed in a PURE procedure"
 msgstr "No se permite la declaración DATA en %C en un procedimiento PURE"
 
-#: fortran/decl.c:664
+#: fortran/decl.c:662
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Old-style initialization at %C"
 msgid "Empty old style initializer list at %C"
 msgstr "Extensión: Inicialización de estilo antiguo en %C"
 
-#: fortran/decl.c:684
+#: fortran/decl.c:671
 #, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "Array component of structure at %C must have an explicit shape"
+msgid "Array in initializer list at %L must have an explicit shape"
+msgstr "El componente de matriz de la estructura en %C debe tener una forma explícita"
+
+#: fortran/decl.c:694
+#, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "extra elements in scalar initializer"
 msgid "Repeat spec invalid in scalar initializer at %C"
 msgstr "elementos extras en el inicializador escalar"
 
-#: fortran/decl.c:689
+#: fortran/decl.c:699
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Cray pointer at %C must be an integer"
 msgid "Repeat spec must be an integer at %C"
 msgstr "El puntero Cray en %C debe ser un entero"
 
-#: fortran/decl.c:698
+#: fortran/decl.c:710
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected alternate return label at %C"
 msgid "Expected data constant after repeat spec at %C"
 msgstr "Se esperaba la etiqueta de devolución alterna en %C"
 
-#: fortran/decl.c:729
+#: fortran/decl.c:742
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected scalar initialization expression at %C"
 msgid "End of scalar initializer expected at %C"
 msgstr "Se esperaba una expresión de inicialización escalar en %C"
 
-#: fortran/decl.c:758
+#: fortran/decl.c:773
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Extension: Old-style initialization at %C"
-msgid "Expected constant array-spec in initializer list at %L"
-msgstr "Extensión: Inicialización de estilo antiguo en %C"
-
-#: fortran/decl.c:767
-#, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "excess elements in array initializer"
 msgid "Not enough elements in array initializer at %C"
 msgstr "exceso de elementos en el inicializador de matriz"
 
-#: fortran/decl.c:769
+#: fortran/decl.c:775
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "excess elements in array initializer"
 msgid "Too many elements in array initializer at %C"
 msgstr "exceso de elementos en el inicializador de matriz"
 
-#: fortran/decl.c:790
+#: fortran/decl.c:795
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in OpenMP variable list at %C"
 msgid "Syntax error in old style initializer list at %C"
 msgstr "Error sintáctico en la lista de variables OpenMP en %C"
 
-#: fortran/decl.c:812
+#: fortran/decl.c:821
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data target at %L shall not have a coindex"
 msgid "The assumed-rank array at %C shall not have a codimension"
 msgstr "El objetivo de datos en %L no puede tener un coíndice"
 
-#: fortran/decl.c:876
+#: fortran/decl.c:885
 #, gcc-internal-format, gfc-internal-format
 msgid "Sum of array rank %d and corank %d at %C exceeds maximum allowed dimensions of %d"
 msgstr ""
 
-#: fortran/decl.c:900
+#: fortran/decl.c:909
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad INTENT specification at %C"
 msgstr "Especificación INTENT errónea en %C"
 
-#: fortran/decl.c:921
+#: fortran/decl.c:930
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: deferred type parameter at %C"
 msgid "deferred type parameter at %C"
 msgstr "Fortran 2003: parámetro de tipo diferido en %C"
 
-#: fortran/decl.c:1004 fortran/resolve.c:11705
+#: fortran/decl.c:1013 fortran/resolve.c:11725
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
 
-#: fortran/decl.c:1030
+#: fortran/decl.c:1039
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Obsolescent feature: Old-style character length at %C"
 msgid "Old-style character length at %C"
 msgstr "Característica obsoleta: Longitud de carácter de estilo antiguo en %C"
 
-#: fortran/decl.c:1061
+#: fortran/decl.c:1070
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in character length specification at %C"
 msgstr "Error sintáctico en la especificación de longitud de carácter en %C"
 
-#: fortran/decl.c:1212 fortran/decl.c:1217 fortran/decl.c:1266
+#: fortran/decl.c:1221 fortran/decl.c:1226 fortran/decl.c:1275
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %C is already defined at %L"
 msgid "Procedure %qs at %C is already defined at %L"
 msgstr "El procedimiento '%s' en %C ya se había definido en %L"
 
-#: fortran/decl.c:1222
+#: fortran/decl.c:1231
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %C is already defined at %L"
 msgid "Contained procedure %qs at %C clashes with procedure defined at %L"
 msgstr "El procedimiento '%s' en %C ya se había definido en %L"
 
-#: fortran/decl.c:1231
+#: fortran/decl.c:1240
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is already defined as a generic interface at %L"
 msgid "Name %qs at %C is already defined as a generic interface at %L"
 msgstr "El nombre '%s' en %C ya se definió como una interfaz genérica en %L"
 
-#: fortran/decl.c:1244
+#: fortran/decl.c:1253
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %C has an explicit interface and must not have attributes declared at %L"
 msgid "Procedure %qs at %C has an explicit interface from a previous declaration"
 msgstr "El procedimiento '%s' en %C tiene una interfaz explícita y no debe tener atributos declarados en %L"
 
-#: fortran/decl.c:1257
+#: fortran/decl.c:1266
 #, gcc-internal-format
 msgid "Procedure %qs defined in interface body at %L clashes with internal procedure defined at %C"
 msgstr ""
 
-#: fortran/decl.c:1335
+#: fortran/decl.c:1344
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L must have the BIND(C) attribute to be C interoperable"
 msgid "Procedure %qs at %L must have the BIND(C) attribute to be C interoperable"
 msgstr "El procedimiento '%s' en %L debe tener el atributo BIND(C) para que sea interoperable con C"
 
-#: fortran/decl.c:1362
+#: fortran/decl.c:1371
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L is a dummy argument to the BIND(C) procedure '%s' but is not C interoperable because derived type '%s' is not C interoperable"
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because derived type %qs is not C interoperable"
 msgstr "La variable '%s' en %L es un argumento dummy del procedimiento BIND(C) '%s' pero no es interoperable con C porque el tipo derivado '%s' no es interoperable con C"
 
-#: fortran/decl.c:1369
+#: fortran/decl.c:1378
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L is a dummy argument to the BIND(C) procedure '%s' but is not C interoperable because it is polymorphic"
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because it is polymorphic"
 msgstr "La variable '%s' en %L es un argumento dummy del procedimiento BIND(C) '%s' pero puede no ser interoperable con C porque es polimórfica"
 
-#: fortran/decl.c:1376
+#: fortran/decl.c:1385
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L is a parameter to the BIND(C) procedure '%s' but may not be C interoperable"
 msgid "Variable %qs at %L is a dummy argument of the BIND(C) procedure %qs but may not be C interoperable"
 msgstr "La variable '%s' en %L es un parámetro del procedimiento BIND(C) '%s' pero puede no ser interoperable con C"
 
-#: fortran/decl.c:1391
+#: fortran/decl.c:1400
 #, fuzzy, gcc-internal-format
 #| msgid "Character argument '%s' at %L must be length 1 because procedure '%s' is BIND(C)"
 msgid "Character argument %qs at %L must be length 1 because procedure %qs is BIND(C)"
 msgstr "El argumento de carácter '%s' en %L debe ser de longitud 1 porque el procedimiento '%s' es BIND(C)"
 
-#: fortran/decl.c:1404
+#: fortran/decl.c:1413
 #, fuzzy, gcc-internal-format
 #| msgid "TS29113: Variable '%s' at %L with OPTIONAL attribute in procedure '%s' which is BIND(C)"
 msgid "Variable %qs at %L with ALLOCATABLE attribute in procedure %qs with BIND(C)"
 msgstr "TS29113: La variable '%s' en %L con atributo OPTIONAL en el procedimiento '%s' que es BIND(C)"
 
-#: fortran/decl.c:1412
+#: fortran/decl.c:1421
 #, fuzzy, gcc-internal-format
 #| msgid "TS29113: Variable '%s' at %L with OPTIONAL attribute in procedure '%s' which is BIND(C)"
 msgid "Variable %qs at %L with POINTER attribute in procedure %qs with BIND(C)"
 msgstr "TS29113: La variable '%s' en %L con atributo OPTIONAL en el procedimiento '%s' que es BIND(C)"
 
-#: fortran/decl.c:1421
+#: fortran/decl.c:1430
 #, gcc-internal-format
 msgid "Scalar variable %qs at %L with POINTER or ALLOCATABLE in procedure %qs with BIND(C) is not yet supported"
 msgstr ""
 
-#: fortran/decl.c:1430
+#: fortran/decl.c:1439
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the OPTIONAL and the VALUE attribute because procedure '%s' is BIND(C)"
 msgid "Variable %qs at %L cannot have both the OPTIONAL and the VALUE attribute because procedure %qs is BIND(C)"
 msgstr "La variable '%s' en %L no puede tener los atributos OPTIONAL y VALUE al mismo tiempo porque el procedimiento '%s' es BIND(C)"
 
-#: fortran/decl.c:1437
+#: fortran/decl.c:1446
 #, fuzzy, gcc-internal-format
 #| msgid "TS29113: Variable '%s' at %L with OPTIONAL attribute in procedure '%s' which is BIND(C)"
 msgid "Variable %qs at %L with OPTIONAL attribute in procedure %qs which is BIND(C)"
 msgstr "TS29113: La variable '%s' en %L con atributo OPTIONAL en el procedimiento '%s' que es BIND(C)"
 
-#: fortran/decl.c:1448
+#: fortran/decl.c:1457
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed-shape array '%s' at %L cannot be an argument to the procedure '%s' at %L because the procedure is BIND(C)"
 msgid "Assumed-shape array %qs at %L as dummy argument to the BIND(C) procedure %qs at %L"
 msgstr "La matriz de forma asumida '%s' en %L no puede ser un argumento para el procedimiento '%s' en %L porque el procedimiento es BIND(C)"
 
-#: fortran/decl.c:1516
+#: fortran/decl.c:1525
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L already has basic type of %s"
 msgid "Symbol %qs at %C also declared as a type at %L"
 msgstr "El símbolo '%s' en %L ya tenía el tipo básico de %s"
 
-#: fortran/decl.c:1575
+#: fortran/decl.c:1584
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' in common block '%s' at %C must be declared with a C interoperable kind since common block '%s' is BIND(C)"
 msgid "Variable %qs in common block %qs at %C must be declared with a C interoperable kind since common block %qs is BIND(C)"
 msgstr "La variable '%s' en el bloque común '%s' en %C se debe declarar con un género interoperable con C porque el bloque común '%s' es BIND(C)"
 
-#: fortran/decl.c:1615
+#: fortran/decl.c:1624
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Different CHARACTER lengths (%d/%d) in array constructor at %L"
 msgid "CHARACTER length must be a constant at %L"
 msgstr "Longitudes de CHARACTER diferentes (%d/%d) en el constructor de matriz en %L"
 
-#: fortran/decl.c:1630
+#: fortran/decl.c:1639
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CHARACTER expression at %L is being truncated (%d/%d)"
 msgid "CHARACTER expression at %L is being truncated (%ld/%ld)"
 msgstr "Se trunca la expresión CHARACTER en %L (%d/%d)"
 
-#: fortran/decl.c:1638
+#: fortran/decl.c:1647
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The CHARACTER elements of the array constructor at %L must have the same length (%d/%d)"
 msgid "The CHARACTER elements of the array constructor at %L must have the same length (%ld/%ld)"
 msgstr "Los elementos CHARACTER del constructor de matriz en %L deben tener la misma longitud (%d/%d)"
 
-#: fortran/decl.c:1729
+#: fortran/decl.c:1738
 #, fuzzy, gcc-internal-format
 #| msgid "Initializer not allowed for PARAMETER '%s' at %C"
 msgid "Initializer not allowed for PARAMETER %qs at %C"
 msgstr "No se permite un inicializador para el PARAMETER '%s' en %C"
 
-#: fortran/decl.c:1739
+#: fortran/decl.c:1748
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER at %L is missing an initializer"
 msgstr "Falta un inicializador para el PARAMETER en %L"
 
-#: fortran/decl.c:1749
+#: fortran/decl.c:1758
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %C with an initializer already appears in a DATA statement"
 msgid "Variable %qs at %C with an initializer already appears in a DATA statement"
 msgstr "La variable '%s' en %C con un inicializador ya aparecía en una declaración DATA"
 
-#: fortran/decl.c:1792
+#: fortran/decl.c:1801
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Can't initialize implied-shape array at %L with scalar"
 msgid "Cannot initialize parameter array at %L with variable length elements"
 msgstr "No se puede inicializar la matriz de tamaño implícito en %L con un escalar"
 
-#: fortran/decl.c:1861
+#: fortran/decl.c:1870
 #, gcc-internal-format, gfc-internal-format
 msgid "Can't initialize implied-shape array at %L with scalar"
 msgstr "No se puede inicializar la matriz de tamaño implícito en %L con un escalar"
 
-#: fortran/decl.c:1896
+#: fortran/decl.c:1905
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-constant lower bound in implied-shape declaration at %L"
 msgstr "El límite inferior no es constante en la declaración de forma implícita en %L"
 
-#: fortran/decl.c:1982 fortran/decl.c:1989
+#: fortran/decl.c:1991 fortran/decl.c:1998
 #, gcc-internal-format, gfc-internal-format
 msgid "Component at %C must have the POINTER attribute"
 msgstr "El componente en %C debe tener el atributo POINTER"
 
-#: fortran/decl.c:1998
+#: fortran/decl.c:2007
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' with CLASS at %L must be allocatable or pointer"
 msgid "Component %qs with CLASS at %C must be allocatable or pointer"
 msgstr "El componente '%s' con CLASS en %L debe ser allocatable o pointer"
 
-#: fortran/decl.c:2007
+#: fortran/decl.c:2016
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr "El componente de matriz de la estructura en %C debe tener una forma explícita o diferida"
 
-#: fortran/decl.c:2031 fortran/symbol.c:2230
+#: fortran/decl.c:2040 fortran/symbol.c:2244
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C already declared at %L"
 msgid "Component %qs at %C already declared at %L"
 msgstr "El componente '%s' en %C ya se había declarado en %L"
 
-#: fortran/decl.c:2079
+#: fortran/decl.c:2088
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer array component of structure at %C must have a deferred shape"
 msgstr "El componente de matriz de puntero de la estructura en %C debe tener una forma diferida"
 
-#: fortran/decl.c:2088
+#: fortran/decl.c:2097
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component of structure at %C must have a deferred shape"
 msgstr "El componente allocatable de la estructura en %C debe tener una forma diferida"
 
-#: fortran/decl.c:2097
+#: fortran/decl.c:2106
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have an explicit shape"
 msgstr "El componente de matriz de la estructura en %C debe tener una forma explícita"
 
-#: fortran/decl.c:2114
+#: fortran/decl.c:2123
 #, fuzzy, gcc-internal-format
 #| msgid "a parameter list with an ellipsis can%'t match an empty parameter name list declaration"
 msgid "Type parameter %qs at %C has no corresponding entry in the type parameter name list at %L"
 msgstr "una lista de parámetros con una elipsis no puede coincidir con una declaración de nombre de lista de parámetros vacía."
 
-#: fortran/decl.c:2171
+#: fortran/decl.c:2180
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C is ambiguous"
 msgstr "La inicialización NULL() en %C es ambigua"
 
-#: fortran/decl.c:2188
+#: fortran/decl.c:2197
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "NULL() initialization at %C is ambiguous"
 msgid "NULL() initialization at %C may not have MOLD"
 msgstr "La inicialización NULL() en %C es ambigua"
 
-#: fortran/decl.c:2205
+#: fortran/decl.c:2214
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of pointer at %C is not allowed in a PURE procedure"
 msgstr "No se permite la inicialización de un puntero en %C en un procedimiento PURE"
 
-#: fortran/decl.c:2226
+#: fortran/decl.c:2235
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in pointer initialization at %C"
 msgstr "Error en la inicialización de puntero en %C"
 
-#: fortran/decl.c:2233
+#: fortran/decl.c:2242
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: non-NULL pointer initialization at %C"
 msgid "non-NULL pointer initialization at %C"
 msgstr "Fortran 2008: inicialización de puntero que no es NULL en %C"
 
-#: fortran/decl.c:2256
+#: fortran/decl.c:2265
 #, gcc-internal-format
 msgid "RESULT variable %qs at %L prohibits FUNCTION name %qs at %C from appearing in a specification statement"
 msgstr ""
 
-#: fortran/decl.c:2318
+#: fortran/decl.c:2327
 #, fuzzy, gcc-internal-format
 #| msgid "RETURN not allowed outside PROC"
 msgid "%qs not allowed outside STRUCTURE at %C"
 msgstr "no se permite RETURN fuera de PROC"
 
-#: fortran/decl.c:2320
+#: fortran/decl.c:2329
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is not a member of the '%s' structure"
 msgid "%qs at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr "'%s' en %C no es un miembro de la estructura '%s'"
 
-#: fortran/decl.c:2327
+#: fortran/decl.c:2336
 #, fuzzy, gcc-internal-format
 #| msgid "%qs function cannot have arguments"
 msgid "%qs entity cannot have attributes at %C"
 msgstr "la función %qs no puede tener argumentos"
 
-#: fortran/decl.c:2367
+#: fortran/decl.c:2376
 #, fuzzy, gcc-internal-format
 #| msgid "Non-PARAMETER symbol '%s' at %L can't be implied-shape"
 msgid "Non-PARAMETER symbol %qs at %L can't be implied-shape"
 msgstr "El símbolo '%s' que no es PARAMETER en %L no puede ser de forma implícita"
 
-#: fortran/decl.c:2377
+#: fortran/decl.c:2386
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: Implied-shape array at %L"
 msgid "Implied-shape array at %L"
 msgstr "Fortran 2008: Matriz de forma implícita en %L"
 
-#: fortran/decl.c:2422
+#: fortran/decl.c:2431
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Not yet implemented: LCOBOUND for coarray with non-constant cobounds at %L"
 msgid "Explicit shaped array with nonconstant bounds at %C"
 msgstr "Aún sin implementar: LCOBOUND para una comatriz con colímites que no son constantes en %L"
 
-#: fortran/decl.c:2501
+#: fortran/decl.c:2510
 #, gcc-internal-format
 msgid "%qs at %C is a redefinition of the declaration in the corresponding interface for MODULE PROCEDURE %qs"
 msgstr ""
 
-#: fortran/decl.c:2512
+#: fortran/decl.c:2521
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "%qs entity cannot have an initializer at %C"
@@ -52576,485 +52653,485 @@
 # como `apuntado'. cfuga
 # Referencia: http://gcc.gnu.org/onlinedocs/gfortran/Cray-pointers.html
 #
-#: fortran/decl.c:2538 fortran/decl.c:8369
+#: fortran/decl.c:2547 fortran/decl.c:8388
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr "Especificación de matriz duplicada para el apuntado Cray en %C"
 
-#: fortran/decl.c:2546
+#: fortran/decl.c:2555
 #, gcc-internal-format
 msgid "Couldn't set pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:2609
+#: fortran/decl.c:2618
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Old-style initialization at %C"
 msgid "Old-style initialization at %C"
 msgstr "Extensión: Inicialización de estilo antiguo en %C"
 
-#: fortran/decl.c:2617
+#: fortran/decl.c:2626
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid value-initialization of reference type"
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr "inicialización por valor no válida del tipo de referencia"
 
-#: fortran/decl.c:2630
+#: fortran/decl.c:2639
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Error in pointer initialization at %C"
 msgid "Syntax error in old style initialization of %s at %C"
 msgstr "Error en la inicialización de puntero en %C"
 
-#: fortran/decl.c:2650 fortran/decl.c:6661
+#: fortran/decl.c:2659 fortran/decl.c:6680
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr "La inicialización en %C no es para una variable puntero"
 
-#: fortran/decl.c:2663
+#: fortran/decl.c:2672
 #, fuzzy, gcc-internal-format
 #| msgid "Pointer initialization at %C requires '=>', not '='"
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr "La inicialización de puntero en %C requiere '=>', no '='"
 
-#: fortran/decl.c:2672 fortran/decl.c:10240
+#: fortran/decl.c:2681 fortran/decl.c:10265
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr "Se esperaba una expresión de inicialización en %C"
 
-#: fortran/decl.c:2679
+#: fortran/decl.c:2688
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr "No se permite la inicialización de una variable en %C en un procedimiento PURE"
 
-#: fortran/decl.c:2696
+#: fortran/decl.c:2705
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr "No se permite la inicialización del componente allocatable en %C"
 
-#: fortran/decl.c:2710
+#: fortran/decl.c:2719
 #, gcc-internal-format, gfc-internal-format
 msgid "The component with KIND or LEN attribute at %C does not not appear in the type parameter list at %L"
 msgstr ""
 
-#: fortran/decl.c:2718
+#: fortran/decl.c:2727
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Entity '%s' at %L has a deferred type parameter and requires either the pointer or allocatable attribute"
 msgid "The component at %C that appears in the type parameter list at %L has neither the KIND nor LEN attribute"
 msgstr "La entidad '%s' en %L tiene un parámetro de tipo diferido y requiere el atributo pointer o allocatable"
 
-#: fortran/decl.c:2726
+#: fortran/decl.c:2735
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The pointer component '%s' of '%s' at %L is a type that has not been declared"
 msgid "The component at %C which is a type parameter must be a scalar"
 msgstr "El componente puntero '%s' de '%s' en %L es de un tipo que no se ha declarado"
 
-#: fortran/decl.c:2789 fortran/decl.c:2825
+#: fortran/decl.c:2798 fortran/decl.c:2834
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr "No se admite la declaración de tipo de estilo antiguo %s*%d en %C"
 
-#: fortran/decl.c:2831
+#: fortran/decl.c:2840
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr "Declaración de tipo %s*%d no estándar en %C"
 
-#: fortran/decl.c:2890 fortran/decl.c:2967
+#: fortran/decl.c:2899 fortran/decl.c:2976
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis at %C"
 msgstr "Falta el paréntesis derecho en %C"
 
-#: fortran/decl.c:2903 fortran/decl.c:3038
+#: fortran/decl.c:2912 fortran/decl.c:3047
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr "Se esperaba una expresión de inicialización en %C"
 
-#: fortran/decl.c:2911 fortran/decl.c:3044
+#: fortran/decl.c:2920 fortran/decl.c:3053
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr "Se esperaba una expresión de inicialización escalar en %C"
 
-#: fortran/decl.c:2941 fortran/decl.c:3657
+#: fortran/decl.c:2950 fortran/decl.c:3676
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr "No se admite el género %d para el tipo %s en %C"
 
-#: fortran/decl.c:2954
+#: fortran/decl.c:2963
 #, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr "El parámetro de tipo de género C es para el tipo %s, pero el tipo en %L es %s"
 
-#: fortran/decl.c:2965
+#: fortran/decl.c:2974
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr "Falta el paréntesis derecho o una coma en %C"
 
-#: fortran/decl.c:3070
+#: fortran/decl.c:3079
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr "No se admite el género %d para CHARACTER en %C"
 
-#: fortran/decl.c:3202
+#: fortran/decl.c:3211
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr "Error sintáctico en la declaración CHARACTER en %C"
 
-#: fortran/decl.c:3291
+#: fortran/decl.c:3310
 #, gcc-internal-format, gfc-internal-format
 msgid "RECORD at %C is an extension, enable it with -fdec-structure"
 msgstr ""
 
-#: fortran/decl.c:3304
+#: fortran/decl.c:3323
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Interface-name expected after '(' at %C"
 msgid "Structure name expected after RECORD at %C"
 msgstr "Se esperaba un nombre de interfaz después de '(' en %C"
 
-#: fortran/decl.c:3417
+#: fortran/decl.c:3436
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C cannot contain both ASSUMED and DEFERRED parameters"
 msgstr ""
 
-#: fortran/decl.c:3441
+#: fortran/decl.c:3460
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Kind type parameter for entity at %L differs from the kind type parameter of the typespec"
 msgid "The type parameter spec list at %C does not contain enough parameter expressions"
 msgstr "El parámetro de tipo de género para la entidad en %L difiere del parámetro de tipo de género de la especificación de tipo"
 
-#: fortran/decl.c:3465
+#: fortran/decl.c:3484
 #, fuzzy, gcc-internal-format
 #| msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgid "The derived parameter %qs at %C does not have a default value"
 msgstr "el primer parámetro de %<operator new%> no puede tener un argumento por defecto"
 
-#: fortran/decl.c:3497
+#: fortran/decl.c:3516
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression at %L must be of INTEGER type, found %s"
 msgid "The parameter expression at %C must be of INTEGER type and not %s type"
 msgstr "La expresión en %L debe ser de tipo INTEGER, se encontró %s"
 
-#: fortran/decl.c:3525
+#: fortran/decl.c:3544
 #, gcc-internal-format
 msgid "The KIND parameter %qs at %C cannot either be ASSUMED or DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:3532
+#: fortran/decl.c:3551
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L is a variable, which does not reduce to a constant expression"
 msgid "The value for the KIND parameter %qs at %C does not reduce to a constant expression"
 msgstr "La matriz '%s' en %L es una variable, lo cual no se reduce a una expresión constante"
 
-#: fortran/decl.c:3547
+#: fortran/decl.c:3566
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C contains too many parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3556
+#: fortran/decl.c:3575
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "parametrized derived type argument"
 msgid "Parameterized derived type at %C is ambiguous"
 msgstr "argumento de tipo derivado parametrizado"
 
-#: fortran/decl.c:3819
+#: fortran/decl.c:3838
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: BYTE type at %C"
 msgid "BYTE type at %C"
 msgstr "Extensión: tipo BYTE en %C"
 
-#: fortran/decl.c:3824
+#: fortran/decl.c:3843
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr "El tipo BYTE usado en %C no está disponible en la máquina objetivo"
 
-#: fortran/decl.c:3846
+#: fortran/decl.c:3865
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "By-value argument at %L is not allowed in this context"
 msgid "Assumed type at %C is not allowed for components"
 msgstr "El argumento por valor en %L no se permite en este contexto"
 
-#: fortran/decl.c:3849
+#: fortran/decl.c:3868
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr ""
 
-#: fortran/decl.c:3872 fortran/decl.c:3903 fortran/decl.c:3932
-#: fortran/decl.c:4216
+#: fortran/decl.c:3891 fortran/decl.c:3922 fortran/decl.c:3951
+#: fortran/decl.c:4235
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: TYPE with intrinsic-type-spec at %C"
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr "Fortran 2008: TYPE con especificación de tipo intrínseco en %C"
 
-#: fortran/decl.c:3928
+#: fortran/decl.c:3947
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: DOUBLE COMPLEX at %C"
 msgid "DOUBLE COMPLEX at %C"
 msgstr "Extensión: DOUBLE COMPLEX en %C"
 
-#: fortran/decl.c:3971 fortran/decl.c:4107 fortran/decl.c:4119
-#: fortran/decl.c:4133 fortran/decl.c:4611 fortran/decl.c:4619
+#: fortran/decl.c:3990 fortran/decl.c:4126 fortran/decl.c:4138
+#: fortran/decl.c:4152 fortran/decl.c:4630 fortran/decl.c:4638
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C is ambiguous"
 msgid "Type name %qs at %C is ambiguous"
 msgstr "El nombre de tipo '%s' en %C es ambiguo"
 
-#: fortran/decl.c:4066
+#: fortran/decl.c:4085
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: CLASS statement at %C"
 msgid "CLASS statement at %C"
 msgstr "Fortran 2003: Declaración CLASS en %C"
 
-#: fortran/decl.c:4148
+#: fortran/decl.c:4167
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C conflicts with previously declared entity at %L, which has the same name"
 msgid "Type name %qs at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr "El nombre de tipo '%s' en %C tiene conflictos con la entidad declarada previamente en %L, la cual tiene el mismo nombre"
 
-#: fortran/decl.c:4287
+#: fortran/decl.c:4306
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr "Declaración IMPLICIT NONE duplicada en %C"
 
-#: fortran/decl.c:4296
+#: fortran/decl.c:4315
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr ""
 
-#: fortran/decl.c:4355
+#: fortran/decl.c:4374
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr "Falta el rango de carácter en IMPLICIT en %C"
 
-#: fortran/decl.c:4401
+#: fortran/decl.c:4420
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr "Las letras debe estar en orden alfabético en la declaración IMPLICIT en %C"
 
-#: fortran/decl.c:4454
+#: fortran/decl.c:4473
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "SAVE statement at %C follows blanket SAVE statement"
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr "Declaración SAVE en %C después de una declaración SAVE incondicional"
 
-#: fortran/decl.c:4464
+#: fortran/decl.c:4483
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr "Declaración IMPLICIT vacía en %C"
 
-#: fortran/decl.c:4570
+#: fortran/decl.c:4589
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr "La declaración IMPORT en %C sólo se permite en un cuerpo INTERFACE"
 
-#: fortran/decl.c:4577
+#: fortran/decl.c:4596
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgid "F2008: C1210 IMPORT statement at %C is not permitted in a module procedure interface body"
 msgstr "La declaración IMPORT en %C sólo se permite en un cuerpo INTERFACE"
 
-#: fortran/decl.c:4582
+#: fortran/decl.c:4601
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "IMPORT statement at %C"
 msgstr "Declaración IMPLICIT vacía en %C"
 
-#: fortran/decl.c:4596
+#: fortran/decl.c:4615
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr "Se espera la lista de entidades nombradas %C"
 
-#: fortran/decl.c:4625
+#: fortran/decl.c:4644
 #, fuzzy, gcc-internal-format
 #| msgid "Cannot IMPORT '%s' from host scoping unit at %C - does not exist."
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr "No se puede IMPORTar '%s' desde la unidad de ámbito del anfitrión en %C - no existe."
 
-#: fortran/decl.c:4632
+#: fortran/decl.c:4651
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' is already IMPORTed from host scoping unit at %C."
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr "'%s' ya se IMPORTó desde la unidad de ámbito del anfitrión en %C."
 
-#: fortran/decl.c:4673
+#: fortran/decl.c:4692
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IMPORT statement at %C"
 msgstr "Error sintáctico en la declaración IMPORT en %C"
 
-#: fortran/decl.c:5010
+#: fortran/decl.c:5029
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing codimension specification at %C"
 msgstr "Falta la especificación de codimensión en %C"
 
-#: fortran/decl.c:5012
+#: fortran/decl.c:5031
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr "Falta la especificación de dimensión en %C"
 
-#: fortran/decl.c:5107
+#: fortran/decl.c:5126
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr "Atributo %s duplicado en %L"
 
-#: fortran/decl.c:5124
+#: fortran/decl.c:5143
 #, gcc-internal-format
 msgid "%s at %L is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:5141
+#: fortran/decl.c:5160
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ALLOCATABLE attribute at %C in a TYPE definition"
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr "Fortran 2003: atributo ALLOCATABLE en %C en una definición TYPE"
 
-#: fortran/decl.c:5150
+#: fortran/decl.c:5169
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: Attribute %s at %L in a TYPE definition"
 msgid "KIND attribute at %C in a TYPE definition"
 msgstr "Fortran 2003: Atributo %s en %L en una definición TYPE"
 
-#: fortran/decl.c:5158
+#: fortran/decl.c:5177
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL Iteration variable at %L must be INTEGER"
 msgid "Component with KIND attribute at %C must be INTEGER"
 msgstr "La variable de iteración FORALL en %L debe ser INTEGER"
 
-#: fortran/decl.c:5165
+#: fortran/decl.c:5184
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Component '%s' with CLASS at %L must be allocatable or pointer"
 msgid "Component with KIND attribute at %C must be default integer kind (%d)"
 msgstr "El componente '%s' con CLASS en %L debe ser allocatable o pointer"
 
-#: fortran/decl.c:5174
+#: fortran/decl.c:5193
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ALLOCATABLE attribute at %C in a TYPE definition"
 msgid "LEN attribute at %C in a TYPE definition"
 msgstr "Fortran 2003: atributo ALLOCATABLE en %C en una definición TYPE"
 
-#: fortran/decl.c:5182
+#: fortran/decl.c:5201
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL Iteration variable at %L must be INTEGER"
 msgid "Component with LEN attribute at %C must be INTEGER"
 msgstr "La variable de iteración FORALL en %L debe ser INTEGER"
 
-#: fortran/decl.c:5189
+#: fortran/decl.c:5208
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Component '%s' with CLASS at %L must be allocatable or pointer"
 msgid "Component with LEN attribute at %C must be default integer kind (%d)"
 msgstr "El componente '%s' con CLASS en %L debe ser allocatable o pointer"
 
-#: fortran/decl.c:5198
+#: fortran/decl.c:5217
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr "No se permite el atributo %L en una definición TYPE"
 
-#: fortran/decl.c:5216
+#: fortran/decl.c:5235
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: Attribute %s at %L in a TYPE definition"
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr "Fortran 2003: Atributo %s en %L en una definición TYPE"
 
-#: fortran/decl.c:5226
+#: fortran/decl.c:5245
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr "No se permite el atributo %s en %L fuera de la parte de especificación de un módulo"
 
-#: fortran/decl.c:5236
+#: fortran/decl.c:5255
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "Attribute at %L is not allowed outside a TYPE definition"
 msgstr "No se permite el atributo %L en una definición TYPE"
 
-#: fortran/decl.c:5249
+#: fortran/decl.c:5268
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ASYNCHRONOUS attribute at %C"
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr "Fortran 2003: Atributo ASYNCHRONOUS en %C"
 
-#: fortran/decl.c:5260
+#: fortran/decl.c:5279
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: CONTIGUOUS attribute at %C"
 msgid "CONTIGUOUS attribute at %C"
 msgstr "Fortran 2008: Atributo CONTIGUOUS en %C"
 
-#: fortran/decl.c:5315 fortran/decl.c:8673
+#: fortran/decl.c:5334 fortran/decl.c:8692
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr "Sólo se permite PROTECTED en %C en la parte de especificación de un módulo"
 
-#: fortran/decl.c:5321
+#: fortran/decl.c:5340
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: PROTECTED attribute at %C"
 msgid "PROTECTED attribute at %C"
 msgstr "Fortran 2003: Atributo PROTECTED en %C"
 
-#: fortran/decl.c:5355
+#: fortran/decl.c:5374
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: VALUE attribute at %C"
 msgid "VALUE attribute at %C"
 msgstr "Fortran 2003: Atributo VALUE en %C"
 
-#: fortran/decl.c:5362
+#: fortran/decl.c:5381
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: VOLATILE attribute at %C"
 msgid "VOLATILE attribute at %C"
 msgstr "Fortran 2003: Atributo VOLATILE en %C"
 
-#: fortran/decl.c:5369
+#: fortran/decl.c:5388
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr ""
 
-#: fortran/decl.c:5410
+#: fortran/decl.c:5429
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr "Se proveen múltiples identificadores con un sólo especificador NAME= en %C"
 
-#: fortran/decl.c:5508
+#: fortran/decl.c:5527
 #, fuzzy, gcc-internal-format
 #| msgid "Implicitly declared BIND(C) function '%s' at %L may not be C interoperable"
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr "La función implícitamente declarada BIND(C) '%s' en %L no puede ser interoperable con C"
 
-#: fortran/decl.c:5530
+#: fortran/decl.c:5549
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' in common block '%s' at %L may not be a C interoperable kind though common block '%s' is BIND(C)"
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr "La variable '%s' en el bloque común '%s' en %L no puede ser un género interoperable con C ya que el bloque común '%s' es BIND(C)"
 
-#: fortran/decl.c:5539
+#: fortran/decl.c:5558
 #, fuzzy, gcc-internal-format
 #| msgid "Type declaration '%s' at %L is not C interoperable but it is BIND(C)"
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr "La declaración de tipo '%s' en %L no es interoperable con C pero es BIND(C)"
 
-#: fortran/decl.c:5543
+#: fortran/decl.c:5562
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L may not be a C interoperable kind but it is bind(c)"
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr "La variable '%s' en %L no es de un género interoperable con C pero es BIND(C)"
 
-#: fortran/decl.c:5555
+#: fortran/decl.c:5574
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' in common block '%s' at %L cannot be declared with BIND(C) since it is not a global"
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr "La variable '%s' en el bloque común '%s' en %L no se puede declarar con BIND(C) porque no es un global"
 
-#: fortran/decl.c:5569
+#: fortran/decl.c:5588
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr "La variable '%s' en %L no puede tener los atributos POINTER y BIND(C) al mismo tiempo"
 
-#: fortran/decl.c:5577
+#: fortran/decl.c:5596
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr "La variable '%s' en %L no puede tener los atributos ALLOCATABLE y BIND(C) al mismo tiempo"
 
-#: fortran/decl.c:5589
+#: fortran/decl.c:5608
 #, fuzzy, gcc-internal-format
 #| msgid "Return type of BIND(C) function '%s' at %L cannot be an array"
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr "El tipo de devolución de la función BIND(C) '%s' en %L no puede ser una matriz"
 
-#: fortran/decl.c:5597
+#: fortran/decl.c:5616
 #, fuzzy, gcc-internal-format
 #| msgid "Return type of BIND(C) function '%s' at %L cannot be a character string"
 msgid "Return type of BIND(C) function %qs at %L cannot be a character string"
@@ -53062,362 +53139,362 @@
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:5608
+#: fortran/decl.c:5627
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L is marked PRIVATE but has been given the binding label '%s'"
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr "El símbolo '%s' en %L se marcó PRIVATE pero se le dio la etiqueta de asignación '%s'"
 
-#: fortran/decl.c:5682
+#: fortran/decl.c:5701
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr "Se necesita una entidad o un nombre de bloque común para la declaración de especificación de atributo en %C"
 
-#: fortran/decl.c:5727
+#: fortran/decl.c:5746
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr "Falta la entidad o el nombre de bloque común para la declaración de especificación de atributo en %C"
 
-#: fortran/decl.c:5734
+#: fortran/decl.c:5753
 #, fuzzy, gcc-internal-format
 #| msgid "Missing name"
 msgid "Missing symbol"
 msgstr "Falta el nombre"
 
-#: fortran/decl.c:5763
+#: fortran/decl.c:5782
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "BIND(C) statement at %C"
 msgstr "Declaración IMPLICIT vacía en %C"
 
-#: fortran/decl.c:5850
+#: fortran/decl.c:5869
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr "El tipo derivado en %C no se definió previamente y no puede aparecer en una definición de tipo derivado"
 
-#: fortran/decl.c:5892
+#: fortran/decl.c:5911
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in data declaration at %C"
 msgid "Syntax error in anonymous structure declaration at %C"
 msgstr "Error sintáctico en la declaración de datos en %C"
 
-#: fortran/decl.c:5901
+#: fortran/decl.c:5920
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr "Error sintáctico en la declaración de datos en %C"
 
-#: fortran/decl.c:5951
+#: fortran/decl.c:5970
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C"
 msgstr ""
 
-#: fortran/decl.c:5996
+#: fortran/decl.c:6015
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: IMPURE procedure at %C"
 msgid "IMPURE procedure at %C"
 msgstr "Fortran 2008: Procedimiento IMPURE en %C"
 
-#: fortran/decl.c:6008
+#: fortran/decl.c:6027
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr "No deben aparecer PURE con IMPURE en %C"
 
-#: fortran/decl.c:6054
+#: fortran/decl.c:6073
 #, gcc-internal-format, gfc-internal-format
 msgid "ELEMENTAL prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6061
+#: fortran/decl.c:6080
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6068
+#: fortran/decl.c:6087
 #, gcc-internal-format, gfc-internal-format
 msgid "RECURSIVE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6134 fortran/primary.c:1820
+#: fortran/decl.c:6153 fortran/primary.c:1820
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected alternate return label at %C"
 msgid "Alternate-return argument at %C"
 msgstr "Se esperaba la etiqueta de devolución alterna en %C"
 
-#: fortran/decl.c:6140 fortran/decl.c:6148
+#: fortran/decl.c:6159 fortran/decl.c:6167
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Left parenthesis required after %<*%>"
 msgid "A parameter name is required at %C"
 msgstr "Se requiere paréntesis izquierdo después de %<*%>"
 
-#: fortran/decl.c:6188
+#: fortran/decl.c:6207
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is the name of the procedure"
 msgid "Name %qs at %C is the name of the procedure"
 msgstr "El nombre '%s' en %C es el nombre del procedimiento"
 
-#: fortran/decl.c:6201
+#: fortran/decl.c:6220
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected another dimension in array declaration at %C"
 msgid "Expected parameter list in type declaration at %C"
 msgstr "Se esperaba otra dimensión en la declaración de matriz %C"
 
-#: fortran/decl.c:6204
+#: fortran/decl.c:6223
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr "Basura inesperada en la lista de argumentos formales en %C"
 
-#: fortran/decl.c:6222
+#: fortran/decl.c:6241
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate name '%s' in association at %C"
 msgid "Duplicate name %qs in parameter list at %C"
 msgstr "Nombre '%s' duplicado en la asociación en %C"
 
-#: fortran/decl.c:6225
+#: fortran/decl.c:6244
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate symbol '%s' in formal argument list at %C"
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr "Símbolo '%s' duplicado en la lista de argumentos formales en %C"
 
-#: fortran/decl.c:6264
+#: fortran/decl.c:6283
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in MODULE PROCEDURE formal argument names (%s/%s) at %C"
 msgstr ""
 
-#: fortran/decl.c:6270
+#: fortran/decl.c:6289
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in number of MODULE PROCEDURE formal arguments at %C"
 msgstr ""
 
-#: fortran/decl.c:6309
+#: fortran/decl.c:6328
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr "La variable RESULT en %C debe ser diferente que el nombre de la función"
 
-#: fortran/decl.c:6386
+#: fortran/decl.c:6405
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr "Basura inesperada después de la declaración de la función en %C"
 
-#: fortran/decl.c:6396 fortran/decl.c:7494
+#: fortran/decl.c:6415 fortran/decl.c:7513
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: BIND(C) attribute at %L may not be specified for an internal procedure"
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr "Fortran 2008: El atributo BIND(C) en %L no se puede especificar para un procedimiento internal"
 
-#: fortran/decl.c:6600
+#: fortran/decl.c:6619
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr "El atributo BIND(C) en %C requiere una interfaz con BIND(C)"
 
-#: fortran/decl.c:6607
+#: fortran/decl.c:6626
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr "El procedimiento BIND(C) con NAME no debe tener atributo POINTER en %C"
 
-#: fortran/decl.c:6613
+#: fortran/decl.c:6632
 #, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr "El procedimiento dummy en %C no puede tener atributo BIND(C) con NAME"
 
-#: fortran/decl.c:6636
+#: fortran/decl.c:6655
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L already has basic type of %s"
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr "El procedimiento '%s' en %L ya tenía el tipo básico de %s"
 
-#: fortran/decl.c:6682 fortran/decl.c:6870 fortran/decl.c:10723
+#: fortran/decl.c:6701 fortran/decl.c:6889 fortran/decl.c:10748
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr "Error sintáctico en la declaración PROCEDURE en %C"
 
-#: fortran/decl.c:6731 fortran/decl.c:10623
+#: fortran/decl.c:6750 fortran/decl.c:10648
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '::' after binding-attributes at %C"
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr "Se esperaba '::' después de los atributos de enlazado en %C"
 
-#: fortran/decl.c:6738
+#: fortran/decl.c:6757
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr "Se requiere NOPASS o una interfaz explícita en %C"
 
-#: fortran/decl.c:6742
+#: fortran/decl.c:6761
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: Procedure pointer component at %C"
 msgid "Procedure pointer component at %C"
 msgstr "Fortran 2003: Procedimiento de componente puntero en %C"
 
-#: fortran/decl.c:6814
+#: fortran/decl.c:6833
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in procedure pointer component at %C"
 msgstr "Error sintáctico en el procedimiento de componente puntero en %C"
 
-#: fortran/decl.c:6832
+#: fortran/decl.c:6851
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr "PROCEDURE en %C debe estar en una interfaz genérica"
 
-#: fortran/decl.c:6841 fortran/decl.c:9392
+#: fortran/decl.c:6860 fortran/decl.c:9411
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: double colon in MODULE PROCEDURE statement at %L"
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr "Fortran 2008: dos puntos dobles en la declaración MODULE PROCEDURE en %L"
 
-#: fortran/decl.c:6911
+#: fortran/decl.c:6930
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: PROCEDURE statement at %C"
 msgid "PROCEDURE statement at %C"
 msgstr "Fortran 2003: Declaración PROCEDURE en %C"
 
-#: fortran/decl.c:6983
+#: fortran/decl.c:7002
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr "Se esperaba una lista de argumentos formales en la definición de la función en %C"
 
-#: fortran/decl.c:7007 fortran/decl.c:7011 fortran/decl.c:7266
-#: fortran/decl.c:7270 fortran/decl.c:7462 fortran/decl.c:7466
-#: fortran/symbol.c:1875
+#: fortran/decl.c:7026 fortran/decl.c:7030 fortran/decl.c:7285
+#: fortran/decl.c:7289 fortran/decl.c:7481 fortran/decl.c:7485
+#: fortran/symbol.c:1889
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr "El atributo BIND(C) en %L sólo se puede usar para variables o bloques comunes"
 
-#: fortran/decl.c:7164
+#: fortran/decl.c:7183
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "ENTRY statement at %C"
 msgstr "Declaración IMPLICIT vacía en %C"
 
-#: fortran/decl.c:7173
+#: fortran/decl.c:7192
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr "La declaración ENTRY en %C no puede aparecer dentro de un PROGRAM"
 
-#: fortran/decl.c:7176
+#: fortran/decl.c:7195
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr "La declaración ENTRY en %C no puede aparecer dentro de un MODULE"
 
-#: fortran/decl.c:7179
+#: fortran/decl.c:7198
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgid "ENTRY statement at %C cannot appear within a SUBMODULE"
 msgstr "La declaración ENTRY en %C no puede aparecer dentro de un MODULE"
 
-#: fortran/decl.c:7182
+#: fortran/decl.c:7201
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr "La declaración ENTRY en %C no puede aparecer dentro de un BLOCK DATA"
 
-#: fortran/decl.c:7186 fortran/decl.c:7231
+#: fortran/decl.c:7205 fortran/decl.c:7250
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr "La declaración ENTRY en %C no puede aparecer dentro de un INTERFACE"
 
-#: fortran/decl.c:7190
+#: fortran/decl.c:7209
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgid "ENTRY statement at %C cannot appear within a STRUCTURE block"
 msgstr "La declaración ENTRY en %C no puede aparecer dentro de un bloque SELECT"
 
-#: fortran/decl.c:7194
+#: fortran/decl.c:7213
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr "La declaración ENTRY en %C no puede aparecer dentro de un bloque DERIVED TYPE"
 
-#: fortran/decl.c:7198
+#: fortran/decl.c:7217
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr "La declaración ENTRY en %C no puede aparecer dentro de un bloque IF-THEN"
 
-#: fortran/decl.c:7203
+#: fortran/decl.c:7222
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr "La declaración ENTRY en %C no puede aparecer dentro de un bloque DO"
 
-#: fortran/decl.c:7207
+#: fortran/decl.c:7226
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr "La declaración ENTRY en %C no puede aparecer dentro de un bloque SELECT"
 
-#: fortran/decl.c:7211
+#: fortran/decl.c:7230
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr "La declaración ENTRY en %C no puede aparecer dentro de un bloque FORALL"
 
-#: fortran/decl.c:7215
+#: fortran/decl.c:7234
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr "La declaración ENTRY en %C no puede aparecer dentro de un bloque WHERE"
 
-#: fortran/decl.c:7219
+#: fortran/decl.c:7238
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr "La declaración ENTRY en %C no puede aparecer dentro de un subprograma contenido"
 
-#: fortran/decl.c:7223
+#: fortran/decl.c:7242
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected END statement at %C"
 msgid "Unexpected ENTRY statement at %C"
 msgstr "Declaración END inesperada en %C"
 
-#: fortran/decl.c:7244
+#: fortran/decl.c:7263
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr "La declaración ENTRY en %C no puede aparecer dentro de un procedimiento contenido"
 
-#: fortran/decl.c:7295 fortran/decl.c:7501
+#: fortran/decl.c:7314 fortran/decl.c:7520
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr "Faltan los paréntesis requeridos antes de BIND(C) en %C"
 
-#: fortran/decl.c:7563 fortran/decl.c:7570
+#: fortran/decl.c:7582 fortran/decl.c:7589
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid C name in NAME= specifier at %C"
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr "Nombre C no válido en el especificador NAME= en %C"
 
-#: fortran/decl.c:7610
+#: fortran/decl.c:7629
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr "Error sintáctico en el especificador NAME= para la etiqueta de asignación %C"
 
-#: fortran/decl.c:7626
+#: fortran/decl.c:7645
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASYNCHRONOUS= specifier at %L must be an initialization expression"
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr "El especificador ASYNCHRONOUS= en %L debe ser una expresión de inicialización"
 
-#: fortran/decl.c:7634
+#: fortran/decl.c:7653
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr ""
 
-#: fortran/decl.c:7653
+#: fortran/decl.c:7672
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing closing paren for binding label at %C"
 msgstr "Falta el paréntesis que cierra en la etiqueta de asignación en %C"
 
-#: fortran/decl.c:7659
+#: fortran/decl.c:7678
 #, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr "No se permite un nombre de enlazado en BIND(C) en %C"
 
-#: fortran/decl.c:7665
+#: fortran/decl.c:7684
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr "Para el procedimiento dummy %s, no se permite un nombre de enlazado en BIND(C) en %C"
 
-#: fortran/decl.c:7694
+#: fortran/decl.c:7713
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr "No se permite NAME en BIND(C) para ABSTRACT INTERFACE en %C"
 
-#: fortran/decl.c:7939
+#: fortran/decl.c:7958
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr "Declaración END inesperada en %C"
 
-#: fortran/decl.c:7948
+#: fortran/decl.c:7967
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: END statement instead of %s statement at %L"
 msgid "END statement instead of %s statement at %L"
@@ -53424,665 +53501,671 @@
 msgstr "Fortran 2008: Declaración END en lugar de una declaración %s en %L"
 
 #. We would have required END [something].
-#: fortran/decl.c:7957
+#: fortran/decl.c:7976
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr "Se esperaba %s en la declaración en %L"
 
-#: fortran/decl.c:7968
+#: fortran/decl.c:7987
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting %s statement at %C"
 msgid "Expecting %s statement at %L"
 msgstr "Se esperaba la declaración %s en %C"
 
-#: fortran/decl.c:7988
+#: fortran/decl.c:8007
 #, fuzzy, gcc-internal-format
 #| msgid "Expected block name of '%s' in %s statement at %C"
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr "Se esperaba el nombre de bloque de '%s' en la declaración %s en %C"
 
-#: fortran/decl.c:8005
+#: fortran/decl.c:8024
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr "Se esperaba un nombre terminal en %C"
 
-#: fortran/decl.c:8019 fortran/decl.c:8027
+#: fortran/decl.c:8038 fortran/decl.c:8046
 #, fuzzy, gcc-internal-format
 #| msgid "Expected label '%s' for %s statement at %C"
 msgid "Expected label %qs for %s statement at %C"
 msgstr "Se esperaba la etiqueta '%s' para la declaración %s en %C"
 
-#: fortran/decl.c:8126
+#: fortran/decl.c:8145
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr "Falta la especificación de matriz en %L en la declaración DIMENSION"
 
-#: fortran/decl.c:8134
+#: fortran/decl.c:8153
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Dimensions specified for %s at %L after its initialisation"
 msgid "Dimensions specified for %s at %L after its initialization"
 msgstr "Se especificarion dimensiones para %s en %L después de su inicialización"
 
-#: fortran/decl.c:8142
+#: fortran/decl.c:8161
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr "Falta la especificación de matriz en %L en la declaración CODIMENSION"
 
-#: fortran/decl.c:8151
+#: fortran/decl.c:8170
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr "La especificación de matriz se debe diferir en %L"
 
-#: fortran/decl.c:8249
+#: fortran/decl.c:8268
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr "Carácter inesperado en la lista de variables en %C"
 
-#: fortran/decl.c:8286
+#: fortran/decl.c:8305
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "Expected %<(%> at %C"
 msgstr "Se esperaba '(' en %C"
 
-#: fortran/decl.c:8300 fortran/decl.c:8340
+#: fortran/decl.c:8319 fortran/decl.c:8359
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr "se esperaba un nombre variable en %C"
 
-#: fortran/decl.c:8316
+#: fortran/decl.c:8335
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C must be an integer"
 msgstr "El puntero Cray en %C debe ser un entero"
 
-#: fortran/decl.c:8320
+#: fortran/decl.c:8339
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr "El puntero Cray en %C tiene %d bytes de precisión; las direcciones de memoria requieren %d bytes"
 
-#: fortran/decl.c:8326
+#: fortran/decl.c:8345
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr "Se esperaba \",\" en %C"
 
-#: fortran/decl.c:8365
+#: fortran/decl.c:8384
 #, gcc-internal-format
 msgid "Couldn't set Cray pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:8389
+#: fortran/decl.c:8408
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr "Se esperaba \")\" en %C"
 
-#: fortran/decl.c:8401
+#: fortran/decl.c:8420
 #, fuzzy, gcc-internal-format
 #| msgid "Expected \",\" or end of statement at %C"
 msgid "Expected %<,%> or end of statement at %C"
 msgstr "Se esperaba \",\" o el final de la declaración en %C"
 
-#: fortran/decl.c:8427
+#: fortran/decl.c:8446
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr "No se permite INTENT dentro de BLOCK en %C"
 
-#: fortran/decl.c:8459
+#: fortran/decl.c:8478
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr "No se permite OPTIONAL dentro de BLOCK en %C"
 
-#: fortran/decl.c:8478
+#: fortran/decl.c:8497
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer declaration at %C requires -fcray-pointer flag"
 msgstr "La declaración de punteros Cray en %C requiere la opción -fcray-pointer"
 
-#: fortran/decl.c:8517
+#: fortran/decl.c:8536
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: CONTIGUOUS statement at %C"
 msgid "CONTIGUOUS statement at %C"
 msgstr "Fortran 2008: Declaración CONTIGUOUS en %C"
 
-#: fortran/decl.c:8623
+#: fortran/decl.c:8642
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr "La especificación de acceso del operador %s en %C ya se había especificado"
 
-#: fortran/decl.c:8640
+#: fortran/decl.c:8659
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr "La especificación de acceso del operador .%s. en %C ya se había especificado"
 
-#: fortran/decl.c:8679
+#: fortran/decl.c:8698
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: PROTECTED statement at %C"
 msgid "PROTECTED statement at %C"
 msgstr "Fortran 2003: Declaración PROTECTED en %C"
 
-#: fortran/decl.c:8717
+#: fortran/decl.c:8736
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr "Error sintáctico en la declaración PROTECTED en %C"
 
-#: fortran/decl.c:8741
+#: fortran/decl.c:8760
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr "Sólo se permite la declaración PRIVATE en %C en la parte de especificación de un módulo"
 
-#: fortran/decl.c:8778
+#: fortran/decl.c:8797
 #, gcc-internal-format, gfc-internal-format
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr "Sólo se permite la declaración PRIVATE en %C en la parte de especificación de un módulo"
 
-#: fortran/decl.c:8806
+#: fortran/decl.c:8825
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr "Se esperaba un nombre de variable en %C en la declaración PARAMETER"
 
-#: fortran/decl.c:8813
+#: fortran/decl.c:8832
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr "Se esperaba un signo = en la declaración PARAMETER en %C"
 
-#: fortran/decl.c:8819
+#: fortran/decl.c:8838
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr "Se esperaba una expresión en %C en la declaración PARAMETER"
 
-#: fortran/decl.c:8839
+#: fortran/decl.c:8858
 #, gcc-internal-format, gfc-internal-format
 msgid "Initializing already initialized variable at %C"
 msgstr "Se inicializa una variable ya inicializada en %C"
 
 #. With legacy PARAMETER statements, don't expect a terminating ')'.
-#: fortran/decl.c:8864
+#: fortran/decl.c:8883
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER without '()' at %C"
 msgstr ""
 
-#: fortran/decl.c:8880
+#: fortran/decl.c:8899
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr "Caracteres inesperados en la declaración PARAMETER en %C"
 
-#: fortran/decl.c:8899 fortran/decl.c:8955
+#: fortran/decl.c:8918 fortran/decl.c:8974
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:8934
+#: fortran/decl.c:8953
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected variable in READ statement at %C"
 msgid "Expected entity-list in AUTOMATIC statement at %C"
 msgstr "Se esperaba una variable en la declaración READ en %C"
 
-#: fortran/decl.c:8941
+#: fortran/decl.c:8960
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in VOLATILE statement at %C"
 msgid "Syntax error in AUTOMATIC statement at %C"
 msgstr "Error sintáctico en la declaración VOLATILE en %C"
 
-#: fortran/decl.c:8990
+#: fortran/decl.c:9009
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected variable in READ statement at %C"
 msgid "Expected entity-list in STATIC statement at %C"
 msgstr "Se esperaba una variable en la declaración READ en %C"
 
-#: fortran/decl.c:8997
+#: fortran/decl.c:9016
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in STATIC statement at %C"
 msgstr "Error sintáctico en la declaración SAVE en %C"
 
-#: fortran/decl.c:9016
+#: fortran/decl.c:9035
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr "Declaración SAVE incondicional en %C después de una declaración SAVE previa"
 
-#: fortran/decl.c:9027
+#: fortran/decl.c:9046
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr "Declaración SAVE en %C después de una declaración SAVE incondicional"
 
-#: fortran/decl.c:9073
+#: fortran/decl.c:9092
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr "Error sintáctico en la declaración SAVE en %C"
 
-#: fortran/decl.c:9087
+#: fortran/decl.c:9106
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr "No se permite VALUE dentro de BLOCK en %C"
 
-#: fortran/decl.c:9091
+#: fortran/decl.c:9110
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: VALUE statement at %C"
 msgid "VALUE statement at %C"
 msgstr "Fortran 2003: Declaración VALUE en %C"
 
-#: fortran/decl.c:9129
+#: fortran/decl.c:9148
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VALUE statement at %C"
 msgstr "Error sintáctico en la declaración VALUE en %C"
 
-#: fortran/decl.c:9141
+#: fortran/decl.c:9160
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: VOLATILE statement at %C"
 msgid "VOLATILE statement at %C"
 msgstr "Fortran 2003: Declaración VOLATILE en %C"
 
-#: fortran/decl.c:9168
+#: fortran/decl.c:9187
 #, fuzzy, gcc-internal-format
 #| msgid "Specifying VOLATILE for coarray variable '%s' at %C, which is use-/host-associated"
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr "Se especifica VOLATILE para la variable de comatriz '%s' en %C, la cual es asociada a uso/anfitrión"
 
-#: fortran/decl.c:9193
+#: fortran/decl.c:9212
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr "Error sintáctico en la declaración VOLATILE en %C"
 
-#: fortran/decl.c:9205
+#: fortran/decl.c:9224
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ASYNCHRONOUS statement at %C"
 msgid "ASYNCHRONOUS statement at %C"
 msgstr "Fortran 2003: Declaración ASYNCHRONOUS en %C"
 
-#: fortran/decl.c:9249
+#: fortran/decl.c:9268
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr "Error sintáctico en la declaración ASYNCHRONOUS en %C"
 
-#: fortran/decl.c:9274
+#: fortran/decl.c:9293
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Junk after PROCEDURE declaration at %C"
 msgid "MODULE PROCEDURE declaration at %C"
 msgstr "Basura después de la declaración PROCEDURE en %C"
 
-#: fortran/decl.c:9367
+#: fortran/decl.c:9386
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr "MODULE PROCEDURE en %C debe estar en una interfaz genérica de módulo"
 
-#: fortran/decl.c:9425
+#: fortran/decl.c:9444
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr "El procedimiento intrínseco en %L no puede ser un MODULE PROCEDURE"
 
-#: fortran/decl.c:9474
+#: fortran/decl.c:9493
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr "Símbolo ambiguo en la definición TYPE en %C"
 
-#: fortran/decl.c:9483
+#: fortran/decl.c:9502
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C has already been host associated"
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr "El símbolo '%s' en %C ya se había asociado con el anfitrión"
 
-#: fortran/decl.c:9489
+#: fortran/decl.c:9508
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' in EXTENDS expression at %C is not a derived type"
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr "'%s' en la expresión EXTENDS en %C no es un tipo derivado"
 
-#: fortran/decl.c:9496
+#: fortran/decl.c:9515
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' cannot be extended at %C because it is BIND(C)"
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr "'%s' no se puede extender en %C porque es BIND(C)"
 
-#: fortran/decl.c:9503
+#: fortran/decl.c:9522
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' cannot be extended at %C because it is a SEQUENCE type"
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr "'%s' no se puede extender en %C porque es un tipo SEQUENCE"
 
-#: fortran/decl.c:9526
+#: fortran/decl.c:9545
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr "El tipo derivado en %C sólo puede ser PRIVATE en la parte de especificación de un módulo"
 
-#: fortran/decl.c:9538
+#: fortran/decl.c:9557
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr "El tipo derivado en %C sólo puede ser PUBLIC en la parte de especificación de un módulo"
 
-#: fortran/decl.c:9559
+#: fortran/decl.c:9578
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ABSTRACT type '%s' used at %L"
 msgid "ABSTRACT type at %C"
 msgstr "El tipo ABSTRACT '%s' se usa en %L"
 
-#: fortran/decl.c:9605
+#: fortran/decl.c:9624
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate construct label '%s' at %C"
 msgid "Failed to create structure type '%s' at %C"
 msgstr "Etiqueta construct '%s' duplicada en %C"
 
-#: fortran/decl.c:9611
+#: fortran/decl.c:9630
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type definition of '%s' at %C has already been defined"
 msgid "Type definition of %qs at %C was already defined at %L"
 msgstr "La definición del tipo derivado de '%s' en %C ya se había definido"
 
-#: fortran/decl.c:9658
+#: fortran/decl.c:9677
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Junk after ASSOCIATE statement at %C"
 msgid "Junk after MAP statement at %C"
 msgstr "Basura después de la declaración ASSOCIATE en %C"
 
-#: fortran/decl.c:9691
+#: fortran/decl.c:9710
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Junk after ASSOCIATE statement at %C"
 msgid "Junk after UNION statement at %C"
 msgstr "Basura después de la declaración ASSOCIATE en %C"
 
-#: fortran/decl.c:9726
+#: fortran/decl.c:9745
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is not a member of the '%s' structure"
 msgid "%s at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr "'%s' en %C no es un miembro de la estructura '%s'"
 
-#: fortran/decl.c:9740
+#: fortran/decl.c:9759
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing structure name for outer structure definition at %0"
 msgid "Structure name expected in non-nested structure declaration at %C"
 msgstr "Falta el nombre de la estructura para la definición de la estructura externa en %0"
 
-#: fortran/decl.c:9758
+#: fortran/decl.c:9777
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Junk after ASSOCIATE statement at %C"
 msgid "Junk after non-nested STRUCTURE statement at %C"
 msgstr "Basura después de la declaración ASSOCIATE en %C"
 
-#: fortran/decl.c:9765
+#: fortran/decl.c:9784
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C cannot be the same as an intrinsic type"
 msgid "Structure name %qs at %C cannot be the same as an intrinsic type"
 msgstr "El nombre de tipo '%s' en %C no puede ser el mismo que un tipo intrínseco"
 
-#: fortran/decl.c:9926
+#: fortran/decl.c:9947
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr "Se esperaba :: en la definición TYPE en %C"
 
-#: fortran/decl.c:9954
+#: fortran/decl.c:9975
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C cannot be the same as an intrinsic type"
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr "El nombre de tipo '%s' en %C no puede ser el mismo que un tipo intrínseco"
 
-#: fortran/decl.c:9964
+#: fortran/decl.c:9986
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type name '%s' at %C already has a basic type of %s"
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr "El nombre de tipo derivado '%s' en %C ya tiene un tipo básico de %s"
 
-#: fortran/decl.c:9981
+#: fortran/decl.c:9989
 #, fuzzy, gcc-internal-format
+#| msgid "Derived type name '%s' at %C already has a basic type of %s"
+msgid "Derived type name %qs at %C already has a basic type"
+msgstr "El nombre de tipo derivado '%s' en %C ya tiene un tipo básico de %s"
+
+#: fortran/decl.c:10006
+#, fuzzy, gcc-internal-format
 #| msgid "Derived type definition of '%s' at %C has already been defined"
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr "La definición del tipo derivado de '%s' en %C ya se había definido"
 
-#: fortran/decl.c:10042
+#: fortran/decl.c:10067
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CHARACTER declaration at %C"
 msgid "Garbage after PARAMETERIZED TYPE declaration at %C"
 msgstr "Error sintáctico en la declaración CHARACTER en %C"
 
-#: fortran/decl.c:10126
+#: fortran/decl.c:10151
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr "El Apuntado Cray en %C no puede ser una matriz de forma asumida"
 
-#: fortran/decl.c:10146
+#: fortran/decl.c:10171
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ENUM and ENUMERATOR at %C"
 msgid "ENUM and ENUMERATOR at %C"
 msgstr "Fortran 2003: ENUM y ENUMERATOR en %C"
 
-#: fortran/decl.c:10178
+#: fortran/decl.c:10203
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr "El enumerador excede el tipo entero de C en %C"
 
-#: fortran/decl.c:10257
+#: fortran/decl.c:10282
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr "ENUMERATOR %L no se inicializó con una expresión entera"
 
-#: fortran/decl.c:10305
+#: fortran/decl.c:10330
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr "Se esperaba una declaración de definición ENUM antes de %C"
 
-#: fortran/decl.c:10341
+#: fortran/decl.c:10366
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr "Error sintáctico en la definición ENUMERATOR en %C"
 
-#: fortran/decl.c:10388 fortran/decl.c:10403
+#: fortran/decl.c:10413 fortran/decl.c:10428
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate access-specifier at %C"
 msgstr "Especificador de acceso duplicado en %C"
 
-#: fortran/decl.c:10423
+#: fortran/decl.c:10448
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr "Los atributos de enlace ya especifican paso, NOPASS ilegal en %C"
 
-#: fortran/decl.c:10443
+#: fortran/decl.c:10468
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr "Los atributos de enlace ya especifican paso, PASS ilegal en %C"
 
-#: fortran/decl.c:10470
+#: fortran/decl.c:10495
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate POINTER attribute at %C"
 msgstr "Atributo POINTER duplicado en %C"
 
-#: fortran/decl.c:10488
+#: fortran/decl.c:10513
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr "NON_OVERRIDABLE duplicado en %C"
 
-#: fortran/decl.c:10504
+#: fortran/decl.c:10529
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DEFERRED at %C"
 msgstr "DEFERRED duplicado en %C"
 
-#: fortran/decl.c:10517
+#: fortran/decl.c:10542
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected access-specifier at %C"
 msgstr "Se esperaba un especificador de acceso en %C"
 
-#: fortran/decl.c:10519
+#: fortran/decl.c:10544
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr "Se esperaba un atributo de enlace en %C"
 
-#: fortran/decl.c:10527
+#: fortran/decl.c:10552
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED can't both appear at %C"
 msgstr "No pueden aparecer NON_OVERRIDABLE y DEFERRED al mismo tiempo en %C"
 
-#: fortran/decl.c:10539
+#: fortran/decl.c:10564
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr "Se requiere el atributo POINTER para el procedimiento de componente puntero en %C"
 
-#: fortran/decl.c:10581
+#: fortran/decl.c:10606
 #, fuzzy, gcc-internal-format
 #| msgid "Interface-name expected after '(' at %C"
 msgid "Interface-name expected after %<(%> at %C"
 msgstr "Se esperaba un nombre de interfaz después de '(' en %C"
 
-#: fortran/decl.c:10587
+#: fortran/decl.c:10612
 #, fuzzy, gcc-internal-format
 #| msgid "')' expected at %C"
 msgid "%<)%> expected at %C"
 msgstr "Se esperaba ')' en %C"
 
-#: fortran/decl.c:10607
+#: fortran/decl.c:10632
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr "Se debe especificar una interfaz para el enlace DEFERRED en %C"
 
-#: fortran/decl.c:10612
+#: fortran/decl.c:10637
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr "PROCEDURE(interface) en %C se debe declarar DEFERRED"
 
-#: fortran/decl.c:10635
+#: fortran/decl.c:10660
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr "Se esperaba un nombre de enlace en %C"
 
-#: fortran/decl.c:10639
+#: fortran/decl.c:10664
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: PROCEDURE list at %C"
 msgid "PROCEDURE list at %C"
 msgstr "Fortran 2008: Lista PROCEDURE en %C"
 
-#: fortran/decl.c:10651
+#: fortran/decl.c:10676
 #, fuzzy, gcc-internal-format
 #| msgid "'=> target' is invalid for DEFERRED binding at %C"
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr "'=> objetivo' es no válido para el enlace DEFERRED en %C"
 
-#: fortran/decl.c:10657
+#: fortran/decl.c:10682
 #, fuzzy, gcc-internal-format
 #| msgid "'::' needed in PROCEDURE binding with explicit target at %C"
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr "Se necesita '::' en el enlace PROCEDURE con objetivo explícito en %C"
 
-#: fortran/decl.c:10667
+#: fortran/decl.c:10692
 #, fuzzy, gcc-internal-format
 #| msgid "Expected binding target after '=>' at %C"
 msgid "Expected binding target after %<=>%> at %C"
 msgstr "Se esperaba un objetivo de enlace después de '=>' en %C"
 
-#: fortran/decl.c:10684
+#: fortran/decl.c:10709
 #, fuzzy, gcc-internal-format
 #| msgid "Type '%s' containing DEFERRED binding at %C is not ABSTRACT"
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr "El tipo '%s' que contiene el enlace DEFERRED en %C no es ABSTRACT"
 
-#: fortran/decl.c:10695
+#: fortran/decl.c:10720
 #, fuzzy, gcc-internal-format
 #| msgid "There is already a procedure with binding name '%s' for the derived type '%s' at %C"
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr "Ya existe un procedimiento con nombre de enlazado '%s' para el tipo derivado '%s' en %C"
 
-#: fortran/decl.c:10746
+#: fortran/decl.c:10771
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr "GENERIC en %C debe estar dentro de un tipo derivado CONTAINS"
 
-#: fortran/decl.c:10766
+#: fortran/decl.c:10791
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '::' at %C"
 msgid "Expected %<::%> at %C"
 msgstr "Se esperaba '::' en %C"
 
-#: fortran/decl.c:10778
+#: fortran/decl.c:10803
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected generic name or operator descriptor at %C"
 msgstr "Se esperaba un nombre genérico o un descriptor de operador en %C"
 
-#: fortran/decl.c:10799
+#: fortran/decl.c:10824
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid form of PROGRAM statement at %C"
 msgid "Malformed GENERIC statement at %C"
 msgstr "Forma no válida de la declaración PROGRAM en %C"
 
-#: fortran/decl.c:10810
+#: fortran/decl.c:10835
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '=>' at %C"
 msgid "Expected %<=>%> at %C"
 msgstr "Se esperaba '=>' en %C"
 
-#: fortran/decl.c:10846
+#: fortran/decl.c:10871
 #, fuzzy, gcc-internal-format
 #| msgid "There's already a non-generic procedure with binding name '%s' for the derived type '%s' at %C"
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr "Ya existe un procedimiento que no es genérico con el nombre de enlace '%s' para el tipo derivado '%s' en %C"
 
-#: fortran/decl.c:10854
+#: fortran/decl.c:10879
 #, fuzzy, gcc-internal-format
 #| msgid "Binding at %C must have the same access as already defined binding '%s'"
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr "El enlace en %C debe tener el mismo acceso que el enlace '%s' que ya está definido"
 
-#: fortran/decl.c:10902
+#: fortran/decl.c:10927
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr "Se esperaba un nombre de enlace específico en %C"
 
-#: fortran/decl.c:10912
+#: fortran/decl.c:10937
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' already defined as specific binding for the generic '%s' at %C"
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr "Ya se definió '%s' como un enlace específico para el genérico '%s' en %C"
 
-#: fortran/decl.c:10930
+#: fortran/decl.c:10955
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr "Basura después del enlace GENERIC en %C"
 
-#: fortran/decl.c:10965
+#: fortran/decl.c:10990
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr "La declaración FINAL en %C debe estar dentro de una sección de tipo derivado CONTAINS"
 
-#: fortran/decl.c:10976
+#: fortran/decl.c:11001
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr "La declaración de tipo derivado con FINAL en %C debe estar en la parte de especificación de un MODULE"
 
-#: fortran/decl.c:10998
+#: fortran/decl.c:11023
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr "FINAL vacío en %C"
 
-#: fortran/decl.c:11005
+#: fortran/decl.c:11030
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr "Se esperaba un nombre de procedimiento de módulo en %C"
 
-#: fortran/decl.c:11015
+#: fortran/decl.c:11040
 #, fuzzy, gcc-internal-format
 #| msgid "Expected \",\" at %C"
 msgid "Expected %<,%> at %C"
 msgstr "Se esperaba \",\" en %C"
 
-#: fortran/decl.c:11021
+#: fortran/decl.c:11046
 #, fuzzy, gcc-internal-format
 #| msgid "Unknown procedure name \"%s\" at %C"
 msgid "Unknown procedure name %qs at %C"
 msgstr "Nombre de procedimiento \"%s\" desconocido en %C"
 
-#: fortran/decl.c:11034
+#: fortran/decl.c:11059
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is already defined as FINAL procedure!"
 msgid "%qs at %C is already defined as FINAL procedure"
 msgstr "¡'%s' en %C ya se había definido como un procedimiento FINAL!"
 
-#: fortran/decl.c:11104
+#: fortran/decl.c:11129
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr "Atributo desconocido en la declaración !GCC$ ATTRIBUTES en %C"
 
-#: fortran/decl.c:11150
+#: fortran/decl.c:11175
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr "Error sintáctico en la declaración !GCC$ ATTRIBUTES en %C"
 
-#: fortran/decl.c:11170
+#: fortran/decl.c:11195
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive requires a non-negative integral constant less than or equal to %u at %C"
 msgstr ""
 
-#: fortran/decl.c:11184
+#: fortran/decl.c:11209
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in FORALL iterator at %C"
 msgid "Syntax error in !GCC$ UNROLL directive at %C"
@@ -54449,31 +54532,31 @@
 msgid "BOZ literal at %L used to initialize non-integer variable %qs"
 msgstr "Extensión: se usa la literal BOZ en %L para inicializar la variable '%s' que no es entera"
 
-#: fortran/expr.c:3369 fortran/resolve.c:10197
+#: fortran/expr.c:3369 fortran/resolve.c:10210
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: BOZ literal at %L outside a DATA statement and outside INT/REAL/DBLE/CMPLX"
 msgid "BOZ literal at %L outside a DATA statement and outside INT/REAL/DBLE/CMPLX"
 msgstr "Extensión: la literal BOZ en %L está fuera de una declaración DATA y fuera de INT/REAL/DBLE/CMPLX"
 
-#: fortran/expr.c:3380 fortran/resolve.c:10208
+#: fortran/expr.c:3380 fortran/resolve.c:10221
 #, fuzzy, gcc-internal-format
 #| msgid "BOZ literal at %L is bitwise transferred non-integer symbol '%s'"
 msgid "BOZ literal at %L is bitwise transferred non-integer symbol %qs"
 msgstr "La literal BOZ en %L se transfiere por bits al símbolo '%s' que no es entero"
 
-#: fortran/expr.c:3388 fortran/resolve.c:10217
+#: fortran/expr.c:3388 fortran/resolve.c:10230
 #, fuzzy, gcc-internal-format
 #| msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option -fno-range-check"
 msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "Desborde aritmético por debajo del BOZ transferido por bits en %L. Esta revisión se puede desactivar con la opción -fno-range-check"
 
-#: fortran/expr.c:3392 fortran/resolve.c:10221
+#: fortran/expr.c:3392 fortran/resolve.c:10234
 #, fuzzy, gcc-internal-format
 #| msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option -fno-range-check"
 msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "Desborde aritmético del BOZ transferido por bits en %L. Esta revisión se puede desactivar con la opción -fno-range-check"
 
-#: fortran/expr.c:3396 fortran/resolve.c:10225
+#: fortran/expr.c:3396 fortran/resolve.c:10238
 #, fuzzy, gcc-internal-format
 #| msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option -fno-range-check"
 msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
@@ -54485,159 +54568,159 @@
 msgid "The assignment to a KIND or LEN component of a parameterized type at %L is not allowed"
 msgstr "El componente de caractér de longitud diferida '%s' en %L aún no se admite"
 
-#: fortran/expr.c:3426
+#: fortran/expr.c:3429
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible types in DATA statement at %L; attempted conversion of %s to %s"
 msgstr "Tipos incompatible en la declaración DATA en %L; se intentó la conversión de %s a %s"
 
-#: fortran/expr.c:3465
+#: fortran/expr.c:3468
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is not a POINTER at %L"
 msgstr "El objetivo de asignación de puntero no es un POINTER en %L"
 
-#: fortran/expr.c:3473
+#: fortran/expr.c:3476
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgid "%qs in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgstr "'%s' en la asignación de puntero en %L no puede ser un l-valor ya que es un procedimiento"
 
-#: fortran/expr.c:3496
+#: fortran/expr.c:3499
 #, fuzzy, gcc-internal-format
 #| msgid "Expected bounds specification for '%s' at %L"
 msgid "Expected bounds specification for %qs at %L"
 msgstr "Se esperaba una especificación de límites para '%s' en %L"
 
-#: fortran/expr.c:3501
+#: fortran/expr.c:3504
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: Bounds specification for '%s' in pointer assignment at %L"
 msgid "Bounds specification for %qs in pointer assignment at %L"
 msgstr "Fortran 2003: Especificación de límites para '%s' en una asignación de puntero en %L"
 
-#: fortran/expr.c:3514
+#: fortran/expr.c:3517
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower bound has to be present at %L"
 msgstr "El límite inferior debe estar presente en %L"
 
-#: fortran/expr.c:3520
+#: fortran/expr.c:3523
 #, gcc-internal-format, gfc-internal-format
 msgid "Stride must not be present at %L"
 msgstr "El tranco no debe ser estar presente en %L"
 
-#: fortran/expr.c:3532
+#: fortran/expr.c:3535
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the upper bounds must be specified at %L"
 msgstr "Se deben especificar todos o ninguno de los límites superiores en %L"
 
-#: fortran/expr.c:3558
+#: fortran/expr.c:3561
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %L shall not have a coindex"
 msgstr "El objeto puntero en %L no debe tener un coíndice"
 
-#: fortran/expr.c:3579
+#: fortran/expr.c:3582
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure pointer assignment at %L"
 msgstr "Asignación de puntero de procedimiento no válida en %L"
 
-#: fortran/expr.c:3603
+#: fortran/expr.c:3606
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' is invalid in procedure pointer assignment at %L"
 msgid "Function result %qs is invalid as proc-target in procedure pointer assignment at %L"
 msgstr "La función de declaración '%s' es no válida en la asignación de puntero de procedimiento en %L"
 
-#: fortran/expr.c:3612
+#: fortran/expr.c:3615
 #, fuzzy, gcc-internal-format
 #| msgid "Abstract interface '%s' is invalid in procedure pointer assignment at %L"
 msgid "Abstract interface %qs is invalid in procedure pointer assignment at %L"
 msgstr "La interfaz abstracta '%s' es no válida en la asignación de puntero de procedimiento en %L"
 
-#: fortran/expr.c:3622
+#: fortran/expr.c:3625
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' is invalid in procedure pointer assignment at %L"
 msgid "Statement function %qs is invalid in procedure pointer assignment at %L"
 msgstr "La función de declaración '%s' es no válida en la asignación de puntero de procedimiento en %L"
 
-#: fortran/expr.c:3628
+#: fortran/expr.c:3631
 #, fuzzy, gcc-internal-format
 #| msgid "Internal procedure '%s' is invalid in procedure pointer assignment at %L"
 msgid "Internal procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "El procedimiento interno '%s' es no válido en la asignación de puntero de procedimiento en %L"
 
-#: fortran/expr.c:3635
+#: fortran/expr.c:3638
 #, fuzzy, gcc-internal-format
 #| msgid "Internal procedure '%s' is invalid in procedure pointer assignment at %L"
 msgid "Intrinsic %qs at %L is invalid in procedure pointer assignment"
 msgstr "El procedimiento interno '%s' es no válido en la asignación de puntero de procedimiento en %L"
 
-#: fortran/expr.c:3643
+#: fortran/expr.c:3646
 #, fuzzy, gcc-internal-format
 #| msgid "Nonintrinsic elemental procedure '%s' is invalid in procedure pointer assigment at %L"
 msgid "Nonintrinsic elemental procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "El procedimiento elemental que no es intrínseco '%s' es no válido en la asignación de puntero de procedimiento en %L"
 
-#: fortran/expr.c:3666
+#: fortran/expr.c:3669
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in the procedure pointer assignment at %L: mismatch in the calling convention"
 msgstr "No hay coincidencia en la asignación de puntero a procedimiento en %L: no hay coincidencia en la convención a llamada"
 
-#: fortran/expr.c:3719
+#: fortran/expr.c:3722
 #, fuzzy, gcc-internal-format
 #| msgid "Interface mismatch in procedure pointer assignment at %L: %s"
 msgid "Interface mismatch in procedure pointer assignment at %L: %qs is not a subroutine"
 msgstr "No coincide la interfaz en la asignación de puntero a procedimiento en %L: %s"
 
-#: fortran/expr.c:3729 fortran/expr.c:3744
+#: fortran/expr.c:3732 fortran/expr.c:3747
 #, fuzzy, gcc-internal-format
 #| msgid "NOPASS or explicit interface required at %C"
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr "Se requiere NOPASS o una interfaz explícita en %C"
 
-#: fortran/expr.c:3735 fortran/expr.c:3750 fortran/resolve.c:2566
+#: fortran/expr.c:3738 fortran/expr.c:3753 fortran/resolve.c:2566
 #, fuzzy, gcc-internal-format
 #| msgid "NOPASS or explicit interface required at %C"
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr "Se requiere NOPASS o una interfaz explícita en %C"
 
-#: fortran/expr.c:3762
+#: fortran/expr.c:3765
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %s"
 msgstr "No coincide la interfaz en la asignación de puntero a procedimiento en %L: %s"
 
-#: fortran/expr.c:3771
+#: fortran/expr.c:3774
 #, gcc-internal-format
 msgid "Procedure pointer target %qs at %L must be either an intrinsic, host or use associated, referenced or have the EXTERNAL attribute"
 msgstr ""
 
-#: fortran/expr.c:3788
+#: fortran/expr.c:3791
 #, gcc-internal-format, gfc-internal-format
 msgid "Data-pointer-object at %L must be unlimited polymorphic, or of a type with the BIND or SEQUENCE attribute, to be compatible with an unlimited polymorphic target"
 msgstr ""
 
-#: fortran/expr.c:3793
+#: fortran/expr.c:3796
 #, gcc-internal-format, gfc-internal-format
 msgid "Different types in pointer assignment at %L; attempted assignment of %s to %s"
 msgstr "Tipos diferentes en la asignación de puntero en %L; se intentó la asignación de %s a %s"
 
-#: fortran/expr.c:3802
+#: fortran/expr.c:3805
 #, gcc-internal-format, gfc-internal-format
 msgid "Different kind type parameters in pointer assignment at %L"
 msgstr "Parámetros de tipo de género diferentes en la asignación de puntero en %L"
 
-#: fortran/expr.c:3809
+#: fortran/expr.c:3812
 #, gcc-internal-format, gfc-internal-format
 msgid "Different ranks in pointer assignment at %L"
 msgstr "Rangos diferentes en la asignación de puntero en %L"
 
-#: fortran/expr.c:3828
+#: fortran/expr.c:3831
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is smaller than size of the pointer (%ld < %ld) at %L"
 msgstr "El objetivo de remapeo de rango es menor que el tamaño del puntero (%ld < %ld) en %L"
 
-#: fortran/expr.c:3841
+#: fortran/expr.c:3844
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target must be rank 1 or simply contiguous at %L"
 msgstr "El objetivo de remapeo de rango de debe ser de rango 1 o simplemente contiguo en %L"
 
-#: fortran/expr.c:3845
+#: fortran/expr.c:3848
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: Rank remapping target is not rank 1 at %L"
 msgid "Rank remapping target is not rank 1 at %L"
@@ -54646,162 +54729,167 @@
 #. The test above might need to be extend when F08, Note 5.4 has to be
 #. interpreted in the way that target and pointer with the same coindex
 #. are allowed.
-#: fortran/expr.c:3877 fortran/expr.c:3925
+#: fortran/expr.c:3880 fortran/expr.c:3928
 #, gcc-internal-format, gfc-internal-format
 msgid "Data target at %L shall not have a coindex"
 msgstr "El objetivo de datos en %L no puede tener un coíndice"
 
-#: fortran/expr.c:3880
+#: fortran/expr.c:3883
 #, gcc-internal-format, gfc-internal-format
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr "La expresión objetivo en la asignación de puntero en %L debe entregar un resultado puntero"
 
-#: fortran/expr.c:3888
+#: fortran/expr.c:3891
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr "El objetivo de asignación de puntero no es TARGET ni POINTER en %L"
 
-#: fortran/expr.c:3895
+#: fortran/expr.c:3898
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr "Objetivo erróneo en la asignación de puntero en el procedimiento PURE en %L"
 
-#: fortran/expr.c:3904
+#: fortran/expr.c:3907
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr "Asignación de puntero con subíndice vectorial del lado derecho en %L"
 
-#: fortran/expr.c:3912
+#: fortran/expr.c:3915
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr "El objetivo de asignación de puntero tiene atributo PROTECTED en %L"
 
-#: fortran/expr.c:3936
+#: fortran/expr.c:3939
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to contiguous pointer from non-contiguous target at %L"
 msgstr ""
 
-#: fortran/expr.c:3975
+#: fortran/expr.c:3978
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr "La expresión objetivo en la asignación de puntero en %L debe entregar un resultado puntero"
 
-#: fortran/expr.c:4051 fortran/resolve.c:1452
+#: fortran/expr.c:4054 fortran/resolve.c:1452
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer initialization target at %L must not be ALLOCATABLE "
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr "El objetivo de inicialización de puntero en %L no debe ser ALLOCATABLE"
 
-#: fortran/expr.c:4057
+#: fortran/expr.c:4060
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer initialization target at %C must have the TARGET attribute"
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr "El objetivo de inicialización de puntero en %C debe tener el atributo TARGET"
 
-#: fortran/expr.c:4072 fortran/resolve.c:1458
+#: fortran/expr.c:4075 fortran/resolve.c:1458
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr "El objetivo de inicialización de puntero en %L debe tener el atributo SAVE"
 
-#: fortran/expr.c:4084
+#: fortran/expr.c:4087
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr "El objetivo de inicialización de puntero a procedimiento en %L tal vez no es un puntero a procedimiento"
 
-#: fortran/expr.c:5512
+#: fortran/expr.c:4557
+#, gcc-internal-format
+msgid "generate_isocbinding_initializer(): bad iso_c_binding type, expected %<c_ptr%> or %<c_funptr%>"
+msgstr ""
+
+#: fortran/expr.c:5568
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr "Fortran 2008: Funciones puntero en un contexto de definición variable (%s) en %L"
 
-#: fortran/expr.c:5520
+#: fortran/expr.c:5576
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr "Expresión que no es variable en el contexto de definición variable (%s) en %L"
 
-#: fortran/expr.c:5528
+#: fortran/expr.c:5584
 #, fuzzy, gcc-internal-format
 #| msgid "Named constant '%s' in variable definition context (%s) at %L"
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr "Constante nombrada '%s' en el contexto de definición variable (%s) en %L"
 
-#: fortran/expr.c:5537
+#: fortran/expr.c:5593
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' in variable definition context (%s) at %L is not a variable"
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr "'%s' en el contexto de definición variable (%s) en %L no es una variable"
 
-#: fortran/expr.c:5548
+#: fortran/expr.c:5604
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr "Uno que no es POINTER en el contexto de asociación de puntero (%s) en %L"
 
-#: fortran/expr.c:5557
+#: fortran/expr.c:5613
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Named constant '%s' in variable definition context (%s) at %L"
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr "Constante nombrada '%s' en el contexto de definición variable (%s) en %L"
 
-#: fortran/expr.c:5570
+#: fortran/expr.c:5626
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr "LOCK_TYPE en el contexto de definición variable (%s) en %L"
 
-#: fortran/expr.c:5583
+#: fortran/expr.c:5639
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr "LOCK_TYPE en el contexto de definición variable (%s) en %L"
 
-#: fortran/expr.c:5613
+#: fortran/expr.c:5669
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' with INTENT(IN) in pointer association context (%s) at %L"
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr "Argumento dummy '%s' con INTENT(IN) en el contexto de asociación de puntero (%s) en %L"
 
-#: fortran/expr.c:5621
+#: fortran/expr.c:5677
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' with INTENT(IN) in variable definition context (%s) at %L"
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr "Argumento dummy '%s' con INTENT(IN) en el contexto de definición de variable (%s) en %L"
 
-#: fortran/expr.c:5634
+#: fortran/expr.c:5690
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' is PROTECTED and can not appear in a pointer association context (%s) at %L"
 msgid "Variable %qs is PROTECTED and can not appear in a pointer association context (%s) at %L"
 msgstr "La variable '%s' es PROTECTED y no puede aparecer en un contexto de asociación de puntero (%s) en %L"
 
-#: fortran/expr.c:5642
+#: fortran/expr.c:5698
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' is PROTECTED and can not appear in a variable definition context (%s) at %L"
 msgid "Variable %qs is PROTECTED and can not appear in a variable definition context (%s) at %L"
 msgstr "La variable '%s' es PROTECTED y no puede aparecer en un contexto de definición variable (%s) en %L"
 
-#: fortran/expr.c:5654
+#: fortran/expr.c:5710
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' can not appear in a variable definition context (%s) at %L in PURE procedure"
 msgid "Variable %qs can not appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr "La variable '%s' no puede aparecer en un contexto de definición variable (%s) en %L en el procedimiento PURE"
 
-#: fortran/expr.c:5713
+#: fortran/expr.c:5769
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
 msgid "%qs at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
 msgstr "No se puede usar '%s' en %L asociado al objetivo con índice vectorial en un contexto de definición variable (%s)"
 
-#: fortran/expr.c:5717
+#: fortran/expr.c:5773
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L associated to expression can not be used in a variable definition context (%s)"
 msgid "%qs at %L associated to expression can not be used in a variable definition context (%s)"
 msgstr "No se puede usar '%s' en %L asociado a una expresión en un contexto de definición variable (%s)"
 
-#: fortran/expr.c:5728
+#: fortran/expr.c:5784
 #, fuzzy, gcc-internal-format
 #| msgid "Associate-name '%s' can not appear in a variable definition context (%s) at %L because its target at %L can not, either"
 msgid "Associate-name %qs can not appear in a variable definition context (%s) at %L because its target at %L can not, either"
 msgstr "El nombre asociado '%s' no puede aparecer en un contexto de definición variable (%s) en %L porque su obtetivo en %L tampoco puede aparecer"
 
-#: fortran/expr.c:5770
+#: fortran/expr.c:5826
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' at %L associated to expression can not be used in a variable definition context (%s)"
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
@@ -54812,24 +54900,24 @@
 msgid "can't open input file: %s"
 msgstr "no se puede abrir el fichero de entrada: %s"
 
-#: fortran/frontend-passes.c:190
+#: fortran/frontend-passes.c:192
 #, fuzzy, gcc-internal-format
 #| msgid "in statement"
 msgid "No location in statement"
 msgstr "en la sentencia"
 
-#: fortran/frontend-passes.c:205
+#: fortran/frontend-passes.c:207
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected exponent in expression at %C"
 msgid "No location in expression near %L"
 msgstr "Se esperaba un exponente en la expresión en %C"
 
-#: fortran/frontend-passes.c:409
+#: fortran/frontend-passes.c:414
 #, gcc-internal-format
 msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
-#: fortran/frontend-passes.c:817 fortran/trans-array.c:1182
+#: fortran/frontend-passes.c:822 fortran/trans-array.c:1182
 #: fortran/trans-array.c:6440 fortran/trans-array.c:7864
 #: fortran/trans-intrinsic.c:7307
 #, gcc-internal-format, gfc-internal-format
@@ -54836,77 +54924,77 @@
 msgid "Creating array temporary at %L"
 msgstr "Se crea una matriz temporal en %L"
 
-#: fortran/frontend-passes.c:842 fortran/frontend-passes.c:846
+#: fortran/frontend-passes.c:847 fortran/frontend-passes.c:851
 #, fuzzy, gcc-internal-format
 #| msgid "Removing call to function '%s' at %L"
 msgid "Removing call to function %qs at %L"
 msgstr "Se elimina la llamada a la función '%s' en %L"
 
-#: fortran/frontend-passes.c:1273 fortran/frontend-passes.c:1312
+#: fortran/frontend-passes.c:1278 fortran/frontend-passes.c:1317
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "bad expression"
 msgstr "se esperaba una expresión"
 
-#: fortran/frontend-passes.c:1308
+#: fortran/frontend-passes.c:1313
 #, fuzzy, gcc-internal-format
 #| msgid "bad move"
 msgid "bad op"
 msgstr "move erróneo"
 
-#: fortran/frontend-passes.c:2161
+#: fortran/frontend-passes.c:2166
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands in gimple comparison"
 msgid "illegal OP in optimize_comparison"
 msgstr "operandos no válidos en la comparación gimple"
 
-#: fortran/frontend-passes.c:2407
+#: fortran/frontend-passes.c:2412
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgid "Variable %qs at %L set to undefined value inside loop  beginning at %L as INTENT(OUT) argument to subroutine %qs"
 msgstr "La variable '%s' en %C no se puede redefinir dentro del inicio de un bucle en %L"
 
-#: fortran/frontend-passes.c:2414
+#: fortran/frontend-passes.c:2419
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to subroutine %qs"
 msgstr "La variable '%s' en %C no se puede redefinir dentro del inicio de un bucle en %L"
 
-#: fortran/frontend-passes.c:2637 fortran/frontend-passes.c:2661
+#: fortran/frontend-passes.c:2642 fortran/frontend-passes.c:2666
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgid "Array reference at %L out of bounds (%ld < %ld) in loop beginning at %L"
 msgstr "La referencia de matriz en %L está fuera de los límites (%ld < %ld) en la codimensión %d"
 
-#: fortran/frontend-passes.c:2646 fortran/frontend-passes.c:2670
+#: fortran/frontend-passes.c:2651 fortran/frontend-passes.c:2675
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgid "Array reference at %L out of bounds (%ld > %ld) in loop beginning at %L"
 msgstr "La referencia de matriz en %L está fuera de los límites (%ld > %ld) en la codimensión %d"
 
-#: fortran/frontend-passes.c:2730
+#: fortran/frontend-passes.c:2735
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgid "Variable %qs at %L set to undefined value inside loop beginning at %L as INTENT(OUT) argument to function %qs"
 msgstr "La variable '%s' en %C no se puede redefinir dentro del inicio de un bucle en %L"
 
-#: fortran/frontend-passes.c:2736
+#: fortran/frontend-passes.c:2741
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr "La variable '%s' en %C no se puede redefinir dentro del inicio de un bucle en %L"
 
-#: fortran/frontend-passes.c:3128 fortran/trans-expr.c:1581
+#: fortran/frontend-passes.c:3133 fortran/trans-expr.c:1581
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr ""
 
-#: fortran/frontend-passes.c:3637
+#: fortran/frontend-passes.c:3642
 #, gcc-internal-format
 msgid "Scalarization using DIMEN_RANGE unimplemented"
 msgstr ""
 
-#: fortran/frontend-passes.c:4429
+#: fortran/frontend-passes.c:4434
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%<continue%> must be in loop"
 msgid "Interchanging loops at %L"
@@ -55034,12 +55122,12 @@
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "El segundo argumento de la asignación definida en %L debe ser INTENT(IN)"
 
-#: fortran/interface.c:970 fortran/resolve.c:16351
+#: fortran/interface.c:970 fortran/resolve.c:16378
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "El primer argumento de la interfaz de operador en %L debe ser INTENT(IN)"
 
-#: fortran/interface.c:977 fortran/resolve.c:16369
+#: fortran/interface.c:977 fortran/resolve.c:16396
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "El segundo argumento de la interfaz de operador en %L debe ser INTENT(IN)"
@@ -56390,7 +56478,7 @@
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr "El objeto NAMELIST '%s' en la lista de nombres '%s' en %L es polimórfico y requiere un procedimiento de entrada/salida definido"
 
-#: fortran/io.c:3369 fortran/resolve.c:14263
+#: fortran/io.c:3369 fortran/resolve.c:14283
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: NAMELIST object '%s' in namelist '%s' at %L with ALLOCATABLE or POINTER components"
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
@@ -56568,7 +56656,7 @@
 msgid "Integer too large at %C"
 msgstr "Entero demasiado grande en %C"
 
-#: fortran/match.c:580 fortran/parse.c:1132
+#: fortran/match.c:580 fortran/parse.c:1136
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many digits in statement label at %C"
 msgstr "Demasiados dígitos en la declaración de etiqueta en %C"
@@ -57403,58 +57491,58 @@
 msgid "Expected block name %qs of SELECT construct at %C"
 msgstr "Se esperaba el nombre de bloque '%s' de la construcción SELECT en %C"
 
-#: fortran/match.c:6186
+#: fortran/match.c:6201
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in PROTECTED statement at %C"
 msgid "parse error in SELECT TYPE statement at %C"
 msgstr "Error sintáctico en la declaración PROTECTED en %C"
 
-#: fortran/match.c:6211
+#: fortran/match.c:6226
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr "El selector en SELECT TYPE en %C no es una variable nombrada; use nombre-asociado =>"
 
-#: fortran/match.c:6249
+#: fortran/match.c:6264
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr "Declaración CASE inesperada en %C"
 
-#: fortran/match.c:6301
+#: fortran/match.c:6316
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CASE specification at %C"
 msgstr "Error sintáctico en la especificación CASE en %C"
 
-#: fortran/match.c:6319
+#: fortran/match.c:6334
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected TYPE IS statement at %C"
 msgstr "Declaración TYPE IS inesperada en %C"
 
-#: fortran/match.c:6351
+#: fortran/match.c:6366
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr ""
 
-#: fortran/match.c:6362
+#: fortran/match.c:6377
 #, gcc-internal-format, gfc-internal-format
 msgid "All the LEN type parameters in the TYPE IS statement at %C must be ASSUMED"
 msgstr ""
 
-#: fortran/match.c:6373
+#: fortran/match.c:6388
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr "Error sintáctico en la especificación TYPE IS en %C"
 
-#: fortran/match.c:6449
+#: fortran/match.c:6464
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr "Error sintáctico en la especificación CLASS IS en %C"
 
-#: fortran/match.c:6572
+#: fortran/match.c:6587
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr "La declaración ELSEWHERE en %C no está dentro de un bloque WHERE"
 
-#: fortran/match.c:6610
+#: fortran/match.c:6625
 #, fuzzy, gcc-internal-format
 #| msgid "Label '%s' at %C doesn't match WHERE label '%s'"
 msgid "Label %qs at %C doesn't match WHERE label %qs"
@@ -57611,193 +57699,193 @@
 msgid "mio_array_ref(): Unknown array ref"
 msgstr "mio_array_ref(): Referencia de array desconocido"
 
-#: fortran/module.c:3716
+#: fortran/module.c:3718
 #, gcc-internal-format, gfc-internal-format
 msgid "Namelist %s cannot be renamed by USE association to %s"
 msgstr "La lista de nombres %s no se puede renombrar por asociación de USE a %s"
 
-#: fortran/module.c:4832
+#: fortran/module.c:4834
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr "!$OMP DECLARE REDUCTION ambiguo en el módulo %s en %L"
 
-#: fortran/module.c:4835
+#: fortran/module.c:4837
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr "!$OMP DECLARE REDUCTION anterior en el módulo %s en %L"
 
-#: fortran/module.c:5029
+#: fortran/module.c:5031
 #, gcc-internal-format
 msgid "%qs of module %qs, imported at %C, is also the name of the current program unit"
 msgstr "%qs del módulo %qs, importado en %C, es también el nombre de la unidad de programa actual"
 
-#: fortran/module.c:5381
+#: fortran/module.c:5383
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in module %qs"
 msgstr "El símbolo %qs referenciado en %L no se encontró en el módulo %qs"
 
-#: fortran/module.c:5388
+#: fortran/module.c:5390
 #, gcc-internal-format
 msgid "User operator %qs referenced at %L not found in module %qs"
 msgstr "El operador de usuario %qs referenciado en %L no se encontró en el módulo %qs"
 
-#: fortran/module.c:5393
+#: fortran/module.c:5395
 #, gcc-internal-format
 msgid "Intrinsic operator %qs referenced at %L not found in module %qs"
 msgstr "El operador intrínseco %qs referenciado en %L no se encontró en el módulo %qs"
 
-#: fortran/module.c:5628
+#: fortran/module.c:5630
 #, gcc-internal-format
 msgid "write_symbol(): bad module symbol %qs"
 msgstr "write_symbol(): símbolo de módulo %qs incorrecto"
 
-#: fortran/module.c:5961
+#: fortran/module.c:5963
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr "write_symtree(): Símbolo no escrito"
 
-#: fortran/module.c:6148
+#: fortran/module.c:6150
 #, gcc-internal-format
 msgid "Can't open module file %qs for writing at %C: %s"
 msgstr "No se puede abrir el fichero de módulo %qs para escritura en %C: %s"
 
 # El mensaje de error seguramente está mal redactado. cfuga
-#: fortran/module.c:6169
+#: fortran/module.c:6171
 #, gcc-internal-format
 msgid "Error writing module file %qs for writing: %s"
 msgstr "Error al escribir al fichero de módulo %qs para escritura: %s"
 
-#: fortran/module.c:6180
+#: fortran/module.c:6182
 #, gcc-internal-format
 msgid "Can't delete module file %qs: %s"
 msgstr "No se puede borrar el fichero de módulo %qs: %s"
 
-#: fortran/module.c:6183
+#: fortran/module.c:6185
 #, gcc-internal-format
 msgid "Can't rename module file %qs to %qs: %s"
 msgstr "No se puede renombrar el fichero de módulo %qs a %qs: %s"
 
-#: fortran/module.c:6189
+#: fortran/module.c:6191
 #, gcc-internal-format
 msgid "Can't delete temporary module file %qs: %s"
 msgstr "No se puede borrar el fichero de módulo temporal %qs: %s"
 
-#: fortran/module.c:6246
+#: fortran/module.c:6248
 #, gcc-internal-format
 msgid "Symbol %qs at %C already declared"
 msgstr "El símbolo %qs en %C ya se había declarado"
 
-#: fortran/module.c:6317
+#: fortran/module.c:6319
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr "import_iso_c_binding_module(): Imposible crear símbolo para %s"
 
-#: fortran/module.c:6425 fortran/module.c:6769
+#: fortran/module.c:6427 fortran/module.c:6771
 #, gcc-internal-format
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr "El símbolo %qs referenciado en %L, no está en el estándar seleccionado"
 
-#: fortran/module.c:6553
+#: fortran/module.c:6555
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr "El símbolo %qs referenciado en %L no se encontró en el módulo intrínseco ISO_C_BINDING"
 
-#: fortran/module.c:6574 fortran/module.c:6607 fortran/module.c:6649
+#: fortran/module.c:6576 fortran/module.c:6609 fortran/module.c:6651
 #, gcc-internal-format
 msgid "Symbol %qs already declared"
 msgstr "El símbolo %qs ya se había declarado"
 
-#: fortran/module.c:6754
+#: fortran/module.c:6756
 #, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr "El uso del módulo intrínseco %qs en %C tiene conflictos con un nombre de módulo no intrínseco usado previamente"
 
-#: fortran/module.c:6776
+#: fortran/module.c:6778
 #, fuzzy, gcc-internal-format
 #| msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %s"
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr "El uso de la constante nombrada NUMERIC_STORAGE_SIZE del módulo intrínseco ISO_FORTRAN_ENV en %L es incompatible con la opción %s"
 
-#: fortran/module.c:6844
+#: fortran/module.c:6846
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr "El uso de la constante nombrada NUMERIC_STORAGE_SIZE del módulo intrínseco ISO_FORTRAN_ENV en %C es incompatible con la opción %s"
 
-#: fortran/module.c:6898
+#: fortran/module.c:6900
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr "El símbolo '%s' referenciado en %L no se encontró en el módulo intrínseco ISO_FORTRAN_ENV"
 
-#: fortran/module.c:6924
+#: fortran/module.c:6926
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CLOSE statement at %L requires a UNIT number"
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr "La declaración CLOSE en %L requiere un número UNIT"
 
-#: fortran/module.c:6953
+#: fortran/module.c:6955
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ISO_FORTRAN_ENV intrinsic module at %C"
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr "Fortran 2003: Módulo intrínseco ISO_FORTRAN_ENV en %C"
 
-#: fortran/module.c:6965
+#: fortran/module.c:6967
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ISO_C_BINDING module at %C"
 msgid "ISO_C_BINDING module at %C"
 msgstr "Fortran 2003: Módulo ISO_C_BINDING en %C"
 
-#: fortran/module.c:6978
+#: fortran/module.c:6980
 #, fuzzy, gcc-internal-format
 #| msgid "Can't find an intrinsic module named '%s' at %C"
 msgid "Can't find an intrinsic module named %qs at %C"
 msgstr "No se puede encontrar un módulo intrínseco llamado '%s' en %C"
 
-#: fortran/module.c:6984
+#: fortran/module.c:6986
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr ""
 
-#: fortran/module.c:6990
+#: fortran/module.c:6992
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr ""
 
-#: fortran/module.c:6996
+#: fortran/module.c:6998
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr ""
 
-#: fortran/module.c:7006
+#: fortran/module.c:7008
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open module file '%s' for reading at %C: %s"
 msgid "Can't open module file %qs for reading at %C: %s"
 msgstr "No se puede abrir el fichero de módulo '%s' para lectura en %C: %s"
 
-#: fortran/module.c:7009
+#: fortran/module.c:7011
 #, gcc-internal-format
 msgid "Module file %qs has not been generated, either because the module does not contain a MODULE PROCEDURE or there is an error in the module."
 msgstr ""
 
-#: fortran/module.c:7020
+#: fortran/module.c:7022
 #, fuzzy, gcc-internal-format
 #| msgid "Use of non-intrinsic module '%s' at %C conflicts with intrinsic module name used previously"
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr "El uso del módulo '%s' que no es intrínseco en %C tiene conflictos con el nombre del módulo intrínseco usado previamente"
 
-#: fortran/module.c:7043
+#: fortran/module.c:7045
 #, fuzzy, gcc-internal-format
 #| msgid "File '%s' opened at %C is not a GFORTRAN module file"
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr "El fichero '%s' abierto en %C no es un fichero de módulo GFORTRAN"
 
-#: fortran/module.c:7051
+#: fortran/module.c:7053
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr ""
 
 # No se puede hacer el mismo juego de palabras que en inglés. cfuga
-#: fortran/module.c:7066
+#: fortran/module.c:7068
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Can't USE the same module we're building!"
 msgid "Can't USE the same %smodule we're building"
@@ -57804,7 +57892,7 @@
 msgstr "¡No se puede hacer USE del mismo módulo que estamos construyendo!"
 
 #: fortran/openmp.c:296 fortran/openmp.c:397 fortran/openmp.c:692
-#: fortran/openmp.c:3167
+#: fortran/openmp.c:3166
 #, gcc-internal-format, gfc-internal-format
 msgid "COMMON block /%s/ not found at %C"
 msgstr "No se encontró el bloque COMMON /%s/ en %C"
@@ -57892,530 +57980,530 @@
 #: fortran/openmp.c:2180
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid third argument of IBITS at %L"
-msgid "Invalid argument to !$ACC WAIT at %L"
+msgid "Invalid argument to !$ACC WAIT at %C"
 msgstr "Tercer argumento de IBITS no válido en %L"
 
-#: fortran/openmp.c:2188
+#: fortran/openmp.c:2187
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "NUM_THREADS clause at %L requires a scalar INTEGER expression"
 msgid "WAIT clause at %L requires a scalar INTEGER expression"
 msgstr "La cláusula NUM_THREADS en %L requiere una expresión INTEGER escalar"
 
-#: fortran/openmp.c:2221
+#: fortran/openmp.c:2220
 #, gcc-internal-format, gfc-internal-format
 msgid "ACC CACHE directive must be inside of loop %C"
 msgstr ""
 
-#: fortran/openmp.c:2252
+#: fortran/openmp.c:2251
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for typename"
 msgid "Multiple loop axes specified for routine"
 msgstr "se especificó una clase de almacenamiento para el nombre de tipo"
 
-#: fortran/openmp.c:2278
+#: fortran/openmp.c:2277
 #, gcc-internal-format, gfc-internal-format
 msgid "Only the !$ACC ROUTINE form without list is allowed in interface block at %C"
 msgstr ""
 
-#: fortran/openmp.c:2306
+#: fortran/openmp.c:2305
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$ACC ROUTINE ( NAME ) at %C, invalid function name %s"
 msgstr ""
 
-#: fortran/openmp.c:2315
+#: fortran/openmp.c:2314
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgid "Syntax error in !$ACC ROUTINE ( NAME ) at %C"
 msgstr "Error sintáctico en la declaración !GCC$ ATTRIBUTES en %C"
 
-#: fortran/openmp.c:2322
+#: fortran/openmp.c:2321
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$ACC ROUTINE ( NAME ) at %C, expecting ')' after NAME"
 msgstr ""
 
-#: fortran/openmp.c:2457 fortran/openmp.c:2481
+#: fortran/openmp.c:2456 fortran/openmp.c:2480
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP CRITICAL statement at %C"
 msgstr "Basura inesperada después de la declaración $OMP CRITICAL en %C"
 
-#: fortran/openmp.c:2548
+#: fortran/openmp.c:2547
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP FLUSH statement at %C"
 msgstr "Basura inesperada después de la declaración $OMP FLUSH en %C"
 
-#: fortran/openmp.c:2942 fortran/openmp.c:6225
+#: fortran/openmp.c:2941 fortran/openmp.c:6230
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined %s !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2946 fortran/openmp.c:6229
+#: fortran/openmp.c:2945 fortran/openmp.c:6234
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2951
+#: fortran/openmp.c:2950
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2953
+#: fortran/openmp.c:2952
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2973
+#: fortran/openmp.c:2972
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after $OMP ORDERED statement at %C"
 msgid "Unexpected junk after !$OMP DECLARE REDUCTION at %C"
 msgstr "Basura inesperada después de la declaración $OMP ORDERED en %C"
 
-#: fortran/openmp.c:3010
+#: fortran/openmp.c:3009
 #, gcc-internal-format, gfc-internal-format
 msgid "Only the !$OMP DECLARE TARGET form without clauses is allowed in interface block at %C"
 msgstr ""
 
-#: fortran/openmp.c:3025
+#: fortran/openmp.c:3024
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after $OMP ORDERED statement at %C"
 msgid "Unexpected junk after !$OMP DECLARE TARGET at %C"
 msgstr "Basura inesperada después de la declaración $OMP ORDERED en %C"
 
-#: fortran/openmp.c:3048
+#: fortran/openmp.c:3047
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Threadprivate variable at %C is an element of a COMMON block"
 msgid "OMP DECLARE TARGET variable at %L is an element of a COMMON block"
 msgstr "La variable threadprivate en %C es un elemento de un bloque COMMON"
 
-#: fortran/openmp.c:3053
+#: fortran/openmp.c:3052
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET variable at %L previously mentioned in LINK clause and later in TO clause"
 msgstr ""
 
-#: fortran/openmp.c:3059
+#: fortran/openmp.c:3058
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET variable at %L previously mentioned in TO clause and later in LINK clause"
 msgstr ""
 
-#: fortran/openmp.c:3063
+#: fortran/openmp.c:3062
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable at %L mentioned multiple times in clauses of the same OMP DECLARE TARGET directive"
 msgstr ""
 
-#: fortran/openmp.c:3078
+#: fortran/openmp.c:3077
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET COMMON at %L previously mentioned in LINK clause and later in TO clause"
 msgstr ""
 
-#: fortran/openmp.c:3084
+#: fortran/openmp.c:3083
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET COMMON at %L previously mentioned in TO clause and later in LINK clause"
 msgstr ""
 
-#: fortran/openmp.c:3088
+#: fortran/openmp.c:3087
 #, gcc-internal-format, gfc-internal-format
 msgid "COMMON at %L mentioned multiple times in clauses of the same OMP DECLARE TARGET directive"
 msgstr ""
 
-#: fortran/openmp.c:3115
+#: fortran/openmp.c:3114
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in !$OMP THREADPRIVATE list at %C"
 msgid "Syntax error in !$OMP DECLARE TARGET list at %C"
 msgstr "Error sintáctico en la lista !$OMP THREADPRIVATE en %C"
 
-#: fortran/openmp.c:3147
+#: fortran/openmp.c:3146
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate variable at %C is an element of a COMMON block"
 msgstr "La variable threadprivate en %C es un elemento de un bloque COMMON"
 
-#: fortran/openmp.c:3184
+#: fortran/openmp.c:3183
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after $OMP ORDERED statement at %C"
 msgid "Unexpected junk after OMP THREADPRIVATE at %C"
 msgstr "Basura inesperada después de la declaración $OMP ORDERED en %C"
 
-#: fortran/openmp.c:3191
+#: fortran/openmp.c:3190
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$OMP THREADPRIVATE list at %C"
 msgstr "Error sintáctico en la lista !$OMP THREADPRIVATE en %C"
 
-#: fortran/openmp.c:3405
+#: fortran/openmp.c:3404
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after TASKWAIT clause at %C"
 msgstr "Basura inesperada después de la cláusula TASKWAIT en %C"
 
-#: fortran/openmp.c:3419
+#: fortran/openmp.c:3418
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after TASKYIELD clause at %C"
 msgstr "Basura inesperada después de la cláusula TASKYIELD en %C"
 
-#: fortran/openmp.c:3478
+#: fortran/openmp.c:3477
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP WORKSHARE statement at %C"
 msgstr "Basura inesperada después de la declaración $OMP WORKSHARE en %C"
 
-#: fortran/openmp.c:3492
+#: fortran/openmp.c:3491
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP MASTER statement at %C"
 msgstr "Basura inesperada después de la declaración $OMP MASTER en %C"
 
-#: fortran/openmp.c:3551
+#: fortran/openmp.c:3550
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP ATOMIC statement at %C"
 msgstr "Basura inesperada después de la declaración $OMP ATOMIC en %C"
 
-#: fortran/openmp.c:3578
+#: fortran/openmp.c:3577
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP BARRIER statement at %C"
 msgstr "Basura inesperada después de la declaración $OMP BARRIER en %C"
 
-#: fortran/openmp.c:3592
+#: fortran/openmp.c:3591
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after $OMP MASTER statement at %C"
 msgid "Unexpected junk after $OMP TASKGROUP statement at %C"
 msgstr "Basura inesperada después de la declaración $OMP MASTER en %C"
 
-#: fortran/openmp.c:3642
+#: fortran/openmp.c:3641
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after $OMP ATOMIC statement at %C"
 msgid "Unexpected junk after $OMP CANCELLATION POINT statement at %C"
 msgstr "Basura inesperada después de la declaración $OMP ATOMIC en %C"
 
-#: fortran/openmp.c:3662
+#: fortran/openmp.c:3661
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after NOWAIT clause at %C"
 msgstr "Basura inesperada después de la cláusula NOWAIT en %C"
 
-#: fortran/openmp.c:3704
+#: fortran/openmp.c:3703
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "NUM_THREADS clause at %L requires a scalar INTEGER expression"
 msgid "%s clause at %L requires a scalar INTEGER expression"
 msgstr "La cláusula NUM_THREADS en %L requiere una expresión INTEGER escalar"
 
-#: fortran/openmp.c:3715
+#: fortran/openmp.c:3714
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "SIZE at %L must be positive"
 msgid "INTEGER expression of %s clause at %L must be positive"
 msgstr "SIZE en %L debe ser positivo"
 
-#: fortran/openmp.c:3726
+#: fortran/openmp.c:3725
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "SIZE at %L must be positive"
 msgid "INTEGER expression of %s clause at %L must be non-negative"
 msgstr "SIZE en %L debe ser positivo"
 
-#: fortran/openmp.c:3737
+#: fortran/openmp.c:3736
 #, fuzzy, gcc-internal-format
 #| msgid "POINTER object '%s' in %s clause at %L"
 msgid "POINTER object %qs of derived type in %s clause at %L"
 msgstr "El objeto POINTER '%s' en la cláusula %s en %L"
 
-#: fortran/openmp.c:3740
+#: fortran/openmp.c:3739
 #, fuzzy, gcc-internal-format
 #| msgid "Cray pointer '%s' in %s clause at %L"
 msgid "Cray pointer object %qs of derived type in %s clause at %L"
 msgstr "El puntero Cray '%s' en la cláusula %s en %L"
 
-#: fortran/openmp.c:3743
+#: fortran/openmp.c:3742
 #, fuzzy, gcc-internal-format
 #| msgid "Cray pointee '%s' in %s clause at %L"
 msgid "Cray pointee object %qs of derived type in %s clause at %L"
 msgstr "El apuntado Cray '%s' en la cláusula %s en %L"
 
-#: fortran/openmp.c:3749 fortran/openmp.c:4687
+#: fortran/openmp.c:3748 fortran/openmp.c:4686
 #, fuzzy, gcc-internal-format
 #| msgid "POINTER object '%s' in %s clause at %L"
 msgid "POINTER object %qs of polymorphic type in %s clause at %L"
 msgstr "El objeto POINTER '%s' en la cláusula %s en %L"
 
-#: fortran/openmp.c:3754
+#: fortran/openmp.c:3753
 #, fuzzy, gcc-internal-format
 #| msgid "Cray pointer '%s' in %s clause at %L"
 msgid "Cray pointer object %qs of polymorphic type in %s clause at %L"
 msgstr "El puntero Cray '%s' en la cláusula %s en %L"
 
-#: fortran/openmp.c:3759
+#: fortran/openmp.c:3758
 #, fuzzy, gcc-internal-format
 #| msgid "Cray pointee '%s' in %s clause at %L"
 msgid "Cray pointee object %qs of polymorphic type in %s clause at %L"
 msgstr "El apuntado Cray '%s' en la cláusula %s en %L"
 
-#: fortran/openmp.c:3769 fortran/openmp.c:4385 fortran/openmp.c:4490
+#: fortran/openmp.c:3768 fortran/openmp.c:4384 fortran/openmp.c:4489
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed size array '%s' in %s clause at %L"
 msgid "Assumed size array %qs in %s clause at %L"
 msgstr "Matriz de tamaño asumido '%s' en la cláusula %s en %L"
 
-#: fortran/openmp.c:3772
+#: fortran/openmp.c:3771
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed size array '%s' in %s clause at %L"
 msgid "Assumed rank array %qs in %s clause at %L"
 msgstr "Matriz de tamaño asumido '%s' en la cláusula %s en %L"
 
-#: fortran/openmp.c:3776
+#: fortran/openmp.c:3775
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed size array '%s' in %s clause at %L"
 msgid "Noncontiguous deferred shape array %qs in %s clause at %L"
 msgstr "Matriz de tamaño asumido '%s' en la cláusula %s en %L"
 
-#: fortran/openmp.c:3784
+#: fortran/openmp.c:3783
 #, fuzzy, gcc-internal-format
 #| msgid "POINTER object '%s' in %s clause at %L"
 msgid "ALLOCATABLE object %qs of derived type in %s clause at %L"
 msgstr "El objeto POINTER '%s' en la cláusula %s en %L"
 
-#: fortran/openmp.c:3789
+#: fortran/openmp.c:3788
 #, fuzzy, gcc-internal-format
 #| msgid "POINTER object '%s' in %s clause at %L"
 msgid "ALLOCATABLE object %qs of polymorphic type in %s clause at %L"
 msgstr "El objeto POINTER '%s' en la cláusula %s en %L"
 
-#: fortran/openmp.c:3801 fortran/openmp.c:4480
+#: fortran/openmp.c:3800 fortran/openmp.c:4479
 #, fuzzy, gcc-internal-format
 #| msgid "POINTER object '%s' in %s clause at %L"
 msgid "POINTER object %qs in %s clause at %L"
 msgstr "El objeto POINTER '%s' en la cláusula %s en %L"
 
-#: fortran/openmp.c:3806 fortran/openmp.c:4691
+#: fortran/openmp.c:3805 fortran/openmp.c:4690
 #, fuzzy, gcc-internal-format
 #| msgid "Cray pointer '%s' in %s clause at %L"
 msgid "Cray pointer object %qs in %s clause at %L"
 msgstr "El puntero Cray '%s' en la cláusula %s en %L"
 
-#: fortran/openmp.c:3811 fortran/openmp.c:4694
+#: fortran/openmp.c:3810 fortran/openmp.c:4693
 #, fuzzy, gcc-internal-format
 #| msgid "Cray pointee '%s' in %s clause at %L"
 msgid "Cray pointee object %qs in %s clause at %L"
 msgstr "El apuntado Cray '%s' en la cláusula %s en %L"
 
-#: fortran/openmp.c:3816 fortran/openmp.c:4682
+#: fortran/openmp.c:3815 fortran/openmp.c:4681
 #, fuzzy, gcc-internal-format
 #| msgid "POINTER object '%s' in %s clause at %L"
 msgid "ALLOCATABLE object %qs in %s clause at %L"
 msgstr "El objeto POINTER '%s' en la cláusula %s en %L"
 
-#: fortran/openmp.c:3819
+#: fortran/openmp.c:3818
 #, fuzzy, gcc-internal-format
 #| msgid "POINTER object '%s' in %s clause at %L"
 msgid "VALUE object %qs in %s clause at %L"
 msgstr "El objeto POINTER '%s' en la cláusula %s en %L"
 
-#: fortran/openmp.c:3862
+#: fortran/openmp.c:3861
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after $OMP ORDERED statement at %C"
 msgid "Implicitly declared function %s used in !$OMP DECLARE REDUCTION at %L"
 msgstr "Basura inesperada después de la declaración $OMP ORDERED en %C"
 
-#: fortran/openmp.c:3911
+#: fortran/openmp.c:3910
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after $OMP ORDERED statement at %C"
 msgid "Implicitly declared subroutine %s used in !$OMP DECLARE REDUCTION at %L"
 msgstr "Basura inesperada después de la declaración $OMP ORDERED en %C"
 
-#: fortran/openmp.c:3944
+#: fortran/openmp.c:3943
 #, gcc-internal-format, gfc-internal-format
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:3952 fortran/openmp.c:3963 fortran/resolve.c:10028
-#: fortran/resolve.c:11295
+#: fortran/openmp.c:3951 fortran/openmp.c:3962 fortran/resolve.c:10041
+#: fortran/resolve.c:11315
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "La cláusula IF en %L requiere una expresión LOGICAL escalar"
 
-#: fortran/openmp.c:3967
+#: fortran/openmp.c:3966
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause without modifier at %L used together with IF clauses with modifiers"
 msgstr ""
 
-#: fortran/openmp.c:4044
+#: fortran/openmp.c:4043
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause modifier %s at %L not appropriate for the current OpenMP construct"
 msgstr ""
 
-#: fortran/openmp.c:4054
+#: fortran/openmp.c:4053
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL clause at %L requires a scalar LOGICAL expression"
 msgstr "La cláusula FINAL en %L requiere una expresión LOGICAL escalar"
 
-#: fortran/openmp.c:4064
+#: fortran/openmp.c:4063
 #, gcc-internal-format, gfc-internal-format
 msgid "SCHEDULE clause's chunk_size at %L requires a scalar INTEGER expression"
 msgstr "El chunk_size de la cláusula SCHEDULE en %L requiere una expresión INTEGER escalar"
 
-#: fortran/openmp.c:4069
+#: fortran/openmp.c:4068
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "SIZE at %L must be positive"
 msgid "INTEGER expression of SCHEDULE clause's chunk_size at %L must be positive"
 msgstr "SIZE en %L debe ser positivo"
 
-#: fortran/openmp.c:4084
+#: fortran/openmp.c:4083
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' has not been assigned a target label at %L"
 msgid "Variable %qs is not a dummy argument at %L"
 msgstr "La variable '%s' no se ha asignado a una etiqueta objetivo en %L"
 
-#: fortran/openmp.c:4116
+#: fortran/openmp.c:4115 fortran/openmp.c:5998
 #, fuzzy, gcc-internal-format
 #| msgid "Object '%s' is not a variable at %L"
 msgid "Object %qs is not a variable at %L"
 msgstr "El objeto '%s' no es una variable en %L"
 
-#: fortran/openmp.c:4132 fortran/openmp.c:4143 fortran/openmp.c:4151
-#: fortran/openmp.c:4162 fortran/openmp.c:4174 fortran/openmp.c:4189
-#: fortran/openmp.c:6023
+#: fortran/openmp.c:4131 fortran/openmp.c:4142 fortran/openmp.c:4150
+#: fortran/openmp.c:4161 fortran/openmp.c:4173 fortran/openmp.c:4188
+#: fortran/openmp.c:6028
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' present on multiple clauses at %L"
 msgid "Symbol %qs present on multiple clauses at %L"
 msgstr "El símbolo '%s' está presente en múltiples cláusulas en %L"
 
-#: fortran/openmp.c:4196
+#: fortran/openmp.c:4195
 #, fuzzy, gcc-internal-format
 #| msgid "Array section not permitted in '%s' call at %L"
 msgid "Array %qs is not permitted in reduction at %L"
 msgstr "No se permite una sección de matriz en la llamada '%s' en %L"
 
-#: fortran/openmp.c:4209
+#: fortran/openmp.c:4208
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' present on multiple clauses at %L"
 msgid "Symbol %qs present on both FROM and TO clauses at %L"
 msgstr "El símbolo '%s' está presente en múltiples cláusulas en %L"
 
-#: fortran/openmp.c:4231
+#: fortran/openmp.c:4230
 #, fuzzy, gcc-internal-format
 #| msgid "Non-THREADPRIVATE object '%s' in COPYIN clause at %L"
 msgid "Non-THREADPRIVATE object %qs in COPYIN clause at %L"
 msgstr "El objeto que no es THREADPRIVATE '%s' en la cláusula COPYIN en %L"
 
-#: fortran/openmp.c:4239
+#: fortran/openmp.c:4238
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed size array '%s' in COPYPRIVATE clause at %L"
 msgid "Assumed size array %qs in COPYPRIVATE clause at %L"
 msgstr "Matriz de tamaño asumido '%s' en la cláusula COPYPRIVATE en %L"
 
-#: fortran/openmp.c:4242
+#: fortran/openmp.c:4241
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed size array '%s' in COPYPRIVATE clause at %L"
 msgid "INTENT(IN) POINTER %qs in COPYPRIVATE clause at %L"
 msgstr "Matriz de tamaño asumido '%s' en la cláusula COPYPRIVATE en %L"
 
-#: fortran/openmp.c:4250
+#: fortran/openmp.c:4249
 #, fuzzy, gcc-internal-format
 #| msgid "THREADPRIVATE object '%s' in SHARED clause at %L"
 msgid "THREADPRIVATE object %qs in SHARED clause at %L"
 msgstr "El objeto THREADPRIVATE '%s' en la cláusula SHARED en %L"
 
-#: fortran/openmp.c:4253
+#: fortran/openmp.c:4252
 #, fuzzy, gcc-internal-format
 #| msgid "Cray pointee '%s' in SHARED clause at %L"
 msgid "Cray pointee %qs in SHARED clause at %L"
 msgstr "El apuntado Cray '%s' en la cláusula SHARED en %L"
 
-#: fortran/openmp.c:4256
+#: fortran/openmp.c:4255
 #, fuzzy, gcc-internal-format
 #| msgid "THREADPRIVATE object '%s' in SHARED clause at %L"
 msgid "ASSOCIATE name %qs in SHARED clause at %L"
 msgstr "El objeto THREADPRIVATE '%s' en la cláusula SHARED en %L"
 
-#: fortran/openmp.c:4271
+#: fortran/openmp.c:4270
 #, gcc-internal-format
 msgid "%qs in ALIGNED clause must be POINTER, ALLOCATABLE, Cray pointer or C_PTR at %L"
 msgstr ""
 
-#: fortran/openmp.c:4283
+#: fortran/openmp.c:4282
 #, fuzzy, gcc-internal-format
 #| msgid "%Hcollapse argument needs positive constant integer expression"
 msgid "%qs in ALIGNED clause at %L requires a scalar positive constant integer alignment expression"
 msgstr "%Hel argumento de collapse necesita ser una expresión entera constante positiva"
 
-#: fortran/openmp.c:4302
+#: fortran/openmp.c:4301
 #, gcc-internal-format, gfc-internal-format
 msgid "SINK dependence type only allowed on ORDERED directive at %L"
 msgstr ""
 
-#: fortran/openmp.c:4306
+#: fortran/openmp.c:4305
 #, gcc-internal-format, gfc-internal-format
 msgid "DEPEND SINK used together with DEPEND SOURCE on the same construct at %L"
 msgstr ""
 
-#: fortran/openmp.c:4316
+#: fortran/openmp.c:4315
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "accumulator is not a constant integer"
 msgid "SINK addend not a constant integer at %L"
 msgstr "el acumulador no es una constante entera"
 
-#: fortran/openmp.c:4322
+#: fortran/openmp.c:4321
 #, gcc-internal-format, gfc-internal-format
 msgid "Only SOURCE or SINK dependence types are allowed on ORDERED directive at %L"
 msgstr ""
 
-#: fortran/openmp.c:4333 fortran/openmp.c:4354
+#: fortran/openmp.c:4332 fortran/openmp.c:4353
 #, gcc-internal-format
 msgid "%qs in %s clause at %L is not a proper array section"
 msgstr ""
 
-#: fortran/openmp.c:4337
+#: fortran/openmp.c:4336
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Cray pointee '%s' in %s clause at %L"
 msgid "Coarrays not supported in %s clause at %L"
 msgstr "El apuntado Cray '%s' en la cláusula %s en %L"
 
-#: fortran/openmp.c:4346
+#: fortran/openmp.c:4345
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed size array '%s' in %s clause at %L"
 msgid "Stride should not be specified for array section in %s clause at %L"
 msgstr "Matriz de tamaño asumido '%s' en la cláusula %s en %L"
 
-#: fortran/openmp.c:4367
+#: fortran/openmp.c:4366
 #, gcc-internal-format
 msgid "%qs in DEPEND clause at %L is a zero size array section"
 msgstr ""
 
-#: fortran/openmp.c:4403
+#: fortran/openmp.c:4402
 #, gcc-internal-format, gfc-internal-format
 msgid "TARGET%s with map-type other than TO, FROM, TOFROM, or ALLOC on MAP clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4419
+#: fortran/openmp.c:4418
 #, gcc-internal-format, gfc-internal-format
 msgid "TARGET ENTER DATA with map-type other than TO, or ALLOC on MAP clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4434
+#: fortran/openmp.c:4433
 #, gcc-internal-format, gfc-internal-format
 msgid "TARGET EXIT DATA with map-type other than FROM, RELEASE, or DELETE on MAP clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4450 fortran/openmp.c:4466
+#: fortran/openmp.c:4449 fortran/openmp.c:4465
 #, fuzzy, gcc-internal-format
 #| msgid "THREADPRIVATE object '%s' in %s clause at %L"
 msgid "THREADPRIVATE object %qs in %s clause at %L"
 msgstr "El objeto THREADPRIVATE '%s' en la cláusula %s en %L"
 
-#: fortran/openmp.c:4453 fortran/openmp.c:4469
+#: fortran/openmp.c:4452 fortran/openmp.c:4468
 #, fuzzy, gcc-internal-format
 #| msgid "Cray pointee '%s' in %s clause at %L"
 msgid "Cray pointee %qs in %s clause at %L"
 msgstr "El apuntado Cray '%s' en la cláusula %s en %L"
 
-#: fortran/openmp.c:4472
+#: fortran/openmp.c:4471
 #, fuzzy, gcc-internal-format
 #| msgid "POINTER object '%s' in %s clause at %L"
 msgid "ASSOCIATE name %qs in %s clause at %L"
 msgstr "El objeto POINTER '%s' en la cláusula %s en %L"
 
-#: fortran/openmp.c:4477
+#: fortran/openmp.c:4476
 #, fuzzy, gcc-internal-format
 #| msgid "Cray pointer '%s' in %s clause at %L"
 msgid "Procedure pointer %qs in %s clause at %L"
 msgstr "El puntero Cray '%s' en la cláusula %s en %L"
 
-#: fortran/openmp.c:4483
+#: fortran/openmp.c:4482
 #, fuzzy, gcc-internal-format
 #| msgid "Cray pointer '%s' in %s clause at %L"
 msgid "Cray pointer %qs in %s clause at %L"
 msgstr "El puntero Cray '%s' en la cláusula %s en %L"
 
-#: fortran/openmp.c:4493
+#: fortran/openmp.c:4492
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' in %s clause is used in NAMELIST statement at %L"
 msgid "Variable %qs in %s clause is used in NAMELIST statement at %L"
@@ -58422,420 +58510,420 @@
 msgstr "Se usó la variable '%s' en la cláusula %s en la declaración NAMELIST en %L"
 
 #. case OMP_LIST_REDUCTION:
-#: fortran/openmp.c:4503
+#: fortran/openmp.c:4502
 #, fuzzy, gcc-internal-format
 #| msgid "POINTER object '%s' in %s clause at %L"
 msgid "INTENT(IN) POINTER %qs in %s clause at %L"
 msgstr "El objeto POINTER '%s' en la cláusula %s en %L"
 
-#: fortran/openmp.c:4596
+#: fortran/openmp.c:4595
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP DECLARE REDUCTION %s not found for type %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:4622
+#: fortran/openmp.c:4621
 #, gcc-internal-format, gfc-internal-format
 msgid "LINEAR clause modifier used on DO or SIMD construct at %L"
 msgstr ""
 
-#: fortran/openmp.c:4627
+#: fortran/openmp.c:4626
 #, gcc-internal-format, gfc-internal-format
 msgid "LINEAR clause specified together with ORDERED clause with argument at %L"
 msgstr ""
 
-#: fortran/openmp.c:4632
+#: fortran/openmp.c:4631
 #, fuzzy, gcc-internal-format
 #| msgid "%s REDUCTION variable '%s' must be INTEGER at %L"
 msgid "LINEAR variable %qs must be INTEGER at %L"
 msgstr "La variable REDUCTION %s '%s' debe ser INTEGER en %L"
 
-#: fortran/openmp.c:4637
+#: fortran/openmp.c:4636
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "LINEAR dummy argument %qs with VALUE attribute with %s modifier at %L"
 msgstr "El argumento actual para '%s' debe ser un puntero en %L"
 
-#: fortran/openmp.c:4648
+#: fortran/openmp.c:4647
 #, fuzzy, gcc-internal-format
 #| msgid "FINAL clause at %L requires a scalar LOGICAL expression"
 msgid "%qs in LINEAR clause at %L requires a scalar integer linear-step expression"
 msgstr "La cláusula FINAL en %L requiere una expresión LOGICAL escalar"
 
-#: fortran/openmp.c:4665
+#: fortran/openmp.c:4664
 #, fuzzy, gcc-internal-format
 #| msgid "FINAL clause at %L requires a scalar LOGICAL expression"
 msgid "%qs in LINEAR clause at %L requires a constant integer linear-step expression or dummy argument specified in UNIFORM clause"
 msgstr "La cláusula FINAL en %L requiere una expresión LOGICAL escalar"
 
-#: fortran/openmp.c:4699
+#: fortran/openmp.c:4698
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%s clause variable %qs at %L is neither a POINTER nor an array"
 msgstr "el tipo de vector delete no es del tipo puntero ni matriz"
 
-#: fortran/openmp.c:4731
+#: fortran/openmp.c:4730
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "SCHEDULE clause's chunk_size at %L requires a scalar INTEGER expression"
 msgid "DIST_SCHEDULE clause's chunk_size at %L requires a scalar INTEGER expression"
 msgstr "El chunk_size de la cláusula SCHEDULE en %L requiere una expresión INTEGER escalar"
 
-#: fortran/openmp.c:4763
+#: fortran/openmp.c:4762
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Incompatible ranks in %s (%d and %d) at %L"
 msgid "Incompatible use of TILE and COLLAPSE at %L"
 msgstr "Rangos incompatibles en %s (%d y %d) en %L"
 
-#: fortran/openmp.c:4765
+#: fortran/openmp.c:4764
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE dependence type only allowed on ORDERED directive at %L"
 msgstr ""
 
-#: fortran/openmp.c:4778
+#: fortran/openmp.c:4777
 #, gcc-internal-format, gfc-internal-format
 msgid "%s must contain at least one MAP clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4875
+#: fortran/openmp.c:4874
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after $OMP ATOMIC statement at %C"
 msgid "unexpected !$OMP ATOMIC expression at %L"
 msgstr "Basura inesperada después de la declaración $OMP ATOMIC en %C"
 
-#: fortran/openmp.c:4904
+#: fortran/openmp.c:4903
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC statement must set a scalar variable of intrinsic type at %L"
 msgstr "La declaración !$OMP ATOMIC debe definir una variable escalar de tipo intrínseco en %L"
 
-#: fortran/openmp.c:4929
+#: fortran/openmp.c:4928
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC READ statement must read from a scalar variable of intrinsic type at %L"
 msgstr "La declaración !$OMP ATOMIC READ debe leer de una variable escalar de tipo intrínseco en %L"
 
-#: fortran/openmp.c:4934
+#: fortran/openmp.c:4933
 #, gcc-internal-format, gfc-internal-format
 msgid "expr in !$OMP ATOMIC WRITE assignment var = expr must be scalar and cannot reference var at %L"
 msgstr "expr en la asignación !$OMP ATOMIC WRITE var =  expr debe ser escalar y no puede referenciar a var en %L"
 
-#: fortran/openmp.c:4956 fortran/openmp.c:5247
+#: fortran/openmp.c:4955 fortran/openmp.c:5246
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE capture statement must read from a scalar variable of intrinsic type at %L"
 msgstr "La declaración de captura !$OMP ATOMIC CAPTURE debe leer de una variable escalar de tipo intrínseco en %L"
 
-#: fortran/openmp.c:4971
+#: fortran/openmp.c:4970
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE update statement must set a scalar variable of intrinsic type at %L"
 msgstr "La declaración de actualización !$OMP ATOMIC CAPTURE debe definir una variable escalar de tipo intrínseco en %L"
 
-#: fortran/openmp.c:4978 fortran/openmp.c:5254
+#: fortran/openmp.c:4977 fortran/openmp.c:5253
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE capture statement reads from different variable than update statement writes into at %L"
 msgstr "La declaración de captura !$OMP ATOMIC CAPTURE lee de una variable diferente a la que escribe la declaración de captura en %L"
 
-#: fortran/openmp.c:4994
+#: fortran/openmp.c:4993
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC with ALLOCATABLE variable at %L"
 msgstr ""
 
-#: fortran/openmp.c:5036
+#: fortran/openmp.c:5035
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "!$OMP ATOMIC assignment operator must be +, *, -, /, .AND., .OR., .EQV. or .NEQV. at %L"
 msgid "!$OMP ATOMIC assignment operator must be binary +, *, -, /, .AND., .OR., .EQV. or .NEQV. at %L"
 msgstr "El operador de la asignación !$OMP ATOMIC debe ser +, -, /, .AND., .OR., .EQV. ó .NEQV. en %L"
 
-#: fortran/openmp.c:5084
+#: fortran/openmp.c:5083
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment must be var = var op expr or var = expr op var at %L"
 msgstr "El operador de la asignación !$OMP ATOMIC debe ser var = var op expr ó var = expr op var en %L"
 
-#: fortran/openmp.c:5098
+#: fortran/openmp.c:5097
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC var = var op expr not mathematically equivalent to var = var op (expr) at %L"
 msgstr "!$OMP ATOMIC var = var op expr no es matemáticamente equivalente a var = var op (expr) en %L"
 
-#: fortran/openmp.c:5130
+#: fortran/openmp.c:5129
 #, gcc-internal-format, gfc-internal-format
 msgid "expr in !$OMP ATOMIC assignment var = var op expr must be scalar and cannot reference var at %L"
 msgstr "expr en la asignación !$OMP ATOMIC var = var op expr debe ser escalar y no puede referenciar a var en %L"
 
-#: fortran/openmp.c:5154
+#: fortran/openmp.c:5153
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment intrinsic IAND, IOR or IEOR must have two arguments at %L"
 msgstr "El intrínseco IAND, IOR ó IEOR de la asignación !$OMP ATOMIC debe tener dos argumentos en %L"
 
-#: fortran/openmp.c:5161
+#: fortran/openmp.c:5160
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment intrinsic must be MIN, MAX, IAND, IOR or IEOR at %L"
 msgstr "El intrínseco de la asignación !$OMP ATOMIC debe ser MIN, MAX, IAND, IOR ó IEOR en %L"
 
-#: fortran/openmp.c:5178
+#: fortran/openmp.c:5177
 #, fuzzy, gcc-internal-format
 #| msgid "!$OMP ATOMIC intrinsic arguments except one must not reference '%s' at %L"
 msgid "!$OMP ATOMIC intrinsic arguments except one must not reference %qs at %L"
 msgstr "Los argumentos del intrínseco !$OMP ATOMIC, excepto uno, no deben referenciar a '%s' en %L"
 
-#: fortran/openmp.c:5185
+#: fortran/openmp.c:5184
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC intrinsic arguments must be scalar at %L"
 msgstr "Los argumentos del intrínseco !$OMP ATOMIC deben ser escalares en %L"
 
-#: fortran/openmp.c:5193
+#: fortran/openmp.c:5192
 #, fuzzy, gcc-internal-format
 #| msgid "First or last !$OMP ATOMIC intrinsic argument must be '%s' at %L"
 msgid "First or last !$OMP ATOMIC intrinsic argument must be %qs at %L"
 msgstr "El primer o último argumentos del intrínseco !$OMP ATOMIC deben ser '%s' en %L"
 
-#: fortran/openmp.c:5211
+#: fortran/openmp.c:5210
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment must have an operator or intrinsic on right hand side at %L"
 msgstr "La asignación !$OMP ATOMIC debe tener un operador o intrínseco del lado derecho en %L"
 
-#: fortran/openmp.c:5225
+#: fortran/openmp.c:5224
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE capture statement must set a scalar variable of intrinsic type at %L"
 msgstr "La declaración de captura !$OMP ATOMIC CAPTURE debe definir una variable escalar de tipo intrínseco en %L"
 
-#: fortran/openmp.c:5544
+#: fortran/openmp.c:5543
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "!$OMP DO cannot be a DO WHILE or DO without loop control at %L"
 msgid "%s cannot be a DO WHILE or DO without loop control at %L"
 msgstr "!$OMP DO no puede ser un DO WHILE ó DO sin control de bucle en %L"
 
-#: fortran/openmp.c:5550
+#: fortran/openmp.c:5549
 #, gcc-internal-format, gfc-internal-format
 msgid "%s cannot be a DO CONCURRENT loop at %L"
 msgstr ""
 
-#: fortran/openmp.c:5556
+#: fortran/openmp.c:5555
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "!$OMP DO iteration variable must be of type integer at %L"
 msgid "%s iteration variable must be of type integer at %L"
 msgstr "La variable de iteración !$OMP DO debe ser de tipo entero en %L"
 
-#: fortran/openmp.c:5560
+#: fortran/openmp.c:5559
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "!$OMP DO iteration variable must not be THREADPRIVATE at %L"
 msgid "%s iteration variable must not be THREADPRIVATE at %L"
 msgstr "La variable de iteración !$OMP DO no puede ser THREADPRIVATE en %L"
 
-#: fortran/openmp.c:5573
+#: fortran/openmp.c:5572
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "!$OMP DO iteration variable present on clause other than PRIVATE or LASTPRIVATE at %L"
 msgid "%s iteration variable present on clause other than PRIVATE or LASTPRIVATE at %L"
 msgstr "La variable de iteración !$OMP DO está presente en una cláusula diferente de PRIVATE o LASTPRIVATE en %L"
 
-#: fortran/openmp.c:5577
+#: fortran/openmp.c:5576
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "!$OMP DO iteration variable present on clause other than PRIVATE or LASTPRIVATE at %L"
 msgid "%s iteration variable present on clause other than LASTPRIVATE at %L"
 msgstr "La variable de iteración !$OMP DO está presente en una cláusula diferente de PRIVATE o LASTPRIVATE en %L"
 
-#: fortran/openmp.c:5581
+#: fortran/openmp.c:5580
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "!$OMP DO iteration variable present on clause other than PRIVATE or LASTPRIVATE at %L"
 msgid "%s iteration variable present on clause other than LINEAR at %L"
 msgstr "La variable de iteración !$OMP DO está presente en una cláusula diferente de PRIVATE o LASTPRIVATE en %L"
 
-#: fortran/openmp.c:5599
+#: fortran/openmp.c:5598
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "!$OMP DO collapsed loops don't form rectangular iteration space at %L"
 msgid "%s collapsed loops don't form rectangular iteration space at %L"
 msgstr "Los bucles !$OMP DO colapsados no forman un espacio de iteración rectangular en %L"
 
-#: fortran/openmp.c:5611
+#: fortran/openmp.c:5610
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "collapsed !$OMP DO loops not perfectly nested at %L"
 msgid "collapsed %s loops not perfectly nested at %L"
 msgstr "Los bucles !$OMP DO colapsados no están perfectamente anidados en %L"
 
-#: fortran/openmp.c:5620 fortran/openmp.c:5628
+#: fortran/openmp.c:5619 fortran/openmp.c:5627
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "not enough DO loops for collapsed !$OMP DO at %L"
 msgid "not enough DO loops for collapsed %s at %L"
 msgstr "no hay suficientes bucles DO para los !$OMP DO colapsados en %L"
 
-#: fortran/openmp.c:5712 fortran/openmp.c:5725
+#: fortran/openmp.c:5711 fortran/openmp.c:5724
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "A format cannot be specified with a namelist"
 msgid "The %s directive cannot be specified within a %s region at %L"
 msgstr "No se puede especificar un formato con una lista de nombres"
 
-#: fortran/openmp.c:5744
+#: fortran/openmp.c:5743
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "!$OMP DO cannot be a DO WHILE or DO without loop control at %L"
 msgid "!$ACC LOOP cannot be a DO WHILE or DO without loop control at %L"
 msgstr "!$OMP DO no puede ser un DO WHILE ó DO sin control de bucle en %L"
 
-#: fortran/openmp.c:5750
+#: fortran/openmp.c:5749
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "!$OMP DO iteration variable must be of type integer at %L"
 msgid "!$ACC LOOP iteration variable must be of type integer at %L"
 msgstr "La variable de iteración !$OMP DO debe ser de tipo entero en %L"
 
-#: fortran/openmp.c:5766
+#: fortran/openmp.c:5765
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "!$OMP DO collapsed loops don't form rectangular iteration space at %L"
 msgid "!$ACC LOOP %s loops don't form rectangular iteration space at %L"
 msgstr "Los bucles !$OMP DO colapsados no forman un espacio de iteración rectangular en %L"
 
-#: fortran/openmp.c:5778
+#: fortran/openmp.c:5777
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "collapsed !$OMP DO loops not perfectly nested at %L"
 msgid "%s !$ACC LOOP loops not perfectly nested at %L"
 msgstr "Los bucles !$OMP DO colapsados no están perfectamente anidados en %L"
 
-#: fortran/openmp.c:5788 fortran/openmp.c:5797
+#: fortran/openmp.c:5787 fortran/openmp.c:5796
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "not enough DO loops for collapsed !$OMP DO at %L"
 msgid "not enough DO loops for %s !$ACC LOOP at %L"
 msgstr "no hay suficientes bucles DO para los !$OMP DO colapsados en %L"
 
-#: fortran/openmp.c:5812 fortran/openmp.c:5819
+#: fortran/openmp.c:5811 fortran/openmp.c:5818
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s in PARALLEL region doesn't allow %s arguments at %L"
 msgstr ""
 
-#: fortran/openmp.c:5841
+#: fortran/openmp.c:5840
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside another loop parallelized across gangs at %L"
 msgstr ""
 
-#: fortran/openmp.c:5845 fortran/openmp.c:5849
+#: fortran/openmp.c:5844 fortran/openmp.c:5848
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside loop parallelized across workers at %L"
 msgstr ""
 
-#: fortran/openmp.c:5856
+#: fortran/openmp.c:5855
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across workers at %L"
 msgstr ""
 
-#: fortran/openmp.c:5860
+#: fortran/openmp.c:5859
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across vectors at %L"
 msgstr ""
 
-#: fortran/openmp.c:5866
+#: fortran/openmp.c:5865
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across vectors is not allowed inside another loop parallelized across vectors at %L"
 msgstr ""
 
-#: fortran/openmp.c:5878
+#: fortran/openmp.c:5877
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgid "Clause SEQ conflicts with INDEPENDENT at %L"
 msgstr "INTENT (%s) genera un conflicto con INTENT(%s) en %L"
 
-#: fortran/openmp.c:5880
+#: fortran/openmp.c:5879
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "Clause SEQ conflicts with GANG at %L"
 msgstr "El atributo %s genera un conflicto con el atributo %s en %L"
 
-#: fortran/openmp.c:5882
+#: fortran/openmp.c:5881
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "MOLD tag at %L conflicts with SOURCE tag at %L"
 msgid "Clause SEQ conflicts with WORKER at %L"
 msgstr "La etiqueta MOLD en %L tiene conflictos con la etiqueta SOURCE en %L"
 
-#: fortran/openmp.c:5884
+#: fortran/openmp.c:5883
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "MOLD tag at %L conflicts with SOURCE tag at %L"
 msgid "Clause SEQ conflicts with VECTOR at %L"
 msgstr "La etiqueta MOLD en %L tiene conflictos con la etiqueta SOURCE en %L"
 
-#: fortran/openmp.c:5886
+#: fortran/openmp.c:5885
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "MOLD tag at %L conflicts with SOURCE tag at %L"
 msgid "Clause SEQ conflicts with AUTO at %L"
 msgstr "La etiqueta MOLD en %L tiene conflictos con la etiqueta SOURCE en %L"
 
-#: fortran/openmp.c:5891
+#: fortran/openmp.c:5890
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "Clause AUTO conflicts with GANG at %L"
 msgstr "El atributo %s genera un conflicto con el atributo %s en %L"
 
-#: fortran/openmp.c:5893
+#: fortran/openmp.c:5892
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "MOLD tag at %L conflicts with SOURCE tag at %L"
 msgid "Clause AUTO conflicts with WORKER at %L"
 msgstr "La etiqueta MOLD en %L tiene conflictos con la etiqueta SOURCE en %L"
 
-#: fortran/openmp.c:5895
+#: fortran/openmp.c:5894
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "MOLD tag at %L conflicts with SOURCE tag at %L"
 msgid "Clause AUTO conflicts with VECTOR at %L"
 msgstr "La etiqueta MOLD en %L tiene conflictos con la etiqueta SOURCE en %L"
 
-#: fortran/openmp.c:5899
+#: fortran/openmp.c:5898
 #, gcc-internal-format, gfc-internal-format
 msgid "Tiled loop cannot be parallelized across gangs, workers and vectors at the same time at %L"
 msgstr ""
 
-#: fortran/openmp.c:5934
+#: fortran/openmp.c:5933
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "TILE requires constant expression at %L"
 msgstr "%qE no es una expresión constante"
 
-#: fortran/openmp.c:5999
+#: fortran/openmp.c:6004
 #, fuzzy, gcc-internal-format
 #| msgid "POINTER object '%s' in %s clause at %L"
 msgid "PARAMETER object %qs is not allowed at %L"
 msgstr "El objeto POINTER '%s' en la cláusula %s en %L"
 
-#: fortran/openmp.c:6006
+#: fortran/openmp.c:6011
 #, fuzzy, gcc-internal-format
 #| msgid "action not allowed in SPEC MODULE"
 msgid "Array sections: %qs not allowed in !$ACC DECLARE at %L"
 msgstr "no se pertite una acción en SPEC MODULE"
 
-#: fortran/openmp.c:6133
+#: fortran/openmp.c:6138
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP TARGET UPDATE at %L requires at least one TO or FROM clause"
 msgstr ""
 
-#: fortran/openmp.c:6155
+#: fortran/openmp.c:6160
 #, gcc-internal-format
 msgid "!$OMP DECLARE SIMD should refer to containing procedure %qs at %L"
 msgstr ""
 
-#: fortran/openmp.c:6179
+#: fortran/openmp.c:6184
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_PRIV or OMP_ORIG used in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6187
+#: fortran/openmp.c:6192
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_OUT or OMP_IN used in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6216
+#: fortran/openmp.c:6221
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid operator for !$OMP DECLARE REDUCTION %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:6238
+#: fortran/openmp.c:6243
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER length in !$OMP DECLARE REDUCTION %s not constant at %L"
 msgstr ""
 
-#: fortran/openmp.c:6254
+#: fortran/openmp.c:6259
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6269
+#: fortran/openmp.c:6274
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6279
+#: fortran/openmp.c:6284
 #, gcc-internal-format, gfc-internal-format
 msgid "One of actual subroutine arguments in INITIALIZER clause of !$OMP DECLARE REDUCTION must be OMP_PRIV at %L"
 msgstr ""
 
-#: fortran/openmp.c:6287
+#: fortran/openmp.c:6292
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing INITIALIZER clause for !$OMP DECLARE REDUCTION of derived type without default initializer at %L"
 msgstr ""
@@ -58962,536 +59050,536 @@
 msgid "Unclassifiable statement at %C"
 msgstr "Declaración inclasificable en %C"
 
-#: fortran/parse.c:629
+#: fortran/parse.c:631
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "OpenMP directives at %C may not appear in PURE or ELEMENTAL procedures"
 msgid "OpenACC directives at %C may not appear in PURE procedures"
 msgstr "Las directivas OpenMP en %C no pueden aparecer en procedimientos PURE o ELEMENTAL"
 
-#: fortran/parse.c:705
+#: fortran/parse.c:707
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unclassifiable OpenMP directive at %C"
 msgid "Unclassifiable OpenACC directive at %C"
 msgstr "Directiva OpenMP inclasificable en %C"
 
-#: fortran/parse.c:831 fortran/parse.c:1040
+#: fortran/parse.c:835 fortran/parse.c:1044
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "OpenMP directives at %C may not appear in PURE or ELEMENTAL procedures"
 msgid "OpenMP directives other than SIMD or DECLARE TARGET at %C may not appear in PURE or ELEMENTAL procedures"
 msgstr "Las directivas OpenMP en %C no pueden aparecer en procedimientos PURE o ELEMENTAL"
 
-#: fortran/parse.c:1024
+#: fortran/parse.c:1028
 #, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable OpenMP directive at %C"
 msgstr "Directiva OpenMP inclasificable en %C"
 
-#: fortran/parse.c:1076
+#: fortran/parse.c:1080
 #, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable GCC directive at %C"
 msgstr "Directiva GCC inclasificable en %C"
 
-#: fortran/parse.c:1135 fortran/parse.c:1362
+#: fortran/parse.c:1139 fortran/parse.c:1366
 #, gcc-internal-format, gfc-internal-format
 msgid "Zero is not a valid statement label at %C"
 msgstr "Cero no es una declaración de etiqueta válida en %C"
 
-#: fortran/parse.c:1142 fortran/parse.c:1354
+#: fortran/parse.c:1146 fortran/parse.c:1358
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-numeric character in statement label at %C"
 msgstr "Carácter no numérico en la etiqueta de declaración en %C"
 
-#: fortran/parse.c:1154 fortran/parse.c:1403
+#: fortran/parse.c:1158 fortran/parse.c:1407
 #, gcc-internal-format, gfc-internal-format
 msgid "Semicolon at %C needs to be preceded by statement"
 msgstr "El punto y coma en %C necesita ser precedido por la declaración"
 
-#: fortran/parse.c:1161 fortran/parse.c:1418
+#: fortran/parse.c:1165 fortran/parse.c:1422
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Ignoring statement label in empty statement at %L"
 msgid "Statement label without statement at %L"
 msgstr "Se descarta la etiqueta de declaración en la declaración vacía en %L"
 
-#: fortran/parse.c:1224 fortran/parse.c:1405
+#: fortran/parse.c:1228 fortran/parse.c:1409
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Semicolon at %C without preceding statement"
 msgstr "Fortran 2008: El punto y coma en %C sin una declaración precedente"
 
-#: fortran/parse.c:1247 fortran/parse.c:1381
+#: fortran/parse.c:1251 fortran/parse.c:1385
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad continuation line at %C"
 msgstr "Continuación de línea errónea en %C"
 
-#: fortran/parse.c:1679
+#: fortran/parse.c:1683
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT statement at %L does not have a statement label"
 msgstr "La declaración FORMAT en %L no tiene una etiqueta de declaración"
 
-#: fortran/parse.c:2435
+#: fortran/parse.c:2439
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_ascii_statement(): Bad statement code"
 msgstr "gfc_trans_code(): Código de declaración erróneo"
 
-#: fortran/parse.c:2577
+#: fortran/parse.c:2581
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement at %C"
 msgstr "Declaración %s inesperada en %C"
 
-#: fortran/parse.c:2732
+#: fortran/parse.c:2736
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot follow %s statement at %L"
 msgstr "La declaración %s en %C no puede ir después de la declaración %s en %L"
 
-#: fortran/parse.c:2749
+#: fortran/parse.c:2753
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of file in '%s'"
 msgid "Unexpected end of file in %qs"
 msgstr "Fin de fichero inesperado en '%s'"
 
-#: fortran/parse.c:2784
+#: fortran/parse.c:2788
 #, fuzzy, gcc-internal-format
 #| msgid "Derived-type '%s' with SEQUENCE must not have a CONTAINS section at %C"
 msgid "Derived-type %qs with SEQUENCE must not have a CONTAINS section at %C"
 msgstr "El tipo derivado '%s' con SEQUENCE no debe tener una sección CONTAINS en %C"
 
-#: fortran/parse.c:2787
+#: fortran/parse.c:2791
 #, fuzzy, gcc-internal-format
 #| msgid "Derived-type '%s' with BIND(C) must not have a CONTAINS section at %C"
 msgid "Derived-type %qs with BIND(C) must not have a CONTAINS section at %C"
 msgstr "El tipo derivado '%s' con BIND(C) no debe tener una sección CONTAINS en %C"
 
-#: fortran/parse.c:2807
+#: fortran/parse.c:2811
 #, gcc-internal-format, gfc-internal-format
 msgid "Components in TYPE at %C must precede CONTAINS"
 msgstr "Los componentes en TYPE en %C deben preceder a CONTAINS"
 
-#: fortran/parse.c:2811
+#: fortran/parse.c:2815
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003:  Type-bound procedure at %C"
 msgid "Type-bound procedure at %C"
 msgstr "Fortran 2003: Procedimiento enlazado a tipo en %C"
 
-#: fortran/parse.c:2819
+#: fortran/parse.c:2823
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Junk after GENERIC binding at %C"
 msgid "GENERIC binding at %C"
 msgstr "Basura después del enlace GENERIC en %C"
 
-#: fortran/parse.c:2827
+#: fortran/parse.c:2831
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003:  FINAL procedure declaration at %C"
 msgid "FINAL procedure declaration at %C"
 msgstr "Fortran 2003: Declaración de procedimiento FINAL en %C"
 
-#: fortran/parse.c:2839
+#: fortran/parse.c:2843
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: Derived type definition at %C with empty CONTAINS section"
 msgid "Derived type definition at %C with empty CONTAINS section"
 msgstr "Fortran 2003: La definición de tipo derivado en %C tiene una sección CONTAINS vacía"
 
-#: fortran/parse.c:2849 fortran/parse.c:3304
+#: fortran/parse.c:2853 fortran/parse.c:3308
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement in TYPE at %C must be inside a MODULE"
 msgstr "La declaración PRIVATE en TYPE en %C debe estar dentro de un MODULE"
 
-#: fortran/parse.c:2856
+#: fortran/parse.c:2860
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede procedure bindings"
 msgstr "La declaración PRIVATE en %C debe preceder a los enlaces de procedimiento"
 
-#: fortran/parse.c:2863 fortran/parse.c:3317
+#: fortran/parse.c:2867 fortran/parse.c:3321
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PRIVATE statement at %C"
 msgstr "Declaración PRIVATE duplicada en %C"
 
-#: fortran/parse.c:2873
+#: fortran/parse.c:2877
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede CONTAINS"
 msgstr "La declaración SEQUENCE en %C debe preceder a CONTAINS"
 
-#: fortran/parse.c:2877
+#: fortran/parse.c:2881
 #, gcc-internal-format, gfc-internal-format
 msgid "Already inside a CONTAINS block at %C"
 msgstr "Ya está dentro de un bloque CONTAINS en %C"
 
-#: fortran/parse.c:2996
+#: fortran/parse.c:3000
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s at %L of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray, which is not possible as the component has the pointer attribute"
 msgstr "El componente %s en %L de tipo LOCK_TYPE debe tener una codimensión o ser un subcomponente de una comatriz, lo cua no es posible ya que el componente tiene el atributo puntero"
 
-#: fortran/parse.c:3002
+#: fortran/parse.c:3006
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer component %s at %L has a noncoarray subcomponent of type LOCK_TYPE, which must have a codimension or be a subcomponent of a coarray"
 msgstr "El componenten puntero %s en %L tiene un subcomponenten que no es comatriz de tipo LOCK_TYPE, el cual debe tener una codimensión o ser un subcomponente de una comatriz"
 
-#: fortran/parse.c:3007
+#: fortran/parse.c:3011
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L of type LOCK_TYPE must have a codimension"
 msgstr "El componente allocatable %s en %L de tipo LOCK_TYPE debe tener una codimensión"
 
-#: fortran/parse.c:3011
+#: fortran/parse.c:3015
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L must have a codimension as it has a noncoarray subcomponent of type LOCK_TYPE"
 msgstr "El componente allocatable %s en %L debe tener una codimensión ya que tiene un subcomponente que no es comatriz de tipo LOCK_TYPE"
 
-#: fortran/parse.c:3016
+#: fortran/parse.c:3020
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as already a coarray subcomponent exists)"
 msgstr "El componente %s que no es comatriz en %L de tipo LOCK_TYPE o con subcomponente de tipo LOCK_TYPE debe tener una codimensión o ser un subcomponente de una comatriz. (Las variables de tipo %s pueden no tener una codimensión si ya existe un subcomponente comatriz)"
 
-#: fortran/parse.c:3023
+#: fortran/parse.c:3027
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as %s at %L has a codimension or a coarray subcomponent)"
 msgstr "El componente %s que no es comatriz en %L de tipo LOCK_TYPE o con subcomponente de tipo LOCK_TYPE debe tener una codimensión o ser un subcomponente de una comatriz. (Las variables de tipo %s pueden no tener una codimiensión ya que %s en %L tiene una codimensión o un componente submatriz)"
 
-#: fortran/parse.c:3033
+#: fortran/parse.c:3037
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Component %s at %L of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray, which is not possible as the component has the pointer attribute"
 msgid "Component %s at %L of type EVENT_TYPE must have a codimension or be a subcomponent of a coarray, which is not possible as the component has the pointer attribute"
 msgstr "El componente %s en %L de tipo LOCK_TYPE debe tener una codimensión o ser un subcomponente de una comatriz, lo cua no es posible ya que el componente tiene el atributo puntero"
 
-#: fortran/parse.c:3039
+#: fortran/parse.c:3043
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer component %s at %L has a noncoarray subcomponent of type LOCK_TYPE, which must have a codimension or be a subcomponent of a coarray"
 msgid "Pointer component %s at %L has a noncoarray subcomponent of type EVENT_TYPE, which must have a codimension or be a subcomponent of a coarray"
 msgstr "El componenten puntero %s en %L tiene un subcomponenten que no es comatriz de tipo LOCK_TYPE, el cual debe tener una codimensión o ser un subcomponente de una comatriz"
 
-#: fortran/parse.c:3044
+#: fortran/parse.c:3048
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Allocatable component %s at %L of type LOCK_TYPE must have a codimension"
 msgid "Allocatable component %s at %L of type EVENT_TYPE must have a codimension"
 msgstr "El componente allocatable %s en %L de tipo LOCK_TYPE debe tener una codimensión"
 
-#: fortran/parse.c:3048
+#: fortran/parse.c:3052
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Allocatable component %s at %L must have a codimension as it has a noncoarray subcomponent of type LOCK_TYPE"
 msgid "Allocatable component %s at %L must have a codimension as it has a noncoarray subcomponent of type EVENT_TYPE"
 msgstr "El componente allocatable %s en %L debe tener una codimensión ya que tiene un subcomponente que no es comatriz de tipo LOCK_TYPE"
 
-#: fortran/parse.c:3053
+#: fortran/parse.c:3057
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as already a coarray subcomponent exists)"
 msgid "Noncoarray component %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as already a coarray subcomponent exists)"
 msgstr "El componente %s que no es comatriz en %L de tipo LOCK_TYPE o con subcomponente de tipo LOCK_TYPE debe tener una codimensión o ser un subcomponente de una comatriz. (Las variables de tipo %s pueden no tener una codimensión si ya existe un subcomponente comatriz)"
 
-#: fortran/parse.c:3060
+#: fortran/parse.c:3064
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as %s at %L has a codimension or a coarray subcomponent)"
 msgid "Noncoarray component %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as %s at %L has a codimension or a coarray subcomponent)"
 msgstr "El componente %s que no es comatriz en %L de tipo LOCK_TYPE o con subcomponente de tipo LOCK_TYPE debe tener una codimensión o ser un subcomponente de una comatriz. (Las variables de tipo %s pueden no tener una codimiensión ya que %s en %L tiene una codimensión o un componente submatriz)"
 
-#: fortran/parse.c:3112
+#: fortran/parse.c:3116
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "failed to open %s"
 msgid "failed to create map component '%s'"
 msgstr "no se puede abrir %s"
 
-#: fortran/parse.c:3145
+#: fortran/parse.c:3149
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "failed to open %s"
 msgid "failed to create union component '%s'"
 msgstr "no se puede abrir %s"
 
-#: fortran/parse.c:3200
+#: fortran/parse.c:3204
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in data declaration at %C"
 msgid "Syntax error in nested structure declaration at %C"
 msgstr "Error sintáctico en la declaración de datos en %C"
 
-#: fortran/parse.c:3287
+#: fortran/parse.c:3291
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside CONTAINS"
 msgstr "La declaración FINAL en %C debe estar dentro de CONTAINS"
 
-#: fortran/parse.c:3295
+#: fortran/parse.c:3299
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: Derived type definition at %C without components"
 msgid "Derived type definition at %C without components"
 msgstr "Fortran 2003: La definición de tipo derivado en %C no tiene componentes"
 
-#: fortran/parse.c:3311
+#: fortran/parse.c:3315
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede structure components"
 msgstr "La declaración PRIVATE en %C debe preceder a los componentes de la estructura"
 
-#: fortran/parse.c:3328
+#: fortran/parse.c:3332
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede structure components"
 msgstr "La declaración SEQUENCE en %C debe preceder a los componentes de la estructura"
 
-#: fortran/parse.c:3334
+#: fortran/parse.c:3338
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE attribute at %C already specified in TYPE statement"
 msgstr "El atributo SEQUENCE en %C ya se especificó en la declaración TYPE"
 
-#: fortran/parse.c:3339
+#: fortran/parse.c:3343
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SEQUENCE statement at %C"
 msgstr "Declaración SEQUENCE duplicada en %C"
 
-#: fortran/parse.c:3349
+#: fortran/parse.c:3353
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003:  CONTAINS block in derived type definition at %C"
 msgid "CONTAINS block in derived type definition at %C"
 msgstr "Fortran 2003: Bloque CONTAINS en una definición de tipo derivado en %C"
 
-#: fortran/parse.c:3407
+#: fortran/parse.c:3411
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM declaration at %C has no ENUMERATORS"
 msgstr "La declaración ENUM en %C no tiene ENUMERATORS"
 
-#: fortran/parse.c:3494
+#: fortran/parse.c:3498
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in INTERFACE block at %C"
 msgstr "Declaración %s inesperada en el bloque INTERFACE en %C"
 
-#: fortran/parse.c:3518
+#: fortran/parse.c:3522
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' of ABSTRACT INTERFACE at %C cannot be the same as an intrinsic type"
 msgid "Name %qs of ABSTRACT INTERFACE at %C cannot be the same as an intrinsic type"
 msgstr "El nombre '%s' de ABSTRACT INTERFACE en %C no puede ser el mismo que un tipo intrínseco"
 
-#: fortran/parse.c:3552
+#: fortran/parse.c:3556
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement at %C in INTERFACE body"
 msgstr "Declaración %s inesperada en %C en el cuerpo de INTERFACE"
 
-#: fortran/parse.c:3570
+#: fortran/parse.c:3574
 #, fuzzy, gcc-internal-format
 #| msgid "INTERFACE procedure '%s' at %L has the same name as the enclosing procedure"
 msgid "INTERFACE procedure %qs at %L has the same name as the enclosing procedure"
 msgstr "El procedimiento INTERFACE '%s' en %L tiene el mismo nombre que el procedimiento que lo incluye"
 
-#: fortran/parse.c:3700
+#: fortran/parse.c:3704
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement is not allowed inside of BLOCK at %C"
 msgstr "No se permite una declaración %s dentro de BLOCK en %C"
 
-#: fortran/parse.c:3732
+#: fortran/parse.c:3736
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement is not allowed inside of BLOCK at %C"
 msgid "%s statement is not allowed inside of BLOCK DATA at %C"
 msgstr "No se permite una declaración %s dentro de BLOCK en %C"
 
-#: fortran/parse.c:3822
+#: fortran/parse.c:3826
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement must appear in a MODULE"
 msgstr "La declaración %s debe aparecer en un MODULE"
 
-#: fortran/parse.c:3830
+#: fortran/parse.c:3834
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C follows another accessibility specification"
 msgstr "La declaración %s en %C después de otra especificación de accesibilidad"
 
-#: fortran/parse.c:3882
+#: fortran/parse.c:3886
 #, fuzzy, gcc-internal-format
 #| msgid "Bad kind expression for function '%s' at %L"
 msgid "Bad kind expression for function %qs at %L"
 msgstr "Expresión de género errónea para la función '%s' en %L"
 
-#: fortran/parse.c:3886
+#: fortran/parse.c:3890
 #, fuzzy, gcc-internal-format
 #| msgid "The type for function '%s' at %L is not accessible"
 msgid "The type for function %qs at %L is not accessible"
 msgstr "El tipo para la función '%s' en %L no es accesible"
 
-#: fortran/parse.c:3946
+#: fortran/parse.c:3950
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C follows previous unmasked ELSEWHERE"
 msgstr "Declaración ELSEWHERE en %C después de un ELSEWHERE desenmascarado previo"
 
-#: fortran/parse.c:3968
+#: fortran/parse.c:3972
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in WHERE block at %C"
 msgstr "Declaración %s inesperada en el bloque WHERE en %C"
 
-#: fortran/parse.c:4027
+#: fortran/parse.c:4031
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in FORALL block at %C"
 msgstr "Declaración %s inesperada en el bloque FORALL en %C"
 
-#: fortran/parse.c:4078
+#: fortran/parse.c:4082
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSE IF statement at %C cannot follow ELSE statement at %L"
 msgstr "La declaración ELSE IF en %C no puede ir después de una declaración ELSE en %L"
 
-#: fortran/parse.c:4096
+#: fortran/parse.c:4100
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ELSE statements at %L and %C"
 msgstr "Declaraciones ELSE duplicadas en %L y %C"
 
-#: fortran/parse.c:4157
+#: fortran/parse.c:4161
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected a CASE or END SELECT statement following SELECT CASE at %C"
 msgstr "Se esperaba una declaración CASE o END SELECT después de un SELECT CASE en %C"
 
-#: fortran/parse.c:4241
+#: fortran/parse.c:4245
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected TYPE IS, CLASS IS or END SELECT statement following SELECT TYPE at %C"
 msgstr "Se esperaba una declaración TYPE IS, CLASS IS o END SELECT después de un SELECT TYPE en %C"
 
-#: fortran/parse.c:4303
+#: fortran/parse.c:4307
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgid "Variable %qs at %C cannot be redefined inside loop beginning at %L"
 msgstr "La variable '%s' en %C no se puede redefinir dentro del inicio de un bucle en %L"
 
-#: fortran/parse.c:4336
+#: fortran/parse.c:4340
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is within another block"
 msgstr "El final de la declaración DO que no es bloque en %C está dentro de otro bloque"
 
-#: fortran/parse.c:4346
+#: fortran/parse.c:4350
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is interwoven with another DO loop"
 msgstr "El final de la declaración DO que no es bloque en %C está entrelazado con otro bucle DO"
 
-#: fortran/parse.c:4372
+#: fortran/parse.c:4376
 #, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL block inside of OpenACC region at %C"
 msgstr ""
 
-#: fortran/parse.c:4373
+#: fortran/parse.c:4377
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003:  CONTAINS block in derived type definition at %C"
 msgid "CRITICAL block inside of OpenMP region at %C"
 msgstr "Fortran 2003: Bloque CONTAINS en una definición de tipo derivado en %C"
 
-#: fortran/parse.c:4399
+#: fortran/parse.c:4403
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Statement label in END CRITICAL at %C does not match CRITIAL label"
 msgid "Statement label in END CRITICAL at %C does not match CRITICAL label"
 msgstr "La etiqueta de declaración en END CRITICAL en %C no coincide con la etiqueta CRITICAL"
 
-#: fortran/parse.c:4468
+#: fortran/parse.c:4472
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: BLOCK construct at %C"
 msgid "BLOCK construct at %C"
 msgstr "Fortran 2008: Constructor BLOCK en %C"
 
-#: fortran/parse.c:4502
+#: fortran/parse.c:4506
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ASSOCIATE construct at %C"
 msgid "ASSOCIATE construct at %C"
 msgstr "Fortran 2003: Constructor ASSOCIATE en %C"
 
-#: fortran/parse.c:4690
+#: fortran/parse.c:4694
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label in ENDDO at %C doesn't match DO label"
 msgstr "La etiqueta de declaración en ENDDO en %C no coincide con la etiqueta DO"
 
-#: fortran/parse.c:4706
+#: fortran/parse.c:4710
 #, gcc-internal-format, gfc-internal-format
 msgid "Named block DO at %L requires matching ENDDO name"
 msgstr "El bloque DO nombrado en %L requiere un nombre ENDDO coincidente"
 
-#: fortran/parse.c:4897
+#: fortran/parse.c:4901
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing !$OMP END ATOMIC after !$OMP ATOMIC CAPTURE at %C"
 msgstr "Falta !$OMP END ATOMIC después de !$OMP ATOMIC CAPTURE en %C"
 
-#: fortran/parse.c:4913 fortran/parse.c:4972
+#: fortran/parse.c:4917 fortran/parse.c:4976
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Nested CRITICAL block at %C"
 msgid "OpenACC directive inside of CRITICAL block at %C"
 msgstr "Bloque CRITICAL anidado en %C"
 
-#: fortran/parse.c:4947
+#: fortran/parse.c:4951
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting %s statement at %C"
 msgid "Expecting %s at %C"
 msgstr "Se esperaba la declaración %s en %C"
 
-#: fortran/parse.c:4991
+#: fortran/parse.c:4995
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "Expected DO loop at %C"
 msgstr "Se esperaba '(' en %C"
 
-#: fortran/parse.c:5011
+#: fortran/parse.c:5015
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Redundant ACQUIRED_LOCK tag found at %L "
 msgid "Redundant !$ACC END LOOP at %C"
 msgstr "Se encontró una etiqueta ACQUIRED_LOCK redundante en %L "
 
-#: fortran/parse.c:5225
+#: fortran/parse.c:5229
 #, gcc-internal-format, gfc-internal-format
 msgid "Name after !$omp critical and !$omp end critical does not match at %C"
 msgstr "Los nombres después de !$omp critical y !$omp end critical no coinciden en %C"
 
-#: fortran/parse.c:5283
+#: fortran/parse.c:5287
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot terminate a non-block DO loop"
 msgstr "La declaración %s en %C no puede terminar un bucle DO que no es bloque"
 
-#: fortran/parse.c:5297
+#: fortran/parse.c:5301
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORMAT statement at %L does not have a statement label"
 msgid "DATA statement at %C after the first executable statement"
 msgstr "La declaración FORMAT en %L no tiene una etiqueta de declaración"
 
-#: fortran/parse.c:5423
+#: fortran/parse.c:5427
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive does not commence a loop at %C"
 msgstr ""
 
-#: fortran/parse.c:5538
+#: fortran/parse.c:5542
 #, fuzzy, gcc-internal-format
 #| msgid "Contained procedure '%s' at %C is already ambiguous"
 msgid "Contained procedure %qs at %C is already ambiguous"
 msgstr "El procedimiento contenido '%s' en %C ya es ambiguo"
 
-#: fortran/parse.c:5595
+#: fortran/parse.c:5599
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in CONTAINS section at %C"
 msgstr "Declaración %s inesperada en la sección CONTAINS en %C"
 
-#: fortran/parse.c:5620
+#: fortran/parse.c:5624
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: CONTAINS statement without FUNCTION or SUBROUTINE statement at %C"
 msgid "CONTAINS statement without FUNCTION or SUBROUTINE statement at %L"
 msgstr "Fortran 2008: Declaración CONTAINS sin una declaración FUNCTION o SUBROUTINE en %C"
 
-#: fortran/parse.c:5732
+#: fortran/parse.c:5736
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS statement at %C is already in a contained program unit"
 msgstr "La declaración CONTAINS en %C ya está contenida en una unidad de programa"
 
-#: fortran/parse.c:5784
+#: fortran/parse.c:5788
 #, fuzzy, gcc-internal-format
 #| msgid "Global name '%s' at %L is already being used as a %s at %L"
 msgid "Global binding name %qs at %L is already being used as a %s at %L"
 msgstr "El nombre global '%s' en %L ya se está usando como un %s en %L"
 
-#: fortran/parse.c:5788
+#: fortran/parse.c:5792
 #, fuzzy, gcc-internal-format
 #| msgid "Global name '%s' at %L is already being used as a %s at %L"
 msgid "Global name %qs at %L is already being used as a %s at %L"
 msgstr "El nombre global '%s' en %L ya se está usando como un %s en %L"
 
-#: fortran/parse.c:5794
+#: fortran/parse.c:5798
 #, fuzzy, gcc-internal-format
 #| msgid "Global name '%s' at %L is already being used as a %s at %L"
 msgid "Global binding name %qs at %L is already being used at %L"
 msgstr "El nombre global '%s' en %L ya se está usando como un %s en %L"
 
-#: fortran/parse.c:5797
+#: fortran/parse.c:5801
 #, fuzzy, gcc-internal-format
 #| msgid "Global name '%s' at %L is already being used as a %s at %L"
 msgid "Global name %qs at %L is already being used at %L"
 msgstr "El nombre global '%s' en %L ya se está usando como un %s en %L"
 
-#: fortran/parse.c:5819
+#: fortran/parse.c:5823
 #, gcc-internal-format, gfc-internal-format
 msgid "Blank BLOCK DATA at %C conflicts with prior BLOCK DATA at %L"
 msgstr "BLOCK DATA en blanco en %C genera un conflicto con un BLOCK DATA previo en %L"
 
-#: fortran/parse.c:5845
+#: fortran/parse.c:5849
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in BLOCK DATA at %C"
 msgstr "Declaración %s inesperada en BLOCK DATA en %C"
 
-#: fortran/parse.c:5949
+#: fortran/parse.c:5953
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in MODULE at %C"
 msgstr "Declaración %s inesperada en MODULE en %C"
@@ -59499,7 +59587,7 @@
 #. If we see a duplicate main program, shut down.  If the second
 #. instance is an implied main program, i.e. data decls or executable
 #. statements, we're in for lots of errors.
-#: fortran/parse.c:6333
+#: fortran/parse.c:6337
 #, gcc-internal-format, gfc-internal-format
 msgid "Two main PROGRAMs at %L and %C"
 msgstr "Dos PROGRAMas principales en %L y %C"
@@ -60341,7 +60429,7 @@
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr "El procedimiento que no es RECURSIVE '%s' en %L posiblemente se está llamando a sí mismo recursivamente. Declárelo RECURSIVE o utilice -frecursive"
 
-#: fortran/resolve.c:1893 fortran/resolve.c:9560 fortran/resolve.c:11225
+#: fortran/resolve.c:1893 fortran/resolve.c:9573 fortran/resolve.c:11245
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "La etiqueta %d referenciada en %L nunca se define"
@@ -60467,7 +60555,7 @@
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "La función '%s' en %L no es de tipo IMPLICIT"
 
-#: fortran/resolve.c:2905 fortran/resolve.c:16283
+#: fortran/resolve.c:2905 fortran/resolve.c:16310
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Function %qs at %L has no IMPLICIT type"
@@ -60610,200 +60698,200 @@
 msgid "logical_to_bitwise(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:4059
+#: fortran/resolve.c:4065
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:4229 fortran/resolve.c:4252
+#: fortran/resolve.c:4235 fortran/resolve.c:4258
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:4347
+#: fortran/resolve.c:4353
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "La referencia de matriz en %L está fuera de los límites (%ld < %ld) en la dimensión %d"
 
-#: fortran/resolve.c:4352
+#: fortran/resolve.c:4358
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr "La referencia de matriz en %L está fuera de los límites (%ld < %ld) en la codimensión %d"
 
-#: fortran/resolve.c:4362
+#: fortran/resolve.c:4368
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "La referencia de matriz en %L está fuera de los límites (%ld > %ld) en la dimensión %d"
 
-#: fortran/resolve.c:4367
+#: fortran/resolve.c:4373
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr "La referencia de matriz en %L está fuera de los límites (%ld > %ld) en la codimensión %d"
 
-#: fortran/resolve.c:4387
+#: fortran/resolve.c:4393
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr "Tranco ilegal de cero en %L"
 
-#: fortran/resolve.c:4404
+#: fortran/resolve.c:4410
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "La referencia de matriz inferior en %L está fuera de los límites (%ld < %ld) en la dimensión %d"
 
-#: fortran/resolve.c:4412
+#: fortran/resolve.c:4418
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "La referencia de matriz inferior en %L está fuera de los límites (%ld > %ld) en la dimensión %d"
 
-#: fortran/resolve.c:4428
+#: fortran/resolve.c:4434
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "La referencia de matriz superior en %L está fuera de los límites (%ld < %ld) en la dimensión %d"
 
-#: fortran/resolve.c:4437
+#: fortran/resolve.c:4443
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "La referencia de matriz superior en %L está fuera de los límites (%ld > %ld) en la dimensión %d"
 
-#: fortran/resolve.c:4453
+#: fortran/resolve.c:4459
 #, fuzzy, gcc-internal-format
 #| msgid "subscript missing in array reference"
 msgid "check_dimension(): Bad array reference"
 msgstr "falta el subíndice en la referencia de la matriz"
 
-#: fortran/resolve.c:4476
+#: fortran/resolve.c:4482
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr "No se especificó el límite superior a la derecha de la sección de matriz de tamaño asumido en %L"
 
-#: fortran/resolve.c:4486
+#: fortran/resolve.c:4492
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr "El rango no coincide en la referencia de matriz en %L (%d/%d)"
 
-#: fortran/resolve.c:4494
+#: fortran/resolve.c:4500
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr "El rango de coíndice no coincide en la referencia de matriz en %L (%d/%d)"
 
-#: fortran/resolve.c:4510
+#: fortran/resolve.c:4516
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr "El coíndice en la codimensión %d debe ser un escalar en %L"
 
-#: fortran/resolve.c:4538
+#: fortran/resolve.c:4544
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr "El índice de matriz en %L debe ser escalar"
 
-#: fortran/resolve.c:4544
+#: fortran/resolve.c:4550
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr "El índice de matriz en %L debe ser de tipo INTEGER, se encontró %s"
 
-#: fortran/resolve.c:4550
+#: fortran/resolve.c:4556
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: REAL array index at %L"
 msgid "REAL array index at %L"
 msgstr "Extensión: índice de matriz REAL en %L"
 
-#: fortran/resolve.c:4589
+#: fortran/resolve.c:4595
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr "El argumento dim en %L debe ser escalar"
 
-#: fortran/resolve.c:4596
+#: fortran/resolve.c:4602
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr "El argumento dim en %L debe ser de tipo entero"
 
-#: fortran/resolve.c:4641
+#: fortran/resolve.c:4647
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr ""
 
-#: fortran/resolve.c:4652
+#: fortran/resolve.c:4658
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.c:4663
+#: fortran/resolve.c:4669
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.c:4706
+#: fortran/resolve.c:4712
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr "El índice de matriz en %L es una matriz de rango %d"
 
-#: fortran/resolve.c:4804
+#: fortran/resolve.c:4810
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr "El índice de inicio de la subcadena en %L debe ser de tipo INTEGER"
 
-#: fortran/resolve.c:4811
+#: fortran/resolve.c:4817
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr "El índice de inicio de la subcadena en %L debe ser escalar"
 
-#: fortran/resolve.c:4820
+#: fortran/resolve.c:4826
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr "El índice de inicio de la subcadena en %L es menor a uno"
 
-#: fortran/resolve.c:4833
+#: fortran/resolve.c:4839
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr "El índice de final de la subcadena en %L debe ser de tipo INTEGER"
 
-#: fortran/resolve.c:4840
+#: fortran/resolve.c:4846
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr "El índice de final de la subcadena en %L debe ser escalar"
 
-#: fortran/resolve.c:4850
+#: fortran/resolve.c:4856
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr "El índice de final de la subcadena en %L excede la longitud de la cadena"
 
-#: fortran/resolve.c:4860
+#: fortran/resolve.c:4866
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr "El índice de final de la subcadena en %L es demasiado grande"
 
-#: fortran/resolve.c:5013
+#: fortran/resolve.c:5019
 #, fuzzy, gcc-internal-format
 #| msgid "Bad array reference at %L"
 msgid "resolve_ref(): Bad array reference"
 msgstr "Referencia de matriz errónea en %L"
 
-#: fortran/resolve.c:5027
+#: fortran/resolve.c:5033
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr "El componente a la derecha de una referencia de parte con rango que no es cero no debe tener el atributo POINTER en %L"
 
-#: fortran/resolve.c:5037
+#: fortran/resolve.c:5043
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr "El componente a la derecha de una referencia de parte con rango que no es cero no debe tener el atributo ALLOCATABLE en %L"
 
-#: fortran/resolve.c:5056
+#: fortran/resolve.c:5062
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr "No se deben especificar dos o más referencias de parte con rango que no es cero en %L"
 
-#: fortran/resolve.c:5154
+#: fortran/resolve.c:5160
 #, gcc-internal-format
 msgid "expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.c:5236
+#: fortran/resolve.c:5242
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr ""
 
-#: fortran/resolve.c:5246
+#: fortran/resolve.c:5252
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
@@ -60813,12 +60901,12 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5256
+#: fortran/resolve.c:5262
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5271
+#: fortran/resolve.c:5277
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
@@ -60828,284 +60916,285 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5281
+#: fortran/resolve.c:5287
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5292
+#: fortran/resolve.c:5298
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Procedure '%s' at %L with BIND(C) attribute must have an explicit interface"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr "El procedimiento '%s' en %L con atributo BIND(C) debe tener una interfaz explícita"
 
-#: fortran/resolve.c:5301
+#: fortran/resolve.c:5307
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Coarray variable '%s' at %L shall not have codimensions with deferred shape"
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr "La variable de comatriz '%s' en %L no debe tener codimensiones con forma diferida"
 
-#: fortran/resolve.c:5316
+#: fortran/resolve.c:5322
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Coarray variable '%s' at %L shall not have codimensions with deferred shape"
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr "La variable de comatriz '%s' en %L no debe tener codimensiones con forma diferida"
 
-#: fortran/resolve.c:5478
+#: fortran/resolve.c:5484
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s', used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr "La variable '%s', usada en una expresión de especificación, se referencía en %L antes de la declaración ENTRY en la cual es un parámetro"
 
-#: fortran/resolve.c:5483
+#: fortran/resolve.c:5489
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' is used at %L before the ENTRY statement in which it is a parameter"
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr "La variable '%s' se usa en %L antes de la declaración ENTRY en la cual es un parámetro"
 
-#: fortran/resolve.c:5553
+#: fortran/resolve.c:5559
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr "Subobjecto polimórfico de un objeto coindizado en %L"
 
-#: fortran/resolve.c:5566
+#: fortran/resolve.c:5572
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr "Objeto coindizado con subcomponente alojable polimórfico en %L"
 
-#: fortran/resolve.c:5919
+#: fortran/resolve.c:5925
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "El objeto pasado en %L debe ser escalar"
 
-#: fortran/resolve.c:5926
+#: fortran/resolve.c:5932
 #, fuzzy, gcc-internal-format
 #| msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type '%s'"
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr "El objeto base para la llamada a componente procedimiento-puntero en %L es de tipo ABSTRACT '%s'"
 
-#: fortran/resolve.c:5961
+#: fortran/resolve.c:5967
 #, fuzzy, gcc-internal-format
 #| msgid "Base object for type-bound procedure call at %L is of ABSTRACT type '%s'"
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr "El objeto base para la llamada a procedimiento enlazada a tipo en %L es de tipo ABSTRACT '%s'"
 
-#: fortran/resolve.c:5970
+#: fortran/resolve.c:5976
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr "El objeto base para la llamada a procedimiento enlazada a tipo NOPASS en %L debe ser escalar"
 
 #. Nothing matching found!
-#: fortran/resolve.c:6158
+#: fortran/resolve.c:6164
 #, fuzzy, gcc-internal-format
 #| msgid "Found no matching specific binding for the call to the GENERIC '%s' at %L"
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr "No se encontró un enlace específico coincidente para la llamada al GENERIC '%s' en %L"
 
-#: fortran/resolve.c:6185
+#: fortran/resolve.c:6191
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L should be a SUBROUTINE"
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "'%s' en %L debe ser una SUBROUTINE"
 
-#: fortran/resolve.c:6236
+#: fortran/resolve.c:6242
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L should be a FUNCTION"
 msgid "%qs at %L should be a FUNCTION"
 msgstr "'%s' en %L debe ser una FUNCTION"
 
-#: fortran/resolve.c:6786
+#: fortran/resolve.c:6792
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "Se esperaba un tipo de expresión"
 
-#: fortran/resolve.c:6812
+#: fortran/resolve.c:6818
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s en %L debe ser un escalar"
 
-#: fortran/resolve.c:6822
+#: fortran/resolve.c:6828
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' at %L must be nonnegative"
 msgid "%s at %L must be integer"
 msgstr "'%s' en %L debe ser no negativo"
 
-#: fortran/resolve.c:6826 fortran/resolve.c:6833
+#: fortran/resolve.c:6832 fortran/resolve.c:6839
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s en %L debe ser INTEGER"
 
-#: fortran/resolve.c:6875
+#: fortran/resolve.c:6881
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "La expresión de paso en el bucle DO en %L no puede ser cero"
 
-#: fortran/resolve.c:6911
+#: fortran/resolve.c:6917
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr "El bucle DO en %L se ejecutará cero veces"
 
-#: fortran/resolve.c:6928
+#: fortran/resolve.c:6934
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.c:6934
+#: fortran/resolve.c:6940
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.c:6995
+#: fortran/resolve.c:7001
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "El nombre de índice FORALL en %L debe ser un INTEGER escalar"
 
-#: fortran/resolve.c:7000
+#: fortran/resolve.c:7006
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "La expresión de inicio FORALL en %L debe ser un INTEGER escalar"
 
-#: fortran/resolve.c:7007
+#: fortran/resolve.c:7013
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "La expresión de fin FORALL en %L debe ser un INTEGER escalar"
 
-#: fortran/resolve.c:7015
+#: fortran/resolve.c:7021
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "La expresión de tranco FORALL en %L debe ser un %s escalar"
 
-#: fortran/resolve.c:7020
+#: fortran/resolve.c:7026
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "La expresión de tranco FORALL en %L no puede ser cero"
 
-#: fortran/resolve.c:7033
+#: fortran/resolve.c:7039
 #, fuzzy, gcc-internal-format
 #| msgid "FORALL index '%s' may not appear in triplet specification at %L"
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "El índice FORALL '%s' no puede aparecer en la especificación triplet en %L"
 
-#: fortran/resolve.c:7136 fortran/resolve.c:7428
+#: fortran/resolve.c:7142 fortran/resolve.c:7434
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "El objeto de alojamiento en %L debe ser ALLOCATABLE o un POINTER"
 
-#: fortran/resolve.c:7144 fortran/resolve.c:7393
+#: fortran/resolve.c:7150 fortran/resolve.c:7399
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr "Objeto alojable coindizado en %L"
 
-#: fortran/resolve.c:7250
+#: fortran/resolve.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr "La expresión fuente en %L debe ser escalar o tener el mismo rango que el objeto de alojamiento en %L"
 
-#: fortran/resolve.c:7281
+#: fortran/resolve.c:7287
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr "La expresión fuente en %L y el objeto de alojamiento en %L deben tener la misma forma"
 
-#: fortran/resolve.c:7439
+#: fortran/resolve.c:7445
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr "El tipo de entidad en %L es de tipo incompatible con la expresión fuente en %L"
 
-#: fortran/resolve.c:7451
+#: fortran/resolve.c:7457
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr "El objeto de alojamiento en %L y la expresión fuente en %L deben tener el mismo parámetro de tipo de género"
 
-#: fortran/resolve.c:7465
+#: fortran/resolve.c:7471
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr "La expresión fuente en %L no puede ser de tipo LOCK_TYPE ni tener un componente LOCK_TYPE si el objeto-alojado en %L es una comatriz"
 
-#: fortran/resolve.c:7480
+#: fortran/resolve.c:7486
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr "La expresión fuente en %L no puede ser de tipo LOCK_TYPE ni tener un componente LOCK_TYPE si el objeto-alojado en %L es una comatriz"
 
-#: fortran/resolve.c:7493
+#: fortran/resolve.c:7499
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr "El alojamiento %s del tipo de base ABSTRACT en %L requiere una especificación de tipo o una expresión source"
 
-#: fortran/resolve.c:7511
+#: fortran/resolve.c:7517
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr "Alojar %s en %L con especificación de tipo requiere el mismo parámetro de longitud de carácter que el de la declaración"
 
-#: fortran/resolve.c:7592 fortran/resolve.c:7607
+#: fortran/resolve.c:7598 fortran/resolve.c:7613
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "Se requiere una especificación de matriz en la declaración ALLOCATE en %L"
 
-#: fortran/resolve.c:7599
+#: fortran/resolve.c:7605
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array specification required in ALLOCATE statement at %L"
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "Se requiere una especificación de matriz en la declaración ALLOCATE en %L"
 
-#: fortran/resolve.c:7622
+#: fortran/resolve.c:7628
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "Se requiere una especificación de comatriz en la declaración ALLOCATE en %L"
 
-#: fortran/resolve.c:7649
+#: fortran/resolve.c:7655
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "Especificación de matriz errónea en la declaración ALLOCATE en %L"
 
-#: fortran/resolve.c:7668
+#: fortran/resolve.c:7674
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr "'%s' no debe aparecer en la especificación de matriz en %L en la misma declaración ALLOCATE donde se aloja a sí misma"
 
-#: fortran/resolve.c:7683
+#: fortran/resolve.c:7689
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr "Se esperaba '*' en la especificación de comatriz en la declaración ALLOCATE en %L"
 
-#: fortran/resolve.c:7694
+#: fortran/resolve.c:7700
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "Especificación de comatriz errónea en la declaración ALLOCATE en %L"
 
-#: fortran/resolve.c:7726
+#: fortran/resolve.c:7732
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "La variable stat en %L debe ser una variable INTEGER escalar"
 
-#: fortran/resolve.c:7749
+#: fortran/resolve.c:7755
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "La variable stat en %L no no debe ser %sd dentro de la misma declaración %s"
 
-#: fortran/resolve.c:7760
+#: fortran/resolve.c:7766
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr "ERRMSG en %L es inútil sin una etiqueta STAT"
 
-#: fortran/resolve.c:7771
-#, gcc-internal-format, gfc-internal-format
-msgid "Errmsg-variable at %L must be a scalar CHARACTER variable"
-msgstr "La variable errmsg en %L debe ser una variable CHARACTER escalar"
+#: fortran/resolve.c:7782
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
+msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
+msgstr "El argumento ERRMSG= en %L debe ser una variable CHARACTER escalar"
 
-#: fortran/resolve.c:7794
+#: fortran/resolve.c:7805
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr "La variable errmsg en %L no debe ser %sd dentro de la misma declaración %s"
 
-#: fortran/resolve.c:7824
+#: fortran/resolve.c:7835
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr "El objeto de alojamiento en %L también aparece en %L"
 
-#: fortran/resolve.c:7830 fortran/resolve.c:7836
+#: fortran/resolve.c:7841 fortran/resolve.c:7847
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr "El objeto de alojamiento en %L es un subobjeto del objeto en %L"
@@ -61114,248 +61203,248 @@
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8064
+#: fortran/resolve.c:8075
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "La etiqueta CASE en %L se encima con la etiqueta CASE en %L"
 
-#: fortran/resolve.c:8115
+#: fortran/resolve.c:8126
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "La expresión en la declaración CASE en %L debe ser de tipo %s"
 
-#: fortran/resolve.c:8126
+#: fortran/resolve.c:8137
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "La expresión en la declaración CASE en %L debe ser de género %d"
 
-#: fortran/resolve.c:8139
+#: fortran/resolve.c:8150
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "La expresión en la declaración CASE en %L debe ser escalar"
 
-#: fortran/resolve.c:8185
+#: fortran/resolve.c:8196
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "La expresión de selección en una declaración GOTO computada en %L debe ser una expresión entera escalar"
 
-#: fortran/resolve.c:8204
+#: fortran/resolve.c:8215
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "El argumento de la declaración SELECT en %L no puede ser %s"
 
-#: fortran/resolve.c:8214
+#: fortran/resolve.c:8225
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "El argumento de la declaración SELECT en %L debe ser una expresión escalar"
 
-#: fortran/resolve.c:8232 fortran/resolve.c:8240
+#: fortran/resolve.c:8243 fortran/resolve.c:8251
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "La expresión en la declaración CASE en %L no está en el rango de %s"
 
-#: fortran/resolve.c:8302 fortran/resolve.c:8873
+#: fortran/resolve.c:8313 fortran/resolve.c:8884
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "El DEFAULT CASE en %L no puede tener después un segundo DEFAULT CASE en %L"
 
-#: fortran/resolve.c:8328
+#: fortran/resolve.c:8339
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "No se permite un rango lógico en una declaración CASE en %L"
 
-#: fortran/resolve.c:8340
+#: fortran/resolve.c:8351
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "Se repite un valor lógico constante en una declaración CASE en %L"
 
-#: fortran/resolve.c:8355
+#: fortran/resolve.c:8366
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "La especificación de rango en %L nunca puede coincidir"
 
-#: fortran/resolve.c:8458
+#: fortran/resolve.c:8469
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "El bloque SELECT CASE lógico en %L tiene más de dos cases"
 
-#: fortran/resolve.c:8518
+#: fortran/resolve.c:8529
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Association target at %C must not be coindexed"
 msgid "Selector at %L cannot be NULL()"
 msgstr "El objetivo de asociación en %C no debe estar coindizado"
 
-#: fortran/resolve.c:8523
+#: fortran/resolve.c:8534
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Association target at %C must not be coindexed"
 msgid "Selector at %L has no type"
 msgstr "El objetivo de asociación en %C no debe estar coindizado"
 
-#: fortran/resolve.c:8545
+#: fortran/resolve.c:8556
 #, fuzzy, gcc-internal-format
 #| msgid "Associate-name '%s' at %L is used as array"
 msgid "Associate-name %qs at %L is used as array"
 msgstr "Se usa el nombre asociado '%s' en %L como una matriz"
 
-#: fortran/resolve.c:8556
+#: fortran/resolve.c:8567
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:8763
+#: fortran/resolve.c:8774
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "El selector debe ser polimórfico en la declaración SELECT TYPE en %L"
 
-#: fortran/resolve.c:8783 fortran/resolve.c:8795
+#: fortran/resolve.c:8794 fortran/resolve.c:8806
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Association target at %C must not be coindexed"
 msgid "Selector at %L must not be coindexed"
 msgstr "El objetivo de asociación en %C no debe estar coindizado"
 
-#: fortran/resolve.c:8824
+#: fortran/resolve.c:8835
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CASE label at %L overlaps with CASE label at %L"
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "La etiqueta CASE en %L se encima con la etiqueta CASE en %L"
 
-#: fortran/resolve.c:8836
+#: fortran/resolve.c:8847
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %L must be extensible"
 msgid "Derived type %qs at %L must be extensible"
 msgstr "El tipo derivado '%s' en %L debe ser extensible"
 
-#: fortran/resolve.c:8848
+#: fortran/resolve.c:8859
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %L must be an extension of '%s'"
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "El tipo derivado '%s' en %L debe ser una extensión de '%s'"
 
-#: fortran/resolve.c:8851
+#: fortran/resolve.c:8862
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected NULL() intrinsic at %L to dummy '%s'"
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "Intrínseco NULL inesperado en %L para el dummy '%s'"
 
-#: fortran/resolve.c:8861
+#: fortran/resolve.c:8872
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Type-spec at %L cannot contain a deferred type parameter"
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr "La especificación de tipo en %L no puede tener un parámetro de tipo diferido"
 
-#: fortran/resolve.c:9108
+#: fortran/resolve.c:9119
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr "Bloque CLASS IS doble en la declaración SELECT TYPE  en %L"
 
-#: fortran/resolve.c:9204
+#: fortran/resolve.c:9215
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid context for NULL() pointer at %%L"
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "Contexto no válido para el puntero NULL() en %%L"
 
-#: fortran/resolve.c:9257
+#: fortran/resolve.c:9268
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "STOP code at %L must be scalar"
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "El código STOP en %L debe ser escalar"
 
-#: fortran/resolve.c:9267
+#: fortran/resolve.c:9278
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr "El elemento de transferencia de datos en %L no puede ser polimórfico a menos que se procese con un procedimiento de entrada/salida definido"
 
-#: fortran/resolve.c:9280
+#: fortran/resolve.c:9291
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "El elemento de transferencia de datos en %L no puede tener componentes POINTER a menos que se procese con un procedimiento de entrada/salida definido"
 
-#: fortran/resolve.c:9289
+#: fortran/resolve.c:9300
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "El elemento de transferencia de datos en %L no puede tener componentes de puntero a procedimiento"
 
-#: fortran/resolve.c:9296
+#: fortran/resolve.c:9307
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "El elemento de transferencia de datos en %L no puede tener componentes ALLOCATABLE a menos que se procese con un procedimiento de entrada/salida definido"
 
-#: fortran/resolve.c:9307
+#: fortran/resolve.c:9318
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "El elemento de transferencia de datos en %L no puede tener componentes PRIVATE"
 
-#: fortran/resolve.c:9313
+#: fortran/resolve.c:9324
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr "El elemento de transferencia de datos en %L no puede tener componentes POINTER a menos que se procese con un procedimiento de entrada/salida definido"
 
-#: fortran/resolve.c:9328
+#: fortran/resolve.c:9339
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "El elemento de transferencia de datos en %L no puede ser una referencia completa a una matriz de tamaño asumido"
 
-#: fortran/resolve.c:9388
+#: fortran/resolve.c:9399
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "La variable lock en %L debe ser un escalar de tipo LOCK_TYPE"
 
-#: fortran/resolve.c:9398
+#: fortran/resolve.c:9409
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr "La variable lock en %L debe ser un escalar de tipo LOCK_TYPE"
 
-#: fortran/resolve.c:9402
+#: fortran/resolve.c:9413
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Actual argument to '%s' at %L must be a coarray"
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "El argumento actual para '%s' en %L debe ser una comatriz"
 
-#: fortran/resolve.c:9405
+#: fortran/resolve.c:9416
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Actual argument to '%s' at %L must be a coarray"
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "El argumento actual para '%s' en %L debe ser una comatriz"
 
-#: fortran/resolve.c:9412 fortran/resolve.c:9533
+#: fortran/resolve.c:9423 fortran/resolve.c:9545
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "El argumento STAT= en %L debe ser una variable INTEGER escalar"
 
-#: fortran/resolve.c:9424 fortran/resolve.c:9540
+#: fortran/resolve.c:9435 fortran/resolve.c:9553
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "El argumento ERRMSG= en %L debe ser una variable CHARACTER escalar"
 
-#: fortran/resolve.c:9436
+#: fortran/resolve.c:9447
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "El argumento ACQUIRED_LOCK= en %L debe ser una variable LOGICAL escalar"
 
-#: fortran/resolve.c:9449
+#: fortran/resolve.c:9460
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "El argumento de conjunto de imagen %L debe ser un escalar o una expresión INTEGER de rango 1"
 
-#: fortran/resolve.c:9510
+#: fortran/resolve.c:9521
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "El argumento de conjunto de imagen %L debe ser un escalar o una expresión INTEGER de rango 1"
 
-#: fortran/resolve.c:9514 fortran/resolve.c:9524
+#: fortran/resolve.c:9525 fortran/resolve.c:9535
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "El argumento de conjunto de imagen en %L debe estar entre 1 y num_images()"
 
-#: fortran/resolve.c:9567
+#: fortran/resolve.c:9580
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "La declaración en %L no es una declaración de objetivo de ramificación válida para la declaración de ramificación en %L"
 
-#: fortran/resolve.c:9577
+#: fortran/resolve.c:9590
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr "La ramificación en %L puede resultar en un bucle infinito"
@@ -61362,12 +61451,12 @@
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:9594 fortran/resolve.c:9617
+#: fortran/resolve.c:9607 fortran/resolve.c:9630
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr "La declaración GOTO en %L deja la construcción CRITICAL por la etiqueta en %L"
 
-#: fortran/resolve.c:9598 fortran/resolve.c:9623
+#: fortran/resolve.c:9611 fortran/resolve.c:9636
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr "La declaración GOTO en %L deja la construcción DO CONCURRENT por la etiqueta en %L"
@@ -61375,114 +61464,114 @@
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:9638
+#: fortran/resolve.c:9651
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "La etiqueta en %L no está en el mismo bloque que la declaración GOTO en %L"
 
-#: fortran/resolve.c:9710
+#: fortran/resolve.c:9723
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "La máscara WHERE en %L tiene forma inconsistente"
 
-#: fortran/resolve.c:9726
+#: fortran/resolve.c:9739
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "El objetivo de asignación WHERE en %L tiene forma inconsistente"
 
-#: fortran/resolve.c:9734 fortran/resolve.c:9821
+#: fortran/resolve.c:9747 fortran/resolve.c:9834
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr "Asignación definida por el usuario de un no-ELEMENTAL en WHERE en %L"
 
-#: fortran/resolve.c:9744 fortran/resolve.c:9831
+#: fortran/resolve.c:9757 fortran/resolve.c:9844
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "Declaración sin soporte dentro de WHERE en %L"
 
-#: fortran/resolve.c:9775
+#: fortran/resolve.c:9788
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "Asignación a una variable de índice FORALL en %L"
 
-#: fortran/resolve.c:9784
+#: fortran/resolve.c:9797
 #, fuzzy, gcc-internal-format
 #| msgid "The FORALL with index '%s' is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "No se usa el FORALL con índice '%s' en el lado izquierdo de la asignación en %L y podría causar múltiples asignaciones a este objeto"
 
-#: fortran/resolve.c:9949
+#: fortran/resolve.c:9962
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "El nombre de índice FORALL en %L debe ser un INTEGER escalar"
 
-#: fortran/resolve.c:9959
+#: fortran/resolve.c:9972
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "Una construcción FORALL externa ya tiene un índice con este nombre %L"
 
-#: fortran/resolve.c:10036
+#: fortran/resolve.c:10049
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "la cláusula WHERE/ELSEWHERE en %L requiere una matriz LOGICAL"
 
-#: fortran/resolve.c:10138
+#: fortran/resolve.c:10151
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:10251
+#: fortran/resolve.c:10264
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CHARACTER expression will be truncated in assignment (%d/%d) at %L"
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr "Se truncará la expresión CHARACTER en la asignación (%d/%d) en %L"
 
-#: fortran/resolve.c:10283
+#: fortran/resolve.c:10296
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "La expresión con coíndice en %L se asigna a una variable de tipo derivado con un componente POINTER en un procedimiento PURE"
 
-#: fortran/resolve.c:10288
+#: fortran/resolve.c:10301
 #, gcc-internal-format, gfc-internal-format
 msgid "The impure variable at %L is assigned to a derived type variable with a POINTER component in a PURE procedure (12.6)"
 msgstr "La variable impura en %L se asigna a una variable de tipo derivado con un componente POINTER en un procedimiento PURE (12.6)"
 
-#: fortran/resolve.c:10298
+#: fortran/resolve.c:10311
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "Asignación a una variable coindizada en %L en un procedimiento PURE"
 
-#: fortran/resolve.c:10330
+#: fortran/resolve.c:10343
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Polymorphic array at %C not yet supported"
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr "Aún no se admite la matriz polimórfica en %C"
 
-#: fortran/resolve.c:10334
+#: fortran/resolve.c:10347
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assignment to a FORALL index variable at %L"
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "Asignación a una variable de índice FORALL en %L"
 
-#: fortran/resolve.c:10339
+#: fortran/resolve.c:10352
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.c:10346
+#: fortran/resolve.c:10359
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr "La variable no debe ser polimórfica en la asignación intrínseca en %L - revise que hay una subrutina específica coincidente para el operador '='"
 
-#: fortran/resolve.c:10357
+#: fortran/resolve.c:10370
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Coindexed variable must not be have an allocatable ultimate component in assignment at %L"
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr "La variable coindizada no debe tener un componente último alojable en la asignación en %L"
 
-#: fortran/resolve.c:10663
+#: fortran/resolve.c:10683
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
@@ -61489,35 +61578,35 @@
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:10905
+#: fortran/resolve.c:10925
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid procedure pointer assignment at %L"
 msgid "Pointer procedure assignment at %L"
 msgstr "Asignación de puntero de procedimiento no válida en %L"
 
-#: fortran/resolve.c:10917
+#: fortran/resolve.c:10937
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr "La expresión objetivo en la asignación de puntero en %L debe entregar un resultado puntero."
 
-#: fortran/resolve.c:11157
+#: fortran/resolve.c:11177
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgstr "La declaración ASSIGNED GOTO en %L requiere una variable INTEGER"
 
-#: fortran/resolve.c:11160
+#: fortran/resolve.c:11180
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' has not been assigned a target label at %L"
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "La variable '%s' no se ha asignado a una etiqueta objetivo en %L"
 
-#: fortran/resolve.c:11171
+#: fortran/resolve.c:11191
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "La declaración RETURN alternativa en %L requiere de un especificador de devolución SCALAR-INTEGER"
 
-#: fortran/resolve.c:11233
+#: fortran/resolve.c:11253
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "La declaración de ASSIGN en %L requiere una variable INTEGER escalar por defecto"
@@ -61524,40 +61613,40 @@
 
 # 'kind' es el tipo del tipo de dato en Fortran. Lo traduzco como 
 # 'género', para evitar confusión con 'type' = 'tipo'. cfuga
-#: fortran/resolve.c:11278
+#: fortran/resolve.c:11298
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Invalid NULL at %L"
 msgstr "Género no válido para %s en %L"
 
-#: fortran/resolve.c:11282
+#: fortran/resolve.c:11302
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Arithmetic IF statement at %L requires a numeric expression"
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr "La declaración IF aritmética en %L requiere una expresión numérica"
 
-#: fortran/resolve.c:11339
+#: fortran/resolve.c:11359
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:11344
+#: fortran/resolve.c:11364
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "La condición de salida del bucle DO WHILE en %L debe ser una expresión LOGICAL escalar"
 
-#: fortran/resolve.c:11428
+#: fortran/resolve.c:11448
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "La cláusula de máscara FORALL en %L requiere una expresión LOGICAL escalar"
 
-#: fortran/resolve.c:11507
+#: fortran/resolve.c:11527
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_trans_code(): Código de declaración erróneo"
 
-#: fortran/resolve.c:11617
+#: fortran/resolve.c:11637
 #, fuzzy, gcc-internal-format
 #| msgid "Binding label '%s' at %L collides with the global entity '%s' at %L"
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
@@ -61565,7 +61654,7 @@
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:11630
+#: fortran/resolve.c:11650
 #, fuzzy, gcc-internal-format
 #| msgid "Binding label '%s' at %L collides with the global entity '%s' at %L"
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
@@ -61574,66 +61663,66 @@
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:11647
+#: fortran/resolve.c:11667
 #, fuzzy, gcc-internal-format
 #| msgid "Binding label '%s' at %L collides with the global entity '%s' at %L"
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "La etiqueta enlazante '%s' en %L colisiona con la entidad global '%s' en %L"
 
-#: fortran/resolve.c:11732
+#: fortran/resolve.c:11752
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "La longitud de la cadena en %L es demasiado grande"
 
-#: fortran/resolve.c:11961
+#: fortran/resolve.c:11981
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable array '%s' at %L must have a deferred shape"
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "La matriz allocatable '%s' en %L debe tener una forma diferida"
 
-#: fortran/resolve.c:11965
+#: fortran/resolve.c:11985
 #, fuzzy, gcc-internal-format
 #| msgid "Scalar object '%s' at %L may not be ALLOCATABLE"
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "El objeto escalar '%s' en %L no puede ser ALLOCATABLE"
 
-#: fortran/resolve.c:11973
+#: fortran/resolve.c:11993
 #, fuzzy, gcc-internal-format
 #| msgid "Array pointer '%s' at %L must have a deferred shape"
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "La matriz de puntero '%s' en %L debe tener una forma diferida"
 
-#: fortran/resolve.c:11983
+#: fortran/resolve.c:12003
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "La matriz '%s' en %L no puede tener una forma diferida"
 
-#: fortran/resolve.c:11998
+#: fortran/resolve.c:12018
 #, fuzzy, gcc-internal-format
 #| msgid "Type '%s' of CLASS variable '%s' at %L is not extensible"
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr "El tipo '%s' de la variable CLASS '%s' en %L no es extensible"
 
-#: fortran/resolve.c:12010
+#: fortran/resolve.c:12030
 #, fuzzy, gcc-internal-format
 #| msgid "CLASS variable '%s' at %L must be dummy, allocatable or pointer"
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr "La variable CLASS '%s' en %L debe ser dummy, allocatable o pointer"
 
-#: fortran/resolve.c:12041
+#: fortran/resolve.c:12061
 #, fuzzy, gcc-internal-format
 #| msgid "The type '%s' cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr "El tipo '%s' no se puede asociar al anfitrión en %L porque está bloqueado por un objeto incompatible del mismo nombre declarado en %L"
 
-#: fortran/resolve.c:12063
+#: fortran/resolve.c:12083
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2008: Implied SAVE for module variable '%s' at %L, needed due to the default initialization"
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr "Fortran 2008: SAVE implícito para la variable de módulo '%s' en %L, se necesita por la inicialización por defecto"
 
-#: fortran/resolve.c:12090
+#: fortran/resolve.c:12110
 #, fuzzy, gcc-internal-format
 #| msgid "Entity '%s' at %L has a deferred type parameter and requires either the pointer or allocatable attribute"
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
@@ -61641,1018 +61730,1024 @@
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12131
+#: fortran/resolve.c:12151
 #, fuzzy, gcc-internal-format
 #| msgid "The module or main program array '%s' at %L must have constant shape"
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "El módulo o la matriz del programa principal '%s' en %L deben tener una forma constante"
 
-#: fortran/resolve.c:12150
+#: fortran/resolve.c:12170
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "La entidad con longitud de carácter asumida en %L debe ser un argumento de prueba o un PARAMETER"
 
-#: fortran/resolve.c:12171
+#: fortran/resolve.c:12191
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "%qs at %L must have constant character length in this context"
 msgstr "'%s' en %L debe tener longitud de cáracter constante en este contexto"
 
-#: fortran/resolve.c:12178
+#: fortran/resolve.c:12198
 #, fuzzy, gcc-internal-format
 #| msgid "COMMON variable '%s' at %L must have constant character length"
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "La variable COMMON '%s' en %L debe tener longitud de cáracter constante en este contexto"
 
-#: fortran/resolve.c:12225
+#: fortran/resolve.c:12245
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable '%s' at %L cannot have an initializer"
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "El allocatable '%s' en %L no puede tener un inicializador"
 
-#: fortran/resolve.c:12228
+#: fortran/resolve.c:12248
 #, fuzzy, gcc-internal-format
 #| msgid "External '%s' at %L cannot have an initializer"
 msgid "External %qs at %L cannot have an initializer"
 msgstr "El external '%s' en %L no puede tener un inicializador"
 
-#: fortran/resolve.c:12232
+#: fortran/resolve.c:12252
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "El dummy '%s' en %L no puede tener un inicializador"
 
-#: fortran/resolve.c:12235
+#: fortran/resolve.c:12255
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L cannot have an initializer"
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "El intrinsic '%s' en %L no puede tener un inicializador"
 
-#: fortran/resolve.c:12238
+#: fortran/resolve.c:12258
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L cannot have an initializer"
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "El resultado de la función '%s' en %L no puede tener un inicializador"
 
-#: fortran/resolve.c:12241
+#: fortran/resolve.c:12261
 #, fuzzy, gcc-internal-format
 #| msgid "Automatic array '%s' at %L cannot have an initializer"
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "La matriz automática '%s' en %L no puede tener un inicializador"
 
-#: fortran/resolve.c:12283
+#: fortran/resolve.c:12303
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "fstat %s"
 msgid "%s at %L"
 msgstr "fstat %s"
 
-#: fortran/resolve.c:12310
+#: fortran/resolve.c:12330
 #, fuzzy, gcc-internal-format
 #| msgid "Character-valued statement function '%s' at %L must have constant length"
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "La función de declaración valuada con carácter '%s' en %L debe tener longitud constante"
 
-#: fortran/resolve.c:12332
+#: fortran/resolve.c:12352
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: '%s' is of a PRIVATE type and cannot be a dummy argument of '%s', which is PUBLIC at %L"
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "Fortran 2003: '%s' es de un tipo PRIVATE y no puede ser un argumento dummy de '%s', el cual es PUBLIC en %L"
 
-#: fortran/resolve.c:12354
+#: fortran/resolve.c:12374
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: Procedure '%s' in PUBLIC interface '%s' at %L takes dummy arguments of '%s' which is PRIVATE"
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr "Fortran 2003: El procedimiento '%s' en la interfaz PUBLIC '%s' en %L toma argumentos dummy de '%s' el cual es PRIVATE"
 
-#: fortran/resolve.c:12372
+#: fortran/resolve.c:12392
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L cannot have an initializer"
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "La función '%s' en %L no puede tener un inicializador"
 
-#: fortran/resolve.c:12381
+#: fortran/resolve.c:12401
 #, fuzzy, gcc-internal-format
 #| msgid "External object '%s' at %L may not have an initializer"
 msgid "External object %qs at %L may not have an initializer"
 msgstr "El objeto external '%s' en %L puede no tener un inicializador"
 
-#: fortran/resolve.c:12389
+#: fortran/resolve.c:12409
 #, fuzzy, gcc-internal-format
 #| msgid "ELEMENTAL function '%s' at %L must have a scalar result"
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "La función ELEMENTAL '%s' en %L debe tener un resultado escalar"
 
-#: fortran/resolve.c:12399
+#: fortran/resolve.c:12419
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' at %L may not have pointer or allocatable attribute"
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "La función de declaración '%s' en %L no debe tener atributo puntero o alojable"
 
-#: fortran/resolve.c:12418
+#: fortran/resolve.c:12438
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be array-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "La función CHARACTER(*) '%s' en %L no puede ser matriz-valuada"
 
-#: fortran/resolve.c:12422
+#: fortran/resolve.c:12442
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pointer-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "La función CHARACTER(*) '%s' en %L no puede ser puntero-valuada"
 
-#: fortran/resolve.c:12426
+#: fortran/resolve.c:12446
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "La función CHARACTER(*) '%s' en %L no puede ser pura"
 
-#: fortran/resolve.c:12430
+#: fortran/resolve.c:12450
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be recursive"
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "La función CHARACTER(*) '%s' en %L no puede ser recursiva"
 
-#: fortran/resolve.c:12443
+#: fortran/resolve.c:12463
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "La función CHARACTER(*) '%s' en %L no puede ser pura"
 
-#: fortran/resolve.c:12452
+#: fortran/resolve.c:12472
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' in %s at %L has no explicit interface"
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "El procedimiento '%s' en %s en %L no tiene una interfaz explícita"
 
-#: fortran/resolve.c:12458
+#: fortran/resolve.c:12478
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy procedure '%s' at %C cannot have a generic interface"
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "El procedimiento dummy '%s' en %C no puede tener una interfaz genérica"
 
-#: fortran/resolve.c:12470
+#: fortran/resolve.c:12490
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr "La variable '%s' en %L no puede tener los atributos ALLOCATABLE y BIND(C) al mismo tiempo"
 
-#: fortran/resolve.c:12527
+#: fortran/resolve.c:12547
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with SAVE attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "El atributo PROCEDURE genera un conflicto con el atributo SAVE en '%s' en %L"
 
-#: fortran/resolve.c:12533
+#: fortran/resolve.c:12553
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with INTENT attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "El atributo PROCEDURE genera un conflicto con el atributo INTENT en '%s' en %L"
 
-#: fortran/resolve.c:12539
+#: fortran/resolve.c:12559
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with RESULT attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "El atributo PROCEDURE genera un conflicto con el atributo RESULT en '%s' en %L"
 
-#: fortran/resolve.c:12547
+#: fortran/resolve.c:12567
 #, fuzzy, gcc-internal-format
 #| msgid "EXTERNAL attribute conflicts with FUNCTION attribute in '%s' at %L"
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "El atributo EXTERNAL genera un conflicto con el atributo FUNCTION en '%s' en %L"
 
-#: fortran/resolve.c:12553
+#: fortran/resolve.c:12573
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure pointer result '%s' at %L is missing the pointer attribute"
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr "Al resultado del puntero de procedimiento '%s' en %L le falta el atributo puntero"
 
-#: fortran/resolve.c:12596
+#: fortran/resolve.c:12616
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12604
+#: fortran/resolve.c:12624
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12612
+#: fortran/resolve.c:12632
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12621
+#: fortran/resolve.c:12641
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.c:12705
+#: fortran/resolve.c:12725
 #, fuzzy, gcc-internal-format
 #| msgid "FINAL procedure '%s' at %L is not a SUBROUTINE"
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "El procedimiento FINAL '%s' en %L no debe ser una SUBROUTINE"
 
-#: fortran/resolve.c:12714
+#: fortran/resolve.c:12734
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "El procedimiento FINAL en %L debe tener exactamente un argumento"
 
-#: fortran/resolve.c:12723
+#: fortran/resolve.c:12743
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of FINAL procedure at %L must be of type '%s'"
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "El argumento del procedimiento FINAL en %L debe ser de tipo '%s'"
 
-#: fortran/resolve.c:12731
+#: fortran/resolve.c:12751
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "El argumento del procedimiento FINAL en %L no debe ser un POINTER"
 
-#: fortran/resolve.c:12737
+#: fortran/resolve.c:12757
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "El argumento del procedimiento final en %L no debe ser ALLOCATABLE"
 
-#: fortran/resolve.c:12743
+#: fortran/resolve.c:12763
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "El argumento del procedimiento FINAL en %L no debe ser OPTIONAL"
 
-#: fortran/resolve.c:12751
+#: fortran/resolve.c:12771
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "El argumento del procedimiento FINAL en %L no debe ser INTENT(OUT)"
 
-#: fortran/resolve.c:12760
+#: fortran/resolve.c:12780
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "El procedimiento FINAL que no es escalar en %L debe tener un argumento sharp asumido"
 
-#: fortran/resolve.c:12782
+#: fortran/resolve.c:12802
 #, fuzzy, gcc-internal-format
 #| msgid "FINAL procedure '%s' declared at %L has the same rank (%d) as '%s'"
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "El procedimiento FINAL '%s' declarado en %L tiene el mismo rango (%d) que '%s'"
 
-#: fortran/resolve.c:12819
+#: fortran/resolve.c:12839
 #, fuzzy, gcc-internal-format
 #| msgid "Only array FINAL procedures declared for derived type '%s' defined at %L, suggest also scalar one"
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr "Sólo se declaran procedimientos FINAL de matriz para el tipo derivado '%s' definido en %L, se sugiere también uno escalar"
 
-#: fortran/resolve.c:12859
+#: fortran/resolve.c:12879
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' and '%s' can't be mixed FUNCTION/SUBROUTINE for GENERIC '%s' at %L"
 msgid "%qs and %qs can't be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr "'%s' y '%s' no pueden ser FUNCTION/SUBROUTINE mezcladas para el GENERIC '%s' en %L"
 
-#: fortran/resolve.c:12895
+#: fortran/resolve.c:12915
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' and '%s' for GENERIC '%s' at %L are ambiguous"
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr "'%s' y '%s' para el GENERIC '%s' en %L son ambiguos"
 
-#: fortran/resolve.c:12954
+#: fortran/resolve.c:12974
 #, fuzzy, gcc-internal-format
 #| msgid "Undefined specific binding '%s' as target of GENERIC '%s' at %L"
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr "El enlace específico '%s' no está definido como objetivo del GENERIC '%s' en %L"
 
-#: fortran/resolve.c:12966
+#: fortran/resolve.c:12986
 #, fuzzy, gcc-internal-format
 #| msgid "GENERIC '%s' at %L must target a specific binding, '%s' is GENERIC, too"
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr "El GENERIC '%s' en %L debe apuntar a un enlace específico, '%s' es GENERIC también"
 
-#: fortran/resolve.c:12994
+#: fortran/resolve.c:13014
 #, fuzzy, gcc-internal-format
 #| msgid "GENERIC '%s' at %L can't overwrite specific binding with the same name"
 msgid "GENERIC %qs at %L can't overwrite specific binding with the same name"
 msgstr "El GENERIC '%s' en %L no puede sobreescribir el enlace específico con el mismo nombre"
 
-#: fortran/resolve.c:13050
+#: fortran/resolve.c:13070
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L can't be NOPASS"
 msgstr "El operador enlazado a tipo en %L no puede ser NOPASS"
 
-#: fortran/resolve.c:13242
+#: fortran/resolve.c:13262
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' must be a module procedure or an external procedure with an explicit interface at %L"
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "'%s' debe ser un procedimiento de módulo o un procedimiento externo con una interfaz explícita en %L"
 
-#: fortran/resolve.c:13284
+#: fortran/resolve.c:13304
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' with PASS(%s) at %L has no argument '%s'"
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "El procedimiento '%s' con PASS(%s) en %L no tiene un argumento '%s'"
 
-#: fortran/resolve.c:13298
+#: fortran/resolve.c:13318
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' with PASS at %L must have at least one argument"
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "El procedimiento '%s' con PASS en %L debe tener al menos un argumento"
 
-#: fortran/resolve.c:13312 fortran/resolve.c:13778
+#: fortran/resolve.c:13332 fortran/resolve.c:13798
 #, fuzzy, gcc-internal-format
 #| msgid "Non-polymorphic passed-object dummy argument of '%s' at %L"
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "Argumento dummy pasado como objeto no polimórfico de '%s' en %L"
 
-#: fortran/resolve.c:13320
+#: fortran/resolve.c:13340
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L must be of the derived-type '%s'"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "El argumento '%s' de '%s' con PASS(%s) en %L debe ser del tipo derivado '%s'"
 
-#: fortran/resolve.c:13329
+#: fortran/resolve.c:13349
 #, fuzzy, gcc-internal-format
 #| msgid "Passed-object dummy argument of '%s' at %L must be scalar"
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "El argumento dummy de objeto pasado de '%s' en %L debe ser escalar"
 
-#: fortran/resolve.c:13335
+#: fortran/resolve.c:13355
 #, fuzzy, gcc-internal-format
 #| msgid "Passed-object dummy argument of '%s' at %L must not be ALLOCATABLE"
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "El argumento dummy de objeto pasado de '%s' en %L no debe ser ALLOCATABLE"
 
-#: fortran/resolve.c:13341
+#: fortran/resolve.c:13361
 #, fuzzy, gcc-internal-format
 #| msgid "Passed-object dummy argument of '%s' at %L must not be POINTER"
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "El argumento dummy de objeto pasado de '%s' en %L no debe ser POINTER"
 
-#: fortran/resolve.c:13370
+#: fortran/resolve.c:13390
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L has the same name as a component of '%s'"
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "El procedimiento '%s' en %L tiene el mismo nombre que un componente de '%s'"
 
-#: fortran/resolve.c:13380
+#: fortran/resolve.c:13400
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L has the same name as an inherited component of '%s'"
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "El procedimiento '%s' en %L tiene el mismo nombre que un componente heredado de '%s'"
 
-#: fortran/resolve.c:13472
+#: fortran/resolve.c:13492
 #, fuzzy, gcc-internal-format
 #| msgid "Derived-type '%s' declared at %L must be ABSTRACT because '%s' is DEFERRED and not overridden"
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr "El tipo derivado '%s' declarado en %L debe ser ABSTRACT porque '%s' es DEFERRED y no se sobreescribió"
 
-#: fortran/resolve.c:13574
+#: fortran/resolve.c:13594
 #, fuzzy, gcc-internal-format
 #| msgid "Coarray component '%s' at %L must be allocatable with deferred shape"
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "El componente de comatriz '%s' en %L debe sel alojable con forma diferida"
 
-#: fortran/resolve.c:13583
+#: fortran/resolve.c:13603
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "El componente '%s' en %L de TYPE(C_PTR) o TYPE(C_FUNPTR) no debe ser una comatriz"
 
-#: fortran/resolve.c:13593
+#: fortran/resolve.c:13613
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr "El componenten '%s' en %L con componente comatriz debe ser un escalar que no sea puntero alojable"
 
-#: fortran/resolve.c:13602
+#: fortran/resolve.c:13622
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr "El componente '%s' en %L tiene el atributo CONTIGUOUS porque no es un puntero de matriz"
 
-#: fortran/resolve.c:13613
+#: fortran/resolve.c:13633
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ICHAR at %L must be of length one"
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "El argumento de ICHAR en %L debe ser de longitud uno"
 
-#: fortran/resolve.c:13711
+#: fortran/resolve.c:13731
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure pointer component '%s' with PASS(%s) at %L has no argument '%s'"
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "El procedimiento de componente puntero '%s' con PASS(%s) en %L no tiene un argumento '%s'"
 
-#: fortran/resolve.c:13725
+#: fortran/resolve.c:13745
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure pointer component '%s' with PASS at %L must have at least one argument"
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "El procedimiento de componente puntero '%s' con PASS en %L debe tener al menos un argumento"
 
-#: fortran/resolve.c:13741
+#: fortran/resolve.c:13761
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L must be of the derived type '%s'"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "El argumento '%s' de '%s' con PASS(%s) en %L debe ser del tipo derivado '%s'"
 
-#: fortran/resolve.c:13751
+#: fortran/resolve.c:13771
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L must be scalar"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "El argumento '%s' de '%s' con PASS(%s) en %L debe ser escalar"
 
-#: fortran/resolve.c:13760
+#: fortran/resolve.c:13780
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L may not have the POINTER attribute"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "El argumento '%s' de '%s' con PASS(%s) en %L no puede tener el atributo POINTER"
 
-#: fortran/resolve.c:13769
+#: fortran/resolve.c:13789
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L may not be ALLOCATABLE"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "El argumento '%s' de '%s' con PASS(%s) en %L no puede ser ALLOCATABLE"
 
-#: fortran/resolve.c:13811
+#: fortran/resolve.c:13831
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' of '%s' at %L has the same name as an inherited type-bound procedure"
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "El componente '%s' de '%s' en %L tiene el mismo nombre que un procedimiento enlazado a tipo heredado"
 
-#: fortran/resolve.c:13824
+#: fortran/resolve.c:13844
 #, fuzzy, gcc-internal-format
 #| msgid "Character length of component '%s' needs to be a constant specification expression at %L"
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "La longitud de carácter del componente '%s' necesita ser una expresión de especificación constante en %L"
 
-#: fortran/resolve.c:13835
+#: fortran/resolve.c:13855
 #, fuzzy, gcc-internal-format
 #| msgid "Character component '%s' of '%s' at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr "El componente de carácter '%s' de '%s' en %L con longitud diferida debe ser POINTER o ALLOCATABLE"
 
-#: fortran/resolve.c:13868
+#: fortran/resolve.c:13888
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: the component '%s' is a PRIVATE type and cannot be a component of '%s', which is PUBLIC at %L"
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "Fortran 2003: el componente '%s' es un tipo PRIVATE y no puede ser un componente de '%s' el cual es PUBLIC en %L"
 
-#: fortran/resolve.c:13876
+#: fortran/resolve.c:13896
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr "El componente polimórfico %s en %L en SEQUENCE o de tipo BIND(C) %s"
 
-#: fortran/resolve.c:13885
+#: fortran/resolve.c:13905
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "El componente %s del tipo SEQUENCE declarado en %L no tiene el atributo SEQUENCE"
 
-#: fortran/resolve.c:13903 fortran/resolve.c:13915
+#: fortran/resolve.c:13923 fortran/resolve.c:13935
 #, fuzzy, gcc-internal-format
 #| msgid "The pointer component '%s' of '%s' at %L is a type that has not been declared"
 msgid "The pointer component %qs of %qs at %L is a type that has not been declared"
 msgstr "El componente puntero '%s' de '%s' en %L es de un tipo que no se ha declarado"
 
-#: fortran/resolve.c:13989
+#: fortran/resolve.c:14009
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Conflicting I/O control specifications at %0 and %1"
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "Especificaciones de control de E/S en conflicto en %0 y %1"
 
-#: fortran/resolve.c:14034
+#: fortran/resolve.c:14054
 #, fuzzy, gcc-internal-format
 #| msgid "As extending type '%s' at %L has a coarray component, parent type '%s' shall also have one"
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr "Como al extender el tipo '%s' en %L tiene un componente de comatriz, el tipo padre '%s' también debe tener uno"
 
-#: fortran/resolve.c:14047
+#: fortran/resolve.c:14067
 #, fuzzy, gcc-internal-format
 #| msgid "Non-extensible derived-type '%s' at %L must not be ABSTRACT"
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "El tipo derivado '%s' que no es extensible en %L no debe ser ABSTRACT"
 
-#: fortran/resolve.c:14111
+#: fortran/resolve.c:14131
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14144
+#: fortran/resolve.c:14164
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: Generic name '%s' of function '%s' at %L being the same name as derived type at %L"
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr "Fortran 2003: El nombre genérico '%s' de la función '%s' en %L tiene el mismo nombre que el tipo derivado en %L"
 
-#: fortran/resolve.c:14216
+#: fortran/resolve.c:14236
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed size array '%s' in namelist '%s' at %L is not allowed"
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "No se permite la matriz de tamaño asumido '%s' en la lista de nombres '%s' en %L"
 
-#: fortran/resolve.c:14222
+#: fortran/resolve.c:14242
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: NAMELIST array object '%s' with assumed shape in namelist '%s' at %L"
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "Fortran 2003: Objeto de matriz NAMELIST '%s' con forma asumida en la lista de nombres '%s' en %L"
 
-#: fortran/resolve.c:14228
+#: fortran/resolve.c:14248
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: NAMELIST array object '%s' with nonconstant shape in namelist '%s' at %L"
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "Fortran 2003: El objeto de matriz NAMELIST '%s' con forma que no es constante en la lista de nombres '%s' en %L"
 
-#: fortran/resolve.c:14236
+#: fortran/resolve.c:14256
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: NAMELIST object '%s' with nonconstant character length in namelist '%s' at %L"
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "Fortran 2003: El objeto de matriz NAMELIST '%s' con longitud de carácter que no es constante en la lista de nombres '%s' en %L"
 
-#: fortran/resolve.c:14253
+#: fortran/resolve.c:14273
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' was declared PRIVATE and cannot be member of PUBLIC namelist '%s' at %L"
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "El objeto NAMELIST '%s' se declaró PRIVATE y no puede ser miembro de una lista de nombres PUBLIC '%s' en %L"
 
-#: fortran/resolve.c:14275
+#: fortran/resolve.c:14295
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' has use-associated PRIVATE components and cannot be member of namelist '%s' at %L"
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "El objeto NAMELIST '%s' tiene componentes PRIVATE asociados a uso y no puede ser miembro de la lista de nombres '%s' en %L"
 
-#: fortran/resolve.c:14286
+#: fortran/resolve.c:14306
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' has PRIVATE components and cannot be a member of PUBLIC namelist '%s' at %L"
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "El objeto NAMELIST '%s' tiene componentes PRIVATE y no puede ser un miembro de la lista de nombres PUBLIC '%s' en %L"
 
-#: fortran/resolve.c:14313
+#: fortran/resolve.c:14333
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "El atributo PROCEDURE genera un conflicto con el atributo NAMELIST en '%s' en %L"
 
-#: fortran/resolve.c:14337
+#: fortran/resolve.c:14357
 #, fuzzy, gcc-internal-format
 #| msgid "Parameter array '%s' at %L cannot be automatic or of deferred shape"
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "La matriz de parámetro '%s' en %L no puede ser automática ni de forma diferida"
 
-#: fortran/resolve.c:14353
+#: fortran/resolve.c:14373
 #, fuzzy, gcc-internal-format
 #| msgid "Implicitly typed PARAMETER '%s' at %L doesn't match a later IMPLICIT type"
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "El PARAMETER de tipo implícito '%s' en %L no coincide con un tipo IMPLICIT posterior"
 
-#: fortran/resolve.c:14364
+#: fortran/resolve.c:14384
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "Tipo derivado incompatible en PARAMETER en %L"
 
-#: fortran/resolve.c:14372
+#: fortran/resolve.c:14392
 #, fuzzy, gcc-internal-format
 #| msgid "COMMON block '%s' at %L can not have the EXTERNAL attribute"
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "El bloque COMMON '%s' en %L no puede tener el atributo EXTERNAL"
 
-#: fortran/resolve.c:14423
+#: fortran/resolve.c:14443
 #, fuzzy, gcc-internal-format
 #| msgid "Entity '%s' at %L has a deferred type parameter and requires either the pointer or allocatable attribute"
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr "La entidad '%s' en %L tiene un parámetro de tipo diferido y requiere el atributo pointer o allocatable"
 
-#: fortran/resolve.c:14434
+#: fortran/resolve.c:14454
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.c:14441
+#: fortran/resolve.c:14461
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.c:14480
+#: fortran/resolve.c:14500
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:14544
+#: fortran/resolve.c:14564
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "El atributo PROTECTED genera un conflicto con el atributo EXTERNAL en %L"
 
-#: fortran/resolve.c:14547
+#: fortran/resolve.c:14567
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "El atributo PROCEDURE genera un conflicto con el atributo PROTECTED en %L"
 
-#: fortran/resolve.c:14643
+#: fortran/resolve.c:14663
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape array"
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr "'%s' en %L tiene el atributo CONTIGUOUS pero no es un puntero de matriz o una matriz de forma asumida"
 
-#: fortran/resolve.c:14664
+#: fortran/resolve.c:14684
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad specification for assumed size array at %C"
 msgid "Bad specification for assumed size array at %L"
 msgstr "Especificación errónea para la matriz de tamaño asumido en %C"
 
-#: fortran/resolve.c:14677
+#: fortran/resolve.c:14697
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "La matriz de tamaño asumido en %L debe ser un argumento de prueba"
 
-#: fortran/resolve.c:14680
+#: fortran/resolve.c:14700
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "La matriz de forma asumida en %L debe ser un argumento de prueba"
 
-#: fortran/resolve.c:14688
+#: fortran/resolve.c:14708
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "La matriz de forma asumida en %L debe ser un argumento de prueba"
 
-#: fortran/resolve.c:14695
+#: fortran/resolve.c:14715
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:14708
+#: fortran/resolve.c:14728
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "El símbolo en %L no es una variable DUMMY"
 
-#: fortran/resolve.c:14714
+#: fortran/resolve.c:14734
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "'%s' en %L no puede tener el atributo VALUE porque no es un argumento dummy"
 
-#: fortran/resolve.c:14724
+#: fortran/resolve.c:14744
 #, fuzzy, gcc-internal-format
 #| msgid "Character dummy variable '%s' at %L with VALUE attribute must have constant length"
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "La variable dummy de carácter '%s' en %L con atributo VALUE debe tener longitud constante"
 
-#: fortran/resolve.c:14733
+#: fortran/resolve.c:14753
 #, fuzzy, gcc-internal-format
 #| msgid "C interoperable character dummy variable '%s' at %L with VALUE attribute must have length one"
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "La variable dummy de carácter interoperable con C '%s' en %L con atributo VALUE debe ser de longitud uno"
 
-#: fortran/resolve.c:14746 fortran/resolve.c:14923
+#: fortran/resolve.c:14766 fortran/resolve.c:14943
 #, fuzzy, gcc-internal-format
 #| msgid "The derived type '%s' at %L is of type '%s', which has not been defined"
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "El tipo derivado '%s' en %L es de tipo '%s', el cual no se ha definido"
 
-#: fortran/resolve.c:14760
+#: fortran/resolve.c:14780
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14769
+#: fortran/resolve.c:14789
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:14778
+#: fortran/resolve.c:14798
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "La variable '%s' en %L no puede tener los atributos ALLOCATABLE y BIND(C) al mismo tiempo"
 
-#: fortran/resolve.c:14786
+#: fortran/resolve.c:14806
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "La variable '%s' en %L no puede tener los atributos POINTER y BIND(C) al mismo tiempo"
 
-#: fortran/resolve.c:14793
+#: fortran/resolve.c:14813
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape array"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr "'%s' en %L tiene el atributo CONTIGUOUS pero no es un puntero de matriz o una matriz de forma asumida"
 
-#: fortran/resolve.c:14813
+#: fortran/resolve.c:14833
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array '%s' at %L is not permitted in an initialization expression"
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "No se permite la matriz de forma asumida '%s' en %L en una expresión de inicialización"
 
-#: fortran/resolve.c:14820
+#: fortran/resolve.c:14840
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "La variable '%s' en %L no puede tener los atributos ALLOCATABLE y BIND(C) al mismo tiempo"
 
-#: fortran/resolve.c:14827
+#: fortran/resolve.c:14847
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "La variable '%s' en %L no puede tener los atributos POINTER y BIND(C) al mismo tiempo"
 
-#: fortran/resolve.c:14834
+#: fortran/resolve.c:14854
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Loop variable at %C cannot be a coarray"
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr "La variable de bucle en %C no puede ser una comatriz"
 
-#: fortran/resolve.c:14860
+#: fortran/resolve.c:14880
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr "La variable '%s' en %L no puede ser BIND(C) porque no es un bloque COMMON ni se declaró en el ámbito de nivel de módulo"
 
-#: fortran/resolve.c:14870
+#: fortran/resolve.c:14890
 #, fuzzy, gcc-internal-format
 #| msgid "COMMON variable '%s' at %L must have constant character length"
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "La variable COMMON '%s' en %L debe tener longitud de cáracter constante en este contexto"
 
-#: fortran/resolve.c:14949
+#: fortran/resolve.c:14969
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: PUBLIC %s '%s' at %L of PRIVATE derived type '%s'"
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "Fortran 2003: La función PUBLIC %s '%s' en %L es de tipo derivado PRIVATE '%s'"
 
-#: fortran/resolve.c:14964
+#: fortran/resolve.c:14984
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr "La variable %s en %L de tipo LOCK_TYPE o con un subcomponente de tipo LOCK_TYPE debe ser una comatriz"
 
-#: fortran/resolve.c:14977
+#: fortran/resolve.c:14997
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr "La variable %s en %L de tipo LOCK_TYPE o con un subcomponente de tipo LOCK_TYPE debe ser una comatriz"
 
-#: fortran/resolve.c:14995
+#: fortran/resolve.c:15015
 #, fuzzy, gcc-internal-format
 #| msgid "The INTENT(OUT) dummy argument '%s' at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "El argumento dummy INTENT(OUT) '%s' en %L es ASSUMED SIZE y por lo tanto no puede tener un inicializador por defecto"
 
-#: fortran/resolve.c:15007
+#: fortran/resolve.c:15027
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "El argumento dummy '%s' en %L de LOCK_TYPE no puede ser INTENT(OUT)"
 
-#: fortran/resolve.c:15016
+#: fortran/resolve.c:15036
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "El argumento dummy '%s' en %L de LOCK_TYPE no puede ser INTENT(OUT)"
 
-#: fortran/resolve.c:15028
+#: fortran/resolve.c:15048
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L shall not be a coarray or have a coarray component"
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "El resultado de la función '%s' en %L no puede ser una comatriz o tener un componente comatriz"
 
-#: fortran/resolve.c:15037
+#: fortran/resolve.c:15057
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "La variable '%s' en %L de TYPE(C_PTR) o TYPE(C_FUNPTR) no debe ser una comatriz"
 
-#: fortran/resolve.c:15049
+#: fortran/resolve.c:15069
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr "La variable '%s' en %L con componente de comatriz debe ser un escalar que no sea puntero alojable"
 
-#: fortran/resolve.c:15065
+#: fortran/resolve.c:15085
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr "La variable '%s' en %L es una comatriz y no es ALLOCATABLE, SAVE ni un argumento dummy"
 
-#: fortran/resolve.c:15073
+#: fortran/resolve.c:15093
 #, fuzzy, gcc-internal-format
 #| msgid "Coarray variable '%s' at %L shall not have codimensions with deferred shape"
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "La variable de comatriz '%s' en %L no debe tener codimensiones con forma diferida"
 
-#: fortran/resolve.c:15080
+#: fortran/resolve.c:15100
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable coarray variable '%s' at %L must have deferred shape"
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "La variable comatriz allocatable '%s' en %L debe tener forma diferida"
 
-#: fortran/resolve.c:15092
+#: fortran/resolve.c:15112
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "La variable '%s' en %L es INTENT(OUT) y por lo tanto no puede ser una comatriz allocatable o tener componentes comatriz"
 
-#: fortran/resolve.c:15101
+#: fortran/resolve.c:15121
 #, fuzzy, gcc-internal-format
 #| msgid "Coarray dummy variable '%s' at %L not allowed in BIND(C) procedure '%s'"
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "No se permite la variable dummy comatriz '%s' en %L en el procedimiento BIND(C) '%s'"
 
-#: fortran/resolve.c:15117
+#: fortran/resolve.c:15137
 #, fuzzy, gcc-internal-format
 #| msgid "Coarray dummy variable '%s' at %L not allowed in BIND(C) procedure '%s'"
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "No se permite la variable dummy comatriz '%s' en %L en el procedimiento BIND(C) '%s'"
 
-#: fortran/resolve.c:15123
+#: fortran/resolve.c:15143
 #, fuzzy, gcc-internal-format
 #| msgid "Coarray dummy variable '%s' at %L not allowed in BIND(C) procedure '%s'"
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "No se permite la variable dummy comatriz '%s' en %L en el procedimiento BIND(C) '%s'"
 
-#: fortran/resolve.c:15148
+#: fortran/resolve.c:15168
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist %s cannot be renamed by USE association to %s"
 msgid "Namelist %qs can not be an argument to subroutine or function at %L"
 msgstr "La lista de nombres %s no se puede renombrar por asociación de USE a %s"
 
-#: fortran/resolve.c:15218
+#: fortran/resolve.c:15238
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "No se guarda (SAVE) el threadprivate en %L"
 
-#: fortran/resolve.c:15229
+#: fortran/resolve.c:15249
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:15333
+#: fortran/resolve.c:15353
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:15339
+#: fortran/resolve.c:15359
 #, fuzzy, gcc-internal-format
 #| msgid "BLOCK DATA element '%s' at %L must be in COMMON"
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "El elemento BLOCK DATA '%s' en %L debe estar en COMMON"
 
-#: fortran/resolve.c:15345
+#: fortran/resolve.c:15365
 #, fuzzy, gcc-internal-format
 #| msgid "DATA array '%s' at %L must be specified in a previous declaration"
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "La matriz DATA '%s' en %L se debe especificar en una declaración previa"
 
-#: fortran/resolve.c:15354
+#: fortran/resolve.c:15374
 #, fuzzy, gcc-internal-format
 #| msgid "DATA element '%s' at %L cannot have a coindex"
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "El elemento DATA '%s' en %L no puede tener un coíndice"
 
-#: fortran/resolve.c:15368
+#: fortran/resolve.c:15388
 #, fuzzy, gcc-internal-format
 #| msgid "DATA element '%s' at %L is a pointer and so must be a full array"
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr "El elemento DATA '%s' en %L es un puntero y entonces debe ser una matriz completa"
 
-#: fortran/resolve.c:15414
+#: fortran/resolve.c:15434
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "Sección de matriz no constante en %L en la declaración DATA"
 
-#: fortran/resolve.c:15427
+#: fortran/resolve.c:15447
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "La declaración DATA en %L tiene más variables que valores"
 
-#: fortran/resolve.c:15526
+#: fortran/resolve.c:15546
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr "el inicio del bucle do implícito en %L no se puede simplificar a un valor constante"
 
-#: fortran/resolve.c:15534
+#: fortran/resolve.c:15554
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr "el final del bucle do implícito en %L no se puede simplificar a un valor constante"
 
-#: fortran/resolve.c:15542
+#: fortran/resolve.c:15562
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr "el paso del bucle do implícito en %L no se puede simplificar a un valor constante"
 
-#: fortran/resolve.c:15667
+#: fortran/resolve.c:15687
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "La declaración DATA en %L tiene más valores que variables"
 
-#: fortran/resolve.c:15832
+#: fortran/resolve.c:15852
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "Se define la etiqueta %d en %L pero no se usa"
 
-#: fortran/resolve.c:15838
+#: fortran/resolve.c:15858
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "Se define la etiqueta %d en %L pero no se puede usar"
 
-#: fortran/resolve.c:15922
+#: fortran/resolve.c:15942
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "La variable de tipo derivado '%s' en %L debe tener el atributo SEQUENCE para ser un objeto EQUIVALENCE"
 
-#: fortran/resolve.c:15931
+#: fortran/resolve.c:15951
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "La variable de tipo derivado '%s' en %L no puede tener componentes ALLOCATABLE que sean un objeto EQUIVALENCE"
 
-#: fortran/resolve.c:15939
+#: fortran/resolve.c:15959
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "La variable de tipo derivado '%s' en %L con inicializadores por defecto no puede ser un objeto EQUIVALENCE con una variable en COMMON"
 
-#: fortran/resolve.c:15955
+#: fortran/resolve.c:15975
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "La variable de tipo derivado '%s' en %L con componente(s) de puntero no puede ser un objeto EQUIVALENCE"
 
-#: fortran/resolve.c:16058
+#: fortran/resolve.c:16078
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "Error sintáctico en la declaración EQUIVALENCE en %L"
 
-#: fortran/resolve.c:16073
+#: fortran/resolve.c:16093
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr "Todos o ninguno de los objetos en el conjunto EQUIVALENCE en %L deben tener el atributo PROTECTED"
 
-#: fortran/resolve.c:16098
+#: fortran/resolve.c:16118
 #, fuzzy, gcc-internal-format
 #| msgid "Common block member '%s' at %L cannot be an EQUIVALENCE object in the pure procedure '%s'"
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "El miembro de bloque común '%s' en %L no puede ser un objeto EQUIVALENCE en el procedimiento puro '%s'"
 
-#: fortran/resolve.c:16107
+#: fortran/resolve.c:16127
 #, fuzzy, gcc-internal-format
 #| msgid "Named constant '%s' at %L cannot be an EQUIVALENCE object"
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "La constante nombrada '%s' en %L no puede ser un objeto EQUIVALENCE"
 
-#: fortran/resolve.c:16180
+#: fortran/resolve.c:16200
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "La matriz '%s' en %L con límites que no son constantes no puede ser un objeto EQUIVALENCE"
 
-#: fortran/resolve.c:16191
+#: fortran/resolve.c:16211
 #, fuzzy, gcc-internal-format
 #| msgid "Structure component '%s' at %L cannot be an EQUIVALENCE object"
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "El componente de estructura '%s' en %L no puede ser un objeto EQUIVALENCE"
 
-#: fortran/resolve.c:16202
+#: fortran/resolve.c:16222
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "La subcadena en %L tiene longitud cero"
 
-#: fortran/resolve.c:16293
+#: fortran/resolve.c:16253
 #, fuzzy, gcc-internal-format
+#| msgid "Different character lengths in pointer assignment at %L"
+msgid "Self reference in character length expression for %qs at %L"
+msgstr "Longitudes de carácter diferentes en la asignación de puntero en %L"
+
+#: fortran/resolve.c:16320
+#, fuzzy, gcc-internal-format
 #| msgid "PUBLIC function '%s' at %L cannot be of PRIVATE type '%s'"
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "La función PUBLIC '%s' en %L no puede ser del tipo PRIVATE '%s'"
 
-#: fortran/resolve.c:16306
+#: fortran/resolve.c:16333
 #, fuzzy, gcc-internal-format
 #| msgid "ENTRY '%s' at %L has no IMPLICIT type"
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "ENTRY '%s' en %L no tiene tipo IMPLICIT"
 
-#: fortran/resolve.c:16326
+#: fortran/resolve.c:16353
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must be a FUNCTION"
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "El procedimiento de operador de usuario '%s' en %L debe ser FUNCTION"
 
-#: fortran/resolve.c:16336
+#: fortran/resolve.c:16363
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L cannot be assumed character length"
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "El procedimiento de operador de usuario '%s' en %L no puede ser de longitud de carácter asumido"
 
-#: fortran/resolve.c:16344
+#: fortran/resolve.c:16371
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "El procedimiento de operador de usuario '%s' en %L debe tener al menos un argumento"
 
-#: fortran/resolve.c:16358
+#: fortran/resolve.c:16385
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "El primer argumento de la interfaz de operador en %L no puede ser opcional"
 
-#: fortran/resolve.c:16376
+#: fortran/resolve.c:16403
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "El segundo argumento de la interfaz de operador en %L no puede ser opcional"
 
-#: fortran/resolve.c:16383
+#: fortran/resolve.c:16410
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "La interfaz de operador en %L debe tener, cuando mucho, dos argumentos"
 
-#: fortran/resolve.c:16461
+#: fortran/resolve.c:16488
 #, fuzzy, gcc-internal-format
 #| msgid "Contained procedure '%s' at %L of a PURE procedure must also be PURE"
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
@@ -62994,19 +63089,13 @@
 msgid "simplify_min_max(): Bad type in arglist"
 msgstr ""
 
-#. Result is processor-dependent.
-#: fortran/simplify.c:5472
-#, gcc-internal-format, gfc-internal-format
-msgid "Second argument MOD at %L is zero"
-msgstr "El segundo argumento MOD en %L es cero"
+#: fortran/simplify.c:5470 fortran/simplify.c:5478
+#, fuzzy, gcc-internal-format
+#| msgid "Argument 'S' of NEAREST at %L shall not be zero"
+msgid "Argument %qs of MOD at %L shall not be zero"
+msgstr "El argumento 'S' de NEAREST en %L no puede ser cero"
 
-#. Result is processor-dependent.
-#: fortran/simplify.c:5483
-#, gcc-internal-format, gfc-internal-format
-msgid "Second argument of MOD at %L is zero"
-msgstr "El segundo argumento de MOD en %L es cero"
-
-#: fortran/simplify.c:5494
+#: fortran/simplify.c:5484
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_simplify_mod(): Bad arguments"
@@ -63015,103 +63104,103 @@
 #. Result is processor-dependent. This processor just opts
 #. to not handle it at all.
 #. Result is processor-dependent.
-#: fortran/simplify.c:5520 fortran/simplify.c:5532
+#: fortran/simplify.c:5525 fortran/simplify.c:5537
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of MODULO at %L is zero"
 msgstr "El segundo argumento de MODULO en %L es cero"
 
-#: fortran/simplify.c:5552
+#: fortran/simplify.c:5557
 #, gcc-internal-format
 msgid "gfc_simplify_modulo(): Bad arguments"
 msgstr ""
 
-#: fortran/simplify.c:5600
+#: fortran/simplify.c:5605
 #, gcc-internal-format, gfc-internal-format
 msgid "Result of NEAREST is NaN at %L"
 msgstr "El resultado de NEAREST es NaN en %L"
 
-#: fortran/simplify.c:6081
+#: fortran/simplify.c:6086
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative at %L"
 msgstr "El argumento NCOPIES del intrínseco REPEAT es negativo en %L"
 
-#: fortran/simplify.c:6137
+#: fortran/simplify.c:6142
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument NCOPIES of REPEAT intrinsic is too large at %L"
 msgstr "El argumento NCOPIES del intrínseco REPEAT es demasiado grande en %L"
 
-#: fortran/simplify.c:6174
+#: fortran/simplify.c:6179
 #, gcc-internal-format, gfc-internal-format
 msgid "Evaluation of string longer than 2**28 at %L deferred to runtime, expect bugs"
 msgstr ""
 
-#: fortran/simplify.c:6302
+#: fortran/simplify.c:6307
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Integer too large at %C"
 msgid "Reshaped array too large at %C"
 msgstr "Entero demasiado grande en %C"
 
-#: fortran/simplify.c:6416
+#: fortran/simplify.c:6421
 #, gcc-internal-format, gfc-internal-format
 msgid "Result of SCALE overflows its kind at %L"
 msgstr "El resultado de SCALE desborda su género en %L"
 
-#: fortran/simplify.c:6995
+#: fortran/simplify.c:7000
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "Bad type in gfc_simplify_sign"
 msgstr "Tipo erróneo en la expresión constante"
 
-#: fortran/simplify.c:7024
+#: fortran/simplify.c:7029
 #, gcc-internal-format
 msgid "in gfc_simplify_sin(): Bad type"
 msgstr ""
 
-#: fortran/simplify.c:7151 fortran/simplify.c:7431
+#: fortran/simplify.c:7156 fortran/simplify.c:7436
 #, gcc-internal-format
 msgid "Failure getting length of a constant array."
 msgstr ""
 
-#: fortran/simplify.c:7161
+#: fortran/simplify.c:7166
 #, fuzzy, gcc-internal-format
 #| msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit.   See -fmax-array-constructor option"
 msgid "The number of elements (%d) in the array constructor at %L requires an increase of the allowed %d upper limit.  See %<-fmax-array-constructor%> option."
 msgstr "El número de elementos en el constructor de matriz en %L requiere un incremento del límite superior %d permitido.  Vea la opción -fmax-array-constructor."
 
-#: fortran/simplify.c:7227
+#: fortran/simplify.c:7232
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Finalization at %L is not yet implemented"
 msgid "Simplification of SPREAD at %C not yet implemented"
 msgstr "Aún no se admite la finalización en %L"
 
-#: fortran/simplify.c:7251
+#: fortran/simplify.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SQRT at %L has a negative value"
 msgstr "El argumento de SQRT en %L tiene un valor negativo"
 
-#: fortran/simplify.c:7267
+#: fortran/simplify.c:7272
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid second argument of IBSET at %L"
 msgid "invalid argument of SQRT at %L"
 msgstr "Segundo argumento de IBSET no válido en %L"
 
-#: fortran/simplify.c:7598
+#: fortran/simplify.c:7603
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY lower bound is %ld)"
 msgstr "Fuera de límites en IMAGE_INDEX en %L para la dimensión %d, SUB tiene %ld y el límite inferior de COARRAY  es %ld)"
 
-#: fortran/simplify.c:7621
+#: fortran/simplify.c:7626
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY upper bound is %ld)"
 msgstr "Fuera de límites en IMAGE_INDEX en %L para la dimensión %d, SUB tiene %ld y el límite superior de COARRAY es %ld)"
 
-#: fortran/simplify.c:7993
+#: fortran/simplify.c:7998
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_conv_constant_to_tree(): invalid type: %s"
 msgid "gfc_convert_constant(): Unexpected type"
 msgstr "gfc_conv_constant_to_tree(): tipo no válido: %s"
 
-#: fortran/simplify.c:8078
+#: fortran/simplify.c:8083
 #, fuzzy, gcc-internal-format
 #| msgid "Character '%s' in string at %L cannot be converted into character kind %d"
 msgid "Character %qs in string at %L cannot be converted into character kind %d"
@@ -63225,7 +63314,7 @@
 msgid "BIND(C) applied to %s %s at %L"
 msgstr "Se aplicó BIND(C) a %s %s en %L"
 
-#: fortran/symbol.c:901 fortran/symbol.c:912 fortran/symbol.c:1762
+#: fortran/symbol.c:901 fortran/symbol.c:912 fortran/symbol.c:1776
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute conflicts with %s attribute at %L"
 msgstr "El atributo %s genera un conflicto con el atributo %s en %L"
@@ -63304,18 +63393,24 @@
 msgid "Duplicate VOLATILE attribute specified at %L"
 msgstr "Se especificó un atributo VOLATILE duplicado en %L"
 
-#: fortran/symbol.c:1367
+#: fortran/symbol.c:1360
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "SAVE attribute at %L cannot be specified in a PURE procedure"
+msgid "VOLATILE attribute at %L cannot be specified in a PURE procedure"
+msgstr "El atributo SAVE en %L no se puede especificar en un procedimiento PURE"
+
+#: fortran/symbol.c:1381
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ASYNCHRONOUS attribute specified at %L"
 msgstr "Se especificó un atributo ASYNCHRONOUS duplicado en %L"
 
-#: fortran/symbol.c:1758
+#: fortran/symbol.c:1772
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute of '%s' conflicts with %s attribute at %L"
 msgid "%s attribute of %qs conflicts with %s attribute at %L"
 msgstr "El atributo %s de '%s' genera un conflicto con el atributo %s en %L"
 
-#: fortran/symbol.c:1794
+#: fortran/symbol.c:1808
 #, gcc-internal-format, gfc-internal-format
 msgid ""
 "%s procedure at %L is already declared as %s procedure. \n"
@@ -63322,163 +63417,163 @@
 "F2008: A pointer function assignment is ambiguous if it is the first executable statement after the specification block. Please add any other kind of executable statement before it. FIXME"
 msgstr ""
 
-#: fortran/symbol.c:1802
+#: fortran/symbol.c:1816
 #, gcc-internal-format, gfc-internal-format
 msgid "%s procedure at %L is already declared as %s procedure"
 msgstr "El procedimiento %s en %L ya se había declarado como un procedimiento %s"
 
-#: fortran/symbol.c:1837
+#: fortran/symbol.c:1851
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgstr "INTENT (%s) genera un conflicto con INTENT(%s) en %L"
 
-#: fortran/symbol.c:1861
+#: fortran/symbol.c:1875
 #, gcc-internal-format, gfc-internal-format
 msgid "ACCESS specification at %L was already specified"
 msgstr "La especificación ACCESS en %L ya se había especificado"
 
-#: fortran/symbol.c:1878
+#: fortran/symbol.c:1892
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate BIND attribute specified at %L"
 msgstr "Se especificó un atributo BIND duplicado en %L"
 
-#: fortran/symbol.c:1885
+#: fortran/symbol.c:1899
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid " BIND(C)"
 msgid "BIND(C) at %L"
 msgstr " BIND(C)"
 
-#: fortran/symbol.c:1901
+#: fortran/symbol.c:1915
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate EXTENDS attribute specified at %L"
 msgstr "Se especificó un atributo EXTENDS duplicado en %L"
 
-#: fortran/symbol.c:1905
+#: fortran/symbol.c:1919
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: EXTENDS at %L"
 msgid "EXTENDS at %L"
 msgstr "Fortran 2003: EXTENDS en %L"
 
-#: fortran/symbol.c:1931
+#: fortran/symbol.c:1945
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L already has an explicit interface"
 msgid "Symbol %qs at %L already has an explicit interface"
 msgstr "El símbolo '%s' en %L ya tenía una interfaz explícita"
 
-#: fortran/symbol.c:1938
+#: fortran/symbol.c:1952
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L has attributes specified outside its INTERFACE body"
 msgid "%qs at %L has attributes specified outside its INTERFACE body"
 msgstr "'%s' en %L tiene atributos especificados fuera de su cuerpo INTERFACE"
 
-#: fortran/symbol.c:1976
+#: fortran/symbol.c:1990
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L conflicts with symbol from module '%s', use-associated at %L"
 msgid "Symbol %qs at %L conflicts with symbol from module %qs, use-associated at %L"
 msgstr "El símbolo '%s' en %L genera conflictos con el símbolo del módulo '%s' asociado a uso en %L"
 
-#: fortran/symbol.c:1980
+#: fortran/symbol.c:1994
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L already has basic type of %s"
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr "El símbolo '%s' en %L ya tenía el tipo básico de %s"
 
-#: fortran/symbol.c:1987
+#: fortran/symbol.c:2001
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L may not have basic type of %s"
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr "El procedimiento '%s' en %L no puede tener el tipo básico de %s"
 
-#: fortran/symbol.c:1999
+#: fortran/symbol.c:2013
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L cannot have a type"
 msgid "Symbol %qs at %L cannot have a type"
 msgstr "El símbolo '%s' en %L no puede tener un tipo"
 
-#: fortran/symbol.c:2242
+#: fortran/symbol.c:2256
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C already in the parent type at %L"
 msgid "Component %qs at %C already in the parent type at %L"
 msgstr "El componente '%s' en %C ya estaba en el tipo padre en %L"
 
-#: fortran/symbol.c:2327
+#: fortran/symbol.c:2341
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C is ambiguous"
 msgid "Symbol %qs at %C is ambiguous"
 msgstr "El símbolo '%s' en %C es ambiguo"
 
-#: fortran/symbol.c:2359
+#: fortran/symbol.c:2373
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %C is being used before it is defined"
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr "El tipo derivado '%s' en %C se está usando antes de ser definido"
 
-#: fortran/symbol.c:2508
+#: fortran/symbol.c:2522
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C is a PRIVATE component of '%s'"
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr "El componente '%s' en %C es un componente PRIVATE de '%s'"
 
-#: fortran/symbol.c:2529
+#: fortran/symbol.c:2543
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is not a member of the '%s' structure"
 msgid "%qs at %C is not a member of the %qs structure; did you mean %qs?"
 msgstr "'%s' en %C no es un miembro de la estructura '%s'"
 
-#: fortran/symbol.c:2533
+#: fortran/symbol.c:2547
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is not a member of the '%s' structure"
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr "'%s' en %C no es un miembro de la estructura '%s'"
 
-#: fortran/symbol.c:2697
+#: fortran/symbol.c:2711
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr "Declaración de etiqueta %d duplicada en %L y %L"
 
-#: fortran/symbol.c:2708
+#: fortran/symbol.c:2722
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr "La etiqueta %d en %C ya se referenció como objetivo de ramificación"
 
-#: fortran/symbol.c:2718
+#: fortran/symbol.c:2732
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr "La etiqueta %d en %C ya se referenció como etiqueta de formato"
 
-#: fortran/symbol.c:2724
+#: fortran/symbol.c:2738
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:2766
+#: fortran/symbol.c:2780
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr "La etiqueta %d en %C se utilizó previamente como una etiqueta FORMAT"
 
-#: fortran/symbol.c:2775
+#: fortran/symbol.c:2789
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr "La etiqueta %d en %C se utilizó previamente como objetivo de ramificación"
 
-#: fortran/symbol.c:2781
+#: fortran/symbol.c:2795
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected terminating name at %C"
 msgid "Shared DO termination label %d at %C"
 msgstr "Se esperaba un nombre terminal en %C"
 
-#: fortran/symbol.c:3110
+#: fortran/symbol.c:3124
 #, gcc-internal-format
 msgid "new_symbol(): Symbol name too long"
 msgstr ""
 
-#: fortran/symbol.c:3135
+#: fortran/symbol.c:3149
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is an ambiguous reference to '%s' from module '%s'"
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr "El nombre '%s' en %C es una referencia ambigua a '%s' del módulo '%s'"
 
-#: fortran/symbol.c:3138
+#: fortran/symbol.c:3152
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is an ambiguous reference to '%s' from current program unit"
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
@@ -63485,72 +63580,72 @@
 msgstr "El nombre '%s' en %C es una referencia ambigua a '%s' de la unidad de programa actual"
 
 #. Symbol is from another namespace.
-#: fortran/symbol.c:3381
+#: fortran/symbol.c:3395
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C has already been host associated"
 msgid "Symbol %qs at %C has already been host associated"
 msgstr "El símbolo '%s' en %C ya se había asociado con el anfitrión"
 
-#: fortran/symbol.c:4397
+#: fortran/symbol.c:4411
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr ""
 
-#: fortran/symbol.c:4410
+#: fortran/symbol.c:4424
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' declared at %L must have the BIND attribute to be C interoperable"
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr "El tipo derivado '%s' declarado en %L debe tener el atributo BIND para ser interoperable con C"
 
-#: fortran/symbol.c:4428
+#: fortran/symbol.c:4442
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr "El tipo derivado '%s' con atributo BIND(C) en %L está vacío, y puede ser inaccesible para el procesador acompañante de C"
 
-#: fortran/symbol.c:4449
+#: fortran/symbol.c:4463
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type '%s' at %L"
 msgid "Component %qs at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr "El componente '%s' en %L no puede tener el atributo POINTER porque es un miembro del tipo derivado BIND(C) '%s' en %L"
 
-#: fortran/symbol.c:4459
+#: fortran/symbol.c:4473
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure pointer component '%s' at %L cannot be a member of the BIND(C) derived type '%s' at %L"
 msgid "Procedure pointer component %qs at %L cannot be a member of the BIND(C) derived type %qs at %L"
 msgstr "El procedimiento de componente puntero '%s' en %L no puede ser un miembro del tipo derivado BIND(C) '%s' en %L"
 
-#: fortran/symbol.c:4470
+#: fortran/symbol.c:4484
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type '%s' at %L"
 msgid "Component %qs at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr "El componente '%s' en %L no puede tener el atributo ALLOCATABLE porque es un miembro del tipo derivado BIND(C) '%s' en %L"
 
-#: fortran/symbol.c:4509
+#: fortran/symbol.c:4523
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' in derived type '%s' at %L may not be C interoperable, even though derived type '%s' is BIND(C)"
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr "El componente '%s' en el tipo derivado '%s' en %L tal vez no es interoperable con C, aún cuando el tipo derivado '%s' es BIND(C)"
 
-#: fortran/symbol.c:4519
+#: fortran/symbol.c:4533
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' in derived type '%s' at %L may not be C interoperable"
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr "El componente '%s' en el tipo derivado '%s' en %L tal vez no es interoperable con C"
 
-#: fortran/symbol.c:4533
+#: fortran/symbol.c:4547
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %L cannot be declared with both PRIVATE and BIND(C) attributes"
 msgid "Derived type %qs at %L cannot be declared with both PRIVATE and BIND(C) attributes"
 msgstr "El tipo derivado '%s' en %L no se puede declarar con atributos PRIVATE y BIND(C) al mismo tiempo"
 
-#: fortran/symbol.c:4541
+#: fortran/symbol.c:4555
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr "El tipo derivado '%s' en %L no puede tener el atributo SEQUENCE porque es BIND(C)"
 
-#: fortran/symbol.c:5018 fortran/symbol.c:5023
+#: fortran/symbol.c:5032 fortran/symbol.c:5037
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' is used before it is typed at %L"
 msgid "Symbol %qs is used before it is typed at %L"
@@ -63602,7 +63697,7 @@
 msgid "Creating array temporary at %L for argument %qs"
 msgstr "Se crea una matriz temporal en %L para el argumento '%s'"
 
-#: fortran/trans-array.c:10693
+#: fortran/trans-array.c:10724
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr "tipo de expresión errónea durante la caminata (%d)"
@@ -63830,13 +63925,13 @@
 msgid "%<dim%> argument of %s intrinsic at %L is not a valid dimension index"
 msgstr "el argumento 'dim' del intrínseco '%s' en %L no es un índice de dimensión válido"
 
-#: fortran/trans-intrinsic.c:10572 fortran/trans-stmt.c:1050
+#: fortran/trans-intrinsic.c:10574 fortran/trans-stmt.c:1050
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Deferred-length character component '%s' at %L is not yet supported"
 msgid "Sorry, the event component of derived type at %L is not yet supported"
 msgstr "El componente de caractér de longitud diferida '%s' en %L aún no se admite"
 
-#: fortran/trans-intrinsic.c:10579
+#: fortran/trans-intrinsic.c:10581
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer object at %C shall not be coindexed"
 msgid "The event variable at %L shall not be coindexed"
@@ -63879,7 +63974,7 @@
 msgid "Sorry, only support for integer kind %d implemented for image-set at %L"
 msgstr "Lo siento, sólo se admite integer kind %d implementado para el conjunto imagen en %L"
 
-#: fortran/trans-stmt.c:3346
+#: fortran/trans-stmt.c:3343
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_trans_select(): Bad type for case expr."
@@ -64021,7 +64116,7 @@
 msgid "two or more sections for %s"
 msgstr "dos o más secciones para %s"
 
-#: lto/lto-partition.c:516
+#: lto/lto-partition.c:570
 #, gcc-internal-format
 msgid "min partition size cannot be greater than max partition size"
 msgstr ""
@@ -64161,60 +64256,60 @@
 msgid "Cannot read %s"
 msgstr "No se puede leer %s"
 
-#: lto/lto.c:2369
+#: lto/lto.c:2337
 #, gcc-internal-format
 msgid "lto_obj_file_open() failed"
 msgstr "falló lto_obj_file_open()"
 
-#: lto/lto.c:2394
+#: lto/lto.c:2362
 #, fuzzy, gcc-internal-format
 #| msgid "atexit failed"
 msgid "waitpid failed"
 msgstr "falló atexit"
 
-#: lto/lto.c:2397
+#: lto/lto.c:2365
 #, fuzzy, gcc-internal-format
 #| msgid "renaming .rpo file: %m"
 msgid "streaming subprocess failed"
 msgstr "se renombra el fichero .rpo: %m"
 
-#: lto/lto.c:2400
+#: lto/lto.c:2368
 #, gcc-internal-format
 msgid "streaming subprocess was killed by signal"
 msgstr ""
 
-#: lto/lto.c:2476
+#: lto/lto.c:2445
 #, gcc-internal-format
 msgid "no LTRANS output list filename provided"
 msgstr "no se proporcionó el nombre de fichero de lista de salida TRANS"
 
-#: lto/lto.c:2564
+#: lto/lto.c:2525
 #, gcc-internal-format
 msgid "opening LTRANS output list %s: %m"
 msgstr "se abre la lista de salida LTRANS %s: %m"
 
-#: lto/lto.c:2570
+#: lto/lto.c:2532
 #, gcc-internal-format
 msgid "writing to LTRANS output list %s: %m"
 msgstr "se escribe a la lista de salida LTRANS %s: %m"
 
-#: lto/lto.c:2581
+#: lto/lto.c:2542
 #, gcc-internal-format
 msgid "closing LTRANS output list %s: %m"
 msgstr "se cierra la lista de salida LTRANS %s: %m"
 
-#: lto/lto.c:2833
+#: lto/lto.c:2794
 #, gcc-internal-format
 msgid "could not open symbol resolution file: %m"
 msgstr "no se puede abrir el fichero de resolución de símbolos: %m"
 
-#: lto/lto.c:2954
+#: lto/lto.c:2915
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing braces around initializer for %qT"
 msgid "missing resolution data for %s"
 msgstr "faltan llaves alrededor del inicializador para %qT"
 
-#: lto/lto.c:2986
+#: lto/lto.c:2947
 #, gcc-internal-format
 msgid "errors during merging of translation units"
 msgstr "errores durante la mezcla de unidades de traducción"
@@ -65157,7 +65252,24 @@
 msgid "creating selector for nonexistent method %qE"
 msgstr "se crea un selector para el método %qE que no existe"
 
+#~ msgid "Warn if the loop cannot be optimized due to nontrivial assumptions."
+#~ msgstr "Avisa si el bucle no se puede optimizar debido a presunciones no triviales."
+
 #, fuzzy
+#~| msgid "Extension: Old-style initialization at %C"
+#~ msgid "Expected constant array-spec in initializer list at %L"
+#~ msgstr "Extensión: Inicialización de estilo antiguo en %C"
+
+#~ msgid "Errmsg-variable at %L must be a scalar CHARACTER variable"
+#~ msgstr "La variable errmsg en %L debe ser una variable CHARACTER escalar"
+
+#~ msgid "Second argument MOD at %L is zero"
+#~ msgstr "El segundo argumento MOD en %L es cero"
+
+#~ msgid "Second argument of MOD at %L is zero"
+#~ msgstr "El segundo argumento de MOD en %L es cero"
+
+#, fuzzy
 #~| msgid "Support MMX and SSE built-in functions and code generation."
 #~ msgid "Support Control-flow Enforcement Technology (CET) built-in functions and code generation."
 #~ msgstr "Admite funciones internas y generación de código MMX y SSE."
@@ -66109,11 +66221,6 @@
 #~ msgstr "%q+D no puede tener el tipo de referencia %qT porque es el miembro de una unión"
 
 #, fuzzy
-#~| msgid "declared here"
-#~ msgid "  declared here"
-#~ msgstr "se declara aquí"
-
-#, fuzzy
 #~| msgid "%qD should be initialized"
 #~ msgid "%q#D initialized"
 #~ msgstr "%qD se debe inicializar"
@@ -69609,9 +69716,6 @@
 #~ msgid "not a relocatable ELF object file"
 #~ msgstr "no es un fichero objeto ELF reubicable"
 
-#~ msgid "inconsistent file architecture detected"
-#~ msgstr "se detectó una arquitectura de fichero inconsistente"
-
 #~ msgid "could not read ELF identification information: %s"
 #~ msgstr "no se puede leer la información de identificación ELF: %s"
 
@@ -70574,9 +70678,6 @@
 #~ msgid "Array PUT of intrinsic %s is too small (%i/%i) at %L"
 #~ msgstr "La matriz PUT del intrínseco %s es demasiado pequeña (%i/%i) en %L"
 
-#~ msgid "Different character lengths in pointer assignment at %L"
-#~ msgstr "Longitudes de carácter diferentes en la asignación de puntero en %L"
-
 #~ msgid "Reference to ENTRY '%s' at %L is recursive, but procedure '%s' is not declared as RECURSIVE"
 #~ msgstr "La referencia a ENTRY '%s' en %L es recursiva, pero el procedimiento '%s' no se declaró como RECURSIVE"
 
Index: gcc/po/fr.po
===================================================================
--- gcc/po/fr.po	(.../tags/gcc_8_2_0_release)
+++ gcc/po/fr.po	(.../branches/gcc-8-branch)
@@ -134,7 +134,7 @@
 msgstr ""
 "Project-Id-Version: gcc 8.1.0\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2018-05-01 20:30+0000\n"
+"POT-Creation-Date: 2018-07-25 14:25+0000\n"
 "PO-Revision-Date: 2018-06-03 11:52+0200\n"
 "Last-Translator: Frédéric Marchal <fmarchal@perso.be>\n"
 "Language-Team: French <traduc@traduc.org>\n"
@@ -166,12 +166,12 @@
 msgid "[cannot find %s]"
 msgstr "[%s introuvable]"
 
-#: collect2.c:1557
+#: collect2.c:1585
 #, c-format
 msgid "collect2 version %s\n"
 msgstr "collect2 version %s\n"
 
-#: collect2.c:1664
+#: collect2.c:1692
 #, c-format
 msgid "%d constructor found\n"
 msgid_plural "%d constructors found\n"
@@ -178,7 +178,7 @@
 msgstr[0] "%d constructeur trouvé\n"
 msgstr[1] "%d constructeurs trouvés\n"
 
-#: collect2.c:1668
+#: collect2.c:1696
 #, c-format
 msgid "%d destructor found\n"
 msgid_plural "%d destructors found\n"
@@ -185,7 +185,7 @@
 msgstr[0] "%d destructeur trouvé\n"
 msgstr[1] "%d destructeurs trouvés\n"
 
-#: collect2.c:1672
+#: collect2.c:1700
 #, c-format
 msgid "%d frame table found\n"
 msgid_plural "%d frame tables found\n"
@@ -192,12 +192,12 @@
 msgstr[0] "%d table de trame trouvée\n"
 msgstr[1] "%d tables de trame trouvées\n"
 
-#: collect2.c:1836
+#: collect2.c:1864
 #, c-format
 msgid "[Leaving %s]\n"
 msgstr "[Quitte %s]\n"
 
-#: collect2.c:2068
+#: collect2.c:2094
 #, c-format
 msgid ""
 "\n"
@@ -206,7 +206,7 @@
 "\n"
 "write_c_file - le nom de sortie est %s, le préfixe est %s\n"
 
-#: collect2.c:2584
+#: collect2.c:2610
 #, c-format
 msgid ""
 "\n"
@@ -229,7 +229,7 @@
 msgid "%s: some warnings being treated as errors"
 msgstr "%s : certains avertissements sont traités comme des erreurs"
 
-#: diagnostic.c:324 input.c:222 input.c:1834 c-family/c-opts.c:1377
+#: diagnostic.c:324 input.c:222 input.c:1834 c-family/c-opts.c:1392
 #: fortran/cpp.c:576 fortran/error.c:1008 fortran/error.c:1028
 msgid "<built-in>"
 msgstr "<interne>"
@@ -321,13 +321,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:4164 config/arc/arc.c:5784 config/i386/i386.c:17302
+#: final.c:4164 config/arc/arc.c:5775 config/i386/i386.c:17305
 #: config/pdp11/pdp11.c:1715
 #, c-format
 msgid "floating constant misused"
 msgstr "constante flottante mal utilisée"
 
-#: final.c:4222 config/arc/arc.c:5881 config/i386/i386.c:17393
+#: final.c:4222 config/arc/arc.c:5872 config/i386/i386.c:17396
 #: config/pdp11/pdp11.c:1756
 #, c-format
 msgid "invalid expression as operand"
@@ -1239,7 +1239,7 @@
 msgid "GCSE disabled"
 msgstr "GCSE désactivé"
 
-#: gimple-ssa-isolate-paths.c:542 c/c-typeck.c:10240
+#: gimple-ssa-isolate-paths.c:542 c/c-typeck.c:10245
 #, gcc-internal-format
 msgid "function returns address of local variable"
 msgstr "la fonction retourne l'adresse d'une variable locale"
@@ -1540,7 +1540,7 @@
 msgid "options enabled: "
 msgstr "options activées : "
 
-#: tree-diagnostic.c:299 c/c-decl.c:5419 c/c-typeck.c:7259 cp/error.c:1042
+#: tree-diagnostic.c:299 c/c-decl.c:5439 c/c-typeck.c:7264 cp/error.c:1042
 #: c-family/c-pretty-print.c:413
 #, gcc-internal-format
 msgid "<anonymous>"
@@ -3000,64 +3000,64 @@
 msgstr "modificateur de longueur dans le format de strfmon"
 
 #. Handle deferred options from command-line.
-#: c-family/c-opts.c:1402 fortran/cpp.c:590
+#: c-family/c-opts.c:1417 fortran/cpp.c:590
 msgid "<command-line>"
 msgstr "<ligne-de-commande>"
 
-#: config/aarch64/aarch64.c:6613
+#: config/aarch64/aarch64.c:6629
 #, c-format
 msgid "unsupported operand for code '%c'"
 msgstr "opérande non supporté pour le code « %c »"
 
-#: config/aarch64/aarch64.c:6624 config/aarch64/aarch64.c:6640
-#: config/aarch64/aarch64.c:6652 config/aarch64/aarch64.c:6663
-#: config/aarch64/aarch64.c:6673 config/aarch64/aarch64.c:6694
-#: config/aarch64/aarch64.c:6764 config/aarch64/aarch64.c:6775
-#: config/aarch64/aarch64.c:6789 config/aarch64/aarch64.c:7011
-#: config/aarch64/aarch64.c:7029
+#: config/aarch64/aarch64.c:6640 config/aarch64/aarch64.c:6656
+#: config/aarch64/aarch64.c:6668 config/aarch64/aarch64.c:6679
+#: config/aarch64/aarch64.c:6689 config/aarch64/aarch64.c:6710
+#: config/aarch64/aarch64.c:6780 config/aarch64/aarch64.c:6791
+#: config/aarch64/aarch64.c:6805 config/aarch64/aarch64.c:7027
+#: config/aarch64/aarch64.c:7045
 #, c-format
 msgid "invalid operand for '%%%c'"
 msgstr "opérande invalide pour « %%%c »"
 
-#: config/aarch64/aarch64.c:6709 config/aarch64/aarch64.c:6720
-#: config/aarch64/aarch64.c:6871 config/aarch64/aarch64.c:6882
+#: config/aarch64/aarch64.c:6725 config/aarch64/aarch64.c:6736
+#: config/aarch64/aarch64.c:6887 config/aarch64/aarch64.c:6898
 #, c-format
 msgid "invalid vector constant"
 msgstr "constante vecteur invalide"
 
-#: config/aarch64/aarch64.c:6732 config/aarch64/aarch64.c:6744
-#: config/aarch64/aarch64.c:6755
+#: config/aarch64/aarch64.c:6748 config/aarch64/aarch64.c:6760
+#: config/aarch64/aarch64.c:6771
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr "opérande en virgule flottante ou registre vecteur incompatible pour « %%%c »"
 
-#: config/aarch64/aarch64.c:6823 config/arm/arm.c:22704
+#: config/aarch64/aarch64.c:6839 config/arm/arm.c:22704
 #, c-format
 msgid "missing operand"
 msgstr "opérande manquant"
 
-#: config/aarch64/aarch64.c:6908
+#: config/aarch64/aarch64.c:6924
 #, c-format
 msgid "invalid constant"
 msgstr "constante invalide"
 
-#: config/aarch64/aarch64.c:6911
+#: config/aarch64/aarch64.c:6927
 #, c-format
 msgid "invalid operand"
 msgstr "opérande invalide"
 
-#: config/aarch64/aarch64.c:7040 config/aarch64/aarch64.c:7045
+#: config/aarch64/aarch64.c:7056 config/aarch64/aarch64.c:7061
 #, c-format
 msgid "invalid operand prefix '%%%c'"
 msgstr "préfixe d'opérande invalide « %%%c »"
 
-#: config/aarch64/aarch64.c:7062
+#: config/aarch64/aarch64.c:7078
 #, c-format
 msgid "invalid address mode"
 msgstr "mode d'adresse invalide"
 
-#: config/alpha/alpha.c:5125 config/i386/i386.c:18558
-#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21798
+#: config/alpha/alpha.c:5125 config/i386/i386.c:18561
+#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21875
 #: config/sparc/sparc.c:9290
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
@@ -3074,7 +3074,7 @@
 msgstr "valeur %%r invalide"
 
 #: config/alpha/alpha.c:5223 config/ia64/ia64.c:5534
-#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21506
+#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21583
 #: config/xtensa/xtensa.c:2429
 #, c-format
 msgid "invalid %%R value"
@@ -3081,13 +3081,13 @@
 msgstr "valeur %%R invalide"
 
 #: config/alpha/alpha.c:5229 config/powerpcspe/powerpcspe.c:23933
-#: config/rs6000/rs6000.c:21426 config/xtensa/xtensa.c:2396
+#: config/rs6000/rs6000.c:21503 config/xtensa/xtensa.c:2396
 #, c-format
 msgid "invalid %%N value"
 msgstr "valeur %%N invalide"
 
 #: config/alpha/alpha.c:5237 config/powerpcspe/powerpcspe.c:23961
-#: config/rs6000/rs6000.c:21454
+#: config/rs6000/rs6000.c:21531
 #, c-format
 msgid "invalid %%P value"
 msgstr "valeur %%P invalide"
@@ -3118,7 +3118,7 @@
 msgstr "valeur %%U invalide"
 
 #: config/alpha/alpha.c:5323 config/powerpcspe/powerpcspe.c:24021
-#: config/rs6000/rs6000.c:21514
+#: config/rs6000/rs6000.c:21591
 #, c-format
 msgid "invalid %%s value"
 msgstr "valeur %%s invalide"
@@ -3129,7 +3129,7 @@
 msgstr "valeur %%C invalide"
 
 #: config/alpha/alpha.c:5371 config/powerpcspe/powerpcspe.c:23797
-#: config/rs6000/rs6000.c:21290
+#: config/rs6000/rs6000.c:21367
 #, c-format
 msgid "invalid %%E value"
 msgstr "valeur %%E invalide"
@@ -3140,7 +3140,7 @@
 msgstr "relocalisation unspec inconnue"
 
 #: config/alpha/alpha.c:5405 config/cr16/cr16.c:1569
-#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21803
+#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21880
 #: config/spu/spu.c:1458
 #, c-format
 msgid "invalid %%xn code"
@@ -3151,57 +3151,57 @@
 msgid "invalid operand address"
 msgstr "adresse d'opérande invalide"
 
-#: config/arc/arc.c:3810
+#: config/arc/arc.c:3808
 #, c-format
 msgid "invalid operand to %%Z code"
 msgstr "opérande invalide pour le code %%Z"
 
-#: config/arc/arc.c:3818
+#: config/arc/arc.c:3816
 #, c-format
 msgid "invalid operand to %%z code"
 msgstr "opérande invalide pour le code %%z"
 
-#: config/arc/arc.c:3826
+#: config/arc/arc.c:3824
 #, c-format
 msgid "invalid operands to %%c code"
 msgstr "opérandes invalides pour le code %%c"
 
-#: config/arc/arc.c:3834
+#: config/arc/arc.c:3832
 #, c-format
 msgid "invalid operand to %%M code"
 msgstr "opérande invalide pour le code %%M"
 
-#: config/arc/arc.c:3842 config/m32r/m32r.c:2100
+#: config/arc/arc.c:3840 config/m32r/m32r.c:2100
 #, c-format
 msgid "invalid operand to %%p code"
 msgstr "opérande invalide pour le code %%p"
 
-#: config/arc/arc.c:3853 config/m32r/m32r.c:2093
+#: config/arc/arc.c:3851 config/m32r/m32r.c:2093
 #, c-format
 msgid "invalid operand to %%s code"
 msgstr "opérande invalide pour le code %%s"
 
-#: config/arc/arc.c:4001 config/m32r/m32r.c:2126
+#: config/arc/arc.c:3999 config/m32r/m32r.c:2126
 #, c-format
 msgid "invalid operand to %%R code"
 msgstr "opérande invalide pour le code %%R"
 
-#: config/arc/arc.c:4077 config/m32r/m32r.c:2149
+#: config/arc/arc.c:4075 config/m32r/m32r.c:2149
 #, c-format
 msgid "invalid operand to %%H/%%L code"
 msgstr "opérande invalide pour le code %%H/%%L"
 
-#: config/arc/arc.c:4145 config/m32r/m32r.c:2220
+#: config/arc/arc.c:4143 config/m32r/m32r.c:2220
 #, c-format
 msgid "invalid operand to %%U code"
 msgstr "opérande invalide pour le code %%U"
 
-#: config/arc/arc.c:4157
+#: config/arc/arc.c:4155
 #, c-format
 msgid "invalid operand to %%V code"
 msgstr "opérande invalide pour le code %%V"
 
-#: config/arc/arc.c:4214
+#: config/arc/arc.c:4212
 #, c-format
 msgid "invalid operand to %%O code"
 msgstr "opérande invalide pour le code %%O"
@@ -3208,18 +3208,18 @@
 
 #. Unknown flag.
 #. Undocumented flag.
-#: config/arc/arc.c:4240 config/epiphany/epiphany.c:1305
-#: config/m32r/m32r.c:2247 config/nds32/nds32.c:3079 config/sparc/sparc.c:9569
+#: config/arc/arc.c:4238 config/epiphany/epiphany.c:1305
+#: config/m32r/m32r.c:2247 config/nds32/nds32.c:3080 config/sparc/sparc.c:9569
 #, c-format
 msgid "invalid operand output code"
 msgstr "opérande invalide pour le code de sortie"
 
-#: config/arc/arc.c:5869
+#: config/arc/arc.c:5860
 #, c-format
 msgid "invalid UNSPEC as operand: %d"
 msgstr "UNSPEC invalide comme opérande : %d"
 
-#: config/arc/arc.c:6158 config/cris/cris.c:2568
+#: config/arc/arc.c:6149 config/cris/cris.c:2568
 msgid "unrecognized supposed constant"
 msgstr "constante supposée non reconnue"
 
@@ -3254,7 +3254,7 @@
 #: config/arm/arm.c:22685 config/arm/arm.c:22692 config/bfin/bfin.c:1441
 #: config/bfin/bfin.c:1448 config/bfin/bfin.c:1455 config/bfin/bfin.c:1462
 #: config/bfin/bfin.c:1471 config/bfin/bfin.c:1478 config/bfin/bfin.c:1485
-#: config/bfin/bfin.c:1492 config/nds32/nds32.c:3098
+#: config/bfin/bfin.c:1492 config/nds32/nds32.c:3099
 #, c-format
 msgid "invalid operand for code '%c'"
 msgstr "opérande invalide pour « %c »"
@@ -3595,97 +3595,97 @@
 msgid "bad output_condmove_single operand"
 msgstr "mauvais opérande output_condmove_single"
 
-#: config/i386/i386.c:17387
+#: config/i386/i386.c:17390
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "UNSPEC invalide comme opérande"
 
-#: config/i386/i386.c:17925
+#: config/i386/i386.c:17928
 #, c-format
 msgid "invalid use of register '%s'"
 msgstr "utilisation invalide du registre « %s »"
 
-#: config/i386/i386.c:17930
+#: config/i386/i386.c:17933
 #, c-format
 msgid "invalid use of asm flag output"
 msgstr "utilisation invalide de la sortie du fanion asm"
 
-#: config/i386/i386.c:18160
+#: config/i386/i386.c:18163
 #, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr "taille d'opérande invalide pour le code d'opérande « 0 »"
 
-#: config/i386/i386.c:18195
+#: config/i386/i386.c:18198
 #, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr "taille d'opérande invalide pour le code d'opérande « z »"
 
-#: config/i386/i386.c:18264
+#: config/i386/i386.c:18267
 #, c-format
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "type opérande invalide utilisé avec le code d'opérande « Z »"
 
-#: config/i386/i386.c:18269
+#: config/i386/i386.c:18272
 #, c-format
 msgid "invalid operand size for operand code 'Z'"
 msgstr "taille d'opérande invalide pour le code d'opérande « Z »"
 
-#: config/i386/i386.c:18346
+#: config/i386/i386.c:18349
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "l'opérande n'est pas du code de condition, code d'opérande « Y » invalide"
 
-#: config/i386/i386.c:18425
+#: config/i386/i386.c:18428
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "l'opérande n'est pas du code de condition, code d'opérande « D » invalide"
 
-#: config/i386/i386.c:18443
+#: config/i386/i386.c:18446
 #, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "l'opérande n'est pas du code de condition, code d'opérande « %c » invalide"
 
-#: config/i386/i386.c:18456
+#: config/i386/i386.c:18459
 #, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "l'opérande n'est pas une référence mémoire avec décalage, code d'opérande « H » invalide"
 
-#: config/i386/i386.c:18471
+#: config/i386/i386.c:18474
 #, c-format
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr "l'opérande n'est pas un entier, code d'opérande « K » invalide"
 
-#: config/i386/i386.c:18499
+#: config/i386/i386.c:18502
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr "l'opérande n'est pas un entier spécifique, code d'opérande « r » invalide"
 
-#: config/i386/i386.c:18517
+#: config/i386/i386.c:18520
 #, c-format
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr "l'opérande n'est pas un entier, code d'opérande « R » invalide"
 
-#: config/i386/i386.c:18540
+#: config/i386/i386.c:18543
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "l'opérande n'est pas un entier spécifique, code d'opérande « R » invalide"
 
-#: config/i386/i386.c:18626
+#: config/i386/i386.c:18629
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "opérande invalide pour « %c »"
 
-#: config/i386/i386.c:18688
+#: config/i386/i386.c:18691
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "contrainte invalide pour l'opérande"
 
-#: config/i386/i386.c:18738
+#: config/i386/i386.c:18741
 #, c-format
 msgid "invalid vector immediate"
 msgstr "immédiat vecteur invalide"
 
-#: config/i386/i386.c:29572
+#: config/i386/i386.c:29575
 msgid "unknown insn mode"
 msgstr "mode insn inconnu"
 
@@ -3723,7 +3723,7 @@
 msgstr "opérande %%P invalide"
 
 #: config/iq2000/iq2000.c:3185 config/powerpcspe/powerpcspe.c:23951
-#: config/rs6000/rs6000.c:21444
+#: config/rs6000/rs6000.c:21521
 #, c-format
 msgid "invalid %%p value"
 msgstr "valeur %%p invalide"
@@ -3777,7 +3777,7 @@
 msgstr "le post-incrément d'adresse n'est pas un registre"
 
 #: config/m32r/m32r.c:2350 config/m32r/m32r.c:2365
-#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33292
+#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33348
 msgid "bad address"
 msgstr "mauvaise adresse"
 
@@ -3896,185 +3896,185 @@
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr "Essayez d'exécuter « %s » dans le shell pour augmenter sa limite.\n"
 
-#: config/powerpcspe/powerpcspe.c:4411 config/rs6000/rs6000.c:4258
+#: config/powerpcspe/powerpcspe.c:4411 config/rs6000/rs6000.c:4278
 msgid "-maltivec=le not allowed for big-endian targets"
 msgstr "-maltivec=le pas permis pour des cibles gros-boutistes"
 
-#: config/powerpcspe/powerpcspe.c:4423 config/rs6000/rs6000.c:4273
+#: config/powerpcspe/powerpcspe.c:4423 config/rs6000/rs6000.c:4293
 msgid "-mvsx requires hardware floating point"
 msgstr "-mvsx nécessite une unité matérielle en virgule flottante"
 
-#: config/powerpcspe/powerpcspe.c:4431 config/rs6000/rs6000.c:4281
+#: config/powerpcspe/powerpcspe.c:4431 config/rs6000/rs6000.c:4301
 msgid "-mvsx and -mpaired are incompatible"
 msgstr "-mvsx et -mpaired sont incompatibles"
 
-#: config/powerpcspe/powerpcspe.c:4433 config/rs6000/rs6000.c:4283
+#: config/powerpcspe/powerpcspe.c:4433 config/rs6000/rs6000.c:4303
 msgid "-mvsx needs indexed addressing"
 msgstr "-mvsx nécessite l'adressage indexé"
 
-#: config/powerpcspe/powerpcspe.c:4438 config/rs6000/rs6000.c:4288
+#: config/powerpcspe/powerpcspe.c:4438 config/rs6000/rs6000.c:4308
 msgid "-mvsx and -mno-altivec are incompatible"
 msgstr "-mvsx et -mno-altivec sont incompatibles"
 
-#: config/powerpcspe/powerpcspe.c:4440 config/rs6000/rs6000.c:4290
+#: config/powerpcspe/powerpcspe.c:4440 config/rs6000/rs6000.c:4310
 msgid "-mno-altivec disables vsx"
 msgstr "-mno-altivec désactive vsx"
 
-#: config/powerpcspe/powerpcspe.c:4648 config/rs6000/rs6000.c:4416
+#: config/powerpcspe/powerpcspe.c:4648 config/rs6000/rs6000.c:4436
 msgid "-mquad-memory requires 64-bit mode"
 msgstr "-mquad-memory requiert le mode 64 bits"
 
-#: config/powerpcspe/powerpcspe.c:4651 config/rs6000/rs6000.c:4419
+#: config/powerpcspe/powerpcspe.c:4651 config/rs6000/rs6000.c:4439
 msgid "-mquad-memory-atomic requires 64-bit mode"
 msgstr "-mquad-memory-atomic requiert le mode 64 bits"
 
-#: config/powerpcspe/powerpcspe.c:4663 config/rs6000/rs6000.c:4431
+#: config/powerpcspe/powerpcspe.c:4663 config/rs6000/rs6000.c:4451
 msgid "-mquad-memory is not available in little endian mode"
 msgstr "-mquad-memory n'est pas disponible en mode petit-boutiste"
 
-#: config/powerpcspe/powerpcspe.c:4735 config/rs6000/rs6000.c:4512
+#: config/powerpcspe/powerpcspe.c:4735 config/rs6000/rs6000.c:4532
 msgid "-mtoc-fusion requires 64-bit"
 msgstr "-mtoc-fusion requiert le mode 64 bits"
 
-#: config/powerpcspe/powerpcspe.c:4742 config/rs6000/rs6000.c:4519
+#: config/powerpcspe/powerpcspe.c:4742 config/rs6000/rs6000.c:4539
 msgid "-mtoc-fusion requires medium/large code model"
 msgstr "-mtoc-fusion requiert le modèle de code moyen/large"
 
-#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10915
+#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10947
 msgid "bad move"
 msgstr "mauvais déplacement"
 
-#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21087
+#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21164
 msgid "Bad 128-bit move"
 msgstr "Mauvais déplacement sur 128 bits"
 
-#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21278
+#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21355
 #, c-format
 msgid "invalid %%e value"
 msgstr "valeur %%e invalide"
 
-#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21299
+#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21376
 #, c-format
 msgid "invalid %%f value"
 msgstr "valeur %%f invalide"
 
-#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21308
+#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21385
 #, c-format
 msgid "invalid %%F value"
 msgstr "valeur %%F invalide"
 
-#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21317
+#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21394
 #, c-format
 msgid "invalid %%G value"
 msgstr "valeur %%G invalide"
 
-#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21352
+#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21429
 #, c-format
 msgid "invalid %%j code"
 msgstr "valeur %%j invalide"
 
-#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21362
+#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21439
 #, c-format
 msgid "invalid %%J code"
 msgstr "valeur %%J invalide"
 
-#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21372
+#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21449
 #, c-format
 msgid "invalid %%k value"
 msgstr "valeur %%k invalide"
 
-#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21387
+#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21464
 #: config/xtensa/xtensa.c:2415
 #, c-format
 msgid "invalid %%K value"
 msgstr "valeur %%K invalide"
 
-#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21434
+#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21511
 #, c-format
 msgid "invalid %%O value"
 msgstr "valeur %%O invalide"
 
-#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21481
+#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21558
 #, c-format
 msgid "invalid %%q value"
 msgstr "valeur %%q invalide"
 
-#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21534
+#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21611
 #, c-format
 msgid "invalid %%T value"
 msgstr "valeur %%T invalide"
 
-#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21546
+#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21623
 #, c-format
 msgid "invalid %%u value"
 msgstr "valeur %%u invalide"
 
-#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21560
+#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21637
 #: config/xtensa/xtensa.c:2384
 #, c-format
 msgid "invalid %%v value"
 msgstr "valeur %%v invalide"
 
-#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21627
+#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21704
 #: config/xtensa/xtensa.c:2436
 #, c-format
 msgid "invalid %%x value"
 msgstr "valeur %%x invalide"
 
-#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21747
+#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21824
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "valeur %%y invalide, essayez d'utiliser la contrainte « Z »"
 
-#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22282
+#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22359
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr "__float128 et __ibm128 ne peuvent pas être utilisés dans la même expression"
 
-#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22288
+#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22365
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr "__ibm128 et long double ne peuvent pas être utilisés dans la même expression"
 
-#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22294
+#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22371
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr "__float128 et long double ne peuvent pas être utilisés dans la même expression"
 
-#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36572
+#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36628
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "Argument AltiVec passé à une fonction sans prototype"
 
-#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38739
+#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38795
 msgid "Could not generate addis value for fusion"
 msgstr "N'a pu générer de valeur addis pour la fusion"
 
-#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38809
+#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38865
 msgid "Unable to generate load/store offset for fusion"
 msgstr "Impossible de générer un offset load/store pour la fusion"
 
-#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38908
+#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38964
 msgid "Bad GPR fusion"
 msgstr "Mauvaise fusion GPR"
 
-#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39126
+#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39182
 msgid "emit_fusion_p9_load, bad reg #1"
 msgstr "emit_fusion_p9_load, mauvais reg #1"
 
-#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39172
+#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39228
 msgid "emit_fusion_p9_load, bad reg #2"
 msgstr "emit_fusion_p9_load, mauvais reg #2"
 
-#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39175
+#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39231
 msgid "emit_fusion_p9_load not MEM"
 msgstr "emit_fusion_p9_load pas MEM"
 
-#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39213
+#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39269
 msgid "emit_fusion_p9_store, bad reg #1"
 msgstr "emit_fusion_p9_store, mauvais reg #1"
 
-#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39259
+#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39315
 msgid "emit_fusion_p9_store, bad reg #2"
 msgstr "emit_fusion_p9_store, mauvais reg #2"
 
-#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39262
+#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39318
 msgid "emit_fusion_p9_store not MEM"
 msgstr "emit_fusion_p9_store pas MEM"
 
@@ -4451,14 +4451,14 @@
 #: c/gimple-parser.c:188 c/gimple-parser.c:197 c/gimple-parser.c:226
 #: c/gimple-parser.c:1375 c/gimple-parser.c:1404 c/gimple-parser.c:1484
 #: c/gimple-parser.c:1511 c/c-parser.c:3204 c/c-parser.c:9967
-#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27841
-#: cp/parser.c:28430
+#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27838
+#: cp/parser.c:28427
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "%<;%> attendu"
 
 #: c/c-parser.c:2431 c/c-parser.c:7573 c/c-parser.c:8015 c/c-parser.c:8058
-#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27839 cp/parser.c:28448
+#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27836 cp/parser.c:28445
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "%<,%> attendu"
@@ -4473,7 +4473,7 @@
 #: c/gimple-parser.c:821 c/gimple-parser.c:837 c/gimple-parser.c:853
 #: c/gimple-parser.c:880 c/gimple-parser.c:915 c/gimple-parser.c:1038
 #: c/gimple-parser.c:1209 c/gimple-parser.c:1220 c/gimple-parser.c:1342
-#: c/gimple-parser.c:1441 cp/parser.c:28478
+#: c/gimple-parser.c:1441 cp/parser.c:28475
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "%<)%> attendu"
@@ -4481,7 +4481,7 @@
 #: c/c-parser.c:3824 c/c-parser.c:4733 c/c-parser.c:4769 c/c-parser.c:6441
 #: c/c-parser.c:8125 c/c-parser.c:8983 c/c-parser.c:9127 c/c-parser.c:11588
 #: c/c-parser.c:18220 c/c-parser.c:18222 c/gimple-parser.c:1015
-#: cp/parser.c:28442
+#: cp/parser.c:28439
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "%<]%> attendu"
@@ -4495,7 +4495,7 @@
 #: c/c-parser.c:17792 c/gimple-parser.c:363 c/gimple-parser.c:811
 #: c/gimple-parser.c:873 c/gimple-parser.c:911 c/gimple-parser.c:1198
 #: c/gimple-parser.c:1339 c/gimple-parser.c:1438 c/c-parser.c:11911
-#: cp/parser.c:28433
+#: cp/parser.c:28430
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "%<(%> attendu"
@@ -4502,7 +4502,7 @@
 
 #: c/c-parser.c:4903 c/c-parser.c:10310 c/c-parser.c:16212 c/c-parser.c:18449
 #: c/gimple-parser.c:141 c/gimple-parser.c:1444 c/c-parser.c:3018
-#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18155 cp/parser.c:28439
+#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18152 cp/parser.c:28436
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "%<{%> attendu"
@@ -4512,13 +4512,13 @@
 #: c/c-parser.c:12351 c/c-parser.c:12493 c/c-parser.c:12864 c/c-parser.c:12957
 #: c/c-parser.c:13566 c/c-parser.c:17636 c/c-parser.c:17695
 #: c/gimple-parser.c:431 c/gimple-parser.c:1492 c/gimple-parser.c:1519
-#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28472 cp/parser.c:29597
-#: cp/parser.c:32279
+#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28469 cp/parser.c:29594
+#: cp/parser.c:32276
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "%<:%> attendu"
 
-#: c/c-parser.c:5974 cp/parser.c:28365
+#: c/c-parser.c:5974 cp/parser.c:28362
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "%<while%> attendu"
@@ -4527,18 +4527,18 @@
 msgid "expected %<.%>"
 msgstr "%<.%> attendu"
 
-#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30172
-#: cp/parser.c:30246
+#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30169
+#: cp/parser.c:30243
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "%<@end%> attendu"
 
-#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28457
+#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28454
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "%<>%> attendu"
 
-#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28481
+#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28478
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "%<,%> ou %<)%> attendu"
@@ -4546,32 +4546,32 @@
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15190 c/c-parser.c:15234 c/c-parser.c:15466 c/c-parser.c:15701
 #: c/c-parser.c:17833 c/gimple-parser.c:286 c/c-parser.c:4792
-#: cp/parser.c:28460
+#: cp/parser.c:28457
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "%<=%> attendu"
 
-#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28436
-#: cp/parser.c:30389
+#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28433
+#: cp/parser.c:30386
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "%<}%> attendu"
 
-#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35674
+#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35671
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "%<#pragma omp section%> ou %<}%> attendu"
 
-#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28445 cp/parser.c:31535
+#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28442 cp/parser.c:31532
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "%<[%> attendu"
 
-#: c/c-typeck.c:7847
+#: c/c-typeck.c:7852
 msgid "(anonymous)"
 msgstr "(anonyme)"
 
-#: c/gimple-parser.c:795 cp/parser.c:15791 cp/parser.c:28454
+#: c/gimple-parser.c:795 cp/parser.c:15788 cp/parser.c:28451
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "%<<%> attendu"
@@ -4825,11 +4825,11 @@
 msgid "%r%s:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr "%r%s:%d:%R   dans l'expansion %<constexpr%> de %qs"
 
-#: cp/pt.c:1949 cp/semantics.c:5268
+#: cp/pt.c:1949 cp/semantics.c:5271
 msgid "candidates are:"
 msgstr "les candidats sont :"
 
-#: cp/pt.c:1951 cp/pt.c:22975
+#: cp/pt.c:1951 cp/pt.c:23053
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "le candidat est :"
@@ -4875,27 +4875,27 @@
 msgid "source type is not polymorphic"
 msgstr "le type source n'est pas polymorphique"
 
-#: cp/typeck.c:6083 c/c-typeck.c:4261
+#: cp/typeck.c:6083 c/c-typeck.c:4266
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "type d'argument erroné pour le moins unaire"
 
-#: cp/typeck.c:6084 c/c-typeck.c:4248
+#: cp/typeck.c:6084 c/c-typeck.c:4253
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "type d'argument erroné pour le plus unaire"
 
-#: cp/typeck.c:6111 c/c-typeck.c:4302
+#: cp/typeck.c:6111 c/c-typeck.c:4307
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "type d'argument erroné pour le complément de bit"
 
-#: cp/typeck.c:6128 c/c-typeck.c:4310
+#: cp/typeck.c:6128 c/c-typeck.c:4315
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "type d'argument erroné pour abs"
 
-#: cp/typeck.c:6140 c/c-typeck.c:4322
+#: cp/typeck.c:6140 c/c-typeck.c:4327
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "type d'argument erroné pour la conjugaison"
@@ -5135,67 +5135,67 @@
 msgid "Expected attribute bit name"
 msgstr "Nom de bit d'attribut attendu"
 
-#: fortran/module.c:3223
+#: fortran/module.c:3225
 msgid "Expected integer string"
 msgstr "Chaîne contenant un entier attendue"
 
-#: fortran/module.c:3227
+#: fortran/module.c:3229
 msgid "Error converting integer"
 msgstr "Erreur de conversion de l'entier"
 
-#: fortran/module.c:3249
+#: fortran/module.c:3251
 msgid "Expected real string"
 msgstr "Chaîne contenant un réel attendue"
 
-#: fortran/module.c:3474
+#: fortran/module.c:3476
 msgid "Expected expression type"
 msgstr "Type d'expression attendue"
 
-#: fortran/module.c:3554
+#: fortran/module.c:3556
 msgid "Bad operator"
 msgstr "Mauvais opérateur"
 
-#: fortran/module.c:3671
+#: fortran/module.c:3673
 msgid "Bad type in constant expression"
 msgstr "Mauvais type dans l'expression constante"
 
-#: fortran/module.c:7038
+#: fortran/module.c:7040
 msgid "Unexpected end of module"
 msgstr "Fin de module inattendue"
 
-#: fortran/parse.c:1757
+#: fortran/parse.c:1761
 msgid "arithmetic IF"
 msgstr "IF arithmétique"
 
-#: fortran/parse.c:1766
+#: fortran/parse.c:1770
 msgid "attribute declaration"
 msgstr "déclaration d'attribut"
 
-#: fortran/parse.c:1802
+#: fortran/parse.c:1806
 msgid "data declaration"
 msgstr "déclaration de données"
 
-#: fortran/parse.c:1820
+#: fortran/parse.c:1824
 msgid "derived type declaration"
 msgstr "déclaration de type dérivé"
 
-#: fortran/parse.c:1947
+#: fortran/parse.c:1951
 msgid "block IF"
 msgstr "bloc IF"
 
-#: fortran/parse.c:1956
+#: fortran/parse.c:1960
 msgid "implied END DO"
 msgstr "END DO implicite"
 
-#: fortran/parse.c:2050 fortran/resolve.c:11199
+#: fortran/parse.c:2054 fortran/resolve.c:11219
 msgid "assignment"
 msgstr "affectation"
 
-#: fortran/parse.c:2053 fortran/resolve.c:11250 fortran/resolve.c:11253
+#: fortran/parse.c:2057 fortran/resolve.c:11270 fortran/resolve.c:11273
 msgid "pointer assignment"
 msgstr "affectation de pointeur"
 
-#: fortran/parse.c:2071
+#: fortran/parse.c:2075
 msgid "simple IF"
 msgstr "IF simple"
 
@@ -5287,106 +5287,112 @@
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr "L'opérande de l'opérateur numérique unaire %%<%s%%> à %%L est %s"
 
-#: fortran/resolve.c:3878
+#: fortran/resolve.c:3879
+#, fuzzy, c-format
+#| msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
+msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
+msgstr "Les opérandes de l'opérateur numérique binaire %%<%s%%> à %%L sont %s/%s"
+
+#: fortran/resolve.c:3884
 #, c-format
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr "Les opérandes de l'opérateur numérique binaire %%<%s%%> à %%L sont %s/%s"
 
-#: fortran/resolve.c:3893
+#: fortran/resolve.c:3899
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr "Les opérandes de l'opérateur de concaténation de chaînes à %%L sont %s/%s"
 
-#: fortran/resolve.c:3926
+#: fortran/resolve.c:3932
 #, c-format
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr "Les opérandes de l'opérateur logique %%<%s%%> à %%L sont %s/%s"
 
-#: fortran/resolve.c:3949
+#: fortran/resolve.c:3955
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr "L'opérande de l'opérateur .not. à %%L est %s"
 
-#: fortran/resolve.c:3963
+#: fortran/resolve.c:3969
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "Les quantités COMPLEX ne peuvent pas être comparées à %L"
 
-#: fortran/resolve.c:4015
+#: fortran/resolve.c:4021
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr "Les valeurs logiques à %%L doivent être comparées avec %s au lieu de %s"
 
-#: fortran/resolve.c:4021
+#: fortran/resolve.c:4027
 #, c-format
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr "Les opérandes de l'opérateur de comparaison %%<%s%%> à %%L sont %s/%s"
 
-#: fortran/resolve.c:4034
+#: fortran/resolve.c:4040
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L; did you mean '%s'?"
 msgstr "Opérateur %%<%s%%> inconnu à %%L; vouliez-vous utiliser « %s » ?"
 
-#: fortran/resolve.c:4037
+#: fortran/resolve.c:4043
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr "Opérateur %%<%s%%> inconnu à %%L"
 
-#: fortran/resolve.c:4040
+#: fortran/resolve.c:4046
 #, c-format
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr "L'opérande de l'opérateur utilisateur %%<%s%%> à %%L est %s"
 
-#: fortran/resolve.c:4044
+#: fortran/resolve.c:4050
 #, c-format
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr "Les opérandes de l'opérateur utilisateur %%<%s%%> à %%L sont %s/%s"
 
-#: fortran/resolve.c:4132
+#: fortran/resolve.c:4138
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "Rangs inconsistant pour l'opérateur à %%L et %%L"
 
-#: fortran/resolve.c:6849
+#: fortran/resolve.c:6855
 msgid "Loop variable"
 msgstr "Variable de boucle"
 
-#: fortran/resolve.c:6853
+#: fortran/resolve.c:6859
 msgid "iterator variable"
 msgstr "variable d'itérateur"
 
-#: fortran/resolve.c:6857
+#: fortran/resolve.c:6863
 msgid "Start expression in DO loop"
 msgstr "Expression de départ dans la boucle DO"
 
-#: fortran/resolve.c:6861
+#: fortran/resolve.c:6867
 msgid "End expression in DO loop"
 msgstr "Expression de fin dans la boucle DO"
 
-#: fortran/resolve.c:6865
+#: fortran/resolve.c:6871
 msgid "Step expression in DO loop"
 msgstr "Expression de pas dans la boucle DO"
 
-#: fortran/resolve.c:7150 fortran/resolve.c:7153
+#: fortran/resolve.c:7156 fortran/resolve.c:7159
 msgid "DEALLOCATE object"
 msgstr "objet DEALLOCATE"
 
-#: fortran/resolve.c:7525 fortran/resolve.c:7528
+#: fortran/resolve.c:7531 fortran/resolve.c:7534
 msgid "ALLOCATE object"
 msgstr "objet ALLOCATE"
 
-#: fortran/resolve.c:7720 fortran/resolve.c:9417
+#: fortran/resolve.c:7726 fortran/resolve.c:9428
 msgid "STAT variable"
 msgstr "variable STAT"
 
-#: fortran/resolve.c:7764 fortran/resolve.c:9429
+#: fortran/resolve.c:7770 fortran/resolve.c:9440
 msgid "ERRMSG variable"
 msgstr "variable ERRMSG"
 
-#: fortran/resolve.c:9219
+#: fortran/resolve.c:9230
 msgid "item in READ"
 msgstr "élément dans READ"
 
-#: fortran/resolve.c:9441
+#: fortran/resolve.c:9452
 msgid "ACQUIRED_LOCK variable"
 msgstr "variable ACQUIRED_LOCK"
 
@@ -5419,7 +5425,7 @@
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr "La cible du remappage de rang est trop petite (%ld < %ld)"
 
-#: fortran/trans-expr.c:10154
+#: fortran/trans-expr.c:10157
 msgid "Assignment of scalar to unallocated array"
 msgstr "Assignation d'un scalaire à un tableau non alloué"
 
@@ -5428,12 +5434,12 @@
 msgid "Unequal character lengths (%ld/%ld) in %s"
 msgstr "Longueurs de caractères inégales (%ld/%ld) dans %s"
 
-#: fortran/trans-intrinsic.c:8088
+#: fortran/trans-intrinsic.c:8090
 #, c-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative (its value is %ld)"
 msgstr "L'argument NCOPIES de l'intrinsèque REPEAT est négatif (sa valeur est %ld)"
 
-#: fortran/trans-intrinsic.c:8120
+#: fortran/trans-intrinsic.c:8122
 msgid "Argument NCOPIES of REPEAT intrinsic is too large"
 msgstr "L'argument NCOPIES de l'intrinsèque REPEAT est trop grand"
 
@@ -5454,15 +5460,15 @@
 msgid "Invalid image number %d in SYNC IMAGES"
 msgstr "Numéro d'image %d invalide dans SYNC IMAGES"
 
-#: fortran/trans-stmt.c:2180
+#: fortran/trans-stmt.c:2177
 msgid "Loop iterates infinitely"
 msgstr "La boucle itère sans fin"
 
-#: fortran/trans-stmt.c:2200 fortran/trans-stmt.c:2456
+#: fortran/trans-stmt.c:2197 fortran/trans-stmt.c:2453
 msgid "Loop variable has been modified"
 msgstr "La variable de boucle a été modifiée"
 
-#: fortran/trans-stmt.c:2309
+#: fortran/trans-stmt.c:2306
 msgid "DO step value is zero"
 msgstr "La valeur de pas de DO est zéro"
 
@@ -6035,10 +6041,10 @@
 msgid "Allow dollar signs in entity names."
 msgstr "Autoriser le signe dollar dans les noms d'entités."
 
-#: fortran/lang.opt:485 config/alpha/alpha.opt:31 common.opt:783
-#: common.opt:985 common.opt:989 common.opt:993 common.opt:997 common.opt:1532
-#: common.opt:1588 common.opt:1712 common.opt:1716 common.opt:1946
-#: common.opt:2116 common.opt:2792
+#: fortran/lang.opt:485 config/alpha/alpha.opt:31 common.opt:649
+#: common.opt:783 common.opt:989 common.opt:993 common.opt:997 common.opt:1001
+#: common.opt:1536 common.opt:1592 common.opt:1716 common.opt:1720
+#: common.opt:1950 common.opt:2120 common.opt:2796
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr "Ne fait rien. Préservé pour rétro-compatibilité."
 
@@ -6257,12 +6263,12 @@
 msgstr "Ajouter un souligné aux noms visibles depuis l'extérieur."
 
 #: fortran/lang.opt:751 c-family/c.opt:1356 c-family/c.opt:1384
-#: c-family/c.opt:1634 config/pa/pa.opt:42 config/pa/pa.opt:70 common.opt:1154
-#: common.opt:1333 common.opt:1408 common.opt:1676 common.opt:1799
-#: common.opt:2169 common.opt:2205 common.opt:2298 common.opt:2302
-#: common.opt:2407 common.opt:2498 common.opt:2506 common.opt:2514
-#: common.opt:2522 common.opt:2623 common.opt:2675 common.opt:2755
-#: common.opt:2893 common.opt:2897 common.opt:2901 common.opt:2905
+#: c-family/c.opt:1634 config/pa/pa.opt:42 config/pa/pa.opt:70 common.opt:1158
+#: common.opt:1337 common.opt:1412 common.opt:1680 common.opt:1803
+#: common.opt:2173 common.opt:2209 common.opt:2302 common.opt:2306
+#: common.opt:2411 common.opt:2502 common.opt:2510 common.opt:2518
+#: common.opt:2526 common.opt:2627 common.opt:2679 common.opt:2759
+#: common.opt:2897 common.opt:2901 common.opt:2905 common.opt:2909
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr "Ne fait rien. Préservé pour rétro-compatibilité."
 
@@ -6312,7 +6318,7 @@
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:220 c-family/c.opt:224
 #: c-family/c.opt:236 c-family/c.opt:1855 c-family/c.opt:1863 brig/lang.opt:39
-#: config/darwin.opt:56 common.opt:338 common.opt:341 common.opt:3046
+#: config/darwin.opt:56 common.opt:338 common.opt:341 common.opt:3050
 #, c-format
 msgid "missing filename after %qs"
 msgstr "nom de fichier manquant après %qs"
@@ -6888,7 +6894,7 @@
 #: c-family/c.opt:1525 c-family/c.opt:1528 c-family/c.opt:1569
 #: c-family/c.opt:1704 c-family/c.opt:1731 c-family/c.opt:1771
 #: c-family/c.opt:1802 c-family/c.opt:1806 c-family/c.opt:1822
-#: config/ia64/ia64.opt:167 config/ia64/ia64.opt:170 c-family/c-opts.c:434
+#: config/ia64/ia64.opt:167 config/ia64/ia64.opt:170 c-family/c-opts.c:432
 #, gcc-internal-format
 msgid "switch %qs is no longer supported"
 msgstr "l'option %qs n'est plus supportée"
@@ -13939,10 +13945,6 @@
 msgid "Warn if dereferencing a NULL pointer may lead to erroneous or undefined behavior."
 msgstr "Avertir si le déréférencement d'un pointeur NULL peut conduire à un comportement erroné ou indéfini."
 
-#: common.opt:649
-msgid "Warn if the loop cannot be optimized due to nontrivial assumptions."
-msgstr "Avertir si une boucle ne peut pas être optimisée à cause de suppositions non triviales."
-
 #: common.opt:656
 msgid "Warn about some C++ One Definition Rule violations during link time optimization."
 msgstr "Avertir à propos de certaines violations de la règle de la définition unique du C++ durant l'optimisation lors de l'édition de liens."
@@ -14111,1680 +14113,1680 @@
 msgid "-dumpdir <dir>\tSet the directory name to be used for dumps."
 msgstr "-dumpdir <répertoire>\tDéfinir le nom du répertoire à utiliser pour les vidanges."
 
-#: common.opt:946
+#: common.opt:950
 msgid "The version of the C++ ABI in use."
 msgstr "La version de l'ABI C++ à utiliser."
 
-#: common.opt:950
+#: common.opt:954
 msgid "Aggressively optimize loops using language constraints."
 msgstr "Optimiser agressivement les boucles en utilisant les contraintes du langage."
 
-#: common.opt:954
+#: common.opt:958
 msgid "Align the start of functions."
 msgstr "Aligner le début des fonctions."
 
-#: common.opt:964
+#: common.opt:968
 msgid "Align labels which are only reached by jumping."
 msgstr "Aligner les étiquettes qui sont uniquement atteintes par sauts."
 
-#: common.opt:971
+#: common.opt:975
 msgid "Align all labels."
 msgstr "Aligner toutes les étiquettes."
 
-#: common.opt:978
+#: common.opt:982
 msgid "Align the start of loops."
 msgstr "Aligner le début des boucles."
 
-#: common.opt:1001
+#: common.opt:1005
 msgid "Select what to sanitize."
 msgstr "Sélectionner quoi assainir."
 
-#: common.opt:1005
+#: common.opt:1009
 msgid "Select type of coverage sanitization."
 msgstr "Sélectionner le type de la couverture d'assainissement."
 
-#: common.opt:1009
+#: common.opt:1013
 msgid "-fasan-shadow-offset=<number>\tUse custom shadow memory offset."
 msgstr "-fasan-shadow-offset=<nombre>\tUtiliser un décalage personnalisé pour la mémoire des informations de validation (shadow memory)."
 
-#: common.opt:1013
+#: common.opt:1017
 msgid "-fsanitize-sections=<sec1,sec2,...>\tSanitize global variables in user-defined sections."
 msgstr "-fsanitize-sections=<sec1,sec2,…>\tAssainir les variables globales dans les sections définies par l'utilisateur."
 
-#: common.opt:1018
+#: common.opt:1022
 msgid "After diagnosing undefined behavior attempt to continue execution."
 msgstr "Essayer de continuer l'exécution après avoir diagnostiqué un comportement indéfini."
 
-#: common.opt:1022
+#: common.opt:1026
 msgid "This switch is deprecated; use -fsanitize-recover= instead."
 msgstr "Cette option est obsolète; utilisez -fsanitize-recover= à la place."
 
-#: common.opt:1029
+#: common.opt:1033
 msgid "Use trap instead of a library function for undefined behavior sanitization."
 msgstr "Utiliser un déroutement au lieu d'une fonction de la bibliothèque pour signaler des comportements indéfinis détectés par le code d'assainissement."
 
-#: common.opt:1033
+#: common.opt:1037
 msgid "Generate unwind tables that are exact at each instruction boundary."
 msgstr "Générer des tables de retour en arrière (unwind tables) qui sont exactes à chaque limite d'instruction."
 
-#: common.opt:1037
+#: common.opt:1041
 msgid "Generate auto-inc/dec instructions."
 msgstr "Générer des instructions auto-inc/dec."
 
-#: common.opt:1041
+#: common.opt:1045
 msgid "Use sample profile information for call graph node weights. The default profile file is fbdata.afdo in 'pwd'."
 msgstr "Utiliser des informations de profilage par échantillonnage pour le poids des nœuds du graphe d'appels. Le fichier profile par défaut est fbdata.afdo dans « pwd »."
 
-#: common.opt:1046
+#: common.opt:1050
 msgid "Use sample profile information for call graph node weights. The profile file is specified in the argument."
 msgstr "Utiliser des informations de profilage par échantillonnage pour le poids des nœuds du graphe d'appels. Le fichier profile est spécifié en argument."
 
-#: common.opt:1055
+#: common.opt:1059
 msgid "Generate code to check bounds before indexing arrays."
 msgstr "Générer du code pour vérifier les bornes avant d'indexer les tableaux."
 
-#: common.opt:1059
+#: common.opt:1063
 msgid "Replace add, compare, branch with branch on count register."
 msgstr "Remplacer add, compare, branch par des branchements utilisant un registre compteur."
 
-#: common.opt:1063
+#: common.opt:1067
 msgid "Use profiling information for branch probabilities."
 msgstr "Utiliser les informations de profilage pour les probabilités de branchements."
 
-#: common.opt:1067
+#: common.opt:1071
 msgid "Perform branch target load optimization before prologue / epilogue threading."
 msgstr "Effectuer l'optimisation du chargement de la cible du branchement avant l'enfilage du prologue ou de l'épilogue."
 
-#: common.opt:1071
+#: common.opt:1075
 msgid "Perform branch target load optimization after prologue / epilogue threading."
 msgstr "Effectuer l'optimisation du chargement de la cible du branchement après l'enfilage du prologue ou de l'épilogue."
 
-#: common.opt:1075
+#: common.opt:1079
 msgid "Restrict target load migration not to re-use registers in any basic block."
 msgstr "Restreindre la migration du chargement de la cible pour que les registres ne soient réutilisés dans aucun bloc de base."
 
-#: common.opt:1079
+#: common.opt:1083
 msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions."
 msgstr "-fcall-saved-<registre>\tMarquer le <registre> comme étant préservé au travers des fonctions."
 
-#: common.opt:1083
+#: common.opt:1087
 msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls."
 msgstr "-fcall-used-<registre>\tMarquer le <registre> comme étant corrompu par les appels de fonctions."
 
-#: common.opt:1090
+#: common.opt:1094
 msgid "Save registers around function calls."
 msgstr "Sauvegarder les registres autour des appels de fonctions."
 
-#: common.opt:1094
+#: common.opt:1098
 msgid "This switch is deprecated; do not use."
 msgstr "Cette option est obsolète; ne l'utilisez pas."
 
-#: common.opt:1098
+#: common.opt:1102
 msgid "Check the return value of new in C++."
 msgstr "Vérifier la valeur retournée par new en C++."
 
-#: common.opt:1102 common.opt:1106
+#: common.opt:1106 common.opt:1110
 msgid "Perform internal consistency checkings."
 msgstr "Réaliser des validations internes d'intégrité."
 
-#: common.opt:1110
+#: common.opt:1114
 msgid "Enable code hoisting."
 msgstr "Activer la sortie du code hors des boucles."
 
-#: common.opt:1114
+#: common.opt:1118
 msgid "Looks for opportunities to reduce stack adjustments and stack references."
 msgstr "Chercher des opportunités de réduire les ajustements de pile et les références à la pile."
 
-#: common.opt:1118
+#: common.opt:1122
 msgid "Do not put uninitialized globals in the common section."
 msgstr "Ne pas placer les globaux non initialisés dans la section commune."
 
-#: common.opt:1126
+#: common.opt:1130
 msgid "-fcompare-debug[=<opts>]\tCompile with and without e.g. -gtoggle, and compare the final-insns dump."
 msgstr "-fcompare-debug[=<opts>]\tCompiler avec et sans l'option (par ex. -gtoggle) et comparer la vidange des insns finales."
 
-#: common.opt:1130
+#: common.opt:1134
 msgid "Run only the second compilation of -fcompare-debug."
 msgstr "N'exécuter que la seconde compilation de -fcompare-debug."
 
-#: common.opt:1134
+#: common.opt:1138
 msgid "Perform comparison elimination after register allocation has finished."
 msgstr "Réaliser l'élimination des comparaisons après que l'allocation des registres ait été terminée."
 
-#: common.opt:1138
+#: common.opt:1142
 msgid "Do not perform optimizations increasing noticeably stack usage."
 msgstr "Ne pas appliquer les optimisations qui augmentent notablement l'utilisation de la pile."
 
-#: common.opt:1142
+#: common.opt:1146
 msgid "Perform a register copy-propagation optimization pass."
 msgstr "Effectuer une étape d'optimisation par propagation des copies des registres."
 
-#: common.opt:1146
+#: common.opt:1150
 msgid "Perform cross-jumping optimization."
 msgstr "Exécuter l'optimisation des sauts croisés."
 
-#: common.opt:1150
+#: common.opt:1154
 msgid "When running CSE, follow jumps to their targets."
 msgstr "Lorsque CSE s'exécute, suivre les sauts jusqu'à leurs cibles."
 
-#: common.opt:1158
+#: common.opt:1162
 msgid "Omit range reduction step when performing complex division."
 msgstr "Omettre l'étape de réduction de plage en réalisant des divisions complexes."
 
-#: common.opt:1162
+#: common.opt:1166
 msgid "Complex multiplication and division follow Fortran rules."
 msgstr "Les multiplications et les divisions complexes suivent les règles du Fortran."
 
-#: common.opt:1166
+#: common.opt:1170
 msgid "Place data items into their own section."
 msgstr "Placer les éléments de données dans leur propre section."
 
-#: common.opt:1170
+#: common.opt:1174
 msgid "List all available debugging counters with their limits and counts."
 msgstr "Lister tous les compteurs de débogage disponibles avec leurs limites et leurs valeurs."
 
-#: common.opt:1174
+#: common.opt:1178
 msgid "-fdbg-cnt=<counter>:<limit>[,<counter>:<limit>,...]\tSet the debug counter limit."
 msgstr "-fdbg-cnt=<compteur>:<limite>[,<compteur>:<limite>,…]\tDéfinir la limite du compteur de débogage."
 
-#: common.opt:1178
+#: common.opt:1182
 msgid "-fdebug-prefix-map=<old>=<new> Map one directory name to another in debug information."
 msgstr "-fdebug-prefix-map=<old>=<new> Remplacer un nom de répertoire par un autre dans les informations de débogage."
 
-#: common.opt:1182
+#: common.opt:1186
 msgid "-ffile-prefix-map=<old>=<new> Map one directory name to another in compilation result."
 msgstr "-ffile-prefix-map=<old>=<new> Remplacer un nom de répertoire par un autre dans le résultat de la compilation."
 
-#: common.opt:1186
+#: common.opt:1190
 msgid "Output .debug_types section when using DWARF v4 debuginfo."
 msgstr "Écrire une section .debug_types lorsque debuginfo de DWARF v4 est utilisé."
 
-#: common.opt:1192
+#: common.opt:1196
 msgid "Defer popping functions args from stack until later."
 msgstr "Retarder à plus tard le dépilage des arguments des fonctions hors de la pile."
 
-#: common.opt:1196
+#: common.opt:1200
 msgid "Attempt to fill delay slots of branch instructions."
 msgstr "Tenter de remplir les créneaux de retard (delay slots) des instructions de branchement."
 
-#: common.opt:1200
+#: common.opt:1204
 msgid "Delete dead instructions that may throw exceptions."
 msgstr "Supprimer les instructions inutiles qui peuvent déclencher des exceptions."
 
-#: common.opt:1204
+#: common.opt:1208
 msgid "Delete useless null pointer checks."
 msgstr "Supprimer les vérifications inutiles des pointeurs nuls."
 
-#: common.opt:1208
+#: common.opt:1212
 msgid "Stream extra data to support more aggressive devirtualization in LTO local transformation mode."
 msgstr "Produire des données supplémentaires pour fournir une dévirtualisation plus agressive dans le mode de transformation local de LTO."
 
-#: common.opt:1212
+#: common.opt:1216
 msgid "Perform speculative devirtualization."
 msgstr "Réaliser une dévirtualisation spéculative."
 
-#: common.opt:1216
+#: common.opt:1220
 msgid "Try to convert virtual calls to direct ones."
 msgstr "Essayer de convertir les appels virtuels en appels directs."
 
-#: common.opt:1220
+#: common.opt:1224
 msgid "-fdiagnostics-show-location=[once|every-line]\tHow often to emit source location at the beginning of line-wrapped diagnostics."
 msgstr "-fdiagnostics-show-location=[once|every-line]\tIndiquer combien de fois les informations sur l'emplacement dans le code source doivent être répétées au début des lignes de diagnostiques écrites sur plusieurs lignes."
 
-#: common.opt:1237
+#: common.opt:1241
 msgid "Show the source line with a caret indicating the column."
 msgstr "Montrer la ligne source avec un curseur indiquant la colonne."
 
-#: common.opt:1245
+#: common.opt:1249
 msgid "-fdiagnostics-color=[never|always|auto]\tColorize diagnostics."
 msgstr "-fdiagnostics-color=[never|always|auto]\tAfficher les diagnostiques en couleur."
 
-#: common.opt:1265
+#: common.opt:1269
 msgid "Print fix-it hints in machine-readable form."
 msgstr "Afficher les indices pour la correction sous forme lisible par une machine."
 
-#: common.opt:1269
+#: common.opt:1273
 msgid "Print fix-it hints to stderr in unified diff format."
 msgstr "Afficher les indices pour la correction vers stderr au format diff unifié."
 
-#: common.opt:1273
+#: common.opt:1277
 msgid "Amend appropriate diagnostic messages with the command line option that controls them."
 msgstr "Amender les messages de diagnostiques appropriés avec les options de la ligne de commande qui les contrôlent."
 
-#: common.opt:1277
+#: common.opt:1281
 msgid "-fdisable-[tree|rtl|ipa]-<pass>=range1+range2 disables an optimization pass."
 msgstr "-fdisable-[tree|rtl|ipa]-<étape>=range1+range2 désactiver une étape d'optimisation."
 
-#: common.opt:1281
+#: common.opt:1285
 msgid "-fenable-[tree|rtl|ipa]-<pass>=range1+range2 enables an optimization pass."
 msgstr "-fenable-[tree|rtl|ipa]-<étape>=range1+range2 activer une étape d'optimisation."
 
-#: common.opt:1285
+#: common.opt:1289
 msgid "-fdump-<type>\tDump various compiler internals to a file."
 msgstr "-fdump-<type>\tVidanger diverses données internes du compilateur dans un fichier."
 
-#: common.opt:1292
+#: common.opt:1296
 msgid "-fdump-final-insns=filename\tDump to filename the insns at the end of translation."
 msgstr "-fdump-final-insns=fichier\tVidanger dans un fichier les insns à la fin d'une traduction."
 
-#: common.opt:1296
+#: common.opt:1300
 msgid "-fdump-go-spec=filename\tWrite all declarations to file as Go code."
 msgstr "-fdump-go-spec=fichier\tÉcrire toutes les déclarations dans un fichier sous forme de code Go."
 
-#: common.opt:1300
+#: common.opt:1304
 msgid "Suppress output of addresses in debugging dumps."
 msgstr "Supprimer la sortie des adresses dans les vidanges de débogage."
 
 # ICE=Internal Compiler Error
-#: common.opt:1304
+#: common.opt:1308
 msgid "Collect and dump debug information into temporary file if ICE in C/C++ compiler occurred."
 msgstr "Collecter et décharger les informations de débogage dans un fichier temporaire si une erreur interne du compilateur a eu lieu dans le compilateur C/C++."
 
-#: common.opt:1309
+#: common.opt:1313
 msgid "Dump detailed information on GCC's internal representation of source code locations."
 msgstr "Vidanger les informations détaillées sur la représentation interne de GCC des emplacements du code source."
 
-#: common.opt:1313
+#: common.opt:1317
 msgid "Dump optimization passes."
 msgstr "Vidanger les étapes d'optimisation."
 
-#: common.opt:1317
+#: common.opt:1321
 msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps."
 msgstr "Supprimer la sortie des numéros d'instructions, des numéros de lignes et des adresses dans les vidanges de débogage."
 
-#: common.opt:1321
+#: common.opt:1325
 msgid "Suppress output of previous and next insn numbers in debugging dumps."
 msgstr "Supprimer la sortie des numéros d'insn précédents et suivants dans les vidanges de débogage."
 
-#: common.opt:1325
+#: common.opt:1329
 msgid "Enable CFI tables via GAS assembler directives."
 msgstr "Activer les tables CFI via les directives de l'assembleur GAS."
 
-#: common.opt:1329
+#: common.opt:1333
 msgid "Perform early inlining."
 msgstr "Exécuter la mise en ligne très tôt."
 
-#: common.opt:1337
+#: common.opt:1341
 msgid "Perform interprocedural reduction of aggregates."
 msgstr "Réaliser la réduction interprocédurale des agrégats."
 
-#: common.opt:1341
+#: common.opt:1345
 msgid "Perform unused symbol elimination in debug info."
 msgstr "Effectuer l'élimination des symboles inutilisés dans les informations de débogage."
 
-#: common.opt:1345
+#: common.opt:1349
 msgid "Perform unused type elimination in debug info."
 msgstr "Effectuer l'élimination des types inutilisés dans l'information de débogage."
 
-#: common.opt:1349
+#: common.opt:1353
 msgid "Do not suppress C++ class debug information."
 msgstr "Ne pas supprimer les informations de débogage des classes C++."
 
-#: common.opt:1353
+#: common.opt:1357
 msgid "Enable exception handling."
 msgstr "Activer le traitement des exceptions."
 
-#: common.opt:1357
+#: common.opt:1361
 msgid "Perform a number of minor, expensive optimizations."
 msgstr "Effectuer un nombre d'optimisations mineures et coûteuses."
 
-#: common.opt:1361
+#: common.opt:1365
 msgid "-fexcess-precision=[fast|standard]\tSpecify handling of excess floating-point precision."
 msgstr "-fexcess-precision=[fast|standard]\tSpécifier la manière de gérer l'excédant de précision en virgule flottante."
 
-#: common.opt:1364
+#: common.opt:1368
 #, c-format
 msgid "unknown excess precision style %qs"
 msgstr "style de précision excédentaire %qs inconnu"
 
-#: common.opt:1376
+#: common.opt:1380
 msgid "-fpermitted-flt-eval-methods=[c11|ts-18661]\tSpecify which values of FLT_EVAL_METHOD are permitted."
 msgstr "-fpermitted-flt-eval-methods=[c11|ts-18661]\tSpécifier les valeurs permises pour FLT_EVAL_METHOD."
 
-#: common.opt:1379
+#: common.opt:1383
 #, c-format
 msgid "unknown specification for the set of FLT_EVAL_METHOD values to permit %qs"
 msgstr "spécification inconnue pour l'ensemble des valeurs de FLT_EVAL_METHOD à permettre %qs"
 
-#: common.opt:1392
+#: common.opt:1396
 msgid "Output lto objects containing both the intermediate language and binary output."
 msgstr "Produire les objets LTO contenant à la fois le langage intermédiaire et la sortie binaire."
 
-#: common.opt:1396
+#: common.opt:1400
 msgid "Assume no NaNs or infinities are generated."
 msgstr "Supposer qu'aucun NaN ni aucun infini ne sont générés."
 
-#: common.opt:1400
+#: common.opt:1404
 msgid "-ffixed-<register>\tMark <register> as being unavailable to the compiler."
 msgstr "-ffixed-<registre>\tMarquer le <registre> comme n'étant pas disponible pour le compilateur."
 
-#: common.opt:1404
+#: common.opt:1408
 msgid "Don't allocate floats and doubles in extended-precision registers."
 msgstr "Ne pas allouer des float ni des double dans des registres en précision étendue."
 
-#: common.opt:1412
+#: common.opt:1416
 msgid "Perform a forward propagation pass on RTL."
 msgstr "Réaliser une étape de propagation dans RTL (Register Transfer Language)."
 
-#: common.opt:1416
+#: common.opt:1420
 msgid "-ffp-contract=[off|on|fast]\tPerform floating-point expression contraction."
 msgstr "-ffp-contract=[off|on|fast]\tRéaliser la contraction d'expression en virgule flottante."
 
-#: common.opt:1419
+#: common.opt:1423
 #, c-format
 msgid "unknown floating point contraction style %qs"
 msgstr "style de contraction en virgule flottante %qs inconnu"
 
-#: common.opt:1433
+#: common.opt:1437
 msgid "Allow built-in functions ceil, floor, round, trunc to raise \"inexact\" exceptions."
 msgstr "Autoriser les fonctions internes ceil, floor, round, trunc à déclencher des exceptions « inexactes »."
 
-#: common.opt:1440
+#: common.opt:1444
 msgid "Allow function addresses to be held in registers."
 msgstr "Autoriser le maintien des adresses de fonctions dans les registres."
 
-#: common.opt:1444
+#: common.opt:1448
 msgid "Place each function into its own section."
 msgstr "Placer chaque fonction dans sa propre section."
 
-#: common.opt:1448
+#: common.opt:1452
 msgid "Perform global common subexpression elimination."
 msgstr "Exécuter l'élimination des sous-expressions communes globales."
 
-#: common.opt:1452
+#: common.opt:1456
 msgid "Perform enhanced load motion during global common subexpression elimination."
 msgstr "Exécuter le mouvement de chargement amélioré lors de l'élimination des sous-expressions communes globales."
 
-#: common.opt:1456
+#: common.opt:1460
 msgid "Perform store motion after global common subexpression elimination."
 msgstr "Exécuter le mouvement de stockage après l'élimination des sous-expressions communes globales."
 
-#: common.opt:1460
+#: common.opt:1464
 msgid "Perform redundant load after store elimination in global common subexpression elimination."
 msgstr "Réaliser les chargements redondants après l'élimination des stockages dans les sous-expressions communes globales."
 
-#: common.opt:1465
+#: common.opt:1469
 msgid "Perform global common subexpression elimination after register allocation has finished."
 msgstr "Exécuter l'élimination des sous-expressions communes globales après que l'allocation des registres soit terminée."
 
-#: common.opt:1482
+#: common.opt:1486
 msgid "-fgnat-encodings=[all|gdb|minimal]\tSelect the balance between GNAT encodings and standard DWARF emitted in the debug information"
 msgstr "-fgnat-encodings=[all|gdb|minimal]\tSélectionner l'équilibre entre les encodages GNAT et le DWARF standard produit dans les informations de débogage."
 
-#: common.opt:1487
+#: common.opt:1491
 msgid "Enable in and out of Graphite representation."
 msgstr "Activer les entrées et sorties de la représentation Graphite."
 
-#: common.opt:1491
+#: common.opt:1495
 msgid "Enable Graphite Identity transformation."
 msgstr "Activer la transformation d'identité Graphite."
 
-#: common.opt:1495
+#: common.opt:1499
 msgid "Enable hoisting adjacent loads to encourage generating conditional move instructions."
 msgstr "Activer la sortie de chargements adjacents hors d'une boucle pour encourager la génération d'instructions de déplacements conditionnels."
 
-#: common.opt:1504
+#: common.opt:1508
 msgid "Mark all loops as parallel."
 msgstr "Marquer toutes les boucles comme étant parallèles."
 
-#: common.opt:1508 common.opt:1516 common.opt:2587
+#: common.opt:1512 common.opt:1520 common.opt:2591
 msgid "Enable loop nest transforms.  Same as -floop-nest-optimize."
 msgstr "Activer les transformations de boucles imbriquées.  Identique à -floop-nest-optimize."
 
-#: common.opt:1512
+#: common.opt:1516
 msgid "Enable loop interchange on trees."
 msgstr "Activer l'échange de boucles sur les arbres."
 
-#: common.opt:1520
+#: common.opt:1524
 msgid "Perform unroll-and-jam on loops."
 msgstr "Réaliser le unroll-and-jam."
 
-#: common.opt:1524
+#: common.opt:1528
 msgid "Enable support for GNU transactional memory."
 msgstr "Activer le support pour la mémoire transactionnelle GNU."
 
-#: common.opt:1528
+#: common.opt:1532
 msgid "Use STB_GNU_UNIQUE if supported by the assembler."
 msgstr "Utiliser STB_GNU_UNIQUE si supporté par l'assembleur."
 
-#: common.opt:1536
+#: common.opt:1540
 msgid "Enable the loop nest optimizer."
 msgstr "Activer l'optimisation de boucles imbriquées."
 
-#: common.opt:1540
+#: common.opt:1544
 msgid "Force bitfield accesses to match their type width."
 msgstr "Forcer les accès aux champs de bits à correspondre à la largeur de leur type."
 
-#: common.opt:1544
+#: common.opt:1548
 msgid "Merge adjacent stores."
 msgstr "Fusionner les stockages adjacents."
 
-#: common.opt:1548
+#: common.opt:1552
 msgid "Enable guessing of branch probabilities."
 msgstr "Activer l'estimation des probabilités de branchement."
 
-#: common.opt:1556
+#: common.opt:1560
 msgid "Process #ident directives."
 msgstr "Traiter les directives #ident."
 
-#: common.opt:1560
+#: common.opt:1564
 msgid "Perform conversion of conditional jumps to branchless equivalents."
 msgstr "Convertir les sauts conditionnels en équivalents sans branchements."
 
-#: common.opt:1564
+#: common.opt:1568
 msgid "Perform conversion of conditional jumps to conditional execution."
 msgstr "Convertir les sauts conditionnels en exécutions conditionnelles."
 
-#: common.opt:1568
+#: common.opt:1572
 msgid "-fstack-reuse=[all|named_vars|none]\tSet stack reuse level for local variables."
 msgstr "-fstack-reuse=[all|named_vars|none]\tDéfinir le niveau de réutilisation de la pile pour les variables locales."
 
-#: common.opt:1571
+#: common.opt:1575
 #, c-format
 msgid "unknown Stack Reuse Level %qs"
 msgstr "Niveau de réutilisation de la pile %qs inconnu"
 
-#: common.opt:1584
+#: common.opt:1588
 msgid "Convert conditional jumps in innermost loops to branchless equivalents."
 msgstr "Convertir les sauts conditionnels des boucles les plus à l'intérieur en équivalents sans branchement."
 
-#: common.opt:1596
+#: common.opt:1600
 msgid "Do not generate .size directives."
 msgstr "Ne pas générer de directives .size."
 
-#: common.opt:1600
+#: common.opt:1604
 msgid "Perform indirect inlining."
 msgstr "Réaliser la mise en ligne indirecte."
 
-#: common.opt:1606
+#: common.opt:1610
 msgid "Enable inlining of function declared \"inline\", disabling disables all inlining."
 msgstr "Activer la mise en ligne de fonctions déclarées « inline ». Le désactiver désactive toutes les mises en ligne."
 
-#: common.opt:1610
+#: common.opt:1614
 msgid "Integrate functions into their callers when code size is known not to grow."
 msgstr "Intégrer les fonctions à l'intérieur de leurs appelants si il est établi que la taille du code ne grandira pas."
 
-#: common.opt:1614
+#: common.opt:1618
 msgid "Integrate functions not declared \"inline\" into their callers when profitable."
 msgstr "Intégrer les fonctions qui ne sont pas déclarées « inline » dans leurs appelants quand cela est profitable."
 
-#: common.opt:1618
+#: common.opt:1622
 msgid "Integrate functions only required by their single caller."
 msgstr "Intégrer les fonctions qui ne sont requises que par leur unique appelant."
 
-#: common.opt:1625
+#: common.opt:1629
 msgid "-finline-limit=<number>\tLimit the size of inlined functions to <number>."
 msgstr "-finline-limit=<nombre>\tLimiter la taille des fonction mises en ligne à <nombre>."
 
-#: common.opt:1629
+#: common.opt:1633
 msgid "Inline __atomic operations when a lock free instruction sequence is available."
 msgstr "Mettre en ligne les opérations __atomic quand une séquence d'instructions sans blocage est disponible."
 
-#: common.opt:1636
+#: common.opt:1640
 msgid "-fcf-protection=[full|branch|return|none]\tInstrument functions with checks to verify jump/call/return control-flow transfer instructions have valid targets."
 msgstr "-fcf-protection=[full|branch|return|none]\tInstrumentaliser les fonctions avec des contrôles pour vérifier que les instructions de contrôle de flux jump/call/return ont une cible valable."
 
-#: common.opt:1640
+#: common.opt:1644
 #, c-format
 msgid "unknown Control-Flow Protection Level %qs"
 msgstr "niveau de Control-Flow Protection %qs inconnu"
 
-#: common.opt:1656
+#: common.opt:1660
 msgid "Instrument function entry and exit with profiling calls."
 msgstr "Ajouter des appels de profilage aux entrées et aux sorties des fonctions."
 
-#: common.opt:1660
+#: common.opt:1664
 msgid "-finstrument-functions-exclude-function-list=name,...  Do not instrument listed functions."
 msgstr "-finstrument-functions-exclude-function-list=nom,...  Ne pas ajouter les appels de profilage aux fonctions listées."
 
-#: common.opt:1664
+#: common.opt:1668
 msgid "-finstrument-functions-exclude-file-list=filename,...  Do not instrument functions listed in files."
 msgstr "-finstrument-functions-exclude-file-list=fichier,...  Ne pas ajouter les appels de profilage aux fonctions listées dans les fichiers."
 
-#: common.opt:1668
+#: common.opt:1672
 msgid "Perform interprocedural constant propagation."
 msgstr "Réaliser la propagation interprocédurale des constantes."
 
-#: common.opt:1672
+#: common.opt:1676
 msgid "Perform cloning to make Interprocedural constant propagation stronger."
 msgstr "Réaliser un clonage pour rendre plus forte la propagation interprocédurale des constantes."
 
-#: common.opt:1680
+#: common.opt:1684
 msgid "Perform interprocedural bitwise constant propagation."
 msgstr "Réaliser la propagation interprocédurale des constantes de bits."
 
-#: common.opt:1684
+#: common.opt:1688
 msgid "Perform interprocedural profile propagation."
 msgstr "Réaliser la propagation interprocédurale de profiles."
 
-#: common.opt:1688
+#: common.opt:1692
 msgid "Perform interprocedural points-to analysis."
 msgstr "Réaliser l'analyse interprocédurale des pointeurs et références."
 
-#: common.opt:1692
+#: common.opt:1696
 msgid "Discover pure and const functions."
 msgstr "Découvrir les fonctions pures et const."
 
-#: common.opt:1696
+#: common.opt:1700
 msgid "Perform Identical Code Folding for functions and read-only variables."
 msgstr "Fusionner le code identique (Identical Code Folding) pour les fonctions et les variables en lecture seule."
 
-#: common.opt:1700
+#: common.opt:1704
 msgid "Perform Identical Code Folding for functions."
 msgstr "Fusionner le code identique (Identical Code Folding) pour les fonctions."
 
-#: common.opt:1704
+#: common.opt:1708
 msgid "Perform Identical Code Folding for variables."
 msgstr "Fusionner le code identique (Identical Code Folding) pour les variables."
 
-#: common.opt:1708
+#: common.opt:1712
 msgid "Discover readonly and non addressable static variables."
 msgstr "Découvrir les variables statiques en lecture seule et non adressables."
 
-#: common.opt:1720
+#: common.opt:1724
 msgid "Perform IPA Value Range Propagation."
 msgstr "Effectuer la propagation des plages de valeurs IPA."
 
-#: common.opt:1724
+#: common.opt:1728
 msgid "-fira-algorithm=[CB|priority]\tSet the used IRA algorithm."
 msgstr "-fira-algorithm=[CB|priority]\tDéfinir l'algorithme IRA utilisé."
 
-#: common.opt:1727
+#: common.opt:1731
 #, c-format
 msgid "unknown IRA algorithm %qs"
 msgstr "algorithme IRA %qs inconnu"
 
-#: common.opt:1737
+#: common.opt:1741
 msgid "-fira-region=[one|all|mixed]\tSet regions for IRA."
 msgstr "-fira-region=[one|all|mixed]\tDéfinir les régions pour IRA."
 
-#: common.opt:1740
+#: common.opt:1744
 #, c-format
 msgid "unknown IRA region %qs"
 msgstr "région IRA %qs inconnue"
 
-#: common.opt:1753
+#: common.opt:1757
 msgid "Use IRA based register pressure calculation in RTL hoist optimizations."
 msgstr "Utiliser le calcul de la pression sur les registres basé sur IRA dans les optimisations qui ont pour but de sortir du code hors d'une boucle durant la phase RTL."
 
-#: common.opt:1758
+#: common.opt:1762
 msgid "Use IRA based register pressure calculation in RTL loop optimizations."
 msgstr "Utiliser le calcul de la pression sur les registres basé sur IRA dans les optimisations de boucles durant la phase RTL."
 
-#: common.opt:1763
+#: common.opt:1767
 msgid "Share slots for saving different hard registers."
 msgstr "Partager les emplacements pour sauvegarder différents registres matériels."
 
-#: common.opt:1767
+#: common.opt:1771
 msgid "Share stack slots for spilled pseudo-registers."
 msgstr "Partager les emplacements sur la pile pour faire déborder les pseudo registres."
 
-#: common.opt:1771
+#: common.opt:1775
 msgid "-fira-verbose=<number>\tControl IRA's level of diagnostic messages."
 msgstr "-fira-verbose=<nombre>\tContrôler le niveau des messages de diagnostique de IRA."
 
-#: common.opt:1775
+#: common.opt:1779
 msgid "Optimize induction variables on trees."
 msgstr "Optimiser les variables d'induction dans les arbres."
 
-#: common.opt:1779
+#: common.opt:1783
 msgid "Use jump tables for sufficiently large switch statements."
 msgstr "Utiliser des tables de sauts pour des instructions switch suffisamment grandes."
 
-#: common.opt:1783
+#: common.opt:1787
 msgid "Generate code for functions even if they are fully inlined."
 msgstr "Générer le code pour les fonctions même si elles sont complètement mises en ligne."
 
-#: common.opt:1787
+#: common.opt:1791
 msgid "Generate code for static functions even if they are never called."
 msgstr "Générer le code pour les fonctions statiques même si elles ne sont jamais appelées."
 
-#: common.opt:1791
+#: common.opt:1795
 msgid "Emit static const variables even if they are not used."
 msgstr "Produire les variables constantes statiques même si elles ne sont pas utilisées."
 
-#: common.opt:1795
+#: common.opt:1799
 msgid "Give external symbols a leading underscore."
 msgstr "Préfixer les symboles externes avec un caractère de soulignement."
 
-#: common.opt:1803
+#: common.opt:1807
 msgid "Do CFG-sensitive rematerialization in LRA."
 msgstr "Faire une rematérialisation sensible au CFG pendant LRA."
 
-#: common.opt:1807
+#: common.opt:1811
 msgid "Enable link-time optimization."
 msgstr "Activer les optimisations durant l'édition de liens."
 
-#: common.opt:1811
+#: common.opt:1815
 msgid "Link-time optimization with number of parallel jobs or jobserver."
 msgstr "Les optimisations durant l'édition de liens sont faites avec un nombre de tâches parallèles ou un serveur de tâches."
 
-#: common.opt:1814
+#: common.opt:1818
 #, c-format
 msgid "unknown LTO partitioning model %qs"
 msgstr "modèle de partitionnement LTO %qs inconnu"
 
-#: common.opt:1833
+#: common.opt:1837
 msgid "Specify the algorithm to partition symbols and vars at linktime."
 msgstr "Spécifier l'algorithme pour partitionner les symboles et les variables durant l'édition de liens."
 
-#: common.opt:1838
+#: common.opt:1842
 msgid "-flto-compression-level=<number>\tUse zlib compression level <number> for IL."
 msgstr "-flto-compression-level=<nombre>\tUtiliser le niveau de compression <nombre> de zlib pour le langage intermédiaire (IL)."
 
-#: common.opt:1842
+#: common.opt:1846
 msgid "Merge C++ types using One Definition Rule."
 msgstr "Fusionner les types C++ en utilisant la règle de la définition unique."
 
-#: common.opt:1846
+#: common.opt:1850
 msgid "Report various link-time optimization statistics."
 msgstr "Rapporter diverses statistiques d'optimisation durant l'édition de liens."
 
-#: common.opt:1850
+#: common.opt:1854
 msgid "Report various link-time optimization statistics for WPA only."
 msgstr "Rapporter diverses statistiques d'optimisation durant l'édition de liens uniquement dans le mode d'analyse complète du programme (mode WPA)."
 
-#: common.opt:1854
+#: common.opt:1858
 msgid "Set errno after built-in math functions."
 msgstr "Changer la valeur de errno après les fonctions mathématiques internes."
 
-#: common.opt:1858
+#: common.opt:1862
 msgid "-fmax-errors=<number>\tMaximum number of errors to report."
 msgstr "-fmax-errors=<nombre>\tNombre maximum d'erreurs à rapporter."
 
-#: common.opt:1862
+#: common.opt:1866
 msgid "Report on permanent memory allocation."
 msgstr "Produire un rapport sur l'allocation de mémoire permanente."
 
-#: common.opt:1866
+#: common.opt:1870
 msgid "Report on permanent memory allocation in WPA only."
 msgstr "Produire un rapport sur l'allocation de mémoire permanente dans le mode d'analyse complète du programme (WPA mode)."
 
-#: common.opt:1873
+#: common.opt:1877
 msgid "Attempt to merge identical constants and constant variables."
 msgstr "Tenter de fusionner les constantes et les variables constantes identiques."
 
-#: common.opt:1877
+#: common.opt:1881
 msgid "Attempt to merge identical constants across compilation units."
 msgstr "Tenter de fusionner les constantes identiques au travers des unités de compilation."
 
-#: common.opt:1881
+#: common.opt:1885
 msgid "Attempt to merge identical debug strings across compilation units."
 msgstr "Tenter de fusionner les chaînes de débogage identiques au travers des unités de compilation."
 
-#: common.opt:1885
+#: common.opt:1889
 msgid "-fmessage-length=<number>\tLimit diagnostics to <number> characters per line.  0 suppresses line-wrapping."
 msgstr "-fmessage-length=<nombre>\tLimiter la longueur des diagnostiques à <nombre> caractères par ligne.  0 supprime le retour automatique à la ligne."
 
 # SMS= Swing Module Scheduler: est-il besoin de le préciser ?
-#: common.opt:1889
+#: common.opt:1893
 msgid "Perform SMS based modulo scheduling before the first scheduling pass."
 msgstr "Réaliser l'ordonnancement modulo basé sur SMS avant la première étape de l'ordonnancement."
 
-#: common.opt:1893
+#: common.opt:1897
 msgid "Perform SMS based modulo scheduling with register moves allowed."
 msgstr "Réaliser l'ordonnancement modulo basé sur SMS en autorisant les déplacements de registres."
 
-#: common.opt:1897
+#: common.opt:1901
 msgid "Move loop invariant computations out of loops."
 msgstr "Déplacer hors des boucles les calculs invariants par rapport aux boucles."
 
-#: common.opt:1901
+#: common.opt:1905
 msgid "Use the RTL dead code elimination pass."
 msgstr "Utiliser l'étape d'élimination du code RTL mort."
 
-#: common.opt:1905
+#: common.opt:1909
 msgid "Use the RTL dead store elimination pass."
 msgstr "Utiliser l'étape d'élimination des stockages RTL morts."
 
-#: common.opt:1909
+#: common.opt:1913
 msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling."
 msgstr "Activer/Désactiver l'ordonnancement traditionnel dans les boucles qui sont déjà passées par l'ordonnancement modulo."
 
 # Je ne comprends même pas comment le message anglais est censé être compréhensible !
-#: common.opt:1913
+#: common.opt:1917
 msgid "Support synchronous non-call exceptions."
 msgstr "Supporter les exceptions émises par des routines de déroutement."
 
-#: common.opt:1916
+#: common.opt:1920
 #, c-format
 msgid "options or targets missing after %qs"
 msgstr "options ou cibles manquantes après %qs"
 
-#: common.opt:1917
+#: common.opt:1921
 msgid "-foffload=<targets>=<options>  Specify offloading targets and options for them."
 msgstr "-foffload=<cible>=<options>  Spécifier les cibles pour les déchargements et leurs options."
 
-#: common.opt:1921
+#: common.opt:1925
 msgid "-foffload-abi=[lp64|ilp32]     Set the ABI to use in an offload compiler."
 msgstr "-foffload-abi=[lp64|ilp32]     Définir l'ABI à utiliser dans un compilateur de déchargement."
 
-#: common.opt:1924
+#: common.opt:1928
 #, c-format
 msgid "unknown offload ABI %qs"
 msgstr "ABI de déchargement %qs inconnue"
 
-#: common.opt:1934
+#: common.opt:1938
 msgid "When possible do not generate stack frames."
 msgstr "Lorsque c'est possible, ne pas générer des trames de pile."
 
-#: common.opt:1938
+#: common.opt:1942
 msgid "Enable all optimization info dumps on stderr."
 msgstr "Activer toutes les vidanges des informations d'optimisation sur stderr."
 
-#: common.opt:1942
+#: common.opt:1946
 msgid "-fopt-info[-<type>=filename]\tDump compiler optimization details."
 msgstr "-fopt-info[-<type>=fichier]\tVidanger les détails de l'optimisation du compilateur."
 
-#: common.opt:1950
+#: common.opt:1954
 msgid "Optimize sibling and tail recursive calls."
 msgstr "Optimiser les appels récursifs dans des fonctions apparentées (sibbling call) et à la fin de la fonction (tail call)."
 
-#: common.opt:1954
+#: common.opt:1958
 msgid "Perform partial inlining."
 msgstr "Réaliser une mise en ligne partielle."
 
-#: common.opt:1958 common.opt:1962
+#: common.opt:1962 common.opt:1966
 msgid "Report on memory allocation before interprocedural optimization."
 msgstr "Produire un rapport sur l'allocation de mémoire avant l'optimisation interprocédurale."
 
-#: common.opt:1966
+#: common.opt:1970
 msgid "Pack structure members together without holes."
 msgstr "Empaqueter les membres des structures ensemble sans trous."
 
-#: common.opt:1970
+#: common.opt:1974
 msgid "-fpack-struct=<number>\tSet initial maximum structure member alignment."
 msgstr "-fpack-struct=<nombre>\tDéfinir l'alignement initial maximum des membres d'une structure."
 
-#: common.opt:1974
+#: common.opt:1978
 msgid "Return small aggregates in memory, not registers."
 msgstr "Retourner les petits agrégats en mémoire, pas dans les registres."
 
-#: common.opt:1978
+#: common.opt:1982
 msgid "Perform loop peeling."
 msgstr "Effectuer l'aplatissage des boucles."
 
-#: common.opt:1982
+#: common.opt:1986
 msgid "Enable machine specific peephole optimizations."
 msgstr "Activer les optimisations sur de petits segments de code (peephole) spécifiques à la machine."
 
-#: common.opt:1986
+#: common.opt:1990
 msgid "Enable an RTL peephole pass before sched2."
 msgstr "Activer une étape d'optimisation sur de petits segments de code (peephole) par RTL avant sched2."
 
-#: common.opt:1990
+#: common.opt:1994
 msgid "Generate position-independent code if possible (large mode)."
 msgstr "Générer du code indépendant de la position si possible (mode large)."
 
-#: common.opt:1994
+#: common.opt:1998
 msgid "Generate position-independent code for executables if possible (large mode)."
 msgstr "Générer du code indépendant de la position pour les exécutables si possible (mode large)."
 
-#: common.opt:1998
+#: common.opt:2002
 msgid "Generate position-independent code if possible (small mode)."
 msgstr "Générer du code indépendant de la position si possible (mode petit)."
 
-#: common.opt:2002
+#: common.opt:2006
 msgid "Generate position-independent code for executables if possible (small mode)."
 msgstr "Générer du code indépendant de la position pour les exécutables si possible (mode petit)."
 
-#: common.opt:2006
+#: common.opt:2010
 msgid "Use PLT for PIC calls (-fno-plt: load the address from GOT at call site)."
 msgstr "Utiliser la PLT pour les appels PIC (-fno-plt: charger l'adresse depuis la GOT à l'endroit de l'appel)."
 
-#: common.opt:2010
+#: common.opt:2014
 msgid "Specify a plugin to load."
 msgstr "Spécifier un greffon à charger."
 
-#: common.opt:2014
+#: common.opt:2018
 msgid "-fplugin-arg-<name>-<key>[=<value>]\tSpecify argument <key>=<value> for plugin <name>."
 msgstr "-fplugin-arg-<nom>-<clé>[=<valeur>]\tSpécifier l'argument <clé>=<valeur> pour le greffon <nom>."
 
-#: common.opt:2018
+#: common.opt:2022
 msgid "Run predictive commoning optimization."
 msgstr "Exécuter l'optimisation de mise en commun prédictive."
 
-#: common.opt:2022
+#: common.opt:2026
 msgid "Generate prefetch instructions, if available, for arrays in loops."
 msgstr "Générer des instructions de préchargement, si disponible, pour les tableaux dans les boucles."
 
-#: common.opt:2026
+#: common.opt:2030
 msgid "Enable basic program profiling code."
 msgstr "Autoriser le code de profilage de base du programme."
 
-#: common.opt:2030
+#: common.opt:2034
 msgid "Generate absolute source path names for gcov."
 msgstr "Générer des noms de chemins absolus vers le code source pour gcov."
 
-#: common.opt:2034
+#: common.opt:2038
 msgid "Insert arc-based program profiling code."
 msgstr "Insérer le code de profilage basé sur arc du programme."
 
-#: common.opt:2038
+#: common.opt:2042
 msgid "Set the top-level directory for storing the profile data. The default is 'pwd'."
 msgstr "Définir le répertoire racine pour stocker les données de profilage. Le répertoire retourné par « pwd » est utilisé par défaut."
 
-#: common.opt:2043
+#: common.opt:2047
 msgid "Enable correction of flow inconsistent profile data input."
 msgstr "Autoriser la correction des inconsistances dans le flux d'entrée du profil."
 
-#: common.opt:2047
+#: common.opt:2051
 msgid "-fprofile-update=[single|atomic|prefer-atomic]\tSet the profile update method."
 msgstr "-fprofile-update=[single|atomic|prefer-atomic]\tDéfinir la méthode de mise à jour du profil."
 
-#: common.opt:2050
+#: common.opt:2054
 #, c-format
 msgid "unknown profile update method %qs"
 msgstr "méthode de mise à jour du profil %qs inconnue"
 
-#: common.opt:2063
+#: common.opt:2067
 msgid "Enable common options for generating profile info for profile feedback directed optimizations."
 msgstr "Activer les options communes pour la génération d'informations de profilage pour l'optimisation directe à partir des données collectées par le profilage."
 
-#: common.opt:2067
+#: common.opt:2071
 msgid "Enable common options for generating profile info for profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr "Activer les options communes pour la génération d'informations de profilage pour l'optimisation directe à partir des données collectées par le profilage et définir -fprofile-dir=."
 
-#: common.opt:2071
+#: common.opt:2075
 msgid "Enable common options for performing profile feedback directed optimizations."
 msgstr "Activer les options communes pour réaliser une optimisation directe à partir des informations recueillies par le profilage."
 
-#: common.opt:2075
+#: common.opt:2079
 msgid "Enable common options for performing profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr "Activer les options communes pour réaliser une optimisation directe à partir des informations recueillies par le profilage et définir -fprofile-dir=."
 
-#: common.opt:2079
+#: common.opt:2083
 msgid "Insert code to profile values of expressions."
 msgstr "Insérer du code pour profiler les valeurs des expressions."
 
-#: common.opt:2083
+#: common.opt:2087
 msgid "Report on consistency of profile."
 msgstr "Rapport sur la cohérence du profilage."
 
-#: common.opt:2087
+#: common.opt:2091
 msgid "Enable function reordering that improves code placement."
 msgstr "Activer la réorganisation des fonctions qui améliore le placement du code."
 
-#: common.opt:2091
+#: common.opt:2095
 msgid "Insert NOP instructions at each function entry."
 msgstr "Insérer des instructions NOP à chaque entrée de fonction."
 
-#: common.opt:2098
+#: common.opt:2102
 msgid "-frandom-seed=<string>\tMake compile reproducible using <string>."
 msgstr "-frandom-seed=<chaîne>\tRendre la compilation reproductible en utilisant <chaîne>."
 
-#: common.opt:2108
+#: common.opt:2112
 msgid "Record gcc command line switches in the object file."
 msgstr "Enregistrer, dans le fichier objet, les options en ligne de commande passées à gcc."
 
-#: common.opt:2112
+#: common.opt:2116
 msgid "Return small aggregates in registers."
 msgstr "Retourner les petits agrégats dans les registres."
 
-#: common.opt:2120
+#: common.opt:2124
 msgid "Tell DSE that the storage for a C++ object is dead when the constructor starts and when the destructor finishes."
 msgstr "Informer DSE que la zone de stockage d'un objet C++ est morte quand le constructeur démarre et quand le destructeur se termine."
 
-#: common.opt:2128
+#: common.opt:2132
 msgid "Relief of register pressure through live range shrinkage."
 msgstr "Soulager la pression sur les registres en réduisant la portée pendant laquelle une valeur peut rester dans un registre."
 
-#: common.opt:2132
+#: common.opt:2136
 msgid "Perform a register renaming optimization pass."
 msgstr "Effectuer une étape d'optimisation pour renommer les registres."
 
-#: common.opt:2136
+#: common.opt:2140
 msgid "Perform a target dependent instruction fusion optimization pass."
 msgstr "Effectuer une étape d'optimisation de fusion des instructions selon la cible."
 
-#: common.opt:2140
+#: common.opt:2144
 msgid "Reorder basic blocks to improve code placement."
 msgstr "Réorganiser les blocs de base pour améliorer le placement du code."
 
-#: common.opt:2144
+#: common.opt:2148
 msgid "-freorder-blocks-algorithm=[simple|stc]\tSet the used basic block reordering algorithm."
 msgstr "-freorder-blocks-algorithm=[simple|stc]\tDéfinir l'algorithme de réorganisation des blocs de base."
 
-#: common.opt:2147
+#: common.opt:2151
 #, c-format
 msgid "unknown basic block reordering algorithm %qs"
 msgstr "algorithme de réorganisation des blocs de base %qs inconnu"
 
-#: common.opt:2157
+#: common.opt:2161
 msgid "Reorder basic blocks and partition into hot and cold sections."
 msgstr "Réorganiser les blocs de base et les partitions dans des sections chaude et froide."
 
-#: common.opt:2161
+#: common.opt:2165
 msgid "Reorder functions to improve code placement."
 msgstr "Réorganiser les fonctions pour améliorer le placement du code."
 
-#: common.opt:2165
+#: common.opt:2169
 msgid "Add a common subexpression elimination pass after loop optimizations."
 msgstr "Ajouter une étape d'élimination des sous-expressions communes après l'optimisation des boucles."
 
-#: common.opt:2173
+#: common.opt:2177
 msgid "Disable optimizations that assume default FP rounding behavior."
 msgstr "Interdire les optimisations qui supposent un comportement par défaut pour l'arrondis des virgules flottantes."
 
-#: common.opt:2177
+#: common.opt:2181
 msgid "Enable scheduling across basic blocks."
 msgstr "Activer l'ordonnancement à travers les blocs de base."
 
-#: common.opt:2181
+#: common.opt:2185
 msgid "Enable register pressure sensitive insn scheduling."
 msgstr "Activer l'ordonnancement des insns sensible à la pression sur les registres."
 
-#: common.opt:2185
+#: common.opt:2189
 msgid "Allow speculative motion of non-loads."
 msgstr "Autoriser le mouvement spéculatif des non chargements."
 
-#: common.opt:2189
+#: common.opt:2193
 msgid "Allow speculative motion of some loads."
 msgstr "Autoriser le mouvement spéculatif de certains chargements."
 
-#: common.opt:2193
+#: common.opt:2197
 msgid "Allow speculative motion of more loads."
 msgstr "Autoriser le mouvement spéculatif de plus de chargements."
 
-#: common.opt:2197
+#: common.opt:2201
 msgid "-fsched-verbose=<number>\tSet the verbosity level of the scheduler."
 msgstr "-fsched-verbose=<numéro>\tDéfinir le niveau de verbosité de l'ordonnanceur."
 
-#: common.opt:2201
+#: common.opt:2205
 msgid "If scheduling post reload, do superblock scheduling."
 msgstr "Si l'ordonnancement est fait après le rechargement, faire un ordonnancement des super blocs."
 
-#: common.opt:2209
+#: common.opt:2213
 msgid "Reschedule instructions before register allocation."
 msgstr "Réordonnancer les instructions avant l'allocation de registres."
 
-#: common.opt:2213
+#: common.opt:2217
 msgid "Reschedule instructions after register allocation."
 msgstr "Réordonnancer les instructions après l'allocation de registres."
 
-#: common.opt:2220
+#: common.opt:2224
 msgid "Schedule instructions using selective scheduling algorithm."
 msgstr "Ordonnancer les instructions en utilisant l'algorithme d'ordonnancement sélectif."
 
-#: common.opt:2224
+#: common.opt:2228
 msgid "Run selective scheduling after reload."
 msgstr "Exécuter l'ordonnancement sélectif après le rechargement."
 
-#: common.opt:2228
+#: common.opt:2232
 msgid "Run self-tests, using the given path to locate test files."
 msgstr "Exécuter les autodiagnostics en utilisant le chemin donné pour trouver les fichiers de tests."
 
-#: common.opt:2232
+#: common.opt:2236
 msgid "Perform software pipelining of inner loops during selective scheduling."
 msgstr "Réaliser la mise en pipeline logicielle des boucles internes durant l'ordonnancement sélectif."
 
-#: common.opt:2236
+#: common.opt:2240
 msgid "Perform software pipelining of outer loops during selective scheduling."
 msgstr "Réaliser la mise en pipeline logicielle des boucles externes durant l'ordonnancement sélectif."
 
-#: common.opt:2240
+#: common.opt:2244
 msgid "Reschedule pipelined regions without pipelining."
 msgstr "Réordonnancer les régions mises en pipeline sans la mise en pipeline."
 
-#: common.opt:2244
+#: common.opt:2248
 msgid "Allow interposing function (or variables) by ones with different semantics (or initializer) respectively by dynamic linker."
 msgstr "Permettre l'interposition des fonctions (ou des variables) par d'autres avec une sémantique différente (ou initialiseur) par l'éditeur de lien dynamique."
 
-#: common.opt:2250
+#: common.opt:2254
 msgid "Allow premature scheduling of queued insns."
 msgstr "Autoriser l'ordonnancement prématuré de insns dans la queue."
 
-#: common.opt:2254
+#: common.opt:2258
 msgid "-fsched-stalled-insns=<number>\tSet number of queued insns that can be prematurely scheduled."
 msgstr "-fsched-stalled-insns=<nombre>\tFixer le nombre d'insns dans la queue qui peuvent être prématurément ordonnancées."
 
-#: common.opt:2262
+#: common.opt:2266
 msgid "Set dependence distance checking in premature scheduling of queued insns."
 msgstr "Définir la distance de vérification de la dépendance dans l'ordonnancement prématuré des insns dans la queue."
 
-#: common.opt:2266
+#: common.opt:2270
 msgid "-fsched-stalled-insns-dep=<number>\tSet dependence distance checking in premature scheduling of queued insns."
 msgstr "-fsched-stalled-insns-dep=<nombre>\tDéfinir la distance de vérification de la dépendance dans l'ordonnancement prématuré des insns dans la queue."
 
-#: common.opt:2270
+#: common.opt:2274
 msgid "Enable the group heuristic in the scheduler."
 msgstr "Activer l'heuristique de groupe dans l'ordonnanceur."
 
-#: common.opt:2274
+#: common.opt:2278
 msgid "Enable the critical path heuristic in the scheduler."
 msgstr "Activer l'heuristique du chemin critique dans l'ordonnanceur."
 
-#: common.opt:2278
+#: common.opt:2282
 msgid "Enable the speculative instruction heuristic in the scheduler."
 msgstr "Activer l'heuristique des instructions spéculatives dans l'ordonnanceur."
 
-#: common.opt:2282
+#: common.opt:2286
 msgid "Enable the rank heuristic in the scheduler."
 msgstr "Activer l'heuristique de rang dans l'ordonnanceur."
 
-#: common.opt:2286
+#: common.opt:2290
 msgid "Enable the last instruction heuristic in the scheduler."
 msgstr "Activer l'heuristique de la dernière instruction dans l'ordonnancement."
 
-#: common.opt:2290
+#: common.opt:2294
 msgid "Enable the dependent count heuristic in the scheduler."
 msgstr "Activer l'heuristique du décompte des dépendances dans l'ordonnanceur."
 
-#: common.opt:2294
+#: common.opt:2298
 msgid "Access data in the same section from shared anchor points."
 msgstr "Accéder au données dans la même section à partir du point d'ancrage partagé."
 
-#: common.opt:2306
+#: common.opt:2310
 msgid "Turn on Redundant Extensions Elimination pass."
 msgstr "Activer l'étape d'élimination des extensions redondantes."
 
-#: common.opt:2310
+#: common.opt:2314
 msgid "Show column numbers in diagnostics, when available.  Default on."
 msgstr "Afficher les numéros des colonnes dans les diagnostiques quand ils sont disponibles. Activé par défaut."
 
-#: common.opt:2314
+#: common.opt:2318
 msgid "Emit function prologues only before parts of the function that need it, rather than at the top of the function."
 msgstr "Produire les prologues des fonctions uniquement devant les parties qui en ont besoin au lieu de les produire au début des fonctions."
 
-#: common.opt:2319
+#: common.opt:2323
 msgid "Shrink-wrap parts of the prologue and epilogue separately."
 msgstr "Emballer séparément les parties du prologue et de l'épilogue."
 
-#: common.opt:2323
+#: common.opt:2327
 msgid "Disable optimizations observable by IEEE signaling NaNs."
 msgstr "Désactiver les optimisations observables par les NaN (Not a Number: pas un nombre) IEEE si ces NaN produisent un effet visible."
 
-#: common.opt:2327
+#: common.opt:2331
 msgid "Disable floating point optimizations that ignore the IEEE signedness of zero."
 msgstr "Désactiver les optimisations des virgules flottantes qui ignorent le signe du zéro défini par IEEE."
 
-#: common.opt:2331
+#: common.opt:2335
 msgid "Convert floating point constants to single precision constants."
 msgstr "Convertir les constantes en virgule flottante en constantes en simple précision."
 
-#: common.opt:2335
+#: common.opt:2339
 msgid "Split lifetimes of induction variables when loops are unrolled."
 msgstr "Scinder le temps de vie des variables d'induction quand des boucles sont dépliées."
 
-#: common.opt:2339
+#: common.opt:2343
 msgid "Generate discontiguous stack frames."
 msgstr "Générer des trames de pile discontinues."
 
-#: common.opt:2343
+#: common.opt:2347
 msgid "Split wide types into independent registers."
 msgstr "Scinder les types larges dans des registres indépendants."
 
-#: common.opt:2347
+#: common.opt:2351
 msgid "Enable backward propagation of use properties at the SSA level."
 msgstr "Activer la propagation vers le haut des propriétés d'utilisation au niveau SSA."
 
-#: common.opt:2351
+#: common.opt:2355
 msgid "Optimize conditional patterns using SSA PHI nodes."
 msgstr "Optimiser les motifs conditionnels utilisant les nœuds PHI SSA."
 
-#: common.opt:2355
+#: common.opt:2359
 msgid "Optimize amount of stdarg registers saved to stack at start of function."
 msgstr "Optimiser le nombre de registres stdarg sauvegardés sur la pile au début d'une fonction."
 
-#: common.opt:2359
+#: common.opt:2363
 msgid "Apply variable expansion when loops are unrolled."
 msgstr "Appliquer l'expansion des variables quand les boucles dont dépliées."
 
-#: common.opt:2363
+#: common.opt:2367
 msgid "-fstack-check=[no|generic|specific]\tInsert stack checking code into the program."
 msgstr "-fstack-check=[no|generic|specific]\tInsérer du code de vérification de la pile dans le programme."
 
-#: common.opt:2367
+#: common.opt:2371
 msgid "Insert stack checking code into the program.  Same as -fstack-check=specific."
 msgstr "Insérer du code de vérification de la pile dans le programme. Identique à -fstack-check=specific."
 
-#: common.opt:2371
+#: common.opt:2375
 msgid "Insert code to probe each page of stack space as it is allocated to protect from stack-clash style attacks."
 msgstr "Insérer du code pour sonder chaque page de l'espace de la pile quand il est alloué pour protéger contre des attaques visant une collision de pile (stack-clash)."
 
-#: common.opt:2379
+#: common.opt:2383
 msgid "-fstack-limit-register=<register>\tTrap if the stack goes past <register>."
 msgstr "-fstack-limit-register=<registre>\tFaire un déroutement si la pile va au delà du <registre>."
 
-#: common.opt:2383
+#: common.opt:2387
 msgid "-fstack-limit-symbol=<name>\tTrap if the stack goes past symbol <name>."
 msgstr "-fstack-limit-symbol=<nom>\tFaire un déroutement si la pile va au delà du symbole <nom>."
 
-#: common.opt:2387
+#: common.opt:2391
 msgid "Use propolice as a stack protection method."
 msgstr "Utiliser ProPolice comme méthode de protection de la pile."
 
-#: common.opt:2391
+#: common.opt:2395
 msgid "Use a stack protection method for every function."
 msgstr "Utiliser une méthode de protection de la pile pour chaque fonction."
 
-#: common.opt:2395
+#: common.opt:2399
 msgid "Use a smart stack protection method for certain functions."
 msgstr "Utiliser une méthode intelligente de protection de la pile pour certaines fonctions."
 
-#: common.opt:2399
+#: common.opt:2403
 msgid "Use stack protection method only for functions with the stack_protect attribute."
 msgstr "N'utiliser une méthode de protection de la pile que sur les fonctions qui ont l'attribut stack_protection."
 
-#: common.opt:2403
+#: common.opt:2407
 msgid "Output stack usage information on a per-function basis."
 msgstr "Fournir les informations d'utilisation de la pile pour chaque fonction."
 
-#: common.opt:2415
+#: common.opt:2419
 msgid "Assume strict aliasing rules apply."
 msgstr "Supposer que la règle selon laquelle une zone mémoire ne peut être accessible que par un seul pointeur (strict aliasing) s'applique."
 
-#: common.opt:2419
+#: common.opt:2423
 msgid "Treat signed overflow as undefined.  Negated as -fwrapv -fwrapv-pointer."
 msgstr "Traiter les débordements signés comme étant indéfinis. Inversé par -fwrapv -fwrapv-pointer."
 
-#: common.opt:2423
+#: common.opt:2427
 msgid "Implement __atomic operations via libcalls to legacy __sync functions."
 msgstr "Implémenter les opérations __atomic via des appels de bibliothèque aux fonctions historiques __sync."
 
-#: common.opt:2427
+#: common.opt:2431
 msgid "Check for syntax errors, then stop."
 msgstr "Vérifier les erreurs de syntaxes et puis stopper."
 
-#: common.opt:2431
+#: common.opt:2435
 msgid "Create data files needed by \"gcov\"."
 msgstr "Créer les fichiers de données nécessaires à « gcov »."
 
 # Jump threading= des sauts consécutifs sont remplacés par un saut vers la cible finale
-#: common.opt:2435
+#: common.opt:2439
 msgid "Perform jump threading optimizations."
 msgstr "Réaliser les optimisations d'enfilage des sauts."
 
-#: common.opt:2439
+#: common.opt:2443
 msgid "Report the time taken by each compiler pass."
 msgstr "Rapporter le temps pris par chaque étape de la compilation."
 
-#: common.opt:2443
+#: common.opt:2447
 msgid "Record times taken by sub-phases separately."
 msgstr "Enregistrer le temps pris par chaque sous-étape séparément."
 
-#: common.opt:2447
+#: common.opt:2451
 msgid "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tSet the default thread-local storage code generation model."
 msgstr "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tDéfinir le modèle de génération de code par défaut pour le stockage local au thread."
 
-#: common.opt:2450
+#: common.opt:2454
 #, c-format
 msgid "unknown TLS model %qs"
 msgstr "modèle TLS %qs inconnu"
 
-#: common.opt:2466
+#: common.opt:2470
 msgid "Reorder top level functions, variables, and asms."
 msgstr "Réorganiser les fonctions, les variables et l'assembleur au plus haut niveau."
 
-#: common.opt:2470
+#: common.opt:2474
 msgid "Perform superblock formation via tail duplication."
 msgstr "Exécuter la formation du super bloc via la duplication de la queue."
 
-#: common.opt:2474
+#: common.opt:2478
 msgid "For targets that normally need trampolines for nested functions, always generate them instead of using descriptors."
 msgstr "Pour les cibles qui requièrent normalement des trampolines pour les fonctions imbriquées, toujours les générer au lieu d'utiliser des descripteurs."
 
-#: common.opt:2482
+#: common.opt:2486
 msgid "Assume floating-point operations can trap."
 msgstr "Supposer que les opérations en virgule flottante peuvent générer des déroutements."
 
-#: common.opt:2486
+#: common.opt:2490
 msgid "Trap for signed overflow in addition, subtraction and multiplication."
 msgstr "Générer des déroutements pour les débordements signés dans les additions, soustractions et multiplications."
 
-#: common.opt:2490
+#: common.opt:2494
 msgid "Enable SSA-CCP optimization on trees."
 msgstr "Activer les optimisations SSA-CCP sur les arbres."
 
-#: common.opt:2494
+#: common.opt:2498
 msgid "Enable SSA-BIT-CCP optimization on trees."
 msgstr "Activer les optimisations SSA-BIT-CCP sur les arbres."
 
-#: common.opt:2502
+#: common.opt:2506
 msgid "Enable loop header copying on trees."
 msgstr "Activer la copie des en-têtes de boucles sur les arbres."
 
-#: common.opt:2510
+#: common.opt:2514
 msgid "Enable SSA coalescing of user variables."
 msgstr "Activer la coalescence SSA sur les variables utilisateur."
 
-#: common.opt:2518
+#: common.opt:2522
 msgid "Enable copy propagation on trees."
 msgstr "Activer la propagation de copie sur les arbres."
 
-#: common.opt:2526
+#: common.opt:2530
 msgid "Transform condition stores into unconditional ones."
 msgstr "Transformer les stockages conditionnels en stockages inconditionnels."
 
-#: common.opt:2530
+#: common.opt:2534
 msgid "Perform conversions of switch initializations."
 msgstr "Réaliser la conversion des initialisations de « switch »."
 
-#: common.opt:2534
+#: common.opt:2538
 msgid "Enable SSA dead code elimination optimization on trees."
 msgstr "Activer l'optimisation de l'élimination du code mort SSA sur les arbres."
 
-#: common.opt:2538
+#: common.opt:2542
 msgid "Enable dominator optimizations."
 msgstr "Activer l'optimisation des dominateurs."
 
-#: common.opt:2542
+#: common.opt:2546
 msgid "Enable tail merging on trees."
 msgstr "Activer la fusion des appels en fin de fonction (tail call) sur les arbres."
 
-#: common.opt:2546
+#: common.opt:2550
 msgid "Enable dead store elimination."
 msgstr "Activer l'élimination des stockages morts."
 
-#: common.opt:2550
+#: common.opt:2554
 msgid "Enable forward propagation on trees."
 msgstr "Activer la propagation vers l'avant sur les arbres."
 
-#: common.opt:2554
+#: common.opt:2558
 msgid "Enable Full Redundancy Elimination (FRE) on trees."
 msgstr "Activer l'élimination redondante totale (Full Redundancy Elimination) sur les arbres."
 
-#: common.opt:2558
+#: common.opt:2562
 msgid "Enable string length optimizations on trees."
 msgstr "Activer l'optimisation des longueurs de chaînes sur les arbres."
 
-#: common.opt:2562
+#: common.opt:2566
 msgid "Detect paths that trigger erroneous or undefined behavior due to dereferencing a null pointer.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr "Détecter les chemins qui déclenchent un comportement erroné ou indéfini dû au déréférencement d'un pointeur nul. Isoler ces chemins du flux de contrôle principal et transformer les instructions avec un comportement erroné ou indéfini en instructions de déroutement."
 
-#: common.opt:2568
+#: common.opt:2572
 msgid "Detect paths that trigger erroneous or undefined behavior due to a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr "Détecter les chemins qui déclenchent un comportement erroné ou indéfini dû à une valeur nulle utilisée d'une manière interdite par l'attribut returns_nonnull ou nonnull. Isoler ces chemins du flux de contrôle principal et transformer l'instruction avec un comportement erroné ou indéfini en une instruction de déroutement."
 
-#: common.opt:2575
+#: common.opt:2579
 msgid "Enable loop distribution on trees."
 msgstr "Activer la distribution des boucles sur les arbres."
 
-#: common.opt:2579
+#: common.opt:2583
 msgid "Enable loop distribution for patterns transformed into a library call."
 msgstr "Activer la distribution des boucles pour les motifs transformés en appels de bibliothèque."
 
-#: common.opt:2583
+#: common.opt:2587
 msgid "Enable loop invariant motion on trees."
 msgstr "Activer les mouvements invariants de boucles sur les arbres."
 
-#: common.opt:2591
+#: common.opt:2595
 msgid "Create canonical induction variables in loops."
 msgstr "Créer des variables d'induction canoniques dans les boucles."
 
-#: common.opt:2595
+#: common.opt:2599
 msgid "Enable loop optimizations on tree level."
 msgstr "Activer les optimisations de boucles au niveau de l'arbre."
 
-#: common.opt:2599
+#: common.opt:2603
 msgid "-ftree-parallelize-loops=<number>\tEnable automatic parallelization of loops."
 msgstr "-ftree-parallelize-loops=<number>\tActiver la parallélisation automatique des boucles."
 
-#: common.opt:2603
+#: common.opt:2607
 msgid "Enable hoisting loads from conditional pointers."
 msgstr "Activer la sortie hors des boucles des chargements par des pointeurs conditionnels."
 
-#: common.opt:2607
+#: common.opt:2611
 msgid "Enable SSA-PRE optimization on trees."
 msgstr "Activer l'optimisation SSA-PRE sur les arbres."
 
-#: common.opt:2611
+#: common.opt:2615
 msgid "In SSA-PRE optimization on trees, enable partial-partial redundancy elimination."
 msgstr "Dans l'optimisation SSA-PRE sur les arbres, activer l'élimination de la redondance partielle-partielle."
 
-#: common.opt:2615
+#: common.opt:2619
 msgid "Perform function-local points-to analysis on trees."
 msgstr "Réaliser une analyse de ce qui est pointé, locale à la fonction, sur les arbres."
 
-#: common.opt:2619
+#: common.opt:2623
 msgid "Enable reassociation on tree level."
 msgstr "Activer la réassociation au niveau de l'arbre."
 
-#: common.opt:2627
+#: common.opt:2631
 msgid "Enable SSA code sinking on trees."
 msgstr "Activer la descente du code SSA sur les arbres."
 
-#: common.opt:2631
+#: common.opt:2635
 msgid "Perform straight-line strength reduction."
 msgstr "Exécuter la simplification des instructions dupliquées lors de l'aplatissage d'une boucle (Straight-Line Strength Reduction)."
 
-#: common.opt:2635
+#: common.opt:2639
 msgid "Perform scalar replacement of aggregates."
 msgstr "Exécuter le remplacement des scalaires des agrégats."
 
-#: common.opt:2639
+#: common.opt:2643
 msgid "Replace temporary expressions in the SSA->normal pass."
 msgstr "Remplacer les expressions temporaires durant l'étape SSA->normale."
 
-#: common.opt:2643
+#: common.opt:2647
 msgid "Perform live range splitting during the SSA->normal pass."
 msgstr "Réaliser une scission de la portée active durant l'étape SSA->normale."
 
-#: common.opt:2647
+#: common.opt:2651
 msgid "Perform Value Range Propagation on trees."
 msgstr "Réaliser une propagation de la plage de valeurs sur les arbres."
 
-#: common.opt:2651
+#: common.opt:2655
 msgid "Split paths leading to loop backedges."
 msgstr "Scinder les chemins conduisant à des arêtes de retour d'une boucle."
 
-#: common.opt:2655
+#: common.opt:2659
 msgid "Assume common declarations may be overridden with ones with a larger trailing array."
 msgstr "Supposer que les déclarations communes peuvent être remplacées par d'autres se terminant par un tableau plus grand."
 
-#: common.opt:2660
+#: common.opt:2664
 msgid "Compile whole compilation unit at a time."
 msgstr "Compiler une unité de compilation entière à la fois."
 
-#: common.opt:2664
+#: common.opt:2668
 msgid "Perform loop unrolling when iteration count is known."
 msgstr "Dérouler les boucles quand le nombre d'itérations est connu."
 
-#: common.opt:2668
+#: common.opt:2672
 msgid "Perform loop unrolling for all loops."
 msgstr "Dérouler toutes les boucles."
 
-#: common.opt:2679
+#: common.opt:2683
 msgid "Allow optimization for floating-point arithmetic which may change the result of the operation due to rounding."
 msgstr "Autoriser l'optimisation de l'arithmétique en virgule flottante qui peut changer le résultat de l'opération à cause de l'arrondi."
 
-#: common.opt:2684
+#: common.opt:2688
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr "Identique à -fassociative-math pour les expressions contenant des divisions."
 
-#: common.opt:2692
+#: common.opt:2696
 msgid "Allow math optimizations that may violate IEEE or ISO standards."
 msgstr "Permettre les optimisations mathématiques qui peuvent violer les standards IEEE ou ISO."
 
-#: common.opt:2696
+#: common.opt:2700
 msgid "Perform loop unswitching."
 msgstr "Déplacer les boucles à l'intérieur des branchements quand c'est possible."
 
-#: common.opt:2700
+#: common.opt:2704
 msgid "Perform loop splitting."
 msgstr "Scinder les boucles pour éliminer des conditions qui sont constantes sur une plage de la boucle (Loop Splitting)."
 
-#: common.opt:2704
+#: common.opt:2708
 msgid "Just generate unwind tables for exception handling."
 msgstr "Générer uniquement les tables de retour en arrière pour la gestion des exceptions."
 
-#: common.opt:2708
+#: common.opt:2712
 msgid "Use the bfd linker instead of the default linker."
 msgstr "Utiliser l'éditeur de liens bfd au lieu de l'éditeur par défaut."
 
-#: common.opt:2712
+#: common.opt:2716
 msgid "Use the gold linker instead of the default linker."
 msgstr "Utiliser l'éditeur de liens gold au lieu de l'éditeur par défaut."
 
-#: common.opt:2724
+#: common.opt:2728
 msgid "Perform variable tracking."
 msgstr "Réaliser le pistage des variables."
 
-#: common.opt:2732
+#: common.opt:2736
 msgid "Perform variable tracking by annotating assignments."
 msgstr "Réaliser le pistage des variables en annotant les affectations."
 
-#: common.opt:2738
+#: common.opt:2742
 msgid "Toggle -fvar-tracking-assignments."
 msgstr "Basculer -fvar-tracking-assignments."
 
-#: common.opt:2746
+#: common.opt:2750
 msgid "Perform variable tracking and also tag variables that are uninitialized."
 msgstr "Réaliser le pistage des variables et aussi étiqueter les variables qui ne sont pas initialisées."
 
-#: common.opt:2751
+#: common.opt:2755
 msgid "Enable vectorization on trees."
 msgstr "Activer la vectorisation sur les arbres."
 
-#: common.opt:2759
+#: common.opt:2763
 msgid "Enable loop vectorization on trees."
 msgstr "Activer la vectorisation des boucles sur les arbres."
 
-#: common.opt:2763
+#: common.opt:2767
 msgid "Enable basic block vectorization (SLP) on trees."
 msgstr "Activer la vectorisation des blocs de base (SLP) sur les arbres."
 
-#: common.opt:2767
+#: common.opt:2771
 msgid "Specifies the cost model for vectorization. -fvect-cost-model=[unlimited|dynamic|cheap]\tSpecifies the cost model for vectorization."
 msgstr "Spécifie le modèle de coût pour la vectorisation. -fvect-cost-model=[unlimited|dynamic|cheap]\tSpécifie le modèle de coût pour la vectorisation."
 
-#: common.opt:2772
+#: common.opt:2776
 msgid "-fsimd-cost-model=[unlimited|dynamic|cheap]\tSpecifies the vectorization cost model for code marked with a simd directive."
 msgstr "-fsimd-cost-model=[unlimited|dynamic|cheap]\tSpécifier le modèle de coût de la vectorisation pour du code marqué par la directive simd."
 
-#: common.opt:2775
+#: common.opt:2779
 #, c-format
 msgid "unknown vectorizer cost model %qs"
 msgstr "modèle de coût de la vectorisation %qs inconnu"
 
-#: common.opt:2788
+#: common.opt:2792
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr "Activer le modèle de coût du vectoriseur dynamique. Préservé pour rétro-compatibilité."
 
-#: common.opt:2796
+#: common.opt:2800
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr "Activer la propagation par copie des informations sur l'évolution scalaire."
 
-#: common.opt:2806
+#: common.opt:2810
 msgid "Add extra commentary to assembler output."
 msgstr "Ajouter des commentaires additionnels à la sortie de l'assembleur."
 
-#: common.opt:2810
+#: common.opt:2814
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility."
 msgstr "-fvisibility=[default|internal|hidden|protected]\tDéfinir la visibilité par défaut des symboles."
 
-#: common.opt:2813
+#: common.opt:2817
 #, c-format
 msgid "unrecognized visibility value %qs"
 msgstr "valeur de visibilité %qs non reconnue"
 
-#: common.opt:2829
+#: common.opt:2833
 msgid "Validate vtable pointers before using them."
 msgstr "Valider les pointeurs dans la vtable avant de les utiliser."
 
-#: common.opt:2832
+#: common.opt:2836
 #, c-format
 msgid "unknown vtable verify initialization priority %qs"
 msgstr "priorité d'initialisation de la vérification de la vtable %qs inconnue"
 
-#: common.opt:2845
+#: common.opt:2849
 msgid "Output vtable verification counters."
 msgstr "Sortir les compteurs de vérifications des vtables."
 
-#: common.opt:2849
+#: common.opt:2853
 msgid "Output vtable verification pointer sets information."
 msgstr "Sortir les informations sur les ensembles de pointeurs pour la vérification des vtables."
 
-#: common.opt:2853
+#: common.opt:2857
 msgid "Use expression value profiles in optimizations."
 msgstr "Utiliser les profils des valeurs des expressions dans les optimisations."
 
-#: common.opt:2857
+#: common.opt:2861
 msgid "Construct webs and split unrelated uses of single variable."
 msgstr "Construire une toile et séparer les utilisations sans relations d'une variable seule."
 
-#: common.opt:2861
+#: common.opt:2865
 msgid "Enable conditional dead code elimination for builtin calls."
 msgstr "Activer l'élimination conditionnelle du code mort pour les appels internes."
 
-#: common.opt:2865
+#: common.opt:2869
 msgid "Perform whole program optimizations."
 msgstr "Réaliser les optimisations sur tout le programme."
 
-#: common.opt:2869
+#: common.opt:2873
 msgid "Assume pointer overflow wraps around."
 msgstr "Supposer que le débordement de pointeur revient au départ."
 
-#: common.opt:2873
+#: common.opt:2877
 msgid "Assume signed arithmetic overflow wraps around."
 msgstr "Supposer que le débordement de l'arithmétique signée boucle sur la plage accessible."
 
-#: common.opt:2877
+#: common.opt:2881
 msgid "Put zero initialized data in the bss section."
 msgstr "Placer des données initialisées à zéros dans la section bss."
 
-#: common.opt:2881
+#: common.opt:2885
 msgid "Generate debug information in default format."
 msgstr "Générer les informations de débogage dans le format par défaut."
 
-#: common.opt:2885
+#: common.opt:2889
 msgid "Assume assembler support for (DWARF2+) .loc directives"
 msgstr "Supposer que l'assembleur supporte les directives .loc (DWARF2+)"
 
-#: common.opt:2889
+#: common.opt:2893
 msgid "Assume assembler support for view in (DWARF2+) .loc directives"
 msgstr "Supposer que l'assembleur supporte les vues dans les directives .loc (DWARF2+)"
 
-#: common.opt:2892 common.opt:2896 common.opt:2900 common.opt:2904
+#: common.opt:2896 common.opt:2900 common.opt:2904 common.opt:2908
 #, c-format
 msgid "switch %qs no longer supported"
 msgstr "l'option %qs n'est plus supportée"
 
-#: common.opt:2909
+#: common.opt:2913
 msgid "Record DW_AT_decl_column and DW_AT_call_column in DWARF."
 msgstr "Enregistrer DW_AT_decl_column et DW_AT_call_column dans DWARF."
 
-#: common.opt:2913
+#: common.opt:2917
 msgid "Generate debug information in default version of DWARF format."
 msgstr "Générer les informations de débogage dans la version par défaut du format DWARF."
 
-#: common.opt:2917
+#: common.opt:2921
 msgid "Generate debug information in DWARF v2 (or later) format."
 msgstr "Générer les informations de débogage dans le format DWARF v2 (ou ultérieur)."
 
-#: common.opt:2921
+#: common.opt:2925
 msgid "Generate debug information in default extended format."
 msgstr "Générer les informations de débogage dans le format étendu par défaut."
 
-#: common.opt:2925
+#: common.opt:2929
 msgid "Generate extended entry point information for inlined functions"
 msgstr "Générer des information étendues pour les points d'entrées des fonctions en ligne"
 
-#: common.opt:2929
+#: common.opt:2933
 msgid "Compute locview reset points based on insn length estimates"
 msgstr "Calculer les points de réinitialisation locview sur base des estimations des longueurs des insns"
 
-#: common.opt:2937
+#: common.opt:2941
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr "Ne pas générer les sections DWARF pubnames et pubtypes."
 
-#: common.opt:2941
+#: common.opt:2945
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr "Générer les sections DWARF pubnames et pubtypes."
 
-#: common.opt:2945
+#: common.opt:2949
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr "Générer les sections DWARF pubnames et pubtypes avec les extensions GNU."
 
-#: common.opt:2949
+#: common.opt:2953
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr "Enregistrer les options de la ligne de commande de gcc dans DW_AT_producer de DWARF."
 
-#: common.opt:2953
+#: common.opt:2957
 msgid "Generate debug information in separate .dwo files."
 msgstr "Générer les informations de débogage dans des fichiers .dwo séparés."
 
-#: common.opt:2957
+#: common.opt:2961
 msgid "Generate debug information in STABS format."
 msgstr "Générer les informations de débogage dans le format STABS."
 
-#: common.opt:2961
+#: common.opt:2965
 msgid "Generate debug information in extended STABS format."
 msgstr "Générer les informations de débogage dans le format STABS étendu."
 
-#: common.opt:2965
+#: common.opt:2969
 msgid "Emit progressive recommended breakpoint locations."
 msgstr "Émettre des emplacements de points d'arrêt progressifs recommandés"
 
-#: common.opt:2969
+#: common.opt:2973
 msgid "Don't emit DWARF additions beyond selected version."
 msgstr "Ne pas produire les suppléments DWARF au delà de la version sélectionnée."
 
-#: common.opt:2973
+#: common.opt:2977
 msgid "Toggle debug information generation."
 msgstr "Inverser l'option actuelle de génération des informations de débogage."
 
-#: common.opt:2977
+#: common.opt:2981
 msgid "Augment variable location lists with progressive views."
 msgstr "Augmenter les listes de positions de variables avec des vues progressives."
 
-#: common.opt:2984
+#: common.opt:2988
 msgid "Generate debug information in VMS format."
 msgstr "Générer les informations de débogage dans le format VMS."
 
-#: common.opt:2988
+#: common.opt:2992
 msgid "Generate debug information in XCOFF format."
 msgstr "Générer les informations de débogage dans le format XCOFF."
 
-#: common.opt:2992
+#: common.opt:2996
 msgid "Generate debug information in extended XCOFF format."
 msgstr "Générer les informations de débogage dans le format XCOFF étendu."
 
-#: common.opt:3010
+#: common.opt:3014
 msgid "Generate compressed debug sections."
 msgstr "Générer des sections de débogage compressées."
 
-#: common.opt:3014
+#: common.opt:3018
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>."
 msgstr "-gz=<format>\tGénérer les sections de débogage compressées dans le format <format>."
 
-#: common.opt:3021
+#: common.opt:3025
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory."
 msgstr "-iplugindir=<répertoire>\tDéfinir le <répertoire> comme étant le répertoire par défaut des modules externes."
 
-#: common.opt:3025
+#: common.opt:3029
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory."
 msgstr "-imultiarch <répertoire>\tDéfinir le <répertoire> comme étant le sous-répertoire d'inclusion multiarch."
 
-#: common.opt:3047
+#: common.opt:3051
 msgid "-o <file>\tPlace output into <file>."
 msgstr "-o <fichier>\tPlacer la sortie dans le <fichier>."
 
-#: common.opt:3051
+#: common.opt:3055
 msgid "Enable function profiling."
 msgstr "Autoriser le profilage des fonctions."
 
-#: common.opt:3061
+#: common.opt:3065
 msgid "Like -pedantic but issue them as errors."
 msgstr "Comme -pedantic mais les avertissements sont rapportés comme des erreurs."
 
-#: common.opt:3101
+#: common.opt:3105
 msgid "Do not display functions compiled or elapsed time."
 msgstr "Ne pas afficher les fonctions compilées ni le temps écoulé."
 
-#: common.opt:3133
+#: common.opt:3137
 msgid "Enable verbose output."
 msgstr "Activer la sortie en mode bavard."
 
-#: common.opt:3137
+#: common.opt:3141
 msgid "Display the compiler's version."
 msgstr "Afficher la version du compilateur."
 
-#: common.opt:3141
+#: common.opt:3145
 msgid "Suppress warnings."
 msgstr "Supprimer les avertissements."
 
-#: common.opt:3151
+#: common.opt:3155
 msgid "Create a shared library."
 msgstr "Créer une bibliothèque partagée."
 
-#: common.opt:3196
+#: common.opt:3200
 msgid "Don't create a dynamically linked position independent executable."
 msgstr "Ne pas créer un exécutable indépendant de la position dynamiquement lié."
 
-#: common.opt:3200
+#: common.opt:3204
 msgid "Create a dynamically linked position independent executable."
 msgstr "Créer un exécutable indépendant de la position dynamiquement lié."
 
-#: common.opt:3204
+#: common.opt:3208
 msgid "Create a static position independent executable."
 msgstr "Créer un exécutable statique indépendant de la position."
 
-#: common.opt:3211
+#: common.opt:3215
 msgid "Use caller save register across calls if possible."
 msgstr "Faire sauvegarder les registres par l'appelant au travers des appels si possible."
 
-#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:598 cp/cvt.c:1308
+#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:599 cp/cvt.c:1308
 #: cp/cvt.c:1561
 #, gcc-internal-format
 msgid "value computed is not used"
@@ -15811,7 +15813,7 @@
 msgstr "type booléen attendu"
 
 #: go/gofrontend/expressions.cc:4331 c/c-parser.c:13477 c/c-parser.c:13484
-#: cp/parser.c:33264 cp/parser.c:33271
+#: cp/parser.c:33261 cp/parser.c:33268
 #, gcc-internal-format
 msgid "expected integer"
 msgstr "entier attendu"
@@ -16227,14 +16229,14 @@
 msgid "ignoring attribute %qE because it conflicts with attribute %qs"
 msgstr "l'attribut %qE est ignoré car il est en conflit avec l'attribut %qs"
 
-#: attribs.c:449 c-family/c-attribs.c:1894 cp/decl.c:13690 cp/friend.c:302
-#: cp/tree.c:4559
+#: attribs.c:449 c-family/c-attribs.c:1905 cp/decl.c:13714 cp/friend.c:302
+#: cp/tree.c:4607
 #, gcc-internal-format
 msgid "previous declaration here"
 msgstr "déclaration précédente ici"
 
 #. Warn about and ignore all others for now, but store them.
-#: attribs.c:564 c-family/c-attribs.c:2717 objc/objc-act.c:4963
+#: attribs.c:564 c-family/c-attribs.c:2728 objc/objc-act.c:4963
 #: objc/objc-act.c:6932 objc/objc-act.c:8119 objc/objc-act.c:8170
 #, gcc-internal-format
 msgid "%qE attribute directive ignored"
@@ -16253,17 +16255,17 @@
 #. This is a c++11 attribute that appertains to a
 #. type-specifier, outside of the definition of, a class
 #. type.  Ignore it.
-#: attribs.c:590 cp/decl.c:10999
+#: attribs.c:590 cp/decl.c:11023
 #, gcc-internal-format
 msgid "attribute ignored"
 msgstr "attribut ignoré"
 
-#: attribs.c:592 cp/decl.c:11000
+#: attribs.c:592 cp/decl.c:11024
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr "un attribut qui appartient à un spécificateur de type est ignoré"
 
-#: attribs.c:610 c-family/c-attribs.c:3219
+#: attribs.c:610 c-family/c-attribs.c:3230
 #, gcc-internal-format
 msgid "%qE attribute does not apply to types"
 msgstr "l'attribut %qE ne s'applique pas aux types"
@@ -16279,40 +16281,40 @@
 msgstr "les attributs de type sont ignorés après que le type ait déjà été défini"
 
 #: attribs.c:691 attribs.c:1622 attribs.c:1632 attribs.c:1642
-#: c-family/c-attribs.c:540 c-family/c-attribs.c:559 c-family/c-attribs.c:577
-#: c-family/c-attribs.c:607 c-family/c-attribs.c:628 c-family/c-attribs.c:649
-#: c-family/c-attribs.c:690 c-family/c-attribs.c:717 c-family/c-attribs.c:733
-#: c-family/c-attribs.c:750 c-family/c-attribs.c:766 c-family/c-attribs.c:792
-#: c-family/c-attribs.c:807 c-family/c-attribs.c:835 c-family/c-attribs.c:852
-#: c-family/c-attribs.c:870 c-family/c-attribs.c:893 c-family/c-attribs.c:931
-#: c-family/c-attribs.c:954 c-family/c-attribs.c:971 c-family/c-attribs.c:1000
-#: c-family/c-attribs.c:1021 c-family/c-attribs.c:1042
-#: c-family/c-attribs.c:1069 c-family/c-attribs.c:1099
-#: c-family/c-attribs.c:1136 c-family/c-attribs.c:1189
-#: c-family/c-attribs.c:1255 c-family/c-attribs.c:1313
-#: c-family/c-attribs.c:1402 c-family/c-attribs.c:1432
-#: c-family/c-attribs.c:1483 c-family/c-attribs.c:1998
-#: c-family/c-attribs.c:2035 c-family/c-attribs.c:2096
-#: c-family/c-attribs.c:2152 c-family/c-attribs.c:2230
-#: c-family/c-attribs.c:2312 c-family/c-attribs.c:2371
-#: c-family/c-attribs.c:2390 c-family/c-attribs.c:2498
-#: c-family/c-attribs.c:2514 c-family/c-attribs.c:2530
-#: c-family/c-attribs.c:2551 c-family/c-attribs.c:2608
-#: c-family/c-attribs.c:2635 c-family/c-attribs.c:2690
-#: c-family/c-attribs.c:2870 c-family/c-attribs.c:2891
-#: c-family/c-attribs.c:3004 c-family/c-attribs.c:3031
-#: c-family/c-attribs.c:3221 c-family/c-attribs.c:3239
-#: c-family/c-attribs.c:3262 c-family/c-attribs.c:3301
-#: c-family/c-attribs.c:3383 c-family/c-attribs.c:3439
-#: c-family/c-attribs.c:3455 c-family/c-attribs.c:3549
-#: c-family/c-common.c:5600 config/darwin.c:2072 config/arm/arm.c:6868
+#: c-family/c-attribs.c:547 c-family/c-attribs.c:566 c-family/c-attribs.c:584
+#: c-family/c-attribs.c:614 c-family/c-attribs.c:635 c-family/c-attribs.c:656
+#: c-family/c-attribs.c:697 c-family/c-attribs.c:728 c-family/c-attribs.c:744
+#: c-family/c-attribs.c:761 c-family/c-attribs.c:777 c-family/c-attribs.c:803
+#: c-family/c-attribs.c:818 c-family/c-attribs.c:846 c-family/c-attribs.c:863
+#: c-family/c-attribs.c:881 c-family/c-attribs.c:904 c-family/c-attribs.c:942
+#: c-family/c-attribs.c:965 c-family/c-attribs.c:982 c-family/c-attribs.c:1011
+#: c-family/c-attribs.c:1032 c-family/c-attribs.c:1053
+#: c-family/c-attribs.c:1080 c-family/c-attribs.c:1110
+#: c-family/c-attribs.c:1147 c-family/c-attribs.c:1200
+#: c-family/c-attribs.c:1266 c-family/c-attribs.c:1324
+#: c-family/c-attribs.c:1413 c-family/c-attribs.c:1443
+#: c-family/c-attribs.c:1494 c-family/c-attribs.c:2009
+#: c-family/c-attribs.c:2046 c-family/c-attribs.c:2107
+#: c-family/c-attribs.c:2163 c-family/c-attribs.c:2241
+#: c-family/c-attribs.c:2323 c-family/c-attribs.c:2382
+#: c-family/c-attribs.c:2401 c-family/c-attribs.c:2509
+#: c-family/c-attribs.c:2525 c-family/c-attribs.c:2541
+#: c-family/c-attribs.c:2562 c-family/c-attribs.c:2619
+#: c-family/c-attribs.c:2646 c-family/c-attribs.c:2701
+#: c-family/c-attribs.c:2881 c-family/c-attribs.c:2902
+#: c-family/c-attribs.c:3015 c-family/c-attribs.c:3042
+#: c-family/c-attribs.c:3232 c-family/c-attribs.c:3250
+#: c-family/c-attribs.c:3273 c-family/c-attribs.c:3312
+#: c-family/c-attribs.c:3394 c-family/c-attribs.c:3450
+#: c-family/c-attribs.c:3466 c-family/c-attribs.c:3560
+#: c-family/c-common.c:5598 config/darwin.c:2072 config/arm/arm.c:6868
 #: config/arm/arm.c:6896 config/arm/arm.c:6913 config/avr/avr.c:9698
-#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6497
-#: config/i386/i386.c:41520 config/ia64/ia64.c:788
-#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33056
-#: config/spu/spu.c:3743 ada/gcc-interface/utils.c:6244
-#: ada/gcc-interface/utils.c:6261 ada/gcc-interface/utils.c:6277
-#: ada/gcc-interface/utils.c:6303 brig/brig-lang.c:476 lto/lto-lang.c:283
+#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6500
+#: config/i386/i386.c:41514 config/ia64/ia64.c:788
+#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33112
+#: config/spu/spu.c:3743 ada/gcc-interface/utils.c:6249
+#: ada/gcc-interface/utils.c:6266 ada/gcc-interface/utils.c:6282
+#: ada/gcc-interface/utils.c:6308 brig/brig-lang.c:476 lto/lto-lang.c:283
 #, gcc-internal-format
 msgid "%qE attribute ignored"
 msgstr "attribut %qE ignoré"
@@ -16680,87 +16682,105 @@
 msgid "%Kattempt to free a non-heap object"
 msgstr "%Ktentative de libérer un objet qui n'est pas sur le tas"
 
-#: calls.c:1434
+#: calls.c:1291 file-prefix-map.c:50
 #, gcc-internal-format
+msgid "invalid argument %qs to %qs"
+msgstr "argument %qs invalide pour %qs"
+
+#: calls.c:1452
+#, gcc-internal-format
 msgid "%Kargument %i value %qE is negative"
 msgstr "%Kl'argument %i a la valeur %qE qui est négative"
 
-#: calls.c:1452
+#: calls.c:1470
 #, gcc-internal-format
 msgid "%Kargument %i value is zero"
 msgstr "%Kla valeur de l'argument %i est zéro"
 
-#: calls.c:1469
+#: calls.c:1487
 #, gcc-internal-format
 msgid "%Kargument %i value %qE exceeds maximum object size %E"
 msgstr "%1$Kla valeur %3$qE de l'argument %2$i excède la taille maximale de l'objet (%4$E)"
 
-#: calls.c:1483
+#: calls.c:1501
 #, gcc-internal-format
 msgid "%Kargument %i range [%E, %E] is negative"
 msgstr "%Kl'argument %i ayant une plage [%E, %E] est négatif"
 
-#: calls.c:1490
+#: calls.c:1508
 #, gcc-internal-format
 msgid "%Kargument %i range [%E, %E] exceeds maximum object size %E"
 msgstr "%Kl'argument %i, ayant une plage [%E, %E], excède la taille maximale de l'objet (%E)"
 
-#: calls.c:1520
+#: calls.c:1538
 #, gcc-internal-format
 msgid "%Kproduct %<%E * %E%> of arguments %i and %i exceeds %<SIZE_MAX%>"
 msgstr "%Kle produit %<%E * %E%> des arguments %i et %i excède %<SIZE_MAX%>"
 
-#: calls.c:1526
+#: calls.c:1544
 #, gcc-internal-format
 msgid "%Kproduct %<%E * %E%> of arguments %i and %i exceeds maximum object size %E"
 msgstr "%Kle produit %<%E * %E%> des arguments %i et %i excède la taille maximale de l'objet (%E)"
 
-#: calls.c:1537 calls.c:1540
+#: calls.c:1555 calls.c:1558
 #, gcc-internal-format
 msgid "argument %i in the range [%E, %E]"
 msgstr "l'argument %i est dans la plage [%E, %E]"
 
-#: calls.c:1551
+#: calls.c:1569
 #, gcc-internal-format
 msgid "in a call to built-in allocation function %qD"
 msgstr "dans un appel à la fonction d'allocation interne %qD"
 
-#: calls.c:1554
+#: calls.c:1572
 #, gcc-internal-format
 msgid "in a call to allocation function %qD declared here"
 msgstr "dans un appel à la fonction d'allocation %qD déclarée ici"
 
-#: calls.c:1711
-#, gcc-internal-format
-msgid "%qD argument %i declared attribute %<nonstring%> is smaller than the specified bound %E"
+#: calls.c:1835
+#, fuzzy, gcc-internal-format
+#| msgid "%qD argument %i declared attribute %<nonstring%> is smaller than the specified bound %E"
+msgid "%qD argument %i declared attribute %<nonstring%> is smaller than the specified bound %wu"
 msgstr "l'argument %qD %i a déclaré l'attribut %<nonstring%> est plus petit que la limité %E spécifiée"
 
-#: calls.c:1716
+#: calls.c:1841
+#, fuzzy, gcc-internal-format
+#| msgid "%qD argument %i declared attribute %<nonstring%> is smaller than the specified bound %E"
+msgid "%qD argument %i declared attribute %<nonstring%> is smaller than the specified bound [%E, %E]"
+msgstr "l'argument %qD %i a déclaré l'attribut %<nonstring%> est plus petit que la limité %E spécifiée"
+
+#: calls.c:1847
+#, fuzzy, gcc-internal-format
+#| msgid "%qD argument %i declared attribute %<nonstring%> is smaller than the specified bound %E"
+msgid "%qD argument %i declared attribute %<nonstring%> may be smaller than the specified bound [%E, %E]"
+msgstr "l'argument %qD %i a déclaré l'attribut %<nonstring%> est plus petit que la limité %E spécifiée"
+
+#: calls.c:1857
 #, gcc-internal-format
 msgid "%qD argument %i declared attribute %<nonstring%>"
 msgstr "l'argument %qD %i a déclaré l'attribut %<nonstring%>"
 
-#: calls.c:1721
+#: calls.c:1862
 #, gcc-internal-format
 msgid "argument %qD declared here"
 msgstr "l'argument %qD est déclarée ici"
 
-#: calls.c:1735
+#: calls.c:1876
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot tail-call: %s"
 msgstr "impossible d'appeler en fin de fonction (tail-call): %s"
 
-#: calls.c:3365
+#: calls.c:3506
 #, gcc-internal-format
 msgid "function call has aggregate value"
 msgstr "l'appel de fonction a une valeur d'agrégat"
 
-#: calls.c:4059
+#: calls.c:4200
 #, gcc-internal-format
 msgid "passing too large argument on stack"
 msgstr "passage d'un argument trop grand sur la pile"
 
-#: cfgexpand.c:1665 function.c:1002 varasm.c:2231
+#: cfgexpand.c:1665 function.c:1002 varasm.c:2242
 #, gcc-internal-format
 msgid "size of variable %q+D is too large"
 msgstr "la taille de la variable %q+D est trop grande"
@@ -17333,237 +17353,237 @@
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr "le nombre d'annotations des bb dans la chaîne des insn (%d) != n_basic_blocks (%d)"
 
-#: cgraph.c:3051
+#: cgraph.c:3056
 #, gcc-internal-format
 msgid "caller edge count invalid"
 msgstr "le nombre d'arêtes de l'appelant est invalide"
 
-#: cgraph.c:3135
+#: cgraph.c:3140
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr "champ aux défini pour l'arête %s->%s"
 
-#: cgraph.c:3142
+#: cgraph.c:3147
 #, gcc-internal-format
 msgid "cgraph count invalid"
 msgstr "décompte cgraph invalide"
 
-#: cgraph.c:3147
+#: cgraph.c:3152
 #, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr "clone en ligne dans la même liste du groupe comdat"
 
-#: cgraph.c:3152
+#: cgraph.c:3157
 #, gcc-internal-format
 msgid "local symbols must be defined"
 msgstr "les symboles locaux doivent être définis"
 
-#: cgraph.c:3157
+#: cgraph.c:3162
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr "clone en ligne visible depuis l'extérieur"
 
-#: cgraph.c:3162
+#: cgraph.c:3167
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr "clone en ligne avec l'adresse prise"
 
-#: cgraph.c:3167
+#: cgraph.c:3172
 #, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr "le clone en ligne est forcé à sortir"
 
-#: cgraph.c:3174
+#: cgraph.c:3179
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for indirect edge from %s"
 msgstr "champ aux défini pour une arête indirecte depuis %s"
 
-#: cgraph.c:3181
+#: cgraph.c:3186
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr "Une arête indirecte depuis %s n'est pas marquée comme indirecte ou a un indirect_info associé, l'instruction correspondante est: "
 
-#: cgraph.c:3196
+#: cgraph.c:3201
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr "la fonction locale comdat est appelée par %s en dehors de son comdat"
 
-#: cgraph.c:3206
+#: cgraph.c:3211
 #, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr "le pointeur inlined_to est faux"
 
-#: cgraph.c:3211
+#: cgraph.c:3216
 #, gcc-internal-format
 msgid "multiple inline callers"
 msgstr "appelants en ligne multiples"
 
-#: cgraph.c:3218
+#: cgraph.c:3223
 #, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr "pointeur inlined_to défini pour des appelants pas en ligne"
 
-#: cgraph.c:3239
+#: cgraph.c:3244
 #, gcc-internal-format
 msgid "caller edge count does not match BB count"
 msgstr "le décompte des arêtes de l'appelant ne correspond pas au décompte du BB"
 
-#: cgraph.c:3261
+#: cgraph.c:3266
 #, gcc-internal-format
 msgid "indirect call count does not match BB count"
 msgstr "le décompte des appels indirects ne correspond pas au décompte du BB"
 
-#: cgraph.c:3272
+#: cgraph.c:3277
 #, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr "le pointeur inlined_to est défini mais aucun prédécesseur trouvé"
 
-#: cgraph.c:3277
+#: cgraph.c:3282
 #, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr "le pointeur inlined_to fait référence à lui même"
 
-#: cgraph.c:3289
+#: cgraph.c:3294
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr "le cgraph_node a un mauvais clone_of"
 
-#: cgraph.c:3301
+#: cgraph.c:3306
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr "le cgraph_node a une mauvaise liste de clones"
 
-#: cgraph.c:3307
+#: cgraph.c:3312
 #, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr "le cgraph_node est dans la liste des clones mais il n'est pas un clone"
 
-#: cgraph.c:3312
+#: cgraph.c:3317
 #, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr "le cgraph_node a un mauvais pointeur prev_clone"
 
-#: cgraph.c:3317
+#: cgraph.c:3322
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr "la liste doublement liée des clones est corrompue"
 
-#: cgraph.c:3329
+#: cgraph.c:3334
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr "L'alias a des arêtes d'appel"
 
-#: cgraph.c:3337
+#: cgraph.c:3342
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr "L'alias a une référence qui n'est pas un alias"
 
-#: cgraph.c:3342
+#: cgraph.c:3347
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr "L'alias a plus d'une référence alias"
 
-#: cgraph.c:3349
+#: cgraph.c:3354
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr "L'alias analysé n'a pas de référence"
 
-#: cgraph.c:3358
+#: cgraph.c:3363
 #, gcc-internal-format
 msgid "Instrumentation clone does not reference original node"
 msgstr "Le clone modifié pour ajouter du code ne fait pas référence au nœud original"
 
-#: cgraph.c:3365
+#: cgraph.c:3370
 #, gcc-internal-format
 msgid "Not instrumented node has non-NULL original declaration"
 msgstr "Le nœud, bien que non modifié pour ajouter du code, déclare un nœud original non NULL"
 
-#: cgraph.c:3375
+#: cgraph.c:3380
 #, gcc-internal-format
 msgid "Instrumented node has wrong original declaration"
 msgstr "Le nœud modifié pour ajouter du code à une mauvaise déclaration originale"
 
-#: cgraph.c:3393
+#: cgraph.c:3398
 #, gcc-internal-format
 msgid "Node has more than one chkp reference"
 msgstr "Le nœud a plus d'une référence chkp"
 
-#: cgraph.c:3398
+#: cgraph.c:3403
 #, gcc-internal-format
 msgid "Wrong node is referenced with chkp reference"
 msgstr "Le mauvais nœud est référencé avec la référence chkp"
 
-#: cgraph.c:3406
+#: cgraph.c:3411
 #, gcc-internal-format
 msgid "Analyzed node has no reference to instrumented version"
 msgstr "Le nœud analysé n'a aucune référence vers la version où le code a été ajouté"
 
-#: cgraph.c:3420
+#: cgraph.c:3425
 #, gcc-internal-format
 msgid "Alias chain for instrumented node is broken"
 msgstr "La chaine des alias pour le nœud avec le code ajouté est rompue"
 
-#: cgraph.c:3429
+#: cgraph.c:3434
 #, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr "Pas d'arête hors du nœud du fragment"
 
-#: cgraph.c:3434
+#: cgraph.c:3439
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr "Plus d'une arête sortante hors du nœud du fragment"
 
-#: cgraph.c:3439
+#: cgraph.c:3444
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr "Le fragment n'est pas supposé avoir un contenu"
 
-#: cgraph.c:3445
+#: cgraph.c:3450
 #, gcc-internal-format
 msgid "Instrumentation thunk has wrong edge callee"
 msgstr "Le fragment pour ajouter du code a une mauvaise arête vers l'appelé"
 
-#: cgraph.c:3481
+#: cgraph.c:3486
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr "call_stmt partagé:"
 
-#: cgraph.c:3489
+#: cgraph.c:3494
 #, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr "l'arête pointe vers la mauvaise déclaration:"
 
-#: cgraph.c:3498
+#: cgraph.c:3503
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr "une arête indirecte avec un appelé inconnu correspondant à un call_stmt avec une déclaration connue:"
 
-#: cgraph.c:3508
+#: cgraph.c:3513
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr "arête callgraph manquante pour l'appel stmt:"
 
-#: cgraph.c:3518
+#: cgraph.c:3523
 #, gcc-internal-format
 msgid "reference to dead statement"
 msgstr "référence à une instruction morte"
 
-#: cgraph.c:3531
+#: cgraph.c:3536
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr "l'arête %s->%s n'a pas de call_stmt correspondant"
 
-#: cgraph.c:3543
+#: cgraph.c:3548
 #, gcc-internal-format, gfc-internal-format
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr "une arête indirecte depuis %s n'a pas de call_stmt correspondant"
 
-#: cgraph.c:3554
+#: cgraph.c:3559
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr "verify_cgraph_node a échoué"
 
-#: cgraph.c:3661 varpool.c:306
+#: cgraph.c:3666 varpool.c:306
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: section %s is missing"
 msgstr "%s: la section %s est manquante"
@@ -17594,12 +17614,12 @@
 msgstr "l'attribut %<weakref%> est ignoré car la variable est initialisée"
 
 #. include_self=
-#: cgraphunit.c:981 c/c-decl.c:11282
+#: cgraphunit.c:981 c/c-decl.c:11302
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F utilisé mais jamais défini"
 
-#: cgraphunit.c:983 c/c-decl.c:11291
+#: cgraphunit.c:983 c/c-decl.c:11311
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "%q+F déclaré %<static%> mais jamais défini"
@@ -17714,12 +17734,12 @@
 msgid "cannot find '%s'"
 msgstr "« %s » introuvable"
 
-#: collect-utils.c:183 collect2.c:2361 collect2.c:2560 gcc.c:3080 gcc.c:6856
+#: collect-utils.c:183 collect2.c:2387 collect2.c:2586 gcc.c:3080 gcc.c:6856
 #, gcc-internal-format
 msgid "pex_init failed: %m"
 msgstr "échec de pex_init: %m"
 
-#: collect-utils.c:192 collect2.c:2370 collect2.c:2568 gcc.c:8498
+#: collect-utils.c:192 collect2.c:2396 collect2.c:2594 gcc.c:8498
 #, gcc-internal-format
 msgid "%s: %m"
 msgstr "%s: %m"
@@ -17729,96 +17749,96 @@
 msgid "COLLECT_LTO_WRAPPER must be set"
 msgstr "COLLECT_LTO_WRAPPER  doit être défini"
 
-#: collect2.c:966 gcc.c:7382 lto-wrapper.c:1666
+#: collect2.c:969 gcc.c:7382 lto-wrapper.c:1692
 #: config/i386/intelmic-mkoffload.c:556 config/nvptx/mkoffload.c:405
 #, gcc-internal-format
 msgid "atexit failed"
 msgstr "échec de atexit"
 
-#: collect2.c:1064
+#: collect2.c:1067
 #, gcc-internal-format
 msgid "no arguments"
 msgstr "pas d'argument"
 
-#: collect2.c:1303 opts.c:904
+#: collect2.c:1311 opts.c:904
 #, gcc-internal-format
 msgid "LTO support has not been enabled in this configuration"
 msgstr "le support LTO n'a pas été activé dans cette configuration"
 
-#: collect2.c:1344
+#: collect2.c:1352
 #, gcc-internal-format
 msgid "can't open %s: %m"
 msgstr "ne peut ouvrir %s: %m"
 
-#: collect2.c:1450
+#: collect2.c:1472
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown demangling style '%s'"
 msgstr "style de décodage des noms « %s » inconnu"
 
 # I18N
-#: collect2.c:1546 collect2.c:1729 collect2.c:1769
+#: collect2.c:1574 collect2.c:1757 collect2.c:1797
 #, gcc-internal-format
 msgid "fopen %s: %m"
 msgstr "fopen %s: %m"
 
 # I18N
-#: collect2.c:1549 collect2.c:1734 collect2.c:1772
+#: collect2.c:1577 collect2.c:1762 collect2.c:1800
 #, gcc-internal-format
 msgid "fclose %s: %m"
 msgstr "fclose %s: %m"
 
-#: collect2.c:2335
+#: collect2.c:2361
 #, gcc-internal-format
 msgid "cannot find 'nm'"
 msgstr "« nm » introuvable"
 
-#: collect2.c:2383
+#: collect2.c:2409
 #, gcc-internal-format
 msgid "can't open nm output: %m"
 msgstr "impossible d'ouvrir la sortie de nm: %m"
 
-#: collect2.c:2467
+#: collect2.c:2493
 #, gcc-internal-format, gfc-internal-format
 msgid "init function found in object %s"
 msgstr "fonction init trouvée dans l'objet %s"
 
-#: collect2.c:2478
+#: collect2.c:2504
 #, gcc-internal-format, gfc-internal-format
 msgid "fini function found in object %s"
 msgstr "fonction fini() trouvée dans l'objet %s"
 
-#: collect2.c:2535
+#: collect2.c:2561
 #, gcc-internal-format
 msgid "cannot find 'ldd'"
 msgstr "« ldd » introuvable"
 
-#: collect2.c:2581
+#: collect2.c:2607
 #, gcc-internal-format
 msgid "can't open ldd output: %m"
 msgstr "impossible d'ouvrir la sortie de ldd: %m"
 
-#: collect2.c:2599
+#: collect2.c:2625
 #, gcc-internal-format, gfc-internal-format
 msgid "dynamic dependency %s not found"
 msgstr "dépendance dynamique %s introuvable"
 
-#: collect2.c:2611
+#: collect2.c:2637
 #, gcc-internal-format, gfc-internal-format
 msgid "unable to open dynamic dependency '%s'"
 msgstr "incapable d'ouvrir la dépendance dynamique « %s »"
 
-#: collect2.c:2765
+#: collect2.c:2791
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: not a COFF file"
 msgstr "%s: pas un fichier COFF"
 
-#: collect2.c:2930
+#: collect2.c:2961
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: cannot open as COFF file"
 msgstr "%s: ne peut ouvrir en tant que fichier COFF"
 
 # I18N
-#: collect2.c:2989
+#: collect2.c:3020
 #, gcc-internal-format, gfc-internal-format
 msgid "library lib%s not found"
 msgstr "bibliothèque lib%s introuvable"
@@ -18029,12 +18049,12 @@
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr "les personnalités EH multiples sont uniquement supportées avec les assembleurs qui supportent la directive .cfi_personality"
 
-#: dwarf2out.c:10901
+#: dwarf2out.c:10909
 #, gcc-internal-format
 msgid "-gdwarf-6 is output as version 5 with incompatibilities"
 msgstr "-gdwarf-6 est émis sous la version 5 avec des incompatibilités"
 
-#: dwarf2out.c:14415
+#: dwarf2out.c:14423
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr "UNSPEC non délégitimisé %s (%d) trouvé à l'emplacement de la variable"
@@ -18154,11 +18174,6 @@
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr "%Kappel à %qs déclaré avec un avertissement d'attribut: %s"
 
-#: file-prefix-map.c:50
-#, gcc-internal-format
-msgid "invalid argument %qs to %qs"
-msgstr "argument %qs invalide pour %qs"
-
 #: final.c:1868
 #, gcc-internal-format
 msgid "the frame size of %wd bytes is larger than %wd bytes"
@@ -18179,42 +18194,42 @@
 msgid "large fixed-point constant implicitly truncated to fixed-point type"
 msgstr "la constante de grande taille en virgule fixe a été tronquée implicitement en un type en virgule fixe"
 
-#: fold-const.c:4151 fold-const.c:4161
+#: fold-const.c:4157 fold-const.c:4167
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d due to width of bit-field"
 msgstr "la comparaison est toujours %d en raison de la largeur du champ de bits"
 
-#: fold-const.c:5478 tree-ssa-reassoc.c:2374 tree-ssa-reassoc.c:3214
+#: fold-const.c:5484 tree-ssa-reassoc.c:2379 tree-ssa-reassoc.c:3219
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr "suppose qu'un débordement signé n'a pas lieu quand le test de la plage est simplifié"
 
-#: fold-const.c:5928 fold-const.c:5942
+#: fold-const.c:5934 fold-const.c:5948
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr "comparaison est toujours %d"
 
-#: fold-const.c:6085
+#: fold-const.c:6091
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr "un %<or%> de tests de non égalités non appariés est toujours 1"
 
-#: fold-const.c:6090
+#: fold-const.c:6096
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr "un %<and%> de tests d'égalités mutuellement exclusifs est toujours 0"
 
-#: fold-const.c:8310
+#: fold-const.c:8316
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr "suppose qu'un débordement signé n'a pas lieu lorsque la constante dans la comparaison est réduite"
 
-#: fold-const.c:8710
+#: fold-const.c:8716
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr "suppose qu'un débordement signé n'a pas lieu lorsque des constantes sont combinées autour d'une comparaison"
 
-#: fold-const.c:12063
+#: fold-const.c:12069
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr "vérification fold: arbre originale modifié par fold"
@@ -18224,7 +18239,7 @@
 msgid "total size of local objects too large"
 msgstr "la taille totale des objets locaux est trop grande"
 
-#: function.c:1776 gimplify.c:6270
+#: function.c:1776 gimplify.c:6273
 #, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr "contrainte impossible dans %<asm%>"
@@ -18531,7 +18546,7 @@
 msgid "%s: linker input file unused because linking not done"
 msgstr "%s: le fichier d'entrée de l'édition de liens n'est pas utilisé parce que l'édition de liens n'a pas été faite"
 
-#: gcc.c:8420 c-family/c-opts.c:770
+#: gcc.c:8420 c-family/c-opts.c:768
 #, gcc-internal-format
 msgid "cannot use %<-%> as input filename for a precompiled header"
 msgstr "impossible d'utiliser %<-%> comme nom de fichier d'entrée pour un en-tête précompilé"
@@ -18766,7 +18781,7 @@
 msgid "%G%qD destination unchanged after copying no bytes"
 msgstr "la destination %G%qD n'a pas été changée après n'avoir copié aucun octet"
 
-#: gimple-fold.c:2052 tree-ssa-strlen.c:2050
+#: gimple-fold.c:2052 tree-ssa-strlen.c:2074
 msgid "%G%qD specified bound %E equals destination size"
 msgstr "la limite spécifiée par %G%qD (%E) est égale à la taille de la destination"
 
@@ -18788,12 +18803,12 @@
 msgid "null pointer dereference"
 msgstr "déréférencement d'un pointeur null"
 
-#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12451
-#: tree.c:12488 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10147
-#: c/c-typeck.c:10164 c/gimple-parser.c:1616 c/gimple-parser.c:1624
+#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12455
+#: tree.c:12492 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10152
+#: c/c-typeck.c:10169 c/gimple-parser.c:1616 c/gimple-parser.c:1624
 #: cp/call.c:6493 cp/call.c:8098 cp/constexpr.c:820 cp/constexpr.c:2309
-#: cp/cvt.c:1015 cp/cvt.c:1042 cp/decl.c:7334 cp/decl2.c:5256 cp/pt.c:8334
-#: cp/semantics.c:1836 cp/semantics.c:4053 cp/typeck.c:1700 cp/typeck.c:1895
+#: cp/cvt.c:1015 cp/cvt.c:1042 cp/decl.c:7355 cp/decl2.c:5246 cp/pt.c:8348
+#: cp/semantics.c:1836 cp/semantics.c:4056 cp/typeck.c:1700 cp/typeck.c:1895
 #: cp/typeck.c:3837
 #, gcc-internal-format
 msgid "declared here"
@@ -18804,27 +18819,27 @@
 msgid "nonnull argument %qD compared to NULL"
 msgstr "argument non null %qD comparé à NULL"
 
-#: gimple-ssa-sprintf.c:2517 gimple-ssa-sprintf.c:2637
+#: gimple-ssa-sprintf.c:2555 gimple-ssa-sprintf.c:2675
 #, gcc-internal-format
 msgid "%qE output may be truncated before the last format character"
 msgstr "la sortie de %qE peut être tronquée avant le dernier caractère de format"
 
-#: gimple-ssa-sprintf.c:2519 gimple-ssa-sprintf.c:2639
+#: gimple-ssa-sprintf.c:2557 gimple-ssa-sprintf.c:2677
 #, gcc-internal-format
 msgid "%qE output truncated before the last format character"
 msgstr "la sortie de %qE peut être tronquée avant le dernier caractère de format"
 
-#: gimple-ssa-sprintf.c:2522 gimple-ssa-sprintf.c:2642
+#: gimple-ssa-sprintf.c:2560 gimple-ssa-sprintf.c:2680
 #, gcc-internal-format
 msgid "%qE may write a terminating nul past the end of the destination"
 msgstr "%qE peut écrire un zéro terminal au delà de la fin de la destination"
 
-#: gimple-ssa-sprintf.c:2524 gimple-ssa-sprintf.c:2644
+#: gimple-ssa-sprintf.c:2562 gimple-ssa-sprintf.c:2682
 #, gcc-internal-format
 msgid "%qE writing a terminating nul past the end of the destination"
 msgstr "%qE écrit un zéro terminal au delà de la fin de la destination"
 
-#: gimple-ssa-sprintf.c:2534
+#: gimple-ssa-sprintf.c:2572
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size %wu"
@@ -18831,7 +18846,7 @@
 msgstr[0] "la directive %<%.*s%> écrit %wu octet dans une région dont la taille est %wu"
 msgstr[1] "la directive %<%.*s%> écrit %wu octets dans une région dont la taille est %wu"
 
-#: gimple-ssa-sprintf.c:2541
+#: gimple-ssa-sprintf.c:2579
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size %wu"
@@ -18838,7 +18853,7 @@
 msgstr[0] "la sortie de la directive %<%.*s%> peut être tronquée en écrivant %wu octet dans une région dont la taille est %wu"
 msgstr[1] "la sortie de la directive %<%.*s%> peut être tronquée en écrivant %wu octets dans une région dont la taille est %wu"
 
-#: gimple-ssa-sprintf.c:2548
+#: gimple-ssa-sprintf.c:2586
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size %wu"
@@ -18845,67 +18860,67 @@
 msgstr[0] "la sortie de la directive %<%.*s%> a été tronquée en écrivant %wu octet dans une région dont la taille est %wu"
 msgstr[1] "la sortie de la directive %<%.*s%> a été tronquée en écrivant %wu octets dans une région dont la taille est %wu"
 
-#: gimple-ssa-sprintf.c:2559
+#: gimple-ssa-sprintf.c:2597
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size %wu"
 msgstr "la sortie de la directive %<%.*s%> peut être tronquée en écrivant jusqu'à %wu octets dans une région dont la taille est %wu"
 
-#: gimple-ssa-sprintf.c:2562
+#: gimple-ssa-sprintf.c:2600
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size %wu"
 msgstr "la sortie de la directive %<%.*s%> a été tronquée en écrivant jusqu'à %wu octets dans une région dont la taille est %wu"
 
-#: gimple-ssa-sprintf.c:2564
+#: gimple-ssa-sprintf.c:2602
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size %wu"
 msgstr "la directive %<%.*s%> écrit jusqu'à %wu octets dans une région dont la taille est %wu"
 
-#: gimple-ssa-sprintf.c:2576
+#: gimple-ssa-sprintf.c:2614
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr "la sortie de la directive %<%.*s%> peut être tronquée en écrivant probablement %wu octets ou plus dans une région dont la taille est %wu"
 
-#: gimple-ssa-sprintf.c:2579
+#: gimple-ssa-sprintf.c:2617
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr "la sortie de la directive %<%.*s%> a été tronquée en écrivant probablement %wu octets ou plus dans une région dont la taille est %wu"
 
-#: gimple-ssa-sprintf.c:2582
+#: gimple-ssa-sprintf.c:2620
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size %wu"
 msgstr "la directive %<%.*s%> écrit probablement %wu octets ou plus dans une région dont la taille est %wu"
 
-#: gimple-ssa-sprintf.c:2591
+#: gimple-ssa-sprintf.c:2629
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr "la sortie de la directive %<%.*s%> peut être tronquée en écrivant entre %wu et %wu octets dans une région dont la taille est %wu"
 
-#: gimple-ssa-sprintf.c:2594
+#: gimple-ssa-sprintf.c:2632
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr "la sortie de la directive %<%.*s%> a été tronquée en écrivant entre %wu et %wu octets dans une région dont la taille est %wu"
 
-#: gimple-ssa-sprintf.c:2597
+#: gimple-ssa-sprintf.c:2635
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size %wu"
 msgstr "la directive %<%.*s%> écrit entre %wu et %wu octets dans une région dont la taille est %wu"
 
-#: gimple-ssa-sprintf.c:2606
+#: gimple-ssa-sprintf.c:2644
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size %wu"
 msgstr "la sortie de la directive %<%.*s%> peut être tronquée en écrivant %wu octets ou plus dans une région dont la taille est %wu"
 
-#: gimple-ssa-sprintf.c:2609
+#: gimple-ssa-sprintf.c:2647
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size %wu"
 msgstr "la sortie de la directive %<%.*s%> a été tronquée en écrivant %wu ou plus d'octets dans une région dont la taille est %wu"
 
-#: gimple-ssa-sprintf.c:2611
+#: gimple-ssa-sprintf.c:2649
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size %wu"
 msgstr "la directive %<%.*s%> écrit %wu ou plus d'octets dans une région dont la taille est %wu"
 
-#: gimple-ssa-sprintf.c:2653
+#: gimple-ssa-sprintf.c:2691
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size between %wu and %wu"
@@ -18912,7 +18927,7 @@
 msgstr[0] "la directive %<%.*s%> écrit %wu octet dans une région dont la taille est comprise entre %wu et %wu"
 msgstr[1] "la directive %<%.*s%> écrit %wu octets dans une région dont la taille est comprise entre %wu et %wu"
 
-#: gimple-ssa-sprintf.c:2660
+#: gimple-ssa-sprintf.c:2698
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size between %wu and %wu"
@@ -18919,7 +18934,7 @@
 msgstr[0] "la sortie de la directive %<%.*s%> peut être tronquée en écrivant %wu octet dans une région dont la taille est comprise entre %wu et %wu"
 msgstr[1] "la sortie de la directive %<%.*s%> peut être tronquée en écrivant %wu octets dans une région dont la taille est comprise entre %wu et %wu"
 
-#: gimple-ssa-sprintf.c:2668
+#: gimple-ssa-sprintf.c:2706
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size between %wu and %wu"
@@ -18926,102 +18941,102 @@
 msgstr[0] "la sortie de la directive %<%.*s%> a été tronquée en écrivant %wu octet dans une région dont la taille est comprise entre %wu et %wu"
 msgstr[1] "la sortie de la directive %<%.*s%> a été tronquée en écrivant %wu octets dans une région dont la taille est comprise entre %wu et %wu"
 
-#: gimple-ssa-sprintf.c:2680
+#: gimple-ssa-sprintf.c:2718
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr "la sortie de la directive %<%.*s%> peut être tronquée en écrivant jusqu'à %wu octets dans une région dont la taille est comprise entre %wu et %wu"
 
-#: gimple-ssa-sprintf.c:2683
+#: gimple-ssa-sprintf.c:2721
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr "la sortie de la directive %<%.*s%> a été tronquée en écrivant jusqu'à %wu octets dans une région dont la taille est comprise entre %wu et %wu"
 
-#: gimple-ssa-sprintf.c:2686
+#: gimple-ssa-sprintf.c:2724
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr "la directive %<%.*s%> écrit jusqu'à %wu octets dans une région dont la taille est comprise entre %wu et %wu"
 
-#: gimple-ssa-sprintf.c:2699
+#: gimple-ssa-sprintf.c:2737
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr "la sortie de la directive %<%.*s%> peut être tronquée en écrivant probablement %wu octets ou plus dans une région dont la taille est comprise entre %wu et %wu"
 
-#: gimple-ssa-sprintf.c:2702
+#: gimple-ssa-sprintf.c:2740
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr "la sortie de la directive %<%.*s%> a été tronquée en écrivant probablement %wu octets ou plus dans une région dont la taille est comprise entre %wu et %wu"
 
-#: gimple-ssa-sprintf.c:2705
+#: gimple-ssa-sprintf.c:2743
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr "la directive %<%.*s%> écrit probablement %wu octets ou plus dans une région dont la taille est comprise entre %wu et %wu"
 
-#: gimple-ssa-sprintf.c:2715
+#: gimple-ssa-sprintf.c:2753
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr "la sortie de la directive %<%.*s%> peut être tronquée en écrivant entre %wu et %wu octets dans une région dont la taille est comprise entre %wu et %wu"
 
-#: gimple-ssa-sprintf.c:2718
+#: gimple-ssa-sprintf.c:2756
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr "la sortie de la directive %<%.*s%> a été tronquée en écrivant entre %wu et %wu octets dans une région dont la taille est comprise entre %wu et %wu"
 
-#: gimple-ssa-sprintf.c:2721
+#: gimple-ssa-sprintf.c:2759
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr "la directive %<%.*s%> écrit entre %wu et %wu octets dans une région dont la taille est comprise entre %wu et %wu"
 
-#: gimple-ssa-sprintf.c:2730
+#: gimple-ssa-sprintf.c:2768
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr "la sortie de la directive %<%.*s%> peut être tronquée en écrivant %wu octets ou plus dans une région dont la taille est comprise entre %wu et %wu"
 
-#: gimple-ssa-sprintf.c:2733
+#: gimple-ssa-sprintf.c:2771
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr "la sortie de la directive %<%.*s%> a été tronquée en écrivant %wu octets ou plus dans une région dont la taille est comprise entre %wu et %wu"
 
-#: gimple-ssa-sprintf.c:2736
+#: gimple-ssa-sprintf.c:2774
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr "la directive %<%.*s%> écrit %wu octets ou plus dans une région dont la taille est comprise entre %wu et %wu"
 
-#: gimple-ssa-sprintf.c:2825
+#: gimple-ssa-sprintf.c:2863
 #, gcc-internal-format
 msgid "%<%.*s%> directive argument is null"
 msgstr "l'argument de la directive %<%.*s%> est nul"
 
-#: gimple-ssa-sprintf.c:2890
+#: gimple-ssa-sprintf.c:2928
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes exceeds minimum required size of 4095"
 msgstr "la sortie de la directive %<%.*s%> qui a %wu octets dépasse la taille minimum requise de 4095"
 
-#: gimple-ssa-sprintf.c:2897
+#: gimple-ssa-sprintf.c:2935
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may exceed minimum required size of 4095"
 msgstr "la sortie de la directive %<%.*s%> qui contient entre %wu et %wu octets peut dépasser la taille minimum requise de 4095"
 
-#: gimple-ssa-sprintf.c:2900
+#: gimple-ssa-sprintf.c:2938
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes exceeds minimum required size of 4095"
 msgstr "la sortie de la directive %<%.*s%> qui contient entre %wu et %wu octets dépasse la taille minimum requise de 4095"
 
-#: gimple-ssa-sprintf.c:2929
+#: gimple-ssa-sprintf.c:2967
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr "la sortie de la directive %<%.*s%> qui a %wu octets fait déborder le résultat au delà de %<INT_MAX%>"
 
-#: gimple-ssa-sprintf.c:2936
+#: gimple-ssa-sprintf.c:2974
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr "la sortie de la directive %<%.*s%> qui contient entre %wu et %wu octets fait déborder le résultat au delà de %<INT_MAX%>"
 
-#: gimple-ssa-sprintf.c:2939
+#: gimple-ssa-sprintf.c:2977
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may cause result to exceed %<INT_MAX%>"
 msgstr "la sortie de la directive %<%.*s%> qui contient entre %wu et %wu octets peut faire déborder le résultat au delà de %<INT_MAX%>"
 
-#: gimple-ssa-sprintf.c:2949
+#: gimple-ssa-sprintf.c:2987
 #, gcc-internal-format
 msgid "assuming directive output of %wu byte"
 msgid_plural "assuming directive output of %wu bytes"
@@ -19028,77 +19043,77 @@
 msgstr[0] "on suppose que la sortie de la directive occupe %wu octet"
 msgstr[1] "on suppose que la sortie de la directive occupe %wu octets"
 
-#: gimple-ssa-sprintf.c:2956
+#: gimple-ssa-sprintf.c:2994
 #, gcc-internal-format
 msgid "directive argument %qE"
 msgstr "argument de directive %qE"
 
-#: gimple-ssa-sprintf.c:2958
+#: gimple-ssa-sprintf.c:2996
 #, gcc-internal-format
 msgid "directive argument in the range [%E, %E]"
 msgstr "argument de directive dans la plage [%E, %E]"
 
-#: gimple-ssa-sprintf.c:2962
+#: gimple-ssa-sprintf.c:3000
 #, gcc-internal-format
 msgid "using the range [%E, %E] for directive argument"
 msgstr "utilise la plage [%E, %E] pour l'argument de la directive"
 
-#: gimple-ssa-sprintf.c:2982
+#: gimple-ssa-sprintf.c:3020
 #, gcc-internal-format
 msgid "%qE output %wu byte into a destination of size %wu"
 msgstr "%qE écrit %wu octet dans une destination dont la taille est %wu"
 
-#: gimple-ssa-sprintf.c:2983
+#: gimple-ssa-sprintf.c:3021
 #, gcc-internal-format
 msgid "%qE output %wu bytes into a destination of size %wu"
 msgstr "%qE écrit %wu octets dans une destination dont la taille est %wu"
 
-#: gimple-ssa-sprintf.c:2987
+#: gimple-ssa-sprintf.c:3025
 #, gcc-internal-format
 msgid "%qE output between %wu and %wu bytes into a destination of size %wu"
 msgstr "%qE écrit entre %wu et %wu octets dans une destination dont la taille est %wu"
 
-#: gimple-ssa-sprintf.c:2992
+#: gimple-ssa-sprintf.c:3030
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes (assuming %wu) into a destination of size %wu"
 msgstr "%qE écrit %wu octets ou plus (%wu supposé) dans une destination dont la taille est %wu"
 
-#: gimple-ssa-sprintf.c:2997
+#: gimple-ssa-sprintf.c:3035
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes into a destination of size %wu"
 msgstr "%qE écrit %wu octets ou plus dans une destination dont la taille est %wu"
 
-#: gimple-ssa-sprintf.c:3368
+#: gimple-ssa-sprintf.c:3406
 #, gcc-internal-format
 msgid "%<%.*s%> directive width out of range"
 msgstr "la largeur de la directive %<%.*s%> est hors limites"
 
-#: gimple-ssa-sprintf.c:3402
+#: gimple-ssa-sprintf.c:3440
 #, gcc-internal-format
 msgid "%<%.*s%> directive precision out of range"
 msgstr "la précision de la directive %<%.*s%> est hors limites"
 
-#: gimple-ssa-sprintf.c:3893
+#: gimple-ssa-sprintf.c:3931
 #, gcc-internal-format
 msgid "specified bound %wu exceeds maximum object size %wu"
 msgstr "la limite spécifiée %wu excède la taille maximale de l'objet (%wu)"
 
-#: gimple-ssa-sprintf.c:3899
+#: gimple-ssa-sprintf.c:3937
 #, gcc-internal-format
 msgid "specified bound %wu exceeds %<INT_MAX%>"
 msgstr "la limite spécifiée %wu excède %<INT_MAX%>"
 
-#: gimple-ssa-sprintf.c:3949
+#: gimple-ssa-sprintf.c:3987
 #, gcc-internal-format
 msgid "null destination pointer"
 msgstr "pointeur de destination null"
 
-#: gimple-ssa-sprintf.c:3966
+#: gimple-ssa-sprintf.c:4004
 #, gcc-internal-format
 msgid "specified bound %wu exceeds the size %wu of the destination object"
 msgstr "la limite spécifiée %wu dépasse la taille %wu de l'objet de destination"
 
-#: gimple-ssa-sprintf.c:3978
+#: gimple-ssa-sprintf.c:4016
 #, gcc-internal-format
 msgid "null format string"
 msgstr "chaîne de format nulle"
@@ -19311,10 +19326,10 @@
 msgstr "%G%qD le décalage %s est hors des limites de l'objet %qD avec le type %qT"
 
 #: gimple-ssa-warn-restrict.c:1678 c/c-decl.c:3603 c/c-decl.c:3874
-#: c/c-typeck.c:8345 cp/class.c:1346 cp/class.c:3098 cp/decl.c:3979
-#: cp/decl.c:10753 cp/decl.c:11151 cp/decl.c:11160 cp/friend.c:384
+#: c/c-typeck.c:8350 cp/class.c:1346 cp/class.c:3102 cp/decl.c:3979
+#: cp/decl.c:10777 cp/decl.c:11175 cp/decl.c:11184 cp/friend.c:384
 #: cp/friend.c:393 cp/parser.c:3275 cp/parser.c:3372 cp/parser.c:3422
-#: cp/parser.c:6327 cp/parser.c:21027
+#: cp/parser.c:6330 cp/parser.c:21024
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD déclaré ici"
@@ -19383,220 +19398,220 @@
 msgid "using result of function returning %<void%>"
 msgstr "utilisation du résultat d'une fonction qui retourne %<void%>"
 
-#: gimplify.c:6128
+#: gimplify.c:6131
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid lvalue in asm output %d"
 msgstr "l-valeur invalide dans la sortie asm %d"
 
-#: gimplify.c:6271
+#: gimplify.c:6274
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr "l'entrée %d qui n'est pas une zone mémoire doit rester en mémoire"
 
-#: gimplify.c:6311 gimplify.c:6320
+#: gimplify.c:6314 gimplify.c:6323
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr "l'entrée mémoire %d n'est pas directement adressable"
 
-#: gimplify.c:6928
+#: gimplify.c:6931
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in target region"
 msgstr "la variable privée au thread %qE est utilisée dans la région cible"
 
-#: gimplify.c:6930
+#: gimplify.c:6933
 #, gcc-internal-format
 msgid "enclosing target region"
 msgstr "région cible englobante"
 
-#: gimplify.c:6942
+#: gimplify.c:6945
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in untied task"
 msgstr "la variable privée au thread %qE est utilisée dans une tâche non liée"
 
-#: gimplify.c:6944
+#: gimplify.c:6947
 #, gcc-internal-format
 msgid "enclosing task"
 msgstr "tâche englobante"
 
 # le %qs est un nom de région non traduit tel que « parallel », « task », « teams ».
-#: gimplify.c:7016
+#: gimplify.c:7019
 #, gcc-internal-format
 msgid "%qE not specified in enclosing %qs"
 msgstr "%qE non spécifié dans la région %qs englobante"
 
 # le %qs est un nom de région non traduit tel que « parallel », « task », « teams ».
-#: gimplify.c:7018
+#: gimplify.c:7021
 #, gcc-internal-format
 msgid "enclosing %qs"
 msgstr "région %qs englobante"
 
-#: gimplify.c:7143
+#: gimplify.c:7146
 #, gcc-internal-format
 msgid "%qE not specified in enclosing OpenACC %qs construct"
 msgstr "%qE non spécifié dans la construction OpenACC %qs englobante"
 
-#: gimplify.c:7145
+#: gimplify.c:7148
 #, gcc-internal-format
 msgid "enclosing OpenACC %qs construct"
 msgstr "construction OpenACC %qs englobante"
 
-#: gimplify.c:7198
+#: gimplify.c:7201
 #, gcc-internal-format
 msgid "%qE with %<link%> clause used in %<routine%> function"
 msgstr "%qE avec une clause %<link%> utilisée dans une fonction %<routine%>"
 
-#: gimplify.c:7206
+#: gimplify.c:7209
 #, gcc-internal-format
 msgid "%qE requires a %<declare%> directive for use in a %<routine%> function"
 msgstr "%qE requiert une directive %<declare%> pour l'utilisation dans une fonction %<routine%>"
 
-#: gimplify.c:7272 gimplify.c:7872
+#: gimplify.c:7275 gimplify.c:7875
 #, gcc-internal-format
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr "la variable %qE est déclarée dans une région %<host_data%> englobante"
 
-#: gimplify.c:7293
+#: gimplify.c:7296
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr "%qD est référencé dans une région cible qui n'a pas de type pour lequel une correspondance peut être établie (mappable type)"
 
-#: gimplify.c:7411 gimplify.c:7443
+#: gimplify.c:7414 gimplify.c:7446
 #, gcc-internal-format
 msgid "iteration variable %qE is predetermined linear"
 msgstr "la variable d'itération %qE est prédéterminée linéaire"
 
-#: gimplify.c:7414
+#: gimplify.c:7417
 #, gcc-internal-format
 msgid "iteration variable %qE should be private"
 msgstr "la variable d'itération %qE devrait être privée"
 
-#: gimplify.c:7428
+#: gimplify.c:7431
 #, gcc-internal-format
 msgid "iteration variable %qE should not be firstprivate"
 msgstr "la variable d'itération %qE ne devrait pas être « firstprivate »"
 
-#: gimplify.c:7431
+#: gimplify.c:7434
 #, gcc-internal-format
 msgid "iteration variable %qE should not be reduction"
 msgstr "la variable d'itération %qE ne devrait pas être une réduction"
 
-#: gimplify.c:7434
+#: gimplify.c:7437
 #, gcc-internal-format
 msgid "iteration variable %qE should not be linear"
 msgstr "la variable d'itération %qE ne devrait pas être linéaire"
 
-#: gimplify.c:7437
+#: gimplify.c:7440
 #, gcc-internal-format
 msgid "iteration variable %qE should not be lastprivate"
 msgstr "la variable d'itération %qE ne devrait pas être « lastprivate »"
 
-#: gimplify.c:7440
+#: gimplify.c:7443
 #, gcc-internal-format
 msgid "iteration variable %qE should not be private"
 msgstr "la variable d'itération %qE ne devrait pas être privée"
 
-#: gimplify.c:7742
+#: gimplify.c:7745
 #, gcc-internal-format
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr "la clause %<linear%> pour une variable autre qu'un itérateur de boucle est spécifiée sur une construction combinée avec %<distribute%>"
 
-#: gimplify.c:7949
+#: gimplify.c:7952
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr "champ de correspondance %qE d'une structure de longueur variable"
 
-#: gimplify.c:8160
+#: gimplify.c:8163
 #, gcc-internal-format
 msgid "%qE appears more than once in map clauses"
 msgstr "%qE apparaît plus d'une fois dans la clause de correspondance (map)"
 
-#: gimplify.c:8464
+#: gimplify.c:8467
 #, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr "la variable « copyprivate » %qE n'est pas « threadprivate » ou privée dans le contexte extérieur"
 
 # le %s est remplacé par des mots-clé non traduits tels que « firstprivate », « lastprivate »,…
-#: gimplify.c:8484
+#: gimplify.c:8487
 #, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr "la variable « %s » %qE est privée dans le contexte extérieur"
 
-#: gimplify.c:8510
+#: gimplify.c:8513
 #, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr "modificateur de clause %qs %<if%> attendu au lieu de %qs"
 
-#: gimplify.c:8775
+#: gimplify.c:8778
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr "%<_Atomic%> %qD dans la clause implicite %<map%>"
 
-#: gimplify.c:8808
+#: gimplify.c:8811
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr "%<_Atomic%> %qD dans la clause implicite %<firstprivate%> dans la construction %<target%>"
 
-#: gimplify.c:9000
+#: gimplify.c:9003
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr "%<_Atomic%> %qD dans la clause %<firstprivate%> dans la construction %<target%>"
 
-#: gimplify.c:9051
+#: gimplify.c:9054
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr "la même variable est utilisée dans les clauses %<firstprivate%> et %<lastprivate%> dans la construction %<distribute%>"
 
-#: gimplify.c:9133
+#: gimplify.c:9136
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to present_or_copy"
 msgstr "clause de données avec réduction sur %qE incompatible; promu en present_or_copy"
 
-#: gimplify.c:9278
+#: gimplify.c:9281
 #, gcc-internal-format
 msgid "invalid private reduction on %qE"
 msgstr "réduction privée invalide sur %qE"
 
-#: gimplify.c:11103 omp-low.c:2791
+#: gimplify.c:11106 omp-low.c:2791
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr "une construction %<ordered%> avec une clause %<depend%> doit être étroitement imbriquée dans une boucle avec une clause %<ordered%> avec un paramètre"
 
-#: gimplify.c:11121
+#: gimplify.c:11124
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr "la variable %qE n'est pas une itération de la boucle %d la plus à l'extérieur, %qE attendu"
 
-#: gimplify.c:11134
+#: gimplify.c:11137
 #, gcc-internal-format
 msgid "number of variables in %<depend(sink)%> clause does not match number of iteration variables"
 msgstr "le nombre de variables dans la clause %<depend(sink)%> ne correspond pas au nombre de variables d'itérations"
 
-#: gimplify.c:11147
+#: gimplify.c:11150
 #, gcc-internal-format
 msgid "more than one %<depend(source)%> clause on an %<ordered%> construct"
 msgstr "plus d'une clause %<depend(source)%> sur une construction %<ordered%>"
 
-#: gimplify.c:11158
+#: gimplify.c:11161
 #, gcc-internal-format
 msgid "%<depend(source)%> clause specified together with %<depend(sink:)%> clauses on the same construct"
 msgstr "une clause %<depend(source)%> a été spécifiée avec des clauses %<depend(sink:)%> sur la même construction"
 
-#: gimplify.c:12393
+#: gimplify.c:12396
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr "la gimplification a échoué"
 
-#: gimplify.c:12936
+#: gimplify.c:12939
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr "%qT a été promu en %qT lors du passage à travers %<...%>"
 
-#: gimplify.c:12941
+#: gimplify.c:12944
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr "(vous devriez donc passer %qT et non %qT à %<va_arg%>)"
 
-#: gimplify.c:12948
+#: gimplify.c:12951
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr "si ce code est atteint, le programme s'arrêtera"
@@ -20069,47 +20084,47 @@
 msgid "Max. number of generated reload insns per insn is achieved (%d)\n"
 msgstr "Le nombre maximum d'insns de rechargement générées par insn est atteint (%d)\n"
 
-#: lto-cgraph.c:1294
+#: lto-cgraph.c:1296
 #, gcc-internal-format, gfc-internal-format
 msgid "bytecode stream: found multiple instances of cgraph node with uid %d"
 msgstr "flux bytecode: plusieurs instances trouvées pour le nœud cgraph avec le uid %d"
 
-#: lto-cgraph.c:1472
+#: lto-cgraph.c:1474
 #, gcc-internal-format
 msgid "bytecode stream: no caller found while reading edge"
 msgstr "flux bytecode: aucun appelant trouvé en lisant l'arête"
 
-#: lto-cgraph.c:1478
+#: lto-cgraph.c:1480
 #, gcc-internal-format
 msgid "bytecode stream: no callee found while reading edge"
 msgstr "flux bytecode: aucun appelé trouvé en lisant l'arête"
 
-#: lto-cgraph.c:1552
+#: lto-cgraph.c:1554
 #, gcc-internal-format
 msgid "bytecode stream: found empty cgraph node"
 msgstr "flux bytecode: nœud cgraph vide rencontré"
 
-#: lto-cgraph.c:1730
+#: lto-cgraph.c:1732
 #, gcc-internal-format, gfc-internal-format
 msgid "At most %i profile runs is supported. Perhaps corrupted profile?"
 msgstr "Un maximum de %i exécutions d'un profile est supporté. Le profile est peut-être corrompu ?"
 
-#: lto-cgraph.c:1817
+#: lto-cgraph.c:1819
 #, gcc-internal-format, gfc-internal-format
 msgid "Profile information in %s corrupted"
 msgstr "Les informations de profile dans %s sont corrompues"
 
-#: lto-cgraph.c:1855
+#: lto-cgraph.c:1857
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO cgraph in %s"
 msgstr "impossible de trouver le cgraph LTO dans %s"
 
-#: lto-cgraph.c:1865
+#: lto-cgraph.c:1867
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO section refs in %s"
 msgstr "impossible de trouver les références des sections LTO dans %s"
 
-#: lto-cgraph.c:1946
+#: lto-cgraph.c:1948
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid offload table in %s"
 msgstr "table de délestage invalide dans %s"
@@ -20180,81 +20195,87 @@
 msgid "bytecode stream in file %qs generated with LTO version %d.%d instead of the expected %d.%d"
 msgstr "le flux bytecode dans le fichier %qs a été généré par la version %d.%d de LTO au lieu de la version %d.%d attendue"
 
-#: lto-wrapper.c:117
+#: lto-wrapper.c:118
 #, gcc-internal-format
 msgid "deleting LTRANS file %s: %m"
 msgstr "effacement du fichier LTRANS %s: %m"
 
-#: lto-wrapper.c:154
+#: lto-wrapper.c:155
 #, gcc-internal-format
 msgid "malformed COLLECT_GCC_OPTIONS"
 msgstr "COLLECT_GCC_OPTIONS mal formé"
 
-#: lto-wrapper.c:308
+#: lto-wrapper.c:309
 #, gcc-internal-format, gfc-internal-format
 msgid "Option %s with different values"
 msgstr "Option %s avec des valeurs différentes"
 
-#: lto-wrapper.c:392
+#: lto-wrapper.c:393
 #, gcc-internal-format, gfc-internal-format
 msgid "Option %s not used consistently in all LTO input files"
 msgstr "Option %s pas utilisée de manière cohérente dans tous les fichiers d'entrée LTO"
 
-#: lto-wrapper.c:832
+#: lto-wrapper.c:833
 #, gcc-internal-format, gfc-internal-format
 msgid "problem with building target image for %s\n"
 msgstr "problème lors de la construction de l'image cible pour %s\n"
 
-#: lto-wrapper.c:852
+#: lto-wrapper.c:853
 #, gcc-internal-format
 msgid "reading input file"
 msgstr "lecture du fichier d'entrée"
 
-#: lto-wrapper.c:857
+#: lto-wrapper.c:858
 #, gcc-internal-format
 msgid "writing output file"
 msgstr "écriture du fichier de sortie"
 
-#: lto-wrapper.c:889
+#: lto-wrapper.c:890
 #, gcc-internal-format
 msgid "installation error, can't find crtoffloadtable.o"
 msgstr "erreur d'installation, impossible de trouver crtoffloadtable.o"
 
-#: lto-wrapper.c:1000 lto-wrapper.c:1012
+#: lto-wrapper.c:1001 lto-wrapper.c:1013
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: %s\n"
 msgstr "%s: %s\n"
 
-#: lto-wrapper.c:1056
+#: lto-wrapper.c:1064
 #, gcc-internal-format
 msgid "environment variable COLLECT_GCC must be set"
 msgstr "la variable d'environnement COLLECT_GCC doit être définie"
 
-#: lto-wrapper.c:1060 config/nvptx/mkoffload.c:363
+#: lto-wrapper.c:1068 config/nvptx/mkoffload.c:363
 #, gcc-internal-format
 msgid "environment variable COLLECT_GCC_OPTIONS must be set"
 msgstr "la variable d'environnement COLLECT_GCC_OPTIONS doit être définie"
 
-#: lto-wrapper.c:1229 lto-wrapper.c:1285
+#: lto-wrapper.c:1237 lto-wrapper.c:1293
 #, gcc-internal-format
 msgid "cannot open %s: %m"
 msgstr "ne peut ouvrir %s: %m"
 
-#: lto-wrapper.c:1232 lto-wrapper.c:1291
+#: lto-wrapper.c:1240 lto-wrapper.c:1299
 #, gcc-internal-format
 msgid "cannot read %s: %m"
 msgstr "ne peut lire %s: %m"
 
-#: lto-wrapper.c:1259
+#: lto-wrapper.c:1267
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid format of %s"
 msgstr "format invalide de %s"
 
-#: lto-wrapper.c:1482
+#: lto-wrapper.c:1491
 #, gcc-internal-format
 msgid "fopen: %s: %m"
 msgstr "fopen: %s: %m"
 
+#: lto-wrapper.c:1508
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "Could not open output file '%s'\n"
+msgid "Corrupted ltrans output file %s"
+msgstr "Impossible d'ouvrir le fichier de sortie « %s »\n"
+
 #: multiple_target.c:76
 #, gcc-internal-format
 msgid "the call requires ifunc, which is not supported by this target"
@@ -20606,12 +20627,12 @@
 msgid "unrecognized argument in option %qs"
 msgstr "argument non reconnu pour l'option %qs"
 
-#: opts-common.c:1198 config/i386/i386.c:3206
+#: opts-common.c:1198 config/i386/i386.c:3209
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "les arguments valables pour %qs sont: %s; vouliez vous utiliser %qs ?"
 
-#: opts-common.c:1201 config/i386/i386.c:3209
+#: opts-common.c:1201 config/i386/i386.c:3212
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "les arguments valables pour %qs sont: %s"
@@ -21206,22 +21227,22 @@
 msgid "output operand %d must use %<&%> constraint"
 msgstr "l'opérande de sortie %d doit utiliser la contrainte %<&%>"
 
-#: regcprop.c:1187
+#: regcprop.c:1193
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad next_regno for empty chain (%u)"
 msgstr "validate_value_data: [%u] next_regno erroné pour une chaîne vide (%u)"
 
-#: regcprop.c:1199
+#: regcprop.c:1205
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: Loop in regno chain (%u)"
 msgstr "validate_value_data: Boucle dans la chaîne regno (%u)"
 
-#: regcprop.c:1202
+#: regcprop.c:1208
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad oldest_regno (%u)"
 msgstr "validate_value_data: [%u] oldest_regno erroné (%u)"
 
-#: regcprop.c:1214
+#: regcprop.c:1220
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Non-empty reg in chain (%s %u %i)"
 msgstr "validate_value_data: [%u] Registre non vide dans la chaîne (%s %u %i)"
@@ -21266,7 +21287,7 @@
 msgstr "le registre de %qD est utilisé pour plusieurs variables-registre globales"
 
 #: reginfo.c:789 config/powerpcspe/powerpcspe.c:32259
-#: config/rs6000/rs6000.c:29453
+#: config/rs6000/rs6000.c:29530
 #, gcc-internal-format
 msgid "conflicts with %qD"
 msgstr "en conflit avec %qD"
@@ -21512,152 +21533,157 @@
 msgid "function symbol is not function"
 msgstr "le symbole de la fonction n'est pas une fonction"
 
-#: symtab.c:1006
+#: symtab.c:1005
 #, gcc-internal-format
+msgid "inconsistent `ifunc' attribute"
+msgstr ""
+
+#: symtab.c:1013
+#, gcc-internal-format
 msgid "variable symbol is not variable"
 msgstr "le symbole de la variable n'est pas une variable"
 
-#: symtab.c:1012
+#: symtab.c:1019
 #, gcc-internal-format
 msgid "node has unknown type"
 msgstr "le nœud a un type inconnu"
 
-#: symtab.c:1021
+#: symtab.c:1028
 #, gcc-internal-format
 msgid "node not found node->decl->decl_with_vis.symtab_node"
 msgstr "nœud pas trouvé node->decl->decl_with_vis.symtab_node"
 
-#: symtab.c:1029
+#: symtab.c:1036
 #, gcc-internal-format
 msgid "node differs from node->decl->decl_with_vis.symtab_node"
 msgstr "le nœud diffère de node->decl->decl_with_vis.symtab_node"
 
-#: symtab.c:1038
+#: symtab.c:1045
 #, gcc-internal-format
 msgid "assembler name hash list corrupted"
 msgstr "la liste de hachage des noms assembleur est corrompue"
 
-#: symtab.c:1051
+#: symtab.c:1058
 #, gcc-internal-format
 msgid "node not found in symtab assembler name hash"
 msgstr "le nœud n'a pas été trouvé dans le hachage des noms assembleur symtab"
 
-#: symtab.c:1058
+#: symtab.c:1065
 #, gcc-internal-format
 msgid "double linked list of assembler names corrupted"
 msgstr "la liste doublement liée des noms assembleur est corrompue"
 
-#: symtab.c:1063
+#: symtab.c:1070
 #, gcc-internal-format
 msgid "node has body_removed but is definition"
 msgstr "le nœud a body_removed mais il est une définition"
 
-#: symtab.c:1068
+#: symtab.c:1075
 #, gcc-internal-format
 msgid "node is analyzed but it is not a definition"
 msgstr "le nœud est analysé mais il n'est pas une définition"
 
-#: symtab.c:1073
+#: symtab.c:1080
 #, gcc-internal-format
 msgid "node is alias but not implicit alias"
 msgstr "le nœud est un alias mais pas un alias implicite"
 
-#: symtab.c:1078
+#: symtab.c:1085
 #, gcc-internal-format
 msgid "node is alias but not definition"
 msgstr "le nœud est un alias mais pas une définition"
 
-#: symtab.c:1083
+#: symtab.c:1090
 #, gcc-internal-format
 msgid "node is weakref but not an transparent_alias"
 msgstr "le nœud est une référence faible (weakref) mais pas un transparent_alias"
 
-#: symtab.c:1088
+#: symtab.c:1095
 #, gcc-internal-format
 msgid "node is transparent_alias but not an alias"
 msgstr "le nœud est un transparent_alias mais pas un alias"
 
-#: symtab.c:1097
+#: symtab.c:1104
 #, gcc-internal-format
 msgid "node is in same_comdat_group list but has no comdat_group"
 msgstr "le nœud est dans la liste same_comdat_group mais il n'a aucun comdat_group"
 
-#: symtab.c:1102
+#: symtab.c:1109
 #, gcc-internal-format
 msgid "same_comdat_group list across different groups"
 msgstr "liste same_comdat_group au travers de groupes différents"
 
-#: symtab.c:1107
+#: symtab.c:1114
 #, gcc-internal-format
 msgid "mixing different types of symbol in same comdat groups is not supported"
 msgstr "le mélange de types de symboles différents dans les mêmes groupes comdat n'est pas supporté"
 
-#: symtab.c:1112
+#: symtab.c:1119
 #, gcc-internal-format
 msgid "node is alone in a comdat group"
 msgstr "le nœud est seul dans un groupe comdat"
 
-#: symtab.c:1119
+#: symtab.c:1126
 #, gcc-internal-format
 msgid "same_comdat_group is not a circular list"
 msgstr "same_comdat_group n'est pas une liste circulaire"
 
-#: symtab.c:1134
+#: symtab.c:1141
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local symbol referred to by %s outside its comdat"
 msgstr "un symbole comdat local est référencé par %s hors de son comdat"
 
-#: symtab.c:1144
+#: symtab.c:1151
 #, gcc-internal-format
 msgid "implicit_section flag is set but section isn't"
 msgstr "le fanion implicit_section est défini mais la section ne l'est pas"
 
-#: symtab.c:1151
+#: symtab.c:1158
 #, gcc-internal-format
 msgid "Both section and comdat group is set"
 msgstr "La section et le groupe comdat sont tous les deux définis"
 
-#: symtab.c:1163
+#: symtab.c:1170
 #, gcc-internal-format
 msgid "Alias and target's section differs"
 msgstr "Les sections de l'alias et de la cible diffèrent"
 
-#: symtab.c:1170
+#: symtab.c:1177
 #, gcc-internal-format
 msgid "Alias and target's comdat groups differs"
 msgstr "Les groupes comdat de l'alias et de la cible diffèrent"
 
-#: symtab.c:1185
+#: symtab.c:1192
 #, gcc-internal-format
 msgid "Transparent alias and target's assembler names differs"
 msgstr "Les noms assembleurs de l'alias transparent et de la cible diffèrent"
 
-#: symtab.c:1193
+#: symtab.c:1200
 #, gcc-internal-format
 msgid "Chained transparent aliases"
 msgstr "Alias transparents enchaînés"
 
-#: symtab.c:1216 symtab.c:1253
+#: symtab.c:1223 symtab.c:1260
 #, gcc-internal-format
 msgid "symtab_node::verify failed"
 msgstr "symtab_node::verify a échoué"
 
-#: symtab.c:1249
+#: symtab.c:1256
 #, gcc-internal-format
 msgid "Two symbols with same comdat_group are not linked by the same_comdat_group list."
 msgstr "Deux symboles avec le même comdat_group ne sont pas liés par la liste same_comdat_group."
 
-#: symtab.c:1658
+#: symtab.c:1665
 #, gcc-internal-format
 msgid "function %q+D part of alias cycle"
 msgstr "la fonction %q+D fait partie du cycle des alias"
 
-#: symtab.c:1660
+#: symtab.c:1667
 #, gcc-internal-format
 msgid "variable %q+D part of alias cycle"
 msgstr "la variable %q+D fait partie du cycle des alias"
 
-#: symtab.c:1688
+#: symtab.c:1695
 #, gcc-internal-format
 msgid "section of alias %q+D must match section of its target"
 msgstr "la section de l'alias %q+D doit correspondre à la section de sa cible"
@@ -22458,7 +22484,7 @@
 msgid "the first argument of a VEC_COND_EXPR must be of a boolean vector type of the same number of elements as the result"
 msgstr "le premier argument d'un VEC_COND_EXPR doit être d'un type vectoriel booléen du même nombre d'éléments que le résultat"
 
-#: tree-cfg.c:4395 c/c-typeck.c:5212
+#: tree-cfg.c:4395 c/c-typeck.c:5217
 #, gcc-internal-format
 msgid "type mismatch in conditional expression"
 msgstr "non concordance de type dans une expression conditionnelle"
@@ -22808,22 +22834,22 @@
 msgid "missing edge %i->%i"
 msgstr "arête manquante %i->%i"
 
-#: tree-cfg.c:9379
+#: tree-cfg.c:9388
 #, gcc-internal-format
 msgid "%<noreturn%> function does return"
 msgstr "une fonction avec %<noreturn%> retourne une valeur"
 
-#: tree-cfg.c:9400 tree-cfg.c:9432
+#: tree-cfg.c:9409 tree-cfg.c:9441
 #, gcc-internal-format
 msgid "control reaches end of non-void function"
 msgstr "le contrôle a atteint la fin d'une fonction non « void »"
 
-#: tree-cfg.c:9498 cp/cvt.c:1039
+#: tree-cfg.c:9507 cp/cvt.c:1039
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgstr "la valeur retournée par %qD est ignorée alors qu'elle est déclarée avec l'attribut warn_unused_result"
 
-#: tree-cfg.c:9503 cp/cvt.c:1046
+#: tree-cfg.c:9512 cp/cvt.c:1046
 #, gcc-internal-format
 msgid "ignoring return value of function declared with attribute warn_unused_result"
 msgstr "la valeur retournée est ignorée pour une fonction déclarée avec l'attribut warn_unused_result"
@@ -23089,46 +23115,46 @@
 msgid "stmt volatile flag not up-to-date"
 msgstr "fanion volatile de l'instruction pas à jour"
 
-#: tree-ssa-strlen.c:1975
+#: tree-ssa-strlen.c:1999
 msgid "%G%qD output truncated before terminating nul copying %E byte from a string of the same length"
 msgid_plural "%G%qD output truncated before terminating nul copying %E bytes from a string of the same length"
 msgstr[0] "la sortie de %G%qD a été tronquée avant le zéro de fin en copiant %E octet depuis une chaîne de la même longueur"
 msgstr[1] "la sortie de %G%qD a été tronquée avant le zéro de fin en copiant %E octets depuis une chaîne de la même longueur"
 
-#: tree-ssa-strlen.c:1989
+#: tree-ssa-strlen.c:2013
 msgid "%G%qD output truncated copying %E byte from a string of length %wu"
 msgid_plural "%G%qD output truncated copying %E bytes from a string of length %wu"
 msgstr[0] "la sortie de %G%qD a été tronquée en copiant %E octet depuis une chaîne de longueur %wu"
 msgstr[1] "la sortie de %G%qD a été tronquée en copiant %E octets depuis une chaîne de longueur %wu"
 
-#: tree-ssa-strlen.c:1996
+#: tree-ssa-strlen.c:2020
 msgid "%G%qD output truncated copying between %wu and %wu bytes from a string of length %wu"
 msgstr "la sortie de %G%qD a été tronquée en copiant entre %wu et %wu octets depuis une chaîne de longueur %wu"
 
-#: tree-ssa-strlen.c:2008
+#: tree-ssa-strlen.c:2032
 msgid "%G%qD output may be truncated copying %E byte from a string of length %wu"
 msgid_plural "%G%qD output may be truncated copying %E bytes from a string of length %wu"
 msgstr[0] "la sortie de %G%qD peut être tronquée en copiant %E octet depuis une chaîne de longueur %wu"
 msgstr[1] "la sortie de %G%qD peut être tronquée en copiant %E octets depuis une chaîne de longueur %wu"
 
-#: tree-ssa-strlen.c:2015 tree-ssa-strlen.c:2029
+#: tree-ssa-strlen.c:2039 tree-ssa-strlen.c:2053
 msgid "%G%qD output may be truncated copying between %wu and %wu bytes from a string of length %wu"
 msgstr "la sortie de %G%qD peut être tronquée en copiant entre %wu et %wu octets depuis une chaîne de longueur %wu"
 
-#: tree-ssa-strlen.c:2150
+#: tree-ssa-strlen.c:2174
 msgid "%G%qD output truncated before terminating nul copying as many bytes from a string as its length"
 msgstr "la sortie de %G%qD a été tronquée avant le zéro final en copiant autant d'octets depuis la chaîne que sa longueur"
 
-#: tree-ssa-strlen.c:2156
+#: tree-ssa-strlen.c:2180
 msgid "%G%qD specified bound depends on the length of the source argument"
 msgstr "la limite spécifiée par %G%qD dépend de la longueur de l'argument source"
 
-#: tree-ssa-strlen.c:2163
+#: tree-ssa-strlen.c:2187
 #, gcc-internal-format
 msgid "length computed here"
 msgstr "longueur calculée ici"
 
-#: tree-ssa-uninit.c:191 varasm.c:331
+#: tree-ssa-uninit.c:191 varasm.c:342
 #, gcc-internal-format
 msgid "%qD was declared here"
 msgstr "%qD a été déclaré ici"
@@ -23303,27 +23329,27 @@
 msgid "target specific builtin not available"
 msgstr "la fonction intégrée spécifique à la cible n'est pas disponible"
 
-#: tree-vect-generic.c:287
+#: tree-vect-generic.c:283
 #, gcc-internal-format
 msgid "vector operation will be expanded piecewise"
 msgstr "l'opération vectorielle sera développée à la pièce"
 
-#: tree-vect-generic.c:290
+#: tree-vect-generic.c:286
 #, gcc-internal-format
 msgid "vector operation will be expanded in parallel"
 msgstr "l'opération vectorielle sera développée en parallèle"
 
-#: tree-vect-generic.c:341
+#: tree-vect-generic.c:337
 #, gcc-internal-format
 msgid "vector operation will be expanded with a single scalar operation"
 msgstr "l'opération vectorielle sera développée avec une seule opération scalaire"
 
-#: tree-vect-generic.c:941
+#: tree-vect-generic.c:937
 #, gcc-internal-format
 msgid "vector condition will be expanded piecewise"
 msgstr "la condition vectorielle sera développée à la pièce"
 
-#: tree-vect-generic.c:1373
+#: tree-vect-generic.c:1369
 #, gcc-internal-format
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr "l'opération de brassage vectoriel sera développée à la pièce"
@@ -23333,27 +23359,27 @@
 msgid "vectorization did not happen for a simd loop"
 msgstr "la vectorisation n'a pas eu lieu pour une boucle simd"
 
-#: tree-vrp.c:4930 tree-vrp.c:4974
+#: tree-vrp.c:4931 tree-vrp.c:4975
 #, gcc-internal-format
 msgid "array subscript %E is above array bounds of %qT"
 msgstr "l'indice du tableau %E est au delà des limites de %qT"
 
-#: tree-vrp.c:4956
+#: tree-vrp.c:4957
 #, gcc-internal-format
 msgid "array subscript [%E, %E] is outside array bounds of %qT"
 msgstr "l'indice du tableau [%E, %E] est en dehors des limites de %qT"
 
-#: tree-vrp.c:4988
+#: tree-vrp.c:4989
 #, gcc-internal-format
 msgid "array subscript %E is below array bounds of %qT"
 msgstr "l'indice du tableau %E est en dessous des limites de %qT"
 
-#: tree-vrp.c:5046
+#: tree-vrp.c:5047
 #, gcc-internal-format
 msgid "array subscript %wi is below array bounds of %qT"
 msgstr "l'indice du tableau %wi est en dessous des limites de %qT"
 
-#: tree-vrp.c:5060
+#: tree-vrp.c:5061
 #, gcc-internal-format
 msgid "array subscript %wu is above array bounds of %qT"
 msgstr "l'indice du tableau %wu est au delà des limites de %qT"
@@ -23368,92 +23394,92 @@
 msgid "side-effects element in no-side-effects CONSTRUCTOR"
 msgstr "élément avec des effets de bord dans un CONSTRUCTOR sans effets de bord"
 
-#: tree.c:7852
+#: tree.c:7856
 #, gcc-internal-format
 msgid "arrays of functions are not meaningful"
 msgstr "les tableaux de fonctions ne sont pas pertinents"
 
-#: tree.c:8019
+#: tree.c:8023
 #, gcc-internal-format
 msgid "function return type cannot be function"
 msgstr "le type retourné par une fonction ne peut être une fonction"
 
-#: tree.c:9327 tree.c:9412 tree.c:9473
+#: tree.c:9331 tree.c:9416 tree.c:9477
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: %s, have %s in %s, at %s:%d"
 msgstr "vérification de l'arbre: %s, obtenu %s dans %s, à %s:%d"
 
-#: tree.c:9364
+#: tree.c:9368
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected none of %s, have %s in %s, at %s:%d"
 msgstr "vérification de l'arbre: n'attendait aucun parmi %s, obtenu %s dans %s, à %s:%d"
 
-#: tree.c:9377
+#: tree.c:9381
 #, gcc-internal-format
 msgid "tree check: expected class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "vérification de l'arbre: attendait la classe %qs, obtenu %qs (%s) dans %s, à %s:%d"
 
-#: tree.c:9426
+#: tree.c:9430
 #, gcc-internal-format
 msgid "tree check: did not expect class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "vérification de l'arbre: on n'attendait pas la classe %qs, obtenu %qs (%s) dans %s, à %s:%d"
 
-#: tree.c:9439
+#: tree.c:9443
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected omp_clause %s, have %s in %s, at %s:%d"
 msgstr "vérification de l'arbre: attendait omp_clause %s, obtenu %s dans %s, à %s:%d"
 
-#: tree.c:9499
+#: tree.c:9503
 #, gcc-internal-format
 msgid "tree check: expected tree that contains %qs structure, have %qs in %s, at %s:%d"
 msgstr "vérification de l'arbre: attendait un arbre contenant la structure %qs, obtenu %qs dans %s, à %s:%d"
 
-#: tree.c:9513
+#: tree.c:9517
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_int_cst with %d elts in %s, at %s:%d"
 msgstr "vérification de l'arbre: accès à elt %d de tree_int_cst avec %d elts dans %s, à %s:%d"
 
-#: tree.c:9525
+#: tree.c:9529
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_vec with %d elts in %s, at %s:%d"
 msgstr "vérification de l'arbre: accès à elt %d de tree_vec avec %d elts dans %s, à %s:%d"
 
-#: tree.c:9538
+#: tree.c:9542
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of %s with %d operands in %s, at %s:%d"
 msgstr "vérification de l'arbre: opérande accédé %d de %s avec %d opérandes dans %s, à %s:%d"
 
-#: tree.c:9551
+#: tree.c:9555
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of omp_clause %s with %d operands in %s, at %s:%d"
 msgstr "vérification de l'arbre: opérande accédé %d de omp_clause %s avec %d opérandes dans %s, à %s:%d"
 
-#: tree.c:12446
+#: tree.c:12450
 #, gcc-internal-format
 msgid "%qD is deprecated: %s"
 msgstr "%qD est obsolète: %s"
 
-#: tree.c:12449
+#: tree.c:12453
 #, gcc-internal-format
 msgid "%qD is deprecated"
 msgstr "%qD est obsolète"
 
-#: tree.c:12473 tree.c:12495
+#: tree.c:12477 tree.c:12499
 #, gcc-internal-format
 msgid "%qE is deprecated: %s"
 msgstr "%qE est obsolète: %s"
 
-#: tree.c:12476 tree.c:12498
+#: tree.c:12480 tree.c:12502
 #, gcc-internal-format
 msgid "%qE is deprecated"
 msgstr "%qE est obsolète"
 
-#: tree.c:12482 tree.c:12503
+#: tree.c:12486 tree.c:12507
 #, gcc-internal-format, gfc-internal-format
 msgid "type is deprecated: %s"
 msgstr "le type est obsolète: %s"
 
-#: tree.c:12485 tree.c:12506
+#: tree.c:12489 tree.c:12510
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr "le type est obsolète"
@@ -23478,242 +23504,242 @@
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.c:13043
+#: tree.c:13047
 #, gcc-internal-format, gfc-internal-format
 msgid "type variant differs by %s"
 msgstr "la variante du type diffère sur %s"
 
-#: tree.c:13084
+#: tree.c:13088
 #, gcc-internal-format
 msgid "type variant has different TYPE_SIZE_UNIT"
 msgstr "la variante du type a un TYPE_SIZE_UNIT différent"
 
-#: tree.c:13086
+#: tree.c:13090
 #, gcc-internal-format
 msgid "type variant's TYPE_SIZE_UNIT"
 msgstr "TYPE_SIZE_UNIT de la variante du type"
 
-#: tree.c:13088
+#: tree.c:13092
 #, gcc-internal-format
 msgid "type's TYPE_SIZE_UNIT"
 msgstr "TYPE_SIZE_UNIT du type"
 
-#: tree.c:13108
+#: tree.c:13112
 #, gcc-internal-format
 msgid "type variant with TYPE_ALIAS_SET_KNOWN_P"
 msgstr "variante du type avec TYPE_ALIAS_SET_KNOWN_P"
 
-#: tree.c:13121
+#: tree.c:13125
 #, gcc-internal-format
 msgid "type variant has different TYPE_VFIELD"
 msgstr "la variante du type a un TYPE_VFIELD différent"
 
-#: tree.c:13157
+#: tree.c:13161
 #, gcc-internal-format
 msgid "type variant has different TYPE_BINFO"
 msgstr "la variante du type a un TYPE_BINFO différent"
 
-#: tree.c:13159
+#: tree.c:13163
 #, gcc-internal-format
 msgid "type variant's TYPE_BINFO"
 msgstr "TYPE_BINFO de la variante du type"
 
-#: tree.c:13161
+#: tree.c:13165
 #, gcc-internal-format
 msgid "type's TYPE_BINFO"
 msgstr "TYPE_BINFO du type"
 
-#: tree.c:13199
+#: tree.c:13203
 #, gcc-internal-format
 msgid "type variant has different TYPE_FIELDS"
 msgstr "la variante du type a un TYPE_FIELDS différent"
 
-#: tree.c:13201
+#: tree.c:13205
 #, gcc-internal-format
 msgid "first mismatch is field"
 msgstr "le premier désaccord est le champ"
 
-#: tree.c:13203
+#: tree.c:13207
 #, gcc-internal-format
 msgid "and field"
 msgstr "et le champ"
 
-#: tree.c:13220
+#: tree.c:13224
 #, gcc-internal-format
 msgid "type variant has different TREE_TYPE"
 msgstr "la variante du type a un TREE_TYPE différent"
 
-#: tree.c:13222 tree.c:13233
+#: tree.c:13226 tree.c:13237
 #, gcc-internal-format
 msgid "type variant's TREE_TYPE"
 msgstr "TREE_TYPE de la variante du type"
 
-#: tree.c:13224 tree.c:13235
+#: tree.c:13228 tree.c:13239
 #, gcc-internal-format
 msgid "type's TREE_TYPE"
 msgstr "TREE_TYPE du type"
 
-#: tree.c:13231
+#: tree.c:13235
 #, gcc-internal-format
 msgid "type is not compatible with its variant"
 msgstr "le type n'est pas compatible avec sa variante"
 
-#: tree.c:13534
+#: tree.c:13538
 #, gcc-internal-format
 msgid "Main variant is not defined"
 msgstr "La variante principale n'est pas définie"
 
-#: tree.c:13539
+#: tree.c:13543
 #, gcc-internal-format
 msgid "TYPE_MAIN_VARIANT has different TYPE_MAIN_VARIANT"
 msgstr "TYPE_MAIN_VARIANT a un TYPE_MAIN_VARIANT différent"
 
-#: tree.c:13551
+#: tree.c:13555
 #, gcc-internal-format
 msgid "TYPE_CANONICAL has different TYPE_CANONICAL"
 msgstr "TYPE_CANONICAL a un TYPE_CANONICAL différent"
 
-#: tree.c:13569
+#: tree.c:13573
 #, gcc-internal-format
 msgid "TYPE_CANONICAL is not compatible"
 msgstr "TYPE_CANONICAL n'est pas compatible"
 
-#: tree.c:13577
+#: tree.c:13581
 #, gcc-internal-format
 msgid "TYPE_MODE of TYPE_CANONICAL is not compatible"
 msgstr "le TYPE_MODE de TYPE_CANONICAL n'est pas compatible"
 
-#: tree.c:13583
+#: tree.c:13587
 #, gcc-internal-format
 msgid "TYPE_CANONICAL of main variant is not main variant"
 msgstr "le TYPE_CANONICAL de la variante principale n'est pas la variante principale"
 
-#: tree.c:13599
+#: tree.c:13603
 #, gcc-internal-format
 msgid "TYPE_VFIELD is not FIELD_DECL nor TREE_LIST"
 msgstr "TYPE_VFIELD n'est pas FIELD_DECL ni TREE_LIST"
 
-#: tree.c:13609
+#: tree.c:13613
 #, gcc-internal-format
 msgid "TYPE_NEXT_PTR_TO is not POINTER_TYPE"
 msgstr "TYPE_NEXT_PTR_TO n'est pas POINTER_TYPE"
 
-#: tree.c:13619
+#: tree.c:13623
 #, gcc-internal-format
 msgid "TYPE_NEXT_REF_TO is not REFERENCE_TYPE"
 msgstr "TYPE_NEXT_REF_TO n'est pas REFERENCE_TYPE"
 
-#: tree.c:13640
+#: tree.c:13644
 #, gcc-internal-format
 msgid "TYPE_BINFO is not TREE_BINFO"
 msgstr "TYPE_BINFO n'est pas TREE_BINFO"
 
-#: tree.c:13646
+#: tree.c:13650
 #, gcc-internal-format
 msgid "TYPE_BINFO type is not TYPE_MAIN_VARIANT"
 msgstr "le type TYPE_BINFO n'est pas TYPE_MAIN_VARIANT"
 
-#: tree.c:13657
+#: tree.c:13661
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not record nor union"
 msgstr "TYPE_METHOD_BASETYPE n'est pas un enregistrement ni une union"
 
-#: tree.c:13668
+#: tree.c:13672
 #, gcc-internal-format
 msgid "TYPE_OFFSET_BASETYPE is not record nor union"
 msgstr "TYPE_OFFSET_BASETYPE n'est pas un enregistrement ni une union"
 
-#: tree.c:13686
+#: tree.c:13690
 #, gcc-internal-format
 msgid "TYPE_ARRAY_MAX_SIZE not INTEGER_CST"
 msgstr "TYPE_ARRAY_MAX_SIZE pas INTEGER_CST"
 
-#: tree.c:13693
+#: tree.c:13697
 #, gcc-internal-format
 msgid "TYPE_MAX_VALUE_RAW non-NULL"
 msgstr "TYPE_MAX_VALUE_RAW non NULL"
 
-#: tree.c:13700
+#: tree.c:13704
 #, gcc-internal-format
 msgid "TYPE_LANG_SLOT_1 (binfo) field is non-NULL"
 msgstr "le champ TYPE_LANG_SLOT_1 (binfo) est non NULL"
 
-#: tree.c:13716
+#: tree.c:13720
 #, gcc-internal-format
 msgid "Enum value is not CONST_DECL or INTEGER_CST"
 msgstr "La valeur de l'enum n'est pas CONST_DECL ou INTEGER_CST"
 
-#: tree.c:13724
+#: tree.c:13728
 #, gcc-internal-format
 msgid "Enum value type is not INTEGER_TYPE nor convertible to the enum"
 msgstr "Le type de la valeur de l'enum n'est pas INTEGER_TYPE et n'est pas convertible en l'enum"
 
-#: tree.c:13731
+#: tree.c:13735
 #, gcc-internal-format
 msgid "Enum value name is not IDENTIFIER_NODE"
 msgstr "Le nom de la valeur de l'enum n'est pas IDENTIFIER_NODE"
 
-#: tree.c:13741
+#: tree.c:13745
 #, gcc-internal-format
 msgid "Array TYPE_DOMAIN is not integer type"
 msgstr "le TYPE_DOMAIN du tableau n'est pas d'un type entier"
 
-#: tree.c:13750
+#: tree.c:13754
 #, gcc-internal-format
 msgid "TYPE_FIELDS defined in incomplete type"
 msgstr "TYPE_FIELDS défini dans un type incomplet"
 
-#: tree.c:13772
+#: tree.c:13776
 #, gcc-internal-format
 msgid "Wrong tree in TYPE_FIELDS list"
 msgstr "Arbre erroné dans la liste TYPE_FIELDS"
 
-#: tree.c:13787
+#: tree.c:13791
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is %i while TYPE_CACHED_VALUES is %p"
 msgstr "TYPE_CACHED_VALUES_P est %i tandis que TYPE_CACHED_VALUES est %p"
 
-#: tree.c:13793
+#: tree.c:13797
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES is not TREE_VEC"
 msgstr "TYPE_CACHED_VALUES n'est pas TREE_VEC"
 
-#: tree.c:13806
+#: tree.c:13810
 #, gcc-internal-format
 msgid "wrong TYPE_CACHED_VALUES entry"
 msgstr "mauvaise entrée TYPE_CACHED_VALUES"
 
-#: tree.c:13819
+#: tree.c:13823
 #, gcc-internal-format
 msgid "TREE_PURPOSE is non-NULL in TYPE_ARG_TYPES list"
 msgstr "TREE_PURPOSE n'est pas NULL dans la liste TYPE_ARG_TYPES"
 
-#: tree.c:13825
+#: tree.c:13829
 #, gcc-internal-format
 msgid "Wrong entry in TYPE_ARG_TYPES list"
 msgstr "Entrée erronée dans la liste TYPE_ARG_TYPES"
 
-#: tree.c:13832
+#: tree.c:13836
 #, gcc-internal-format
 msgid "TYPE_VALUES_RAW field is non-NULL"
 msgstr "le champ TYPE_VALUES_RAW n'est pas NULL"
 
-#: tree.c:13844
+#: tree.c:13848
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is set while it should not"
 msgstr "TYPE_CACHED_VALUES_P est défini alors qu'il ne le devrait pas"
 
-#: tree.c:13850
+#: tree.c:13854
 #, gcc-internal-format
 msgid "TYPE_STRING_FLAG is set on wrong type code"
 msgstr "TYPE_STRING_FLAG est défini sur le mauvais code de type"
 
-#: tree.c:13860
+#: tree.c:13864
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not main variant"
 msgstr "TYPE_METHOD_BASETYPE n'est pas la variante principale"
 
-#: tree.c:13867
+#: tree.c:13871
 #, gcc-internal-format
 msgid "verify_type failed"
 msgstr "verify_type a échoué"
@@ -23739,182 +23765,182 @@
 msgid "corrupted value profile: %s profile counter (%d out of %d) inconsistent with basic-block count (%d)"
 msgstr "valeur de profilage corrompue: %s le compteur de profilage (%d sur %d) est inconsistant avec le décompte du bloc de base (%d)"
 
-#: var-tracking.c:7166
+#: var-tracking.c:7184
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded with -fvar-tracking-assignments, retrying without"
 msgstr "la limite de la taille de pistage des variables est dépassée avec -fvar-tracking-assignments, on réessaie sans"
 
-#: var-tracking.c:7170
+#: var-tracking.c:7188
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded"
 msgstr "la limite de la taille de pistage des variables est dépassée"
 
-#: varasm.c:326
+#: varasm.c:337
 #, gcc-internal-format
 msgid "%+qD causes a section type conflict with %qD"
 msgstr "%+qD cause un conflit du type de section avec %qD"
 
-#: varasm.c:329
+#: varasm.c:340
 #, gcc-internal-format
 msgid "section type conflict with %qD"
 msgstr "conflit du type de section avec %qD"
 
-#: varasm.c:334
+#: varasm.c:345
 #, gcc-internal-format
 msgid "%+qD causes a section type conflict"
 msgstr "%+qD cause un conflit du type de section"
 
-#: varasm.c:336
+#: varasm.c:347
 #, gcc-internal-format
 msgid "section type conflict"
 msgstr "conflit du type de section"
 
-#: varasm.c:1019
+#: varasm.c:1030
 #, gcc-internal-format
 msgid "alignment of %q+D is greater than maximum object file alignment %d"
 msgstr "l'alignement de %q+D est plus grand que l'alignement maximal du fichier objet %d"
 
-#: varasm.c:1172
+#: varasm.c:1183
 #, gcc-internal-format
 msgid "only zero initializers are allowed in section %qs"
 msgstr "seuls les initialiseurs à zéro sont autorisés dans la section %qs"
 
-#: varasm.c:1378 varasm.c:1387
+#: varasm.c:1389 varasm.c:1398
 #, gcc-internal-format
 msgid "register name not specified for %q+D"
 msgstr "le nom du registre n'est pas spécifié pour %q+D"
 
-#: varasm.c:1389
+#: varasm.c:1400
 #, gcc-internal-format
 msgid "invalid register name for %q+D"
 msgstr "nom de registre invalide pour %q+D"
 
-#: varasm.c:1391
+#: varasm.c:1402
 #, gcc-internal-format
 msgid "data type of %q+D isn%'t suitable for a register"
 msgstr "le type de données de %q+D ne convient pas pour un registre"
 
-#: varasm.c:1394
+#: varasm.c:1405
 #, gcc-internal-format
 msgid "the register specified for %q+D cannot be accessed by the current target"
 msgstr "le registre spécifié pour %q+D n'est pas accessible par la cible actuelle"
 
-#: varasm.c:1397
+#: varasm.c:1408
 #, gcc-internal-format
 msgid "the register specified for %q+D is not general enough to be used as a register variable"
 msgstr "le registre spécifié pour %q+D n'est pas assez général pour être utilisé comme registre de variable"
 
-#: varasm.c:1400
+#: varasm.c:1411
 #, gcc-internal-format
 msgid "register specified for %q+D isn%'t suitable for data type"
 msgstr "le registre spécifié pour %q+D ne convient pas pour un type de données"
 
-#: varasm.c:1410
+#: varasm.c:1421
 #, gcc-internal-format
 msgid "global register variable has initial value"
 msgstr "la variable-registre globale a une valeur initiale"
 
-#: varasm.c:1414
+#: varasm.c:1425
 #, gcc-internal-format
 msgid "optimization may eliminate reads and/or writes to register variables"
 msgstr "l'optimisation peut éliminer les lectures ou les écritures dans les variables-registres"
 
-#: varasm.c:1460
+#: varasm.c:1471
 #, gcc-internal-format
 msgid "register name given for non-register variable %q+D"
 msgstr "nom de registre donné pour la variable non registre %q+D"
 
-#: varasm.c:1870
+#: varasm.c:1881
 #, gcc-internal-format
 msgid "Patchable function entry > size"
 msgstr "Entrée de fonction patchable > taille"
 
-#: varasm.c:2069
+#: varasm.c:2080
 #, gcc-internal-format
 msgid "thread-local COMMON data not implemented"
 msgstr "les données COMMON locales au thread ne sont pas implémentées"
 
-#: varasm.c:2102
+#: varasm.c:2113
 #, gcc-internal-format
 msgid "requested alignment for %q+D is greater than implemented alignment of %wu"
 msgstr "l'alignement requis pour %q+D est plus grand que l'alignement implémenté de %wu"
 
-#: varasm.c:2205 c/c-decl.c:5027 c/c-parser.c:1534
+#: varasm.c:2216 c/c-decl.c:5027 c/c-parser.c:1534
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t known"
 msgstr "la taille de stockage de %q+D est inconnue"
 
-#: varasm.c:4910
+#: varasm.c:4921
 #, gcc-internal-format
 msgid "initializer for integer/fixed-point value is too complicated"
 msgstr "l'initialiseur pour les valeurs entières/virgules fixes est trop compliqué"
 
-#: varasm.c:4915
+#: varasm.c:4926
 #, gcc-internal-format
 msgid "initializer for floating value is not a floating constant"
 msgstr "l'initialiseur pour une valeur en virgule flottante n'est pas une constante en virgule flottante"
 
-#: varasm.c:5227
+#: varasm.c:5238
 #, gcc-internal-format
 msgid "invalid initial value for member %qE"
 msgstr "valeur initiale invalide pour le membre %qE"
 
-#: varasm.c:5487
+#: varasm.c:5498
 #, gcc-internal-format
 msgid "%+qD declared weak after being used"
 msgstr "%+qD déclaré faible après avoir été utilisé"
 
-#: varasm.c:5539
+#: varasm.c:5550
 #, gcc-internal-format
 msgid "weak declaration of %q+D being applied to a already existing, static definition"
 msgstr "la déclaration faible de %q+D est appliquée à une définition statique qui existe déjà"
 
-#: varasm.c:5575
+#: varasm.c:5586
 #, gcc-internal-format
 msgid "weak declaration of %q+D must be public"
 msgstr "la déclaration faible de %q+D doit être publique"
 
-#: varasm.c:5579
+#: varasm.c:5590
 #, gcc-internal-format
 msgid "weak declaration of %q+D not supported"
 msgstr "la déclaration faible de %q+D n'est pas supportée"
 
-#: varasm.c:5608 varasm.c:5912
+#: varasm.c:5619 varasm.c:5926
 #, gcc-internal-format
 msgid "only weak aliases are supported in this configuration"
 msgstr "seulement les alias faibles sont supportés dans cette configuration"
 
-#: varasm.c:5802
+#: varasm.c:5813
 #, gcc-internal-format
 msgid "weakref is not supported in this configuration"
 msgstr "« weakref » n'est pas supporté par cette configuration"
 
-#: varasm.c:5834
+#: varasm.c:5846
 #, gcc-internal-format
 msgid "ifunc is not supported on this target"
 msgstr "« ifunc » n'est pas supporté sur cette cible"
 
-#: varasm.c:5892
+#: varasm.c:5904
 #, gcc-internal-format
 msgid "weakref %q+D ultimately targets itself"
 msgstr "weakref %q+D pointe vers lui-même en fin de compte"
 
-#: varasm.c:5894
+#: varasm.c:5906
 #, gcc-internal-format
 msgid "weakref %q+D must have static linkage"
 msgstr "weakref %q+D doit avoir une classe de liaison statique"
 
-#: varasm.c:5901
+#: varasm.c:5913
 #, gcc-internal-format
 msgid "alias definitions not supported in this configuration"
 msgstr "les définitions d'alias ne sont pas supportées dans cette configuration"
 
-#: varasm.c:5909
+#: varasm.c:5923
 #, gcc-internal-format
 msgid "ifunc is not supported in this configuration"
 msgstr "« ifunc » n'est pas supporté par cette configuration"
 
-#: varasm.c:6127 config/sol2.c:159 config/i386/winnt.c:265
+#: varasm.c:6141 config/sol2.c:159 config/i386/winnt.c:265
 #, gcc-internal-format
 msgid "visibility attribute not supported in this configuration; ignored"
 msgstr "l'attribut de visibilité n'est pas supporté dans cette configuration; ignoré"
@@ -23990,468 +24016,474 @@
 msgid "bytecode stream: tag %s is not in the expected range [%s, %s]"
 msgstr "flux bytecode: la balise %s n'est pas dans la plage [%s, %s] attendue"
 
-#: c-family/c-attribs.c:529
+#: c-family/c-attribs.c:524
+#, fuzzy, gcc-internal-format
+#| msgid "%qE attribute ignored for %qE"
+msgid "%qE attribute ignored for type %qT"
+msgstr "l'attribut %qE est ignoré pour %qE"
+
+#: c-family/c-attribs.c:536
 #, gcc-internal-format
 msgid "%qE attribute ignored for field of type %qT"
 msgstr "l'attribut %qE est ignoré pour le champ de type %qT"
 
-#: c-family/c-attribs.c:696
+#: c-family/c-attribs.c:706
 #, gcc-internal-format
 msgid "no_sanitize argument not a string"
 msgstr "l'argument de no_sanitize n'est pas une chaîne"
 
 # %qs est remplacé par un texte non traduit: « hot », « cold », « always_inline ».
-#: c-family/c-attribs.c:826 ada/gcc-interface/utils.c:6235
+#: c-family/c-attribs.c:837 ada/gcc-interface/utils.c:6240
 #, gcc-internal-format
 msgid "%qE attribute ignored due to conflict with attribute %qs"
 msgstr "l'attribut %qE est ignoré à cause d'un conflit avec l'attribut %qs"
 
-#: c-family/c-attribs.c:875
+#: c-family/c-attribs.c:886
 #, gcc-internal-format
 msgid "%qE attribute ignored. Use -fcf-protection option to enable it"
 msgstr "l'attribut %qE est ignoré. Utilisez l'option -fcf-protection pour l'activer"
 
 # %qs est remplacé par un texte non traduit: « noinline », « target_clones », « always_inline », « target ».
-#: c-family/c-attribs.c:914 c-family/c-attribs.c:920 c-family/c-attribs.c:3388
-#: c-family/c-attribs.c:3423 c-family/c-attribs.c:3429
+#: c-family/c-attribs.c:925 c-family/c-attribs.c:931 c-family/c-attribs.c:3399
+#: c-family/c-attribs.c:3434 c-family/c-attribs.c:3440
 #, gcc-internal-format
 msgid "%qE attribute ignored due to conflict with %qs attribute"
 msgstr "l'attribut %qE est ignoré à cause d'un conflit avec l'attribut %qs"
 
-#: c-family/c-attribs.c:976 brig/brig-lang.c:482 lto/lto-lang.c:288
+#: c-family/c-attribs.c:987 brig/brig-lang.c:482 lto/lto-lang.c:288
 #, gcc-internal-format
 msgid "%qE attribute has no effect on unit local functions"
 msgstr "l'attribut %qE n'a pas d'effet sur les fonctions locales dans l'unité"
 
-#: c-family/c-attribs.c:1130
+#: c-family/c-attribs.c:1141
 #, gcc-internal-format
 msgid "%qE attribute have effect only on public objects"
 msgstr "l'attribut %qE n'a d'effet que sur les objets publics"
 
-#: c-family/c-attribs.c:1159
+#: c-family/c-attribs.c:1170
 #, gcc-internal-format
 msgid "%qE attribute only affects top level objects"
 msgstr "l'attribut %qE affecte uniquement les objets au niveau le plus haut"
 
-#: c-family/c-attribs.c:1198 c-family/c-attribs.c:2682
+#: c-family/c-attribs.c:1209 c-family/c-attribs.c:2693
 #, gcc-internal-format
 msgid "%qE attribute on function returning %<void%>"
 msgstr "attribut %qE sur une fonction retournant %<void%>"
 
-#: c-family/c-attribs.c:1221 c-family/c-pragma.c:419
+#: c-family/c-attribs.c:1232 c-family/c-pragma.c:419
 #, gcc-internal-format
 msgid "scalar_storage_order is not supported because endianness is not uniform"
 msgstr "scalar_storage_order n'est pas supporté car le boutisme n'est pas uniforme"
 
-#: c-family/c-attribs.c:1238
+#: c-family/c-attribs.c:1249
 #, gcc-internal-format
 msgid "scalar_storage_order argument must be one of \"big-endian\" or \"little-endian\""
 msgstr "l'argument de scalar_storage_order doit être soit « big-endian » ou soit « little-endian »"
 
-#: c-family/c-attribs.c:1334
+#: c-family/c-attribs.c:1345
 #, gcc-internal-format
 msgid "destructor priorities are not supported"
 msgstr "les priorités des destructeurs ne sont pas supportées"
 
-#: c-family/c-attribs.c:1336
+#: c-family/c-attribs.c:1347
 #, gcc-internal-format
 msgid "constructor priorities are not supported"
 msgstr "les priorités des constructeurs ne sont pas supportées"
 
-#: c-family/c-attribs.c:1358
+#: c-family/c-attribs.c:1369
 #, gcc-internal-format, gfc-internal-format
 msgid "destructor priorities from 0 to %d are reserved for the implementation"
 msgstr "les priorités des destructeurs entre 0 et %d sont réservées pour l'implémentation"
 
-#: c-family/c-attribs.c:1363
+#: c-family/c-attribs.c:1374
 #, gcc-internal-format, gfc-internal-format
 msgid "constructor priorities from 0 to %d are reserved for the implementation"
 msgstr "les priorités des constructeurs entre 0 et %d sont réservées pour l'implémentation"
 
-#: c-family/c-attribs.c:1371
+#: c-family/c-attribs.c:1382
 #, gcc-internal-format, gfc-internal-format
 msgid "destructor priorities must be integers from 0 to %d inclusive"
 msgstr "les priorités des destructeurs doivent être des entiers entre 0 et %d inclus"
 
-#: c-family/c-attribs.c:1374
+#: c-family/c-attribs.c:1385
 #, gcc-internal-format, gfc-internal-format
 msgid "constructor priorities must be integers from 0 to %d inclusive"
 msgstr "les priorités des constructeurs doivent être des entiers entre 0 et %d inclus"
 
-#: c-family/c-attribs.c:1527
+#: c-family/c-attribs.c:1538
 #, gcc-internal-format
 msgid "unknown machine mode %qE"
 msgstr "mode machine %qE inconnu"
 
-#: c-family/c-attribs.c:1557
+#: c-family/c-attribs.c:1568
 #, gcc-internal-format
 msgid "specifying vector types with __attribute__ ((mode)) is deprecated"
 msgstr "spécifier les types vectoriels avec __attribute__ ((mode)) est obsolète"
 
-#: c-family/c-attribs.c:1560
+#: c-family/c-attribs.c:1571
 #, gcc-internal-format
 msgid "use __attribute__ ((vector_size)) instead"
 msgstr "utilisez __attribute__ ((vector_size)) à la place"
 
-#: c-family/c-attribs.c:1569
+#: c-family/c-attribs.c:1580
 #, gcc-internal-format
 msgid "unable to emulate %qs"
 msgstr "impossible d'émuler %qs"
 
-#: c-family/c-attribs.c:1582
+#: c-family/c-attribs.c:1593
 #, gcc-internal-format
 msgid "invalid pointer mode %qs"
 msgstr "mode pointeur %qs invalide"
 
-#: c-family/c-attribs.c:1599
+#: c-family/c-attribs.c:1610
 #, gcc-internal-format
 msgid "signedness of type and machine mode %qs don%'t match"
 msgstr "la plage signée du type et le mode machine %qs ne correspondent pas"
 
-#: c-family/c-attribs.c:1610
+#: c-family/c-attribs.c:1621
 #, gcc-internal-format
 msgid "no data type for mode %qs"
 msgstr "aucun type de données pour le mode %qs"
 
-#: c-family/c-attribs.c:1620
+#: c-family/c-attribs.c:1631
 #, gcc-internal-format
 msgid "cannot use mode %qs for enumeral types"
 msgstr "impossible d'utiliser le mode %qs pour des types énumérés"
 
-#: c-family/c-attribs.c:1647
+#: c-family/c-attribs.c:1658
 #, gcc-internal-format
 msgid "mode %qs applied to inappropriate type"
 msgstr "mode %qs appliqué à un type inapproprié"
 
-#: c-family/c-attribs.c:1669
+#: c-family/c-attribs.c:1680
 #, gcc-internal-format
 msgid "section attributes are not supported for this target"
 msgstr "les attributs de sections ne sont pas supportés pour cette cible"
 
-#: c-family/c-attribs.c:1675
+#: c-family/c-attribs.c:1686
 #, gcc-internal-format
 msgid "section attribute not allowed for %q+D"
 msgstr "l'attribut de section n'est pas permis pour %q+D"
 
-#: c-family/c-attribs.c:1681
+#: c-family/c-attribs.c:1692
 #, gcc-internal-format
 msgid "section attribute argument not a string constant"
 msgstr "l'argument de l'attribut de section n'est pas une constante de type chaîne de caractères"
 
-#: c-family/c-attribs.c:1690
+#: c-family/c-attribs.c:1701
 #, gcc-internal-format
 msgid "section attribute cannot be specified for local variables"
 msgstr "l'attribut de section ne peut pas être spécifié pour des variables locales"
 
-#: c-family/c-attribs.c:1700 config/bfin/bfin.c:4806 config/bfin/bfin.c:4857
+#: c-family/c-attribs.c:1711 config/bfin/bfin.c:4806 config/bfin/bfin.c:4857
 #: config/bfin/bfin.c:4883 config/bfin/bfin.c:4896
 #, gcc-internal-format
 msgid "section of %q+D conflicts with previous declaration"
 msgstr "la section de %q+D est en conflit avec la déclaration précédente"
 
-#: c-family/c-attribs.c:1708
+#: c-family/c-attribs.c:1719
 #, gcc-internal-format
 msgid "section of %q+D cannot be overridden"
 msgstr "la section de %q+D ne peut pas être contournée"
 
-#: c-family/c-attribs.c:1773
+#: c-family/c-attribs.c:1784
 #, gcc-internal-format, gfc-internal-format
 msgid "requested alignment %d is larger than %d"
 msgstr "l'alignement %d demandé est plus grand que %d"
 
-#: c-family/c-attribs.c:1866
+#: c-family/c-attribs.c:1877
 #, gcc-internal-format
 msgid "alignment may not be specified for %q+D"
 msgstr "l'alignement ne peut pas être spécifié pour %q+D"
 
-#: c-family/c-attribs.c:1886
+#: c-family/c-attribs.c:1897
 #, gcc-internal-format
 msgid "ignoring attribute %<%E (%u)%> because it conflicts with attribute %<%E (%u)%>"
 msgstr "l'attribut %<%E (%u)%> ignoré car il est en conflit avec l'attribut %<%E (%u)%>"
 
 #. Do not error out for attribute warn_if_not_aligned.
-#: c-family/c-attribs.c:1891 c-family/c-attribs.c:1920
+#: c-family/c-attribs.c:1902 c-family/c-attribs.c:1931
 #, gcc-internal-format
 msgid "alignment for %q+D must be at least %d"
 msgstr "l'alignement pour %q+D doit être au moins %d"
 
-#: c-family/c-attribs.c:1916
+#: c-family/c-attribs.c:1927
 #, gcc-internal-format
 msgid "alignment for %q+D was previously specified as %d and may not be decreased"
 msgstr "l'alignement pour %q+D a été précédemment spécifié comme étant %d et ne peut plus être diminué"
 
-#: c-family/c-attribs.c:1943
+#: c-family/c-attribs.c:1954
 #, gcc-internal-format
 msgid "%<warn_if_not_aligned%> may not be specified for %q+D"
 msgstr "%<warn_if_not_aligned%> ne peut pas être spécifié pour %q+D"
 
-#: c-family/c-attribs.c:1986
+#: c-family/c-attribs.c:1997
 #, gcc-internal-format
 msgid "inline function %q+D declared weak"
 msgstr "la fonction « inline » %q+D est déclarée faible"
 
-#: c-family/c-attribs.c:1991
+#: c-family/c-attribs.c:2002
 #, gcc-internal-format
 msgid "indirect function %q+D cannot be declared weak"
 msgstr "la fonction indirecte %q+D ne peut pas être déclarée faible"
 
-#: c-family/c-attribs.c:2015
+#: c-family/c-attribs.c:2026
 #, gcc-internal-format
 msgid "%qE attribute is only applicable on functions"
 msgstr "l'attribut %qE s'applique uniquement aux fonctions"
 
-#: c-family/c-attribs.c:2046
+#: c-family/c-attribs.c:2057
 #, gcc-internal-format
 msgid "%q+D defined both normally and as %qE attribute"
 msgstr "%q+D est défini à la fois normalement et en tant qu'attribut %qE"
 
-#: c-family/c-attribs.c:2054
+#: c-family/c-attribs.c:2065
 #, gcc-internal-format
 msgid "weak %q+D cannot be defined %qE"
 msgstr "le %q+D faible ne peut pas être défini %qE"
 
-#: c-family/c-attribs.c:2071 c-family/c-attribs.c:2582
+#: c-family/c-attribs.c:2082 c-family/c-attribs.c:2593
 #, gcc-internal-format
 msgid "attribute %qE argument not a string"
 msgstr "l'argument de l'attribut %qE n'est pas une chaîne"
 
-#: c-family/c-attribs.c:2106
+#: c-family/c-attribs.c:2117
 #, gcc-internal-format
 msgid "%+qD declared alias after being used"
 msgstr "%+qD est déclaré comme un alias après avoir été utilisé"
 
-#: c-family/c-attribs.c:2108
+#: c-family/c-attribs.c:2119
 #, gcc-internal-format
 msgid "%+qD declared ifunc after being used"
 msgstr "%+qD est déclaré « ifunc » après avoir été utilisé"
 
-#: c-family/c-attribs.c:2159
+#: c-family/c-attribs.c:2170
 #, gcc-internal-format
 msgid "indirect function %q+D cannot be declared weakref"
 msgstr "la fonction indirecte %q+D ne peut pas être déclarée « weakref »"
 
-#: c-family/c-attribs.c:2181
+#: c-family/c-attribs.c:2192
 #, gcc-internal-format
 msgid "weakref attribute must appear before alias attribute"
 msgstr "l'attribut « weakref » doit apparaître avant l'attribut « alias »"
 
-#: c-family/c-attribs.c:2193
+#: c-family/c-attribs.c:2204
 #, gcc-internal-format
 msgid "%+qD declared weakref after being used"
 msgstr "%+qD est déclaré « weakref » après avoir été utilisé"
 
-#: c-family/c-attribs.c:2217
+#: c-family/c-attribs.c:2228
 #, gcc-internal-format
 msgid "%qE attribute ignored on non-class types"
 msgstr "l'attribut %qE est ignoré pour un type qui n'est pas une classe"
 
-#: c-family/c-attribs.c:2223
+#: c-family/c-attribs.c:2234
 #, gcc-internal-format
 msgid "%qE attribute ignored because %qT is already defined"
 msgstr "l'attribut %qE est ignoré car %qT est déjà défini"
 
-#: c-family/c-attribs.c:2236
+#: c-family/c-attribs.c:2247
 #, gcc-internal-format
 msgid "visibility argument not a string"
 msgstr "l'argument de visibilité n'est pas une chaîne"
 
-#: c-family/c-attribs.c:2248
+#: c-family/c-attribs.c:2259
 #, gcc-internal-format
 msgid "%qE attribute ignored on types"
 msgstr "l'attribut %qE est ignoré sur les types"
 
-#: c-family/c-attribs.c:2264
+#: c-family/c-attribs.c:2275
 #, gcc-internal-format
 msgid "visibility argument must be one of \"default\", \"hidden\", \"protected\" or \"internal\""
 msgstr "l'argument de visibilité doit être l'un de « default » (par défaut), « hidden » (masqué), « protected » (protégé) ou « internal » (interne)"
 
-#: c-family/c-attribs.c:2275
+#: c-family/c-attribs.c:2286
 #, gcc-internal-format
 msgid "%qD redeclared with different visibility"
 msgstr "%qD est redéclaré avec une visibilité différente"
 
-#: c-family/c-attribs.c:2278 c-family/c-attribs.c:2282
+#: c-family/c-attribs.c:2289 c-family/c-attribs.c:2293
 #, gcc-internal-format
 msgid "%qD was declared %qs which implies default visibility"
 msgstr "%qD a été déclaré %qs ce qui implique la visibilité par défaut"
 
-#: c-family/c-attribs.c:2320
+#: c-family/c-attribs.c:2331
 #, gcc-internal-format
 msgid "tls_model argument not a string"
 msgstr "l'argument de tls_model n'est pas une chaîne"
 
-#: c-family/c-attribs.c:2333
+#: c-family/c-attribs.c:2344
 #, gcc-internal-format
 msgid "tls_model argument must be one of \"local-exec\", \"initial-exec\", \"local-dynamic\" or \"global-dynamic\""
 msgstr "l'argument de tls_model doit être l'une des valeurs « local-exec », « initial-exec », « local-dynamic » ou « global-dynamic »"
 
-#: c-family/c-attribs.c:2353 c-family/c-attribs.c:2656
-#: c-family/c-attribs.c:3497 config/m32c/m32c.c:2944
+#: c-family/c-attribs.c:2364 c-family/c-attribs.c:2667
+#: c-family/c-attribs.c:3508 config/m32c/m32c.c:2944
 #, gcc-internal-format
 msgid "%qE attribute applies only to functions"
 msgstr "l'attribut %qE ne s'applique qu'à des fonctions"
 
-#: c-family/c-attribs.c:2417
+#: c-family/c-attribs.c:2428
 #, gcc-internal-format
 msgid "alloc_size parameter outside range"
 msgstr "le paramètre alloc_size est hors limites"
 
-#: c-family/c-attribs.c:2443
+#: c-family/c-attribs.c:2454
 #, gcc-internal-format
 msgid "alloc_align parameter outside range"
 msgstr "le paramètre alloc_align est hors limites"
 
-#: c-family/c-attribs.c:2467
+#: c-family/c-attribs.c:2478
 #, gcc-internal-format
 msgid "assume_aligned parameter not integer constant"
 msgstr "le paramètre de assume_aligned n'est pas une constante entière"
 
-#: c-family/c-attribs.c:2595
+#: c-family/c-attribs.c:2606
 #, gcc-internal-format
 msgid "only %<inbranch%> and %<notinbranch%> flags are allowed for %<__simd__%> attribute"
 msgstr "seuls les fanions %<inbranch%> et %<notinbranch%> sont permis pour l'attribut %<__simd__%>"
 
-#: c-family/c-attribs.c:2662 c-family/c-attribs.c:3503
+#: c-family/c-attribs.c:2673 c-family/c-attribs.c:3514
 #, gcc-internal-format
 msgid "can%'t set %qE attribute after definition"
 msgstr "l'attribut %qE ne peut pas être appliqué après la définition"
 
-#: c-family/c-attribs.c:2727
+#: c-family/c-attribs.c:2738
 #, gcc-internal-format
 msgid "%qE attribute duplicated"
 msgstr "attribut %qE dupliqué"
 
-#: c-family/c-attribs.c:2729
+#: c-family/c-attribs.c:2740
 #, gcc-internal-format
 msgid "%qE attribute follows %qE"
 msgstr "l'attribut %qE suit %qE"
 
-#: c-family/c-attribs.c:2828
+#: c-family/c-attribs.c:2839
 #, gcc-internal-format
 msgid "type was previously declared %qE"
 msgstr "le type a été précédemment déclaré %qE"
 
-#: c-family/c-attribs.c:2841 cp/class.c:4397
+#: c-family/c-attribs.c:2852 cp/class.c:4401
 #, gcc-internal-format
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
 msgstr "%<transaction_safe_dynamic%> ne peut être spécifié que pour une fonction virtuelle"
 
-#: c-family/c-attribs.c:2899
+#: c-family/c-attribs.c:2910
 #, gcc-internal-format
 msgid "%qE argument not an identifier"
 msgstr "l'argument %qE n'est pas un identificateur"
 
-#: c-family/c-attribs.c:2910
+#: c-family/c-attribs.c:2921
 #, gcc-internal-format
 msgid "%qD is not compatible with %qD"
 msgstr "%qD n'est pas compatible avec %qD"
 
-#: c-family/c-attribs.c:2913
+#: c-family/c-attribs.c:2924
 #, gcc-internal-format
 msgid "%qE argument is not a function"
 msgstr "l'argument de %qE n'est pas une fonction"
 
-#: c-family/c-attribs.c:2961
+#: c-family/c-attribs.c:2972
 #, gcc-internal-format
 msgid "deprecated message is not a string"
 msgstr "le message déprécié n'est pas une chaîne"
 
-#: c-family/c-attribs.c:3002
+#: c-family/c-attribs.c:3013
 #, gcc-internal-format
 msgid "%qE attribute ignored for %qE"
 msgstr "l'attribut %qE est ignoré pour %qE"
 
-#: c-family/c-attribs.c:3065
+#: c-family/c-attribs.c:3076
 #, gcc-internal-format
 msgid "invalid vector type for attribute %qE"
 msgstr "type de vecteur invalide pour l'attribut %qE"
 
-#: c-family/c-attribs.c:3071 ada/gcc-interface/utils.c:3896
+#: c-family/c-attribs.c:3082 ada/gcc-interface/utils.c:3899
 #, gcc-internal-format
 msgid "vector size not an integral multiple of component size"
 msgstr "la taille du vecteur n'est pas un multiple entier de la taille des éléments"
 
-#: c-family/c-attribs.c:3077 ada/gcc-interface/utils.c:3903
+#: c-family/c-attribs.c:3088 ada/gcc-interface/utils.c:3906
 #, gcc-internal-format
 msgid "zero vector size"
 msgstr "vecteur de taille nulle"
 
-#: c-family/c-attribs.c:3085
+#: c-family/c-attribs.c:3096
 #, gcc-internal-format
 msgid "number of components of the vector not a power of two"
 msgstr "le nombre d'éléments du vecteur n'est pas une puissance de deux"
 
-#: c-family/c-attribs.c:3118 ada/gcc-interface/utils.c:6092
+#: c-family/c-attribs.c:3129 ada/gcc-interface/utils.c:6098
 #, gcc-internal-format
 msgid "nonnull attribute without arguments on a non-prototype"
 msgstr "attribut non nul sans argument sur un non-prototype"
 
-#: c-family/c-attribs.c:3137 ada/gcc-interface/utils.c:6106
+#: c-family/c-attribs.c:3148 ada/gcc-interface/utils.c:6112
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument has invalid operand number (argument %lu)"
 msgstr "un argument non nul a un numéro d'opérande invalide (argument %lu)"
 
-#: c-family/c-attribs.c:3159 ada/gcc-interface/utils.c:6128
+#: c-family/c-attribs.c:3170 ada/gcc-interface/utils.c:6134
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument with out-of-range operand number (argument %lu, operand %lu)"
 msgstr "un argument non nul a un numéro d'opérande hors des bornes (argument %lu, opérande %lu)"
 
-#: c-family/c-attribs.c:3168 ada/gcc-interface/utils.c:6137
+#: c-family/c-attribs.c:3179 ada/gcc-interface/utils.c:6143
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument references non-pointer operand (argument %lu, operand %lu)"
 msgstr "un argument non nul référence un opérande qui n'est pas un pointeur (argument %lu, opérande %lu)"
 
-#: c-family/c-attribs.c:3208
+#: c-family/c-attribs.c:3219
 #, gcc-internal-format
 msgid "%qE attribute ignored on objects of type %qT"
 msgstr "l'attribut %qE est ignoré pour l'objet de type %qT"
 
-#: c-family/c-attribs.c:3216
+#: c-family/c-attribs.c:3227
 #, gcc-internal-format
 msgid "%qE attribute does not apply to functions"
 msgstr "l'attribut %qE ne s'applique pas aux fonctions"
 
-#: c-family/c-attribs.c:3273
+#: c-family/c-attribs.c:3284
 #, gcc-internal-format
 msgid "cleanup argument not an identifier"
 msgstr "l'argument de nettoyage n'est pas un identificateur"
 
-#: c-family/c-attribs.c:3280
+#: c-family/c-attribs.c:3291
 #, gcc-internal-format
 msgid "cleanup argument not a function"
 msgstr "l'argument de nettoyage n'est pas une fonction"
 
-#: c-family/c-attribs.c:3317
+#: c-family/c-attribs.c:3328
 #, gcc-internal-format
 msgid "%qE attribute requires prototypes with named arguments"
 msgstr "l'attribut %qE exige des prototypes avec des arguments nommés"
 
-#: c-family/c-attribs.c:3325
+#: c-family/c-attribs.c:3336
 #, gcc-internal-format
 msgid "%qE attribute only applies to variadic functions"
 msgstr "l'attribut %qE s'applique uniquement aux fonctions variadiques"
 
-#: c-family/c-attribs.c:3341 ada/gcc-interface/utils.c:6179
+#: c-family/c-attribs.c:3352 ada/gcc-interface/utils.c:6185
 #, gcc-internal-format
 msgid "requested position is not an integer constant"
 msgstr "la position demandée n'est pas une constante entière"
 
-#: c-family/c-attribs.c:3349 ada/gcc-interface/utils.c:6186
+#: c-family/c-attribs.c:3360 ada/gcc-interface/utils.c:6192
 #, gcc-internal-format
 msgid "requested position is less than zero"
 msgstr "la position demandée est plus petite que zéro"
 
-#: c-family/c-attribs.c:3404
+#: c-family/c-attribs.c:3415
 #, gcc-internal-format
 msgid "empty string in attribute %<target%>"
 msgstr "chaîne vide dans l'attribut %<target%>"
 
-#: c-family/c-attribs.c:3520
+#: c-family/c-attribs.c:3531
 #, gcc-internal-format
 msgid "returns_nonnull attribute on a function not returning a pointer"
 msgstr "attribut returns_nonnull sur une fonction qui ne retourne pas un pointeur"
 
-#: c-family/c-attribs.c:3535
+#: c-family/c-attribs.c:3546
 #, gcc-internal-format
 msgid "%qE attribute is only valid on %<struct%> type"
 msgstr "l'attribut %qE est uniquement valable sur un type %<struct%>"
@@ -24496,12 +24528,12 @@
 msgid "__builtin_shuffle argument vector(s) inner type must have the same size as inner type of the mask"
 msgstr "le type intérieur du/des argument(s) vectoriel(s) de __builtin_shuffle doivent avoir la même taille que le type intérieur du masque"
 
-#: c-family/c-common.c:1262 c-family/c-warn.c:1194
+#: c-family/c-common.c:1262 c-family/c-warn.c:1202
 #, gcc-internal-format
 msgid "unsigned conversion from %qT to %qT changes value from %qE to %qE"
 msgstr "la conversion non-signée de %qT vers %qT change la valeur de %qE en %qE"
 
-#: c-family/c-common.c:1267 c-family/c-warn.c:1202
+#: c-family/c-common.c:1267 c-family/c-warn.c:1210
 #, gcc-internal-format
 msgid "unsigned conversion from %qT to %qT changes the value of %qE"
 msgstr "la conversion non-signée de %qT vers %qT change la valeur de %qE"
@@ -24631,7 +24663,7 @@
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "parenthèses suggérées autour de l'affectation utilisée comme valeur dans une condition"
 
-#: c-family/c-common.c:3518 c/c-decl.c:4325 c/c-decl.c:6430 c/c-typeck.c:14177
+#: c-family/c-common.c:3518 c/c-decl.c:4325 c/c-decl.c:6450 c/c-typeck.c:14182
 #, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr "usage de %<restrict%> invalide"
@@ -24712,7 +24744,7 @@
 msgstr "valeur du « case » dupliquée"
 
 # ce message fait référence à une valeur (dans c-common.c) ou une condition (c-warn.c), d'où le féminin
-#: c-family/c-common.c:4867 c-family/c-warn.c:2216
+#: c-family/c-common.c:4867 c-family/c-warn.c:2225
 #, gcc-internal-format
 msgid "previously used here"
 msgstr "précédemment utilisée ici"
@@ -24757,193 +24789,193 @@
 msgid "missing sentinel in function call"
 msgstr "sentinelle manquante dans l'appel à la fonction"
 
-#: c-family/c-common.c:5411
+#: c-family/c-common.c:5409
 #, gcc-internal-format, gfc-internal-format
 msgid "null argument where non-null required (argument %lu)"
 msgstr "argument nul là où un non-nul est requis (argument %lu)"
 
-#: c-family/c-common.c:5506 c-family/c-common.c:5553
+#: c-family/c-common.c:5504 c-family/c-common.c:5551
 #, gcc-internal-format
 msgid "bad option %qs to attribute %<optimize%>"
 msgstr "mauvaise option %qs pour l'attribut %<optimize%>"
 
-#: c-family/c-common.c:5509 c-family/c-common.c:5557
+#: c-family/c-common.c:5507 c-family/c-common.c:5555
 #, gcc-internal-format
 msgid "bad option %qs to pragma %<optimize%>"
 msgstr "mauvaise option %qs pour le pragma %<optimize%>"
 
-#: c-family/c-common.c:5589
+#: c-family/c-common.c:5587
 #, gcc-internal-format
 msgid "%<fallthrough%> attribute specified multiple times"
 msgstr "l'attribut %<fallthrough%> est spécifié plusieurs fois"
 
-#: c-family/c-common.c:5593
+#: c-family/c-common.c:5591
 #, gcc-internal-format
 msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr "l'attribut %<fallthrough%> est spécifié avec un paramètre"
 
-#: c-family/c-common.c:5733 c-family/c-common.c:6485 c-family/c-common.c:6558
+#: c-family/c-common.c:5731 c-family/c-common.c:6477 c-family/c-common.c:6550
 #: c/c-typeck.c:3555
 #, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr "trop peu d'arguments pour la fonction %qE"
 
-#: c-family/c-common.c:5738 c-family/c-common.c:6584 c/c-typeck.c:3284
+#: c-family/c-common.c:5736 c-family/c-common.c:6576 c/c-typeck.c:3284
 #, gcc-internal-format
 msgid "too many arguments to function %qE"
 msgstr "trop d'arguments pour la fonction %qE"
 
-#: c-family/c-common.c:5769
+#: c-family/c-common.c:5767
 #, gcc-internal-format
 msgid "third argument to function %qE must be a constant integer"
 msgstr "le troisième argument de la fonction %qE doit être une constante entière"
 
-#: c-family/c-common.c:5794
+#: c-family/c-common.c:5792
 #, gcc-internal-format
 msgid "second argument to function %qE must be a constant integer power of 2 between %qi and %qu bits"
 msgstr "le deuxième argument de la fonction %qE doit être une constante entière qui est une puissance de 2 comprise entre %qi et %qu bits"
 
-#: c-family/c-common.c:5815 c-family/c-common.c:5859
+#: c-family/c-common.c:5813 c-family/c-common.c:5857
 #, gcc-internal-format
 msgid "non-floating-point argument in call to function %qE"
 msgstr "l'argument dans l'appel de la fonction %qE n'est pas en virgule flottante"
 
-#: c-family/c-common.c:5838
+#: c-family/c-common.c:5836
 #, gcc-internal-format
 msgid "non-floating-point arguments in call to function %qE"
 msgstr "l'argument dans l'appel de la fonction %qE n'est pas en virgule flottante"
 
-#: c-family/c-common.c:5852
+#: c-family/c-common.c:5850
 #, gcc-internal-format
 msgid "non-const integer argument %u in call to function %qE"
 msgstr "argument entier non constant %u dans l'appel à la fonction %qE"
 
-#: c-family/c-common.c:5872
+#: c-family/c-common.c:5870
 #, gcc-internal-format
 msgid "non-integer argument 3 in call to function %qE"
 msgstr "argument 3 non entier dans l'appel à la fonction %qE"
 
-#: c-family/c-common.c:5889 c-family/c-common.c:5925
+#: c-family/c-common.c:5887 c-family/c-common.c:5923
 #, gcc-internal-format
 msgid "argument %u in call to function %qE does not have integral type"
 msgstr "l'argument %u dans l'appel à la fonction %qE n'a pas un type intégral"
 
-#: c-family/c-common.c:5896
+#: c-family/c-common.c:5894
 #, gcc-internal-format
 msgid "argument 3 in call to function %qE does not have pointer to integral type"
 msgstr "l'argument 3 dans l'appel à la fonction %qE n'est pas un pointeur vers un type intégral"
 
-#: c-family/c-common.c:5902
+#: c-family/c-common.c:5900
 #, gcc-internal-format
 msgid "argument 3 in call to function %qE has pointer to enumerated type"
 msgstr "l'argument 3 dans l'appel à la fonction %qE est un pointeur vers un type énuméré"
 
-#: c-family/c-common.c:5908
+#: c-family/c-common.c:5906
 #, gcc-internal-format
 msgid "argument 3 in call to function %qE has pointer to boolean type"
 msgstr "l'argument 3 dans l'appel à la fonction %qE est un pointeur vers un type booléen"
 
-#: c-family/c-common.c:5931
+#: c-family/c-common.c:5929
 #, gcc-internal-format
 msgid "argument 3 in call to function %qE has enumerated type"
 msgstr "l'argument 3 dans l'appel à la fonction %qE est un type énuméré"
 
-#: c-family/c-common.c:5937
+#: c-family/c-common.c:5935
 #, gcc-internal-format
 msgid "argument 3 in call to function %qE has boolean type"
 msgstr "l'argument 3 dans l'appel à la fonction %qE est un type booléen"
 
-#: c-family/c-common.c:6184
+#: c-family/c-common.c:6183
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to static data member %qD"
 msgstr "%<offsetof%> ne peut être appliqué au membre de données statique %qD"
 
-#: c-family/c-common.c:6189
+#: c-family/c-common.c:6188
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> when %<operator[]%> is overloaded"
 msgstr "%<offsetof%> ne peut être appliqué quand %<operator[]%> est surchargé"
 
-#: c-family/c-common.c:6196
+#: c-family/c-common.c:6195
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to a non constant address"
 msgstr "%<offsetof%> ne peut être appliqué à une adresse non constante"
 
-#: c-family/c-common.c:6209
+#: c-family/c-common.c:6208
 #, gcc-internal-format
 msgid "attempt to take address of bit-field structure member %qD"
 msgstr "tentative de prendre l'adresse du membre %qD qui est un champ de bits d'une structure"
 
-#: c-family/c-common.c:6261
+#: c-family/c-common.c:6260
 #, gcc-internal-format
 msgid "index %E denotes an offset greater than size of %qT"
 msgstr "l'index %E désigne un offset plus grand que la taille de %qT"
 
-#: c-family/c-common.c:6427 cp/init.c:3004 cp/init.c:3023
+#: c-family/c-common.c:6419 cp/init.c:3020 cp/init.c:3039
 #, gcc-internal-format
 msgid "size of array is too large"
 msgstr "la taille du tableau est trop grande"
 
-#: c-family/c-common.c:6517
+#: c-family/c-common.c:6509
 #, gcc-internal-format
 msgid "operand type %qT is incompatible with argument %d of %qE"
 msgstr "le type %qT de l'opérande est incompatible avec l'argument %d de %qE"
 
-#: c-family/c-common.c:6651
+#: c-family/c-common.c:6643
 #, gcc-internal-format
 msgid "incorrect number of arguments to function %qE"
 msgstr "nombre d'arguments incorrect pour la fonction %qE"
 
-#: c-family/c-common.c:6665
+#: c-family/c-common.c:6657
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a non-void pointer type"
 msgstr "l'argument 1 de %qE doit être un type pointeur non void"
 
-#: c-family/c-common.c:6674
+#: c-family/c-common.c:6666
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a constant size type"
 msgstr "l'argument 1 de %qE doit être un pointeur vers un type ayant une taille constante"
 
-#: c-family/c-common.c:6685
+#: c-family/c-common.c:6677
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a nonzero size object"
 msgstr "l'argument 1 de %qE doit être un pointeur vers un objet de taille non nulle"
 
-#: c-family/c-common.c:6706
+#: c-family/c-common.c:6698
 #, gcc-internal-format
 msgid "argument %d of %qE must be a pointer type"
 msgstr "l'argument %d de %qE doit être un type pointeur"
 
-#: c-family/c-common.c:6714
+#: c-family/c-common.c:6706
 #, gcc-internal-format
 msgid "argument %d of %qE must be a pointer to a constant size type"
 msgstr "l'argument %d de %qE doit être un pointeur vers un type ayant une taille constante"
 
-#: c-family/c-common.c:6720
+#: c-family/c-common.c:6712
 #, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a function"
 msgstr "l'argument %d de %qE doit être un pointeur vers une fonction"
 
-#: c-family/c-common.c:6728
+#: c-family/c-common.c:6720
 #, gcc-internal-format
 msgid "size mismatch in argument %d of %qE"
 msgstr "désaccord de taille dans l'argument %d de %qE"
 
-#: c-family/c-common.c:6740
+#: c-family/c-common.c:6732
 #, gcc-internal-format
 msgid "non-integer memory model argument %d of %qE"
 msgstr "modèle mémoire non entier pour l'argument %d de %qE"
 
-#: c-family/c-common.c:6753
+#: c-family/c-common.c:6745
 #, gcc-internal-format
 msgid "invalid memory model argument %d of %qE"
 msgstr "modèle mémoire invalide pour l'argument %d de %qE"
 
-#: c-family/c-common.c:7672
+#: c-family/c-common.c:7664
 #, gcc-internal-format
 msgid "index value is out of bound"
 msgstr "la valeur de l'index est hors limites"
 
-#: c-family/c-common.c:7714 c-family/c-common.c:7763 c-family/c-common.c:7779
+#: c-family/c-common.c:7706 c-family/c-common.c:7755 c-family/c-common.c:7771
 #, gcc-internal-format
 msgid "conversion of scalar %qT to vector %qT involves truncation"
 msgstr "la conversion du scalaire %qT vers le vecteur %qT implique une troncature"
@@ -24950,22 +24982,22 @@
 
 #. Reject arguments that are built-in functions with
 #. no library fallback.
-#: c-family/c-common.c:7867
+#: c-family/c-common.c:7859
 #, gcc-internal-format
 msgid "built-in function %qE must be directly called"
 msgstr "la fonction interne %qE doit être appelée directement"
 
-#: c-family/c-common.c:7889 c/c-decl.c:6177
+#: c-family/c-common.c:7881 c/c-decl.c:6197
 #, gcc-internal-format
 msgid "size of array %qE is too large"
 msgstr "la taille du tableau %qE est trop grande"
 
-#: c-family/c-common.c:7891 c/c-decl.c:6180
+#: c-family/c-common.c:7883 c/c-decl.c:6200
 #, gcc-internal-format
 msgid "size of unnamed array is too large"
 msgstr "la taille du tableau sans nom est trop grande"
 
-#: c-family/c-common.c:7921
+#: c-family/c-common.c:7913
 #, gcc-internal-format
 msgid "environment variable SOURCE_DATE_EPOCH must expand to a non-negative integer less than or equal to %wd"
 msgstr "la variable d'environnement SOURCE_DATE_EPOCH doit fournir un entier non négatif plus petit que ou égal à %wd"
@@ -25487,7 +25519,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr "%<#pragma omp atomic capture%> utilise deux variables différentes pour la mémoire"
 
-#: c-family/c-omp.c:557 cp/semantics.c:8186
+#: c-family/c-omp.c:557 cp/semantics.c:8189
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "type invalide pour la variable d'itération %qE"
@@ -25502,22 +25534,22 @@
 msgid "%qE is not initialized"
 msgstr "%qE n'est pas initialisé"
 
-#: c-family/c-omp.c:599 cp/semantics.c:8076
+#: c-family/c-omp.c:599 cp/semantics.c:8079
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "prédicat de contrôle manquant"
 
-#: c-family/c-omp.c:704 cp/semantics.c:7732
+#: c-family/c-omp.c:704 cp/semantics.c:7735
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "prédicat de contrôle invalide"
 
-#: c-family/c-omp.c:711 cp/semantics.c:8082
+#: c-family/c-omp.c:711 cp/semantics.c:8085
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "expression d'incrémentation manquante"
 
-#: c-family/c-omp.c:775 cp/semantics.c:7847
+#: c-family/c-omp.c:775 cp/semantics.c:7850
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "expression d'incrémentation invalide"
@@ -25572,112 +25604,127 @@
 msgid "%<-Wabi=1%> is not supported, using =2"
 msgstr "%<-Wabi=1%> n'est pas supporté, on utilise =2"
 
-#: c-family/c-opts.c:612 fortran/cpp.c:350
+#: c-family/c-opts.c:610 fortran/cpp.c:350
 #, gcc-internal-format
 msgid "output filename specified twice"
 msgstr "nom du fichier de sortie spécifié deux fois"
 
-#: c-family/c-opts.c:799
+#: c-family/c-opts.c:797
 #, gcc-internal-format
 msgid "-fexcess-precision=standard for C++"
 msgstr "-fexcess-precision=standard pour C++"
 
-#: c-family/c-opts.c:834
+#: c-family/c-opts.c:832
 #, gcc-internal-format
 msgid "-fno-gnu89-inline is only supported in GNU99 or C99 mode"
 msgstr "-fno-gnu89-inline est uniquement supporté dans les modes GNU99 ou C99"
 
-#: c-family/c-opts.c:880
+#: c-family/c-opts.c:878
 #, gcc-internal-format
 msgid "-Wformat-y2k ignored without -Wformat"
 msgstr "-Wformat-y2k ignoré sans -Wformat"
 
-#: c-family/c-opts.c:882
+#: c-family/c-opts.c:880
 #, gcc-internal-format
 msgid "-Wformat-extra-args ignored without -Wformat"
 msgstr "-Wformat-extra-args ignoré sans -Wformat"
 
-#: c-family/c-opts.c:884
+#: c-family/c-opts.c:882
 #, gcc-internal-format
 msgid "-Wformat-zero-length ignored without -Wformat"
 msgstr "-Wformat-zero-length ignoré sans -Wformat"
 
-#: c-family/c-opts.c:886
+#: c-family/c-opts.c:884
 #, gcc-internal-format
 msgid "-Wformat-nonliteral ignored without -Wformat"
 msgstr "-Wformat-nonliteral ignoré sans -Wformat"
 
-#: c-family/c-opts.c:888
+#: c-family/c-opts.c:886
 #, gcc-internal-format
 msgid "-Wformat-contains-nul ignored without -Wformat"
 msgstr "-Wformat-contains-nul ignoré sans -Wformat"
 
-#: c-family/c-opts.c:890
+#: c-family/c-opts.c:888
 #, gcc-internal-format
 msgid "-Wformat-security ignored without -Wformat"
 msgstr "-Wformat-security ignorée sans -Wformat"
 
-#: c-family/c-opts.c:928
+#: c-family/c-opts.c:918
 #, gcc-internal-format
 msgid "%<-fabi-compat-version=1%> is not supported, using =2"
 msgstr "%<-fabi-compat-version=1%> n'est pas supporté, on utilise =2"
 
-#: c-family/c-opts.c:988
+#: c-family/c-opts.c:944
 #, gcc-internal-format
+msgid "-Wabi won't warn about anything"
+msgstr ""
+
+#: c-family/c-opts.c:946
+#, gcc-internal-format
+msgid "-Wabi warns about differences from the most up-to-date ABI, which is also used by default"
+msgstr ""
+
+#: c-family/c-opts.c:949
+#, gcc-internal-format
+msgid "use e.g. -Wabi=11 to warn about changes from GCC 7"
+msgstr ""
+
+#: c-family/c-opts.c:1003
+#, gcc-internal-format
 msgid "external TLS initialization functions not supported on this target"
 msgstr "les fonctions d'initialisation TLS externes ne sont pas supportées sur cette cible"
 
-#: c-family/c-opts.c:1001
+#: c-family/c-opts.c:1016
 #, gcc-internal-format, gfc-internal-format
 msgid "too many filenames given.  Type %s --help for usage"
 msgstr "trop de noms de fichiers. Tapez %s --help pour connaître l'usage"
 
-#: c-family/c-opts.c:1016
+#: c-family/c-opts.c:1031
 #, gcc-internal-format
 msgid "opening output file %s: %m"
 msgstr "ouverture du fichier de sortie %s: %m"
 
-#: c-family/c-opts.c:1036
+#: c-family/c-opts.c:1051
 #, gcc-internal-format, gfc-internal-format
 msgid "the \"%s\" debug format cannot be used with pre-compiled headers"
 msgstr "le format de débogage « %s » ne peut pas être utilisé avec des en-têtes précompilés"
 
-#: c-family/c-opts.c:1190
+#: c-family/c-opts.c:1205
 #, gcc-internal-format
 msgid "opening dependency file %s: %m"
 msgstr "ouverture du fichier de dépendances %s: %m"
 
-#: c-family/c-opts.c:1201
+#: c-family/c-opts.c:1216
 #, gcc-internal-format
 msgid "closing dependency file %s: %m"
 msgstr "fermeture du fichier de dépendances %s: %m"
 
-#: c-family/c-opts.c:1204
+#: c-family/c-opts.c:1219
 #, gcc-internal-format
 msgid "when writing output to %s: %m"
 msgstr "lors de l'écriture de la sortie dans %s: %m"
 
-#: c-family/c-opts.c:1284
+#: c-family/c-opts.c:1299
 #, gcc-internal-format
 msgid "to generate dependencies you must specify either -M or -MM"
 msgstr "pour générer les dépendances, vous devez spécifier -M ou -MM"
 
-#: c-family/c-opts.c:1307
+#: c-family/c-opts.c:1322
 #, gcc-internal-format
 msgid "-MG may only be used with -M or -MM"
 msgstr "-MG ne peut être utilisé qu'avec -M ou -MM"
 
-#: c-family/c-opts.c:1340
+#: c-family/c-opts.c:1355
 #, gcc-internal-format
 msgid "-fdirectives-only is incompatible with -Wunused_macros"
 msgstr "-fdirectives-only est incompatible avec -Wunused_macros"
 
-#: c-family/c-opts.c:1342
+#: c-family/c-opts.c:1357
 #, gcc-internal-format
 msgid "-fdirectives-only is incompatible with -traditional"
 msgstr "-fdirectives-only est incompatible avec -traditional"
 
-#: c-family/c-opts.c:1534
+#: c-family/c-opts.c:1549
 #, gcc-internal-format
 msgid "too late for # directive to set debug directory"
 msgstr "il est trop tard pour définir le répertoire de débogage avec la directive #"
@@ -26062,725 +26109,725 @@
 msgid "wrong type argument to %s"
 msgstr "argument de type erroné pour %s"
 
-#: c-family/c-warn.c:53 c-family/c-warn.c:66 cp/constexpr.c:1847
+#: c-family/c-warn.c:54 c-family/c-warn.c:67 cp/constexpr.c:1847
 #: cp/constexpr.c:4099
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "débordement dans l'expression constante"
 
-#: c-family/c-warn.c:93
+#: c-family/c-warn.c:94
 #, gcc-internal-format
 msgid "integer overflow in expression %qE of type %qT results in %qE"
 msgstr "débordement d'entier dans l'expression %qE de type %qT résulte en %qE"
 
-#: c-family/c-warn.c:95
+#: c-family/c-warn.c:96
 #, gcc-internal-format
 msgid "integer overflow in expression of type %qT results in %qE"
 msgstr "débordement d'entier dans l'expression de type %qT résulte en %qE"
 
-#: c-family/c-warn.c:101
+#: c-family/c-warn.c:102
 #, gcc-internal-format
 msgid "floating point overflow in expression %qE of type %qT results in %qE"
 msgstr "débordement d'un nombre en virgule flottante dans l'expression %qE de type %qT résulte en %qE"
 
-#: c-family/c-warn.c:103
+#: c-family/c-warn.c:104
 #, gcc-internal-format
 msgid "floating point overflow in expression of type %qT results in %qE"
 msgstr "débordement d'un nombre en virgule flottante dans l'expression de type %qT résulte en %qE"
 
-#: c-family/c-warn.c:109
+#: c-family/c-warn.c:110
 #, gcc-internal-format
 msgid "fixed-point overflow in expression %qE of type %qT results in %qE"
 msgstr "débordement d'un nombre en virgule fixe dans l'expression %qE de type %qT résulte in %qE"
 
-#: c-family/c-warn.c:111
+#: c-family/c-warn.c:112
 #, gcc-internal-format
 msgid "fixed-point overflow in expression of type %qT results in %qE"
 msgstr "débordement d'un nombre en virgule fixe dans l'expression de type %qT résulte en %qE"
 
-#: c-family/c-warn.c:117
+#: c-family/c-warn.c:118
 #, gcc-internal-format
 msgid "vector overflow in expression %qE of type %qT results in %qE"
 msgstr "débordement du vecteur dans l'expression %qE de type %qT résulte en %qE"
 
-#: c-family/c-warn.c:119
+#: c-family/c-warn.c:120
 #, gcc-internal-format
 msgid "vector overflow in expression of type %qT results in %qE"
 msgstr "débordement du vecteur dans l'expression de type %qT résulte en %qE"
 
-#: c-family/c-warn.c:126
+#: c-family/c-warn.c:127
 #, gcc-internal-format
 msgid "complex integer overflow in expression %qE of type %qT results in %qE"
 msgstr "débordement d'un entier complexe dans l'expression %qE de type %qT résulte en %qE"
 
-#: c-family/c-warn.c:128
+#: c-family/c-warn.c:129
 #, gcc-internal-format
 msgid "complex integer overflow in expression of type %qT results in %qE"
 msgstr "débordement d'un entier complexe dans l'expression de type %qT résulte en %qE"
 
-#: c-family/c-warn.c:132
+#: c-family/c-warn.c:133
 #, gcc-internal-format
 msgid "complex floating point overflow in expression %qE of type %qT results in %qE"
 msgstr "débordement d'un nombre en virgule flottante complexe dans l'expression %qE de type %qT résulte en %qE"
 
-#: c-family/c-warn.c:134
+#: c-family/c-warn.c:135
 #, gcc-internal-format
 msgid "complex floating point overflow in expression of type %qT results in %qE"
 msgstr "débordement d'un nombre en virgule flottante complexe dans l'expression de type %qT résulte en %qE"
 
-#: c-family/c-warn.c:216
+#: c-family/c-warn.c:217
 #, gcc-internal-format
 msgid "logical %<or%> applied to non-boolean constant"
 msgstr "%<ou%> logique appliqué à une constante non booléenne"
 
-#: c-family/c-warn.c:219
+#: c-family/c-warn.c:220
 #, gcc-internal-format
 msgid "logical %<and%> applied to non-boolean constant"
 msgstr "%<et%> logique appliqué à une constante non booléenne"
 
-#: c-family/c-warn.c:289
+#: c-family/c-warn.c:290
 #, gcc-internal-format
 msgid "logical %<or%> of collectively exhaustive tests is always true"
 msgstr "le %<ou%> logique des tests collectivement exhaustifs est toujours vrai"
 
-#: c-family/c-warn.c:293
+#: c-family/c-warn.c:294
 #, gcc-internal-format
 msgid "logical %<and%> of mutually exclusive tests is always false"
 msgstr "le %<et%> logique des tests mutuellement exclusifs est toujours faux"
 
-#: c-family/c-warn.c:303
+#: c-family/c-warn.c:304
 #, gcc-internal-format
 msgid "logical %<or%> of equal expressions"
 msgstr "%<ou%> logique d'expressions égales"
 
-#: c-family/c-warn.c:306
+#: c-family/c-warn.c:307
 #, gcc-internal-format
 msgid "logical %<and%> of equal expressions"
 msgstr "%<et%> logique d'expressions égales"
 
-#: c-family/c-warn.c:384
+#: c-family/c-warn.c:385
 #, gcc-internal-format
 msgid "bitwise comparison always evaluates to false"
 msgstr "la comparaison au niveau du bit est toujours évaluée à faux"
 
-#: c-family/c-warn.c:387
+#: c-family/c-warn.c:388
 #, gcc-internal-format
 msgid "bitwise comparison always evaluates to true"
 msgstr "la comparaison au niveau du bit est toujours évaluée à vrai"
 
-#: c-family/c-warn.c:441
+#: c-family/c-warn.c:442
 #, gcc-internal-format
 msgid "self-comparison always evaluates to true"
 msgstr "la comparaison avec soi-même retourne toujours vrai"
 
-#: c-family/c-warn.c:444
+#: c-family/c-warn.c:445
 #, gcc-internal-format
 msgid "self-comparison always evaluates to false"
 msgstr "la comparaison avec soi-même retourne toujours faux"
 
-#: c-family/c-warn.c:494
+#: c-family/c-warn.c:495
 #, gcc-internal-format
 msgid "logical not is only applied to the left hand side of comparison"
 msgstr "le non logique est toujours appliqué au membre de gauche de la comparaison"
 
-#: c-family/c-warn.c:502
+#: c-family/c-warn.c:503
 #, gcc-internal-format
 msgid "add parentheses around left hand side expression to silence this warning"
 msgstr "ajoutez des parenthèses autour de l'expression du membre de gauche pour ne plus recevoir cet avertissement"
 
-#: c-family/c-warn.c:636
+#: c-family/c-warn.c:637
 #, gcc-internal-format
 msgid "type-punning to incomplete type might break strict-aliasing rules"
 msgstr "un transtypage à la barbare vers un type incomplet pourrait enfreindre la règle selon laquelle un seul pointeur pointe vers une zone mémoire (strict aliasing)."
 
-#: c-family/c-warn.c:654
+#: c-family/c-warn.c:655
 #, gcc-internal-format
 msgid "dereferencing type-punned pointer will break strict-aliasing rules"
 msgstr "le déréférencement d'un pointeur transtypé à la barbare va enfreindre la règle selon laquelle une zone mémoire ne peut être accédée que par un seul pointeur (strict aliasing)"
 
-#: c-family/c-warn.c:662 c-family/c-warn.c:680
+#: c-family/c-warn.c:663 c-family/c-warn.c:681
 #, gcc-internal-format
 msgid "dereferencing type-punned pointer might break strict-aliasing rules"
 msgstr "le déréférencement d'un pointeur transtypé à la barbare pourrait enfreindre la règle selon laquelle une zone mémoire ne peut être accédée que par un seul pointeur (strict aliasing)"
 
-#: c-family/c-warn.c:803
+#: c-family/c-warn.c:811
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to use the size of the destination?"
 msgstr "l'argument de %<sizeof%> dans l'appel à %qD est la même expression que la source; ne vouliez-vous pas utiliser la taille de la destination ?"
 
-#: c-family/c-warn.c:834
+#: c-family/c-warn.c:842
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the destination; did you mean to remove the addressof?"
 msgstr "l'argument de %<sizeof%> dans l'appel à %qD est la même expression que la destination; avez-vous oublié de retirer « addressof » ?"
 
-#: c-family/c-warn.c:841
+#: c-family/c-warn.c:849
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the destination; did you mean to provide an explicit length?"
 msgstr "l'argument de %<sizeof%> dans l'appel à %qD est la même expression que la destination; aviez-vous l'intention de fournir une longueur explicite ?"
 
-#: c-family/c-warn.c:846
+#: c-family/c-warn.c:854
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the destination; did you mean to dereference it?"
 msgstr "l'argument de %<sizeof%> dans l'appel à %qD est la même expression que la destination; aviez-vous l'intention de le déréférencer ?"
 
-#: c-family/c-warn.c:858
+#: c-family/c-warn.c:866
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the destination; expected %qT or an explicit length"
 msgstr "l'argument de %<sizeof%> dans l'appel à %qD est le même type de pointeur %qT que la destination; on attendait %qT ou une longueur explicite"
 
-#: c-family/c-warn.c:874
+#: c-family/c-warn.c:882
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to remove the addressof?"
 msgstr "l'argument de %<sizeof%> dans l'appel à %qD est la même expression que la source; avez-vous oublié de retirer « addressof » ?"
 
-#: c-family/c-warn.c:881
+#: c-family/c-warn.c:889
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to provide an explicit length?"
 msgstr "l'argument de %<sizeof%> dans l'appel à %qD est la même expression que la source; aviez-vous l'intention de fournir une longueur explicite ?"
 
-#: c-family/c-warn.c:886
+#: c-family/c-warn.c:894
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to dereference it?"
 msgstr "l'argument de %<sizeof%> dans l'appel à %qD est la même expression que la source; aviez-vous l'intention de le déréférencer ?"
 
-#: c-family/c-warn.c:898
+#: c-family/c-warn.c:906
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the source; expected %qT or an explicit length"
 msgstr "l'argument de %<sizeof%> dans l'appel à %qD est le même type de pointeur %qT que la source; on attendait %qT ou une longueur explicite"
 
-#: c-family/c-warn.c:914
+#: c-family/c-warn.c:922
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the first source; did you mean to remove the addressof?"
 msgstr "l'argument de %<sizeof%> dans l'appel à %qD est la même expression que la première source; avez-vous oublié de retirer « addressof » ?"
 
-#: c-family/c-warn.c:921
+#: c-family/c-warn.c:929
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the first source; did you mean to provide an explicit length?"
 msgstr "l'argument de %<sizeof%> dans l'appel %qD est la même expression que la première source; aviez-vous l'intention de fournir une longueur explicite ?"
 
-#: c-family/c-warn.c:926
+#: c-family/c-warn.c:934
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the first source; did you mean to dereference it?"
 msgstr "l'argument de %<sizeof%> dans l'appel à %qD est la même expression que la première source; aviez-vous l'intention de le déréférencer ?"
 
-#: c-family/c-warn.c:938
+#: c-family/c-warn.c:946
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the first source; expected %qT or an explicit length"
 msgstr "l'argument de %<sizeof%> dans l'appel à %qD est le même type de pointeur %qT que la première source; on attendait %qT ou une longueur explicite"
 
-#: c-family/c-warn.c:954
+#: c-family/c-warn.c:962
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the second source; did you mean to remove the addressof?"
 msgstr "l'argument de %<sizeof%> dans l'appel à %qD est la même expression que la deuxième source; avez-vous oublié de retirer « addressof » ?"
 
-#: c-family/c-warn.c:961
+#: c-family/c-warn.c:969
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the second source; did you mean to provide an explicit length?"
 msgstr "l'argument de %<sizeof%> dans l'appel %qD est la même expression que la deuxième source; aviez-vous l'intention de fournir une longueur explicite ?"
 
-#: c-family/c-warn.c:966
+#: c-family/c-warn.c:974
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the second source; did you mean to dereference it?"
 msgstr "l'argument de %<sizeof%> dans l'appel à %qD est la même expression que la deuxième source; aviez-vous l'intention de le déréférencer ?"
 
-#: c-family/c-warn.c:978
+#: c-family/c-warn.c:986
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the second source; expected %qT or an explicit length"
 msgstr "l'argument de %<sizeof%> dans l'appel à %qD est le même type de pointeur %qT que la deuxième source; on attendait %qT ou une longueur explicite"
 
-#: c-family/c-warn.c:1007 c-family/c-warn.c:1014
+#: c-family/c-warn.c:1015 c-family/c-warn.c:1022
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified parameter type %qT of %q+D"
 msgstr "le type du paramètre %qT est qualifié avec %<_Atomic%> dans %q+D"
 
-#: c-family/c-warn.c:1024
+#: c-family/c-warn.c:1032
 #, gcc-internal-format
 msgid "first argument of %q+D should be %<int%>"
 msgstr "le premier argument de %q+D devrait être %<int%>"
 
-#: c-family/c-warn.c:1033
+#: c-family/c-warn.c:1041
 #, gcc-internal-format
 msgid "second argument of %q+D should be %<char **%>"
 msgstr "le deuxième argument de %q+D devrait être %<char **%>"
 
-#: c-family/c-warn.c:1042
+#: c-family/c-warn.c:1050
 #, gcc-internal-format
 msgid "third argument of %q+D should probably be %<char **%>"
 msgstr "le troisième argument de %q+D devrait probablement être %<char **%>"
 
-#: c-family/c-warn.c:1053
+#: c-family/c-warn.c:1061
 #, gcc-internal-format
 msgid "%q+D takes only zero or two arguments"
 msgstr "%q+D prend soit aucun argument ou soit deux arguments"
 
-#: c-family/c-warn.c:1057
+#: c-family/c-warn.c:1065
 #, gcc-internal-format
 msgid "%q+D declared as variadic function"
 msgstr "%q+D est déclarée comme fonction variadique"
 
-#: c-family/c-warn.c:1099
+#: c-family/c-warn.c:1107
 #, gcc-internal-format
 msgid "conversion to %qT from boolean expression"
 msgstr "conversion d'une expression booléenne vers %qT"
 
-#: c-family/c-warn.c:1117 c-family/c-warn.c:1192
+#: c-family/c-warn.c:1125 c-family/c-warn.c:1200
 #, gcc-internal-format
 msgid "conversion from %qT to %qT changes value from %qE to %qE"
 msgstr "la conversion depuis %qT vers %qT change la valeur de %qE en %qE"
 
-#: c-family/c-warn.c:1121 c-family/c-warn.c:1200
+#: c-family/c-warn.c:1129 c-family/c-warn.c:1208
 #, gcc-internal-format
 msgid "conversion from %qT to %qT changes the value of %qE"
 msgstr "la conversion de %qT vers %qT change la valeur de %qE"
 
-#: c-family/c-warn.c:1141
+#: c-family/c-warn.c:1149
 #, gcc-internal-format
 msgid "conversion from %qT to %qT discards imaginary component"
 msgstr "la conversion de %qT vers %qT abandonne la partir imaginaire"
 
-#: c-family/c-warn.c:1153
+#: c-family/c-warn.c:1161
 #, gcc-internal-format
 msgid "conversion from %qT to %qT may change value"
 msgstr "la conversion de %qT vers %qT peut changer la valeur"
 
-#: c-family/c-warn.c:1213 c-family/c-warn.c:1230 c-family/c-warn.c:1247
+#: c-family/c-warn.c:1221 c-family/c-warn.c:1238 c-family/c-warn.c:1255
 #, gcc-internal-format
 msgid "overflow in conversion from %qT to %qT changes value from %qE to %qE"
 msgstr "le débordement dans la conversion de %qT vers %qT change la valeur de %qE en %qE"
 
-#: c-family/c-warn.c:1218 c-family/c-warn.c:1235 c-family/c-warn.c:1252
+#: c-family/c-warn.c:1226 c-family/c-warn.c:1243 c-family/c-warn.c:1260
 #, gcc-internal-format
 msgid "overflow in conversion from %qT to %qT changes the value of %qE"
 msgstr "le débordement dans la conversion de %qT vers %qT change la valeur en %qE"
 
-#: c-family/c-warn.c:1282
+#: c-family/c-warn.c:1290
 #, gcc-internal-format
 msgid "case value %qs not in enumerated type"
 msgstr "la valeur %qs du « case » n'est pas dans le type énuméré"
 
-#: c-family/c-warn.c:1287
+#: c-family/c-warn.c:1295
 #, gcc-internal-format
 msgid "case value %qs not in enumerated type %qT"
 msgstr "la valeur %qs du « case » n'est pas dans le type énuméré %qT"
 
-#: c-family/c-warn.c:1348
+#: c-family/c-warn.c:1356
 #, gcc-internal-format
 msgid "switch missing default case"
 msgstr "le « switch » n'a pas de branche par défaut"
 
-#: c-family/c-warn.c:1393
+#: c-family/c-warn.c:1401
 #, gcc-internal-format
 msgid "switch condition has boolean value"
 msgstr "la condition du « switch » a une valeur booléenne"
 
-#: c-family/c-warn.c:1466
+#: c-family/c-warn.c:1474
 #, gcc-internal-format
 msgid "enumeration value %qE not handled in switch"
 msgstr "la valeur %qE de l'énumération n'est pas traitée dans le « switch »"
 
-#: c-family/c-warn.c:1494
+#: c-family/c-warn.c:1502
 #, gcc-internal-format
 msgid "the omitted middle operand in ?: will always be %<true%>, suggest explicit middle operand"
 msgstr "l'opérande omis au milieu de ?: sera toujours %<vrai%>, il est suggéré de spécifier explicitement l'opérande du milieu"
 
-#: c-family/c-warn.c:1515
+#: c-family/c-warn.c:1523
 #, gcc-internal-format
 msgid "assignment of member %qD in read-only object"
 msgstr "affectation au membre %qD d'un objet en lecture seule"
 
-#: c-family/c-warn.c:1517
+#: c-family/c-warn.c:1525
 #, gcc-internal-format
 msgid "increment of member %qD in read-only object"
 msgstr "incrémentation du membre %qD d'un objet en lecture seule"
 
-#: c-family/c-warn.c:1519
+#: c-family/c-warn.c:1527
 #, gcc-internal-format
 msgid "decrement of member %qD in read-only object"
 msgstr "décrémentation du membre %qD d'un objet en lecture seule"
 
-#: c-family/c-warn.c:1521
+#: c-family/c-warn.c:1529
 #, gcc-internal-format
 msgid "member %qD in read-only object used as %<asm%> output"
 msgstr "le membre %qD d'un objet en lecture seule est utilisé comme sortie %<asm%>"
 
-#: c-family/c-warn.c:1525
+#: c-family/c-warn.c:1533
 #, gcc-internal-format
 msgid "assignment of read-only member %qD"
 msgstr "affectation du membre %qD en lecture seule"
 
-#: c-family/c-warn.c:1526
+#: c-family/c-warn.c:1534
 #, gcc-internal-format
 msgid "increment of read-only member %qD"
 msgstr "incrémentation du membre %qD en lecture seule"
 
-#: c-family/c-warn.c:1527
+#: c-family/c-warn.c:1535
 #, gcc-internal-format
 msgid "decrement of read-only member %qD"
 msgstr "décrémentation du membre %qD en lecture seule"
 
-#: c-family/c-warn.c:1528
+#: c-family/c-warn.c:1536
 #, gcc-internal-format
 msgid "read-only member %qD used as %<asm%> output"
 msgstr "le membre %qD, en lecture seule, est utilisé comme sortie %<asm%>"
 
-#: c-family/c-warn.c:1532
+#: c-family/c-warn.c:1540
 #, gcc-internal-format
 msgid "assignment of read-only variable %qD"
 msgstr "affectation de la variable %qD en lecture seule"
 
-#: c-family/c-warn.c:1533
+#: c-family/c-warn.c:1541
 #, gcc-internal-format
 msgid "increment of read-only variable %qD"
 msgstr "incrémentation de la variable %qD en lecture seule"
 
-#: c-family/c-warn.c:1534
+#: c-family/c-warn.c:1542
 #, gcc-internal-format
 msgid "decrement of read-only variable %qD"
 msgstr "décrémentation de la variable %qD en lecture seule"
 
-#: c-family/c-warn.c:1535
+#: c-family/c-warn.c:1543
 #, gcc-internal-format
 msgid "read-only variable %qD used as %<asm%> output"
 msgstr "la variable %qD, en lecture seule, est utilisée comme sortie %<asm%>"
 
-#: c-family/c-warn.c:1538
+#: c-family/c-warn.c:1546
 #, gcc-internal-format
 msgid "assignment of read-only parameter %qD"
 msgstr "affectation du paramètre %qD en lecture seule"
 
-#: c-family/c-warn.c:1539
+#: c-family/c-warn.c:1547
 #, gcc-internal-format
 msgid "increment of read-only parameter %qD"
 msgstr "incrémentation du paramètre %qD en lecture seule"
 
-#: c-family/c-warn.c:1540
+#: c-family/c-warn.c:1548
 #, gcc-internal-format
 msgid "decrement of read-only parameter %qD"
 msgstr "décrémentation du paramètre %qD en lecture seule"
 
-#: c-family/c-warn.c:1541
+#: c-family/c-warn.c:1549
 #, gcc-internal-format
 msgid "read-only parameter %qD use as %<asm%> output"
 msgstr "le paramètre %qD, en lecture seule, est utilisé comme sortie %<asm%>"
 
-#: c-family/c-warn.c:1546
+#: c-family/c-warn.c:1554
 #, gcc-internal-format
 msgid "assignment of read-only named return value %qD"
 msgstr "affectation à la valeur de retour nommée %qD en lecture seule"
 
-#: c-family/c-warn.c:1548
+#: c-family/c-warn.c:1556
 #, gcc-internal-format
 msgid "increment of read-only named return value %qD"
 msgstr "incrémentation de la valeur de retour nommée %qD en lecture seule"
 
-#: c-family/c-warn.c:1550
+#: c-family/c-warn.c:1558
 #, gcc-internal-format
 msgid "decrement of read-only named return value %qD"
 msgstr "décrémentation de la valeur de retour nommée %qD en lecture seule"
 
-#: c-family/c-warn.c:1552
+#: c-family/c-warn.c:1560
 #, gcc-internal-format
 msgid "read-only named return value %qD used as %<asm%>output"
 msgstr "la valeur de retour nommée %qD, en lecture seule, est utilisée comme sortie %<asm%>"
 
-#: c-family/c-warn.c:1557
+#: c-family/c-warn.c:1565
 #, gcc-internal-format
 msgid "assignment of function %qD"
 msgstr "affectation de la fonction %qD"
 
-#: c-family/c-warn.c:1558
+#: c-family/c-warn.c:1566
 #, gcc-internal-format
 msgid "increment of function %qD"
 msgstr "incrémentation de la fonction %qD"
 
-#: c-family/c-warn.c:1559
+#: c-family/c-warn.c:1567
 #, gcc-internal-format
 msgid "decrement of function %qD"
 msgstr "décrémentation de la fonction %qD"
 
-#: c-family/c-warn.c:1560
+#: c-family/c-warn.c:1568
 #, gcc-internal-format
 msgid "function %qD used as %<asm%> output"
 msgstr "la fonction %qD est utilisée comme sortie %<asm%>"
 
-#: c-family/c-warn.c:1563 c/c-typeck.c:4762
+#: c-family/c-warn.c:1571 c/c-typeck.c:4767
 #, gcc-internal-format
 msgid "assignment of read-only location %qE"
 msgstr "affectation de l'emplacement %qE en lecture seule"
 
-#: c-family/c-warn.c:1564 c/c-typeck.c:4765
+#: c-family/c-warn.c:1572 c/c-typeck.c:4770
 #, gcc-internal-format
 msgid "increment of read-only location %qE"
 msgstr "incrémentation de l'emplacement %qE en lecture seule"
 
-#: c-family/c-warn.c:1565 c/c-typeck.c:4768
+#: c-family/c-warn.c:1573 c/c-typeck.c:4773
 #, gcc-internal-format
 msgid "decrement of read-only location %qE"
 msgstr "décrémentation de l'emplacement %qE en lecture seule"
 
-#: c-family/c-warn.c:1566
+#: c-family/c-warn.c:1574
 #, gcc-internal-format
 msgid "read-only location %qE used as %<asm%> output"
 msgstr "l'emplacement %qE, en lecture seule, est utilisé comme sortie %<asm%>"
 
-#: c-family/c-warn.c:1580
+#: c-family/c-warn.c:1588
 #, gcc-internal-format
 msgid "lvalue required as left operand of assignment"
 msgstr "l-valeur exigée comme opérande de gauche de l'affectation"
 
-#: c-family/c-warn.c:1583
+#: c-family/c-warn.c:1591
 #, gcc-internal-format
 msgid "lvalue required as increment operand"
 msgstr "l-valeur exigée comme opérande d'incrémentation"
 
-#: c-family/c-warn.c:1586
+#: c-family/c-warn.c:1594
 #, gcc-internal-format
 msgid "lvalue required as decrement operand"
 msgstr "l-valeur exigée comme opérande de décrémentation"
 
-#: c-family/c-warn.c:1589
+#: c-family/c-warn.c:1597
 #, gcc-internal-format
 msgid "lvalue required as unary %<&%> operand"
 msgstr "l-valeur exigée comme opérande unaire %<&%>"
 
-#: c-family/c-warn.c:1592
+#: c-family/c-warn.c:1600
 #, gcc-internal-format
 msgid "lvalue required in asm statement"
 msgstr "l-valeur exigée dans l'instruction asm"
 
-#: c-family/c-warn.c:1609
+#: c-family/c-warn.c:1617
 #, gcc-internal-format
 msgid "invalid type argument (have %qT)"
 msgstr "argument de type invalide (%qT obtenu)"
 
-#: c-family/c-warn.c:1613
+#: c-family/c-warn.c:1621
 #, gcc-internal-format
 msgid "invalid type argument of array indexing (have %qT)"
 msgstr "argument de type invalide pour l'index d'un tableau (%qT obtenu)"
 
-#: c-family/c-warn.c:1618
+#: c-family/c-warn.c:1626
 #, gcc-internal-format
 msgid "invalid type argument of unary %<*%> (have %qT)"
 msgstr "argument de type invalide pour le %<*%> unaire (%qT obtenu)"
 
-#: c-family/c-warn.c:1623
+#: c-family/c-warn.c:1631
 #, gcc-internal-format
 msgid "invalid type argument of %<->%> (have %qT)"
 msgstr "argument de type invalide pour %<->%> (%qT obtenu)"
 
-#: c-family/c-warn.c:1628
+#: c-family/c-warn.c:1636
 #, gcc-internal-format
 msgid "invalid type argument of %<->*%> (have %qT)"
 msgstr "argument de type invalide pour %<->*%> (%qT obtenu)"
 
-#: c-family/c-warn.c:1633
+#: c-family/c-warn.c:1641
 #, gcc-internal-format
 msgid "invalid type argument of implicit conversion (have %qT)"
 msgstr "argument de type invalide pour la conversion implicite (%qT obtenu)"
 
-#: c-family/c-warn.c:1654
+#: c-family/c-warn.c:1662
 #, gcc-internal-format
 msgid "array subscript has type %<char%>"
 msgstr "l'indice du tableau est de type %<char%>"
 
-#: c-family/c-warn.c:1689 c-family/c-warn.c:1692
+#: c-family/c-warn.c:1697 c-family/c-warn.c:1700
 #, gcc-internal-format
 msgid "suggest parentheses around %<+%> inside %<<<%>"
 msgstr "parenthèses suggérées autour de %<+%> à l'intérieur de %<<<%>"
 
-#: c-family/c-warn.c:1695 c-family/c-warn.c:1698
+#: c-family/c-warn.c:1703 c-family/c-warn.c:1706
 #, gcc-internal-format
 msgid "suggest parentheses around %<-%> inside %<<<%>"
 msgstr "parenthèses suggérées autour de %<-%> à l'intérieur de %<<<%>"
 
-#: c-family/c-warn.c:1704 c-family/c-warn.c:1707
+#: c-family/c-warn.c:1712 c-family/c-warn.c:1715
 #, gcc-internal-format
 msgid "suggest parentheses around %<+%> inside %<>>%>"
 msgstr "parenthèses suggérées autour de %<+%> à l'intérieur de %<>>%>"
 
-#: c-family/c-warn.c:1710 c-family/c-warn.c:1713
+#: c-family/c-warn.c:1718 c-family/c-warn.c:1721
 #, gcc-internal-format
 msgid "suggest parentheses around %<-%> inside %<>>%>"
 msgstr "parenthèses suggérées autour de %<-%> à l'intérieur de %<>>%>"
 
-#: c-family/c-warn.c:1719 c-family/c-warn.c:1722
+#: c-family/c-warn.c:1727 c-family/c-warn.c:1730
 #, gcc-internal-format
 msgid "suggest parentheses around %<&&%> within %<||%>"
 msgstr "parenthèses suggérées autour de %<&&%> à l'intérieur de %<||%>"
 
-#: c-family/c-warn.c:1729 c-family/c-warn.c:1733
+#: c-family/c-warn.c:1737 c-family/c-warn.c:1741
 #, gcc-internal-format
 msgid "suggest parentheses around arithmetic in operand of %<|%>"
 msgstr "parenthèses suggérées autour de l'arithmétique dans l'opérande de %<|%>"
 
-#: c-family/c-warn.c:1737 c-family/c-warn.c:1740
+#: c-family/c-warn.c:1745 c-family/c-warn.c:1748
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<|%>"
 msgstr "parenthèses suggérées autour de la comparaison dans l'opérande de %<|%>"
 
-#: c-family/c-warn.c:1745
+#: c-family/c-warn.c:1753
 #, gcc-internal-format
 msgid "suggest parentheses around operand of %<!%> or change %<|%> to %<||%> or %<!%> to %<~%>"
 msgstr "parenthèses suggérées autour de l'opérande de %<!%> ou changez %<|%> en %<||%> ou %<!%> en %<~%>"
 
-#: c-family/c-warn.c:1753 c-family/c-warn.c:1757
+#: c-family/c-warn.c:1761 c-family/c-warn.c:1765
 #, gcc-internal-format
 msgid "suggest parentheses around arithmetic in operand of %<^%>"
 msgstr "parenthèses suggérées autour de l'arithmétique dans l'opérande de %<^%>"
 
-#: c-family/c-warn.c:1761 c-family/c-warn.c:1764
+#: c-family/c-warn.c:1769 c-family/c-warn.c:1772
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<^%>"
 msgstr "parenthèses suggérées autour de la comparaison dans l'opérande de %<^%>"
 
-#: c-family/c-warn.c:1770 c-family/c-warn.c:1773
+#: c-family/c-warn.c:1778 c-family/c-warn.c:1781
 #, gcc-internal-format
 msgid "suggest parentheses around %<+%> in operand of %<&%>"
 msgstr "parenthèses suggérées autour de %<+%> dans l'opérande de %<&%>"
 
-#: c-family/c-warn.c:1776 c-family/c-warn.c:1779
+#: c-family/c-warn.c:1784 c-family/c-warn.c:1787
 #, gcc-internal-format
 msgid "suggest parentheses around %<-%> in operand of %<&%>"
 msgstr "parenthèses suggérées autour de %<-%> dans l'opérande de %<&%>"
 
-#: c-family/c-warn.c:1783 c-family/c-warn.c:1786
+#: c-family/c-warn.c:1791 c-family/c-warn.c:1794
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<&%>"
 msgstr "parenthèses suggérées autour de la comparaison dans l'opérande de %<&%>"
 
-#: c-family/c-warn.c:1791
+#: c-family/c-warn.c:1799
 #, gcc-internal-format
 msgid "suggest parentheses around operand of %<!%> or change %<&%> to %<&&%> or %<!%> to %<~%>"
 msgstr "parenthèses suggérées autour de l'opérande de %<!%> ou changez %<&%> en %<&&%> ou %<!%> en %<~%>"
 
-#: c-family/c-warn.c:1798 c-family/c-warn.c:1801
+#: c-family/c-warn.c:1806 c-family/c-warn.c:1809
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<==%>"
 msgstr "parenthèses suggérées autour de la comparaison dans l'opérande de %<==%>"
 
-#: c-family/c-warn.c:1806 c-family/c-warn.c:1809
+#: c-family/c-warn.c:1814 c-family/c-warn.c:1817
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<!=%>"
 msgstr "parenthèses suggérées autour de la comparaison dans l'opérande de %<!=%>"
 
-#: c-family/c-warn.c:1819 c-family/c-warn.c:1825
+#: c-family/c-warn.c:1827 c-family/c-warn.c:1833
 #, gcc-internal-format
 msgid "comparisons like %<X<=Y<=Z%> do not have their mathematical meaning"
 msgstr "les comparaisons telles que %<X<=Y<=Z%> n'ont pas leur signification mathématique"
 
-#: c-family/c-warn.c:1841
+#: c-family/c-warn.c:1849
 #, gcc-internal-format
 msgid "label %q+D defined but not used"
 msgstr "étiquette %q+D définie mais non utilisée"
 
-#: c-family/c-warn.c:1843
+#: c-family/c-warn.c:1851
 #, gcc-internal-format
 msgid "label %q+D declared but not defined"
 msgstr "étiquette %q+D déclarée mais pas définie"
 
-#: c-family/c-warn.c:1866
+#: c-family/c-warn.c:1874
 #, gcc-internal-format
 msgid "division by zero"
 msgstr "division par zéro"
 
-#: c-family/c-warn.c:1886
+#: c-family/c-warn.c:1894
 #, gcc-internal-format
 msgid "%<memset%> used with constant zero length parameter; this could be due to transposed parameters"
 msgstr "%<memset%> utilisé avec un paramètre de longueur qui est la constante zéro; cela pourrait être dû à des paramètres transposés"
 
-#: c-family/c-warn.c:1909
+#: c-family/c-warn.c:1918
 #, gcc-internal-format
 msgid "%<memset%> used with length equal to number of elements without multiplication by element size"
 msgstr "%<memset%> utilisé avec une longueur égale au nombre d'éléments sans être multiplié par la taille des éléments"
 
-#: c-family/c-warn.c:1948 c/c-typeck.c:11499 c/c-typeck.c:11667
+#: c-family/c-warn.c:1957 c/c-typeck.c:11504 c/c-typeck.c:11672
 #: cp/typeck.c:5048
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr "comparaison entre les types %qT et %qT"
 
-#: c-family/c-warn.c:1998
+#: c-family/c-warn.c:2007
 #, gcc-internal-format
 msgid "comparison of integer expressions of different signedness: %qT and %qT"
 msgstr "comparaison d'expressions entières de types signés différents: %qT et %qT"
 
-#: c-family/c-warn.c:2051
+#: c-family/c-warn.c:2060
 #, gcc-internal-format
 msgid "promoted ~unsigned is always non-zero"
 msgstr "un ~unsigned promu est toujours non nul"
 
-#: c-family/c-warn.c:2054
+#: c-family/c-warn.c:2063
 #, gcc-internal-format
 msgid "comparison of promoted ~unsigned with constant"
 msgstr "comparaison entre un ~unsigned promu et une constante"
 
-#: c-family/c-warn.c:2064
+#: c-family/c-warn.c:2073
 #, gcc-internal-format
 msgid "comparison of promoted ~unsigned with unsigned"
 msgstr "comparaison entre un ~unsigned promu et un non signé"
 
-#: c-family/c-warn.c:2118
+#: c-family/c-warn.c:2127
 #, gcc-internal-format
 msgid "unused parameter %qD"
 msgstr "paramètre %qD inutilisé"
 
-#: c-family/c-warn.c:2180
+#: c-family/c-warn.c:2189
 #, gcc-internal-format
 msgid "typedef %qD locally defined but not used"
 msgstr "le typedef %qD est défini localement sans être utilisé"
 
-#: c-family/c-warn.c:2215
+#: c-family/c-warn.c:2224
 #, gcc-internal-format
 msgid "duplicated %<if%> condition"
 msgstr "condition %<if%> dupliquée"
 
-#: c-family/c-warn.c:2244
+#: c-family/c-warn.c:2253
 #, gcc-internal-format
 msgid "optimization attribute on %qD follows definition but the attribute doesn%'t match"
 msgstr "l'attribut d'optimisation sur %qD suit la définition mais l'attribut ne correspond pas"
 
-#: c-family/c-warn.c:2254
+#: c-family/c-warn.c:2261
 #, gcc-internal-format
 msgid "inline declaration of %qD follows declaration with attribute %qs"
 msgstr "la déclaration en ligne de %qD suit la déclaration avec l'attribut %qs"
 
-#: c-family/c-warn.c:2259
+#: c-family/c-warn.c:2266
 #, gcc-internal-format
 msgid "declaration of %q+D with attribute %qs follows inline declaration"
 msgstr "la déclaration de %q+D avec l'attribut %qs suit la déclaration « inline »"
 
-#: c-family/c-warn.c:2306
+#: c-family/c-warn.c:2313
 #, gcc-internal-format
 msgid "result of %qE requires %u bits to represent, but %qT only has %u bits"
 msgstr "le résultat de %qE a besoin de %u bits pour être représenté mais %qT n'a que %u bits"
 
-#: c-family/c-warn.c:2344 c-family/c-warn.c:2368
+#: c-family/c-warn.c:2351 c-family/c-warn.c:2375
 #, gcc-internal-format
 msgid "comparison of constant %qE with boolean expression is always false"
 msgstr "la comparaison de la constante %qE avec une expression booléenne est toujours fausse"
 
-#: c-family/c-warn.c:2347 c-family/c-warn.c:2365
+#: c-family/c-warn.c:2354 c-family/c-warn.c:2372
 #, gcc-internal-format
 msgid "comparison of constant %qE with boolean expression is always true"
 msgstr "la comparaison de la constante %qE avec une expression booléenne est toujours vraie"
 
-#: c-family/c-warn.c:2415
+#: c-family/c-warn.c:2422
 msgid "passing argument %i to restrict-qualified parameter aliases with argument %Z"
 msgid_plural "passing argument %i to restrict-qualified parameter aliases with arguments %Z"
 msgstr[0] "l'argument %i est passé à un paramètre avec un qualificatif restrictif alors qu'il est également passé dans l'argument %Z"
 msgstr[1] "l'argument %i est passé à un paramètre avec un qualificatif restrictif alors qu'il est également passé dans les arguments %Z"
 
-#: c-family/c-warn.c:2480 c/c-typeck.c:5288 cp/call.c:5365
+#: c-family/c-warn.c:2487 c/c-typeck.c:5293 cp/call.c:5365
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr "cette condition a des branches identiques"
 
-#: c-family/c-warn.c:2586
+#: c-family/c-warn.c:2593
 #, gcc-internal-format
 msgid "macro expands to multiple statements"
 msgstr "la macro s'étend en des instructions multiples"
 
-#: c-family/c-warn.c:2587
+#: c-family/c-warn.c:2594
 #, gcc-internal-format
 msgid "some parts of macro expansion are not guarded by this %qs clause"
 msgstr "certaines parties de l'expansion de la macro ne sont pas protégées par cette instruction %qs"
@@ -26795,7 +26842,7 @@
 msgid "too many input files"
 msgstr "trop de fichiers d'entrée"
 
-#: common/config/aarch64/aarch64-common.c:319 config/aarch64/aarch64.c:10686
+#: common/config/aarch64/aarch64-common.c:319 config/aarch64/aarch64.c:10702
 #, gcc-internal-format
 msgid "unknown value %qs for -mcpu"
 msgstr "valeur %qs inconnue pour -mcpu"
@@ -26826,13 +26873,13 @@
 msgstr "option non reconnue passée à %%:target_mode_check"
 
 #: common/config/arm/arm-common.c:322 common/config/arm/arm-common.c:376
-#: common/config/arm/arm-common.c:423 config/aarch64/aarch64.c:10639
+#: common/config/arm/arm-common.c:423 config/aarch64/aarch64.c:10655
 #, gcc-internal-format
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr "les arguments valides sont: %s; vouliez-vous utiliser %qs ?"
 
 #: common/config/arm/arm-common.c:325 common/config/arm/arm-common.c:379
-#: common/config/arm/arm-common.c:426 config/aarch64/aarch64.c:10642
+#: common/config/arm/arm-common.c:426 config/aarch64/aarch64.c:10658
 #, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s"
 msgstr "les arguments valables sont: %s"
@@ -27305,12 +27352,12 @@
 msgid "profiler support for VxWorks"
 msgstr "support du profilage pour VxWorks"
 
-#: config/aarch64/aarch64-builtins.c:1109 config/arm/arm-builtins.c:2262
+#: config/aarch64/aarch64-builtins.c:1109 config/arm/arm-builtins.c:2272
 #, gcc-internal-format
 msgid "%Kargument %d must be a constant immediate"
 msgstr "%Kl'argument %d doit être une constante immédiate"
 
-#: config/aarch64/aarch64-builtins.c:1180 config/arm/arm-builtins.c:2492
+#: config/aarch64/aarch64-builtins.c:1180 config/arm/arm-builtins.c:2502
 #, gcc-internal-format
 msgid "%Klane index must be a constant immediate"
 msgstr "%Kl'index de l'avenue doit être une constante immédiate"
@@ -27320,175 +27367,175 @@
 msgid "%Ktotal size and element size must be a non-zero constant immediate"
 msgstr "%Kla taille totale et la taille de l'élément doivent être des constantes immédiates non nulles"
 
-#: config/aarch64/aarch64.c:1053
+#: config/aarch64/aarch64.c:1069
 #, gcc-internal-format
 msgid "%qs is incompatible with %s %s"
 msgstr "%qs est incompatible avec %s %s"
 
-#: config/aarch64/aarch64.c:1055
+#: config/aarch64/aarch64.c:1071
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with %s %s"
 msgstr "le modificateur de fonctionnalité %qs est incompatible avec %s %s"
 
-#: config/aarch64/aarch64.c:3772
+#: config/aarch64/aarch64.c:3788
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr "sondes de pile pour les trames SVE"
 
-#: config/aarch64/aarch64.c:10287
+#: config/aarch64/aarch64.c:10303
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown flag passed in -moverride=%s (%s)"
 msgstr "fanion inconnu passé à -moverride=%s (%s)"
 
-#: config/aarch64/aarch64.c:10331
+#: config/aarch64/aarch64.c:10347
 #, gcc-internal-format, gfc-internal-format
 msgid "%s string ill-formed\n"
 msgstr "chaîne %s mal formée\n"
 
-#: config/aarch64/aarch64.c:10388
+#: config/aarch64/aarch64.c:10404
 #, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr "chaîne d'ajustement manquante dans l'option (%s)"
 
-#: config/aarch64/aarch64.c:10406
+#: config/aarch64/aarch64.c:10422
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown tuning option (%s)"
 msgstr "option d'ajustement inconnue (%s)"
 
-#: config/aarch64/aarch64.c:10683
+#: config/aarch64/aarch64.c:10699
 #, gcc-internal-format
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr "nom de processeur manquant dans %<-mcpu=%s%>"
 
-#: config/aarch64/aarch64.c:10690
+#: config/aarch64/aarch64.c:10706
 #, gcc-internal-format
 msgid "invalid feature modifier in %<-mcpu=%s%>"
 msgstr "modificateur de fonctionnalité invalide dans %<-mcpu=%s%>"
 
-#: config/aarch64/aarch64.c:10717
+#: config/aarch64/aarch64.c:10733
 #, gcc-internal-format
 msgid "missing arch name in %<-march=%s%>"
 msgstr "nom d'architecture manquant dans %<-march=%s%>"
 
-#: config/aarch64/aarch64.c:10720
+#: config/aarch64/aarch64.c:10736
 #, gcc-internal-format
 msgid "unknown value %qs for -march"
 msgstr "valeur %qs inconnue pour -march"
 
-#: config/aarch64/aarch64.c:10724
+#: config/aarch64/aarch64.c:10740
 #, gcc-internal-format
 msgid "invalid feature modifier in %<-march=%s%>"
 msgstr "modificateur de fonctionnalité invalide dans %<-march=%s%>"
 
-#: config/aarch64/aarch64.c:10750
+#: config/aarch64/aarch64.c:10766
 #, gcc-internal-format
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr "nom de processeur manquant dans %<-mtune=%s%>"
 
-#: config/aarch64/aarch64.c:10753
+#: config/aarch64/aarch64.c:10769
 #, gcc-internal-format
 msgid "unknown value %qs for -mtune"
 msgstr "valeur %qs inconnue pour -mtune"
 
-#: config/aarch64/aarch64.c:10871 config/arm/arm.c:3173
+#: config/aarch64/aarch64.c:10887 config/arm/arm.c:3173
 #, gcc-internal-format, gfc-internal-format
 msgid "switch -mcpu=%s conflicts with -march=%s switch"
 msgstr "l'option -mcpu=%s est en conflit avec l'option -march=%s"
 
-#: config/aarch64/aarch64.c:10906
+#: config/aarch64/aarch64.c:10922
 #, gcc-internal-format
 msgid "assembler does not support -mabi=ilp32"
 msgstr "l'assembleur ne supporte pas -mabi=ilp32"
 
-#: config/aarch64/aarch64.c:10913
+#: config/aarch64/aarch64.c:10929
 #, gcc-internal-format
 msgid "return address signing is only supported for -mabi=lp64"
 msgstr "la signature de l'adresse de retour n'est supportée qu'avec -mabi=lp64"
 
-#: config/aarch64/aarch64.c:10975
+#: config/aarch64/aarch64.c:10991
 #, gcc-internal-format
 msgid "code model %qs with -f%s"
 msgstr "modèle de code %qs avec -f%s"
 
-#: config/aarch64/aarch64.c:11138
+#: config/aarch64/aarch64.c:11154
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr "nom manquant dans le pragma ou l'attribut %<target(\"arch=\")%>"
 
-#: config/aarch64/aarch64.c:11141
+#: config/aarch64/aarch64.c:11157
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"arch=\")%> pragma or attribute"
 msgstr "nom invalide (« %s ») dans le pragma ou l'attribut %<target(\"arch=\")%>"
 
-#: config/aarch64/aarch64.c:11145 config/aarch64/aarch64.c:11184
-#: config/aarch64/aarch64.c:11257
+#: config/aarch64/aarch64.c:11161 config/aarch64/aarch64.c:11200
+#: config/aarch64/aarch64.c:11273
 #, gcc-internal-format
 msgid "invalid value (\"%s\") in %<target()%> pragma or attribute"
 msgstr "valeur invalide (« %s ») dans le pragma ou l'attribut %<target(\"arch=\")%>"
 
-#: config/aarch64/aarch64.c:11177
+#: config/aarch64/aarch64.c:11193
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr "nom manquant dans le pragma ou l'attribut %<target(\"cpu=\")%>"
 
-#: config/aarch64/aarch64.c:11180
+#: config/aarch64/aarch64.c:11196
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"cpu=\")%> pragma or attribute"
 msgstr "nom invalide (« %s ») dans le pragma ou l'attribut %<target(\"cpu=\")%>"
 
-#: config/aarch64/aarch64.c:11213
+#: config/aarch64/aarch64.c:11229
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"tune=\")%> pragma or attribute"
 msgstr "nom invalide (« %s ») dans le pragma ou l'attribut %<target(\"tune=\")%>"
 
-#: config/aarch64/aarch64.c:11253
+#: config/aarch64/aarch64.c:11269
 #, gcc-internal-format
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr "valeur manquante dans le pragma ou l'attribut %<target()%>"
 
-#: config/aarch64/aarch64.c:11306 config/aarch64/aarch64.c:11483
+#: config/aarch64/aarch64.c:11322 config/aarch64/aarch64.c:11499
 #, gcc-internal-format
 msgid "malformed %<target()%> pragma or attribute"
 msgstr "le pragma ou l'attribut %<target()%> est mal composé"
 
-#: config/aarch64/aarch64.c:11354
+#: config/aarch64/aarch64.c:11370
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr "le pragma ou l'attribut %<target(\"%s\")%> n'accepte pas d'argument"
 
-#: config/aarch64/aarch64.c:11362
+#: config/aarch64/aarch64.c:11378
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr "le pragma ou l'attribut %<target(\"%s\")%> n'autorise pas de forme négative"
 
-#: config/aarch64/aarch64.c:11416
+#: config/aarch64/aarch64.c:11432
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr "le pragma ou l'attribut %<target(\"%s=%s\")%> n'est pas valide"
 
-#: config/aarch64/aarch64.c:11473 config/arm/arm.c:30742
-#: config/i386/i386.c:5440 config/powerpcspe/powerpcspe.c:39760
-#: config/rs6000/rs6000.c:36904 config/s390/s390.c:15746
+#: config/aarch64/aarch64.c:11489 config/arm/arm.c:30742
+#: config/i386/i386.c:5443 config/powerpcspe/powerpcspe.c:39760
+#: config/rs6000/rs6000.c:36960 config/s390/s390.c:15746
 #, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "l'argument %<target%> de l'attribut n'est pas une chaîne"
 
-#: config/aarch64/aarch64.c:11500
+#: config/aarch64/aarch64.c:11516
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr "le pragma ou l'attribut %<target(\"%s\")%> n'est pas valide"
 
-#: config/aarch64/aarch64.c:11509
+#: config/aarch64/aarch64.c:11525
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr "le pragma ou l'attribut %<target(\"%s\")%> est mal composé"
 
-#: config/aarch64/aarch64.c:13571
+#: config/aarch64/aarch64.c:13587
 #, gcc-internal-format
 msgid "%Klane %wd out of range %wd - %wd"
 msgstr "%Kl'avenue %wd est hors des limites %wd - %wd"
 
-#: config/aarch64/aarch64.c:13573
+#: config/aarch64/aarch64.c:13589
 #, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr "avenue %wd hors des limites %wd - %wd"
@@ -27548,8 +27595,8 @@
 msgid "bad value %qs for -mmemory-latency"
 msgstr "valeur %qs erronée pour -mmemory-latency"
 
-#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6526
-#: config/arc/arc.c:6800 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
+#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6517
+#: config/arc/arc.c:6791 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
 #: config/tilepro/tilepro.c:3108
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -27658,11 +27705,11 @@
 #: config/arm/arm.c:7029 config/avr/avr.c:9718 config/avr/avr.c:9734
 #: config/bfin/bfin.c:4705 config/bfin/bfin.c:4766 config/bfin/bfin.c:4795
 #: config/epiphany/epiphany.c:491 config/h8300/h8300.c:5459
-#: config/i386/i386.c:6452 config/i386/i386.c:12479 config/i386/i386.c:41424
-#: config/i386/i386.c:41474 config/i386/i386.c:41544 config/m68k/m68k.c:780
+#: config/i386/i386.c:6455 config/i386/i386.c:12482 config/i386/i386.c:41418
+#: config/i386/i386.c:41468 config/i386/i386.c:41538 config/m68k/m68k.c:780
 #: config/mcore/mcore.c:3070 config/nvptx/nvptx.c:4611
 #: config/powerpcspe/powerpcspe.c:35785 config/riscv/riscv.c:2698
-#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:32982
+#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:33038
 #: config/rx/rx.c:2719 config/rx/rx.c:2745 config/s390/s390.c:1056
 #: config/s390/s390.c:1143 config/sh/sh.c:8428 config/sh/sh.c:8446
 #: config/sh/sh.c:8470 config/sh/sh.c:8541 config/sh/sh.c:8564
@@ -27672,133 +27719,133 @@
 msgid "%qE attribute only applies to functions"
 msgstr "l'attribut %qE s'applique uniquement aux fonctions"
 
-#: config/arc/arc.c:6425
+#: config/arc/arc.c:6416
 #, gcc-internal-format
 msgid "__builtin_arc_aligned with non-constant alignment"
 msgstr "__builtin_arc_aligned avec un alignement non constant"
 
-#: config/arc/arc.c:6433
+#: config/arc/arc.c:6424
 #, gcc-internal-format
 msgid "invalid alignment value for __builtin_arc_aligned"
 msgstr "valeur d'alignement invalide pour __builtin_arc_aligned"
 
-#: config/arc/arc.c:6596
+#: config/arc/arc.c:6587
 #, gcc-internal-format
 msgid "operand 1 should be an unsigned 3-bit immediate"
 msgstr "l'opérande 1 devrait être une valeur immédiate non signée sur 3 bits"
 
-#: config/arc/arc.c:6637 config/arc/arc.c:6734
+#: config/arc/arc.c:6628 config/arc/arc.c:6725
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (I0-I7)"
 msgstr "l'opérande 2 devrait être une valeur non signée sur 3 bits (I0-I7)"
 
-#: config/arc/arc.c:6670 config/arc/arc.c:6702
+#: config/arc/arc.c:6661 config/arc/arc.c:6693
 #, gcc-internal-format
 msgid "operand 1 should be an unsigned 3-bit value (I0-I7)"
 msgstr "l'opérande 1 devrait être une valeur non signée sur 3 bits (I0-I7)"
 
-#: config/arc/arc.c:6674 config/arc/arc.c:6706
+#: config/arc/arc.c:6665 config/arc/arc.c:6697
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 8-bit value"
 msgstr "l'opérande 2 devrait être une valeur non signée sur 8 bits"
 
-#: config/arc/arc.c:6738
+#: config/arc/arc.c:6729
 #, gcc-internal-format
 msgid "operand 3 should be an unsigned 8-bit value"
 msgstr "l'opérande 3 devrait être une valeur non signée sur 8 bits"
 
-#: config/arc/arc.c:6771
+#: config/arc/arc.c:6762
 #, gcc-internal-format
 msgid "operand 4 should be an unsigned 8-bit value (0-255)"
 msgstr "l'opérande 4 devrait être une valeur non signée sur 8 bits (0-255)"
 
-#: config/arc/arc.c:6775
+#: config/arc/arc.c:6766
 #, gcc-internal-format
 msgid "operand 3 should be an unsigned 3-bit value (I0-I7)"
 msgstr "l'opérande 3 devrait être une valeur non signée sur 3 bits (I0-I7)"
 
-#: config/arc/arc.c:6782
+#: config/arc/arc.c:6773
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (subreg 0-7)"
 msgstr "l'opérande 2 devrait être une valeur non signée sur 3 bits (sous-registre 0-7)"
 
-#: config/arc/arc.c:6785
+#: config/arc/arc.c:6776
 #, gcc-internal-format
 msgid "operand 2 should be an even 3-bit value (subreg 0,2,4,6)"
 msgstr "l'opérande 2 devrait être une valeur paire sur 3 bits (sous-registre 0,2,4,6)"
 
-#: config/arc/arc.c:6832
+#: config/arc/arc.c:6823
 #, gcc-internal-format, gfc-internal-format
 msgid "builtin requires an immediate for operand %d"
 msgstr "la fonction intégrée exige une valeur immédiate pour l'opérande %d"
 
-#: config/arc/arc.c:6837
+#: config/arc/arc.c:6828
 #, gcc-internal-format, gfc-internal-format
 msgid "operand %d should be a 6 bit unsigned immediate"
 msgstr "l'opérande %d devrait être une valeur immédiate non signée sur 6 bits"
 
-#: config/arc/arc.c:6841
+#: config/arc/arc.c:6832
 #, gcc-internal-format, gfc-internal-format
 msgid "operand %d should be a 8 bit unsigned immediate"
 msgstr "l'opérande %d devrait être une valeur immédiate non signée sur 8 bits"
 
-#: config/arc/arc.c:6845
+#: config/arc/arc.c:6836
 #, gcc-internal-format, gfc-internal-format
 msgid "operand %d should be a 3 bit unsigned immediate"
 msgstr "l'opérande %d devrait être une valeur immédiate non signée sur 3 bits"
 
-#: config/arc/arc.c:6848
+#: config/arc/arc.c:6839
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown builtin immediate operand type for operand %d"
 msgstr "type d'opérande immédiat de la fonction intégrée inconnu pour l'opérande %d"
 
-#: config/arc/arc.c:6899
+#: config/arc/arc.c:6890
 #, gcc-internal-format
 msgid "register number must be a compile-time constant. Try giving higher optimization levels"
 msgstr "le numéro de registre doit être une constante à la compilation. Essayez à des niveaux d'optimisation supérieurs"
 
-#: config/arc/arc.c:7685
+#: config/arc/arc.c:7747
 #, gcc-internal-format
 msgid "Insn addresses not set after shorten_branches"
 msgstr "les adresses des insn ne sont pas définies après shorten_branches"
 
-#: config/arc/arc.c:7894
+#: config/arc/arc.c:7956
 #, gcc-internal-format
 msgid "insn addresses not freed"
 msgstr "les adresses des insn ne sont pas libérées"
 
-#: config/arc/arc.c:10682
+#: config/arc/arc.c:10670
 #, gcc-internal-format
 msgid "%qE attribute only valid for ARCv2 architecture"
 msgstr "l'attribut %qE est uniquement valable pour l'architecture ARCv2"
 
-#: config/arc/arc.c:10690 config/arc/arc.c:10729
+#: config/arc/arc.c:10678 config/arc/arc.c:10717
 #, gcc-internal-format
 msgid "argument of %qE attribute is missing"
 msgstr "l'argument de l'attribut %qE est manquant"
 
-#: config/arc/arc.c:10701 config/arc/arc.c:10740 config/arc/arc.c:10842
+#: config/arc/arc.c:10689 config/arc/arc.c:10728 config/arc/arc.c:10830
 #: config/avr/avr.c:9790
 #, gcc-internal-format
 msgid "%qE attribute allows only an integer constant argument"
 msgstr "l'attribut %qE n'accepte qu'une constante entière comme argument"
 
-#: config/arc/arc.c:10721
+#: config/arc/arc.c:10709
 #, gcc-internal-format
 msgid "%qE attribute only valid for ARC EM architecture"
 msgstr "l'attribut %qE est uniquement valable pour l'architecture ARC EM"
 
-#: config/arc/arc.c:10776
+#: config/arc/arc.c:10764
 #, gcc-internal-format
 msgid "%qE attribute only applies to types"
 msgstr "l'attribut %qE ne s'applique qu'à des types"
 
-#: config/arc/arc.c:10782
+#: config/arc/arc.c:10770
 #, gcc-internal-format
 msgid "argument of %qE attribute ignored"
 msgstr "l'argument de l'attribut %qE est ignoré"
 
-#: config/arc/arc.c:10832 config/avr/avr.c:9777 config/bfin/bfin.c:4827
+#: config/arc/arc.c:10820 config/avr/avr.c:9777 config/bfin/bfin.c:4827
 #: config/i386/winnt.c:63 config/msp430/msp430.c:2018
 #: config/nvptx/nvptx.c:4634
 #, gcc-internal-format
@@ -27805,174 +27852,174 @@
 msgid "%qE attribute only applies to variables"
 msgstr "l'attribut %qE ne s'applique qu'aux variables"
 
-#: config/arm/arm-builtins.c:2370
+#: config/arm/arm-builtins.c:2380
 #, gcc-internal-format
 msgid "this builtin is not supported for this target"
 msgstr "cette fonction interne n'est pas supportée pour cette cible"
 
-#: config/arm/arm-builtins.c:2475
+#: config/arm/arm-builtins.c:2485
 #, gcc-internal-format
 msgid "You must enable NEON instructions (e.g. -mfloat-abi=softfp -mfpu=neon) to use these intrinsics."
 msgstr "Vous devez activer les instructions NEON (par ex. -mfloat-abi=softfp -mfpu=neon) pour utiliser ces intrinsèques."
 
-#: config/arm/arm-builtins.c:2513
+#: config/arm/arm-builtins.c:2523
 #, gcc-internal-format
 msgid "You must enable VFP instructions to use these intrinsics."
 msgstr "Vous devez activer les instructions VFP pour utiliser ces intrinsèques."
 
-#: config/arm/arm-builtins.c:2573
+#: config/arm/arm-builtins.c:2583
 #, gcc-internal-format
 msgid "You must enable crypto instructions (e.g. include -mfloat-abi=softfp -mfpu=crypto-neon...) to use these intrinsics."
 msgstr "Vous devez activer les instructions crypto (par ex. inclure -mfloat-abi=softfp -mfpu=crypto-neon…) pour utiliser ces intrinsèques."
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:2633 config/arm/arm-builtins.c:2737
+#: config/arm/arm-builtins.c:2643 config/arm/arm-builtins.c:2747
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr "sélecteur doit être un immédiat"
 
-#: config/arm/arm-builtins.c:2641 config/arm/arm-builtins.c:2686
-#: config/arm/arm-builtins.c:2744 config/arm/arm-builtins.c:2753
+#: config/arm/arm-builtins.c:2651 config/arm/arm-builtins.c:2696
+#: config/arm/arm-builtins.c:2754 config/arm/arm-builtins.c:2763
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr "la plage du sélecteur doit être entre 0 et 7"
 
-#: config/arm/arm-builtins.c:2646 config/arm/arm-builtins.c:2755
+#: config/arm/arm-builtins.c:2656 config/arm/arm-builtins.c:2765
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr "la plage du sélecteur doit être entre 0 et 3"
 
-#: config/arm/arm-builtins.c:2651 config/arm/arm-builtins.c:2757
+#: config/arm/arm-builtins.c:2661 config/arm/arm-builtins.c:2767
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr "la plage du sélecteur doit être entre 0 et 1"
 
-#: config/arm/arm-builtins.c:2823
+#: config/arm/arm-builtins.c:2833
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr "le masque doit être un immédiat"
 
-#: config/arm/arm-builtins.c:2828
+#: config/arm/arm-builtins.c:2838
 #, gcc-internal-format
 msgid "the range of mask should be in 0 to 255"
 msgstr "la plage du masque doit être entre 0 et 255"
 
-#: config/arm/arm-builtins.c:3016
+#: config/arm/arm-builtins.c:3026
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr "la plage du décompte doit être entre 0 et 32. Veuillez vérifier l'intrinsèque _mm_rori_pi16 dans le code."
 
-#: config/arm/arm-builtins.c:3018
+#: config/arm/arm-builtins.c:3028
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr "la plage du décompte doit être entre 0 et 32. Veuillez vérifier l'intrinsèque _mm_rori_pi32 dans le code."
 
-#: config/arm/arm-builtins.c:3020
+#: config/arm/arm-builtins.c:3030
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr "la plage du décompte doit être entre 0 et 32. Veuillez vérifier l'intrinsèque _mm_ror_pi16 dans le code."
 
-#: config/arm/arm-builtins.c:3022
+#: config/arm/arm-builtins.c:3032
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr "la plage du décompte doit être entre 0 et 32. Veuillez vérifier l'intrinsèque _mm_ror_pi32 dans le code."
 
-#: config/arm/arm-builtins.c:3028
+#: config/arm/arm-builtins.c:3038
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr "la plage du décompte doit être entre 0 et 64. Veuillez vérifier l'intrinsèque _mm_rori_si64 dans le code."
 
-#: config/arm/arm-builtins.c:3030
+#: config/arm/arm-builtins.c:3040
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr "la plage du décompte doit être entre 0 et 64. Veuillez vérifier l'intrinsèque _mm_ror_si64 dans le code."
 
-#: config/arm/arm-builtins.c:3035
+#: config/arm/arm-builtins.c:3045
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_srli_pi16 dans le code"
 
-#: config/arm/arm-builtins.c:3037
+#: config/arm/arm-builtins.c:3047
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_srli_pi32 dans le code"
 
-#: config/arm/arm-builtins.c:3039
+#: config/arm/arm-builtins.c:3049
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_srli_si64 dans le code"
 
-#: config/arm/arm-builtins.c:3041
+#: config/arm/arm-builtins.c:3051
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_slli_pi16 dans le code"
 
-#: config/arm/arm-builtins.c:3043
+#: config/arm/arm-builtins.c:3053
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_slli_pi32 dans le code"
 
-#: config/arm/arm-builtins.c:3045
+#: config/arm/arm-builtins.c:3055
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_slli_si64 dans le code"
 
-#: config/arm/arm-builtins.c:3047
+#: config/arm/arm-builtins.c:3057
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_srai_pi16 dans le code"
 
-#: config/arm/arm-builtins.c:3049
+#: config/arm/arm-builtins.c:3059
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_srai_pi32 dans le code"
 
-#: config/arm/arm-builtins.c:3051
+#: config/arm/arm-builtins.c:3061
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_srai_si64 dans le code"
 
-#: config/arm/arm-builtins.c:3053
+#: config/arm/arm-builtins.c:3063
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_srl_pi16 dans le code"
 
-#: config/arm/arm-builtins.c:3055
+#: config/arm/arm-builtins.c:3065
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_srl_pi32 dans le code"
 
-#: config/arm/arm-builtins.c:3057
+#: config/arm/arm-builtins.c:3067
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_srl_si64 dans le code"
 
-#: config/arm/arm-builtins.c:3059
+#: config/arm/arm-builtins.c:3069
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_sll_pi16 dans le code"
 
-#: config/arm/arm-builtins.c:3061
+#: config/arm/arm-builtins.c:3071
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_sll_pi32 dans le code"
 
-#: config/arm/arm-builtins.c:3063
+#: config/arm/arm-builtins.c:3073
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_sll_si64 dans le code"
 
-#: config/arm/arm-builtins.c:3065
+#: config/arm/arm-builtins.c:3075
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_sra_pi16 dans le code"
 
-#: config/arm/arm-builtins.c:3067
+#: config/arm/arm-builtins.c:3077
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_sra_pi32 dans le code"
 
-#: config/arm/arm-builtins.c:3069
+#: config/arm/arm-builtins.c:3079
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_sra_si64 dans le code"
@@ -28882,552 +28929,552 @@
 msgid "can%'t set position in PCH file: %m"
 msgstr "ne peut définir la position dans le fichier PCH: %m"
 
-#: config/i386/i386.c:3177
+#: config/i386/i386.c:3180
 #, gcc-internal-format
 msgid "wrong argument %qs to option %qs"
 msgstr "argument %qs erroné pour l'option %qs"
 
-#: config/i386/i386.c:3183
+#: config/i386/i386.c:3186
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr "les plages de tailles de l'option %qs devraient être croissantes"
 
-#: config/i386/i386.c:3193
+#: config/i386/i386.c:3196
 #, gcc-internal-format
 msgid "wrong strategy name %qs specified for option %qs"
 msgstr "nom de stratégie %qs erroné spécifié pour l'option %qs"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3219
+#: config/i386/i386.c:3222
 #, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr "le nom de stratégie %qs spécifié pour l'option %qs n'est pas supporté pour du code 32 bits"
 
-#: config/i386/i386.c:3232
+#: config/i386/i386.c:3235
 #, gcc-internal-format
 msgid "unknown alignment %qs specified for option %qs"
 msgstr "alignement %qs inconnu spécifié pour l'option %qs"
 
-#: config/i386/i386.c:3242
+#: config/i386/i386.c:3245
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr "la valeur maximale pour la dernière plage de taille de l'option %qs devrait être -1"
 
-#: config/i386/i386.c:3249
+#: config/i386/i386.c:3252
 #, gcc-internal-format
 msgid "too many size ranges specified in option %qs"
 msgstr "trop de plages de tailles spécifiées dans l'option %qs"
 
-#: config/i386/i386.c:3302
+#: config/i386/i386.c:3305
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown parameter to option -mtune-ctrl: %s"
 msgstr "paramètre inconnu dans l'option -mtune-ctrl: %s"
 
-#: config/i386/i386.c:3726
+#: config/i386/i386.c:3729
 #, gcc-internal-format
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "la psABI du MCU Intel n'est pas supportée dans le mode %s"
 
-#: config/i386/i386.c:3775
+#: config/i386/i386.c:3778
 #, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "%<-mtune=x86-64%> est déprécié; utilisez plutôt %<-mtune=k8%> ou %<-mtune=generic%> selon ce qui est approprié"
 
-#: config/i386/i386.c:3777
+#: config/i386/i386.c:3780
 #, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr "%<target(\"tune=x86-64\")%> est déprécié; utilisez plutôt %<target(\"tune=k8\")%> ou %<target(\"tune=generic\")%> selon ce qui est approprié"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3804
+#: config/i386/i386.c:3807
 #, gcc-internal-format
 msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgstr "-mstringop-strategy=rep_8byte pas supporté pour du code 32 bits"
 
-#: config/i386/i386.c:3821
+#: config/i386/i386.c:3824
 #, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "le mode d'adresse %qs n'est pas supporté en mode %s bits"
 
-#: config/i386/i386.c:3833
+#: config/i386/i386.c:3836
 #, gcc-internal-format
 msgid "-mabi=ms not supported with X32 ABI"
 msgstr "-mabi=ms pas supporté avec l'ABI X32"
 
-#: config/i386/i386.c:3851 config/i386/i386.c:3860 config/i386/i386.c:3872
-#: config/i386/i386.c:3883 config/i386/i386.c:3894
+#: config/i386/i386.c:3854 config/i386/i386.c:3863 config/i386/i386.c:3875
+#: config/i386/i386.c:3886 config/i386/i386.c:3897
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "le modèle de code %qs n'est pas supporté en mode %s bits"
 
-#: config/i386/i386.c:3863 config/i386/i386.c:3875
+#: config/i386/i386.c:3866 config/i386/i386.c:3878
 #, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "le modèle de code %qs n'est pas supporté en mode x32"
 
-#: config/i386/i386.c:3881 config/i386/i386.c:3890 config/i386/i386.c:5213
+#: config/i386/i386.c:3884 config/i386/i386.c:3893 config/i386/i386.c:5216
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "le modèle de code %s ne supporte pas le mode PIC"
 
-#: config/i386/i386.c:3918
+#: config/i386/i386.c:3921
 #, gcc-internal-format
 msgid "-masm=intel not supported in this configuration"
 msgstr "-masm=intel n'est pas supporté dans cette configuration"
 
-#: config/i386/i386.c:3923
+#: config/i386/i386.c:3926
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "mode %i bits pas compilé"
 
-#: config/i386/i386.c:3932
+#: config/i386/i386.c:3935
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr "le processeur %<generic%> ne peut être utilisé qu'avec l'option %<-mtune=%>"
 
-#: config/i386/i386.c:3934
+#: config/i386/i386.c:3937
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "le processeur %<generic%> ne peut être utilisé qu'avec l'attribut %<target(\"tune=\")%>"
 
-#: config/i386/i386.c:3941
+#: config/i386/i386.c:3944
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr "le processeur %<intel%> ne peut être utilisé qu'avec l'option %<-mtune=%>"
 
-#: config/i386/i386.c:3943
+#: config/i386/i386.c:3946
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "le processeur %<intel%> ne peut être utilisé qu'avec l'attribut %<target(\"tune=\")%>"
 
-#: config/i386/i386.c:3951 config/i386/i386.c:4265
+#: config/i386/i386.c:3954 config/i386/i386.c:4268
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "le processeur sélectionné ne supporte pas le jeu d'instructions x86-64"
 
-#: config/i386/i386.c:4197 config/i386/i386.c:4200
+#: config/i386/i386.c:4200 config/i386/i386.c:4203
 #, gcc-internal-format
 msgid "Intel MPX does not support x32"
 msgstr "le MPX de Intel ne supporte pas x32"
 
-#: config/i386/i386.c:4205
+#: config/i386/i386.c:4208
 #, gcc-internal-format
 msgid "bad value (%qs) for %<-march=%> switch"
 msgstr "valeur erronée (%qs) pour l'option %<-march=%>"
 
-#: config/i386/i386.c:4206
+#: config/i386/i386.c:4209
 #, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"arch=\")%> attribute"
 msgstr "valeur erronée (%qs) pour l'attribut %<target(\"arch=\")%>"
 
-#: config/i386/i386.c:4228
+#: config/i386/i386.c:4231
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "les arguments valides pour l'option %<-march=%> sont: %s; vouliez-vous utiliser %qs ?"
 
-#: config/i386/i386.c:4230
+#: config/i386/i386.c:4233
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr "les arguments valides pour l'attribut %<target(\"arch=\")%> sont: %s; vouliez-vous utiliser %qs ?"
 
-#: config/i386/i386.c:4235
+#: config/i386/i386.c:4238
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "les arguments valides pour l'option %<-march=%> sont: %s"
 
-#: config/i386/i386.c:4236
+#: config/i386/i386.c:4239
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "les arguments valides pour l'attribut %<target(\"arch=\")%> sont: %s"
 
-#: config/i386/i386.c:4284
+#: config/i386/i386.c:4287
 #, gcc-internal-format
 msgid "bad value (%qs) for %<-mtune=%> switch"
 msgstr "valeur erronée (%qs) pour l'option %<-mtune=%>"
 
-#: config/i386/i386.c:4285
+#: config/i386/i386.c:4288
 #, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"tune=\")%> attribute"
 msgstr "valeur erronée (%qs) pour l'attribut %<target(\"tune=\")%>"
 
-#: config/i386/i386.c:4305
+#: config/i386/i386.c:4308
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "les arguments valides pour l'option %<-mtune=%> sont: %s; vouliez-vous utiliser %qs ?"
 
-#: config/i386/i386.c:4307
+#: config/i386/i386.c:4310
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr "les arguments valides pour l'attribut %<target(\"tune=\")%> sont: %s; vouliez-vous utiliser %qs ?"
 
-#: config/i386/i386.c:4312
+#: config/i386/i386.c:4315
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "les arguments valides pour l'option %<-mtune=%> sont: %s"
 
-#: config/i386/i386.c:4313
+#: config/i386/i386.c:4316
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "les arguments valides pour l'attribut %<target(\"tune=\")%> sont: %s"
 
-#: config/i386/i386.c:4379
+#: config/i386/i386.c:4382
 #, gcc-internal-format
 msgid "-mregparm is ignored in 64-bit mode"
 msgstr "-mregparm est ignoré en mode 64 bits"
 
-#: config/i386/i386.c:4381
+#: config/i386/i386.c:4384
 #, gcc-internal-format
 msgid "-mregparm is ignored for Intel MCU psABI"
 msgstr "-mregparm est ignoré avec la psABI du MCU Intel"
 
-#: config/i386/i386.c:4384
+#: config/i386/i386.c:4387
 #, gcc-internal-format, gfc-internal-format
 msgid "-mregparm=%d is not between 0 and %d"
 msgstr "-mregparm=%d n'est pas entre 0 et %d"
 
-#: config/i386/i386.c:4417
+#: config/i386/i386.c:4420
 #, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "%<-mrtd%> est ignoré en mode 64 bits"
 
-#: config/i386/i386.c:4418
+#: config/i386/i386.c:4421
 #, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "%<target(\"rtd\")%> est ignoré en mode 64 bits"
 
-#: config/i386/i386.c:4497
+#: config/i386/i386.c:4500
 #, gcc-internal-format
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "-mpreferred-stack-boundary n'est pas supporté pour cette cible"
 
-#: config/i386/i386.c:4500
+#: config/i386/i386.c:4503
 #, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d n'est pas entre %d et %d"
 
-#: config/i386/i386.c:4523
+#: config/i386/i386.c:4526
 #, gcc-internal-format, gfc-internal-format
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr "-mincoming-stack-boundary=%d n'est pas entre %d et 12"
 
-#: config/i386/i386.c:4536
+#: config/i386/i386.c:4539
 #, gcc-internal-format
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "-mnop-mcount n'est pas compatible avec cette cible"
 
-#: config/i386/i386.c:4539
+#: config/i386/i386.c:4542
 #, gcc-internal-format
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr "-mnop-mcount n'est pas implémenté pour -fPIC"
 
-#: config/i386/i386.c:4545
+#: config/i386/i386.c:4548
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "%<-msseregparm%> utilisé sans que SSE soit activé"
 
-#: config/i386/i386.c:4546
+#: config/i386/i386.c:4549
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "%<target(\"sseregparm\")%> utilisé sans que SSE soit activé"
 
-#: config/i386/i386.c:4556
+#: config/i386/i386.c:4559
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "jeu d'instructions SSE désactivé, l'arithmétique 387 est utilisée"
 
-#: config/i386/i386.c:4563
+#: config/i386/i386.c:4566
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "jeu d'instructions 387 désactivé, l'arithmétique SSE est utilisée"
 
-#: config/i386/i386.c:4613
+#: config/i386/i386.c:4616
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr "le sondage de la pile requiert %<-maccumulate-outgoing-args%> pour être correcte"
 
-#: config/i386/i386.c:4615
+#: config/i386/i386.c:4618
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr "le sondage de la pile requiert %<target(\"accumulate-outgoing-args\")%> pour être correcte"
 
-#: config/i386/i386.c:4629
+#: config/i386/i386.c:4632
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr "le registre ebp fixé requiert %<-maccumulate-outgoing-args%>"
 
-#: config/i386/i386.c:4631
+#: config/i386/i386.c:4634
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr "le registre ebp fixé requiert %<target(\"accumulate-outgoing-args\")%>"
 
-#: config/i386/i386.c:4741
+#: config/i386/i386.c:4744
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr "-mfentry n'est pas supporté en 32 bits en combinaison avec -fpic"
 
-#: config/i386/i386.c:4744
+#: config/i386/i386.c:4747
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr "-mno-fentry n'est pas compatible avec SEH (gestionnaire d'exceptions structuré)"
 
-#: config/i386/i386.c:4748
+#: config/i386/i386.c:4751
 #, gcc-internal-format
 msgid "-mcall-ms2sysv-xlogues isn%'t currently supported with SEH"
 msgstr "-mcall-ms2sysv-xlogues n'est actuellement pas supporté avec SEH"
 
-#: config/i386/i386.c:4813 config/powerpcspe/powerpcspe.c:5663
+#: config/i386/i386.c:4816 config/powerpcspe/powerpcspe.c:5663
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown option for -mrecip=%s"
 msgstr "option inconnue pour -mrecip=%s"
 
-#: config/i386/i386.c:4870 config/powerpcspe/powerpcspe.c:5339
+#: config/i386/i386.c:4873 config/powerpcspe/powerpcspe.c:5339
 #, gcc-internal-format
 msgid "%qs is not a valid number in -mstack-protector-guard-offset="
 msgstr "%qs n'est pas un nombre valable dans -mstack-protector-guard-offset="
 
-#: config/i386/i386.c:4875 config/powerpcspe/powerpcspe.c:5344
+#: config/i386/i386.c:4878 config/powerpcspe/powerpcspe.c:5344
 #, gcc-internal-format
 msgid "%qs is not a valid offset in -mstack-protector-guard-offset="
 msgstr "%qs n'est pas un décalage valable dans -mstack-protector-guard-offset="
 
-#: config/i386/i386.c:4907 config/powerpcspe/powerpcspe.c:5356
+#: config/i386/i386.c:4910 config/powerpcspe/powerpcspe.c:5356
 #, gcc-internal-format
 msgid "%qs is not a valid base register in -mstack-protector-guard-reg="
 msgstr "%qs n'est pas un registre de base valable dans -mstack-protector-guard-reg="
 
-#: config/i386/i386.c:5506 config/i386/i386.c:5553 config/s390/s390.c:15812
+#: config/i386/i386.c:5509 config/i386/i386.c:5556 config/s390/s390.c:15812
 #: config/s390/s390.c:15862 config/s390/s390.c:15879
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr "attribute(target(\"%s\")) est inconnu"
 
-#: config/i386/i386.c:5534
+#: config/i386/i386.c:5537
 #, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr "option(\"%s\") a déjà été spécifié"
 
-#: config/i386/i386.c:5837
+#: config/i386/i386.c:5840
 #, gcc-internal-format
 msgid "interrupt and naked attributes are not compatible"
 msgstr "les attributs d'interruption et nus sont incompatibles"
 
-#: config/i386/i386.c:5852
+#: config/i386/i386.c:5855
 #, gcc-internal-format
 msgid "Only DWARF debug format is supported for interrupt service routine."
 msgstr "Seul le format de débogage DWARF est supporté pour les routines de service d'interruptions."
 
-#: config/i386/i386.c:5901
+#: config/i386/i386.c:5904
 #, gcc-internal-format
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "%<-mindirect-branch=%s%> et %<-mcmodel=large%> sont incompatibles"
 
-#: config/i386/i386.c:5913
+#: config/i386/i386.c:5916
 #, gcc-internal-format
 msgid "%<-mindirect-branch=thunk-extern%>, %<-fcf-protection=branch%> and %<-fcheck-pointer-bounds%> are not compatible"
 msgstr "%<-mindirect-branch=thunk-extern%>, %<-fcf-protection=branch%> et %<-fcheck-pointer-bounds%> sont incompatibles"
 
-#: config/i386/i386.c:5949
+#: config/i386/i386.c:5952
 #, gcc-internal-format
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "%<-mfunction-return=%s%> et %<-mcmodel=large%> sont incompatibles"
 
 # Le dernier %s est le texte non traduit « exception » ou « interrupt ».
-#: config/i386/i386.c:6047
+#: config/i386/i386.c:6050
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in %s service routine"
 msgstr "les instructions %s ne sont pas autorisées dans la routine de service de type « %s »"
 
-#: config/i386/i386.c:6051
+#: config/i386/i386.c:6054
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in function with no_caller_saved_registers attribute"
 msgstr "les instructions %s ne sont pas autorisées dans la fonction avec l'attribut no_caller_saved_registers"
 
-#: config/i386/i386.c:6465 config/i386/i386.c:6516
+#: config/i386/i386.c:6468 config/i386/i386.c:6519
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "les attributs fastcall et regparm sont incompatibles"
 
-#: config/i386/i386.c:6470
+#: config/i386/i386.c:6473
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "les attributs regparam et thiscall sont incompatibles"
 
-#: config/i386/i386.c:6477 config/i386/i386.c:41444
+#: config/i386/i386.c:6480 config/i386/i386.c:41438
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "l'attribut %qE requiert un argument de type constante entière"
 
-#: config/i386/i386.c:6483
+#: config/i386/i386.c:6486
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "l'argument pour l'attribut %qE est plus grand que %d"
 
-#: config/i386/i386.c:6508 config/i386/i386.c:6551
+#: config/i386/i386.c:6511 config/i386/i386.c:6554
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "les attributs fastcall et cdecl sont incompatibles"
 
-#: config/i386/i386.c:6512
+#: config/i386/i386.c:6515
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "les attributs fastcall et stdcall sont incompatibles"
 
-#: config/i386/i386.c:6520 config/i386/i386.c:6569
+#: config/i386/i386.c:6523 config/i386/i386.c:6572
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "les attributs fastcall et thiscall sont incompatibles"
 
-#: config/i386/i386.c:6530 config/i386/i386.c:6547
+#: config/i386/i386.c:6533 config/i386/i386.c:6550
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "les attributs stdcall et cdecl sont incompatibles"
 
-#: config/i386/i386.c:6534
+#: config/i386/i386.c:6537
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "les attributs stdcall et fastcall sont incompatibles"
 
-#: config/i386/i386.c:6538 config/i386/i386.c:6565
+#: config/i386/i386.c:6541 config/i386/i386.c:6568
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "les attributs stdcall et thiscall sont incompatibles"
 
-#: config/i386/i386.c:6555 config/i386/i386.c:6573
+#: config/i386/i386.c:6558 config/i386/i386.c:6576
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "les attributs cdecl et thiscall sont incompatibles"
 
-#: config/i386/i386.c:6561
+#: config/i386/i386.c:6564
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "l'attribut %qE est utilisé pour une méthode qui n'est pas une classe"
 
-#: config/i386/i386.c:6805
+#: config/i386/i386.c:6808
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "appel de %qD avec l'attribut sseregparm sans que SSE/SSE2 soit activé"
 
-#: config/i386/i386.c:6808
+#: config/i386/i386.c:6811
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "appel de %qT avec l'attribut sseregparm sans que SSE/SSE2 soit activé"
 
-#: config/i386/i386.c:7126
+#: config/i386/i386.c:7129
 #, gcc-internal-format
 msgid "X32 does not support ms_abi attribute"
 msgstr "X32 ne supporte pas l'attribut ms_abi"
 
-#: config/i386/i386.c:7160
+#: config/i386/i386.c:7163
 #, gcc-internal-format
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr "ms_hook_prologue n'est pas compatible avec les fonctions imbriquées"
 
-#: config/i386/i386.c:7502
+#: config/i386/i386.c:7505
 #, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr "l'argument vectoriel AVX512F sans activer AVX512F change l'ABI"
 
-#: config/i386/i386.c:7508
+#: config/i386/i386.c:7511
 #, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr "le retour vectoriel AVX512F sans activer AVX512F change l'ABI"
 
-#: config/i386/i386.c:7522
+#: config/i386/i386.c:7525
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr "l'argument vectoriel AVX sans activer AVX change l'ABI"
 
-#: config/i386/i386.c:7528
+#: config/i386/i386.c:7531
 #, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr "le retour vectoriel AVX sans activer AVX change l'ABI"
 
-#: config/i386/i386.c:7544
+#: config/i386/i386.c:7547
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr "l'argument vectoriel SSE sans activer SSE modifie l'ABI"
 
-#: config/i386/i386.c:7550
+#: config/i386/i386.c:7553
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr "le retour vectoriel SSE sans activer SSE change l'ABI"
 
-#: config/i386/i386.c:7566
+#: config/i386/i386.c:7569
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr "l'argument vectoriel MMX sans activer MMX modifie l'ABI"
 
-#: config/i386/i386.c:7572
+#: config/i386/i386.c:7575
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr "le retour vectoriel MMX sans activer MMX change l'ABI"
 
-#: config/i386/i386.c:7754
+#: config/i386/i386.c:7757
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr "l'ABI pour passer une structure possédant un tableau flexible comme membre a changé dans GCC 4.4"
 
-#: config/i386/i386.c:7871
+#: config/i386/i386.c:7874
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr "l'ABI pour passer une union avec un double long a changé dans GCC 4.4"
 
-#: config/i386/i386.c:7989
+#: config/i386/i386.c:7992
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr "l'ABI pour passer une structure possédant un nombre décimal complexe comme membre a changé dans GCC 4.4"
 
-#: config/i386/i386.c:8152
+#: config/i386/i386.c:8155
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr "retour d'un registre SSE alors que SSE est désactivé"
 
-#: config/i386/i386.c:8158
+#: config/i386/i386.c:8161
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr "argument dans un registre SSE alors que SSE est désactivé"
 
-#: config/i386/i386.c:8174
+#: config/i386/i386.c:8177
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr "retour d'un registre x87 alors que x87 est désactivé"
 
-#: config/i386/i386.c:8471 config/i386/i386.c:8750 config/i386/i386.c:9276
+#: config/i386/i386.c:8474 config/i386/i386.c:8753 config/i386/i386.c:9279
 #, gcc-internal-format
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr "appel de %qD avec la convention d'appel SSE sans avoir activé SSE/SSE2"
 
-#: config/i386/i386.c:8473 config/i386/i386.c:8752 config/i386/i386.c:9278
+#: config/i386/i386.c:8476 config/i386/i386.c:8755 config/i386/i386.c:9281
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr "ceci est un bogue de GCC qui peut être contourné en ajoutant l'attribut utilisé à la fonction appelée"
 
-#: config/i386/i386.c:9178
+#: config/i386/i386.c:9181
 #, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr "L'ABI pour passer des paramètres avec un alignement de %d octets a changé dans GCC 4.6"
 
-#: config/i386/i386.c:11601
+#: config/i386/i386.c:11604
 #, gcc-internal-format, gfc-internal-format
 msgid "-mcall-ms2sysv-xlogues is not compatible with %s"
 msgstr "-mcall-ms2sysv-xlogues est incompatible avec %s"
 
-#: config/i386/i386.c:13593
+#: config/i386/i386.c:13596
 #, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr "l'attribut ms_hook_prologue est incompatible avec -mfentry pour 32 bits"
 
-#: config/i386/i386.c:13683
+#: config/i386/i386.c:13686
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr "DRAP (Dynamic Realign Argument Pointer) n'est pas supporté dans une routine de service d'interruption. Ceci peut être contourné en évitant les fonctions avec un retour agrégé."
 
-#: config/i386/i386.c:14970
+#: config/i386/i386.c:14973
 #, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr "-fsplit-stack ne supporte pas fastcall avec des fonctions imbriquées"
 
-#: config/i386/i386.c:14990
+#: config/i386/i386.c:14993
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
 msgstr "-fsplit-stack ne supporte pas deux paramètres registres pour une fonction imbriquée"
@@ -29434,311 +29481,311 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:15001
+#: config/i386/i386.c:15004
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr "-fsplit-stack ne supporte pas trois paramètres registres"
 
-#: config/i386/i386.c:17939
+#: config/i386/i386.c:17942
 #, gcc-internal-format
 msgid "'V' modifier on non-integer register"
 msgstr "modificateur « V » sur un registre non entier"
 
-#: config/i386/i386.c:17950 config/i386/i386.c:17964
+#: config/i386/i386.c:17953 config/i386/i386.c:17967
 #, gcc-internal-format
 msgid "unsupported size for integer register"
 msgstr "taille non supportée pour un registre entier"
 
-#: config/i386/i386.c:17996
+#: config/i386/i386.c:17999
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr "les registres étendus n'ont pas de moitié haute"
 
-#: config/i386/i386.c:18011
+#: config/i386/i386.c:18014
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr "taille d'opérande non supportée pour un registre étendu"
 
-#: config/i386/i386.c:18202
+#: config/i386/i386.c:18205
 #, gcc-internal-format
 msgid "non-integer operand used with operand code 'z'"
 msgstr "opérande non entier utilise avec le code d'opérande « z »"
 
-#: config/i386/i386.c:28467
+#: config/i386/i386.c:28470
 #, gcc-internal-format
 msgid "interrupt service routine can't be called directly"
 msgstr "une routine de service d'interruption ne peut pas être appelée directement"
 
-#: config/i386/i386.c:29995
+#: config/i386/i386.c:29998
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in -fabi-version=12 (GCC 8)"
 msgstr "l'ABI de passage de paramètres pour la classe vide %qT change avec -fabi-version=12 (GCC 8)"
 
-#: config/i386/i386.c:32435
+#: config/i386/i386.c:32438
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr "Pas de répartiteur trouvé pour les attributs de version"
 
-#: config/i386/i386.c:32485
+#: config/i386/i386.c:32488
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for %s"
 msgstr "Pas de répartiteur trouvé pour %s"
 
-#: config/i386/i386.c:32495
+#: config/i386/i386.c:32498
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr "Pas de répartiteur trouvé pour les attributs de version : %s"
 
-#: config/i386/i386.c:32657
+#: config/i386/i386.c:32660
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr "Les versions de fonctions ne peuvent pas être marquées avec gnu_inline, des corps de fonctions doivent être générés"
 
-#: config/i386/i386.c:32662 config/i386/i386.c:32938
-#: config/rs6000/rs6000.c:37850
+#: config/i386/i386.c:32665 config/i386/i386.c:32941
+#: config/rs6000/rs6000.c:37906
 #, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "Des versions multiples de fonctions virtuelles ne sont pas supportées"
 
-#: config/i386/i386.c:32795 config/rs6000/rs6000.c:37607
+#: config/i386/i386.c:32798 config/rs6000/rs6000.c:37663
 #, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "les versions multiples requièrent ifunc qui n'est pas supporté sur cette cible"
 
-#: config/i386/i386.c:33207
+#: config/i386/i386.c:33210
 #, gcc-internal-format
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr "Le paramètre à une fonction interne doit être une chaîne sous forme constante ou littérale"
 
-#: config/i386/i386.c:33232 config/i386/i386.c:33282
+#: config/i386/i386.c:33235 config/i386/i386.c:33285
 #, gcc-internal-format, gfc-internal-format
 msgid "Parameter to builtin not valid: %s"
 msgstr "Le paramètre à la fonction interne n'est pas valable: %s"
 
-#: config/i386/i386.c:33975 config/i386/i386.c:35415
+#: config/i386/i386.c:33978 config/i386/i386.c:35418
 #, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "le dernier argument doit être une valeur immédiate sur 2 bits"
 
-#: config/i386/i386.c:34370
+#: config/i386/i386.c:34373
 #, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "le cinquième argument doit être une valeur immédiate sur 8 bits"
 
-#: config/i386/i386.c:34465
+#: config/i386/i386.c:34468
 #, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "le troisième argument doit être une valeur immédiate sur 8 bits"
 
-#: config/i386/i386.c:35346
+#: config/i386/i386.c:35349
 #, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "le dernier argument doit être une valeur immédiate sur 1 bit"
 
-#: config/i386/i386.c:35361
+#: config/i386/i386.c:35364
 #, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "le dernier argument doit être une valeur immédiate sur 3 bits"
 
-#: config/i386/i386.c:35394
+#: config/i386/i386.c:35397
 #, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "le dernier argument doit être une valeur immédiate sur 4 bits"
 
-#: config/i386/i386.c:35434
+#: config/i386/i386.c:35437
 #, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "le dernier argument doit être une valeur immédiate sur 1 bit"
 
-#: config/i386/i386.c:35447
+#: config/i386/i386.c:35450
 #, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "le dernier argument doit être une valeur immédiate sur 5 bits"
 
-#: config/i386/i386.c:35457
+#: config/i386/i386.c:35460
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "l'avant dernier argument doit être une valeur immédiate sur 8 bits"
 
-#: config/i386/i386.c:35462 config/i386/i386.c:36249
+#: config/i386/i386.c:35465 config/i386/i386.c:36252
 #, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "le dernier argument doit être une valeur immédiate sur 8 bits"
 
-#: config/i386/i386.c:35596
+#: config/i386/i386.c:35599
 #, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr "le troisième argument doit être une constante de comparaison"
 
-#: config/i386/i386.c:35601
+#: config/i386/i386.c:35604
 #, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr "mode de comparaison incorrect"
 
-#: config/i386/i386.c:35607 config/i386/i386.c:35814
+#: config/i386/i386.c:35610 config/i386/i386.c:35817
 #, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr "opérande d'arrondi incorrect"
 
-#: config/i386/i386.c:35796
+#: config/i386/i386.c:35799
 #, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "l'argument immédiat doit être une valeur immédiate sur 4 bits"
 
-#: config/i386/i386.c:35802
+#: config/i386/i386.c:35805
 #, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "l'argument immédiat doit être une valeur immédiate sur 5 bits"
 
-#: config/i386/i386.c:35805
+#: config/i386/i386.c:35808
 #, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "l'argument immédiat doit être une valeur immédiate sur 8 bits"
 
-#: config/i386/i386.c:36247
+#: config/i386/i386.c:36250
 #, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "le dernier argument doit être une valeur immédiate sur 32 bits"
 
-#: config/i386/i386.c:36329 config/powerpcspe/powerpcspe.c:16219
-#: config/rs6000/rs6000.c:15304
+#: config/i386/i386.c:36332 config/powerpcspe/powerpcspe.c:16219
+#: config/rs6000/rs6000.c:15348
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr "le sélecteur doit être une constante entière dans la plage 0..%wi"
 
-#: config/i386/i386.c:36539
+#: config/i386/i386.c:36542
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr "%qE a besoin d'une option isa inconnue"
 
-#: config/i386/i386.c:36543
+#: config/i386/i386.c:36546
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "%qE a besoin de l'option isa %s"
 
-#: config/i386/i386.c:37381
+#: config/i386/i386.c:37375
 #, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "le dernier argument doit être une valeur immédiate"
 
-#: config/i386/i386.c:38108 config/i386/i386.c:38290
+#: config/i386/i386.c:38102 config/i386/i386.c:38284
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "le dernier argument doit être une échelle 1, 2, 4, 8"
 
-#: config/i386/i386.c:38343
+#: config/i386/i386.c:38337
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "le quatrième argument doit être une échelle 1, 2, 4, 8"
 
-#: config/i386/i386.c:38349
+#: config/i386/i386.c:38343
 #, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr "opérande d'indice incorrect"
 
-#: config/i386/i386.c:38368
+#: config/i386/i386.c:38362
 #, gcc-internal-format
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr "l'argument de xabort doit être une valeur immédiate sur 8 bits"
 
-#: config/i386/i386.c:41431
+#: config/i386/i386.c:41425
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "l'attribut %qE est uniquement disponible en 32 bits"
 
-#: config/i386/i386.c:41452
+#: config/i386/i386.c:41446
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "l'argument de l'attribut %qE n'est ni zéro ni un"
 
-#: config/i386/i386.c:41485 config/i386/i386.c:41494
+#: config/i386/i386.c:41479 config/i386/i386.c:41488
 #, gcc-internal-format
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr "les attributs ms_abi et sysv_abi sont incompatibles"
 
-#: config/i386/i386.c:41530 config/powerpcspe/powerpcspe.c:35868
-#: config/rs6000/rs6000.c:33065
+#: config/i386/i386.c:41524 config/powerpcspe/powerpcspe.c:35868
+#: config/rs6000/rs6000.c:33121
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "l'attribut incompatible %qE est ignoré"
 
-#: config/i386/i386.c:41555 config/i386/i386.c:41577 config/ia64/ia64.c:815
+#: config/i386/i386.c:41549 config/i386/i386.c:41571 config/ia64/ia64.c:815
 #: config/s390/s390.c:1153
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "l'attribut %qE requiert un argument de type constante chaîne de caractères"
 
-#: config/i386/i386.c:41565 config/i386/i386.c:41587 config/s390/s390.c:1182
+#: config/i386/i386.c:41559 config/i386/i386.c:41581 config/s390/s390.c:1182
 #, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "l'argument de l'attribut %qE n'est pas (keep|thunk|thunk-inline|thunk-extern)"
 
-#: config/i386/i386.c:41619
+#: config/i386/i386.c:41613
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr "la routine de service d'interruption devrait avoir un pointeur comme premier argument"
 
-#: config/i386/i386.c:41626
+#: config/i386/i386.c:41620
 #, gcc-internal-format, gfc-internal-format
 msgid "interrupt service routine should have unsigned %sint as the second argument"
 msgstr "la routine de service d'interruption devrait avoir un « unsigned %sint » comme deuxième argument"
 
-#: config/i386/i386.c:41636
+#: config/i386/i386.c:41630
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr "la routine de service d'interruption ne peut avoir qu'un argument de type pointeur et un argument entier optionnel"
 
-#: config/i386/i386.c:41639
+#: config/i386/i386.c:41633
 #, gcc-internal-format
 msgid "interrupt service routine can't have non-void return value"
 msgstr "la routine de service d'interruption ne peut pas avoir une valeur de retour non void"
 
-#: config/i386/i386.c:44676
+#: config/i386/i386.c:44670
 #, gcc-internal-format
 msgid "alternatives not allowed in asm flag output"
 msgstr "les alternatives ne sont pas autorisées dans la sortie du fanion asm"
 
-#: config/i386/i386.c:44740
+#: config/i386/i386.c:44734
 #, gcc-internal-format
 msgid "unknown asm flag output %qs"
 msgstr "sortie du fanion asm %qs inconnue"
 
-#: config/i386/i386.c:44769
+#: config/i386/i386.c:44763
 #, gcc-internal-format
 msgid "invalid type for asm flag output"
 msgstr "type invalide pour la sortie du fanion asm"
 
-#: config/i386/i386.c:50634
+#: config/i386/i386.c:50628
 #, gcc-internal-format
 msgid "unknown architecture specific memory model"
 msgstr "modèle mémoire spécifique à l'architecture inconnu"
 
-#: config/i386/i386.c:50641
+#: config/i386/i386.c:50635
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr "HLE_ACQUIRE n'est pas utilisé avec le modèle mémoire ACQUIRE ou un autre plus contraignant"
 
-#: config/i386/i386.c:50647
+#: config/i386/i386.c:50641
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr "HLE_RELEASE n'est pas utilisé avec le modèle mémoire RELEASE ou un autre plus contraignant"
 
-#: config/i386/i386.c:50671 config/i386/i386.c:50787
+#: config/i386/i386.c:50665 config/i386/i386.c:50781
 #, gcc-internal-format, gfc-internal-format
 msgid "unsupported simdlen %d"
 msgstr "simdlen %d non supportée"
 
-#: config/i386/i386.c:50690
+#: config/i386/i386.c:50684
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd"
 msgstr "type de retour %qT non supporté pour simd"
 
-#: config/i386/i386.c:50712
+#: config/i386/i386.c:50706
 #, gcc-internal-format
 msgid "unsupported argument type %qT for simd"
 msgstr "type d'argument %qT non supporté pour simd"
 
-#: config/i386/i386.c:51033
+#: config/i386/i386.c:51027
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr "Le contrôleur de pointeurs requiert le support MPX sur cette cible. Utilisez les options -mmpx pour activer MPX."
@@ -29959,7 +30006,7 @@
 msgstr "interrupt_thread est disponible uniquement sur fido"
 
 #: config/m68k/m68k.c:1128 config/powerpcspe/powerpcspe.c:28512
-#: config/rs6000/rs6000.c:25791
+#: config/rs6000/rs6000.c:25868
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "l'expression limitant la pile n'est pas supportée"
@@ -30538,58 +30585,58 @@
 
 #. Trampoline is not supported on reduced-set registers yet.
 #: config/nds32/nds32.c:2327 config/nds32/nds32.c:2381
-#: config/nds32/nds32.c:3127 config/nds32/nds32.c:3201
-#: config/nds32/nds32.c:3216 config/nds32/nds32.c:3222
-#: config/nds32/nds32.c:3284 config/nds32/nds32.c:3290
-#: config/nds32/nds32.c:3322
+#: config/nds32/nds32.c:3128 config/nds32/nds32.c:3202
+#: config/nds32/nds32.c:3217 config/nds32/nds32.c:3223
+#: config/nds32/nds32.c:3285 config/nds32/nds32.c:3291
+#: config/nds32/nds32.c:3323
 #, gcc-internal-format
 msgid "a nested function is not supported for reduced registers"
 msgstr "une fonction imbriquée n'est pas supportée pour les registres réduits"
 
 #. The enum index value for array size is out of range.
-#: config/nds32/nds32.c:3025
+#: config/nds32/nds32.c:3026
 #, gcc-internal-format
 msgid "intrinsic register index is out of range"
 msgstr "l'index du registre intrinsèque est hors limite"
 
-#: config/nds32/nds32.c:3041 config/nds32/nds32.c:3048
-#: config/nds32/nds32.c:3055 config/nds32/nds32.c:3062
-#: config/nds32/nds32.c:3069
+#: config/nds32/nds32.c:3042 config/nds32/nds32.c:3049
+#: config/nds32/nds32.c:3056 config/nds32/nds32.c:3063
+#: config/nds32/nds32.c:3070
 #, gcc-internal-format
 msgid "CCTL intrinsic function subtype out of range!"
 msgstr "le sous-type de fonction intrinsèque CCTL est hors limite !"
 
-#: config/nds32/nds32.c:3508
+#: config/nds32/nds32.c:3509
 #, gcc-internal-format
 msgid "invalid id value for interrupt/exception attribute"
 msgstr "valeur d'identifiant invalide pour l'attribut d'interruption/exception"
 
-#: config/nds32/nds32.c:3536
+#: config/nds32/nds32.c:3537
 #, gcc-internal-format
 msgid "invalid id value for reset attribute"
 msgstr "valeur d'identifiant invalide pour l'attribut de réinitialisation"
 
-#: config/nds32/nds32.c:3552
+#: config/nds32/nds32.c:3553
 #, gcc-internal-format
 msgid "invalid nmi function for reset attribute"
 msgstr "fonction nmi invalide pour l'attribut de réinitialisation"
 
-#: config/nds32/nds32.c:3565
+#: config/nds32/nds32.c:3566
 #, gcc-internal-format
 msgid "invalid warm function for reset attribute"
 msgstr "fonction « warm » invalide pour l'attribut de réinitialisation"
 
-#: config/nds32/nds32.c:3638
+#: config/nds32/nds32.c:3639
 #, gcc-internal-format
 msgid "Disable FPU ISA, the ABI option must be enable '-mfloat-abi=soft'"
 msgstr "Désactiver l'ISA FPU, l'option ABI doit activer « -mfloat-abi=soft »"
 
-#: config/nds32/nds32.c:3641
+#: config/nds32/nds32.c:3642
 #, gcc-internal-format
 msgid "'-mabi=2fp+' option only support when FPU available, must be enable '-mext-fpu-sp' or '-mext-fpu-dp'"
 msgstr "L'option « -mabi=2fp+ » est supportée si un FPU est disponible, doit activer « -mext-fpu-sp » ou « -mext-fpu-dp »"
 
-#: config/nds32/nds32.c:3647
+#: config/nds32/nds32.c:3648
 #, gcc-internal-format
 msgid "position-independent code not supported"
 msgstr "le code indépendant de la position n'est pas supporté"
@@ -30923,12 +30970,12 @@
 msgid "junk at end of #pragma longcall"
 msgstr "rebut à la fin de #pragma longcall"
 
-#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6154
+#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6152
 #, gcc-internal-format
 msgid "vec_lvsl is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr "vec_lvsl est déprécié pour les petits boutistes; utilisation d'une affectation pour des chargements et des stockages non alignés"
 
-#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6158
+#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6156
 #, gcc-internal-format
 msgid "vec_lvsr is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr "vec_lvsr est déprécié pour les petits boutistes; utilisation d'une affectation pour des chargements et des stockages non alignés"
@@ -30978,7 +31025,7 @@
 msgid "vec_insert only accepts 3 arguments"
 msgstr "vec_insert accepte uniquement 3 arguments"
 
-#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6868
+#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6866
 #, gcc-internal-format
 msgid "passing arg %d of %qE discards qualifiers from pointer target type"
 msgstr "le passage de l'argument %d de %qE abandonne les qualificatifs du type cible du pointeur"
@@ -31063,7 +31110,7 @@
 msgid "target attribute or pragma changes SPE ABI"
 msgstr "l'attribut cible ou le pragma change l'ABI SPE"
 
-#: config/powerpcspe/powerpcspe.c:4351 config/rs6000/rs6000.c:4223
+#: config/powerpcspe/powerpcspe.c:4351 config/rs6000/rs6000.c:4243
 #, gcc-internal-format
 msgid "AltiVec not supported in this target"
 msgstr "AltiVec pas supporté par cette cible"
@@ -31209,7 +31256,7 @@
 msgid "-mvsx-small-integer requires -mpower8-vector, -mupper-regs-di, and -mdirect-move"
 msgstr "-mvsx-small-integer requiert -mpower8-vector, -mupper-regs-di et -mdirect-move"
 
-#: config/powerpcspe/powerpcspe.c:4959 config/rs6000/rs6000.c:4601
+#: config/powerpcspe/powerpcspe.c:4959 config/rs6000/rs6000.c:4628
 #, gcc-internal-format
 msgid "target attribute or pragma changes long double size"
 msgstr "l'attribut cible ou le pragma change la taille du double long"
@@ -31250,22 +31297,22 @@
 msgstr "type d'ABI de la bibliothèque de vectorisation (%s) inconnu pour l'option -mveclibabi="
 
 #: config/powerpcspe/powerpcspe.c:5140 config/powerpcspe/powerpcspe.c:5155
-#: config/rs6000/rs6000.c:4766 config/rs6000/rs6000.c:4781
+#: config/rs6000/rs6000.c:4791 config/rs6000/rs6000.c:4806
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr "l'attribut cible ou le pragma change l'ABI AltiVec"
 
-#: config/powerpcspe/powerpcspe.c:5168 config/rs6000/rs6000.c:4794
+#: config/powerpcspe/powerpcspe.c:5168 config/rs6000/rs6000.c:4819
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr "l'attribut cible ou le pragma change l'ABI darwin64"
 
-#: config/powerpcspe/powerpcspe.c:5234 config/rs6000/rs6000.c:4828
+#: config/powerpcspe/powerpcspe.c:5234 config/rs6000/rs6000.c:4853
 #, gcc-internal-format
 msgid "target attribute or pragma changes single precision floating point"
 msgstr "l'attribut cible ou le pragma change la virgule flottante simple précision"
 
-#: config/powerpcspe/powerpcspe.c:5237 config/rs6000/rs6000.c:4831
+#: config/powerpcspe/powerpcspe.c:5237 config/rs6000/rs6000.c:4856
 #, gcc-internal-format
 msgid "target attribute or pragma changes double precision floating point"
 msgstr "l'attribut cible ou le pragma change la virgule flottante double précision"
@@ -31275,12 +31322,12 @@
 msgid "-mstack-protector-guard=tls needs a valid base register"
 msgstr "-mstack-protector-guard=tls a besoin d'un registre de base valable"
 
-#: config/powerpcspe/powerpcspe.c:8415 config/rs6000/rs6000.c:7925
+#: config/powerpcspe/powerpcspe.c:8415 config/rs6000/rs6000.c:7950
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr "l'agencement des agrégats contenant des vecteurs alignés sur %d octets a changé avec GCC 5"
 
-#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11237
+#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11269
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "vecteur GCC retourné par référence: extension ABI non standard sans aucune garantie de compatibilité"
@@ -31290,7 +31337,7 @@
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "la valeur ne peut être retournée dans le registre vectoriel parce que les instructions altivec sont désactivées, utilisez -maltivec pour les autoriser"
 
-#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11595
+#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11633
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr "l'ABI pour passer des agrégats avec un alignement sur %d octets a changé avec GCC 5"
@@ -31300,12 +31347,12 @@
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "l'argument ne peut pas être passé dans le registre vectoriel parce que les instructions altivec sont désactivées, utilisez -maltivec pour les autoriser"
 
-#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12604
+#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12648
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr "l'ABI pour passer des agrégats de flottants homogènes a changé avec GCC 5"
 
-#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12779
+#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12823
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "vecteur GCC passé par référence: extension ABI non standard sans aucune garantie de compatibilité"
@@ -31315,28 +31362,28 @@
 msgid "internal error: builtin function %s already processed"
 msgstr "erreur interne: fonction interne %s déjà traitée"
 
-#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:13971
+#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:14015
 #, gcc-internal-format
 msgid "argument 1 must be an 8-bit field value"
 msgstr "l'argument 1 doit être une valeur de champ sur 8 bits"
 
-#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14015
+#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14059
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "l'argument 1 doit être un littéral signé de 5 bits"
 
 #: config/powerpcspe/powerpcspe.c:14934 config/powerpcspe/powerpcspe.c:16803
-#: config/rs6000/rs6000.c:14101
+#: config/rs6000/rs6000.c:14145
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "l'argument 2 doit être un littéral non signé de 5 bits"
 
-#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14119
+#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14163
 #, gcc-internal-format
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "l'argument 1 doit être un littéral non signé de 6 bits"
 
-#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14135
+#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14179
 #, gcc-internal-format
 msgid "argument 2 must be a 7-bit unsigned literal"
 msgstr "l'argument 2 doit être un littéral non signé de 7 bits"
@@ -31356,12 +31403,12 @@
 msgid "builtin %s is only valid in 64-bit mode"
 msgstr "la fonction interne %s est uniquement valable en mode 64 bits"
 
-#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14791
+#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14835
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %d must be an unsigned literal"
 msgstr "l'argument %d doit être un littéral non signé"
 
-#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14793
+#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14837
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "l'argument %d est un littéral non signé qui est hors limite"
@@ -31383,53 +31430,53 @@
 msgid "hwcap %s is an invalid argument to builtin %s"
 msgstr "le hwcap %s est un argument invalide pour la fonction interne %s"
 
-#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15065
+#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15109
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "l'argument 3 doit être un littéral non signé de 4 bits"
 
-#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15090
+#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15134
 #, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "l'argument 3 doit être un littéral non signé de 2 bits"
 
-#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15110
+#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15154
 #, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "l'argument 3 doit être un littéral non signé de 1 bit"
 
-#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15122
+#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15166
 #, gcc-internal-format
 msgid "argument 1 must be 0 or 2"
 msgstr "l'argument 1 doit être 0 ou 2"
 
-#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15134
+#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15178
 #, gcc-internal-format
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "l'argument 1 doit être un littéral non signé de 1 bit"
 
-#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15148
+#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15192
 #, gcc-internal-format
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "l'argument 2 doit être un littéral non signé de 6 bits"
 
-#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15160
+#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15204
 #, gcc-internal-format
 msgid "argument 2 must be 0 or 1"
 msgstr "l'argument 1 doit être 0 ou 1"
 
-#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15168
+#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15212
 #, gcc-internal-format
 msgid "argument 3 must be in the range 0..15"
 msgstr "l'argument 3 doit être dans la plage 0..15"
 
-#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15237
-#: config/rs6000/rs6000.c:15569
+#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15281
+#: config/rs6000/rs6000.c:15613
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "l'argument de %qs doit être un littéral non signé de 2 bits"
 
-#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15394
+#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15438
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr "surcharge non résolue pour la fonction Altivec interne %qF"
@@ -31554,7 +31601,7 @@
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr "erreur interne: pour la fonction interne %s, l'argument %d a le type %s inattendu"
 
-#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25758
+#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25835
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr "trame de pile trop grande"
@@ -31564,12 +31611,12 @@
 msgid "-fsplit-stack uses register r29"
 msgstr "-fsplit-stack utilise le registre r29"
 
-#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29459
+#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29536
 #, gcc-internal-format
 msgid "Stack frame larger than 2G is not supported for -fsplit-stack"
 msgstr "Une trame de pile plus grande que 2G n'est pas supportée par -fsplit-stack"
 
-#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30447
+#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30524
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "pas de profilage du code 64 bits pour cette ABI"
@@ -31579,22 +31626,22 @@
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr "Vous ne pouvez pas prendre l'adresse d'une fonction imbriquée si vous utilisez l'option -mno-pointers-to-nested-functions."
 
-#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32830
+#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32907
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "l'utilisation de %<long double%> dans les types AltiVec est invalide"
 
-#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32832
+#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32909
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "l'utilisation des types booléens dans les types AltiVec est invalide"
 
-#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32834
+#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32911
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "l'utilisation de %<complex%> dans les types AltiVec est invalide"
 
-#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32836
+#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32913
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr "l'utilisation de types décimaux en virgule flottante dans les types AltiVec est invalide"
@@ -31604,7 +31651,7 @@
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr "l'utilisation de %<long%> dans les types AltiVec est invalide pour du code 64 bits sans -mvsx"
 
-#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32845
+#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32922
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "l'utilisation de %<long%> dans les types Altivec est obsolète; utilisez %<int%>"
@@ -32148,72 +32195,72 @@
 "Nom de processeur non supporté retourné par le noyau pour -mcpu=native: %s\n"
 "Veuillez utiliser un nom de processeur explicite.  Les noms de processeurs valides sont: %s"
 
-#: config/rs6000/rs6000-c.c:6168 config/rs6000/rs6000-c.c:6219
-#: config/rs6000/rs6000-c.c:6489 config/rs6000/rs6000-c.c:6555
-#: config/rs6000/rs6000-c.c:6916 config/rs6000/rs6000-c.c:6963
+#: config/rs6000/rs6000-c.c:6166 config/rs6000/rs6000-c.c:6217
+#: config/rs6000/rs6000-c.c:6487 config/rs6000/rs6000-c.c:6553
+#: config/rs6000/rs6000-c.c:6914 config/rs6000/rs6000-c.c:6961
 #, gcc-internal-format
 msgid "builtin %qs only accepts 2 arguments"
 msgstr "la fonction interne %qs n'accepte que 2 arguments"
 
-#: config/rs6000/rs6000-c.c:6292 config/rs6000/rs6000-c.c:6375
-#: config/rs6000/rs6000-c.c:6736
+#: config/rs6000/rs6000-c.c:6290 config/rs6000/rs6000-c.c:6373
+#: config/rs6000/rs6000-c.c:6734
 #, gcc-internal-format
 msgid "builtin %qs only accepts 3 arguments"
 msgstr "la fonction interne %qs n'accepte que 3 arguments"
 
-#: config/rs6000/rs6000-c.c:6484
+#: config/rs6000/rs6000-c.c:6482
 #, gcc-internal-format
 msgid "builtin %qs only accepts 1 argument"
 msgstr "la fonction interne %qs n'accepte qu'un argument"
 
-#: config/rs6000/rs6000-c.c:7054
+#: config/rs6000/rs6000-c.c:7052
 #, gcc-internal-format
 msgid "builtin %qs requires builtin %qs"
 msgstr "l'interne %qs requiert l'interne %qs"
 
-#: config/rs6000/rs6000-c.c:7058
+#: config/rs6000/rs6000-c.c:7056
 #, gcc-internal-format
 msgid "builtin function %qs not supported in this compiler configuration"
 msgstr "la fonction interne %qs n'est pas supportée dans cette configuration du compilateur"
 
-#: config/rs6000/rs6000-c.c:7068
+#: config/rs6000/rs6000-c.c:7066
 #, gcc-internal-format
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr "combinaison invalide de paramètres pour l'intrinsèque Altivec %qs"
 
 # le premier %qs est un mot non traduit tel que « private », « shared » ou « threadprivate ».
-#: config/rs6000/rs6000.c:3754 config/rs6000/rs6000.c:3757
-#: config/rs6000/rs6000.c:3760
+#: config/rs6000/rs6000.c:3772 config/rs6000/rs6000.c:3775
+#: config/rs6000/rs6000.c:3778
 #, gcc-internal-format
 msgid "%qs requires %qs or %qs"
 msgstr "%qs requiert %qs ou %qs"
 
-#: config/rs6000/rs6000.c:3861
+#: config/rs6000/rs6000.c:3879
 #, gcc-internal-format
 msgid "%qs requires PowerPC64 architecture, enabling"
 msgstr "%qs requiert une architecture PowerPC64, elle est maintenant activée"
 
-#: config/rs6000/rs6000.c:4037
+#: config/rs6000/rs6000.c:4057
 #, gcc-internal-format
 msgid "%qs command-line option is deprecated"
 msgstr "l'option de la ligne de commande %qs est obsolète"
 
-#: config/rs6000/rs6000.c:4048
+#: config/rs6000/rs6000.c:4068
 #, gcc-internal-format
 msgid "%qs is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr "%qs n'est pas supporté sur Darwin 64 bits; il est incompatible avec les bibliothèques C et C++ installées"
 
-#: config/rs6000/rs6000.c:4147
+#: config/rs6000/rs6000.c:4167
 #, gcc-internal-format
 msgid "will not generate %qs instructions because assembler lacks %qs support"
 msgstr "ne générera pas d'instructions %s car l'assembleur ne supporte pas %s"
 
-#: config/rs6000/rs6000.c:4240
+#: config/rs6000/rs6000.c:4260
 #, gcc-internal-format
 msgid "%qs is not supported on little endian systems"
 msgstr "%qs n'est pas supporté sur des systèmes petits boutistes"
 
-#: config/rs6000/rs6000.c:4333
+#: config/rs6000/rs6000.c:4353
 #, gcc-internal-format
 msgid "power9 target option is incompatible with %<%s=<xxx>%> for <xxx> less than power9"
 msgstr "l'option de la cible power9 est incompatible avec %<%s=<xxx>%> pour <xxx> inférieur à power9"
@@ -32220,7 +32267,7 @@
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:4341
+#: config/rs6000/rs6000.c:4361
 #, gcc-internal-format
 msgid "%qs incompatible with explicitly disabled options"
 msgstr "%qs est incompatible avec les options explicitement désactivées"
@@ -32229,240 +32276,241 @@
 #. error messages.  However, if users have managed to select
 #. power9-fusion without selecting power8-fusion, they
 #. already know about undocumented flags.
-#: config/rs6000/rs6000.c:4366 config/rs6000/rs6000.c:4373
-#: config/rs6000/rs6000.c:4380 config/rs6000/rs6000.c:4388
-#: config/rs6000/rs6000.c:4407 config/rs6000/rs6000.c:4464
-#: config/rs6000/rs6000.c:4468 config/rs6000/rs6000.c:4485
-#: config/rs6000/rs6000.c:4538 config/rs6000/rs6000.c:4565
-#: config/rs6000/rs6000.c:4580 config/rs6000/rs6000.c:4588
-#: config/rs6000/rs6000.c:4684
+#: config/rs6000/rs6000.c:4386 config/rs6000/rs6000.c:4393
+#: config/rs6000/rs6000.c:4400 config/rs6000/rs6000.c:4408
+#: config/rs6000/rs6000.c:4427 config/rs6000/rs6000.c:4484
+#: config/rs6000/rs6000.c:4488 config/rs6000/rs6000.c:4505
+#: config/rs6000/rs6000.c:4558 config/rs6000/rs6000.c:4585
+#: config/rs6000/rs6000.c:4600 config/rs6000/rs6000.c:4608
+#: config/rs6000/rs6000.c:4709
 #, gcc-internal-format
 msgid "%qs requires %qs"
 msgstr "%qs requiert %qs"
 
-#: config/rs6000/rs6000.c:4625
+#: config/rs6000/rs6000.c:4650
 #, gcc-internal-format
 msgid "Using IEEE extended precision long double"
 msgstr "Utilisation du long double en précision étendue de IEEE"
 
-#: config/rs6000/rs6000.c:4627
+#: config/rs6000/rs6000.c:4652
 #, gcc-internal-format
 msgid "Using IBM extended precision long double"
 msgstr "Utilisation du long double en précision étendue de IBM"
 
-#: config/rs6000/rs6000.c:4644
+#: config/rs6000/rs6000.c:4669
 #, gcc-internal-format
 msgid "%qs requires VSX support"
 msgstr "%qs requiert le support VSX"
 
-#: config/rs6000/rs6000.c:4653
+#: config/rs6000/rs6000.c:4678
 #, gcc-internal-format
 msgid "The -mfloat128 option may not be fully supported"
 msgstr "L'option -mfloat128 peut ne pas être totalement supportée"
 
-#: config/rs6000/rs6000.c:4676
+#: config/rs6000/rs6000.c:4701
 #, gcc-internal-format
 msgid "%qs requires full ISA 3.0 support"
 msgstr "%qs requiert le support ISA 3.0 complet"
 
-#: config/rs6000/rs6000.c:4743
+#: config/rs6000/rs6000.c:4768
 #, gcc-internal-format
 msgid "unknown vectorization library ABI type (%qs) for %qs switch"
 msgstr "type d'ABI de la bibliothèque de vectorisation (%qs) inconnu pour l'option %qs"
 
-#: config/rs6000/rs6000.c:4930
+#: config/rs6000/rs6000.c:4955
 #, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr "%qs n'est pas un nombre valide dans %qs"
 
-#: config/rs6000/rs6000.c:4935
+#: config/rs6000/rs6000.c:4960
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr "%qs n'est pas un décalage valide dans %qs"
 
-#: config/rs6000/rs6000.c:4947
+#: config/rs6000/rs6000.c:4972
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %qs"
 msgstr "%qs n'est pas un registre de base valable dans %qs"
 
-#: config/rs6000/rs6000.c:4955
+#: config/rs6000/rs6000.c:4980
 #, gcc-internal-format
 msgid "%qs needs a valid base register"
 msgstr "%qs a besoin d'un registre de base valable"
 
-#: config/rs6000/rs6000.c:5253
+#: config/rs6000/rs6000.c:5278
 #, gcc-internal-format
 msgid "unknown option for %<%s=%s%>"
 msgstr "option inconnue pour %<%s=%s%>"
 
-#: config/rs6000/rs6000.c:5290
+#: config/rs6000/rs6000.c:5315
 #, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr "%qs est déprécié et recommandé dans aucune circonstance"
 
-#: config/rs6000/rs6000.c:11401
+#: config/rs6000/rs6000.c:11439
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr "la valeur ne peut être retournée dans le registre vectoriel parce que les instructions altivec sont désactivées, utilisez %qs pour les autoriser"
 
-#: config/rs6000/rs6000.c:11862
+#: config/rs6000/rs6000.c:11906
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr "l'argument ne peut pas être passé dans le registre vectoriel parce que les instructions altivec sont désactivées, utilisez %qs pour les autoriser"
 
-#: config/rs6000/rs6000.c:13572
+#: config/rs6000/rs6000.c:13616
 #, gcc-internal-format
 msgid "internal error: builtin function %qs already processed"
 msgstr "erreur interne: fonction interne %qs déjà traitée"
 
-#: config/rs6000/rs6000.c:14150
+#: config/rs6000/rs6000.c:14194
 #, gcc-internal-format
 msgid "argument 2 must be a 1-bit unsigned literal"
 msgstr "l'argument 2 doit être un littéral non signé de 1 bit"
 
-#: config/rs6000/rs6000.c:14189
+#: config/rs6000/rs6000.c:14233
 #, gcc-internal-format
 msgid "argument 1 of %qs must be a constant"
 msgstr "l'argument 1 de %qs doit être une constante"
 
-#: config/rs6000/rs6000.c:14247 config/rs6000/rs6000.c:15898
+#: config/rs6000/rs6000.c:14291 config/rs6000/rs6000.c:15942
 #, gcc-internal-format
 msgid "argument 1 of %qs is out of range"
 msgstr "l'argument 1 de %qs est hors limite"
 
-#: config/rs6000/rs6000.c:14742
+#: config/rs6000/rs6000.c:14786
 #, gcc-internal-format
 msgid "builtin %qs is only valid in 64-bit mode"
 msgstr "la fonction interne %qs est uniquement valable en mode 64 bits"
 
-#: config/rs6000/rs6000.c:14939
+#: config/rs6000/rs6000.c:14983
 #, gcc-internal-format
 msgid "builtin %qs only accepts a string argument"
 msgstr "la fonction interne %qs n'accepte qu'une chaîne comme argument"
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000.c:14958
+#: config/rs6000/rs6000.c:15002
 #, gcc-internal-format
 msgid "cpu %qs is an invalid argument to builtin %qs"
 msgstr "le processeur %qs est un argument invalide pour la fonction interne %qs"
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000.c:14986
+#: config/rs6000/rs6000.c:15030
 #, gcc-internal-format
 msgid "%s %qs is an invalid argument to builtin %qs"
 msgstr "%s %qs est un argument invalide pour la fonction interne %qs"
 
-#: config/rs6000/rs6000.c:15012
+#: config/rs6000/rs6000.c:15056
 #, gcc-internal-format
 msgid "builtin %qs needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr "la fonction interne %qs requiert GLIBC (2.23 ou plus récent) qui exporte des bits de capacité matérielle"
 
-#: config/rs6000/rs6000.c:15616
+#: config/rs6000/rs6000.c:15660
 #, gcc-internal-format
 msgid "second argument to %qs must be 0..12"
 msgstr "le deuxième argument de %qs doit être 0..12"
 
-#: config/rs6000/rs6000.c:15631
+#: config/rs6000/rs6000.c:15675
 #, gcc-internal-format
 msgid "third argument to %qs must be 0..12"
 msgstr "le troisième argument de %qs doit être 0..12"
 
-#: config/rs6000/rs6000.c:15850
+#: config/rs6000/rs6000.c:15894
 #, gcc-internal-format, gfc-internal-format
 msgid "argument 1 of %s must be a constant"
 msgstr "l'argument 1 de %s doit être une constante"
 
-#: config/rs6000/rs6000.c:15932
+#: config/rs6000/rs6000.c:15976
 #, gcc-internal-format
 msgid "builtin function %qs is only valid for the cell processor"
 msgstr "la fonction interne %qs est uniquement valable pour le processeur cell"
 
-#: config/rs6000/rs6000.c:15934 config/rs6000/rs6000.c:15936
-#: config/rs6000/rs6000.c:15938 config/rs6000/rs6000.c:15940
-#: config/rs6000/rs6000.c:15946 config/rs6000/rs6000.c:15948
-#: config/rs6000/rs6000.c:15955 config/rs6000/rs6000.c:15962
-#: config/rs6000/rs6000.c:15969 config/rs6000/rs6000.c:15975
+#: config/rs6000/rs6000.c:15978 config/rs6000/rs6000.c:15980
+#: config/rs6000/rs6000.c:15982 config/rs6000/rs6000.c:15984
+#: config/rs6000/rs6000.c:15990 config/rs6000/rs6000.c:15992
+#: config/rs6000/rs6000.c:15999 config/rs6000/rs6000.c:16006
+#: config/rs6000/rs6000.c:16011 config/rs6000/rs6000.c:16014
+#: config/rs6000/rs6000.c:16018 config/rs6000/rs6000.c:16024
 #, gcc-internal-format
 msgid "builtin function %qs requires the %qs option"
 msgstr "la fonction interne %qs requiert l'option %qs"
 
-#: config/rs6000/rs6000.c:15943 config/rs6000/rs6000.c:15952
-#: config/rs6000/rs6000.c:15959 config/rs6000/rs6000.c:15966
+#: config/rs6000/rs6000.c:15987 config/rs6000/rs6000.c:15996
+#: config/rs6000/rs6000.c:16003
 #, gcc-internal-format
 msgid "builtin function %qs requires the %qs and %qs options"
 msgstr "la fonction interne %qs requiert les options %qs et %qs"
 
-#: config/rs6000/rs6000.c:15972
+#: config/rs6000/rs6000.c:16021
 #, gcc-internal-format
 msgid "builtin function %qs requires ISA 3.0 IEEE 128-bit floating point"
 msgstr "la fonction interne %qs requiert l'ISA 3.0 en virgule flottante IEEE 128 bits"
 
-#: config/rs6000/rs6000.c:15978
+#: config/rs6000/rs6000.c:16027
 #, gcc-internal-format
 msgid "builtin function %qs requires the %qs (or newer), and %qs or %qs options"
 msgstr "la fonction interne %qs requiert les options %qs (ou plus récente) et %qs ou %qs"
 
-#: config/rs6000/rs6000.c:15982
+#: config/rs6000/rs6000.c:16031
 #, gcc-internal-format
 msgid "builtin function %qs is not supported with the current options"
 msgstr "la fonction interne %qs n'est pas supportée avec les options actuelles"
 
-#: config/rs6000/rs6000.c:18218
+#: config/rs6000/rs6000.c:18290
 #, gcc-internal-format
 msgid "internal error: builtin function %qs had an unexpected return type %qs"
 msgstr "erreur interne: la fonction interne %qs a un type de retour %qs inattendu"
 
-#: config/rs6000/rs6000.c:18235
+#: config/rs6000/rs6000.c:18307
 #, gcc-internal-format
 msgid "internal error: builtin function %qs, argument %d had unexpected argument type %qs"
 msgstr "erreur interne: pour la fonction interne %qs, l'argument %d a le type %qs inattendu"
 
-#: config/rs6000/rs6000.c:29451
+#: config/rs6000/rs6000.c:29528
 #, gcc-internal-format
 msgid "%qs uses register r29"
 msgstr "%qs utilise le registre r29"
 
-#: config/rs6000/rs6000.c:32748
+#: config/rs6000/rs6000.c:32825
 #, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "Vous ne pouvez pas prendre l'adresse d'une fonction imbriquée si vous utilisez l'option %qs"
 
-#: config/rs6000/rs6000.c:32842
+#: config/rs6000/rs6000.c:32919
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "l'utilisation de %<long%> dans les types AltiVec est invalide pour du code 64 bits sans %qs"
 
-#: config/rs6000/rs6000.c:32850
+#: config/rs6000/rs6000.c:32927
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "l'utilisation de %<long long%> dans les types AltiVec est invalide sans %qs"
 
-#: config/rs6000/rs6000.c:32853
+#: config/rs6000/rs6000.c:32930
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "l'utilisation de %<double%> dans les types AltiVec est invalide sans %qs"
 
-#: config/rs6000/rs6000.c:36876
+#: config/rs6000/rs6000.c:36932
 #, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "processeur %qs invalide pour %s\"%s\"%s"
 
-#: config/rs6000/rs6000.c:36879
+#: config/rs6000/rs6000.c:36935
 #, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr "%s\"%s\"%s n'est pas permis"
 
-#: config/rs6000/rs6000.c:36881
+#: config/rs6000/rs6000.c:36937
 #, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr "%s\"%s\"%s est invalide"
 
-#: config/rs6000/rs6000.c:37416
+#: config/rs6000/rs6000.c:37472
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr "%<-mno-%s%> désactive %<-m%s%>"
 
-#: config/rs6000/rs6000.c:37575
+#: config/rs6000/rs6000.c:37631
 #, gcc-internal-format
 msgid "target_clones attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr "l'attribut target_clones requiert GLIBC (2.23 ou plus récent) qui exporte des bits de capacité matérielle"
@@ -33199,48 +33247,48 @@
 msgid "subprogram %q+F not marked Inline"
 msgstr "le sous-programme %q+F n'est pas marqué comme étant Inline"
 
-#: ada/gcc-interface/trans.c:6404
+#: ada/gcc-interface/trans.c:6401
 #, gcc-internal-format
 msgid "out-of-bounds access may be optimized away"
 msgstr "l'accès hors limites peut être éliminé par l'optimisation"
 
-#: ada/gcc-interface/trans.c:6406
+#: ada/gcc-interface/trans.c:6403
 #, gcc-internal-format
 msgid "containing loop"
 msgstr "boucle contenante"
 
-#: ada/gcc-interface/utils.c:3887
+#: ada/gcc-interface/utils.c:3890
 #, gcc-internal-format
 msgid "invalid element type for attribute %qs"
 msgstr "type d'élément invalide pour l'attribut %qs"
 
-#: ada/gcc-interface/utils.c:3911
+#: ada/gcc-interface/utils.c:3914
 #, gcc-internal-format
 msgid "number of components of vector not a power of two"
 msgstr "le nombre d'éléments du vecteur n'est pas une puissance de deux"
 
-#: ada/gcc-interface/utils.c:6037 ada/gcc-interface/utils.c:6215
-#: ada/gcc-interface/utils.c:6322
+#: ada/gcc-interface/utils.c:6043 ada/gcc-interface/utils.c:6220
+#: ada/gcc-interface/utils.c:6327
 #, gcc-internal-format
 msgid "%qs attribute ignored"
 msgstr "attribut %qs ignoré"
 
-#: ada/gcc-interface/utils.c:6158
+#: ada/gcc-interface/utils.c:6164
 #, gcc-internal-format
 msgid "%qs attribute requires prototypes with named arguments"
 msgstr "l'attribut %qs requiert des prototypes avec des arguments nommés"
 
-#: ada/gcc-interface/utils.c:6167
+#: ada/gcc-interface/utils.c:6173
 #, gcc-internal-format
 msgid "%qs attribute only applies to variadic functions"
 msgstr "l'attribut %qs s’applique seulement aux fonctions variadiques"
 
-#: ada/gcc-interface/utils.c:6282
+#: ada/gcc-interface/utils.c:6287
 #, gcc-internal-format
 msgid "%qE attribute has no effect"
 msgstr "l'attribut %qE n'a pas d’effet"
 
-#: ada/gcc-interface/utils.c:6406
+#: ada/gcc-interface/utils.c:6411
 #, gcc-internal-format
 msgid "attribute %qs applies to array types only"
 msgstr "l'attribut %qs s'applique seulement aux types tableaux"
@@ -33255,7 +33303,7 @@
 #. an unprototyped function, it is compile-time undefined;
 #. making it a constraint in that case was rejected in
 #. DR#252.
-#: c/c-convert.c:101 c/c-typeck.c:2175 c/c-typeck.c:6507 c/c-typeck.c:12138
+#: c/c-convert.c:101 c/c-typeck.c:2175 c/c-typeck.c:6512 c/c-typeck.c:12143
 #: cp/typeck.c:2027 cp/typeck.c:7977 cp/typeck.c:8742
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
@@ -33316,7 +33364,7 @@
 msgid "type of array %q+D completed incompatibly with implicit initialization"
 msgstr "le type du tableau %q+D est complété de manière incompatible avec une initialisation implicite"
 
-#: c/c-decl.c:1567 c/c-decl.c:6701 c/c-decl.c:7574 c/c-decl.c:8381
+#: c/c-decl.c:1567 c/c-decl.c:6721 c/c-decl.c:7594 c/c-decl.c:8401
 #, gcc-internal-format
 msgid "originally defined here"
 msgstr "défini initialement ici"
@@ -33721,16 +33769,11 @@
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.c:4548 c/c-decl.c:7147
+#: c/c-decl.c:4548 c/c-decl.c:7167
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr "%<[*]%> n'est pas permis ailleurs que dans la portée du prototype d'une fonction"
 
-#: c/c-decl.c:4635 cp/decl2.c:1520
-#, gcc-internal-format
-msgid "%q+D in declare target directive does not have mappable type"
-msgstr "%q+D dans la directive de déclaration de cible n'a pas de type pour lequel une correspondance peut être établie (mappable type)"
-
 #: c/c-decl.c:4693
 #, gcc-internal-format
 msgid "%q+D is usually a function"
@@ -33756,7 +33799,7 @@
 #. of VLAs themselves count as VLAs, it does not make
 #. sense to permit them to be initialized given that
 #. ordinary VLAs may not be initialized.
-#: c/c-decl.c:4732 c/c-decl.c:4747 c/c-typeck.c:7630
+#: c/c-decl.c:4732 c/c-decl.c:4747 c/c-typeck.c:7635
 #, gcc-internal-format
 msgid "variable-sized object may not be initialized"
 msgstr "un objet de taille variable peut ne pas être initialisé"
@@ -33816,202 +33859,207 @@
 msgid "uninitialized const %qD is invalid in C++"
 msgstr "la constante %qD non initialisée est invalide en C++"
 
-#: c/c-decl.c:5268
+#: c/c-decl.c:5224 cp/decl.c:7318
 #, gcc-internal-format
+msgid "%q+D in declare target directive does not have mappable type"
+msgstr "%q+D dans la directive de déclaration de cible n'a pas de type pour lequel une correspondance peut être établie (mappable type)"
+
+#: c/c-decl.c:5288
+#, gcc-internal-format
 msgid "ISO C forbids forward parameter declarations"
 msgstr "le C ISO interdit la déclaration anticipée des paramètres"
 
-#: c/c-decl.c:5371
+#: c/c-decl.c:5391
 #, gcc-internal-format
 msgid "defining a type in a compound literal is invalid in C++"
 msgstr "définir un type dans un littéral composé (compound literal) est invalide en C++"
 
-#: c/c-decl.c:5425 c/c-decl.c:5440
+#: c/c-decl.c:5445 c/c-decl.c:5460
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant"
 msgstr "la largeur du champ de bits %qs n'est pas une constante entière"
 
-#: c/c-decl.c:5435
+#: c/c-decl.c:5455
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant expression"
 msgstr "la largeur du champ de bits %qs n'est pas une expression constante entière"
 
-#: c/c-decl.c:5446
+#: c/c-decl.c:5466
 #, gcc-internal-format
 msgid "negative width in bit-field %qs"
 msgstr "largeur négative du champ de bits %qs"
 
-#: c/c-decl.c:5451
+#: c/c-decl.c:5471
 #, gcc-internal-format
 msgid "zero width for bit-field %qs"
 msgstr "largeur nulle pour le champ de bits %qs"
 
-#: c/c-decl.c:5461
+#: c/c-decl.c:5481
 #, gcc-internal-format
 msgid "bit-field %qs has invalid type"
 msgstr "le champ de bits %qs a un type invalide"
 
-#: c/c-decl.c:5467
+#: c/c-decl.c:5487
 #, gcc-internal-format
 msgid "cannot declare bit-field %qs with %<warn_if_not_aligned%> type"
 msgstr "ne peut déclarer le champ de bits %qs avec un type %<warn_if_not_aligned%>"
 
-#: c/c-decl.c:5478
+#: c/c-decl.c:5498
 #, gcc-internal-format
 msgid "type of bit-field %qs is a GCC extension"
 msgstr "le type de champ de bit %qs est une extension de GCC"
 
-#: c/c-decl.c:5484
+#: c/c-decl.c:5504
 #, gcc-internal-format
 msgid "width of %qs exceeds its type"
 msgstr "la largeur de %qs excède son type"
 
-#: c/c-decl.c:5497
+#: c/c-decl.c:5517
 #, gcc-internal-format
 msgid "%qs is narrower than values of its type"
 msgstr "%qs est plus étroit que les valeurs de son type"
 
-#: c/c-decl.c:5512
+#: c/c-decl.c:5532
 #, gcc-internal-format
 msgid "ISO C90 forbids array %qE whose size can%'t be evaluated"
 msgstr "le C90 ISO interdit le tableau %qE dont la taille ne peut être évaluée"
 
-#: c/c-decl.c:5515
+#: c/c-decl.c:5535
 #, gcc-internal-format
 msgid "ISO C90 forbids array whose size can%'t be evaluated"
 msgstr "le C90 ISO interdit le tableau dont la taille ne peut être évaluée"
 
-#: c/c-decl.c:5522
+#: c/c-decl.c:5542
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array %qE"
 msgstr "le C90 ISO interdit le tableau %qE de taille variable"
 
-#: c/c-decl.c:5524
+#: c/c-decl.c:5544
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array"
 msgstr "le C90 ISO interdit le tableau de taille variable"
 
-#: c/c-decl.c:5733 c/c-decl.c:6107 c/c-decl.c:6117
+#: c/c-decl.c:5753 c/c-decl.c:6127 c/c-decl.c:6137
 #, gcc-internal-format
 msgid "variably modified %qE at file scope"
 msgstr "%qE modifié par une variable ayant une portée sur tout le fichier"
 
-#: c/c-decl.c:5735
+#: c/c-decl.c:5755
 #, gcc-internal-format
 msgid "variably modified field at file scope"
 msgstr "champ modifié par une variable au niveau de la portée du fichier"
 
-#: c/c-decl.c:5755
+#: c/c-decl.c:5775
 #, gcc-internal-format
 msgid "type defaults to %<int%> in declaration of %qE"
 msgstr "le type %<int%> est utilisé par défaut dans la déclaration de %qE"
 
-#: c/c-decl.c:5759
+#: c/c-decl.c:5779
 #, gcc-internal-format
 msgid "type defaults to %<int%> in type name"
 msgstr "le type %<int%> est utilisé par défaut dans le nom du type"
 
-#: c/c-decl.c:5791
+#: c/c-decl.c:5811
 #, gcc-internal-format
 msgid "duplicate %<const%>"
 msgstr "%<const%> dupliqué"
 
-#: c/c-decl.c:5793
+#: c/c-decl.c:5813
 #, gcc-internal-format
 msgid "duplicate %<restrict%>"
 msgstr "%<restrict%> dupliqué"
 
-#: c/c-decl.c:5795
+#: c/c-decl.c:5815
 #, gcc-internal-format
 msgid "duplicate %<volatile%>"
 msgstr "%<volatile%> dupliqué"
 
-#: c/c-decl.c:5797
+#: c/c-decl.c:5817
 #, gcc-internal-format
 msgid "duplicate %<_Atomic%>"
 msgstr "%<_Atomic%> dupliqué"
 
-#: c/c-decl.c:5800
+#: c/c-decl.c:5820
 #, gcc-internal-format, gfc-internal-format
 msgid "conflicting named address spaces (%s vs %s)"
 msgstr "les espaces d'adresses nommés sont en conflits (%s contre %s)"
 
-#: c/c-decl.c:5823 c/c-parser.c:2821
+#: c/c-decl.c:5843 c/c-parser.c:2821
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified array type"
 msgstr "type de tableau qualifié avec %<_Atomic%>"
 
-#: c/c-decl.c:5837
+#: c/c-decl.c:5857
 #, gcc-internal-format
 msgid "function definition declared %<auto%>"
 msgstr "définition de fonction déclarée %<auto%>"
 
-#: c/c-decl.c:5839
+#: c/c-decl.c:5859
 #, gcc-internal-format
 msgid "function definition declared %<register%>"
 msgstr "définition de fonction déclarée %<register%>"
 
-#: c/c-decl.c:5841
+#: c/c-decl.c:5861
 #, gcc-internal-format
 msgid "function definition declared %<typedef%>"
 msgstr "définition de fonction déclarée %<typedef%>"
 
-#: c/c-decl.c:5843
+#: c/c-decl.c:5863
 #, gcc-internal-format
 msgid "function definition declared %qs"
 msgstr "définition de fonction déclarée %qs"
 
-#: c/c-decl.c:5861
+#: c/c-decl.c:5881
 #, gcc-internal-format
 msgid "storage class specified for structure field %qE"
 msgstr "classe de stockage spécifiée pour le champ de la structure %qE"
 
-#: c/c-decl.c:5864
+#: c/c-decl.c:5884
 #, gcc-internal-format
 msgid "storage class specified for structure field"
 msgstr "classe de stockage spécifiée pour le champ de la structure"
 
-#: c/c-decl.c:5868
+#: c/c-decl.c:5888
 #, gcc-internal-format
 msgid "storage class specified for parameter %qE"
 msgstr "classe de stockage spécifiée pour le paramètre %qE"
 
-#: c/c-decl.c:5871
+#: c/c-decl.c:5891
 #, gcc-internal-format
 msgid "storage class specified for unnamed parameter"
 msgstr "classe de stockage spécifiée pour le paramètre sans nom"
 
-#: c/c-decl.c:5874 cp/decl.c:10935
+#: c/c-decl.c:5894 cp/decl.c:10959
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "classe de stockage spécifiée pour un typename"
 
-#: c/c-decl.c:5891
+#: c/c-decl.c:5911
 #, gcc-internal-format
 msgid "%qE initialized and declared %<extern%>"
 msgstr "%qE initialisé et déclaré %<extern%>"
 
-#: c/c-decl.c:5895
+#: c/c-decl.c:5915
 #, gcc-internal-format
 msgid "%qE has both %<extern%> and initializer"
 msgstr "%qE a, à la fois, %<extern%> et un initialiseur"
 
-#: c/c-decl.c:5900
+#: c/c-decl.c:5920
 #, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<auto%>"
 msgstr "la déclaration de %qE au niveau du fichier spécifie %<auto%>"
 
-#: c/c-decl.c:5904
+#: c/c-decl.c:5924
 #, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<register%>"
 msgstr "la déclaration de %qE au niveau du fichier spécifie %<register%>"
 
-#: c/c-decl.c:5909
+#: c/c-decl.c:5929
 #, gcc-internal-format
 msgid "nested function %qE declared %<extern%>"
 msgstr "fonction imbriquée %qE» déclarée %<extern%>"
 
-#: c/c-decl.c:5912
+#: c/c-decl.c:5932
 #, gcc-internal-format
 msgid "function-scope %qE implicitly auto and declared %qs"
 msgstr "%qE au niveau de la fonction est implicitement « auto » et déclaré %qs"
@@ -34019,702 +34067,702 @@
 #. Only the innermost declarator (making a parameter be of
 #. array type which is converted to pointer type)
 #. may have static or type qualifiers.
-#: c/c-decl.c:5959 c/c-decl.c:6328
+#: c/c-decl.c:5979 c/c-decl.c:6348
 #, gcc-internal-format
 msgid "static or type qualifiers in non-parameter array declarator"
 msgstr "« static » ou qualificatifs de type dans un déclarateur de tableau n'étant pas un paramètre"
 
-#: c/c-decl.c:6007
+#: c/c-decl.c:6027
 #, gcc-internal-format
 msgid "declaration of %qE as array of voids"
 msgstr "déclaration de %qE comme un tableau de « void »"
 
-#: c/c-decl.c:6009
+#: c/c-decl.c:6029
 #, gcc-internal-format
 msgid "declaration of type name as array of voids"
 msgstr "déclaration du nom de type comme un tableau de « void »"
 
-#: c/c-decl.c:6016
+#: c/c-decl.c:6036
 #, gcc-internal-format
 msgid "declaration of %qE as array of functions"
 msgstr "déclaration de %qE comme un tableau de fonctions"
 
-#: c/c-decl.c:6019
+#: c/c-decl.c:6039
 #, gcc-internal-format
 msgid "declaration of type name as array of functions"
 msgstr "déclaration du nom de type comme un tableau de fonctions"
 
-#: c/c-decl.c:6027 c/c-decl.c:8085
+#: c/c-decl.c:6047 c/c-decl.c:8105
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr "utilisation invalide d'une structure ayant un membre qui est un tableau flexible"
 
-#: c/c-decl.c:6053
+#: c/c-decl.c:6073
 #, gcc-internal-format
 msgid "size of array %qE has non-integer type"
 msgstr "la taille du tableau %qE a un type qui n'est pas un entier"
 
-#: c/c-decl.c:6057
+#: c/c-decl.c:6077
 #, gcc-internal-format
 msgid "size of unnamed array has non-integer type"
 msgstr "la taille du tableau sans nom a un type qui n'est pas un entier"
 
-#: c/c-decl.c:6064
+#: c/c-decl.c:6084
 #, gcc-internal-format
 msgid "size of array %qE has incomplete type"
 msgstr "la taille du tableau %qE a un type incomplet"
 
-#: c/c-decl.c:6067
+#: c/c-decl.c:6087
 #, gcc-internal-format
 msgid "size of unnamed array has incomplete type"
 msgstr "la taille du tableau sans nom a un type incomplet"
 
-#: c/c-decl.c:6078
+#: c/c-decl.c:6098
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array %qE"
 msgstr "le C ISO interdit le tableau de taille nulle %qE"
 
-#: c/c-decl.c:6081
+#: c/c-decl.c:6101
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array"
 msgstr "le C ISO interdit le tableau de taille nulle"
 
-#: c/c-decl.c:6090
+#: c/c-decl.c:6110
 #, gcc-internal-format
 msgid "size of array %qE is negative"
 msgstr "la taille du tableau %qE est négative"
 
-#: c/c-decl.c:6092
+#: c/c-decl.c:6112
 #, gcc-internal-format
 msgid "size of unnamed array is negative"
 msgstr "la taille du tableau sans nom est négative"
 
-#: c/c-decl.c:6216 c/c-decl.c:6871
+#: c/c-decl.c:6236 c/c-decl.c:6891
 #, gcc-internal-format
 msgid "ISO C90 does not support flexible array members"
 msgstr "le C90 ISO ne supporte pas les membres qui sont des tableaux flexibles"
 
 #. C99 6.7.5.2p4
-#: c/c-decl.c:6238
+#: c/c-decl.c:6258
 #, gcc-internal-format
 msgid "%<[*]%> not in a declaration"
 msgstr "%<[*]%> n'est pas dans une déclaration"
 
-#: c/c-decl.c:6251
+#: c/c-decl.c:6271
 #, gcc-internal-format
 msgid "array type has incomplete element type %qT"
 msgstr "le type du tableau a un élément de type %qT incomplet"
 
-#: c/c-decl.c:6257
+#: c/c-decl.c:6277
 #, gcc-internal-format
 msgid "declaration of %qE as multidimensional array must have bounds for all dimensions except the first"
 msgstr "la déclaration de %qE comme tableau multidimensionnel doit avoir des bornes pour chaque dimension excepté la première"
 
-#: c/c-decl.c:6261
+#: c/c-decl.c:6281
 #, gcc-internal-format
 msgid "declaration of multidimensional array must have bounds for all dimensions except the first"
 msgstr "la déclaration du tableau multidimensionnel doit avoir des bornes pour chaque dimension excepté la première"
 
-#: c/c-decl.c:6364
+#: c/c-decl.c:6384
 #, gcc-internal-format
 msgid "%qE declared as function returning a function"
 msgstr "%qE déclaré comme une fonction retournant une fonction"
 
-#: c/c-decl.c:6367
+#: c/c-decl.c:6387
 #, gcc-internal-format
 msgid "type name declared as function returning a function"
 msgstr "nom de type déclaré comme une fonction retournant une fonction"
 
-#: c/c-decl.c:6374
+#: c/c-decl.c:6394
 #, gcc-internal-format
 msgid "%qE declared as function returning an array"
 msgstr "%qE déclaré comme une fonction retournant un tableau"
 
-#: c/c-decl.c:6377
+#: c/c-decl.c:6397
 #, gcc-internal-format
 msgid "type name declared as function returning an array"
 msgstr "nom de type déclaré comme une fonction retournant un tableau"
 
-#: c/c-decl.c:6418
+#: c/c-decl.c:6438
 #, gcc-internal-format
 msgid "function definition has qualified void return type"
 msgstr "la définition de la fonction a un type de retour « void » qualifié"
 
-#: c/c-decl.c:6421 cp/decl.c:11201
+#: c/c-decl.c:6441 cp/decl.c:11225
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "les qualificatifs de type sont ignorés sur le type retourné par la fonction"
 
-#: c/c-decl.c:6459 c/c-decl.c:6668 c/c-decl.c:6721 c/c-decl.c:6805
-#: c/c-decl.c:6926 c/c-parser.c:2823
+#: c/c-decl.c:6479 c/c-decl.c:6688 c/c-decl.c:6741 c/c-decl.c:6825
+#: c/c-decl.c:6946 c/c-parser.c:2823
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified function type"
 msgstr "type de fonction qualifié par %<_Atomic%>"
 
-#: c/c-decl.c:6465 c/c-decl.c:6674 c/c-decl.c:6810 c/c-decl.c:6931
+#: c/c-decl.c:6485 c/c-decl.c:6694 c/c-decl.c:6830 c/c-decl.c:6951
 #, gcc-internal-format
 msgid "ISO C forbids qualified function types"
 msgstr "le C ISO interdit les types de fonction qualifiés"
 
-#: c/c-decl.c:6559
+#: c/c-decl.c:6579
 #, gcc-internal-format
 msgid "%qs combined with %<auto%> qualifier for %qE"
 msgstr "%qs combiné avec le qualificatif %<auto%> pour %qE"
 
-#: c/c-decl.c:6563
+#: c/c-decl.c:6583
 #, gcc-internal-format
 msgid "%qs combined with %<register%> qualifier for %qE"
 msgstr "%qs combiné avec le qualificatif %<register%> pour %qE"
 
-#: c/c-decl.c:6569
+#: c/c-decl.c:6589
 #, gcc-internal-format
 msgid "%qs specified for auto variable %qE"
 msgstr "%qs est spécifié pour la variable auto %qE"
 
-#: c/c-decl.c:6585
+#: c/c-decl.c:6605
 #, gcc-internal-format
 msgid "%qs specified for parameter %qE"
 msgstr "%qs est spécifié pour le paramètre %qE"
 
-#: c/c-decl.c:6588
+#: c/c-decl.c:6608
 #, gcc-internal-format
 msgid "%qs specified for unnamed parameter"
 msgstr "%qs est spécifié pour un paramètre non nommé"
 
-#: c/c-decl.c:6594
+#: c/c-decl.c:6614
 #, gcc-internal-format
 msgid "%qs specified for structure field %qE"
 msgstr "%qs spécifié pour le champ %qE de la structure"
 
-#: c/c-decl.c:6597
+#: c/c-decl.c:6617
 #, gcc-internal-format
 msgid "%qs specified for structure field"
 msgstr "%qs spécifié pour un champ d'une structure"
 
-#: c/c-decl.c:6612
+#: c/c-decl.c:6632
 #, gcc-internal-format
 msgid "bit-field %qE has atomic type"
 msgstr "le champ de bits %qE a un type atomique"
 
-#: c/c-decl.c:6614
+#: c/c-decl.c:6634
 #, gcc-internal-format
 msgid "bit-field has atomic type"
 msgstr "le champ de bits a un type atomique"
 
-#: c/c-decl.c:6623
+#: c/c-decl.c:6643
 #, gcc-internal-format
 msgid "alignment specified for typedef %qE"
 msgstr "un alignement est spécifié pour le typedef %qE"
 
-#: c/c-decl.c:6625
+#: c/c-decl.c:6645
 #, gcc-internal-format
 msgid "alignment specified for %<register%> object %qE"
 msgstr "un alignement est spécifié pour l'objet %<register%> %qE"
 
-#: c/c-decl.c:6630
+#: c/c-decl.c:6650
 #, gcc-internal-format
 msgid "alignment specified for parameter %qE"
 msgstr "un alignement est spécifié pour le paramètre %qE"
 
-#: c/c-decl.c:6632
+#: c/c-decl.c:6652
 #, gcc-internal-format
 msgid "alignment specified for unnamed parameter"
 msgstr "un alignement est spécifié pour un paramètre sans nom"
 
-#: c/c-decl.c:6637
+#: c/c-decl.c:6657
 #, gcc-internal-format
 msgid "alignment specified for bit-field %qE"
 msgstr "un alignement est spécifié pour le champ de bits %qE"
 
-#: c/c-decl.c:6639
+#: c/c-decl.c:6659
 #, gcc-internal-format
 msgid "alignment specified for unnamed bit-field"
 msgstr "un alignement est spécifié pour un champ de bits sans nom"
 
-#: c/c-decl.c:6642
+#: c/c-decl.c:6662
 #, gcc-internal-format
 msgid "alignment specified for function %qE"
 msgstr "un alignement est spécifié pour la fonction %qE"
 
-#: c/c-decl.c:6649
+#: c/c-decl.c:6669
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of %qE"
 msgstr "les spécificateurs %<_Alignas%> ne peuvent pas réduire l'alignement de %qE"
 
-#: c/c-decl.c:6652
+#: c/c-decl.c:6672
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of unnamed field"
 msgstr "les spécificateurs %<_Alignas%> ne peuvent pas réduire l'alignement du champ sans nom"
 
-#: c/c-decl.c:6683
+#: c/c-decl.c:6703
 #, gcc-internal-format
 msgid "typedef %q+D declared %<inline%>"
 msgstr "le typedef %q+D est déclaré %<inline%>"
 
-#: c/c-decl.c:6685
+#: c/c-decl.c:6705
 #, gcc-internal-format
 msgid "typedef %q+D declared %<_Noreturn%>"
 msgstr "le typedef %q+D est déclaré %<_Noreturn%>"
 
-#: c/c-decl.c:6727
+#: c/c-decl.c:6747
 #, gcc-internal-format
 msgid "ISO C forbids const or volatile function types"
 msgstr "le C ISO interdit les fonctions de type volatile ou constante"
 
 #. C99 6.7.2.1p8
-#: c/c-decl.c:6738
+#: c/c-decl.c:6758
 #, gcc-internal-format
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "un membre d'une structure ou d'une union ne peut pas avoir de type modifié par une variable"
 
-#: c/c-decl.c:6755 cp/decl.c:9989
+#: c/c-decl.c:6775 cp/decl.c:10010
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "variable ou champ %qE déclaré « void »"
 
-#: c/c-decl.c:6795
+#: c/c-decl.c:6815
 #, gcc-internal-format
 msgid "attributes in parameter array declarator ignored"
 msgstr "les attributs dans un déclarateur de tableau de paramètres sont ignorés"
 
-#: c/c-decl.c:6837
+#: c/c-decl.c:6857
 #, gcc-internal-format
 msgid "parameter %q+D declared %<inline%>"
 msgstr "paramètre %q+D déclaré %<inline%>"
 
-#: c/c-decl.c:6839
+#: c/c-decl.c:6859
 #, gcc-internal-format
 msgid "parameter %q+D declared %<_Noreturn%>"
 msgstr "paramètre %q+D déclaré %<_Noreturn%>"
 
-#: c/c-decl.c:6852
+#: c/c-decl.c:6872
 #, gcc-internal-format
 msgid "field %qE declared as a function"
 msgstr "champ %qE déclaré comme une fonction"
 
-#: c/c-decl.c:6859
+#: c/c-decl.c:6879
 #, gcc-internal-format
 msgid "field %qE has incomplete type"
 msgstr "le champ %qE est d'un type incomplet"
 
-#: c/c-decl.c:6861
+#: c/c-decl.c:6881
 #, gcc-internal-format
 msgid "unnamed field has incomplete type"
 msgstr "un champ sans nom a un type incomplet"
 
-#: c/c-decl.c:6897 c/c-decl.c:6908 c/c-decl.c:6911
+#: c/c-decl.c:6917 c/c-decl.c:6928 c/c-decl.c:6931
 #, gcc-internal-format
 msgid "invalid storage class for function %qE"
 msgstr "classe de stockage invalide pour la fonction %qE"
 
-#: c/c-decl.c:6968
+#: c/c-decl.c:6988
 #, gcc-internal-format
 msgid "cannot inline function %<main%>"
 msgstr "la fonction %<main%> ne peut pas être mise en ligne"
 
-#: c/c-decl.c:6970
+#: c/c-decl.c:6990
 #, gcc-internal-format
 msgid "%<main%> declared %<_Noreturn%>"
 msgstr "%<main%> est déclarée %<_Noreturn%>"
 
-#: c/c-decl.c:6981
+#: c/c-decl.c:7001
 #, gcc-internal-format
 msgid "ISO C99 does not support %<_Noreturn%>"
 msgstr "le C99 ISO ne supporte pas %<_Noreturn%>"
 
-#: c/c-decl.c:6984
+#: c/c-decl.c:7004
 #, gcc-internal-format
 msgid "ISO C90 does not support %<_Noreturn%>"
 msgstr "le C90 ISO ne supporte pas %<_Noreturn%>"
 
-#: c/c-decl.c:7013
+#: c/c-decl.c:7033
 #, gcc-internal-format
 msgid "variable previously declared %<static%> redeclared %<extern%>"
 msgstr "une variable précédemment déclarée %<static%> est redéclarée %<extern%>"
 
-#: c/c-decl.c:7023
+#: c/c-decl.c:7043
 #, gcc-internal-format
 msgid "variable %q+D declared %<inline%>"
 msgstr "variable %q+D déclarée %<inline%>"
 
-#: c/c-decl.c:7025
+#: c/c-decl.c:7045
 #, gcc-internal-format
 msgid "variable %q+D declared %<_Noreturn%>"
 msgstr "variable %q+D déclarée %<_Noreturn%>"
 
-#: c/c-decl.c:7060
+#: c/c-decl.c:7080
 #, gcc-internal-format
 msgid "non-nested function with variably modified type"
 msgstr "fonction non imbriquée avec un type modifié par une variable"
 
-#: c/c-decl.c:7062
+#: c/c-decl.c:7082
 #, gcc-internal-format
 msgid "object with variably modified type must have no linkage"
 msgstr "un objet avec un type modifié par une variable ne peut pas avoir de classe de liaison"
 
-#: c/c-decl.c:7153 c/c-decl.c:8821
+#: c/c-decl.c:7173 c/c-decl.c:8841
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr "la déclaration de fonction n'est pas un prototype"
 
-#: c/c-decl.c:7163
+#: c/c-decl.c:7183
 #, gcc-internal-format
 msgid "parameter names (without types) in function declaration"
 msgstr "noms de paramètres (sans type) dans la déclaration de fonction"
 
-#: c/c-decl.c:7201
+#: c/c-decl.c:7221
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has incomplete type"
 msgstr "le paramètre %u (%q+D) a un type incomplet"
 
-#: c/c-decl.c:7205
+#: c/c-decl.c:7225
 #, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has incomplete type"
 msgstr "le paramètre %u a un type incomplet"
 
-#: c/c-decl.c:7216
+#: c/c-decl.c:7236
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has void type"
 msgstr "le paramètre %u (%q+D) a le type void"
 
-#: c/c-decl.c:7220
+#: c/c-decl.c:7240
 #, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has void type"
 msgstr "le paramètre %u a le type void"
 
-#: c/c-decl.c:7294
+#: c/c-decl.c:7314
 #, gcc-internal-format
 msgid "%<void%> as only parameter may not be qualified"
 msgstr "un %<void%> comme seul paramètre ne peut être qualifié"
 
-#: c/c-decl.c:7298 c/c-decl.c:7334
+#: c/c-decl.c:7318 c/c-decl.c:7354
 #, gcc-internal-format
 msgid "%<void%> must be the only parameter"
 msgstr "%<void%> doit être le seul paramètre"
 
-#: c/c-decl.c:7328
+#: c/c-decl.c:7348
 #, gcc-internal-format
 msgid "parameter %q+D has just a forward declaration"
 msgstr "le paramètre %q+D n'a qu'une déclaration anticipée"
 
-#: c/c-decl.c:7374
+#: c/c-decl.c:7394
 #, gcc-internal-format
 msgid "%<%s %E%> declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr "%<%s %E%> est déclaré à l'intérieur d'une liste de paramètres et ne sera pas visible en dehors de cette définition ou déclaration"
 
 # le %s est « struct », « union » ou « enum »
-#: c/c-decl.c:7380
+#: c/c-decl.c:7400
 #, gcc-internal-format, gfc-internal-format
 msgid "anonymous %s declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr "le %s anonyme est déclaré à l'intérieur d'une liste de paramètres et ne sera pas visible en dehors de cette définition ou déclaration"
 
-#: c/c-decl.c:7482
+#: c/c-decl.c:7502
 #, gcc-internal-format
 msgid "enum type defined here"
 msgstr "type « enum » défini ici"
 
-#: c/c-decl.c:7488
+#: c/c-decl.c:7508
 #, gcc-internal-format
 msgid "struct defined here"
 msgstr "« struct » défini ici"
 
-#: c/c-decl.c:7494
+#: c/c-decl.c:7514
 #, gcc-internal-format
 msgid "union defined here"
 msgstr "« union » défini ici"
 
-#: c/c-decl.c:7570
+#: c/c-decl.c:7590
 #, gcc-internal-format
 msgid "redefinition of %<union %E%>"
 msgstr "redéfinition de %<union %E%>"
 
-#: c/c-decl.c:7572
+#: c/c-decl.c:7592
 #, gcc-internal-format
 msgid "redefinition of %<struct %E%>"
 msgstr "redéfinition de %<struct %E%>"
 
-#: c/c-decl.c:7581
+#: c/c-decl.c:7601
 #, gcc-internal-format
 msgid "nested redefinition of %<union %E%>"
 msgstr "redéfinition imbriquée de %<union %E%>"
 
-#: c/c-decl.c:7583
+#: c/c-decl.c:7603
 #, gcc-internal-format
 msgid "nested redefinition of %<struct %E%>"
 msgstr "redéfinition imbriquée de %<struct %E%>"
 
-#: c/c-decl.c:7613 c/c-decl.c:8400
+#: c/c-decl.c:7633 c/c-decl.c:8420
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr "définir le type dans l'expression %qs est invalide en C++"
 
-#: c/c-decl.c:7680 cp/decl.c:4802
+#: c/c-decl.c:7700 cp/decl.c:4802
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "la déclaration ne déclare rien du tout"
 
-#: c/c-decl.c:7685
+#: c/c-decl.c:7705
 #, gcc-internal-format
 msgid "ISO C99 doesn%'t support unnamed structs/unions"
 msgstr "le C99 ISO ne supporte pas les structures et unions sans nom"
 
-#: c/c-decl.c:7688
+#: c/c-decl.c:7708
 #, gcc-internal-format
 msgid "ISO C90 doesn%'t support unnamed structs/unions"
 msgstr "le C90 ISO ne supporte pas les structures et unions sans nom"
 
-#: c/c-decl.c:7781 c/c-decl.c:7799 c/c-decl.c:7860
+#: c/c-decl.c:7801 c/c-decl.c:7819 c/c-decl.c:7880
 #, gcc-internal-format
 msgid "duplicate member %q+D"
 msgstr "membre %q+D dupliqué"
 
-#: c/c-decl.c:7886
+#: c/c-decl.c:7906
 #, gcc-internal-format
 msgid "empty struct has size 0 in C, size 1 in C++"
 msgstr "une structure vide a une taille 0 en C et une taille 1 en C++"
 
-#: c/c-decl.c:7889
+#: c/c-decl.c:7909
 #, gcc-internal-format
 msgid "empty union has size 0 in C, size 1 in C++"
 msgstr "une union vide a une taille 0 en C et une taille 1 en C++"
 
-#: c/c-decl.c:7994
+#: c/c-decl.c:8014
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr "l'union n'a aucun membre nommé"
 
-#: c/c-decl.c:7996
+#: c/c-decl.c:8016
 #, gcc-internal-format
 msgid "union has no members"
 msgstr "l'union n'a aucun membre"
 
-#: c/c-decl.c:8001
+#: c/c-decl.c:8021
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr "la structure n'a aucun membre nommé"
 
-#: c/c-decl.c:8003
+#: c/c-decl.c:8023
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr "la structure n'a aucun membre"
 
-#: c/c-decl.c:8064 cp/decl.c:12069
+#: c/c-decl.c:8084 cp/decl.c:12093
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "tableau flexible comme membre de l'union"
 
-#: c/c-decl.c:8070
+#: c/c-decl.c:8090
 #, gcc-internal-format
 msgid "flexible array member not at end of struct"
 msgstr "le tableau flexible n'est pas le dernier membre à la fin de la structure"
 
-#: c/c-decl.c:8076
+#: c/c-decl.c:8096
 #, gcc-internal-format
 msgid "flexible array member in a struct with no named members"
 msgstr "tableau flexible comme membre d'une structure sans aucun membre nommé"
 
-#: c/c-decl.c:8107
+#: c/c-decl.c:8127
 #, gcc-internal-format
 msgid "type %qT is too large"
 msgstr "le type %qT est trop grand"
 
-#: c/c-decl.c:8230
+#: c/c-decl.c:8250
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr "une union ne peut pas être rendue transparente"
 
-#: c/c-decl.c:8372
+#: c/c-decl.c:8392
 #, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr "redéfinition imbriquée de %<enum %E%>"
 
 #. This enum is a named one that has been declared already.
-#: c/c-decl.c:8379
+#: c/c-decl.c:8399
 #, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr "redéclaration de %<enum %E%>"
 
-#: c/c-decl.c:8458 cp/decl.c:14423
+#: c/c-decl.c:8478 cp/decl.c:14447
 #, gcc-internal-format
 msgid "specified mode too small for enumeral values"
 msgstr "le mode spécifié est trop petit pour les valeurs de l'énumération"
 
-#: c/c-decl.c:8473
+#: c/c-decl.c:8493
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr "les valeurs de l'énumération excèdent les limites du plus grand entier"
 
-#: c/c-decl.c:8587 c/c-decl.c:8603
+#: c/c-decl.c:8607 c/c-decl.c:8623
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr "la valeur de l'énumérateur pour %qE n'est pas une constante entière"
 
-#: c/c-decl.c:8598
+#: c/c-decl.c:8618
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr "la valeur de l'énumérateur pour %qE n'est pas une expression constante entière"
 
-#: c/c-decl.c:8622
+#: c/c-decl.c:8642
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr "débordement dans les valeurs de l'énumération"
 
-#: c/c-decl.c:8630
+#: c/c-decl.c:8650
 #, gcc-internal-format
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "le C ISO restreint les valeurs de l'énumérateur à la plage d'un %<int%>"
 
-#: c/c-decl.c:8715 cp/decl.c:5104 cp/decl.c:14955
+#: c/c-decl.c:8735 cp/decl.c:5104 cp/decl.c:14979
 #, gcc-internal-format
 msgid "inline function %qD given attribute noinline"
 msgstr "la fonction à mettre en ligne %qD a reçu l'attribut « noinline »"
 
-#: c/c-decl.c:8733
+#: c/c-decl.c:8753
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr "le type du retour est un type incomplet"
 
-#: c/c-decl.c:8744
+#: c/c-decl.c:8764
 #, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr "le type du retour devient %<int%> par défaut"
 
-#: c/c-decl.c:8771
+#: c/c-decl.c:8791
 #, gcc-internal-format
 msgid "%q+D defined as variadic function without prototype"
 msgstr "%q+D est définie comme fonction variadique sans prototype"
 
-#: c/c-decl.c:8830
+#: c/c-decl.c:8850
 #, gcc-internal-format
 msgid "no previous prototype for %qD"
 msgstr "aucun prototype précédent pour %qD"
 
-#: c/c-decl.c:8839
+#: c/c-decl.c:8859
 #, gcc-internal-format
 msgid "%qD was used with no prototype before its definition"
 msgstr "%qD a été utilisé sans prototype avant sa définition"
 
-#: c/c-decl.c:8847 cp/decl.c:15090
+#: c/c-decl.c:8867 cp/decl.c:15114
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "aucune déclaration précédente pour %qD"
 
-#: c/c-decl.c:8857
+#: c/c-decl.c:8877
 #, gcc-internal-format
 msgid "%qD was used with no declaration before its definition"
 msgstr "%qD a été utilisé sans déclaration avant sa définition"
 
-#: c/c-decl.c:8876
+#: c/c-decl.c:8896
 #, gcc-internal-format
 msgid "return type of %qD is not %<int%>"
 msgstr "le type de retour de %qD n'est pas %<int%>"
 
-#: c/c-decl.c:8878
+#: c/c-decl.c:8898
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr "type de retour qualifié avec %<_Atomic%> pour %qD"
 
-#: c/c-decl.c:8885
+#: c/c-decl.c:8905
 #, gcc-internal-format
 msgid "%qD is normally a non-static function"
 msgstr "%qD est normalement une fonction non statique"
 
-#: c/c-decl.c:8922
+#: c/c-decl.c:8942
 #, gcc-internal-format
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr "déclaration de paramètres selon l'ancien style dans la définition de fonction prototypée"
 
-#: c/c-decl.c:8937
+#: c/c-decl.c:8957
 #, gcc-internal-format
 msgid "traditional C rejects ISO C style function definitions"
 msgstr "le C traditionnel rejette les définitions de fonctions de style C ISO"
 
-#: c/c-decl.c:8953
+#: c/c-decl.c:8973
 #, gcc-internal-format
 msgid "parameter name omitted"
 msgstr "nom de paramètre omis"
 
-#: c/c-decl.c:8990
+#: c/c-decl.c:9010
 #, gcc-internal-format
 msgid "old-style function definition"
 msgstr "définition de fonction selon l'ancien style"
 
-#: c/c-decl.c:8999
+#: c/c-decl.c:9019
 #, gcc-internal-format
 msgid "parameter name missing from parameter list"
 msgstr "nom du paramètre manquant dans la liste des paramètres"
 
-#: c/c-decl.c:9015
+#: c/c-decl.c:9035
 #, gcc-internal-format
 msgid "%qD declared as a non-parameter"
 msgstr "%qD déclaré comme un non paramètre"
 
-#: c/c-decl.c:9023
+#: c/c-decl.c:9043
 #, gcc-internal-format
 msgid "multiple parameters named %qD"
 msgstr "plusieurs paramètres nommés %qD"
 
-#: c/c-decl.c:9032
+#: c/c-decl.c:9052
 #, gcc-internal-format
 msgid "parameter %qD declared with void type"
 msgstr "paramètre %qD déclaré avec le type « void »"
 
-#: c/c-decl.c:9061 c/c-decl.c:9066
+#: c/c-decl.c:9081 c/c-decl.c:9086
 #, gcc-internal-format
 msgid "type of %qD defaults to %<int%>"
 msgstr "le type de %qD devient %<int%> par défaut"
 
-#: c/c-decl.c:9086
+#: c/c-decl.c:9106
 #, gcc-internal-format
 msgid "parameter %qD has incomplete type"
 msgstr "le paramètre %qD a un type incomplet"
 
-#: c/c-decl.c:9093
+#: c/c-decl.c:9113
 #, gcc-internal-format
 msgid "declaration for parameter %qD but no such parameter"
 msgstr "déclaration du paramètre %qD mais pas de tel paramètre"
 
-#: c/c-decl.c:9146
+#: c/c-decl.c:9166
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr "le nombre d'arguments ne concorde pas avec celui du prototype interne"
 
-#: c/c-decl.c:9157
+#: c/c-decl.c:9177
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr "le nombre d'arguments ne concorde pas avec celui du prototype"
 
-#: c/c-decl.c:9160 c/c-decl.c:9207 c/c-decl.c:9221
+#: c/c-decl.c:9180 c/c-decl.c:9227 c/c-decl.c:9241
 #, gcc-internal-format
 msgid "prototype declaration"
 msgstr "déclaration de prototype"
 
-#: c/c-decl.c:9199
+#: c/c-decl.c:9219
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr "l'argument promu %qD ne concorde pas avec le prototype interne"
 
-#: c/c-decl.c:9204
+#: c/c-decl.c:9224
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr "l'argument promu %qD ne concorde pas avec le prototype"
 
-#: c/c-decl.c:9214
+#: c/c-decl.c:9234
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr "l'argument %qD ne concorde pas avec le prototype interne"
 
-#: c/c-decl.c:9219
+#: c/c-decl.c:9239
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr "l'argument %qD ne concorde pas avec le prototype"
 
-#: c/c-decl.c:9470 cp/decl.c:15873
+#: c/c-decl.c:9490 cp/decl.c:15897
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "« return » manquant dans une fonction devant retourner une valeur"
 
-#: c/c-decl.c:9490 cp/decl.c:15905
+#: c/c-decl.c:9510 cp/decl.c:15929
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "le paramètre %qD est défini mais pas utilisé"
@@ -34722,247 +34770,247 @@
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:9586
+#: c/c-decl.c:9606
 #, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "les déclarations initiales de boucles %<for%> ne sont permises qu'en mode C99 et C11"
 
-#: c/c-decl.c:9591
+#: c/c-decl.c:9611
 #, gcc-internal-format
 msgid "use option -std=c99, -std=gnu99, -std=c11 or -std=gnu11 to compile your code"
 msgstr "utilisez l'option -std=c99, -std=gnu99, -std=c11 ou -std=gnu11 pour compiler votre code"
 
-#: c/c-decl.c:9626
+#: c/c-decl.c:9646
 #, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "déclaration de la variable statique %qD dans la déclaration initiale de la boucle %<for%>"
 
-#: c/c-decl.c:9630
+#: c/c-decl.c:9650
 #, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "déclaration de la variable %<extern%> %qD dans la déclaration initiale de la boucle %<for%>"
 
-#: c/c-decl.c:9637
+#: c/c-decl.c:9657
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "%<struct %E%> déclarée dans la déclaration initiale de la boucle %<for%>"
 
-#: c/c-decl.c:9642
+#: c/c-decl.c:9662
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "%<union %E%> déclarée dans la déclaration initiale de la boucle %<for%>"
 
-#: c/c-decl.c:9646
+#: c/c-decl.c:9666
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "%<enum %E%> déclarée dans la déclaration initiale de la boucle %<for%>"
 
-#: c/c-decl.c:9650
+#: c/c-decl.c:9670
 #, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "déclaration de %qD (qui n'est pas une variable) dans la déclaration initiale de la boucle %<for%>"
 
-#: c/c-decl.c:9900
+#: c/c-decl.c:9920
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr "les qualificatifs d'espace d'adresses %qs et %qs sont incompatibles"
 
-#: c/c-decl.c:9958 c/c-decl.c:9965
+#: c/c-decl.c:9978 c/c-decl.c:9985
 #, gcc-internal-format
 msgid "duplicate %qE declaration specifier"
 msgstr "spécificateur de déclaration %qE dupliqué"
 
-#: c/c-decl.c:9992 c/c-decl.c:10376 c/c-decl.c:10766
+#: c/c-decl.c:10012 c/c-decl.c:10396 c/c-decl.c:10786
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr "deux types de données ou plus dans le spécificateur de déclaration"
 
-#: c/c-decl.c:10004 cp/parser.c:28261
+#: c/c-decl.c:10024 cp/parser.c:28258
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> est trop long pour GCC"
 
-#: c/c-decl.c:10017
+#: c/c-decl.c:10037
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "le C90 ISO ne supporte pas %<long long%>"
 
-#: c/c-decl.c:10246 c/c-parser.c:8848
+#: c/c-decl.c:10266 c/c-parser.c:8848
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "le C90 ISO ne supporte pas les types « complex »"
 
-#: c/c-decl.c:10292
+#: c/c-decl.c:10312
 #, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr "le C ISO ne supporte pas les types saturants"
 
-#: c/c-decl.c:10363 c/c-decl.c:10923
+#: c/c-decl.c:10383 c/c-decl.c:10943
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "%qE dupliqué"
 
-#: c/c-decl.c:10419
+#: c/c-decl.c:10439
 #, gcc-internal-format
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "le C ISO ne supporte pas les types %<__int%d%>"
 
-#: c/c-decl.c:10441
+#: c/c-decl.c:10461
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr "%<__int%d%> n'est pas supporté sur cette cible"
 
-#: c/c-decl.c:10484
+#: c/c-decl.c:10504
 #, gcc-internal-format
 msgid "ISO C90 does not support boolean types"
 msgstr "le C90 ISO ne supporte pas les types booléens"
 
-#: c/c-decl.c:10603
+#: c/c-decl.c:10623
 #, gcc-internal-format
 msgid "ISO C does not support the %<_Float%d%s%> type"
 msgstr "le C ISO ne supporte pas le type %<_Float%d%s%>"
 
-#: c/c-decl.c:10653
+#: c/c-decl.c:10673
 #, gcc-internal-format
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "%<_Float%d%s%> n'est pas supporté sur cette cible"
 
-#: c/c-decl.c:10724
+#: c/c-decl.c:10744
 #, gcc-internal-format
 msgid "ISO C does not support decimal floating point"
 msgstr "le C ISO ne supporte pas les virgules flottantes décimales"
 
-#: c/c-decl.c:10747 c/c-decl.c:11013 c/c-parser.c:7842
+#: c/c-decl.c:10767 c/c-decl.c:11033 c/c-parser.c:7842
 #, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "les types en virgule fixe ne sont pas supportés pour cette cible"
 
-#: c/c-decl.c:10749
+#: c/c-decl.c:10769
 #, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr "le C ISO ne supporte pas les types en virgule fixe"
 
-#: c/c-decl.c:10784
+#: c/c-decl.c:10804
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr "la recherche de %qD par le C++ retournerait un champ, pas un type"
 
-#: c/c-decl.c:10797
+#: c/c-decl.c:10817
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr "%qE échoue a être un typedef ou un type interne"
 
-#: c/c-decl.c:10845
+#: c/c-decl.c:10865
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qE n'est pas au début de la déclaration"
 
-#: c/c-decl.c:10866
+#: c/c-decl.c:10886
 #, gcc-internal-format
 msgid "%qE used with %<auto%>"
 msgstr "%qE utilisé avec %<auto%>"
 
-#: c/c-decl.c:10868
+#: c/c-decl.c:10888
 #, gcc-internal-format
 msgid "%qE used with %<register%>"
 msgstr "%qE utilisé avec %<register%>"
 
-#: c/c-decl.c:10870
+#: c/c-decl.c:10890
 #, gcc-internal-format
 msgid "%qE used with %<typedef%>"
 msgstr "%qE utilisé avec %<typedef%>"
 
-#: c/c-decl.c:10884 c/c-parser.c:7360
+#: c/c-decl.c:10904 c/c-parser.c:7360
 #, gcc-internal-format
 msgid "ISO C99 does not support %qE"
 msgstr "le C99 ISO ne supporte pas %qE"
 
-#: c/c-decl.c:10887 c/c-parser.c:7363
+#: c/c-decl.c:10907 c/c-parser.c:7363
 #, gcc-internal-format
 msgid "ISO C90 does not support %qE"
 msgstr "le C90 ISO ne supporte pas %qE"
 
-#: c/c-decl.c:10899
+#: c/c-decl.c:10919
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<__thread%> avant %<extern%>"
 
-#: c/c-decl.c:10908
+#: c/c-decl.c:10928
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<__thread%> avant %<static%>"
 
-#: c/c-decl.c:10921
+#: c/c-decl.c:10941
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr "%<_Thread_local%> ou %<__thread%> dupliqué"
 
-#: c/c-decl.c:10929
+#: c/c-decl.c:10949
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr "classes de stockage multiples dans les spécificateurs de la déclaration"
 
-#: c/c-decl.c:10937
+#: c/c-decl.c:10957
 #, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr "%qs utilisé avec %qE"
 
-#: c/c-decl.c:11010
+#: c/c-decl.c:11030
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "%<_Sat%> est utilisé sans %<_Fract%> ou %<_Accum%>"
 
-#: c/c-decl.c:11025
+#: c/c-decl.c:11045
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "le C ISO ne supporte pas un simple %<complex%> signifiant %<double complex%>"
 
-#: c/c-decl.c:11076 c/c-decl.c:11092 c/c-decl.c:11118
+#: c/c-decl.c:11096 c/c-decl.c:11112 c/c-decl.c:11138
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "le C ISO interdit les types entiers complexes"
 
-#: c/c-decl.c:11514 cp/semantics.c:5348
+#: c/c-decl.c:11534 cp/semantics.c:5351
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr "le combinateur %<#pragma omp declare reduction%> fait référence à la variable %qD qui n'est ni %<omp_out%> ni %<omp_in%>"
 
-#: c/c-decl.c:11518 cp/semantics.c:5352
+#: c/c-decl.c:11538 cp/semantics.c:5355
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr "l'initialiseur %<#pragma omp declare reduction%> fait référence à la variable %qD qui n'est ni %<omp_priv%> ni %<omp_orig%>"
 
-#: c/c-fold.c:385 c/c-typeck.c:11426 cp/typeck.c:4680
+#: c/c-fold.c:385 c/c-typeck.c:11431 cp/typeck.c:4680
 #, gcc-internal-format
 msgid "left shift of negative value"
 msgstr "décalage vers la gauche d'une valeur négative"
 
-#: c/c-fold.c:395 c/c-typeck.c:11435 cp/typeck.c:4688
+#: c/c-fold.c:395 c/c-typeck.c:11440 cp/typeck.c:4688
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "le compteur de décalages vers la gauche est négatif"
 
-#: c/c-fold.c:396 c/c-typeck.c:11365 cp/typeck.c:4633
+#: c/c-fold.c:396 c/c-typeck.c:11370 cp/typeck.c:4633
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "le compteur de décalages vers la droite est négatif"
 
-#: c/c-fold.c:404 c/c-typeck.c:11454 cp/typeck.c:4696
+#: c/c-fold.c:404 c/c-typeck.c:11459 cp/typeck.c:4696
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "compteur de décalages vers la gauche >= à la largeur du type"
 
-#: c/c-fold.c:405 c/c-typeck.c:11389 cp/typeck.c:4641
+#: c/c-fold.c:405 c/c-typeck.c:11394 cp/typeck.c:4641
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "compteur de décalages vers la droite >= à la largeur du type"
 
-#: c/c-fold.c:412 c/c-typeck.c:11446
+#: c/c-fold.c:412 c/c-typeck.c:11451
 #, gcc-internal-format
 msgid "left shift count >= width of vector element"
 msgstr "compteur de décalages vers la gauche >= à la largeur de l'élément du vecteur"
 
-#: c/c-fold.c:413 c/c-typeck.c:11376
+#: c/c-fold.c:413 c/c-typeck.c:11381
 #, gcc-internal-format
 msgid "right shift count >= width of vector element"
 msgstr "compteur de décalages vers la droite >= à la largeur de l'élément du vecteur"
@@ -34982,7 +35030,7 @@
 msgid "to match this %qs"
 msgstr "pour correspondre à ce %qs"
 
-#: c/c-parser.c:1216 cp/parser.c:28484
+#: c/c-parser.c:1216 cp/parser.c:28481
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr "fin de ligne attendue"
@@ -35023,7 +35071,7 @@
 msgstr "nom de type %qE inconnu"
 
 #: c/c-parser.c:1848 c/c-parser.c:11129 c/c-parser.c:16147 c/c-parser.c:16585
-#: c/c-parser.c:17061 cp/parser.c:36007 cp/parser.c:38993
+#: c/c-parser.c:17061 cp/parser.c:36004 cp/parser.c:38990
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "spécificateurs de déclaration attendus"
@@ -35038,7 +35086,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "%<;%>, identificateur ou %<(%> attendu"
 
-#: c/c-parser.c:1906 cp/parser.c:30161 cp/parser.c:30235
+#: c/c-parser.c:1906 cp/parser.c:30158 cp/parser.c:30232
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "les attributs de préfixes sont ignorés pour les méthodes"
@@ -35092,7 +35140,7 @@
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr "%<__auto_type%> peut uniquement être utilisé avec un seul déclarateur"
 
-#: c/c-parser.c:2220 cp/parser.c:13002 cp/parser.c:13159
+#: c/c-parser.c:2220 cp/parser.c:12999 cp/parser.c:13156
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "%<,%> ou %<;%> attendu"
@@ -35120,7 +35168,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "le C90 ISO ne supporte pas %<_Static_assert%>"
 
-#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38634
+#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38631
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr "chaîne littérale attendue"
@@ -35184,13 +35232,13 @@
 #: c/c-parser.c:10745 c/c-parser.c:10798 c/c-parser.c:10814 c/c-parser.c:10860
 #: c/c-parser.c:11496 c/c-parser.c:11537 c/c-parser.c:13445 c/c-parser.c:13681
 #: c/c-parser.c:15544 c/c-parser.c:18218 c/gimple-parser.c:1058
-#: c/gimple-parser.c:1096 cp/parser.c:28487 cp/parser.c:31013
-#: cp/parser.c:31043 cp/parser.c:31113 cp/parser.c:33230 cp/parser.c:38350
+#: c/gimple-parser.c:1096 cp/parser.c:28484 cp/parser.c:31010
+#: cp/parser.c:31040 cp/parser.c:31110 cp/parser.c:33227 cp/parser.c:38347
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "identificateur attendu"
 
-#: c/c-parser.c:2995 cp/parser.c:18384
+#: c/c-parser.c:2995 cp/parser.c:18381
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "virgule à la fin de la liste d'énumerateurs"
@@ -35359,12 +35407,12 @@
 msgid "expected statement"
 msgstr "instruction attendue"
 
-#: c/c-parser.c:5639 cp/parser.c:12516
+#: c/c-parser.c:5639 cp/parser.c:12513
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "accolades suggérées autour du corps vide d'une instruction %<if%>"
 
-#: c/c-parser.c:5681 cp/parser.c:12519
+#: c/c-parser.c:5681 cp/parser.c:12516
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "accolades suggérées autour du corps vide d'une instruction %<else%>"
@@ -35702,7 +35750,7 @@
 msgid "%<__builtin_complex%> operands of different types"
 msgstr "opérandes de %<__builtin_complex%> de types différents"
 
-#: c/c-parser.c:8891 cp/parser.c:6918
+#: c/c-parser.c:8891 cp/parser.c:6921
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_shuffle%>"
 msgstr "mauvais nombre d'arguments pour %<__builtin_shuffle%>"
@@ -35762,76 +35810,76 @@
 msgid "no type or storage class may be specified here,"
 msgstr "aucun type ni classe de stockage ne peut être spécifié ici,"
 
-#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31073
+#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31070
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "attribut de propriété inconnu"
 
-#: c/c-parser.c:10682 cp/parser.c:31033
+#: c/c-parser.c:10682 cp/parser.c:31030
 #, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "%<=%> manquant (après l'attribut %<getter%>)"
 
-#: c/c-parser.c:10685 cp/parser.c:31036
+#: c/c-parser.c:10685 cp/parser.c:31033
 #, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "%<=%> manquant (après l'attribut %<setter%>)"
 
-#: c/c-parser.c:10699 cp/parser.c:31051
+#: c/c-parser.c:10699 cp/parser.c:31048
 #, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "l'attribut %<setter%> ne peut être spécifié qu'une seule fois"
 
-#: c/c-parser.c:10704 cp/parser.c:31057
+#: c/c-parser.c:10704 cp/parser.c:31054
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr "le nom du « setter » doit être terminé par %<:%>"
 
-#: c/c-parser.c:10711 cp/parser.c:31065
+#: c/c-parser.c:10711 cp/parser.c:31062
 #, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "l'attribut %<getter%> ne peut être spécifié qu'une seule fois"
 
-#: c/c-parser.c:10905 cp/parser.c:38674
+#: c/c-parser.c:10905 cp/parser.c:38671
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr "%<#pragma GCC unroll%> requiert une expression d'affectation qui est évaluée en une constante entière non négative plus petite que %u"
 
 #: c/c-parser.c:10949 c/c-parser.c:16582 c/c-parser.c:16840 c/c-parser.c:16899
-#: c/c-parser.c:16983 cp/parser.c:36004 cp/parser.c:36298 cp/parser.c:36386
-#: cp/parser.c:36457 cp/parser.c:38721 cp/parser.c:38736 cp/parser.c:38752
-#: cp/parser.c:38768 cp/parser.c:38784 cp/parser.c:38811 cp/parser.c:38824
-#: cp/parser.c:38847 cp/parser.c:38860
+#: c/c-parser.c:16983 cp/parser.c:36001 cp/parser.c:36295 cp/parser.c:36383
+#: cp/parser.c:36454 cp/parser.c:38718 cp/parser.c:38733 cp/parser.c:38749
+#: cp/parser.c:38765 cp/parser.c:38781 cp/parser.c:38808 cp/parser.c:38821
+#: cp/parser.c:38844 cp/parser.c:38857
 #, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<#pragma %s%> ne peut être utilisé que dans des instructions composées"
 
-#: c/c-parser.c:10972 cp/parser.c:38837
+#: c/c-parser.c:10972 cp/parser.c:38834
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<#pragma acc routine%> doit être dans la portée au niveau du fichier"
 
-#: c/c-parser.c:11050 cp/parser.c:38918
+#: c/c-parser.c:11050 cp/parser.c:38915
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<#pragma omp section%> ne peut être utilisé que dans une construction %<#pragma omp sections%>"
 
-#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38947 cp/parser.c:38980
+#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38944 cp/parser.c:38977
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "instruction « for », « while » ou « do » attendue"
 
-#: c/c-parser.c:11111 cp/parser.c:38711
+#: c/c-parser.c:11111 cp/parser.c:38708
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%> doit être le premier"
 
-#: c/c-parser.c:11421 cp/parser.c:31457
+#: c/c-parser.c:11421 cp/parser.c:31454
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "trop de clauses %qs"
 
-#: c/c-parser.c:11443 cp/parser.c:31994
+#: c/c-parser.c:11443 cp/parser.c:31991
 #, gcc-internal-format
 msgid "expected integer expression before ')'"
 msgstr "expression entière attendue avant « ) »"
@@ -35846,53 +35894,53 @@
 msgid "%qD is not a variable"
 msgstr "%qD n'est pas une variable"
 
-#: c/c-parser.c:11746 cp/semantics.c:6808
+#: c/c-parser.c:11746 cp/semantics.c:6811
 #, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "%qD n'est pas une variable pointeur"
 
-#: c/c-parser.c:11788 cp/parser.c:32073
+#: c/c-parser.c:11788 cp/parser.c:32070
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr "l'argument « collapse » a besoin d'une expression entière constante positive"
 
-#: c/c-parser.c:11865 cp/parser.c:32137
+#: c/c-parser.c:11865 cp/parser.c:32134
 #, gcc-internal-format
 msgid "expected %<none%> or %<present%>"
 msgstr "%<none%> ou %<present%> attendu"
 
-#: c/c-parser.c:11867 cp/parser.c:32139
+#: c/c-parser.c:11867 cp/parser.c:32136
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "%<none%> ou %<shared%> attendu"
 
-#: c/c-parser.c:11968 cp/parser.c:32242
+#: c/c-parser.c:11968 cp/parser.c:32239
 #, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "%<data%>, %<update%>, %<enter%> ou %<exit%> attendu"
 
-#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32260
-#: cp/parser.c:36290 cp/parser.c:36378
+#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32257
+#: cp/parser.c:36287 cp/parser.c:36375
 #, gcc-internal-format
 msgid "expected %<data%>"
 msgstr "%<data%> attendu"
 
-#: c/c-parser.c:12035 cp/parser.c:32313
+#: c/c-parser.c:12035 cp/parser.c:32310
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr "trop de %<if%> avec le modificateur %qs"
 
-#: c/c-parser.c:12042 cp/parser.c:32320
+#: c/c-parser.c:12042 cp/parser.c:32317
 #, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr "trop de clauses %<if%>"
 
-#: c/c-parser.c:12044 cp/parser.c:32322
+#: c/c-parser.c:12044 cp/parser.c:32319
 #, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr "trop de clauses %<if%> sans modificateur"
 
-#: c/c-parser.c:12050 cp/parser.c:32328
+#: c/c-parser.c:12050 cp/parser.c:32325
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr "si une clause %<if%> a un modificateur, alors toutes les clauses %<if%> doivent utiliser un modificateur"
@@ -35914,82 +35962,82 @@
 msgid "%<num_tasks%> value must be positive"
 msgstr "la valeur de %<num_tasks%> doit être positive"
 
-#: c/c-parser.c:12229 cp/semantics.c:6992
+#: c/c-parser.c:12229 cp/semantics.c:6995
 #, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr "la valeur de %<grainsize%> doit être positive"
 
-#: c/c-parser.c:12276 cp/semantics.c:7021
+#: c/c-parser.c:12276 cp/semantics.c:7024
 #, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr "la valeur de %<priority%> doit être positive ou nulle"
 
-#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32545 cp/parser.c:32552
+#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32542 cp/parser.c:32549
 #, gcc-internal-format
 msgid "expected %<tofrom%>"
 msgstr "%<tofrom%> attendu"
 
-#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32561 cp/parser.c:32568
+#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32558 cp/parser.c:32565
 #, gcc-internal-format
 msgid "expected %<scalar%>"
 msgstr "%<scalar%> attendu"
 
-#: c/c-parser.c:12425 cp/semantics.c:6299
+#: c/c-parser.c:12425 cp/semantics.c:6302
 #, gcc-internal-format
 msgid "%qs expression must be integral"
 msgstr "l'expression %qs doit être un entier"
 
-#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6331
+#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6334
 #, gcc-internal-format
 msgid "%qs value must be positive"
 msgstr "la valeur de %qs doit être positive"
 
-#: c/c-parser.c:12499 cp/parser.c:31853
+#: c/c-parser.c:12499 cp/parser.c:31850
 #, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "trop d'arguments pour %<static%>"
 
-#: c/c-parser.c:12533 cp/parser.c:31886
+#: c/c-parser.c:12533 cp/parser.c:31883
 #, gcc-internal-format
 msgid "unexpected argument"
 msgstr "argument inattendu"
 
-#: c/c-parser.c:12699 cp/semantics.c:7120
+#: c/c-parser.c:12699 cp/semantics.c:7123
 #, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "l'argument %<tile%> a besoin d'une constante entière positive"
 
-#: c/c-parser.c:12765 cp/parser.c:32626
+#: c/c-parser.c:12765 cp/parser.c:32623
 #, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr "les arguments ordonnés ont besoin d'une expression entière constante positive"
 
-#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37643
+#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37640
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "%<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> ou identificateur attendu"
 
-#: c/c-parser.c:12967 cp/parser.c:32840
+#: c/c-parser.c:12967 cp/parser.c:32837
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "les deux modificateurs %<monotonic%> et %<nonmonotonic%> sont spécifiés"
 
-#: c/c-parser.c:13021 cp/parser.c:32856
+#: c/c-parser.c:13021 cp/parser.c:32853
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "schedule %<runtime%> ne prend pas de paramètre %<chunk_size%>"
 
-#: c/c-parser.c:13025 cp/parser.c:32859
+#: c/c-parser.c:13025 cp/parser.c:32856
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "schedule %<auto%> ne prend pas de paramètre %<chunk_size%>"
 
-#: c/c-parser.c:13037 cp/semantics.c:6389
+#: c/c-parser.c:13037 cp/semantics.c:6392
 #, gcc-internal-format
 msgid "chunk size value must be positive"
 msgstr "la taille du fragment doit être positive"
 
-#: c/c-parser.c:13060 cp/parser.c:32879
+#: c/c-parser.c:13060 cp/parser.c:32876
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "type d'ordonnancement invalide"
@@ -35999,12 +36047,12 @@
 msgid "%<num_teams%> value must be positive"
 msgstr "la valeur de %<num_teams%> doit être positive"
 
-#: c/c-parser.c:13226 cp/semantics.c:6479
+#: c/c-parser.c:13226 cp/semantics.c:6482
 #, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr "la valeur de %<thread_limit%> doit être positive"
 
-#: c/c-parser.c:13271 cp/semantics.c:6589
+#: c/c-parser.c:13271 cp/semantics.c:6592
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr "l'expression d'alignement %<aligned%> doit être une expression entière constante positive"
@@ -36024,17 +36072,17 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr "l'expression %<simdlen%> doit être une expression entière constante positive"
 
-#: c/c-parser.c:13584 cp/parser.c:33374 cp/parser.c:33599
+#: c/c-parser.c:13584 cp/parser.c:33371 cp/parser.c:33596
 #, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "type de « depend » invalide"
 
-#: c/c-parser.c:13669 cp/parser.c:33447
+#: c/c-parser.c:13669 cp/parser.c:33444
 #, gcc-internal-format
 msgid "invalid map kind"
 msgstr "type de « map » invalide"
 
-#: c/c-parser.c:13767 cp/parser.c:33546
+#: c/c-parser.c:13767 cp/parser.c:33543
 #, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "type de « dist_schedule » invalide"
@@ -36044,67 +36092,67 @@
 msgid "invalid proc_bind kind"
 msgstr "type de « proc_bind » invalide"
 
-#: c/c-parser.c:14059 cp/parser.c:33825
+#: c/c-parser.c:14059 cp/parser.c:33822
 #, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr "clause %<#pragma acc%> attendue"
 
-#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33836 cp/parser.c:34143
+#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33833 cp/parser.c:34140
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs n'est pas valide pour %qs"
 
-#: c/c-parser.c:14214 cp/parser.c:34010
+#: c/c-parser.c:14214 cp/parser.c:34007
 #, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "%qs doit être la première clause de %qs"
 
-#: c/c-parser.c:14334 cp/parser.c:34132
+#: c/c-parser.c:14334 cp/parser.c:34129
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "clause %<#pragma omp%> attendue"
 
-#: c/c-parser.c:14472 cp/parser.c:36803
+#: c/c-parser.c:14472 cp/parser.c:36800
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr "pas de clause valide spécifiée dans %<#pragma acc declare%>"
 
-#: c/c-parser.c:14482 cp/parser.c:36813
+#: c/c-parser.c:14482 cp/parser.c:36810
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr "section de tableau dans %<#pragma acc declare%>"
 
-#: c/c-parser.c:14502 cp/parser.c:36833
+#: c/c-parser.c:14502 cp/parser.c:36830
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr "%qD doit être une variable globale dans %<#pragma acc declare link%>"
 
-#: c/c-parser.c:14513 cp/parser.c:36844
+#: c/c-parser.c:14513 cp/parser.c:36841
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr "clause OpenACC invalide au niveau global du fichier"
 
-#: c/c-parser.c:14520 cp/parser.c:36851
+#: c/c-parser.c:14520 cp/parser.c:36848
 #, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "utilisation invalide de la variable %<extern%> %qD dans %<#pragma acc declare%>"
 
-#: c/c-parser.c:14528 cp/parser.c:36859
+#: c/c-parser.c:14528 cp/parser.c:36856
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "utilisation invalide de la variable %<globale%> %qD dans %<#pragma acc declare%>"
 
-#: c/c-parser.c:14540 cp/parser.c:36871
+#: c/c-parser.c:14540 cp/parser.c:36868
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr "variable %qD utilisée plus d'une fois avec %<#pragma acc declare%>"
 
-#: c/c-parser.c:14632 cp/parser.c:36957
+#: c/c-parser.c:14632 cp/parser.c:36954
 #, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "%<data%> attendu après %<#pragma acc %s%>"
 
-#: c/c-parser.c:14648 cp/parser.c:36974
+#: c/c-parser.c:14648 cp/parser.c:36971
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr "%<#pragma acc %s data%> n'a pas clause de mouvement de données"
@@ -36119,7 +36167,7 @@
 msgid "expected function name"
 msgstr "nom de fonction attendu"
 
-#: c/c-parser.c:14893 cp/parser.c:38064
+#: c/c-parser.c:14893 cp/parser.c:38061
 #, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr "%qD ne fait pas référence à une fonction"
@@ -36129,42 +36177,42 @@
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr "%<#pragma acc routine%> n'est pas immédiatement suivi d'une déclaration ou d'une définition de fonction"
 
-#: c/c-parser.c:14953 cp/parser.c:38118 cp/parser.c:38160
+#: c/c-parser.c:14953 cp/parser.c:38115 cp/parser.c:38157
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr "%<#pragma acc routine%> n'est pas immédiatement suivi d'une seule déclaration ou définition de fonction"
 
-#: c/c-parser.c:14970 cp/parser.c:38174
+#: c/c-parser.c:14970 cp/parser.c:38171
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> already applied to %qD"
 msgstr "%<#pragma acc routine%> déjà appliqué à %qD"
 
-#: c/c-parser.c:14979 cp/parser.c:38183
+#: c/c-parser.c:14979 cp/parser.c:38180
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr "%<#pragma acc routine%> doit être appliqué avant l'utilisation"
 
-#: c/c-parser.c:14980 cp/parser.c:38184
+#: c/c-parser.c:14980 cp/parser.c:38181
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<#pragma acc routine%> doit être appliqué avant la définition"
 
-#: c/c-parser.c:15023 cp/parser.c:37152
+#: c/c-parser.c:15023 cp/parser.c:37149
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr "%<#pragma acc update%> doit contenir au moins une clause %<device%> ou %<host%> ou %<self%>"
 
-#: c/c-parser.c:15435 cp/parser.c:34511 cp/parser.c:34537
+#: c/c-parser.c:15435 cp/parser.c:34508 cp/parser.c:34534
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "forme invalide de %<#pragma omp atomic%>"
 
-#: c/c-parser.c:15439 cp/parser.c:34568 cp/parser.c:34584
+#: c/c-parser.c:15439 cp/parser.c:34565 cp/parser.c:34581
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "opération invalide pour %<#pragma omp atomic%>"
 
-#: c/c-parser.c:15488 cp/semantics.c:8401 cp/semantics.c:8411
+#: c/c-parser.c:15488 cp/semantics.c:8404 cp/semantics.c:8414
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr "%<#pragma omp atomic capture%> utilise deux expressions différentes pour la mémoire"
@@ -36174,22 +36222,22 @@
 msgid "expected %<(%> or end of line"
 msgstr "%<(%> ou fin de ligne attendue"
 
-#: c/c-parser.c:15619 cp/parser.c:35103
+#: c/c-parser.c:15619 cp/parser.c:35100
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr "le paramètre de la clause %<ordered%> est plus petit que %<collapse%>"
 
-#: c/c-parser.c:15630 cp/parser.c:35114
+#: c/c-parser.c:15630 cp/parser.c:35111
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr "la clause %<linear%> ne peut pas être spécifiée avec la clause %<ordered%> comportant un paramètre"
 
-#: c/c-parser.c:15648 cp/parser.c:35141
+#: c/c-parser.c:15648 cp/parser.c:35138
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "instruction « for » attendue"
 
-#: c/c-parser.c:15718 cp/semantics.c:8066 cp/semantics.c:8153
+#: c/c-parser.c:15718 cp/semantics.c:8069 cp/semantics.c:8156
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "déclaration ou initialisation d'itération attendue"
@@ -36199,72 +36247,72 @@
 msgid "not enough perfectly nested loops"
 msgstr "pas assez de boucles parfaitement imbriquées"
 
-#: c/c-parser.c:15862 cp/parser.c:35364
+#: c/c-parser.c:15862 cp/parser.c:35361
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr "boucles coalescées imparfaitement imbriquées"
 
-#: c/c-parser.c:15909 cp/parser.c:35184 cp/parser.c:35226 cp/pt.c:16385
+#: c/c-parser.c:15909 cp/parser.c:35181 cp/parser.c:35223 cp/pt.c:16407
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "la variable d'itération %qD ne devrait pas être « firstprivate »"
 
-#: c/c-parser.c:16000 cp/parser.c:35437
+#: c/c-parser.c:16000 cp/parser.c:35434
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "la clause %<ordered%> avec un paramètre ne devrait pas être spécifiée sur la construction %qs"
 
-#: c/c-parser.c:16166 cp/parser.c:35600
+#: c/c-parser.c:16166 cp/parser.c:35597
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr "%<#pragma omp ordered%> avec une clause %<depend%> peut uniquement être utilisé dans des instructions composées"
 
-#: c/c-parser.c:16374 cp/parser.c:35799
+#: c/c-parser.c:16374 cp/parser.c:35796
 #, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "%<for%> attendu après %qs"
 
-#: c/c-parser.c:16573 cp/parser.c:35995
+#: c/c-parser.c:16573 cp/parser.c:35992
 #, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "%<point%> attendu"
 
-#: c/c-parser.c:16793 cp/parser.c:36232
+#: c/c-parser.c:16793 cp/parser.c:36229
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target data%> avec un type avec correspondance autre que %<to%>, %<from%>, %<tofrom%> ou %<alloc%> sur un clause %<map%>"
 
-#: c/c-parser.c:16806 cp/parser.c:36245
+#: c/c-parser.c:16806 cp/parser.c:36242
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp target data%> doit contenir au moins une clause %<map%>"
 
-#: c/c-parser.c:16853 cp/parser.c:36470
+#: c/c-parser.c:16853 cp/parser.c:36467
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr "%<#pragma omp target update%> doit contenir au moins une clause %<from%> ou %<to%>"
 
-#: c/c-parser.c:16925 cp/parser.c:36325
+#: c/c-parser.c:16925 cp/parser.c:36322
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target enter data%> avec un type avec correspondance autre que %<to%> ou %<alloc%> sur une clause %<map%>"
 
-#: c/c-parser.c:16937 cp/parser.c:36337
+#: c/c-parser.c:16937 cp/parser.c:36334
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp target enter data%> doit contenir au moins une clause %<map%>"
 
-#: c/c-parser.c:17011 cp/parser.c:36414
+#: c/c-parser.c:17011 cp/parser.c:36411
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr "%<#pragma omp target exit data%> avec un type « map » autre que %<from%>, %<release%> ou %<delete%> sur une clause %<map%>"
 
-#: c/c-parser.c:17024 cp/parser.c:36427
+#: c/c-parser.c:17024 cp/parser.c:36424
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp target exit data%> doit contenir au moins une clause %<map%>"
 
-#: c/c-parser.c:17238 cp/parser.c:36680
+#: c/c-parser.c:17238 cp/parser.c:36677
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target%> avec un type avec correspondance autre que %<to%>, %<from%>, %<tofrom%> ou %<alloc%> sur une clause %<map%>"
@@ -36284,32 +36332,32 @@
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr "%<#pragma omp declare simd%> pas immédiatement suivi d'une déclaration ou une définition de fonction"
 
-#: c/c-parser.c:17395 cp/parser.c:37273
+#: c/c-parser.c:17395 cp/parser.c:37270
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr "%<#pragma omp declare simd%> pas immédiatement suivi par une seule déclaration ou définition de fonction"
 
-#: c/c-parser.c:17474 cp/parser.c:37343
+#: c/c-parser.c:17474 cp/parser.c:37340
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> with clauses in between %<#pragma omp declare target%> without clauses and %<#pragma omp end declare target%>"
 msgstr "%<#pragma omp declare target%> avec des clauses entre %<#pragma omp declare target%> sans clauses et %<#pragma omp end declare target%>"
 
-#: c/c-parser.c:17493 cp/parser.c:37362
+#: c/c-parser.c:17493 cp/parser.c:37359
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr "%qD est spécifié à la fois dans les clauses declare target %<link%> et %<to%>"
 
-#: c/c-parser.c:17534 cp/parser.c:37409
+#: c/c-parser.c:17534 cp/parser.c:37406
 #, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "%<target%> attendu"
 
-#: c/c-parser.c:17541 cp/parser.c:37416
+#: c/c-parser.c:17541 cp/parser.c:37413
 #, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "%<declare%> attendu"
 
-#: c/c-parser.c:17547 cp/parser.c:37423
+#: c/c-parser.c:17547 cp/parser.c:37420
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr "%<#pragma omp end declare target%> sans %<#pragma omp declare target%> correspondant"
@@ -36364,47 +36412,47 @@
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr "un des arguments de l'appel de l'initialisation devrait être %<&omp_priv%>"
 
-#: c/c-parser.c:17947 cp/parser.c:37868
+#: c/c-parser.c:17947 cp/parser.c:37865
 #, gcc-internal-format
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr "%<simd%> ou %<reduction%> ou %<target%> attendu"
 
-#: c/c-parser.c:18162 cp/semantics.c:7531
+#: c/c-parser.c:18162 cp/semantics.c:7534
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE est déclaré %<threadprivate%> après la première utilisation"
 
-#: c/c-parser.c:18164 cp/semantics.c:7533
+#: c/c-parser.c:18164 cp/semantics.c:7536
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "la variable automatique %qE ne peut être %<threadprivate%>"
 
-#: c/c-parser.c:18168 cp/semantics.c:7535
+#: c/c-parser.c:18168 cp/semantics.c:7538
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%<threadprivate%> %qE a un type incomplet"
 
-#: c/c-parser.c:18368 cp/parser.c:38565
+#: c/c-parser.c:18368 cp/parser.c:38562
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr "%<__transaction_cancel%> sans avoir activé le support pour la mémoire transactionnelle"
 
-#: c/c-parser.c:18374 cp/parser.c:38571
+#: c/c-parser.c:18374 cp/parser.c:38568
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr "%<__transaction_cancel%> à l'intérieur de %<__transaction_relaxed%>"
 
-#: c/c-parser.c:18383 cp/parser.c:38580
+#: c/c-parser.c:18383 cp/parser.c:38577
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr "le %<__transaction_cancel%> extérieur n'est pas à l'intérieur d'un %<__transaction_atomic%> extérieur"
 
-#: c/c-parser.c:18385 cp/parser.c:38583
+#: c/c-parser.c:18385 cp/parser.c:38580
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr "  ou une fonction %<transaction_may_cancel_outer%>"
 
-#: c/c-parser.c:18391 cp/parser.c:38589
+#: c/c-parser.c:18391 cp/parser.c:38586
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr "%<__transaction_cancel%> pas à l'intérieur de %<__transaction_atomic%>"
@@ -36419,7 +36467,7 @@
 msgid "%qD has an incomplete type %qT"
 msgstr "%qD a un type incomplet %qT"
 
-#: c/c-typeck.c:237 c/c-typeck.c:9994 c/c-typeck.c:10036 cp/call.c:4147
+#: c/c-typeck.c:237 c/c-typeck.c:9999 c/c-typeck.c:10041 cp/call.c:4147
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "utilisation invalide de l'expression void"
@@ -36495,12 +36543,12 @@
 msgid "converting an array compound literal to a pointer is ill-formed in C++"
 msgstr "convertir un tableau de littéraux composés en un pointeur est mal formé en C++"
 
-#: c/c-typeck.c:2417 c/c-typeck.c:8641
+#: c/c-typeck.c:2417 c/c-typeck.c:8646
 #, gcc-internal-format
 msgid "%qT has no member named %qE; did you mean %qE?"
 msgstr "%qT n'a pas de membre nommé %qE; vouliez-vous employer %qE ?"
 
-#: c/c-typeck.c:2421 c/c-typeck.c:8645
+#: c/c-typeck.c:2421 c/c-typeck.c:8650
 #, gcc-internal-format
 msgid "%qT has no member named %qE"
 msgstr "%qT n'a pas de membre nommé %qE"
@@ -36698,457 +36746,457 @@
 msgid "pointer to a function used in subtraction"
 msgstr "pointeur vers une fonction utilisé dans une soustraction"
 
-#: c/c-typeck.c:3847
+#: c/c-typeck.c:3852
 #, gcc-internal-format
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "arithmétique sur un pointeur vers un type incomplet"
 
-#: c/c-typeck.c:3852 cp/typeck.c:5562
+#: c/c-typeck.c:3857 cp/typeck.c:5562
 #, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr "arithmétique sur un pointeur vers un agrégat vide"
 
-#: c/c-typeck.c:4283
+#: c/c-typeck.c:4288
 #, gcc-internal-format
 msgid "%<~%> on a boolean expression"
 msgstr "%<~%> sur une expression booléenne"
 
-#: c/c-typeck.c:4287
+#: c/c-typeck.c:4292
 #, gcc-internal-format
 msgid "did you mean to use logical not?"
 msgstr "vouliez-vous utiliser le « non » logique ?"
 
-#: c/c-typeck.c:4296
+#: c/c-typeck.c:4301
 #, gcc-internal-format
 msgid "ISO C does not support %<~%> for complex conjugation"
 msgstr "le C ISO ne permet pas d'utiliser %<~%> pour calculer le conjugué d'un complexe"
 
-#: c/c-typeck.c:4335
+#: c/c-typeck.c:4340
 #, gcc-internal-format
 msgid "wrong type argument to unary exclamation mark"
 msgstr "type d'argument erroné pour le point d'exclamation unaire"
 
-#: c/c-typeck.c:4393
+#: c/c-typeck.c:4398
 #, gcc-internal-format
 msgid "increment of enumeration value is invalid in C++"
 msgstr "incrémenter une valeur énumérée est invalide en C++"
 
-#: c/c-typeck.c:4396
+#: c/c-typeck.c:4401
 #, gcc-internal-format
 msgid "decrement of enumeration value is invalid in C++"
 msgstr "décrémenter une valeur énumérée est invalide en C++"
 
-#: c/c-typeck.c:4403
+#: c/c-typeck.c:4408
 #, gcc-internal-format
 msgid "increment of a boolean expression"
 msgstr "incrémentation d'une expression booléenne"
 
-#: c/c-typeck.c:4406
+#: c/c-typeck.c:4411
 #, gcc-internal-format
 msgid "decrement of a boolean expression"
 msgstr "décrémentation d'une expression booléenne"
 
-#: c/c-typeck.c:4422
+#: c/c-typeck.c:4427
 #, gcc-internal-format
 msgid "ISO C does not support %<++%> and %<--%> on complex types"
 msgstr "le C ISO ne permet pas %<++%> ni %<--%> sur les types complexes"
 
-#: c/c-typeck.c:4447 c/c-typeck.c:4481
+#: c/c-typeck.c:4452 c/c-typeck.c:4486
 #, gcc-internal-format
 msgid "wrong type argument to increment"
 msgstr "type d'argument erroné pour un incrément"
 
-#: c/c-typeck.c:4449 c/c-typeck.c:4484
+#: c/c-typeck.c:4454 c/c-typeck.c:4489
 #, gcc-internal-format
 msgid "wrong type argument to decrement"
 msgstr "type d'argument erroné pour un décrément"
 
-#: c/c-typeck.c:4469
+#: c/c-typeck.c:4474
 #, gcc-internal-format
 msgid "increment of pointer to an incomplete type %qT"
 msgstr "incrément d'un pointeur vers un type incomplet %qT"
 
-#: c/c-typeck.c:4473
+#: c/c-typeck.c:4478
 #, gcc-internal-format
 msgid "decrement of pointer to an incomplete type %qT"
 msgstr "décrément d'un pointeur vers un type incomplet %qT"
 
-#: c/c-typeck.c:4577
+#: c/c-typeck.c:4582
 #, gcc-internal-format
 msgid "taking address of expression of type %<void%>"
 msgstr "prise de l'adresse d'une expression de type %<void%>"
 
-#: c/c-typeck.c:4636
+#: c/c-typeck.c:4641
 #, gcc-internal-format
 msgid "cannot take address of bit-field %qD"
 msgstr "ne peut prendre l'adresse du champ de bits %qD"
 
-#: c/c-typeck.c:4649
+#: c/c-typeck.c:4654
 #, gcc-internal-format
 msgid "cannot take address of scalar with reverse storage order"
 msgstr "ne peut prendre l'adresse d'un scalaire avec un ordre de stockage inversé"
 
-#: c/c-typeck.c:4657
+#: c/c-typeck.c:4662
 #, gcc-internal-format
 msgid "address of array with reverse scalar storage order requested"
 msgstr "adresse demandée pour un tableau avec un ordre de stockage scalaire inversé"
 
-#: c/c-typeck.c:4838
+#: c/c-typeck.c:4843
 #, gcc-internal-format
 msgid "global register variable %qD used in nested function"
 msgstr "variable globale de registre %qD utilisée dans une fonction imbriquée"
 
-#: c/c-typeck.c:4841
+#: c/c-typeck.c:4846
 #, gcc-internal-format
 msgid "register variable %qD used in nested function"
 msgstr "variable de registre %qD utilisée dans une fonction imbriquée"
 
-#: c/c-typeck.c:4846
+#: c/c-typeck.c:4851
 #, gcc-internal-format
 msgid "address of global register variable %qD requested"
 msgstr "adresse d'une variable registre globale %qD demandée"
 
-#: c/c-typeck.c:4848
+#: c/c-typeck.c:4853
 #, gcc-internal-format
 msgid "address of register variable %qD requested"
 msgstr "adresse d'une variable registre %qD demandée"
 
-#: c/c-typeck.c:4951
+#: c/c-typeck.c:4956
 #, gcc-internal-format
 msgid "non-lvalue array in conditional expression"
 msgstr "le tableau n'est pas une l-valeur dans l'expression conditionnelle"
 
-#: c/c-typeck.c:5033
+#: c/c-typeck.c:5038
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other result of conditional"
 msgstr "conversion implicite depuis %qT vers %qT pour correspondre à d'autres résultats de la condition"
 
-#: c/c-typeck.c:5092 c/c-typeck.c:5098
+#: c/c-typeck.c:5097 c/c-typeck.c:5103
 #, gcc-internal-format
 msgid "operand of ?: changes signedness from %qT to %qT due to unsignedness of other operand"
 msgstr "l'opérande de ?: change de type signé de %qT à %qT à cause du caractère non signé de l'autre opérande"
 
-#: c/c-typeck.c:5115
+#: c/c-typeck.c:5120
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr with only one void side"
 msgstr "le C ISO interdit une expression conditionnelle dont un seul côté est « void »"
 
-#: c/c-typeck.c:5132
+#: c/c-typeck.c:5137
 #, gcc-internal-format
 msgid "pointers to disjoint address spaces used in conditional expression"
 msgstr "pointeurs vers des espaces d'adresses disjoints utilisés dans une expression conditionnelle"
 
-#: c/c-typeck.c:5143 c/c-typeck.c:5160
+#: c/c-typeck.c:5148 c/c-typeck.c:5165
 #, gcc-internal-format
 msgid "pointer to array loses qualifier in conditional expression"
 msgstr "le pointeur vers le tableau perd le qualificatif dans l'expression conditionnelle"
 
-#: c/c-typeck.c:5148 c/c-typeck.c:5165
+#: c/c-typeck.c:5153 c/c-typeck.c:5170
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr between %<void *%> and function pointer"
 msgstr "le C ISO interdit une expression conditionnelle entre %<void *%> et un pointeur de fonction"
 
-#: c/c-typeck.c:5178
+#: c/c-typeck.c:5183
 #, gcc-internal-format
 msgid "pointer type mismatch in conditional expression"
 msgstr "non concordance de type de pointeurs dans une expression conditionnelle"
 
-#: c/c-typeck.c:5187 c/c-typeck.c:5198
+#: c/c-typeck.c:5192 c/c-typeck.c:5203
 #, gcc-internal-format
 msgid "pointer/integer type mismatch in conditional expression"
 msgstr "non concordance entre un pointeur et un entier dans une expression conditionnelle"
 
-#: c/c-typeck.c:5336
+#: c/c-typeck.c:5341
 #, gcc-internal-format
 msgid "left-hand operand of comma expression has no effect"
 msgstr "l'opérande à gauche de la virgule n'a pas d'effet"
 
-#: c/c-typeck.c:5354 c/c-typeck.c:10636
+#: c/c-typeck.c:5359 c/c-typeck.c:10641
 #, gcc-internal-format
 msgid "right-hand operand of comma expression has no effect"
 msgstr "l'opérande à droite de la virgule n'a pas d'effet"
 
-#: c/c-typeck.c:5423
+#: c/c-typeck.c:5428
 msgid "cast adds %q#v qualifier to function type"
 msgstr "le transtypage ajoute le qualificatif %q#v au type de la fonction"
 
-#: c/c-typeck.c:5429
+#: c/c-typeck.c:5434
 msgid "cast discards %qv qualifier from pointer target type"
 msgstr "le transtypage annule le qualificatif %qv du type ciblé par le pointeur"
 
-#: c/c-typeck.c:5464
+#: c/c-typeck.c:5469
 #, gcc-internal-format
 msgid "to be safe all intermediate pointers in cast from %qT to %qT must be %<const%> qualified"
 msgstr "pour être sûrs, tous les pointeurs intermédiaires dans les transtypages de %qT vers %qT doivent être qualifiés avec %<const%>"
 
-#: c/c-typeck.c:5554
+#: c/c-typeck.c:5559
 #, gcc-internal-format
 msgid "cast specifies array type"
 msgstr "le transtypage spécifie un type de tableau"
 
-#: c/c-typeck.c:5560
+#: c/c-typeck.c:5565
 #, gcc-internal-format
 msgid "cast specifies function type"
 msgstr "le transtypage spécifie un type de fonction"
 
-#: c/c-typeck.c:5575
+#: c/c-typeck.c:5580
 #, gcc-internal-format
 msgid "ISO C forbids casting nonscalar to the same type"
 msgstr "le C ISO interdit le transtypage d'un type non scalaire vers lui-même"
 
-#: c/c-typeck.c:5595
+#: c/c-typeck.c:5600
 #, gcc-internal-format
 msgid "ISO C forbids casts to union type"
 msgstr "le C ISO interdit le transtypage vers un type union"
 
-#: c/c-typeck.c:5605
+#: c/c-typeck.c:5610
 #, gcc-internal-format
 msgid "cast to union type from type not present in union"
 msgstr "transtypage vers un type union depuis un type absent de l'union"
 
-#: c/c-typeck.c:5640
+#: c/c-typeck.c:5645
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint generic address space pointer"
 msgstr "transtypage vers un pointeur de l'espace d'adresses %s depuis un pointeur d'espace d'adresses générique disjoint"
 
-#: c/c-typeck.c:5645
+#: c/c-typeck.c:5650
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to generic address space pointer from disjoint %s address space pointer"
 msgstr "transtypage vers un pointeur de l'espace d'adresses générique vers un pointeur de l'espace d'adresses %s disjoint"
 
-#: c/c-typeck.c:5650
+#: c/c-typeck.c:5655
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint %s address space pointer"
 msgstr "transtypage vers un pointeur de l'espace d'adresses %s depuis un pointeur de l'espace d'adresses %s disjoint"
 
-#: c/c-typeck.c:5670
+#: c/c-typeck.c:5675
 #, gcc-internal-format
 msgid "cast increases required alignment of target type"
 msgstr "le transtypage augmente l'alignement requis pour le type ciblé"
 
-#: c/c-typeck.c:5681
+#: c/c-typeck.c:5686
 #, gcc-internal-format
 msgid "cast from pointer to integer of different size"
 msgstr "transtypage d'un pointeur vers un entier de taille différente"
 
-#: c/c-typeck.c:5686
+#: c/c-typeck.c:5691
 #, gcc-internal-format
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "transtypage d'un appel de fonction de type %qT vers le type %qT ne correspondant pas"
 
-#: c/c-typeck.c:5695 cp/typeck.c:7811
+#: c/c-typeck.c:5700 cp/typeck.c:7811
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "transtypage vers un pointeur depuis un entier de taille différente"
 
-#: c/c-typeck.c:5709
+#: c/c-typeck.c:5714
 #, gcc-internal-format
 msgid "ISO C forbids conversion of function pointer to object pointer type"
 msgstr "le C ISO interdit la conversion d'un pointeur de fonction en un type de pointeur vers un objet"
 
-#: c/c-typeck.c:5718
+#: c/c-typeck.c:5723
 #, gcc-internal-format
 msgid "ISO C forbids conversion of object pointer to function pointer type"
 msgstr "le C ISO interdit la conversion d'un pointeur vers un objet en un type de pointeur vers une fonction"
 
-#: c/c-typeck.c:5728
+#: c/c-typeck.c:5733
 #, gcc-internal-format
 msgid "cast between incompatible function types from %qT to %qT"
 msgstr "transtypage entre des types de fonction incompatibles de %qT vers %qT"
 
-#: c/c-typeck.c:5815
+#: c/c-typeck.c:5820
 #, gcc-internal-format
 msgid "defining a type in a cast is invalid in C++"
 msgstr "définir un type dans un transtypage est invalide en C++"
 
-#: c/c-typeck.c:5856
+#: c/c-typeck.c:5861
 #, gcc-internal-format
 msgid "assignment to expression with array type"
 msgstr "affectation vers une expression de type tableau"
 
-#: c/c-typeck.c:5982
+#: c/c-typeck.c:5987
 #, gcc-internal-format
 msgid "enum conversion in assignment is invalid in C++"
 msgstr "la conversion en enum dans une affectation est invalide en C++"
 
-#: c/c-typeck.c:6180 c/c-typeck.c:6202 c/c-typeck.c:6226
+#: c/c-typeck.c:6185 c/c-typeck.c:6207 c/c-typeck.c:6231
 #, gcc-internal-format
 msgid "(near initialization for %qs)"
 msgstr "(près de l'initialisation de %qs)"
 
-#: c/c-typeck.c:6241
+#: c/c-typeck.c:6246
 #, gcc-internal-format
 msgid "array initialized from parenthesized string constant"
 msgstr "tableau initialisé depuis une constante chaîne entre parenthèses"
 
-#: c/c-typeck.c:6284 c/c-typeck.c:6476 c/c-typeck.c:6908
+#: c/c-typeck.c:6289 c/c-typeck.c:6481 c/c-typeck.c:6913
 #, gcc-internal-format
 msgid "expected %qT but argument is of type %qT"
 msgstr "%qT attendu mais l'argument est de type %qT"
 
-#: c/c-typeck.c:6471
+#: c/c-typeck.c:6476
 #, gcc-internal-format
 msgid "enum conversion when passing argument %d of %qE is invalid in C++"
 msgstr "la conversion d'un enum lors du passage de l'argument %d de %qE est invalide en C++"
 
-#: c/c-typeck.c:6480
+#: c/c-typeck.c:6485
 #, gcc-internal-format
 msgid "enum conversion from %qT to %qT in assignment is invalid in C++"
 msgstr "la conversion d'un enum de %qT vers %qT dans une affectation est invalide en C++"
 
-#: c/c-typeck.c:6484
+#: c/c-typeck.c:6489
 #, gcc-internal-format
 msgid "enum conversion from %qT to %qT in initialization is invalid in C++"
 msgstr "la conversion d'un enum de %qT vers %qT durant l'initialisation est invalide en C++"
 
-#: c/c-typeck.c:6489
+#: c/c-typeck.c:6494
 #, gcc-internal-format
 msgid "enum conversion from %qT to %qT in return is invalid in C++"
 msgstr "la conversion d'un enum de %qT vers %qT durant le retour est invalide en C++"
 
-#: c/c-typeck.c:6523
+#: c/c-typeck.c:6528
 #, gcc-internal-format
 msgid "cannot pass rvalue to reference parameter"
 msgstr "impossible de passer une r-valeur en paramètre par référence"
 
-#: c/c-typeck.c:6656 c/c-typeck.c:6942
+#: c/c-typeck.c:6661 c/c-typeck.c:6947
 msgid "passing argument %d of %qE makes %q#v qualified function pointer from unqualified"
 msgstr "passer l'argument %d de %qE ajoute le qualificatif %q#v au pointeur de fonction qui n'avait pas de qualificatif"
 
-#: c/c-typeck.c:6659 c/c-typeck.c:6945
+#: c/c-typeck.c:6664 c/c-typeck.c:6950
 msgid "assignment makes %q#v qualified function pointer from unqualified"
 msgstr "l'affectation ajoute la qualificatif %q#v au pointeur de fonction qui n'avait pas de qualificatif"
 
-#: c/c-typeck.c:6662 c/c-typeck.c:6947
+#: c/c-typeck.c:6667 c/c-typeck.c:6952
 msgid "initialization makes %q#v qualified function pointer from unqualified"
 msgstr "l'initialisation ajoute le qualificatif %q#v au pointeur de fonction qui n'avait pas de qualificatif"
 
-#: c/c-typeck.c:6665 c/c-typeck.c:6949
+#: c/c-typeck.c:6670 c/c-typeck.c:6954
 msgid "return makes %q#v qualified function pointer from unqualified"
 msgstr "le retour ajoute le qualificatif %q#v au pointeur de fonction qui n'avait pas de qualificatif"
 
-#: c/c-typeck.c:6673 c/c-typeck.c:6840 c/c-typeck.c:6883
+#: c/c-typeck.c:6678 c/c-typeck.c:6845 c/c-typeck.c:6888
 msgid "passing argument %d of %qE discards %qv qualifier from pointer target type"
 msgstr "passer l'argument %d de %qE abandonne le qualificatif %qv du type pointé"
 
-#: c/c-typeck.c:6675 c/c-typeck.c:6842 c/c-typeck.c:6885
+#: c/c-typeck.c:6680 c/c-typeck.c:6847 c/c-typeck.c:6890
 msgid "assignment discards %qv qualifier from pointer target type"
 msgstr "l'affectation abandonne le qualificatif %qv du type pointé"
 
-#: c/c-typeck.c:6677 c/c-typeck.c:6844 c/c-typeck.c:6887
+#: c/c-typeck.c:6682 c/c-typeck.c:6849 c/c-typeck.c:6892
 msgid "initialization discards %qv qualifier from pointer target type"
 msgstr "l'initialisation abandonne le qualificatif %qv du type pointé"
 
-#: c/c-typeck.c:6679 c/c-typeck.c:6846 c/c-typeck.c:6889
+#: c/c-typeck.c:6684 c/c-typeck.c:6851 c/c-typeck.c:6894
 msgid "return discards %qv qualifier from pointer target type"
 msgstr "le retour abandonne le qualificatif %qv du type pointé"
 
-#: c/c-typeck.c:6688
+#: c/c-typeck.c:6693
 #, gcc-internal-format
 msgid "ISO C prohibits argument conversion to union type"
 msgstr "le C ISO interdit la conversion d'argument en type union"
 
-#: c/c-typeck.c:6750
+#: c/c-typeck.c:6755
 #, gcc-internal-format
 msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgstr "la conversion implicite de %qT vers %qT n'est pas permise en C++"
 
-#: c/c-typeck.c:6762
+#: c/c-typeck.c:6767
 #, gcc-internal-format
 msgid "passing argument %d of %qE from pointer to non-enclosed address space"
 msgstr "passage de l'argument %d de %qE depuis un pointeur vers un espace d'adresses non fermé"
 
-#: c/c-typeck.c:6766
+#: c/c-typeck.c:6771
 #, gcc-internal-format
 msgid "assignment from pointer to non-enclosed address space"
 msgstr "affectation depuis un pointeur vers un espace d'adresses non fermé"
 
-#: c/c-typeck.c:6770
+#: c/c-typeck.c:6775
 #, gcc-internal-format
 msgid "initialization from pointer to non-enclosed address space"
 msgstr "initialisation depuis un pointeur vers un espace d'adresses non fermé"
 
-#: c/c-typeck.c:6774
+#: c/c-typeck.c:6779
 #, gcc-internal-format
 msgid "return from pointer to non-enclosed address space"
 msgstr "retour depuis un pointeur vers un espace d'adresses non fermé"
 
-#: c/c-typeck.c:6792
+#: c/c-typeck.c:6797
 #, gcc-internal-format
 msgid "argument %d of %qE might be a candidate for a format attribute"
 msgstr "l'argument %d de %qE pourrait être un candidat pour un attribut de format"
 
-#: c/c-typeck.c:6798
+#: c/c-typeck.c:6803
 #, gcc-internal-format
 msgid "assignment left-hand side might be a candidate for a format attribute"
 msgstr "le membre de gauche de l'affectation pourrait être un candidat pour un attribut de format"
 
-#: c/c-typeck.c:6803
+#: c/c-typeck.c:6808
 #, gcc-internal-format
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "le membre de gauche de l'initialisation pourrait être un candidat pour un attribut de format"
 
-#: c/c-typeck.c:6808 cp/typeck.c:8891
+#: c/c-typeck.c:6813 cp/typeck.c:8891
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "le type de retour pourrait être un candidat pour un attribut de format"
 
-#: c/c-typeck.c:6857
+#: c/c-typeck.c:6862
 #, gcc-internal-format
 msgid "ISO C forbids passing argument %d of %qE between function pointer and %<void *%>"
 msgstr "le C ISO interdit de passer l'argument %d de %qE entre un pointeur de fonction et %<void *%>"
 
-#: c/c-typeck.c:6860
+#: c/c-typeck.c:6865
 #, gcc-internal-format
 msgid "ISO C forbids assignment between function pointer and %<void *%>"
 msgstr "le C ISO interdit l'affectation entre un pointeur de fonction et %<void *%>"
 
-#: c/c-typeck.c:6862
+#: c/c-typeck.c:6867
 #, gcc-internal-format
 msgid "ISO C forbids initialization between function pointer and %<void *%>"
 msgstr "le C ISO interdit l'initialisation entre un pointeur de fonction et %<void *%>"
 
-#: c/c-typeck.c:6864
+#: c/c-typeck.c:6869
 #, gcc-internal-format
 msgid "ISO C forbids return between function pointer and %<void *%>"
 msgstr "le C ISO interdit le retour entre un pointeur de fonction et %<void *%>"
 
-#: c/c-typeck.c:6904
+#: c/c-typeck.c:6909
 #, gcc-internal-format
 msgid "pointer targets in passing argument %d of %qE differ in signedness"
 msgstr "les cibles pointées dans le passage de l'argument %d de %qE diffèrent dans la plage signée"
 
-#: c/c-typeck.c:6913
+#: c/c-typeck.c:6918
 #, gcc-internal-format
 msgid "pointer targets in assignment from %qT to %qT differ in signedness"
 msgstr "les cibles pointées dans l'affectation de %qT vers %qT diffèrent dans la plage signée"
 
-#: c/c-typeck.c:6918
+#: c/c-typeck.c:6923
 #, gcc-internal-format
 msgid "pointer targets in initialization of %qT from %qT differ in signedness"
 msgstr "les cibles pointées dans l'initialisation de %qT depuis %qT diffèrent dans la plage signée"
 
-#: c/c-typeck.c:6923
+#: c/c-typeck.c:6928
 #, gcc-internal-format
 msgid "pointer targets in returning %qT from a function with return type %qT differ in signedness"
 msgstr "les cibles pointées en retournant %qT depuis une fonction qui retourne le type %qT  diffèrent dans la plage signée"
 
-#: c/c-typeck.c:6961
+#: c/c-typeck.c:6966
 #, gcc-internal-format
 msgid "passing argument %d of %qE from incompatible pointer type"
 msgstr "passage de l'argument %d de %qE depuis un type pointeur incompatible"
 
-#: c/c-typeck.c:6967
+#: c/c-typeck.c:6972
 #, gcc-internal-format
 msgid "assignment to %qT from incompatible pointer type %qT"
 msgstr "affectation à %qT depuis le type pointeur %qT qui est incompatible"
 
-#: c/c-typeck.c:6972
+#: c/c-typeck.c:6977
 #, gcc-internal-format
 msgid "initialization of %qT from incompatible pointer type %qT"
 msgstr "initialisation de %qT depuis le type pointeur %qT qui est incompatible"
 
-#: c/c-typeck.c:6977
+#: c/c-typeck.c:6982
 #, gcc-internal-format
 msgid "returning %qT from a function with incompatible return type %qT"
 msgstr "retour de %qT depuis une fonction avec le type de retour %qT qui est incompatible"
@@ -37155,783 +37203,783 @@
 
 #. ??? This should not be an error when inlining calls to
 #. unprototyped functions.
-#: c/c-typeck.c:6991 c/c-typeck.c:7514 cp/typeck.c:2063
+#: c/c-typeck.c:6996 c/c-typeck.c:7519 cp/typeck.c:2063
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "utilisation invalide d'un tableau n'étant pas une l-valeur"
 
-#: c/c-typeck.c:7004
+#: c/c-typeck.c:7009
 #, gcc-internal-format
 msgid "passing argument %d of %qE makes pointer from integer without a cast"
 msgstr "le passage de l'argument %d de %qE transforme un entier en pointeur sans transtypage"
 
-#: c/c-typeck.c:7010
+#: c/c-typeck.c:7015
 #, gcc-internal-format
 msgid "assignment to %qT from %qT makes pointer from integer without a cast"
 msgstr "l'affectation à %qT depuis %qT transforme un entier en pointeur sans transtypage"
 
-#: c/c-typeck.c:7015
+#: c/c-typeck.c:7020
 #, gcc-internal-format
 msgid "initialization of %qT from %qT makes pointer from integer without a cast"
 msgstr "l'initialisation de %qT depuis %qT transforme un entier en pointeur sans transtypage"
 
-#: c/c-typeck.c:7019
+#: c/c-typeck.c:7024
 #, gcc-internal-format
 msgid "returning %qT from a function with return type %qT makes pointer from integer without a cast"
 msgstr "retourner %qT depuis une fonction avec le type de retour %qT transforme un entier en pointeur sans transtypage"
 
-#: c/c-typeck.c:7035
+#: c/c-typeck.c:7040
 #, gcc-internal-format
 msgid "passing argument %d of %qE makes integer from pointer without a cast"
 msgstr "le passage de l'argument %d de %qE transforme un pointeur en entier sans transtypage"
 
-#: c/c-typeck.c:7041
+#: c/c-typeck.c:7046
 #, gcc-internal-format
 msgid "assignment to %qT from %qT makes integer from pointer without a cast"
 msgstr "l'affectation à %qT depuis %qT transforme un pointeur en entier sans transtypage"
 
-#: c/c-typeck.c:7046
+#: c/c-typeck.c:7051
 #, gcc-internal-format
 msgid "initialization of %qT from %qT makes integer from pointer without a cast"
 msgstr "l'initialisation de %qT depuis %qT transforme un pointeur en entier sans transtypage"
 
-#: c/c-typeck.c:7050
+#: c/c-typeck.c:7055
 #, gcc-internal-format
 msgid "returning %qT from a function with return type %qT makes integer from pointer without a cast"
 msgstr "retourner %qT depuis une fonction qui retourne le type %qT transforme un pointeur en entier sans transtypage"
 
-#: c/c-typeck.c:7073
+#: c/c-typeck.c:7078
 #, gcc-internal-format
 msgid "incompatible type for argument %d of %qE"
 msgstr "type incompatible pour l'argument %d de %qE"
 
-#: c/c-typeck.c:7078
+#: c/c-typeck.c:7083
 #, gcc-internal-format
 msgid "incompatible types when assigning to type %qT from type %qT"
 msgstr "types incompatibles dans l'affectation au type %qT depuis le type %qT"
 
-#: c/c-typeck.c:7083
+#: c/c-typeck.c:7088
 #, gcc-internal-format
 msgid "incompatible types when initializing type %qT using type %qT"
 msgstr "types incompatibles dans l'initialisation du type %qT en utilisant le type %qT"
 
-#: c/c-typeck.c:7088
+#: c/c-typeck.c:7093
 #, gcc-internal-format
 msgid "incompatible types when returning type %qT but %qT was expected"
 msgstr "types incompatibles en retournant le type %qT alors que %qT était attendu"
 
-#: c/c-typeck.c:7152
+#: c/c-typeck.c:7157
 #, gcc-internal-format
 msgid "traditional C rejects automatic aggregate initialization"
 msgstr "le C traditionnel rejette l'initialisation automatique d'agrégats"
 
-#: c/c-typeck.c:7388 c/c-typeck.c:8284 cp/typeck2.c:1045
+#: c/c-typeck.c:7393 c/c-typeck.c:8289 cp/typeck2.c:1045
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "initialisation d'un membre de tableau flexible"
 
-#: c/c-typeck.c:7398 cp/typeck2.c:1059
+#: c/c-typeck.c:7403 cp/typeck2.c:1059
 #, gcc-internal-format
 msgid "char-array initialized from wide string"
 msgstr "tableau de caractères initialisé à l'aide d'une chaîne de caractères larges"
 
-#: c/c-typeck.c:7407
+#: c/c-typeck.c:7412
 #, gcc-internal-format
 msgid "wide character array initialized from non-wide string"
 msgstr "tableau de caractères larges initialisé depuis un chaîne non large"
 
-#: c/c-typeck.c:7413
+#: c/c-typeck.c:7418
 #, gcc-internal-format
 msgid "wide character array initialized from incompatible wide string"
 msgstr "tableau de caractères larges initialisé depuis une chaîne large incompatible"
 
-#: c/c-typeck.c:7446
+#: c/c-typeck.c:7451
 #, gcc-internal-format
 msgid "array of inappropriate type initialized from string constant"
 msgstr "tableau d'un type inapproprié initialisé avec une chaîne constante"
 
-#: c/c-typeck.c:7533 c/c-typeck.c:7557 c/c-typeck.c:7560 c/c-typeck.c:7568
-#: c/c-typeck.c:7608 c/c-typeck.c:9131 c/c-typeck.c:9181
+#: c/c-typeck.c:7538 c/c-typeck.c:7562 c/c-typeck.c:7565 c/c-typeck.c:7573
+#: c/c-typeck.c:7613 c/c-typeck.c:9136 c/c-typeck.c:9186
 #, gcc-internal-format
 msgid "initializer element is not constant"
 msgstr "un élément de l'initialisation n'est pas une constante"
 
-#: c/c-typeck.c:7542
+#: c/c-typeck.c:7547
 #, gcc-internal-format
 msgid "array initialized from non-constant array expression"
 msgstr "tableau initialisé à l'aide d'une expression de tableau non constante"
 
-#: c/c-typeck.c:7573 c/c-typeck.c:7621 c/c-typeck.c:9191
+#: c/c-typeck.c:7578 c/c-typeck.c:7626 c/c-typeck.c:9196
 #, gcc-internal-format
 msgid "initializer element is not a constant expression"
 msgstr "un élément de l'initialisation n'est pas une expression constante"
 
-#: c/c-typeck.c:7615 c/c-typeck.c:9186
+#: c/c-typeck.c:7620 c/c-typeck.c:9191
 #, gcc-internal-format
 msgid "initializer element is not computable at load time"
 msgstr "un élément de l'initialisation n'est pas évaluable lors du chargement"
 
-#: c/c-typeck.c:7634
+#: c/c-typeck.c:7639
 #, gcc-internal-format
 msgid "invalid initializer"
 msgstr "initialisation invalide"
 
-#: c/c-typeck.c:7912 cp/decl.c:6396
+#: c/c-typeck.c:7917 cp/decl.c:6396
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "type de vecteur opaque ne peut être initialisé"
 
-#: c/c-typeck.c:8132
+#: c/c-typeck.c:8137
 #, gcc-internal-format
 msgid "extra brace group at end of initializer"
 msgstr "groupe d'accolades superflu à la fin de l'initialisation"
 
-#: c/c-typeck.c:8215
+#: c/c-typeck.c:8220
 #, gcc-internal-format
 msgid "braces around scalar initializer"
 msgstr "accolades autour d'une initialisation d'un scalaire"
 
-#: c/c-typeck.c:8281 c/c-typeck.c:9615 cp/typeck2.c:1084 cp/typeck2.c:1297
+#: c/c-typeck.c:8286 c/c-typeck.c:9620 cp/typeck2.c:1084 cp/typeck2.c:1297
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "initialisation d'un membre de tableau flexible dans un contexte imbriqué"
 
-#: c/c-typeck.c:8318
+#: c/c-typeck.c:8323
 #, gcc-internal-format
 msgid "missing braces around initializer"
 msgstr "accolades manquantes autour de l'initialisation"
 
-#: c/c-typeck.c:8341
+#: c/c-typeck.c:8346
 #, gcc-internal-format
 msgid "missing initializer for field %qD of %qT"
 msgstr "initialisation manquante pour le champ %qD de %qT"
 
-#: c/c-typeck.c:8365
+#: c/c-typeck.c:8370
 #, gcc-internal-format
 msgid "empty scalar initializer"
 msgstr "initialisation vide d'un scalaire"
 
-#: c/c-typeck.c:8370
+#: c/c-typeck.c:8375
 #, gcc-internal-format
 msgid "extra elements in scalar initializer"
 msgstr "éléments superflus dans l'initialisation d'un scalaire"
 
-#: c/c-typeck.c:8483 c/c-typeck.c:8565
+#: c/c-typeck.c:8488 c/c-typeck.c:8570
 #, gcc-internal-format
 msgid "array index in non-array initializer"
 msgstr "index de tableau dans l'initialisation de quelque chose n'étant pas un tableau"
 
-#: c/c-typeck.c:8488 c/c-typeck.c:8627
+#: c/c-typeck.c:8493 c/c-typeck.c:8632
 #, gcc-internal-format
 msgid "field name not in record or union initializer"
 msgstr "le nom du champ n'est pas dans l'initialisation de l'enregistrement ou de l'union"
 
-#: c/c-typeck.c:8538
+#: c/c-typeck.c:8543
 #, gcc-internal-format
 msgid "array index in initializer not of integer type"
 msgstr "l'index de tableau dans l'initialisation n'est pas un entier"
 
-#: c/c-typeck.c:8547 c/c-typeck.c:8556
+#: c/c-typeck.c:8552 c/c-typeck.c:8561
 #, gcc-internal-format
 msgid "array index in initializer is not an integer constant expression"
 msgstr "l'index de tableau dans l'initialisation n'est pas une expression entière constante"
 
-#: c/c-typeck.c:8561 c/c-typeck.c:8563
+#: c/c-typeck.c:8566 c/c-typeck.c:8568
 #, gcc-internal-format
 msgid "nonconstant array index in initializer"
 msgstr "index de tableau non constant dans l'initialisation"
 
-#: c/c-typeck.c:8567 c/c-typeck.c:8570
+#: c/c-typeck.c:8572 c/c-typeck.c:8575
 #, gcc-internal-format
 msgid "array index in initializer exceeds array bounds"
 msgstr "l'index de tableau dépasse les limites du tableau dans l'initialisation"
 
-#: c/c-typeck.c:8589
+#: c/c-typeck.c:8594
 #, gcc-internal-format
 msgid "empty index range in initializer"
 msgstr "plage de l'index vide dans l'initialisation"
 
-#: c/c-typeck.c:8598
+#: c/c-typeck.c:8603
 #, gcc-internal-format
 msgid "array index range in initializer exceeds array bounds"
 msgstr "la plage d'index du tableau excède les limites du tableau dans l'initialisation"
 
-#: c/c-typeck.c:8700 c/c-typeck.c:8730 c/c-typeck.c:9274
+#: c/c-typeck.c:8705 c/c-typeck.c:8735 c/c-typeck.c:9279
 #, gcc-internal-format
 msgid "initialized field with side-effects overwritten"
 msgstr "le champ initialisé a des effets de bord écrasés"
 
-#: c/c-typeck.c:8704 c/c-typeck.c:8734 c/c-typeck.c:9277
+#: c/c-typeck.c:8709 c/c-typeck.c:8739 c/c-typeck.c:9282
 #, gcc-internal-format
 msgid "initialized field overwritten"
 msgstr "le champ initialisé est écrasé"
 
-#: c/c-typeck.c:9208
+#: c/c-typeck.c:9213
 #, gcc-internal-format
 msgid "enum conversion in initialization is invalid in C++"
 msgstr "la conversion en enum durant l'initialisation est invalide en C++"
 
-#: c/c-typeck.c:9496
+#: c/c-typeck.c:9501
 #, gcc-internal-format
 msgid "excess elements in char array initializer"
 msgstr "trop d'éléments dans l'initialisation de tableau de caractères"
 
-#: c/c-typeck.c:9503 c/c-typeck.c:9574
+#: c/c-typeck.c:9508 c/c-typeck.c:9579
 #, gcc-internal-format
 msgid "excess elements in struct initializer"
 msgstr "trop d'éléments dans l'initialisation de la structure"
 
-#: c/c-typeck.c:9518
+#: c/c-typeck.c:9523
 #, gcc-internal-format
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr "initialisation par position de champs dans une %<struct%> qui est déclarée avec l'attribut %<designated_init%>"
 
-#: c/c-typeck.c:9589
+#: c/c-typeck.c:9594
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr "initialisation non statique d'un membre de tableau flexible"
 
-#: c/c-typeck.c:9687
+#: c/c-typeck.c:9692
 #, gcc-internal-format
 msgid "excess elements in union initializer"
 msgstr "trop d'éléments dans l'initialisation de l'union"
 
-#: c/c-typeck.c:9709
+#: c/c-typeck.c:9714
 #, gcc-internal-format
 msgid "traditional C rejects initialization of unions"
 msgstr "le C traditionnel rejette l'initialisation des unions"
 
-#: c/c-typeck.c:9777
+#: c/c-typeck.c:9782
 #, gcc-internal-format
 msgid "excess elements in array initializer"
 msgstr "trop d'éléments dans l'initialisation du tableau"
 
-#: c/c-typeck.c:9811
+#: c/c-typeck.c:9816
 #, gcc-internal-format
 msgid "excess elements in vector initializer"
 msgstr "trop d'éléments dans l'initialisation du vecteur"
 
-#: c/c-typeck.c:9843
+#: c/c-typeck.c:9848
 #, gcc-internal-format
 msgid "excess elements in scalar initializer"
 msgstr "trop d'éléments dans l'initialisation d'un scalaire"
 
-#: c/c-typeck.c:10086
+#: c/c-typeck.c:10091
 #, gcc-internal-format
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "le C ISO interdit %<goto *expr;%>"
 
-#: c/c-typeck.c:10113 c/gimple-parser.c:1604 cp/typeck.c:9113
+#: c/c-typeck.c:10118 c/gimple-parser.c:1604 cp/typeck.c:9113
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "la fonction est déclarée avec %<noreturn%> mais elle utilise l'instruction %<return%>"
 
-#: c/c-typeck.c:10139 c/c-typeck.c:10143
+#: c/c-typeck.c:10144 c/c-typeck.c:10148
 #, gcc-internal-format
 msgid "%<return%> with no value, in function returning non-void"
 msgstr "%<return%> sans valeur dans une fonction retournant autre chose que void"
 
-#: c/c-typeck.c:10157 c/gimple-parser.c:1614
+#: c/c-typeck.c:10162 c/gimple-parser.c:1614
 #, gcc-internal-format
 msgid "%<return%> with a value, in function returning void"
 msgstr "%<return%> avec une valeur dans une fonction retournant un void"
 
-#: c/c-typeck.c:10160
+#: c/c-typeck.c:10165
 #, gcc-internal-format
 msgid "ISO C forbids %<return%> with expression, in function returning void"
 msgstr "le C ISO interdit %<return%> avec une expression dans une fonction qui retourne un void"
 
-#: c/c-typeck.c:10236
+#: c/c-typeck.c:10241
 #, gcc-internal-format
 msgid "function returns address of label"
 msgstr "la fonction retourne l'adresse d'une étiquette"
 
-#: c/c-typeck.c:10327 cp/semantics.c:1171
+#: c/c-typeck.c:10332 cp/semantics.c:1171
 #, gcc-internal-format
 msgid "switch quantity not an integer"
 msgstr "la quantité du switch n'est pas un entier"
 
-#: c/c-typeck.c:10352
+#: c/c-typeck.c:10357
 #, gcc-internal-format
 msgid "%<long%> switch expression not converted to %<int%> in ISO C"
 msgstr "l'expression %<long%> du « switch » n'est pas convertie en %<int%> avec le C ISO"
 
-#: c/c-typeck.c:10390 c/c-typeck.c:10398
+#: c/c-typeck.c:10395 c/c-typeck.c:10403
 #, gcc-internal-format
 msgid "case label is not an integer constant expression"
 msgstr "l'étiquette du « case » doit être une expression constante entière"
 
-#: c/c-typeck.c:10404 cp/parser.c:11067
+#: c/c-typeck.c:10409 cp/parser.c:11067
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "étiquette « case » en dehors de tout « switch »"
 
-#: c/c-typeck.c:10406
+#: c/c-typeck.c:10411
 #, gcc-internal-format
 msgid "%<default%> label not within a switch statement"
 msgstr "étiquette %<default%> en dehors de tout « switch »"
 
-#: c/c-typeck.c:10578 cp/parser.c:12356
+#: c/c-typeck.c:10583 cp/parser.c:12353
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "mot-clé « break » à l'extérieur de toute boucle ou « switch »"
 
-#: c/c-typeck.c:10580 cp/parser.c:12379
+#: c/c-typeck.c:10585 cp/parser.c:12376
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "mot-clé « continue » à l'extérieur de toute boucle"
 
-#: c/c-typeck.c:10585 cp/parser.c:12369
+#: c/c-typeck.c:10590 cp/parser.c:12366
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr "mot-clé « break » utilisé dans une boucle OpenMP"
 
-#: c/c-typeck.c:10590
+#: c/c-typeck.c:10595
 #, gcc-internal-format
 msgid "break statement within %<#pragma simd%> loop body"
 msgstr "mot-clé « break » à l'intérieur du corps d'une boucle %<#pragma simd%>"
 
-#: c/c-typeck.c:10592
+#: c/c-typeck.c:10597
 #, gcc-internal-format
 msgid "continue statement within %<#pragma simd%> loop body"
 msgstr "mot-clé « continue » à l'intérieur du corps d'une boucle %<#pragma simd%>"
 
-#: c/c-typeck.c:10618 cp/cp-gimplify.c:432
+#: c/c-typeck.c:10623 cp/cp-gimplify.c:432
 #, gcc-internal-format
 msgid "statement with no effect"
 msgstr "déclaration sans effet"
 
-#: c/c-typeck.c:10662
+#: c/c-typeck.c:10667
 #, gcc-internal-format
 msgid "expression statement has incomplete type"
 msgstr "l'instruction de l'expression a un type incomplet"
 
-#: c/c-typeck.c:11476 c/c-typeck.c:11644 cp/typeck.c:5017
+#: c/c-typeck.c:11481 c/c-typeck.c:11649 cp/typeck.c:5017
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr "comparaison de vecteurs avec des types d'éléments différents"
 
-#: c/c-typeck.c:11484 c/c-typeck.c:11652 cp/typeck.c:5030
+#: c/c-typeck.c:11489 c/c-typeck.c:11657 cp/typeck.c:5030
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr "comparaison de vecteurs avec des nombres d'éléments différents"
 
-#: c/c-typeck.c:11509 c/c-typeck.c:11677 cp/typeck.c:5058
+#: c/c-typeck.c:11514 c/c-typeck.c:11682 cp/typeck.c:5058
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr "n'a pu trouver un type entier de la même taille que %qT"
 
-#: c/c-typeck.c:11523 cp/typeck.c:4743
+#: c/c-typeck.c:11528 cp/typeck.c:4743
 #, gcc-internal-format
 msgid "comparing floating point with == or != is unsafe"
 msgstr "comparer des nombres flottants à l'aide de == ou != n'est pas sûr"
 
-#: c/c-typeck.c:11541 c/c-typeck.c:11562
+#: c/c-typeck.c:11546 c/c-typeck.c:11567
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<false%> for the address of %qD will never be NULL"
 msgstr "la comparaison sera toujours %<false%> car l'adresse de %qD ne sera jamais NULL"
 
-#: c/c-typeck.c:11547 c/c-typeck.c:11568
+#: c/c-typeck.c:11552 c/c-typeck.c:11573
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<true%> for the address of %qD will never be NULL"
 msgstr "la comparaison sera toujours %<true%> car l'adresse de %qD ne sera jamais NULL"
 
-#: c/c-typeck.c:11589 c/c-typeck.c:11718
+#: c/c-typeck.c:11594 c/c-typeck.c:11723
 #, gcc-internal-format
 msgid "comparison of pointers to disjoint address spaces"
 msgstr "comparaison de pointeurs vers des espaces d'adresses disjoints"
 
-#: c/c-typeck.c:11596 c/c-typeck.c:11602
+#: c/c-typeck.c:11601 c/c-typeck.c:11607
 #, gcc-internal-format
 msgid "ISO C forbids comparison of %<void *%> with function pointer"
 msgstr "le C ISO interdit la comparaison de %<void *%> avec un pointeur de fonction"
 
-#: c/c-typeck.c:11609 c/c-typeck.c:11728
+#: c/c-typeck.c:11614 c/c-typeck.c:11733
 #, gcc-internal-format
 msgid "comparison of distinct pointer types lacks a cast"
 msgstr "il manque un transtypage pour comparer des types de pointeurs distincts"
 
-#: c/c-typeck.c:11621 c/c-typeck.c:11626 c/c-typeck.c:11754 c/c-typeck.c:11759
+#: c/c-typeck.c:11626 c/c-typeck.c:11631 c/c-typeck.c:11759 c/c-typeck.c:11764
 #, gcc-internal-format
 msgid "comparison between pointer and integer"
 msgstr "comparaison entre un pointeur et un entier"
 
-#: c/c-typeck.c:11706
+#: c/c-typeck.c:11711
 #, gcc-internal-format
 msgid "comparison of complete and incomplete pointers"
 msgstr "comparaison de pointeurs complet et incomplet"
 
-#: c/c-typeck.c:11708
+#: c/c-typeck.c:11713
 #, gcc-internal-format
 msgid "ISO C forbids ordered comparisons of pointers to functions"
 msgstr "le C ISO interdit les comparaisons ordonnées de pointeurs vers des fonctions"
 
-#: c/c-typeck.c:11713
+#: c/c-typeck.c:11718
 #, gcc-internal-format
 msgid "ordered comparison of pointer with null pointer"
 msgstr "comparaison ordonnée d'un pointeur avec un pointeur nul"
 
-#: c/c-typeck.c:11736 c/c-typeck.c:11739 c/c-typeck.c:11746 c/c-typeck.c:11749
+#: c/c-typeck.c:11741 c/c-typeck.c:11744 c/c-typeck.c:11751 c/c-typeck.c:11754
 #: cp/typeck.c:5081 cp/typeck.c:5088
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "comparaison ordonnée d'un pointeur avec un zéro entier"
 
-#: c/c-typeck.c:11811
+#: c/c-typeck.c:11816
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
 msgstr "conversion implicite de %qT vers %qT pour correspondre à d'autres opérandes de l'expression binaire"
 
-#: c/c-typeck.c:12126
+#: c/c-typeck.c:12131
 #, gcc-internal-format
 msgid "used array that cannot be converted to pointer where scalar is required"
 msgstr "le tableau utilisé ne peut pas être converti en pointeur là où un scalaire est requis"
 
-#: c/c-typeck.c:12130
+#: c/c-typeck.c:12135
 #, gcc-internal-format
 msgid "used struct type value where scalar is required"
 msgstr "valeur de type « struct » utilisée là où un scalaire est requis"
 
-#: c/c-typeck.c:12134
+#: c/c-typeck.c:12139
 #, gcc-internal-format
 msgid "used union type value where scalar is required"
 msgstr "valeur de type « union » utilisée là où un scalaire est requis"
 
-#: c/c-typeck.c:12150
+#: c/c-typeck.c:12155
 #, gcc-internal-format
 msgid "used vector type where scalar is required"
 msgstr "valeur de type « vector » utilisée là où un scalaire est requis"
 
-#: c/c-typeck.c:12340 cp/semantics.c:8508
+#: c/c-typeck.c:12345 cp/semantics.c:8511
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp cancel%> doit spécifier l'une des clauses %<parallel%>, %<for%>, %<sections%> ou %<taskgroup%>"
 
-#: c/c-typeck.c:12379 cp/semantics.c:8545
+#: c/c-typeck.c:12384 cp/semantics.c:8548
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp cancellation point%> doit spécifier l'une des clauses %<parallel%>, %<for%>, %<sections%> ou %<taskgroup%>"
 
-#: c/c-typeck.c:12423 c/c-typeck.c:13581 c/c-typeck.c:13642 c/c-typeck.c:13704
+#: c/c-typeck.c:12428 c/c-typeck.c:13586 c/c-typeck.c:13647 c/c-typeck.c:13709
 #, gcc-internal-format
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "%<_Atomic%> %qE dans la clause %qs"
 
-#: c/c-typeck.c:12436 c/c-typeck.c:13628 cp/semantics.c:4546
-#: cp/semantics.c:6717
+#: c/c-typeck.c:12441 c/c-typeck.c:13633 cp/semantics.c:4549
+#: cp/semantics.c:6720
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr "champ de bits %qE dans la clause %qs"
 
-#: c/c-typeck.c:12445 c/c-typeck.c:13652 cp/semantics.c:4556
-#: cp/semantics.c:6735
+#: c/c-typeck.c:12450 c/c-typeck.c:13657 cp/semantics.c:4559
+#: cp/semantics.c:6738
 #, gcc-internal-format
 msgid "%qE is a member of a union"
 msgstr "%qE est un membre d'une union"
 
-#: c/c-typeck.c:12455 cp/semantics.c:4570 cp/semantics.c:6760
+#: c/c-typeck.c:12460 cp/semantics.c:4573 cp/semantics.c:6763
 #, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD n'est pas une variable dans la clause %qs"
 
-#: c/c-typeck.c:12459 c/c-typeck.c:13669 cp/semantics.c:4574
-#: cp/semantics.c:6763
+#: c/c-typeck.c:12464 c/c-typeck.c:13674 cp/semantics.c:4577
+#: cp/semantics.c:6766
 #, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qE n'est pas une variable dans la clause %qs"
 
-#: c/c-typeck.c:12466
+#: c/c-typeck.c:12471
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %qs clause"
 msgstr "%<_Atomic%> %qD dans la clause %qs"
 
-#: c/c-typeck.c:12475 c/c-typeck.c:13676 c/c-typeck.c:13778
-#: cp/semantics.c:4591 cp/semantics.c:6769 cp/semantics.c:6931
+#: c/c-typeck.c:12480 c/c-typeck.c:13681 c/c-typeck.c:13783
+#: cp/semantics.c:4594 cp/semantics.c:6772 cp/semantics.c:6934
 #, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD est une variable « threadprivate » dans la clause %qs"
 
-#: c/c-typeck.c:12511 cp/semantics.c:4623
+#: c/c-typeck.c:12516 cp/semantics.c:4626
 #, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr "la borne inférieure %qE de la section du tableau n'a pas un type entier"
 
-#: c/c-typeck.c:12518 cp/semantics.c:4630
+#: c/c-typeck.c:12523 cp/semantics.c:4633
 #, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr "la longueur %qE de la section du tableau n'a pas un type entier"
 
-#: c/c-typeck.c:12545 c/c-typeck.c:12609 c/c-typeck.c:12867
-#: cp/semantics.c:4666 cp/semantics.c:4730
+#: c/c-typeck.c:12550 c/c-typeck.c:12614 c/c-typeck.c:12872
+#: cp/semantics.c:4669 cp/semantics.c:4733
 #, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr "section de tableau ayant une longueur nulle dans la clause %qs"
 
-#: c/c-typeck.c:12564 cp/semantics.c:4685
+#: c/c-typeck.c:12569 cp/semantics.c:4688
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr "l'expression de longueur doit être spécifiée pour un type tableau dont la limite est inconnue"
 
-#: c/c-typeck.c:12572 cp/semantics.c:4693
+#: c/c-typeck.c:12577 cp/semantics.c:4696
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr "limite inférieure négative dans la section du tableau dans la clause %qs"
 
-#: c/c-typeck.c:12581 c/c-typeck.c:12691 cp/semantics.c:4702
-#: cp/semantics.c:4812
+#: c/c-typeck.c:12586 c/c-typeck.c:12696 cp/semantics.c:4705
+#: cp/semantics.c:4815
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr "longueur négative dans la section du tableau dans la clause %qs"
 
-#: c/c-typeck.c:12598 cp/semantics.c:4719
+#: c/c-typeck.c:12603 cp/semantics.c:4722
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr "limite inférieure %qE au delà de la taille de la section du tableau dans la clause %qs"
 
-#: c/c-typeck.c:12635 cp/semantics.c:4756
+#: c/c-typeck.c:12640 cp/semantics.c:4759
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr "longueur %qE au delà de la taille de la section du tableau dans la clause %qs"
 
-#: c/c-typeck.c:12650 cp/semantics.c:4771
+#: c/c-typeck.c:12655 cp/semantics.c:4774
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr "limite supérieure %qE au delà de la taille de la section du tableau dans la clause %qs"
 
-#: c/c-typeck.c:12683 cp/semantics.c:4804
+#: c/c-typeck.c:12688 cp/semantics.c:4807
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr "l'expression de longueur doit être spécifiée pour un type pointeur"
 
-#: c/c-typeck.c:12701 c/c-typeck.c:12810 cp/semantics.c:4822
-#: cp/semantics.c:4934
+#: c/c-typeck.c:12706 c/c-typeck.c:12815 cp/semantics.c:4825
+#: cp/semantics.c:4937
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr "la section du tableau n'est pas contigüe dans la clause %qs"
 
-#: c/c-typeck.c:12709 cp/semantics.c:4830
+#: c/c-typeck.c:12714 cp/semantics.c:4833
 #, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr "%qE n'a pas un type pointeur ou tableau"
 
-#: c/c-typeck.c:13103 c/c-typeck.c:13113
+#: c/c-typeck.c:13108 c/c-typeck.c:13118
 #, gcc-internal-format
 msgid "%qD in %<reduction%> clause is a zero size array"
 msgstr "%qD dans la clause %<reduction%> est un tableau de taille nulle"
 
-#: c/c-typeck.c:13130
+#: c/c-typeck.c:13135
 #, gcc-internal-format
 msgid "%<_Atomic%> %qE in %<reduction%> clause"
 msgstr "%<_Atomic%> %qE dans la clause %<reduction%>"
 
-#: c/c-typeck.c:13178
+#: c/c-typeck.c:13183
 #, gcc-internal-format
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "%qE a un type invalide pour %<reduction(%s)%>"
 
-#: c/c-typeck.c:13187 cp/semantics.c:5755
+#: c/c-typeck.c:13192 cp/semantics.c:5758
 #, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr "réduction définie par l'utilisateur pas trouvée pour %qE"
 
-#: c/c-typeck.c:13275
+#: c/c-typeck.c:13280
 #, gcc-internal-format
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "type d'élément de longueur variable dans la table de la clause %<reduction%>"
 
-#: c/c-typeck.c:13293 c/c-typeck.c:13836 cp/semantics.c:7249
+#: c/c-typeck.c:13298 c/c-typeck.c:13841 cp/semantics.c:7252
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr "la clause %<nowait%> ne doit pas être utilisée avec %<copyprivate%>"
 
-#: c/c-typeck.c:13305 cp/semantics.c:7289
+#: c/c-typeck.c:13310 cp/semantics.c:7292
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE doit être %<threadprivate%> pour %<copyin%>"
 
-#: c/c-typeck.c:13319 cp/semantics.c:5929
+#: c/c-typeck.c:13324 cp/semantics.c:5932
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr "le modificateur ne devrait pas être spécifié dans la clause %<linear%> sur des constructions %<simd%> ou %<for%>"
 
-#: c/c-typeck.c:13327
+#: c/c-typeck.c:13332
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with type %qT"
 msgstr "clause linéaire appliquée à une variable non entière non pointeur de type %qT"
 
-#: c/c-typeck.c:13335
+#: c/c-typeck.c:13340
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr "%<_Atomic%> %qD dans la clause %<linear%>"
 
-#: c/c-typeck.c:13354 cp/semantics.c:5999
+#: c/c-typeck.c:13359 cp/semantics.c:6002
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr "le pas %qE de la clause %<linear%> n'est ni une constante ni un paramètre"
 
-#: c/c-typeck.c:13384 c/c-typeck.c:13771 cp/semantics.c:6083
-#: cp/semantics.c:6924
+#: c/c-typeck.c:13389 c/c-typeck.c:13776 cp/semantics.c:6086
+#: cp/semantics.c:6927
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE n'est pas une variable dans la clause %qs"
 
-#: c/c-typeck.c:13393 cp/semantics.c:6092
+#: c/c-typeck.c:13398 cp/semantics.c:6095
 #, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr "%qD apparaît plus d'une fois dans les clauses de réduction"
 
-#: c/c-typeck.c:13404 c/c-typeck.c:13434 c/c-typeck.c:13463
+#: c/c-typeck.c:13409 c/c-typeck.c:13439 c/c-typeck.c:13468
 #, gcc-internal-format
 msgid "%qE appears more than once in data clauses"
 msgstr "%qE apparaît plus d'une fois dans les clauses de données"
 
-#: c/c-typeck.c:13411 c/c-typeck.c:13440 c/c-typeck.c:13600 c/c-typeck.c:13714
-#: c/c-typeck.c:13720 c/c-typeck.c:13733 c/c-typeck.c:13742
-#: cp/semantics.c:6102 cp/semantics.c:6109 cp/semantics.c:6160
-#: cp/semantics.c:6166 cp/semantics.c:6203 cp/semantics.c:6680
-#: cp/semantics.c:6817 cp/semantics.c:6823 cp/semantics.c:6836
-#: cp/semantics.c:6845
+#: c/c-typeck.c:13416 c/c-typeck.c:13445 c/c-typeck.c:13605 c/c-typeck.c:13719
+#: c/c-typeck.c:13725 c/c-typeck.c:13738 c/c-typeck.c:13747
+#: cp/semantics.c:6105 cp/semantics.c:6112 cp/semantics.c:6163
+#: cp/semantics.c:6169 cp/semantics.c:6206 cp/semantics.c:6683
+#: cp/semantics.c:6820 cp/semantics.c:6826 cp/semantics.c:6839
+#: cp/semantics.c:6848
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr "%qD apparaît plus d'une fois dans les clauses de données"
 
-#: c/c-typeck.c:13413 c/c-typeck.c:13442 c/c-typeck.c:13722 c/c-typeck.c:13744
-#: cp/semantics.c:6111 cp/semantics.c:6168 cp/semantics.c:6825
-#: cp/semantics.c:6847
+#: c/c-typeck.c:13418 c/c-typeck.c:13447 c/c-typeck.c:13727 c/c-typeck.c:13749
+#: cp/semantics.c:6114 cp/semantics.c:6171 cp/semantics.c:6828
+#: cp/semantics.c:6850
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr "%qD apparaît à la fois dans les clauses « data » et « map »"
 
-#: c/c-typeck.c:13427 cp/semantics.c:6154
+#: c/c-typeck.c:13432 cp/semantics.c:6157
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "%qE n'est pas une variable dans la clause %<firstprivate%>"
 
-#: c/c-typeck.c:13456 cp/semantics.c:6197
+#: c/c-typeck.c:13461 cp/semantics.c:6200
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "%qE n'est pas une variable dans la clause %<lastprivate%>"
 
-#: c/c-typeck.c:13475 cp/semantics.c:6545
+#: c/c-typeck.c:13480 cp/semantics.c:6548
 #, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "%qE n'est pas une variable dans la clause %<aligned%>"
 
-#: c/c-typeck.c:13482
+#: c/c-typeck.c:13487
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array"
 msgstr "%qE dans la clause %<aligned%> n'est ni un pointeur ni un tableau"
 
-#: c/c-typeck.c:13489
+#: c/c-typeck.c:13494
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<aligned%> clause"
 msgstr "%<_Atomic%> %qD dans la clause %<aligned%>"
 
-#: c/c-typeck.c:13496
+#: c/c-typeck.c:13501
 #, gcc-internal-format
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr "%qE apparaît plus d'une fois dans les clause %<aligned%>"
 
-#: c/c-typeck.c:13551 cp/semantics.c:6627
+#: c/c-typeck.c:13556 cp/semantics.c:6630
 #, gcc-internal-format
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr "%qE n'est pas une variable dans la clause %<depend%>"
 
-#: c/c-typeck.c:13573 cp/semantics.c:6658
+#: c/c-typeck.c:13578 cp/semantics.c:6661
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr "la section du tableau n'a pas un type pour lequel une correspondance peut être établie (mappable type) dans la clause %qs"
 
-#: c/c-typeck.c:13597 c/c-typeck.c:13731 cp/semantics.c:6677
-#: cp/semantics.c:6834
+#: c/c-typeck.c:13602 c/c-typeck.c:13736 cp/semantics.c:6680
+#: cp/semantics.c:6837
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD apparaît plus d'une fois dans les clauses de mouvement"
 
-#: c/c-typeck.c:13603 c/c-typeck.c:13735 cp/semantics.c:6683
-#: cp/semantics.c:6838
+#: c/c-typeck.c:13608 c/c-typeck.c:13740 cp/semantics.c:6686
+#: cp/semantics.c:6841
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD apparaît plus d'une fois dans les clauses %<map%>"
 
-#: c/c-typeck.c:13635 cp/semantics.c:6724
+#: c/c-typeck.c:13640 cp/semantics.c:6727
 #, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qE n'a pas un type pour lequel une correspondance peut être établie (mappable type) dans la clause %qs"
 
-#: c/c-typeck.c:13695 c/c-typeck.c:13785 cp/semantics.c:6799
-#: cp/semantics.c:6938
+#: c/c-typeck.c:13700 c/c-typeck.c:13790 cp/semantics.c:6802
+#: cp/semantics.c:6941
 #, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD n'a pas un type pour lequel la correspondance peut être établie (mappable type) dans la clause %qs"
 
-#: c/c-typeck.c:13766 cp/semantics.c:6918
+#: c/c-typeck.c:13771 cp/semantics.c:6921
 #, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE n'est ni une variable ni un nom de fonction dans la clause %qs"
 
-#: c/c-typeck.c:13794 cp/semantics.c:6947
+#: c/c-typeck.c:13799 cp/semantics.c:6950
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qE apparaît plus d'une fois dans la même directive %<declare target%>"
 
-#: c/c-typeck.c:13808 cp/semantics.c:6962
+#: c/c-typeck.c:13813 cp/semantics.c:6965
 #, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD n'est pas un argument dans la clause %<uniform%>"
 
-#: c/c-typeck.c:13811 cp/semantics.c:6964
+#: c/c-typeck.c:13816 cp/semantics.c:6967
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qE n'est pas un argument dans la clause %<uniform%>"
 
-#: c/c-typeck.c:13826
+#: c/c-typeck.c:13831
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "la variable %qs n'est ni un pointeur ni un tableau"
 
-#: c/c-typeck.c:13900 cp/semantics.c:6359
+#: c/c-typeck.c:13905 cp/semantics.c:6362
 #, gcc-internal-format
 msgid "%<nonmonotonic%> modifier specified for %qs schedule kind"
 msgstr "modificateur %<nonmonotonic%> spécifié pour le type d'ordonnancement %qs"
 
-#: c/c-typeck.c:13931 cp/semantics.c:7141
+#: c/c-typeck.c:13936 cp/semantics.c:7144
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr "la clause %<inbranch%> est incompatible avec %<notinbranch%>"
 
 # le premier %qs est un mot non traduit tel que « private », « shared » ou « threadprivate ».
-#: c/c-typeck.c:13981 cp/semantics.c:7332
+#: c/c-typeck.c:13986 cp/semantics.c:7335
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE est prédéterminé %qs pour %qs"
 
-#: c/c-typeck.c:14001 cp/semantics.c:7223
+#: c/c-typeck.c:14006 cp/semantics.c:7226
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr "la valeur de la clause %<simdlen%> est plus grande que la valeur de la clause %<safelen%>"
 
-#: c/c-typeck.c:14013 cp/semantics.c:7236
+#: c/c-typeck.c:14018 cp/semantics.c:7239
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr "modificateur d'ordonnancement %<nonmonotonic%> spécifié en même temps que la clause %<ordered%>"
 
-#: c/c-typeck.c:14031 cp/semantics.c:7203
+#: c/c-typeck.c:14036 cp/semantics.c:7206
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr "le pas de la clause %<linear%> est un paramètre %qD pas spécifié dans la clause %<uniform%>"
 
-#: c/c-typeck.c:14204
+#: c/c-typeck.c:14209
 #, gcc-internal-format
 msgid "cannot use %<va_arg%> with reverse storage order"
 msgstr "impossible d'utiliser %<va_arg%> avec un ordre de stockage inversé"
 
-#: c/c-typeck.c:14209
+#: c/c-typeck.c:14214
 #, gcc-internal-format
 msgid "second argument to %<va_arg%> is of incomplete type %qT"
 msgstr "le deuxième argument de %<va_arg%> est du type incompatible %qT"
 
-#: c/c-typeck.c:14215
+#: c/c-typeck.c:14220
 #, gcc-internal-format
 msgid "C++ requires promoted type, not enum type, in %<va_arg%>"
 msgstr "le C++ exige un type promu, pas un type enum, dans %<va_arg%>"
@@ -38045,7 +38093,7 @@
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "  pas de conversion connue pour convertir l'argument %d depuis %qH vers %qI"
 
-#: cp/call.c:3441 cp/pt.c:6495
+#: cp/call.c:3441 cp/pt.c:6509
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -38335,7 +38383,7 @@
 msgid "%q#D is private within this context"
 msgstr "%q#D est privé dans ce contexte"
 
-#: cp/call.c:6478 cp/decl.c:7343
+#: cp/call.c:6478 cp/decl.c:7364
 #, gcc-internal-format
 msgid "declared private here"
 msgstr "déclaré privé ici"
@@ -38345,7 +38393,7 @@
 msgid "%q#D is protected within this context"
 msgstr "%q#D est protégé dans ce contexte"
 
-#: cp/call.c:6486 cp/decl.c:7344
+#: cp/call.c:6486 cp/decl.c:7365
 #, gcc-internal-format
 msgid "declared protected here"
 msgstr "déclaré protégé ici"
@@ -38644,7 +38692,7 @@
 msgid "call to non-function %qD"
 msgstr "appel à la non fonction %qD"
 
-#: cp/call.c:9119 cp/pt.c:15053 cp/typeck.c:2901
+#: cp/call.c:9119 cp/pt.c:15075 cp/typeck.c:2901
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "ne peut appeler le constructeur %<%T::%D%> directement"
@@ -38853,262 +38901,262 @@
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr "impossible de dériver de la classe de base %<final%> %qT dans le type dérivé %qT"
 
-#: cp/class.c:2098
+#: cp/class.c:2103
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr "toutes les fonctions membre de la classe %qT sont privées"
 
-#: cp/class.c:2110
+#: cp/class.c:2115
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr "%q#T définit uniquement un destructeur privé et n'a pas d'amis"
 
-#: cp/class.c:2152
+#: cp/class.c:2156
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr "%q#T définit uniquement des constructeurs privés et n'a pas d'amis"
 
-#: cp/class.c:2156
+#: cp/class.c:2160
 #, gcc-internal-format
 msgid "%q#D is public, but requires an existing %q#T object"
 msgstr "%q#D est public mais requiert un objet %q#T existant"
 
-#: cp/class.c:2430
+#: cp/class.c:2434
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr "pas de surcharge finale unique pour %qD dans %qT"
 
-#: cp/class.c:2785
+#: cp/class.c:2789
 #, gcc-internal-format
 msgid "%qD can be marked override"
 msgstr "%qD peut être marqué « override »"
 
-#: cp/class.c:2797
+#: cp/class.c:2801
 #, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr "%q+#D est marqué %<final%> mais il n'est pas virtuel"
 
-#: cp/class.c:2799
+#: cp/class.c:2803
 #, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr "%q+#D est marqué %<override%> mais il ne surcharge rien"
 
-#: cp/class.c:2861
+#: cp/class.c:2865
 #, gcc-internal-format
 msgid "%qD was hidden"
 msgstr "%qD était caché"
 
-#: cp/class.c:2863
+#: cp/class.c:2867
 #, gcc-internal-format
 msgid "  by %qD"
 msgstr "  par %qD"
 
-#: cp/class.c:2896
+#: cp/class.c:2900
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "%q#D est invalide; une union anonyme ne peut avoir que des membres de données publiques non statiques"
 
-#: cp/class.c:2906 cp/name-lookup.c:3293 cp/parser.c:19720
+#: cp/class.c:2910 cp/name-lookup.c:3293 cp/parser.c:19717
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr "cette flexibilité est dépréciée et sera supprimée"
 
-#: cp/class.c:3097
+#: cp/class.c:3101
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr "l'élision dans %qD n'est pas héritée"
 
-#: cp/class.c:3213
+#: cp/class.c:3217
 #, gcc-internal-format
 msgid "bit-field %q+#D with non-integral type"
 msgstr "champ de bits %q+#D avec un type non entier"
 
-#: cp/class.c:3229
+#: cp/class.c:3233
 #, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr "la largeur du champ de bits %q+D n'est pas une constante entière"
 
-#: cp/class.c:3234
+#: cp/class.c:3238
 #, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr "largeur négative dans le champ de bits %q+D"
 
-#: cp/class.c:3239
+#: cp/class.c:3243
 #, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr "largeur nulle pour le champ de bits %q+D"
 
-#: cp/class.c:3249
+#: cp/class.c:3253
 #, gcc-internal-format
 msgid "width of %qD exceeds its type"
 msgstr "la largeur de %qD dépasse celle de son type"
 
-#: cp/class.c:3255
+#: cp/class.c:3259
 #, gcc-internal-format
 msgid "%qD is too small to hold all values of %q#T"
 msgstr "%qD est trop petit pour contenir toutes les valeurs de %q#T"
 
-#: cp/class.c:3316
+#: cp/class.c:3320
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr "le membre %q+#D avec un constructeur n'est pas permis dans l'union"
 
-#: cp/class.c:3319
+#: cp/class.c:3323
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr "le membre %q+#D avec destructeur n'est pas permis dans l'union"
 
-#: cp/class.c:3321
+#: cp/class.c:3325
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr "le membre %q#D avec un opérateur d’affectation par copie n'est pas permis dans l'union"
 
-#: cp/class.c:3325
+#: cp/class.c:3329
 #, gcc-internal-format
 msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgstr "les unions sans restrictions sont disponibles avec -std=c++11 ou -std=gnu++11"
 
-#: cp/class.c:3453
+#: cp/class.c:3457
 #, gcc-internal-format
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr "en C++98, %q+D ne peut pas être statique parce qu'il est un membre d'une union"
 
-#: cp/class.c:3460
+#: cp/class.c:3464
 #, gcc-internal-format
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr "le membre de donnée non statique %q+D dans une union ne peut pas avoir le type référencé %qT"
 
-#: cp/class.c:3470
+#: cp/class.c:3474
 #, gcc-internal-format
 msgid "field %q+D invalidly declared function type"
 msgstr "le champ %q+D est incorrectement déclaré avec le type d'une fonction"
 
-#: cp/class.c:3476
+#: cp/class.c:3480
 #, gcc-internal-format
 msgid "field %q+D invalidly declared method type"
 msgstr "le champ %q+D est incorrectement déclaré avec le type d'une méthode"
 
-#: cp/class.c:3536
+#: cp/class.c:3540
 #, gcc-internal-format
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr "attribut « packed » ignoré à cause du champ non POD non empaqueté %q#D"
 
-#: cp/class.c:3585
+#: cp/class.c:3589
 #, gcc-internal-format
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr "le membre %q+D ne peut pas être déclaré à la fois %<const%> et %<mutable%>"
 
-#: cp/class.c:3591
+#: cp/class.c:3595
 #, gcc-internal-format
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr "le membre %q+D ne peut pas être déclaré comme une référence %<mutable%>"
 
-#: cp/class.c:3617
+#: cp/class.c:3621
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr "champs multiples initialisés dans l'union %qT"
 
-#: cp/class.c:3658
+#: cp/class.c:3662
 #, gcc-internal-format
 msgid "field %q#D with same name as class"
 msgstr "champ %q#D avec le même nom que la classe"
 
-#: cp/class.c:3681
+#: cp/class.c:3685
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr "%q#T a des membres de données qui sont des pointeurs"
 
-#: cp/class.c:3686
+#: cp/class.c:3690
 #, gcc-internal-format
 msgid "  but does not override %<%T(const %T&)%>"
 msgstr "  mais il ne surcharge pas %<%T(const %T&)%>"
 
-#: cp/class.c:3688
+#: cp/class.c:3692
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr "  ou %<operator=(const %T&)%>"
 
-#: cp/class.c:3692
+#: cp/class.c:3696
 #, gcc-internal-format
 msgid "  but does not override %<operator=(const %T&)%>"
 msgstr "  mais il ne surcharge pas %<operator=(const %T&)%>"
 
-#: cp/class.c:4097
+#: cp/class.c:4101
 #, gcc-internal-format
 msgid "alignment of %qD increased in -fabi-version=9 (GCC 5.2)"
 msgstr "l'alignement de %qD a augmenté avec -fabi-version=9 (GCC 5.2)"
 
-#: cp/class.c:4100
+#: cp/class.c:4104
 #, gcc-internal-format
 msgid "alignment of %qD will increase in -fabi-version=9"
 msgstr "l'alignement de %qD augmentera avec -fabi-version=9"
 
-#: cp/class.c:4378
+#: cp/class.c:4382
 #, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "initialisation spécifiée pour une méthode non virtuelle %q+D"
 
-#: cp/class.c:4813
+#: cp/class.c:4817
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr "la méthode surcharge à la fois les méthodes %<transaction_pure%> et %qE"
 
-#: cp/class.c:4834
+#: cp/class.c:4838
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr "la méthode déclarée %qE surcharge la méthode %qE"
 
-#: cp/class.c:5350 cp/constexpr.c:237
+#: cp/class.c:5367 cp/constexpr.c:237
 #, gcc-internal-format
 msgid "enclosing class of %<constexpr%> non-static member function %q+#D is not a literal type"
 msgstr "la classe englobant la fonction membre non statique %<constexpr%> %q+#D n'est pas un type littéral"
 
-#: cp/class.c:5374
+#: cp/class.c:5391
 #, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr "%q+T n'est pas littéral à cause de:"
 
-#: cp/class.c:5377
+#: cp/class.c:5394
 #, gcc-internal-format
 msgid "  %qT is a closure type, which is only literal in C++17 and later"
 msgstr "  %qT est un type de fermeture qui n'est un littéral qu'à partir du C++17"
 
-#: cp/class.c:5380
+#: cp/class.c:5397
 #, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr "  %q+T a un destructeur non trivial"
 
-#: cp/class.c:5387
+#: cp/class.c:5404
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no %<constexpr%> constructor that is not a copy or move constructor"
 msgstr "  %q+T n'est pas un agrégat, n'a pas de constructeur par défaut trivial et n'a pas de constructeur %<constexpr%> qui n'est pas un constructeur de copie ou par déplacement"
 
-#: cp/class.c:5420
+#: cp/class.c:5437
 #, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "  la classe de base %qT de %q+T n'est pas littérale"
 
-#: cp/class.c:5435
+#: cp/class.c:5452
 #, gcc-internal-format
 msgid "  non-static data member %qD has non-literal type"
 msgstr "  le membre de donnée non statique %qD a un type non littéral"
 
-#: cp/class.c:5442
+#: cp/class.c:5459
 #, gcc-internal-format
 msgid "  non-static data member %qD has volatile type"
 msgstr "  le membre de donnée non statique %qD a un type volatile"
 
-#: cp/class.c:5561
+#: cp/class.c:5578
 #, gcc-internal-format
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "la classe de base %q#T a un destructeur non virtuel accessible"
 
-#: cp/class.c:5590
+#: cp/class.c:5607
 #, gcc-internal-format
 msgid "non-static reference %q#D in class without a constructor"
 msgstr "la référence non statique %q#D dans la classe sans un constructeur"
 
-#: cp/class.c:5596
+#: cp/class.c:5613
 #, gcc-internal-format
 msgid "non-static const member %q#D in class without a constructor"
 msgstr "le membre constant non statique %q#D dans la classe sans un constructeur"
@@ -39115,153 +39163,153 @@
 
 #. If the function is defaulted outside the class, we just
 #. give the synthesis error.
-#: cp/class.c:5624
+#: cp/class.c:5641
 #, gcc-internal-format
 msgid "%q+D declared to take const reference, but implicit declaration would take non-const"
 msgstr "%q+D est déclaré pour prendre une référence const mais la déclaration implicite prendrait un non-const"
 
-#: cp/class.c:5898
+#: cp/class.c:5915
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr "la base directe %qT est inaccessible dans %qT en raison de l'ambiguïté"
 
-#: cp/class.c:5910
+#: cp/class.c:5927
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr "la base virtuelle %qT est inaccessible dans %qT en raison de l'ambiguïté"
 
-#: cp/class.c:6133
+#: cp/class.c:6150
 #, gcc-internal-format
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr "le décalage relatif de %qD n'est pas compatible avec l'ABI et peut changer dans une version future de GCC"
 
-#: cp/class.c:6291
+#: cp/class.c:6308
 #, gcc-internal-format
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr "la taille du type %qT est trop grande (%qE octets)"
 
-#: cp/class.c:6576
+#: cp/class.c:6593
 #, gcc-internal-format
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr "utilisation invalide de %q#T avec un tableau de taille nulle dans %q#D"
 
-#: cp/class.c:6578
+#: cp/class.c:6595
 #, gcc-internal-format
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr "utilisation invalide de %q#T avec un membre sous forme de tableau flexible dans %q#T"
 
-#: cp/class.c:6583
+#: cp/class.c:6600
 #, gcc-internal-format
 msgid "array member %q#D declared here"
 msgstr "membre tableau %q#D déclaré ici"
 
-#: cp/class.c:6610
+#: cp/class.c:6627
 #, gcc-internal-format
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr "membre tableau de taille nulle %qD pas à la fin de %q#T"
 
-#: cp/class.c:6612
+#: cp/class.c:6629
 #, gcc-internal-format
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr "membre tableau de taille nulle %qD dans un %q#T par ailleurs vide"
 
-#: cp/class.c:6620 cp/class.c:6650
+#: cp/class.c:6637 cp/class.c:6667
 #, gcc-internal-format
 msgid "in the definition of %q#T"
 msgstr "dans la définition de %q#T"
 
-#: cp/class.c:6628
+#: cp/class.c:6645
 #, gcc-internal-format
 msgid "flexible array member %qD not at end of %q#T"
 msgstr "le membre tableau flexible %qD n'est pas à la fin de %q#T"
 
-#: cp/class.c:6630
+#: cp/class.c:6647
 #, gcc-internal-format
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr "membre tableau flexible %qD dans %q#T par ailleurs vide"
 
-#: cp/class.c:6648
+#: cp/class.c:6665
 #, gcc-internal-format
 msgid "next member %q#D declared here"
 msgstr "membre %q#D suivant déclaré ici"
 
-#: cp/class.c:6760 cp/parser.c:23239
+#: cp/class.c:6777 cp/parser.c:23236
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "redéfinition de %q#T"
 
-#: cp/class.c:6897
+#: cp/class.c:6914
 #, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "%q#T a des fonctions virtuelles et un destructeur non virtuel accessible"
 
-#: cp/class.c:6925
+#: cp/class.c:6942
 #, gcc-internal-format
 msgid "type transparent %q#T does not have any fields"
 msgstr "le type transparent %q#T n'a aucun champ"
 
 # un type transparent est un type qui est passé comme le type qu'elle manipule, par ex decimal32
-#: cp/class.c:6931
+#: cp/class.c:6948
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr "la classe de type transparent %qT a des classes de base"
 
-#: cp/class.c:6935
+#: cp/class.c:6952
 #, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr "la classe de type transparent %qT a des fonctions virtuelles"
 
-#: cp/class.c:6941
+#: cp/class.c:6958
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr "le type transparent %q#T ne peut être rendu transparent car le type du premier champ a une ABI différente de la classe générale"
 
-#: cp/class.c:7071
+#: cp/class.c:7088
 #, gcc-internal-format
 msgid "definition of %qD does not match %<#include <initializer_list>%>"
 msgstr "la définition de %qD ne correspond pas à %<#include <initializer_list>%>"
 
-#: cp/class.c:7082
+#: cp/class.c:7099
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr "la tentative de terminer la struct a été stoppée nette en raison des erreurs précédentes dans l'analyse syntaxique"
 
-#: cp/class.c:7582
+#: cp/class.c:7599
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "la chaîne de langage %<\"%E\"%> n'est pas reconnue"
 
-#: cp/class.c:7672
+#: cp/class.c:7689
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr "ne peut résoudre la fonction surchargée %qD basé sur la conversion vers le type %qT"
 
-#: cp/class.c:7817
+#: cp/class.c:7834
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr "pas de correspondance pour convertir la fonction %qD vers le type %q#T"
 
-#: cp/class.c:7844
+#: cp/class.c:7861
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "la conversion de la fonction surchargée %qD vers le type %q#T est ambiguë"
 
-#: cp/class.c:7870
+#: cp/class.c:7887
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "on suppose un pointeur vers le membre %qD"
 
-#: cp/class.c:7873
+#: cp/class.c:7890
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(un pointeur vers un membre peut seulement être formé avec %<&%E%>)"
 
-#: cp/class.c:7948 cp/class.c:7990
+#: cp/class.c:7965 cp/class.c:8007
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "pas assez d'informations sur le type"
 
-#: cp/class.c:7968
+#: cp/class.c:7985
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "impossible de convertir %qE du type %qT vers le type %qT"
@@ -39271,13 +39319,13 @@
 #. A name N used in a class S shall refer to the same declaration
 #. in its context and when re-evaluated in the completed scope of
 #. S.
-#: cp/class.c:8235
+#: cp/class.c:8252
 #, gcc-internal-format
 msgid "declaration of %q#D"
 msgstr "la déclaration de %q#D"
 
 # ce message suit directement le précédent
-#: cp/class.c:8237
+#: cp/class.c:8254
 #, gcc-internal-format
 msgid "changes meaning of %qD from %q#D"
 msgstr "change la signification de %qD depuis %q#D"
@@ -39668,17 +39716,17 @@
 msgid "unexpected AST of kind %s"
 msgstr "arbre syntaxique abstrait (AST=Abstract Syntax Tree) de type %s inattendu"
 
-#: cp/cp-gimplify.c:1415
+#: cp/cp-gimplify.c:1416
 #, gcc-internal-format
 msgid "throw will always call terminate()"
 msgstr "throw appellera toujours terminate()"
 
-#: cp/cp-gimplify.c:1418
+#: cp/cp-gimplify.c:1419
 #, gcc-internal-format
 msgid "in C++11 destructors default to noexcept"
 msgstr "en C++11, les destructeurs sont noexcept par défaut"
 
-#: cp/cp-gimplify.c:1429
+#: cp/cp-gimplify.c:1430
 #, gcc-internal-format
 msgid "in C++11 this throw will terminate because destructors default to noexcept"
 msgstr "en C++11, ce throw sera terminal car les destructeurs sont noexcept par défaut"
@@ -40082,7 +40130,7 @@
 msgid "redeclaration %qD differs in %<constexpr%> from previous declaration"
 msgstr "la redéclaration de %qD diffère de la déclaration précédente sur le %<constexpr%>"
 
-#: cp/decl.c:1304 cp/decl.c:13843
+#: cp/decl.c:1304 cp/decl.c:13867
 #, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr "déclaration précédente de %qD"
@@ -40406,7 +40454,7 @@
 msgid "  enters OpenMP structured block"
 msgstr "  entre dans le bloc structuré OpenMP"
 
-#: cp/decl.c:3434 cp/parser.c:12366 cp/parser.c:12387
+#: cp/decl.c:3434 cp/parser.c:12363 cp/parser.c:12384
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr "sortie invalide du bloc structuré OpenMP"
@@ -40416,7 +40464,7 @@
 msgid "%qD is not a type"
 msgstr "%qD n'est pas un type"
 
-#: cp/decl.c:3838 cp/parser.c:6366
+#: cp/decl.c:3838 cp/parser.c:6369
 #, gcc-internal-format
 msgid "%qD used without template parameters"
 msgstr "%qD utilisé sans paramètres du patron"
@@ -40793,8 +40841,8 @@
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr "le champ désigné par l'indicateur C99 %qE est hors de l'initialisation de l'agrégat"
 
-#: cp/decl.c:6011 cp/decl.c:6234 cp/typeck2.c:1310 cp/typeck2.c:1590
-#: cp/typeck2.c:1638 cp/typeck2.c:1685
+#: cp/decl.c:6011 cp/decl.c:6234 cp/typeck2.c:1310 cp/typeck2.c:1593
+#: cp/typeck2.c:1641 cp/typeck2.c:1688
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "trop d'éléments d'initialisation pour %qT"
@@ -40869,12 +40917,12 @@
 msgid "assignment (not initialization) in declaration"
 msgstr "affectation (pas une initialisation) dans la déclaration"
 
-#: cp/decl.c:6873 cp/decl.c:12605
+#: cp/decl.c:6873 cp/decl.c:12629
 #, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "le C++17 ISO n'autorise pas le spécificateur de classe de stockage %<register%>"
 
-#: cp/decl.c:6877 cp/decl.c:12609
+#: cp/decl.c:6877 cp/decl.c:12633
 #, gcc-internal-format
 msgid "%<register%> storage class specifier used"
 msgstr "spécificateur de classe de stockage %<register%> utilisé"
@@ -40899,42 +40947,42 @@
 msgid "function %q#D is initialized like a variable"
 msgstr "la fonction %q#D est initialisée comme une variable"
 
-#: cp/decl.c:7329
+#: cp/decl.c:7350
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "impossible de décomposer le type de la classe %qT car il a une structure anonyme comme membre"
 
-#: cp/decl.c:7332
+#: cp/decl.c:7353
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr "impossible de décomposer le type de la classe %qT car il a une union anonyme comme membre"
 
-#: cp/decl.c:7339
+#: cp/decl.c:7360
 #, gcc-internal-format
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "impossible de décomposer le membre inaccessible %qD de %qT"
 
-#: cp/decl.c:7365
+#: cp/decl.c:7386
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr "impossible de décomposer le type de classe %qT: lui et sa classe de base %qT ont des membres de données non statiques"
 
-#: cp/decl.c:7374
+#: cp/decl.c:7395
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr "impossible de décomposer le type de classe %qT: ses classes de base %qT et %qT ont des membres de données non statiques"
 
-#: cp/decl.c:7592
+#: cp/decl.c:7613
 #, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr "la liaison structurée fait référence au type incomplet %qT"
 
-#: cp/decl.c:7608
+#: cp/decl.c:7629
 #, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr "impossible de décomposer le tableau de longueur variable %qT"
 
-#: cp/decl.c:7617 cp/decl.c:7702
+#: cp/decl.c:7638 cp/decl.c:7723
 #, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
@@ -40941,7 +40989,7 @@
 msgstr[0] "%u nom fourni pour la liaison structurée"
 msgstr[1] "%u noms fournis pour la liaison structurée"
 
-#: cp/decl.c:7621
+#: cp/decl.c:7642
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
@@ -40948,7 +40996,7 @@
 msgstr[0] "seulement %u nom fourni pour la liaison structurée"
 msgstr[1] "seulement %u noms fournis pour la liaison structurée"
 
-#: cp/decl.c:7624
+#: cp/decl.c:7645
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
@@ -40955,878 +41003,878 @@
 msgstr[0] "alors que %qT se décompose en %wu élément"
 msgstr[1] "alors que %qT se décompose en %wu éléments"
 
-#: cp/decl.c:7669
+#: cp/decl.c:7690
 #, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr "impossible de décomposer le vecteur de longueur variable %qT"
 
-#: cp/decl.c:7695
+#: cp/decl.c:7716
 #, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "%<std::tuple_size<%T>::value%> n'est pas une expression constante entière"
 
-#: cp/decl.c:7704
+#: cp/decl.c:7725
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr "alors que %qT se décompose en %E éléments"
 
-#: cp/decl.c:7725
+#: cp/decl.c:7746
 #, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr "dans l'initialisation de la variable de liaison structurée %qD"
 
-#: cp/decl.c:7751
+#: cp/decl.c:7772
 #, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr "impossible de décomposer le type union %qT"
 
-#: cp/decl.c:7756
+#: cp/decl.c:7777
 #, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "impossible de décomposer le type %qT qui n'est ni une classe ni un tableau"
 
-#: cp/decl.c:7761
+#: cp/decl.c:7782
 #, gcc-internal-format
 msgid "cannot decompose lambda closure type %qT"
 msgstr "impossible de décomposer le type de fermeture lambda %qT"
 
-#: cp/decl.c:7765
+#: cp/decl.c:7786
 #, gcc-internal-format
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "la liaison structurée fait référence au type de classe incomplet %qT"
 
-#: cp/decl.c:7774
+#: cp/decl.c:7795
 #, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "impossible de décomposer le type de classe %qT sans membre de donnée non statique"
 
-#: cp/decl.c:8213
+#: cp/decl.c:8234
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr "la variable non locale %qD déclarée %<__thread%> a besoin d'une initialisation dynamique"
 
-#: cp/decl.c:8216
+#: cp/decl.c:8237
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr "la variable non locale %qD déclarée %<__thread%> a un destructeur non trivial"
 
-#: cp/decl.c:8222
+#: cp/decl.c:8243
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr "%<thread_local%> en C++11 permet l'initialisation et la destruction dynamique"
 
-#: cp/decl.c:8450
+#: cp/decl.c:8471
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "l'initialisation n'a pu déterminer la taille de %qT"
 
-#: cp/decl.c:8454
+#: cp/decl.c:8475
 #, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "taille du tableau manquante dans %qT"
 
-#: cp/decl.c:8457
+#: cp/decl.c:8478
 #, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "tableau %qT de taille zéro"
 
-#: cp/decl.c:8473
+#: cp/decl.c:8494
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "le destructeur pour la classe étrangère %qT ne peut pas être un membre"
 
-#: cp/decl.c:8475
+#: cp/decl.c:8496
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "le constructeur pour la classe étrangère %qT ne peut pas être un membre"
 
-#: cp/decl.c:8499
+#: cp/decl.c:8520
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD est déclaré comme une variable %<virtual%>"
 
-#: cp/decl.c:8501
+#: cp/decl.c:8522
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "les spécificateurs de fonction %<const%> et %<volatile%> sur %qD sont invalides dans la déclaration de variable"
 
-#: cp/decl.c:8506
+#: cp/decl.c:8527
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD déclaré comme un paramètre %<virtual%>"
 
-#: cp/decl.c:8508
+#: cp/decl.c:8529
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD déclaré comme un paramètre %<inline%>"
 
-#: cp/decl.c:8510
+#: cp/decl.c:8531
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "les spécificateurs de fonction %<const%> et %<volatile%> sur %qD sont invalides dans la déclaration de paramètre"
 
-#: cp/decl.c:8515
+#: cp/decl.c:8536
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD déclaré comme un type %<virtual%>"
 
-#: cp/decl.c:8517
+#: cp/decl.c:8538
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD déclaré comme un type %<inline%>"
 
-#: cp/decl.c:8519
+#: cp/decl.c:8540
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "les spécificateurs de fonction %<const%> et %<volatile%> sur %qD sont invalides dans la déclaration de type"
 
-#: cp/decl.c:8524
+#: cp/decl.c:8545
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD déclaré comme un champ %<virtual%>"
 
-#: cp/decl.c:8526
+#: cp/decl.c:8547
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD déclaré comme un champ %<inline%>"
 
-#: cp/decl.c:8528
+#: cp/decl.c:8549
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "les spécificateurs de fonction %<const%> et %<volatile%> sur %qD sont invalides dans la déclaration de champ"
 
-#: cp/decl.c:8535
+#: cp/decl.c:8556
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D déclaré comme un ami"
 
-#: cp/decl.c:8542
+#: cp/decl.c:8563
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D déclaré avec une spécification d'exception"
 
-#: cp/decl.c:8574
+#: cp/decl.c:8595
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "la définition de %qD n'est pas dans l'espace de noms incluant %qT"
 
-#: cp/decl.c:8614
+#: cp/decl.c:8635
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "la fonction membre statique %q#D est déclarée avec des qualificatifs de type"
 
-#: cp/decl.c:8624
+#: cp/decl.c:8645
 #, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr "le concept %q#D est déclaré avec des paramètres de fonction"
 
-#: cp/decl.c:8630
+#: cp/decl.c:8651
 #, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr "le concept %q#D est déclaré avec un type de retour déduit"
 
-#: cp/decl.c:8632
+#: cp/decl.c:8653
 #, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "le concept %q#D a le type de retour %qT qui n'est pas %<bool%>"
 
-#: cp/decl.c:8703
+#: cp/decl.c:8724
 #, gcc-internal-format
 msgid "concept %qD has no definition"
 msgstr "le concept %qD n'a pas de définition"
 
-#: cp/decl.c:8772
+#: cp/decl.c:8793
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "définition de la spécialisation explicite %qD dans la déclaration amie"
 
 #. Something like `template <class T> friend void f<T>()'.
-#: cp/decl.c:8782
+#: cp/decl.c:8803
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "utilisation invalide du template-id %qD dans la déclaration du patron primaire"
 
-#: cp/decl.c:8800
+#: cp/decl.c:8821
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "les arguments par défaut ne sont pas permis dans la déclaration de la spécialisation du patron ami %qD"
 
-#: cp/decl.c:8808
+#: cp/decl.c:8829
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "%<inline%> n'est pas permis dans la déclaration de la spécialisation du patron ami %qD"
 
-#: cp/decl.c:8857
+#: cp/decl.c:8878
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "ne peut déclarer %<::main%> comme étant un patron"
 
-#: cp/decl.c:8859
+#: cp/decl.c:8880
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "ne peut déclarer %<::main%> comme étant à mettre en ligne"
 
-#: cp/decl.c:8861
+#: cp/decl.c:8882
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be %<constexpr%>"
 msgstr "ne peut déclarer %<::main%> comme étant %<constexpr%>"
 
-#: cp/decl.c:8863
+#: cp/decl.c:8884
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "ne peut déclarer %<::main%> comme étant static"
 
-#: cp/decl.c:8920
+#: cp/decl.c:8941
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "la fonction membre statique %qD ne peut pas avoir de qualificatif CV"
 
-#: cp/decl.c:8921
+#: cp/decl.c:8942
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "la fonction non membre %qD ne peut pas avoir de qualificatif CV"
 
-#: cp/decl.c:8929
+#: cp/decl.c:8950
 #, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "la fonction membre statique %qD ne peut pas avoir de qualificatif de référence"
 
-#: cp/decl.c:8930
+#: cp/decl.c:8951
 #, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "la fonction non membre %qD ne peut pas avoir de qualificatif de référence"
 
-#: cp/decl.c:8940
+#: cp/decl.c:8961
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared at namespace scope"
 msgstr "le guide de déduction %qD doit être déclaré au niveau de l'espace de noms"
 
-#: cp/decl.c:8946
+#: cp/decl.c:8967
 #, gcc-internal-format
 msgid "deduction guide %qD must not have a function body"
 msgstr "le guide de déduction %qD ne peut pas avoir un corps de fonction"
 
-#: cp/decl.c:8959
+#: cp/decl.c:8980
 #, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr "opérateur littéral avec une classe de liaison C"
 
-#: cp/decl.c:8969
+#: cp/decl.c:8990
 #, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "%qD a une liste d'arguments invalide"
 
-#: cp/decl.c:8977
+#: cp/decl.c:8998
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr "le suffixe entier %qs est masqué par l'implémentation"
 
-#: cp/decl.c:8983
+#: cp/decl.c:9004
 #, gcc-internal-format
 msgid "floating point suffix %qs shadowed by implementation"
 msgstr "le suffixe en virgule flottante %qs est masqué par l'implémentation"
 
-#: cp/decl.c:8991
+#: cp/decl.c:9012
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr "les suffixes d'opérateurs littéraux qui ne sont pas précédés par %<_%> sont réservés pour une standardisation future"
 
-#: cp/decl.c:8996
+#: cp/decl.c:9017
 #, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "%qD doit être une fonction non membre"
 
-#: cp/decl.c:9076
+#: cp/decl.c:9097
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> doit retourner %<int%>"
 
-#: cp/decl.c:9116
+#: cp/decl.c:9137
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "définition de %qD déclaré implicitement"
 
-#: cp/decl.c:9121
+#: cp/decl.c:9142
 #, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "définition de %qD explicitement par défaut"
 
-#: cp/decl.c:9123
+#: cp/decl.c:9144
 #, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr "%q#D explicitement par défaut ici"
 
-#: cp/decl.c:9140
+#: cp/decl.c:9161
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "pas de fonction membre %q#D déclarée dans la classe %qT"
 
-#: cp/decl.c:9329
+#: cp/decl.c:9350
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "ne peut déclarer %<::main%> comme variable globale"
 
-#: cp/decl.c:9337
+#: cp/decl.c:9358
 #, gcc-internal-format
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "une variable qui n'est pas un patron ne peut pas avoir %<concept%>"
 
-#: cp/decl.c:9344
+#: cp/decl.c:9365
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr "un concept doit avoir le type %<bool%>"
 
-#: cp/decl.c:9464
+#: cp/decl.c:9485
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "initialisation intra-classe du membre de donnée statique %q#D d'un type incomplet"
 
-#: cp/decl.c:9468
+#: cp/decl.c:9489
 #, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "%<constexpr%> est requis pour l'initialisation intra-classe du membre de donnée statique %q#D d'un type non entier"
 
-#: cp/decl.c:9472
+#: cp/decl.c:9493
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "initialisation intra-classe du membre de donnée statique %q#D du type non littéral"
 
-#: cp/decl.c:9486
+#: cp/decl.c:9507
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "initialisation intra-classe invalide du membre de donnée statique du type non entier %qT"
 
-#: cp/decl.c:9493
+#: cp/decl.c:9514
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "le C++ ISO interdit l'initialisation intra-classe du membre statique non constant %qD"
 
-#: cp/decl.c:9498
+#: cp/decl.c:9519
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "le C++ ISO interdit l'initialisation du membre constant %qD du type non entier %qT"
 
-#: cp/decl.c:9598
+#: cp/decl.c:9619
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "la taille du tableau %qD a le type non entier %qT"
 
-#: cp/decl.c:9600
+#: cp/decl.c:9621
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "la taille du tableau a le type non entier %qT"
 
-#: cp/decl.c:9630 cp/decl.c:9680
+#: cp/decl.c:9651 cp/decl.c:9701
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "la taille du tableau n'est pas une expression constante entière"
 
-#: cp/decl.c:9646
+#: cp/decl.c:9667
 #, gcc-internal-format
 msgid "size of array %qD is negative"
 msgstr "la taille du tableau %qD est négative"
 
-#: cp/decl.c:9648 cp/init.c:3651
+#: cp/decl.c:9669 cp/init.c:3667
 #, gcc-internal-format
 msgid "size of array is negative"
 msgstr "la taille du tableau est négative"
 
-#: cp/decl.c:9662
+#: cp/decl.c:9683
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "le C++ ISO interdit le tableau de taille zéro %qD"
 
-#: cp/decl.c:9664
+#: cp/decl.c:9685
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "le C++ ISO interdit le tableau de taille zéro"
 
-#: cp/decl.c:9677
+#: cp/decl.c:9698
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "la taille du tableau %qD n'est pas une expression constante de type entier"
 
-#: cp/decl.c:9686
+#: cp/decl.c:9707
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "le C++ ISO interdit le tableau de taille variable %qD"
 
-#: cp/decl.c:9688
+#: cp/decl.c:9709
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "le C++ ISO interdit le tableau de taille variable"
 
-#: cp/decl.c:9694
+#: cp/decl.c:9715
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr "le tableau de taille variable %qD est utilisé"
 
-#: cp/decl.c:9697
+#: cp/decl.c:9718
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr "le tableau de taille variable est utilisé"
 
-#: cp/decl.c:9746
+#: cp/decl.c:9767
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "débordement dans la dimension du tableau"
 
-#: cp/decl.c:9799
+#: cp/decl.c:9820
 #, gcc-internal-format
 msgid "%qD declared as array of %qT"
 msgstr "%qD est déclaré comme tableau de %qT"
 
-#: cp/decl.c:9809
+#: cp/decl.c:9830
 #, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "déclaration de %qD comme un tableau de « void »"
 
-#: cp/decl.c:9811
+#: cp/decl.c:9832
 #, gcc-internal-format
 msgid "creating array of void"
 msgstr "création d'un tableau « void »"
 
-#: cp/decl.c:9816
+#: cp/decl.c:9837
 #, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "déclaration de %qD comme un tableau de fonctions"
 
-#: cp/decl.c:9818
+#: cp/decl.c:9839
 #, gcc-internal-format
 msgid "creating array of functions"
 msgstr "création d'un tableau de fonctions"
 
-#: cp/decl.c:9823
+#: cp/decl.c:9844
 #, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "déclaration de %qD comme un tableau de références"
 
-#: cp/decl.c:9825
+#: cp/decl.c:9846
 #, gcc-internal-format
 msgid "creating array of references"
 msgstr "création d'un tableau de références"
 
-#: cp/decl.c:9830
+#: cp/decl.c:9851
 #, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "déclaration de %qD comme un tableau de fonctions membres"
 
-#: cp/decl.c:9832
+#: cp/decl.c:9853
 #, gcc-internal-format
 msgid "creating array of function members"
 msgstr "création d'un tableau de fonctions membres"
 
-#: cp/decl.c:9846
+#: cp/decl.c:9867
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "la déclaration de %qD comme tableau multidimensionnel doit avoir des bornes pour chaque dimension excepté la première"
 
-#: cp/decl.c:9850
+#: cp/decl.c:9871
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "le tableau multidimensionnel doit avoir des bornes pour chaque dimension excepté la première"
 
-#: cp/decl.c:9909
+#: cp/decl.c:9930
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "la spécification d'un type retourné pour un constructeur est invalide"
 
-#: cp/decl.c:9912
+#: cp/decl.c:9933
 #, gcc-internal-format
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "les qualificatifs ne sont pas permis dans la déclaration d'un constructeur"
 
-#: cp/decl.c:9922
+#: cp/decl.c:9943
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "la spécification d'un type retourné pour un destructeur est invalide"
 
-#: cp/decl.c:9925
+#: cp/decl.c:9946
 #, gcc-internal-format
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "les qualificatifs ne sont pas permis dans la déclaration d'un destructeur"
 
-#: cp/decl.c:9937
+#: cp/decl.c:9958
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "type de retour spécifié pour %<operator %T%>"
 
-#: cp/decl.c:9940
+#: cp/decl.c:9961
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "les qualificatifs ne sont pas permis dans la déclaration de %<operator %T%>"
 
-#: cp/decl.c:9948
+#: cp/decl.c:9969
 #, gcc-internal-format
 msgid "return type specified for deduction guide"
 msgstr "type de retour spécifié pour le guide de déduction"
 
-#: cp/decl.c:9951
+#: cp/decl.c:9972
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "les qualificatifs ne sont pas permis dans la déclaration du guide de déduction"
 
-#: cp/decl.c:9955
+#: cp/decl.c:9976
 #, gcc-internal-format
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "paramètre de patron %qT, qui est lui-même un patron, dans la déclaration du guide de déduction"
 
-#: cp/decl.c:9964
+#: cp/decl.c:9985
 #, gcc-internal-format
 msgid "decl-specifier in declaration of deduction guide"
 msgstr "spécificateur de type « decl-specifier » dans la déclaration du guide de déduction"
 
-#: cp/decl.c:9985
+#: cp/decl.c:10006
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "variable non nommée ou champ déclaré void"
 
-#: cp/decl.c:9992
+#: cp/decl.c:10013
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "variable ou champ déclaré void"
 
-#: cp/decl.c:10007
+#: cp/decl.c:10028
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "spécificateur %<inline%> invalide pour la variable %qD déclarée au niveau du bloc"
 
-#: cp/decl.c:10013
+#: cp/decl.c:10034
 #, gcc-internal-format
 msgid "inline variables are only available with -std=c++17 or -std=gnu++17"
 msgstr "les variables « inline » sont uniquement disponibles avec -std=c++17 ou -std=gnu++17"
 
-#: cp/decl.c:10268
+#: cp/decl.c:10292
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "utilisation invalide du nom qualifié %<::%D%>"
 
-#: cp/decl.c:10271 cp/decl.c:10291
+#: cp/decl.c:10295 cp/decl.c:10315
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "utilisation invalide du nom qualifié %<%T::%D%>"
 
-#: cp/decl.c:10274
+#: cp/decl.c:10298
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "utilisation invalide du nom qualifié %<%D::%D%>"
 
-#: cp/decl.c:10283
+#: cp/decl.c:10307
 #, gcc-internal-format
 msgid "%q#T is not a class or a namespace"
 msgstr "%q#T n'est pas une classe ou un espace de noms"
 
-#: cp/decl.c:10305 cp/decl.c:10398 cp/decl.c:10407 cp/decl.c:11970
+#: cp/decl.c:10329 cp/decl.c:10422 cp/decl.c:10431 cp/decl.c:11994
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "déclaration de %qD comme non fonction"
 
-#: cp/decl.c:10311
+#: cp/decl.c:10335
 #, gcc-internal-format
 msgid "declaration of %qD as non-member"
 msgstr "déclaration de %qD comme non membre"
 
-#: cp/decl.c:10339
+#: cp/decl.c:10363
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "declarator-id manquant; utilisation du mot réservé %qD"
 
-#: cp/decl.c:10390
+#: cp/decl.c:10414
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "la définition de fonction ne déclare aucun paramètre"
 
-#: cp/decl.c:10415
+#: cp/decl.c:10439
 #, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "déclaration de %qD comme %<typedef%>"
 
-#: cp/decl.c:10420
+#: cp/decl.c:10444
 #, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "déclaration de %qD comme paramètre"
 
-#: cp/decl.c:10454
+#: cp/decl.c:10478
 #, gcc-internal-format
 msgid "%<concept%> cannot appear in a typedef declaration"
 msgstr "%<concept%> ne peut pas apparaître dans une déclaration typedef"
 
-#: cp/decl.c:10460
+#: cp/decl.c:10484
 #, gcc-internal-format
 msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgstr "%<constexpr%> ne peut pas apparaître dans une déclaration typedef"
 
-#: cp/decl.c:10468
+#: cp/decl.c:10492
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "au moins deux types de données dans la déclaration de %qs"
 
-#: cp/decl.c:10474
+#: cp/decl.c:10498
 #, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr "spécificateurs conflictuels dans la déclaration de %qs"
 
-#: cp/decl.c:10515
+#: cp/decl.c:10539
 #, gcc-internal-format
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "le C++ ISO n'accepte pas qu'un simple %<complex%> signifie %<double complex%>"
 
-#: cp/decl.c:10564 cp/decl.c:10567 cp/decl.c:10570
+#: cp/decl.c:10588 cp/decl.c:10591 cp/decl.c:10594
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "le C++ ISO interdit la déclaration de %qs sans type"
 
-#: cp/decl.c:10586
+#: cp/decl.c:10610
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr "%<__int%d%> n'est pas supporté par la cible"
 
-#: cp/decl.c:10592
+#: cp/decl.c:10616
 #, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "le C++ ISO ne supporte pas %<__int%d%> pour %qs"
 
-#: cp/decl.c:10614 cp/decl.c:10634
+#: cp/decl.c:10638 cp/decl.c:10658
 #, gcc-internal-format
 msgid "%<signed%> or %<unsigned%> invalid for %qs"
 msgstr "%<signed%> ou %<unsigned%> sont invalides pour %qs"
 
-#: cp/decl.c:10616
+#: cp/decl.c:10640
 #, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgstr "%<signed%> et %<unsigned%> spécifiés ensemble pour %qs"
 
-#: cp/decl.c:10618
+#: cp/decl.c:10642
 #, gcc-internal-format
 msgid "%<long long%> invalid for %qs"
 msgstr "%<long long%> invalide pour %qs"
 
-#: cp/decl.c:10620
+#: cp/decl.c:10644
 #, gcc-internal-format
 msgid "%<long%> invalid for %qs"
 msgstr "%<long%> invalide pour %qs"
 
-#: cp/decl.c:10622
+#: cp/decl.c:10646
 #, gcc-internal-format
 msgid "%<short%> invalid for %qs"
 msgstr "%<short%> invalide pour %qs"
 
-#: cp/decl.c:10624
+#: cp/decl.c:10648
 #, gcc-internal-format
 msgid "%<long%> or %<short%> invalid for %qs"
 msgstr "%<long%> ou %<short%> sont invalides pour %qs"
 
-#: cp/decl.c:10626
+#: cp/decl.c:10650
 #, gcc-internal-format
 msgid "%<long%>, %<int%>, %<short%>, or %<char%> invalid for %qs"
 msgstr "%<long%>, %<int%>, %<short%> ou %<char%> sont invalides pour %qs"
 
-#: cp/decl.c:10628
+#: cp/decl.c:10652
 #, gcc-internal-format
 msgid "%<long%> or %<short%> specified with char for %qs"
 msgstr "%<long%> ou %<short%> spécifié avec « char » pour %qs"
 
-#: cp/decl.c:10630
+#: cp/decl.c:10654
 #, gcc-internal-format
 msgid "%<long%> and %<short%> specified together for %qs"
 msgstr "%<long%> et %<short%> spécifiés ensemble pour %qs"
 
-#: cp/decl.c:10636
+#: cp/decl.c:10660
 #, gcc-internal-format
 msgid "%<short%> or %<long%> invalid for %qs"
 msgstr "%<short%> ou %<long%> sont invalides pour %qs"
 
-#: cp/decl.c:10644
+#: cp/decl.c:10668
 #, gcc-internal-format
 msgid "long, short, signed or unsigned used invalidly for %qs"
 msgstr "« long », « short », « signed » ou « unsigned » utilisé incorrectement pour %qs"
 
-#: cp/decl.c:10712
+#: cp/decl.c:10736
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "« complex » invalide pour %qs"
 
-#: cp/decl.c:10751
+#: cp/decl.c:10775
 #, gcc-internal-format
 msgid "template placeholder type %qT must be followed by a simple declarator-id"
 msgstr "l'espace réservé par le type %qT dans le patron doit être suivi d'un simple declarator-id"
 
-#: cp/decl.c:10769
+#: cp/decl.c:10793
 #, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "le membre %qD ne peut pas être déclaré à la fois %<virtual%> et %<static%>"
 
-#: cp/decl.c:10775
+#: cp/decl.c:10799
 #, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<constexpr%>"
 msgstr "le membre %qD ne peut pas être déclaré à la fois %<virtual%> et %<constexpr%>"
 
-#: cp/decl.c:10785
+#: cp/decl.c:10809
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "la déclaration typedef est invalide dans la déclaration du paramètre"
 
-#: cp/decl.c:10790
+#: cp/decl.c:10814
 #, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "classe de stockage spécifiée pour le paramètre %qs du patron"
 
-#: cp/decl.c:10796
+#: cp/decl.c:10820
 #, gcc-internal-format
 msgid "storage class specifiers invalid in parameter declarations"
 msgstr "spécificateurs de classe de stockage invalides dans la déclaration des paramètres"
 
-#: cp/decl.c:10800
+#: cp/decl.c:10824
 #, gcc-internal-format
 msgid "a parameter cannot be declared %<concept%>"
 msgstr "un paramètre ne peut pas être déclaré %<concept%>"
 
-#: cp/decl.c:10805
+#: cp/decl.c:10829
 #, gcc-internal-format
 msgid "a parameter cannot be declared %<constexpr%>"
 msgstr "un paramètre ne peut pas être déclaré %<constexpr%>"
 
-#: cp/decl.c:10815
+#: cp/decl.c:10839
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "%<virtual%> en dehors de la déclaration de classe"
 
-#: cp/decl.c:10825
+#: cp/decl.c:10849
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<inline%>"
 msgstr "une déclaration de liaison structurée ne peut pas être %<inline%>"
 
-#: cp/decl.c:10828
+#: cp/decl.c:10852
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<typedef%>"
 msgstr "une déclaration de liaison structurée ne peut pas être %<typedef%>"
 
-#: cp/decl.c:10830
+#: cp/decl.c:10854
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<constexpr%>"
 msgstr "une déclaration de liaison structurée ne peut pas être %<constexpr%>"
 
-#: cp/decl.c:10834
+#: cp/decl.c:10858
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr "la déclaration d'une liaison structurée ne peut pas être %qs"
 
-#: cp/decl.c:10839
+#: cp/decl.c:10863
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<concept%>"
 msgstr "une déclaration de liaison structurée ne peut pas être %<concept%>"
 
-#: cp/decl.c:10845
+#: cp/decl.c:10869
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<register%>"
 msgstr "une déclaration de liaison structurée ne peut pas être %<register%>"
 
-#: cp/decl.c:10849
+#: cp/decl.c:10873
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<static%>"
 msgstr "une déclaration de liaison structurée ne peut pas être %<static%>"
 
-#: cp/decl.c:10853
+#: cp/decl.c:10877
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<extern%>"
 msgstr "une déclaration de liaison structurée ne peut pas être %<extern%>"
 
-#: cp/decl.c:10857
+#: cp/decl.c:10881
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<mutable%>"
 msgstr "une déclaration de liaison structurée ne peut pas être %<mutable%>"
 
-#: cp/decl.c:10861
+#: cp/decl.c:10885
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr "une déclaration de liaison structurée ne peut pas avoir le %<auto%> du C++98"
 
-#: cp/decl.c:10872
+#: cp/decl.c:10896
 #, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr "une déclaration de liaison structurée ne peut pas avoir le type %qT"
 
-#: cp/decl.c:10875
+#: cp/decl.c:10899
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr "le type doit être un %<auto%> qualifié avec CV ou une référence à un %<auto%> qualifié avec CV"
 
-#: cp/decl.c:10906
+#: cp/decl.c:10930
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "classes de stockage multiples dans la déclaration de %qs"
 
-#: cp/decl.c:10929
+#: cp/decl.c:10953
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "classe de stockage spécifiée pour %qs"
 
-#: cp/decl.c:10933
+#: cp/decl.c:10957
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "classe de stockage spécifiée pour le paramètre %qs"
 
-#: cp/decl.c:10946
+#: cp/decl.c:10970
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "fonction imbriquée %qs déclarée %<extern%>"
 
-#: cp/decl.c:10950
+#: cp/decl.c:10974
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "la déclaration de %qs hors de toute fonction spécifie %<auto%>"
 
-#: cp/decl.c:10957
+#: cp/decl.c:10981
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "%qs dans le champ de la fonction est implicitement déclaré auto et déclaré %<__thread%>"
 
-#: cp/decl.c:10969
+#: cp/decl.c:10993
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "spécificateurs de classe de stockage invalides dans les déclarations de fonctions amies"
 
-#: cp/decl.c:11050
+#: cp/decl.c:11074
 #, gcc-internal-format
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "parenthèses inutiles dans la déclaration de %qs"
 
-#: cp/decl.c:11098
+#: cp/decl.c:11122
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr "clause « requires » sur le type de retour"
 
-#: cp/decl.c:11118
+#: cp/decl.c:11142
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr "la fonction %qs utilise le spécificateur de type %<auto%> sans type de retour à la fin"
 
-#: cp/decl.c:11121
+#: cp/decl.c:11145
 #, gcc-internal-format
 msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgstr "le type de retour déduit est uniquement disponible avec -std=c++14 ou -std=gnu++14"
 
-#: cp/decl.c:11127
+#: cp/decl.c:11151
 #, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr "une fonction virtuelle ne peut pas avoir un type de retour déduit"
 
-#: cp/decl.c:11134
+#: cp/decl.c:11158
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr "la fonction %qs avec un type de retour à la fin a %qT comme étant son type au lieu d'un simple %<auto%>"
 
-#: cp/decl.c:11147
+#: cp/decl.c:11171
 #, gcc-internal-format
 msgid "deduced class type %qD in function return type"
 msgstr "type de classe %qD déduit dans le type de retour de la fonction"
 
-#: cp/decl.c:11156
+#: cp/decl.c:11180
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr "le guide de déduction pour %qT doit avoir un type de retour à la fin"
 
-#: cp/decl.c:11169
+#: cp/decl.c:11193
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr "le type de retour %qT à la fin du guide de déduction n'est pas une spécialisation de %qT"
@@ -41833,459 +41881,459 @@
 
 #. Not using maybe_warn_cpp0x because this should
 #. always be an error.
-#: cp/decl.c:11180
+#: cp/decl.c:11204
 #, gcc-internal-format
 msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgstr "le type de retour à la fin est uniquement disponible avec -std=c++11 ou -std=gnu++11"
 
-#: cp/decl.c:11183
+#: cp/decl.c:11207
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr "la fonction %qs avec le type de retour à la fin n'est pas déclarée avec le spécificateur de type %<auto%>"
 
-#: cp/decl.c:11212
+#: cp/decl.c:11236
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs déclaré comme une fonction retournant une fonction"
 
-#: cp/decl.c:11218
+#: cp/decl.c:11242
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs déclaré comme une fonction retournant un tableau"
 
-#: cp/decl.c:11247
+#: cp/decl.c:11271
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "le destructeur ne peut être une fonction membre statique"
 
-#: cp/decl.c:11248
+#: cp/decl.c:11272
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "le constructeur ne peut être une fonction membre statique"
 
-#: cp/decl.c:11252
+#: cp/decl.c:11276
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "les destructeurs ne peuvent pas être qualifiés avec CV"
 
-#: cp/decl.c:11253
+#: cp/decl.c:11277
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "les constructeurs ne peuvent pas être qualifiés avec CV"
 
-#: cp/decl.c:11261
+#: cp/decl.c:11285
 #, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr "les destructeurs ne peuvent pas être qualifiés comme des références"
 
-#: cp/decl.c:11262
+#: cp/decl.c:11286
 #, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr "les constructeurs ne peuvent pas être qualifiés comme des références"
 
-#: cp/decl.c:11280
+#: cp/decl.c:11304
 #, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "les constructeurs ne peuvent pas être déclarés %<virtual%>"
 
 #. Cannot be both friend and virtual.
-#: cp/decl.c:11295
+#: cp/decl.c:11319
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "les fonctions virtuelles ne peuvent pas être amies"
 
-#: cp/decl.c:11299
+#: cp/decl.c:11323
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "la déclaration amie n'est pas dans la définition de la classe"
 
-#: cp/decl.c:11301
+#: cp/decl.c:11325
 #, gcc-internal-format
 msgid "can%'t define friend function %qs in a local class definition"
 msgstr "ne peut définir la fonction amie %qs dans une définition de classe locale"
 
-#: cp/decl.c:11313
+#: cp/decl.c:11337
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr "une fonction de conversion ne peut pas avoir de type de retour à la fin"
 
-#: cp/decl.c:11339
+#: cp/decl.c:11363
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "destructeurs ne peuvent pas avoir de paramètre"
 
-#: cp/decl.c:11379
+#: cp/decl.c:11403
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "ne peut déclarer un pointeur vers %q#T"
 
-#: cp/decl.c:11392 cp/decl.c:11399
+#: cp/decl.c:11416 cp/decl.c:11423
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "ne peut déclarer une référence vers %q#T"
 
-#: cp/decl.c:11401
+#: cp/decl.c:11425
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "ne peut déclarer un pointeur vers le membre %q#T"
 
-#: cp/decl.c:11430
+#: cp/decl.c:11454
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "ne peut déclarer une référence vers le type de fonction qualifié %qT"
 
-#: cp/decl.c:11431
+#: cp/decl.c:11455
 #, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "ne peut déclarer un pointeur vers le type de fonction qualifié %qT"
 
-#: cp/decl.c:11504
+#: cp/decl.c:11528
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr "ne peut déclarer une référence vers %q#T qui n'est pas un typedef ou un argument vers un type d'un patron"
 
-#: cp/decl.c:11574
+#: cp/decl.c:11598
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "template-id %qD utilisé comme un déclarateur"
 
-#: cp/decl.c:11599
+#: cp/decl.c:11623
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "les fonctions membres sont implicitement amies de leur classe"
 
-#: cp/decl.c:11605
+#: cp/decl.c:11629
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "qualification %<%T::%> additionnelle sur le membre %qs"
 
-#: cp/decl.c:11635
+#: cp/decl.c:11659
 #, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "ne peut définir la fonction membre %<%T::%s%> à l'intérieur de %qT"
 
-#: cp/decl.c:11637
+#: cp/decl.c:11661
 #, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "ne peut déclarer la fonction membre %<%T::%s%> à l'intérieur de %qT"
 
-#: cp/decl.c:11645
+#: cp/decl.c:11669
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "ne peut déclarer le membre %<%T::%s%> à l'intérieur de %qT"
 
-#: cp/decl.c:11685
+#: cp/decl.c:11709
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "le non paramètre %qs ne peut pas être un paquet de paramètres"
 
-#: cp/decl.c:11693
+#: cp/decl.c:11717
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "les membres de données ne peuvent pas avoir le type %qT modifié par une variable"
 
-#: cp/decl.c:11695
+#: cp/decl.c:11719
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "le paramètre ne peut pas avoir le type %qT modifié par une variable"
 
-#: cp/decl.c:11706
+#: cp/decl.c:11730
 #, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "%<explicit%> en dehors de la déclaration de la classe"
 
-#: cp/decl.c:11709
+#: cp/decl.c:11733
 #, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr "%<explicit%> dans une déclaration amie"
 
-#: cp/decl.c:11712
+#: cp/decl.c:11736
 #, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "seuls les déclarations de constructeurs et les opérateurs de conversion peuvent être %<explicit%>"
 
-#: cp/decl.c:11721
+#: cp/decl.c:11745
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "le non membre %qs ne peut pas être déclaré %<mutable%>"
 
-#: cp/decl.c:11726
+#: cp/decl.c:11750
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "le membre non objet %qs ne peut pas être déclaré %<mutable%>"
 
-#: cp/decl.c:11732
+#: cp/decl.c:11756
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "la fonction %qs ne peut pas être déclarée %<mutable%>"
 
-#: cp/decl.c:11737
+#: cp/decl.c:11761
 #, gcc-internal-format
 msgid "static %qs cannot be declared %<mutable%>"
 msgstr "le %qs statique ne peut pas être déclaré %<mutable%>"
 
-#: cp/decl.c:11742
+#: cp/decl.c:11766
 #, gcc-internal-format
 msgid "const %qs cannot be declared %<mutable%>"
 msgstr "le %qs constant ne peut pas être déclaré %<mutable%>"
 
-#: cp/decl.c:11747
+#: cp/decl.c:11771
 #, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "la référence %qs ne peut pas être déclarée %<mutable%>"
 
-#: cp/decl.c:11778
+#: cp/decl.c:11802
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "typedef déclaré %<auto%>"
 
-#: cp/decl.c:11783
+#: cp/decl.c:11807
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr "clause « requires » sur un typedef"
 
-#: cp/decl.c:11787
+#: cp/decl.c:11811
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "le nom du typedef ne peut pas être un nom de spécificateur imbriqué"
 
-#: cp/decl.c:11813
+#: cp/decl.c:11837
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "le C++ ISO interdit le type imbriqué %qD avec le même nom que la classe englobante"
 
-#: cp/decl.c:11900
+#: cp/decl.c:11924
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "%<inline%> spécifié pour la déclaration d'une classe amie"
 
-#: cp/decl.c:11908
+#: cp/decl.c:11932
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "les paramètres du patron ne peuvent pas être amis"
 
-#: cp/decl.c:11910
+#: cp/decl.c:11934
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "une déclaration amie requiert le mot-clé « class », c-à-d. %<friend class %T::%D%>"
 
-#: cp/decl.c:11914
+#: cp/decl.c:11938
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "une déclaration amie requiert le mot-clé « class », c-à-d %<friend %#T%>"
 
-#: cp/decl.c:11927
+#: cp/decl.c:11951
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "tentative de rendre amie la classe %qT au niveau de la portée globale"
 
-#: cp/decl.c:11947
+#: cp/decl.c:11971
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "qualificatifs invalides sur un type de fonction non membre"
 
-#: cp/decl.c:11951
+#: cp/decl.c:11975
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr "clause « requires » sur type-id"
 
-#: cp/decl.c:11961
+#: cp/decl.c:11985
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "déclaration abstraite %qT utilisée comme déclaration"
 
-#: cp/decl.c:11976
+#: cp/decl.c:12000
 #, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "clause « requires » dans la déclaration du type non fonction %qT"
 
-#: cp/decl.c:11995
+#: cp/decl.c:12019
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "ne peut utiliser %<::%> dans la déclaration d'un paramètre"
 
-#: cp/decl.c:12001
+#: cp/decl.c:12025
 #, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "le paramètre %<auto%> n'est pas permis dans ce contexte"
 
-#: cp/decl.c:12003
+#: cp/decl.c:12027
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "paramètre déclaré %<auto%>"
 
-#: cp/decl.c:12052 cp/parser.c:3270
+#: cp/decl.c:12076 cp/parser.c:3270
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "utilisation invalide du nom de patron %qE sans liste d'arguments"
 
-#: cp/decl.c:12056
+#: cp/decl.c:12080
 #, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr "membre de donnée non statique déclaré avec %qT comme espace réservé"
 
-#: cp/decl.c:12080
+#: cp/decl.c:12104
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "le C++ ISO interdit le membre tableau flexible %qs"
 
-#: cp/decl.c:12083
+#: cp/decl.c:12107
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array members"
 msgstr "le C++ ISO interdit les tableaux flexibles comme membres"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:12099
+#: cp/decl.c:12123
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "utilisation invalide de %<::%>"
 
-#: cp/decl.c:12121
+#: cp/decl.c:12145
 #, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "déclaration de la fonction %qD dans un contexte invalide"
 
-#: cp/decl.c:12130
+#: cp/decl.c:12154
 #, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "fonction %qD déclarée %<virtual%> à l'intérieur d'une union"
 
-#: cp/decl.c:12139
+#: cp/decl.c:12163
 #, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%qD ne peut pas être déclaré %<virtual%> puisqu'il est toujours statique"
 
-#: cp/decl.c:12153
+#: cp/decl.c:12177
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "nom qualifié attendu dans la déclaration amie du destructeur %qD"
 
-#: cp/decl.c:12160
+#: cp/decl.c:12184
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "déclaration de %qD comme membre de %qT"
 
-#: cp/decl.c:12166
+#: cp/decl.c:12190
 #, gcc-internal-format
 msgid "a destructor cannot be %<concept%>"
 msgstr "un destructeur ne peut pas être un %<concept%>"
 
-#: cp/decl.c:12171
+#: cp/decl.c:12195
 #, gcc-internal-format
 msgid "a destructor cannot be %<constexpr%>"
 msgstr "un destructeur ne peut pas être %<constexpr%>"
 
-#: cp/decl.c:12177
+#: cp/decl.c:12201
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "nom qualifié attendu dans la déclaration amie pour le constructeur %qD"
 
-#: cp/decl.c:12185
+#: cp/decl.c:12209
 #, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr "un constructeur ne peut pas être un %<concept%>"
 
-#: cp/decl.c:12190
+#: cp/decl.c:12214
 #, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr "un concept ne peut être une fonction membre"
 
-#: cp/decl.c:12199
+#: cp/decl.c:12223
 #, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr "spécialisation du patron de variable %qD déclaré comme une fonction"
 
-#: cp/decl.c:12202
+#: cp/decl.c:12226
 #, gcc-internal-format
 msgid "variable template declared here"
 msgstr "le patron de variable a été déclaré ici"
 
-#: cp/decl.c:12257
+#: cp/decl.c:12281
 #, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr "le champ %qD a le type incomplet %qT"
 
-#: cp/decl.c:12262
+#: cp/decl.c:12286
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "le nom %qT a un type incomplet"
 
-#: cp/decl.c:12272
+#: cp/decl.c:12296
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE n'est ni une fonction ni une fonction membre; il ne peut pas être déclaré ami"
 
-#: cp/decl.c:12318
+#: cp/decl.c:12342
 #, gcc-internal-format
 msgid "static data member %qE declared %<concept%>"
 msgstr "membre statique %qE déclaré %<concept%>"
 
-#: cp/decl.c:12322
+#: cp/decl.c:12346
 #, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "le membre statique %<constexpr%> %qD doit avoir une initialisation"
 
-#: cp/decl.c:12350
+#: cp/decl.c:12374
 #, gcc-internal-format
 msgid "non-static data member %qE declared %<concept%>"
 msgstr "le membre non statique %qE est déclaré %<concept%>"
 
-#: cp/decl.c:12354
+#: cp/decl.c:12378
 #, gcc-internal-format
 msgid "non-static data member %qE declared %<constexpr%>"
 msgstr "le membre non statique %qE est déclaré %<constexpr%>"
 
-#: cp/decl.c:12409
+#: cp/decl.c:12433
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "la classe de stockage %<auto%> est invalide pour la fonction %qs"
 
-#: cp/decl.c:12411
+#: cp/decl.c:12435
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "la classe de stockage %<register%> est invalide pour la fonction %qs"
 
-#: cp/decl.c:12415
+#: cp/decl.c:12439
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "la classe de stockage %<__thread%> est invalide pour la fonction %qs"
 
-#: cp/decl.c:12418
+#: cp/decl.c:12442
 #, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "la classe de stockage %<thread_local%> est invalide pour la fonction %qs"
 
-#: cp/decl.c:12423
+#: cp/decl.c:12447
 #, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "le spécificateur de type « virt-specifier » sur %qs n'est pas permis en dehors d'une définition de classe"
 
-#: cp/decl.c:12434
+#: cp/decl.c:12458
 #, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "le spécificateur %<static%> est invalide pour la fonction %qs déclarée en dehors de la portée globale"
 
-#: cp/decl.c:12438
+#: cp/decl.c:12462
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "le spécificateur %<inline%> est invalide pour la fonction %qs déclarée en dehors de la portée globale"
 
-#: cp/decl.c:12446
+#: cp/decl.c:12470
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "fonction non classe virtuelle %qs"
 
-#: cp/decl.c:12453
+#: cp/decl.c:12477
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "%qs défini en dehors d'un contexte de classe"
 
-#: cp/decl.c:12454
+#: cp/decl.c:12478
 #, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "%qs déclaré en dehors d'un contexte de classe"
 
-#: cp/decl.c:12489
+#: cp/decl.c:12513
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "ne peut déclarer la fonction membre %qD comme ayant une classe de liaison statique"
@@ -42292,77 +42340,77 @@
 
 #. 7.1.1: There can be no static function declarations within a
 #. block.
-#: cp/decl.c:12497
+#: cp/decl.c:12521
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "ne peut déclarer une fonction statique à l'intérieur d'une autre fonction"
 
-#: cp/decl.c:12533
+#: cp/decl.c:12557
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "%<static%> ne peut pas être utilisé lors de la définition (contrairement à la déclaration) d'un membre de donnée statique"
 
-#: cp/decl.c:12540
+#: cp/decl.c:12564
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "membre statique %qD déclaré %<register%>"
 
-#: cp/decl.c:12546
+#: cp/decl.c:12570
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "ne peut explicitement déclarer le membre %q#D comme ayant une classe de liaison externe"
 
-#: cp/decl.c:12553
+#: cp/decl.c:12577
 #, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "la déclaration de la variable %<constexpr%> %qD n'est pas une définition"
 
-#: cp/decl.c:12574
+#: cp/decl.c:12598
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "la déclaration de %q#D n'est pas initialisée"
 
-#: cp/decl.c:12585
+#: cp/decl.c:12609
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs initialisé et déclaré %<extern%>"
 
-#: cp/decl.c:12589
+#: cp/decl.c:12613
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs a, à la fois, %<extern%> et une initialisation"
 
-#: cp/decl.c:12754
+#: cp/decl.c:12778
 #, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "l'argument par défaut %qE utilise %qD"
 
-#: cp/decl.c:12757
+#: cp/decl.c:12781
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "l'argument par défaut %qE utilise la variable locale %qD"
 
-#: cp/decl.c:12841
+#: cp/decl.c:12865
 #, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "utilisation invalide du type %qT qualifié CV dans la déclaration du paramètre"
 
-#: cp/decl.c:12845
+#: cp/decl.c:12869
 #, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "utilisation invalide du type %<void%> dans la déclaration du paramètre"
 
-#: cp/decl.c:12868
+#: cp/decl.c:12892
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "le paramètre %qD est incorrectement déclaré comme type de méthode"
 
-#: cp/decl.c:12895
+#: cp/decl.c:12919
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "le paramètre %qD inclut un pointeur vers un tableau %qT dont les bornes sont inconnues"
 
-#: cp/decl.c:12897
+#: cp/decl.c:12921
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "le paramètre %qD inclut une référence vers un tableau %qT dont les bornes sont inconnues"
@@ -42382,169 +42430,169 @@
 #. or implicitly defined), there's no need to worry about their
 #. existence.  Theoretically, they should never even be
 #. instantiated, but that's hard to forestall.
-#: cp/decl.c:13150
+#: cp/decl.c:13174
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "constructeur invalide; vous vouliez probablement utiliser %<%T (const %T&)%>"
 
-#: cp/decl.c:13228
+#: cp/decl.c:13252
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD ne peut pas être déclaré dans un espace de noms"
 
-#: cp/decl.c:13234
+#: cp/decl.c:13258
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD ne peut pas être déclaré statique"
 
-#: cp/decl.c:13261
+#: cp/decl.c:13285
 #, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr "%qD doit être une fonction membre non statique"
 
-#: cp/decl.c:13267
+#: cp/decl.c:13291
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD doit être soit une fonction membre non statique ou une fonction non membre"
 
-#: cp/decl.c:13277
+#: cp/decl.c:13301
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD doit avoir un argument de type classe ou énuméré"
 
 #. 13.4.0.3
-#: cp/decl.c:13303
+#: cp/decl.c:13327
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading operator ?:"
 msgstr "le C++ ISO interdit la surcharge de l'opérateur ?:"
 
 #. Variadic.
-#: cp/decl.c:13314
+#: cp/decl.c:13338
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD ne doit pas avoir un nombre variables d'arguments"
 
-#: cp/decl.c:13338
+#: cp/decl.c:13362
 #, gcc-internal-format
 msgid "%qD must have either zero or one argument"
 msgstr "%qD doit avoir zéro ou un argument"
 
-#: cp/decl.c:13339
+#: cp/decl.c:13363
 #, gcc-internal-format
 msgid "%qD must have either one or two arguments"
 msgstr "%qD doit avoir un ou deux arguments"
 
-#: cp/decl.c:13350
+#: cp/decl.c:13374
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "%qD suffixé doit avoir %<int%> comme argument"
 
-#: cp/decl.c:13351
+#: cp/decl.c:13375
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "%qD suffixé doit avoir %<int%> comme second argument"
 
-#: cp/decl.c:13361
+#: cp/decl.c:13385
 #, gcc-internal-format
 msgid "%qD must have no arguments"
 msgstr "%qD ne doit avoir aucun argument"
 
-#: cp/decl.c:13362 cp/decl.c:13371
+#: cp/decl.c:13386 cp/decl.c:13395
 #, gcc-internal-format
 msgid "%qD must have exactly one argument"
 msgstr "%qD doit avoir exactement un argument"
 
-#: cp/decl.c:13372
+#: cp/decl.c:13396
 #, gcc-internal-format
 msgid "%qD must have exactly two arguments"
 msgstr "%qD doit avoir exactement deux arguments"
 
-#: cp/decl.c:13389 cp/decl.c:13392
+#: cp/decl.c:13413 cp/decl.c:13416
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD ne peut avoir d'arguments par défaut"
 
-#: cp/decl.c:13419
+#: cp/decl.c:13443
 #, gcc-internal-format
 msgid "conversion to a reference to void will never use a type conversion operator"
 msgstr "la conversion en une référence vers void n'utilisera jamais un opérateur de conversion de type"
 
-#: cp/decl.c:13421
+#: cp/decl.c:13445
 #, gcc-internal-format
 msgid "conversion to void will never use a type conversion operator"
 msgstr "la conversion vers void n'utilisera jamais un opérateur de conversion de type"
 
-#: cp/decl.c:13428
+#: cp/decl.c:13452
 #, gcc-internal-format
 msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgstr "la conversion en une référence vers le même type n'utilisera jamais un opérateur de conversion de type"
 
-#: cp/decl.c:13430
+#: cp/decl.c:13454
 #, gcc-internal-format
 msgid "conversion to the same type will never use a type conversion operator"
 msgstr "la conversion vers le même type n'utilisera jamais un opérateur de conversion de type"
 
-#: cp/decl.c:13438
+#: cp/decl.c:13462
 #, gcc-internal-format
 msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgstr "la conversion en une référence vers une classe de base n'utilisera jamais un opérateur de conversion de type"
 
-#: cp/decl.c:13440
+#: cp/decl.c:13464
 #, gcc-internal-format
 msgid "conversion to a base class will never use a type conversion operator"
 msgstr "la conversion vers une classe de base n'utilisera jamais un opérateur de conversion de type"
 
-#: cp/decl.c:13455
+#: cp/decl.c:13479
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "%qD défini par l'usager évalue toujours les 2 arguments"
 
-#: cp/decl.c:13474
+#: cp/decl.c:13498
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "%qD préfixé devrait retourner %qT"
 
-#: cp/decl.c:13480
+#: cp/decl.c:13504
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "%qD suffixé devrait retourner %qT"
 
-#: cp/decl.c:13492
+#: cp/decl.c:13516
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD devrait retourner par valeur"
 
-#: cp/decl.c:13547
+#: cp/decl.c:13571
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "utilisation du paramètre du type de patron %qT après %qs"
 
-#: cp/decl.c:13570
+#: cp/decl.c:13594
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "utilisation de la spécialisation du patron d'alias %qT après %qs"
 
-#: cp/decl.c:13573
+#: cp/decl.c:13597
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "utilisation du nom de typedef %qD après %qs"
 
-#: cp/decl.c:13575
+#: cp/decl.c:13599
 #, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "%qD a une déclaration précédente ici"
 
-#: cp/decl.c:13583
+#: cp/decl.c:13607
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "%qT référé en tant que %qs"
 
-#: cp/decl.c:13584 cp/decl.c:13591
+#: cp/decl.c:13608 cp/decl.c:13615
 #, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr "%qT a une déclaration précédente ici"
 
-#: cp/decl.c:13590
+#: cp/decl.c:13614
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "il est fait référence à %qT comme un enum"
@@ -42556,94 +42604,94 @@
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:13605
+#: cp/decl.c:13629
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "argument du patron requis pour %<%s %T%>"
 
-#: cp/decl.c:13659 cp/name-lookup.c:4652
+#: cp/decl.c:13683 cp/name-lookup.c:4652
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD a le même nom que la classe dans laquelle il est déclaré"
 
-#: cp/decl.c:13689 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6425
-#: cp/pt.c:9209
+#: cp/decl.c:13713 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6428
+#: cp/pt.c:9223
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT n'est pas un patron"
 
-#: cp/decl.c:13694
+#: cp/decl.c:13718
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr "vous voulez peut-être ajouter %<%T::%> explicitement"
 
-#: cp/decl.c:13703 cp/name-lookup.c:4079 cp/name-lookup.c:4086
-#: cp/name-lookup.c:4939 cp/parser.c:6376 cp/parser.c:26300
+#: cp/decl.c:13727 cp/name-lookup.c:4079 cp/name-lookup.c:4086
+#: cp/name-lookup.c:4939 cp/parser.c:6379 cp/parser.c:26297
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "la référence à %qD est ambiguë"
 
-#: cp/decl.c:13806
+#: cp/decl.c:13830
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "utilisation de l'enum %q#D sans déclaration précédente"
 
-#: cp/decl.c:13842
+#: cp/decl.c:13866
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "redéclaration de %qT sous une forme qui n'est pas un patron"
 
-#: cp/decl.c:13982
+#: cp/decl.c:14006
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "l'union dérivée %qT est invalide"
 
-#: cp/decl.c:13989
+#: cp/decl.c:14013
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr "%qT est défini avec des bases directes multiples"
 
-#: cp/decl.c:14000
+#: cp/decl.c:14024
 #, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr "%qT est défini avec des bases virtuelles directes"
 
-#: cp/decl.c:14025
+#: cp/decl.c:14049
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "le type de base %qT n'est pas un « struct » ou une « class »"
 
-#: cp/decl.c:14055
+#: cp/decl.c:14079
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "type récursif %qT non défini"
 
-#: cp/decl.c:14057
+#: cp/decl.c:14081
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "le type de base dupliqué %qT est invalide"
 
-#: cp/decl.c:14202
+#: cp/decl.c:14226
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr "non concordance entre un enum simple et un enum fortement typé pour %q#T"
 
-#: cp/decl.c:14205 cp/decl.c:14213 cp/decl.c:14225 cp/parser.c:18284
+#: cp/decl.c:14229 cp/decl.c:14237 cp/decl.c:14249 cp/parser.c:18281
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "définition précédente ici"
 
-#: cp/decl.c:14210
+#: cp/decl.c:14234
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr "désaccord dans le type sous-jacent de l'enum %q#T"
 
-#: cp/decl.c:14222
+#: cp/decl.c:14246
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr "types sous-jacents différents dans l'enum %q#T"
 
-#: cp/decl.c:14300
+#: cp/decl.c:14324
 #, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr "le type sous-jacent %qT de %qT doit être un type entier"
@@ -42652,77 +42700,77 @@
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:14447
+#: cp/decl.c:14471
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "aucun type entier ne peut représenter toutes les valeurs de l'énumération pour %qT"
 
-#: cp/decl.c:14619
+#: cp/decl.c:14643
 #, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "les valeurs énumérées de %qD doivent être de type entier ou une énumération simple (donc, pas fortement typée)"
 
-#: cp/decl.c:14629
+#: cp/decl.c:14653
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "la valeur de l'énumération pour %qD n'est pas une constante entière"
 
-#: cp/decl.c:14678
+#: cp/decl.c:14702
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "la valeur incrémentée de l'énumération est trop grande pour %<unsigned long%>"
 
-#: cp/decl.c:14679
+#: cp/decl.c:14703
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "la valeur incrémentée de l'énumération est trop grande pour %<long%>"
 
-#: cp/decl.c:14690
+#: cp/decl.c:14714
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "débordement dans les valeurs de l'énumération à %qD"
 
-#: cp/decl.c:14710
+#: cp/decl.c:14734
 #, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "la valeur de l'énumération %qE est en dehors de la plage du type sous-jacent %qT"
 
-#: cp/decl.c:14821
+#: cp/decl.c:14845
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "le type retourné %q#T est incomplet"
 
-#: cp/decl.c:14999 cp/typeck.c:9286
+#: cp/decl.c:15023 cp/typeck.c:9286
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> devrait retourner une référence à %<*this%>"
 
-#: cp/decl.c:15344
+#: cp/decl.c:15368
 #, gcc-internal-format
 msgid "invalid function declaration"
 msgstr "déclaration de fonction invalide"
 
-#: cp/decl.c:15786
+#: cp/decl.c:15810
 #, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr "« return » manquant dans une fonction retournant %qT"
 
-#: cp/decl.c:15788 cp/typeck.c:9166
+#: cp/decl.c:15812 cp/typeck.c:9166
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "seul un type de retour %<auto%> évident peut être déduit en %<void%>"
 
-#: cp/decl.c:15996
+#: cp/decl.c:16020
 #, gcc-internal-format
 msgid "invalid member function declaration"
 msgstr "déclaration de fonction membre invalide"
 
-#: cp/decl.c:16010
+#: cp/decl.c:16034
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD est déjà défini dans la classe %qT"
 
-#: cp/decl.c:16386
+#: cp/decl.c:16410
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr "utilisation de %qD avant la déduction de %<auto%>"
@@ -42762,7 +42810,7 @@
 msgid "deleting %qT is undefined"
 msgstr "la destruction de %qT est non définie"
 
-#: cp/decl2.c:585 cp/pt.c:5552
+#: cp/decl2.c:585 cp/pt.c:5566
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "déclaration du patron de %q#D"
@@ -42775,7 +42823,7 @@
 #. [temp.mem]
 #.
 #. A destructor shall not be a member template.
-#: cp/decl2.c:640 cp/pt.c:5511
+#: cp/decl2.c:640 cp/pt.c:5525
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "le destructeur %qD est déclaré en tant que patron membre"
@@ -42949,47 +42997,47 @@
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "%<operator delete%> prend le type %qT comme premier paramètre"
 
-#: cp/decl2.c:2660
+#: cp/decl2.c:2650
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type has no linkage"
 msgstr "%qT a un champ %qD dont le type n'a pas de classe de liaison"
 
-#: cp/decl2.c:2664
+#: cp/decl2.c:2654
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr "%qT a un champ %qD dont le type dépend du type %qT qui n'a pas de classe de liaison"
 
-#: cp/decl2.c:2669
+#: cp/decl2.c:2659
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr "%qT a un champ %qD dont le type utilise l'espace de noms anonyme"
 
-#: cp/decl2.c:2677
+#: cp/decl2.c:2667
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr "%qT est déclaré avec une plus grande visibilité que le type de son champs %qD"
 
-#: cp/decl2.c:2695
+#: cp/decl2.c:2685
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type has no linkage"
 msgstr "%qT a la base %qT dont le type n'a pas de classe de liaison"
 
-#: cp/decl2.c:2699
+#: cp/decl2.c:2689
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type depends on the type %qT which has no linkage"
 msgstr "%qT a la base %qT dont le type dépend du type %qT qui n'a pas de classe de liaison"
 
-#: cp/decl2.c:2704
+#: cp/decl2.c:2694
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr "%qT a la base %qT dont le type utilise l'espace de noms anonyme"
 
-#: cp/decl2.c:2711
+#: cp/decl2.c:2701
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr "%qT est déclaré avec une plus grande visibilité que sa base %qT"
 
-#: cp/decl2.c:4309
+#: cp/decl2.c:4299
 #, gcc-internal-format
 msgid "%q#D, declared using unnamed type, is used but never defined"
 msgstr "%q#D, déclaré avec un type non nommé, est utilisé mais jamais défini"
@@ -42998,62 +43046,62 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4318
+#: cp/decl2.c:4308
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr "un type non nommé sans classe de liaison est utilisé pour déclarer la variable %q#D avec une classe de liaison"
 
-#: cp/decl2.c:4322
+#: cp/decl2.c:4312
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr "un type non nommé sans classe de liaison est utilisé pour déclarer la fonction %q#D avec une classe de liaison"
 
-#: cp/decl2.c:4326
+#: cp/decl2.c:4316
 #, gcc-internal-format
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr "%q#D ne réfère pas au type non qualifié, aussi n'est-il pas utilisé pour la liaison"
 
-#: cp/decl2.c:4334
+#: cp/decl2.c:4324
 #, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "%q#D, déclaré avec le type local %qT, est utilisé mais jamais défini"
 
-#: cp/decl2.c:4338
+#: cp/decl2.c:4328
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr "le type %qT sans classe de liaison est utilisé pour déclarer la variable %q#D avec une classe de liaison"
 
-#: cp/decl2.c:4341
+#: cp/decl2.c:4331
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "le type %qT sans classe de liaison est utilisé pour déclarer la fonction %q#D avec une classe de liaison"
 
-#: cp/decl2.c:4529
+#: cp/decl2.c:4519
 #, gcc-internal-format
 msgid "mangling of %q#D as %qE conflicts with a previous mangle"
 msgstr "la décoration de %q#D qui abouti à %qE entre en conflit avec une décoration précédente"
 
-#: cp/decl2.c:4532
+#: cp/decl2.c:4522
 #, gcc-internal-format
 msgid "previous mangling %q#D"
 msgstr "décoration précédente de %q#D"
 
-#: cp/decl2.c:4534
+#: cp/decl2.c:4524
 #, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr "un -fabi-version= plus récent (ou =0) évite cette erreur avec un changement de décoration"
 
-#: cp/decl2.c:4606 cp/decl2.c:4609
+#: cp/decl2.c:4596 cp/decl2.c:4599
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr "le programme devrait aussi définir %qD"
 
-#: cp/decl2.c:4956
+#: cp/decl2.c:4946
 #, gcc-internal-format
 msgid "inline function %qD used but never defined"
 msgstr "la fonction en ligne %qD est utilisée mais n'a jamais été définie"
 
-#: cp/decl2.c:5143
+#: cp/decl2.c:5133
 #, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr "argument par défaut manquant pour le paramètre %P de %q+#D"
@@ -43060,17 +43108,17 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5251
+#: cp/decl2.c:5241
 #, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr "conversion d'une fonction lambda qui utilise %<...%> en pointeur de fonction"
 
-#: cp/decl2.c:5254
+#: cp/decl2.c:5244
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "utilisation de la fonction supprimée %qD"
 
-#: cp/decl2.c:5307
+#: cp/decl2.c:5297
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr "utilisation du paquet de paramètres intégré %qD en dehors d'un patron"
@@ -43356,333 +43404,333 @@
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr "instanciation récursive de l'initialisation du membre par défaut pour %qD"
 
-#: cp/init.c:613
+#: cp/init.c:629
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr "l'initialisation du membre par défaut pour %qD est requise avant la fin de sa classe englobante"
 
-#: cp/init.c:615
+#: cp/init.c:631
 #, gcc-internal-format
 msgid "defined here"
 msgstr "défini ici"
 
-#: cp/init.c:673
+#: cp/init.c:689
 #, gcc-internal-format
 msgid "initializer for flexible array member %q#D"
 msgstr "initialisation pour le membre tableau flexible %q#D"
 
-#: cp/init.c:699
+#: cp/init.c:715
 #, gcc-internal-format
 msgid "%qD should be initialized in the member initialization list"
 msgstr "%qD devrait être initialisé dans la liste d'initialisation du membre"
 
-#: cp/init.c:720
+#: cp/init.c:736
 #, gcc-internal-format
 msgid "%qD is initialized with itself"
 msgstr "%qD est initialisé avec lui-même"
 
-#: cp/init.c:831
+#: cp/init.c:847
 #, gcc-internal-format
 msgid "invalid initializer for array member %q#D"
 msgstr "initialisation invalide pour le membre tableau %q#D"
 
-#: cp/init.c:845 cp/init.c:869 cp/init.c:2410 cp/method.c:1368
+#: cp/init.c:861 cp/init.c:885 cp/init.c:2427 cp/method.c:1368
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr "membre constant non initialisé dans %q#T"
 
-#: cp/init.c:847 cp/init.c:864 cp/init.c:871 cp/init.c:2395 cp/init.c:2423
+#: cp/init.c:863 cp/init.c:880 cp/init.c:887 cp/init.c:2412 cp/init.c:2440
 #: cp/method.c:1371 cp/method.c:1382
 #, gcc-internal-format
 msgid "%q#D should be initialized"
 msgstr "%q#D devrait être initialisé"
 
-#: cp/init.c:862 cp/init.c:2382 cp/method.c:1379
+#: cp/init.c:878 cp/init.c:2399 cp/method.c:1379
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr "membre par référence non initialisé dans %q#T"
 
-#: cp/init.c:1041
+#: cp/init.c:1057
 #, gcc-internal-format
 msgid "%qD will be initialized after"
 msgstr "%qD sera initialisé après"
 
-#: cp/init.c:1044
+#: cp/init.c:1060
 #, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr "la base %qT sera initialisée après"
 
-#: cp/init.c:1048
+#: cp/init.c:1064
 #, gcc-internal-format
 msgid "  %q#D"
 msgstr "  %q#D"
 
-#: cp/init.c:1050
+#: cp/init.c:1066
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr "  la base %qT"
 
-#: cp/init.c:1052
+#: cp/init.c:1068
 #, gcc-internal-format
 msgid "  when initialized here"
 msgstr "  quand elle est initialisée ici"
 
-#: cp/init.c:1069
+#: cp/init.c:1085
 #, gcc-internal-format
 msgid "multiple initializations given for %qD"
 msgstr "initialisations multiples données pour %qD"
 
-#: cp/init.c:1073
+#: cp/init.c:1089
 #, gcc-internal-format
 msgid "multiple initializations given for base %qT"
 msgstr "initialisations multiples données pour la base %qT"
 
-#: cp/init.c:1158
+#: cp/init.c:1174
 #, gcc-internal-format
 msgid "initializations for multiple members of %qT"
 msgstr "initialisations pour des membres multiples de %qT"
 
-#: cp/init.c:1255
+#: cp/init.c:1271
 #, gcc-internal-format
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr "la classe de base %q#T devrait être explicitement initialisée dans le constructeur par copie"
 
-#: cp/init.c:1482 cp/init.c:1501
+#: cp/init.c:1498 cp/init.c:1517
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr "la classe %qT n'a aucun champ nommé %qD"
 
-#: cp/init.c:1488
+#: cp/init.c:1504
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr "%q#D est un membre de donnée statique; il peut seulement être initialisé lors de sa définition"
 
-#: cp/init.c:1495
+#: cp/init.c:1511
 #, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr "%q#D n'est pas un membre de donnée non statique de %qT"
 
-#: cp/init.c:1534
+#: cp/init.c:1550
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr "initialisation sans nom pour %qT, lequel n'a pas de classe de base"
 
-#: cp/init.c:1542
+#: cp/init.c:1558
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr "initialisation sans nom pour %qT, lequel utilise de multiples héritages"
 
-#: cp/init.c:1589
+#: cp/init.c:1605
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr "%qD est à la fois une base directe et une base virtuelle indirecte"
 
-#: cp/init.c:1597
+#: cp/init.c:1613
 #, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr "le type %qT n'est pas une base directe ou virtuelle de %qT"
 
-#: cp/init.c:1600
+#: cp/init.c:1616
 #, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr "le type %qT n'est pas une base directe de %qT"
 
-#: cp/init.c:1710 cp/init.c:4386 cp/typeck2.c:1175
+#: cp/init.c:1727 cp/init.c:4402 cp/typeck2.c:1175
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "le tableau doit être initialisé avec une initialisation entre accolades"
 
-#: cp/init.c:2019 cp/semantics.c:3268
+#: cp/init.c:2036 cp/semantics.c:3271
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qT n'est pas un type de classe"
 
-#: cp/init.c:2075
+#: cp/init.c:2092
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr "le type incomplet %qT n'a pas de membre %qD"
 
-#: cp/init.c:2089
+#: cp/init.c:2106
 #, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr "pointeur invalide vers le champ de bits %qD"
 
-#: cp/init.c:2175 cp/typeck.c:1893
+#: cp/init.c:2192 cp/typeck.c:1893
 #, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "utilisation invalide de la fonction membre non statique %qD"
 
-#: cp/init.c:2182 cp/semantics.c:1835
+#: cp/init.c:2199 cp/semantics.c:1835
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "utilisation invalide du membre de donnée non statique %qD"
 
-#: cp/init.c:2379
+#: cp/init.c:2396
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr "le membre de référence non initialisé dans %q#T utilise %<new%> sans initialisation « new »"
 
-#: cp/init.c:2387
+#: cp/init.c:2404
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "le membre de référence non initialisé dans la base %q#T de %q#T utilise %<new%> sans initialisation « new »"
 
-#: cp/init.c:2391
+#: cp/init.c:2408
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr "membre de référence non initialisé dans la base %q#T de %q#T"
 
-#: cp/init.c:2407
+#: cp/init.c:2424
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr "le membre constant non initialisé dans %q#T utilise %<new%> sans initialisation « new »"
 
-#: cp/init.c:2415
+#: cp/init.c:2432
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "le membre constant non initialisé dans la base %q#T de %q#T utilise %<new%> sans initialisation « new »"
 
-#: cp/init.c:2419
+#: cp/init.c:2436
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr "membre constant non initialisé dans la base %q#T de %q#T"
 
-#: cp/init.c:2710
+#: cp/init.c:2727
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr "l'opérateur « new » avec placement construit un objet de type %<%T [%wu]%> et de taille %qwu dans une région de type %qT et de taille %qwi"
 
-#: cp/init.c:2721
+#: cp/init.c:2738
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr "l'opérateur « new » avec placement construit un tableau d'objets de type %qT et de taille %qwu dans une région de type %qT et de taille %qwi"
 
-#: cp/init.c:2732
+#: cp/init.c:2749
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr "l'opérateur « new » avec placement construit un objet de type %qT et de taille %qwu dans une région de type %qT et de taille %qwi"
 
-#: cp/init.c:2880
+#: cp/init.c:2896
 #, gcc-internal-format
 msgid "integer overflow in array size"
 msgstr "débordement d'entier dans la taille du tableau"
 
-#: cp/init.c:2890
+#: cp/init.c:2906
 #, gcc-internal-format
 msgid "array size in new-expression must be constant"
 msgstr "la taille du tableau dans l'expression « new » doit être une constante"
 
-#: cp/init.c:2904
+#: cp/init.c:2920
 #, gcc-internal-format
 msgid "variably modified type not allowed in new-expression"
 msgstr "le type modifié par une variable n'est pas permis dans l'expression « new »"
 
-#: cp/init.c:2920
+#: cp/init.c:2936
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by typedef"
 msgstr "la nouvelle longueur du tableau non constant doit être spécifiée directement, pas par un typedef"
 
-#: cp/init.c:2922
+#: cp/init.c:2938
 #, gcc-internal-format
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr "la nouvelle longueur du tableau non constant doit être spécifiée sans parenthèses autour du id de type"
 
-#: cp/init.c:2932
+#: cp/init.c:2948
 #, gcc-internal-format
 msgid "invalid type %<void%> for new"
 msgstr "type %<void%> invalide pour « new »"
 
-#: cp/init.c:2975
+#: cp/init.c:2991
 #, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr "constante non initialisée dans %<new%> de %q#T"
 
-#: cp/init.c:3101
+#: cp/init.c:3117
 #, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr "pas de %qD convenable dans la classe %qT"
 
-#: cp/init.c:3108 cp/search.c:1023
+#: cp/init.c:3124 cp/search.c:1026
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "la requête pour le membre %qD est ambiguë"
 
-#: cp/init.c:3181
+#: cp/init.c:3197
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr "%<new%> de type %qT avec l'alignement étendu %d"
 
-#: cp/init.c:3184
+#: cp/init.c:3200
 #, gcc-internal-format
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr "utilisation de %qD qui n'a pas de paramètre d'alignement"
 
-#: cp/init.c:3187
+#: cp/init.c:3203
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr "utilisez %<-faligned-new%> pour activer le support du « new » sur-aligné du C++17"
 
-#: cp/init.c:3370
+#: cp/init.c:3386
 #, gcc-internal-format
 msgid "parenthesized initializer in array new"
 msgstr "initialisation entre parenthèses dans le « new » du tableau"
 
-#: cp/init.c:3633
+#: cp/init.c:3649
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr "la taille du tableau dans « new » doit avoir un type entier"
 
-#: cp/init.c:3665
+#: cp/init.c:3681
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr "« new » ne peut pas être appliqué à un type référencé"
 
-#: cp/init.c:3674
+#: cp/init.c:3690
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr "« new » ne peut être appliqué à un type de fonction"
 
-#: cp/init.c:3743
+#: cp/init.c:3759
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete [] operator:"
 msgstr "problème possible détecté dans l'invocation de l'opérateur delete[]:"
 
-#: cp/init.c:3747
+#: cp/init.c:3763
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete [] will be called, even if they are declared when the class is defined"
 msgstr "ni le destructeur ni l'opérateur « delete[] » spécifique à la classe seront appelés, même s'ils sont déclarés lorsque la classe est définie"
 
-#: cp/init.c:4295
+#: cp/init.c:4311
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "fin prématurée de l'initialisation"
 
-#: cp/init.c:4599
+#: cp/init.c:4615
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr "taille du tableau inconnue dans delete"
 
-#: cp/init.c:4623
+#: cp/init.c:4639
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete operator:"
 msgstr "problème possible détecté dans l'invocation de l'opérateur delete:"
 
-#: cp/init.c:4628
+#: cp/init.c:4644
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
 msgstr "ni le destructeur ni l'opérateur « delete » spécifique à la classe seront appelés, même s'ils sont déclarés lorsque la classe est définie"
 
-#: cp/init.c:4642
+#: cp/init.c:4658
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr "la destruction d'un objet de la classe abstraite %qT qui a un destructeur non virtuel provoquera un comportement indéfini"
 
-#: cp/init.c:4647
+#: cp/init.c:4663
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr "la destruction d'un objet de la classe polymorphique %qT qui a un destructeur non virtuel pourrait produire un comportement indéfini"
 
-#: cp/init.c:4954
+#: cp/init.c:4970
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "le type passé au delete vectoriel n'est ni un pointeur ni un type tableau"
@@ -44154,7 +44202,7 @@
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "l'attribut %qD est ignoré sur l'espace de noms pas en ligne"
 
-#: cp/name-lookup.c:5111 cp/name-lookup.c:7065
+#: cp/name-lookup.c:5111 cp/name-lookup.c:7073
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "la directive d'attribut %qD est ignorée"
@@ -44201,53 +44249,53 @@
 msgid "it was later defined here"
 msgstr "elle a été définie ici plus tard"
 
-#: cp/name-lookup.c:6687
+#: cp/name-lookup.c:6695
 #, gcc-internal-format
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn't a template"
 msgstr "la déclaration de %<std::initializer_list%> ne correspond pas à %<#include <initializer_list>%> et n'est pas un patron"
 
-#: cp/name-lookup.c:7059
+#: cp/name-lookup.c:7067
 #, gcc-internal-format
 msgid "strong using directive no longer supported"
 msgstr "la directive « using » forte n'est plus supportée"
 
-#: cp/name-lookup.c:7062
+#: cp/name-lookup.c:7070
 #, gcc-internal-format
 msgid "you may use an inline namespace instead"
 msgstr "vous pouvez utiliser un espace de noms en ligne à la place"
 
-#: cp/name-lookup.c:7079
+#: cp/name-lookup.c:7087
 #, gcc-internal-format
 msgid "attributes ignored on local using directive"
 msgstr "attributs ignorés sur une directive « using » locale"
 
-#: cp/name-lookup.c:7163
+#: cp/name-lookup.c:7171
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "l'alias de l'espace de noms %qD n'est pas permis ici, on suppose %qD"
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:7183
+#: cp/name-lookup.c:7191
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot nest more than %d namespaces"
 msgstr "impossible d'imbriquer plus de %d espaces de noms"
 
-#: cp/name-lookup.c:7218
+#: cp/name-lookup.c:7226
 #, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr "un espace de nom en ligne doit être spécifié à la définition initiale"
 
-#: cp/name-lookup.c:7219
+#: cp/name-lookup.c:7227
 #, gcc-internal-format
 msgid "%qD defined here"
 msgstr "%qD défini ici"
 
-#: cp/name-lookup.c:7292
+#: cp/name-lookup.c:7300
 #, gcc-internal-format
 msgid "XXX entering pop_everything ()\n"
 msgstr "XXX entre dans pop_everything ()\n"
 
-#: cp/name-lookup.c:7301
+#: cp/name-lookup.c:7309
 #, gcc-internal-format
 msgid "XXX leaving pop_everything ()\n"
 msgstr "XXX quitte pop_everything ()\n"
@@ -44267,7 +44315,7 @@
 msgid "LEXER_DEBUGGING_ENABLED_P is not set to true"
 msgstr "LEXER_DEBUGGING_ENABLED_P n'est pas défini à vrai"
 
-#: cp/parser.c:1352 cp/parser.c:37254
+#: cp/parser.c:1352 cp/parser.c:37251
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr "%<#pragma omp declare simd%> pas immédiatement suivi par une déclaration ou une définition de fonction"
@@ -44292,7 +44340,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr "requête du membre %qE dans le type %qT qui n'est pas une classe"
 
-#: cp/parser.c:2949 cp/parser.c:18221
+#: cp/parser.c:2949 cp/parser.c:18218
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "%<%T::%E%> n'a pas été déclaré"
@@ -44372,7 +44420,7 @@
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "le C++ ISO interdit l'utilisation d'un littéral en virgule flottante dans une expression constante"
 
-#: cp/parser.c:3143 cp/pt.c:17853
+#: cp/parser.c:3143 cp/pt.c:17890
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr "un transtypage vers un type autre qu'un entier ou une énumération ne peut pas apparaître dans une expression constante"
@@ -44594,7 +44642,7 @@
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr "impossible de trouver l'opérateur littéral de chaîne %qD avec les arguments %qT, %qT"
 
-#: cp/parser.c:4587 cp/parser.c:12940
+#: cp/parser.c:4587 cp/parser.c:12937
 #, gcc-internal-format
 msgid "expected declaration"
 msgstr "déclaration attendue"
@@ -44645,7 +44693,7 @@
 msgid "fold-expressions only available with -std=c++17 or -std=gnu++17"
 msgstr "les expressions fold sont uniquement disponibles avec -std=c++17 ou -std=gnu++17"
 
-#: cp/parser.c:5275 cp/parser.c:5452 cp/parser.c:5630 cp/semantics.c:3612
+#: cp/parser.c:5275 cp/parser.c:5452 cp/parser.c:5633 cp/semantics.c:3615
 #, gcc-internal-format
 msgid "expected primary-expression"
 msgstr "expression primaire attendue"
@@ -44665,92 +44713,92 @@
 msgid "local variable %qD may not appear in this context"
 msgstr "la variable locale %qD ne peut pas apparaître dans ce contexte"
 
-#: cp/parser.c:5787
+#: cp/parser.c:5790
 #, gcc-internal-format
 msgid "expected id-expression"
 msgstr "expression id attendue"
 
-#: cp/parser.c:5919
+#: cp/parser.c:5922
 #, gcc-internal-format
 msgid "scope %qT before %<~%> is not a class-name"
 msgstr "la portée %qT avant %<~%> n'est pas un nom de classe"
 
-#: cp/parser.c:5948 cp/parser.c:7860
+#: cp/parser.c:5951 cp/parser.c:7860
 #, gcc-internal-format
 msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgstr "%<~auto%> est uniquement disponible avec -std=c++14 ou -std=gnu++14"
 
-#: cp/parser.c:6059
+#: cp/parser.c:6062
 #, gcc-internal-format
 msgid "declaration of %<~%T%> as member of %qT"
 msgstr "déclaration de %<~%T%> comme membre de %qT"
 
-#: cp/parser.c:6074
+#: cp/parser.c:6077
 #, gcc-internal-format
 msgid "typedef-name %qD used as destructor declarator"
 msgstr "nom du typedef %qD utilisé comme déclaration de destructeur"
 
-#: cp/parser.c:6111 cp/parser.c:20249
+#: cp/parser.c:6114 cp/parser.c:20246
 #, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr "unqualified-id attendu"
 
-#: cp/parser.c:6220
+#: cp/parser.c:6223
 #, gcc-internal-format
 msgid "found %<:%> in nested-name-specifier, expected %<::%>"
 msgstr "%<:%> trouvé dans le spécificateur de nom imbriqué, %<::%> attendu"
 
-#: cp/parser.c:6288
+#: cp/parser.c:6291
 #, gcc-internal-format
 msgid "decltype evaluates to %qT, which is not a class or enumeration type"
 msgstr "decltype est évalué en %qT qui n'est ni une classe ni un type énuméré"
 
-#: cp/parser.c:6314
+#: cp/parser.c:6317
 #, gcc-internal-format
 msgid "function template-id %qD in nested-name-specifier"
 msgstr "template-id de la fonction %qD dans le spécificateur de nom imbriqué"
 
-#: cp/parser.c:6322
+#: cp/parser.c:6325
 #, gcc-internal-format
 msgid "variable template-id %qD in nested-name-specifier"
 msgstr "template-id de la variable %qD dans le spécificateur de nom imbriqué"
 
-#: cp/parser.c:6426 cp/typeck.c:2684 cp/typeck.c:2687 cp/typeck.c:2704
+#: cp/parser.c:6429 cp/typeck.c:2684 cp/typeck.c:2687 cp/typeck.c:2704
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD n'est pas un patron"
 
-#: cp/parser.c:6504
+#: cp/parser.c:6507
 #, gcc-internal-format
 msgid "expected nested-name-specifier"
 msgstr "spécificateur de nom imbriqué attendu"
 
-#: cp/parser.c:6711 cp/parser.c:8950
+#: cp/parser.c:6714 cp/parser.c:8950
 #, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr "les types ne peuvent pas être définis dans les transtypages"
 
-#: cp/parser.c:6797
+#: cp/parser.c:6800
 #, gcc-internal-format
 msgid "types may not be defined in a %<typeid%> expression"
 msgstr "les types ne peuvent pas être définis dans une expression %<typeid%>"
 
-#: cp/parser.c:6889
+#: cp/parser.c:6892
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "mauvais nombre d'arguments pour %<__builtin_addressof%>"
 
-#: cp/parser.c:6901 cp/pt.c:18416
+#: cp/parser.c:6904 cp/pt.c:18453
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "mauvais nombre d'arguments pour %<__builtin_launder%>"
 
-#: cp/parser.c:6995
+#: cp/parser.c:6998
 #, gcc-internal-format
 msgid "ISO C++ forbids compound-literals"
 msgstr "le C++ ISO interdit les littéraux composés"
 
-#: cp/parser.c:7054
+#: cp/parser.c:7057
 #, gcc-internal-format
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr "deux %<[%> consécutifs n'introduiront qu'un attribut"
@@ -44880,7 +44928,7 @@
 msgid "capture of non-variable %qE"
 msgstr "capture de %qE qui n'est pas une variable"
 
-#: cp/parser.c:10391 cp/parser.c:10401 cp/semantics.c:3453 cp/semantics.c:3465
+#: cp/parser.c:10391 cp/parser.c:10401 cp/semantics.c:3456 cp/semantics.c:3468
 #, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "%q#D déclaré ici"
@@ -44965,7 +45013,7 @@
 msgid "init-statement in selection statements only available with -std=c++17 or -std=gnu++17"
 msgstr "l'instruction init dans des instructions de sélection est uniquement disponible avec -std=c++17 ou -std=gnu++17"
 
-#: cp/parser.c:11546 cp/parser.c:28490
+#: cp/parser.c:11546 cp/parser.c:28487
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "instruction de sélection attendue"
@@ -44985,558 +45033,558 @@
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr "types différents pour « begin » et « end » de l'instruction %<for%> parcourant une plage: %qT et %qT"
 
-#: cp/parser.c:12250 cp/parser.c:28493
+#: cp/parser.c:12250 cp/parser.c:28490
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "instruction d'itération attendue"
 
-#: cp/parser.c:12298
+#: cp/parser.c:12297
 #, gcc-internal-format
 msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
 msgstr "les boucles %<for%> parcourant une plage sont uniquement disponibles avec -std=c++11 ou -std=gnu++11"
 
-#: cp/parser.c:12426
+#: cp/parser.c:12423
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr "%<goto%> dans une fonction %<constexpr%>"
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:12434
+#: cp/parser.c:12431
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "le C++ ISO interdit les gotos calculés"
 
-#: cp/parser.c:12447 cp/parser.c:28496
+#: cp/parser.c:12444 cp/parser.c:28493
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "instruction de saut attendue"
 
-#: cp/parser.c:12620 cp/parser.c:23584
+#: cp/parser.c:12617 cp/parser.c:23581
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "%<;%> superflu"
 
-#: cp/parser.c:12863
+#: cp/parser.c:12860
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr "%<__label__%> pas au début du bloc"
 
-#: cp/parser.c:13083
+#: cp/parser.c:13080
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr "non variable %qD dans la déclaration avec plus d'une déclaration contenant un type à remplacer"
 
-#: cp/parser.c:13103
+#: cp/parser.c:13100
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr "déduction incohérente pour %qT: %qT et puis %qT"
 
-#: cp/parser.c:13124
+#: cp/parser.c:13121
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr "mélanger des déclarations et des définitions de fonctions est interdit"
 
-#: cp/parser.c:13148
+#: cp/parser.c:13145
 #, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr "des types ne peuvent pas être définis dans la déclaration d'une instruction « for » parcourant une plage"
 
-#: cp/parser.c:13203
+#: cp/parser.c:13200
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr "initialisation dans une boucle %<for%> parcourant une plage"
 
-#: cp/parser.c:13206
+#: cp/parser.c:13203
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr "déclarations multiples dans une boucle %<for%> parcourant une plage"
 
-#: cp/parser.c:13257
+#: cp/parser.c:13254
 #, gcc-internal-format
 msgid "structured bindings only available with -std=c++17 or -std=gnu++17"
 msgstr "les liaisons structurées sont uniquement disponibles avec -std=c++17 ou -std=gnu++17"
 
-#: cp/parser.c:13306
+#: cp/parser.c:13303
 #, gcc-internal-format
 msgid "empty structured binding declaration"
 msgstr "déclaration de liaison structurée vide"
 
-#: cp/parser.c:13324
+#: cp/parser.c:13321
 #, gcc-internal-format
 msgid "invalid initializer for structured binding declaration"
 msgstr "initialisation invalide pour la déclaration de liaison structurée"
 
-#: cp/parser.c:13491
+#: cp/parser.c:13488
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr "%<friend%> utilisé en dehors d'une classe"
 
-#: cp/parser.c:13558
+#: cp/parser.c:13555
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr "%<auto%> a changé de signification en C++11; retirez-le"
 
-#: cp/parser.c:13594
+#: cp/parser.c:13591
 #, gcc-internal-format
 msgid "decl-specifier invalid in condition"
 msgstr "spécificateur de déclaration invalide dans une condition"
 
-#: cp/parser.c:13600
+#: cp/parser.c:13597
 #, gcc-internal-format
 msgid "%qD invalid in lambda"
 msgstr "%qD est invalide dans une lambda"
 
-#: cp/parser.c:13693
+#: cp/parser.c:13690
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "la définition de classe ne peut pas être déclarée comme amie"
 
-#: cp/parser.c:13763 cp/parser.c:24064
+#: cp/parser.c:13760 cp/parser.c:24061
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr "les patrons ne peuvent pas être %<virtual%>"
 
-#: cp/parser.c:13805
+#: cp/parser.c:13802
 #, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr "spécification de classe de liaison invalide"
 
-#: cp/parser.c:13909
+#: cp/parser.c:13906
 #, gcc-internal-format
 msgid "static_assert without a message only available with -std=c++17 or -std=gnu++17"
 msgstr "un static_assert sans message est uniquement disponible avec -std=c++17 ou -std=gnu++17"
 
-#: cp/parser.c:14111
+#: cp/parser.c:14108
 #, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr "les types ne peuvent pas être définis dans les expressions %<decltype%>"
 
-#: cp/parser.c:14264
+#: cp/parser.c:14261
 #, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr "les types ne peuvent pas être définis dans un conversion-type-id"
 
-#: cp/parser.c:14291
+#: cp/parser.c:14288
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "utilisation invalide de %<auto%> dans un opérateur de conversion"
 
-#: cp/parser.c:14295
+#: cp/parser.c:14292
 #, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr "un %<auto%> dans un opérateur de conversion d'un patron membre ne peut jamais être déduit"
 
-#: cp/parser.c:14379
+#: cp/parser.c:14376
 #, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr "seuls les constructeurs prennent des initialisions membres"
 
-#: cp/parser.c:14406
+#: cp/parser.c:14403
 #, gcc-internal-format
 msgid "cannot expand initializer for member %qD"
 msgstr "impossible de développer l'initialisation du membre %qD"
 
-#: cp/parser.c:14418 cp/pt.c:24255
+#: cp/parser.c:14415 cp/pt.c:24333
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "l'initialisation en mémoire pour %qD suit la délégation du constructeur"
 
-#: cp/parser.c:14430 cp/pt.c:24267
+#: cp/parser.c:14427 cp/pt.c:24345
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr "la délégation du constructeur suit l'initialisation en mémoire pour %qD"
 
-#: cp/parser.c:14482
+#: cp/parser.c:14479
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr "ancien style anachronique d'initialisation de classe de base"
 
-#: cp/parser.c:14552
+#: cp/parser.c:14549
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr "le mot-clé %<typename%> n'est pas permis dans ce contexte (une initialisation de membre qualifiée est implicitement un type)"
 
-#: cp/parser.c:14927
+#: cp/parser.c:14924
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr "mot-clé inattendu; enlevez l'espace entre les guillemets et l'identificateur du suffixe"
 
-#: cp/parser.c:14933
+#: cp/parser.c:14930
 #, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr "identificateur de suffixe attendu"
 
-#: cp/parser.c:14942
+#: cp/parser.c:14939
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr "une chaîne vide était attendue après le mot-clé %<operator%>"
 
-#: cp/parser.c:14948
+#: cp/parser.c:14945
 #, gcc-internal-format
 msgid "invalid encoding prefix in literal operator"
 msgstr "préfixe d'encodage invalide dans l'opérateur littéral"
 
-#: cp/parser.c:14975
+#: cp/parser.c:14972
 #, gcc-internal-format
 msgid "expected operator"
 msgstr "opérateur attendu"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:15020
+#: cp/parser.c:15017
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "le mot-clé %<export%> n'est pas implémenté et sera ignoré"
 
-#: cp/parser.c:15190
+#: cp/parser.c:15187
 #, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr "paramètre de type contraint invalide"
 
-#: cp/parser.c:15198
+#: cp/parser.c:15195
 #, gcc-internal-format
 msgid "cv-qualified type parameter"
 msgstr "paramètre de type qualifié avec CV"
 
-#: cp/parser.c:15283
+#: cp/parser.c:15280
 #, gcc-internal-format
 msgid "variadic constraint introduced without %<...%>"
 msgstr "contrainte variadique introduite sans %<...%>"
 
-#: cp/parser.c:15347
+#: cp/parser.c:15344
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "utilisation invalide de %<auto%> dans l'argument par défaut du patron"
 
-#: cp/parser.c:15582 cp/parser.c:15668 cp/parser.c:21694
+#: cp/parser.c:15579 cp/parser.c:15665 cp/parser.c:21691
 #, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "le paquet de paramètres %qD du patron ne peut pas avoir d'argument par défaut"
 
-#: cp/parser.c:15586 cp/parser.c:15672
+#: cp/parser.c:15583 cp/parser.c:15669
 #, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr "les paquets de paramètres des patrons ne peuvent pas avoir d'arguments par défaut"
 
-#: cp/parser.c:15738
+#: cp/parser.c:15735
 #, gcc-internal-format
 msgid "expected template-id"
 msgstr "template-id attendu"
 
-#: cp/parser.c:15798
+#: cp/parser.c:15795
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "%<<::%> ne peut pas être au début d'une liste d'arguments d'un patron"
 
-#: cp/parser.c:15802
+#: cp/parser.c:15799
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr "%<<:%> est une écriture alternative pour %<[%>. Insérer un espace entre %<<%> et %<::%>"
 
-#: cp/parser.c:15806
+#: cp/parser.c:15803
 #, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr "(si vous utilisez %<-fpermissive%> ou %<-std=c++11%> ou %<-std=gnu++11%> G++ acceptera votre code)"
 
-#: cp/parser.c:15924
+#: cp/parser.c:15921
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "erreur d'analyse dans la liste des arguments du patron"
 
 #. The name does not name a template.
-#: cp/parser.c:15992 cp/parser.c:16122 cp/parser.c:16337
+#: cp/parser.c:15989 cp/parser.c:16119 cp/parser.c:16334
 #, gcc-internal-format
 msgid "expected template-name"
 msgstr "nom de patron attendu"
 
 #. Explain what went wrong.
-#: cp/parser.c:16038
+#: cp/parser.c:16035
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr "%qD n'est pas un patron mais il est utilisé comme patron"
 
-#: cp/parser.c:16040
+#: cp/parser.c:16037
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr "utilisez %<%T::template %D%> pour indiquer que c'est un patron"
 
-#: cp/parser.c:16189
+#: cp/parser.c:16186
 #, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr "paquet de paramètres attendu avant %<...%>"
 
-#: cp/parser.c:16298 cp/parser.c:16316 cp/parser.c:16483
+#: cp/parser.c:16295 cp/parser.c:16313 cp/parser.c:16480
 #, gcc-internal-format
 msgid "expected template-argument"
 msgstr "argument de patron attendu"
 
-#: cp/parser.c:16458
+#: cp/parser.c:16455
 #, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr "argument de patron invalide car ce n'est pas un type"
 
-#: cp/parser.c:16585
+#: cp/parser.c:16582
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "une instanciation explicite ne doit pas utiliser le spécificateur %<inline%>"
 
-#: cp/parser.c:16589
+#: cp/parser.c:16586
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "une instanciation explicite ne doit pas utiliser le spécificateur %<constexpr%>"
 
-#: cp/parser.c:16648
+#: cp/parser.c:16645
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr "spécialisation de patron avec édition de liens C"
 
-#: cp/parser.c:16869
+#: cp/parser.c:16866
 #, gcc-internal-format
 msgid "expected type specifier"
 msgstr "spécificateur du type attendu"
 
-#: cp/parser.c:17053
+#: cp/parser.c:17050
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "l'utilisation de %<auto%> dans la déclaration d'un paramètre lambda est uniquement disponible avec -std=c++14 ou -std=gnu++14"
 
-#: cp/parser.c:17059
+#: cp/parser.c:17056
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "l'utilisation de %<auto%> dans une déclaration de paramètre est uniquement disponible avec -std=c++14 ou -std=gnu++14"
 
-#: cp/parser.c:17064
+#: cp/parser.c:17061
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -fconcepts"
 msgstr "l'utilisation de %<auto%> dans une déclaration de paramètre est uniquement disponible avec -fconcepts"
 
-#: cp/parser.c:17209
+#: cp/parser.c:17206
 #, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "template-id attendu pour le type"
 
-#: cp/parser.c:17278
+#: cp/parser.c:17275
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr "un nom de type attendu"
 
-#: cp/parser.c:17631
+#: cp/parser.c:17628
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr "un spécificateur de type élaboré pour un enum fortement typé ne peut pas utiliser le mot-clé %qD"
 
-#: cp/parser.c:17854
+#: cp/parser.c:17851
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "la déclaration %qD ne déclare rien du tout"
 
-#: cp/parser.c:17942
+#: cp/parser.c:17939
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "attributs ignorés sur un type non instancié"
 
-#: cp/parser.c:17946
+#: cp/parser.c:17943
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "attributs ignorés sur une instanciation de patron"
 
-#: cp/parser.c:17951
+#: cp/parser.c:17948
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr "attributs ignorés sur un spécificateur de type élaboré qui n'est pas une déclaration anticipée"
 
-#: cp/parser.c:18085
+#: cp/parser.c:18082
 #, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "%qD est un patron d'énumération"
 
-#: cp/parser.c:18096
+#: cp/parser.c:18093
 #, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr "%qD ne nomme pas une énumération dans %qT"
 
-#: cp/parser.c:18111
+#: cp/parser.c:18108
 #, gcc-internal-format
 msgid "unnamed scoped enum is not allowed"
 msgstr "un enum fortement typé sans nom n'est pas permis"
 
-#: cp/parser.c:18166
+#: cp/parser.c:18163
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "%<;%> ou %<{%> attendu"
 
-#: cp/parser.c:18215
+#: cp/parser.c:18212
 #, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "impossible d'ajouter une liste d'énumération à l'instanciation d'un patron"
 
-#: cp/parser.c:18229
+#: cp/parser.c:18226
 #, gcc-internal-format
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "le spécificateur de nom imbriqué %qT pour la déclaration d'un enum ne nomme pas une classe ou un espace de noms"
 
-#: cp/parser.c:18241 cp/parser.c:23070
+#: cp/parser.c:18238 cp/parser.c:23067
 #, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "déclaration de %qD dans l'espace de noms %qD lequel n'englobe pas %qD"
 
-#: cp/parser.c:18246 cp/parser.c:23075
+#: cp/parser.c:18243 cp/parser.c:23072
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "déclaration de %qD dans %qD lequel n'englobe pas %qD"
 
-#: cp/parser.c:18258 cp/parser.c:23089
+#: cp/parser.c:18255 cp/parser.c:23086
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr "qualification supplémentaire pas permise"
 
-#: cp/parser.c:18282
+#: cp/parser.c:18279
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "définition multiple de %q#T"
 
-#: cp/parser.c:18295
+#: cp/parser.c:18292
 #, gcc-internal-format
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "le C++ ISO interdit un enum vide et sans nom"
 
-#: cp/parser.c:18315
+#: cp/parser.c:18312
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr "spécificateur enum opaque sans nom"
 
-#: cp/parser.c:18318
+#: cp/parser.c:18315
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr "un spécificateur enum opaque doit utiliser un simple identificateur"
 
-#: cp/parser.c:18497
+#: cp/parser.c:18494
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD n'est pas un espace de noms"
 
-#: cp/parser.c:18503
+#: cp/parser.c:18500
 #, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "espace de noms attendu"
 
-#: cp/parser.c:18570
+#: cp/parser.c:18567
 #, gcc-internal-format
 msgid "nested namespace definitions only available with -std=c++17 or -std=gnu++17"
 msgstr "les définitions d'espace de noms imbriqués sont uniquement disponibles avec -std=c++17 ou -std=gnu++17"
 
-#: cp/parser.c:18578
+#: cp/parser.c:18575
 #, gcc-internal-format
 msgid "nested namespace name required"
 msgstr "nom d'espace de nom imbriqué attendu"
 
-#: cp/parser.c:18583
+#: cp/parser.c:18580
 #, gcc-internal-format
 msgid "namespace name required"
 msgstr "nom d'espace de nom attendu"
 
-#: cp/parser.c:18587
+#: cp/parser.c:18584
 #, gcc-internal-format
 msgid "a nested namespace definition cannot have attributes"
 msgstr "une définition d'espace de noms imbriqué ne peut pas avoir d'attribut"
 
-#: cp/parser.c:18590
+#: cp/parser.c:18587
 #, gcc-internal-format
 msgid "a nested namespace definition cannot be inline"
 msgstr "une définition d'un espace de noms imbriqué ne peut pas être « inline »"
 
-#: cp/parser.c:18597
+#: cp/parser.c:18594
 #, gcc-internal-format
 msgid "namespace %qD entered"
 msgstr "entrée dans l'espace de noms %qD"
 
-#: cp/parser.c:18652
+#: cp/parser.c:18649
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "la définition %<namespace%> n'est pas permise ici"
 
-#: cp/parser.c:18803
+#: cp/parser.c:18800
 #, gcc-internal-format
 msgid "pack expansion in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr "l'expansion de paquets dans une déclaration « using » est uniquement disponible avec -std=c++17 ou -std=gnu++17"
 
-#: cp/parser.c:18818
+#: cp/parser.c:18815
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "un template-id ne peut pas apparaître dans l'utilisation de la déclaration"
 
-#: cp/parser.c:18865
+#: cp/parser.c:18862
 #, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr "une liste séparée par des virgules dans une déclaration « using » est uniquement disponible avec -std=c++17 ou -std=gnu++17"
 
-#: cp/parser.c:18875
+#: cp/parser.c:18872
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr "les déclarations d'accès sont dépréciées en faveur des déclarations « using »; suggestion: ajoutez le mot-clé %<using%>"
 
 # alias template est un patron appliqué à un alias == patron d'alias
-#: cp/parser.c:18940
+#: cp/parser.c:18937
 #, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "les types ne peuvent pas être définis dans des déclarations de patrons d'alias"
 
-#: cp/parser.c:19106
+#: cp/parser.c:19103
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr "%<asm%> dans une fonction %<constexpr%>"
 
-#: cp/parser.c:19493
+#: cp/parser.c:19490
 #, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "une définition de fonction n'est pas permise ici"
 
-#: cp/parser.c:19504
+#: cp/parser.c:19501
 #, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr "une spécification asm n'est pas permise dans une définition de fonction"
 
-#: cp/parser.c:19508
+#: cp/parser.c:19505
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "des attributs ne sont pas permis dans une définition de fonction"
 
-#: cp/parser.c:19559
+#: cp/parser.c:19556
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr "constructeur, destructeur ou conversion de type attendu"
 
 #. Anything else is an error.
-#: cp/parser.c:19598 cp/parser.c:21906
+#: cp/parser.c:19595 cp/parser.c:21903
 #, gcc-internal-format
 msgid "expected initializer"
 msgstr "initialisation attendue"
 
-#: cp/parser.c:19679
+#: cp/parser.c:19676
 #, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "initialisation fournie pour une fonction"
 
-#: cp/parser.c:19713
+#: cp/parser.c:19710
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "les attributs après l'initialisation entre parenthèses sont ignorés"
 
-#: cp/parser.c:19727
+#: cp/parser.c:19724
 #, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr "la non fonction %qD est déclarée comme un patron implicite"
 
-#: cp/parser.c:20169
+#: cp/parser.c:20166
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "la limite du tableau n'est pas une constante entière"
 
-#: cp/parser.c:20295
+#: cp/parser.c:20292
 #, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr "impossible de définir le membre du typedef dépendant %qT"
 
-#: cp/parser.c:20299
+#: cp/parser.c:20296
 #, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "%<%T::%E%> n'est pas un type"
@@ -45545,17 +45593,17 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:20328
+#: cp/parser.c:20325
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr "déclarateur invalide"
 
-#: cp/parser.c:20336
+#: cp/parser.c:20333
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "utilisation invalide du constructeur comme patron"
 
-#: cp/parser.c:20338
+#: cp/parser.c:20335
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr "utilisez %<%T::%D%> au lieu de %<%T::%D%> pour nommer le constructeur dans un nom qualifié"
@@ -45562,383 +45610,383 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:20410
+#: cp/parser.c:20407
 #, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr "qualified-id dans une déclaration"
 
-#: cp/parser.c:20435
+#: cp/parser.c:20432
 #, gcc-internal-format
 msgid "expected declarator"
 msgstr "déclarateur attendu"
 
-#: cp/parser.c:20554
+#: cp/parser.c:20551
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD est un espace de noms"
 
-#: cp/parser.c:20556
+#: cp/parser.c:20553
 #, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "impossible de former un pointeur vers un membre de la non classe %q#T"
 
-#: cp/parser.c:20577
+#: cp/parser.c:20574
 #, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "opérateur pointeur attendu"
 
-#: cp/parser.c:20638
+#: cp/parser.c:20635
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "qualificatif CV dupliqué"
 
-#: cp/parser.c:20692
+#: cp/parser.c:20689
 #, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr "qualificatifs de référence multiples"
 
-#: cp/parser.c:20729
+#: cp/parser.c:20726
 #, gcc-internal-format
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr "%qE requiert %<-fgnu-tm%>"
 
-#: cp/parser.c:20787
+#: cp/parser.c:20784
 #, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "spécificateurs virtuels (virt-specifier) multiples"
 
-#: cp/parser.c:21025
+#: cp/parser.c:21022
 #, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr "arguments de patron manquants après %qT"
 
-#: cp/parser.c:21031 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2090
+#: cp/parser.c:21028 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2093
 #, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr "utilisation invalide de %qT"
 
-#: cp/parser.c:21052
+#: cp/parser.c:21049
 #, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "les types ne peuvent pas être définis dans les arguments du patron"
 
-#: cp/parser.c:21057
+#: cp/parser.c:21054
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "utilisation invalide de %<auto%> dans un argument de patron"
 
-#: cp/parser.c:21145
+#: cp/parser.c:21142
 #, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "spécificateur de type attendu"
 
-#: cp/parser.c:21429
+#: cp/parser.c:21426
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "%<,%> ou %<...%> attendu"
 
-#: cp/parser.c:21504
+#: cp/parser.c:21501
 #, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr "des types ne peuvent pas être définis dans des types de paramètres"
 
-#: cp/parser.c:21678
+#: cp/parser.c:21675
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "des arguments par défaut sont uniquement permis pour des paramètres de fonction"
 
-#: cp/parser.c:21696
+#: cp/parser.c:21693
 #, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "le paquet de paramètres %qD ne peut pas avoir d'argument par défaut"
 
-#: cp/parser.c:21702
+#: cp/parser.c:21699
 #, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr "le paquet de paramètres du patron ne peut pas avoir d'argument par défaut"
 
-#: cp/parser.c:21704
+#: cp/parser.c:21701
 #, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr "le paquet de paramètres ne peut pas avoir d'argument par défaut"
 
-#: cp/parser.c:22131
+#: cp/parser.c:22128
 #, gcc-internal-format
 msgid "C++ designated initializers only available with -std=c++2a or -std=gnu++2a"
 msgstr "les initialisations désignées du C++ sont uniquement disponibles avec -std=c++2a ou -std=gnu++2a"
 
-#: cp/parser.c:22151
+#: cp/parser.c:22148
 #, gcc-internal-format
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr "le C++ ISO ne permet pas des initialisations par désignation de GNU"
 
-#: cp/parser.c:22189
+#: cp/parser.c:22186
 #, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "le C++ ISO ne permet pas des initialisations par désignation du C99"
 
-#: cp/parser.c:22203
+#: cp/parser.c:22200
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr "soit toutes les instructions d'initialisation devraient être désignées ou aucune ne devrait l'être"
 
-#: cp/parser.c:22228
+#: cp/parser.c:22225
 #, gcc-internal-format
 msgid "%<...%> not allowed in designated initializer list"
 msgstr "%<...%> pas permis dans une liste d'initialisation par désignation"
 
-#: cp/parser.c:22266
+#: cp/parser.c:22263
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr "désignateur %<.%s%> utilisé plusieurs fois dans la même liste d'initialiseurs"
 
-#: cp/parser.c:22322 cp/parser.c:22448
+#: cp/parser.c:22319 cp/parser.c:22445
 #, gcc-internal-format
 msgid "expected class-name"
 msgstr "nom de classe attendu"
 
-#: cp/parser.c:22650
+#: cp/parser.c:22647
 #, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "%<;%> attendu après la définition de la classe"
 
-#: cp/parser.c:22653
+#: cp/parser.c:22650
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "%<;%> attendu après la définition de la structure"
 
-#: cp/parser.c:22656
+#: cp/parser.c:22653
 #, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "%<;%> attendu après la définition de l'union"
 
-#: cp/parser.c:23012
+#: cp/parser.c:23009
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "%<{%> ou %<:%> attendu"
 
-#: cp/parser.c:23023
+#: cp/parser.c:23020
 #, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "ne peut spécifier %<override%> pour une classe"
 
-#: cp/parser.c:23031
+#: cp/parser.c:23028
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr "la qualification globale du nom de la classe est invalide"
 
-#: cp/parser.c:23038
+#: cp/parser.c:23035
 #, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "le nom qualifié ne nomme pas une classe"
 
-#: cp/parser.c:23050
+#: cp/parser.c:23047
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr "le mot-clé %<template%> n'est pas permis dans class-head-name (NdT: nom de classe)"
 
-#: cp/parser.c:23056
+#: cp/parser.c:23053
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "nom de classe invalide dans la déclaration de %qD"
 
-#: cp/parser.c:23114
+#: cp/parser.c:23111
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "une spécialisation explicite doit être précédée par %<template <>%>"
 
-#: cp/parser.c:23146
+#: cp/parser.c:23143
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "le patron de fonction %qD est redéclaré comme un patron de classe"
 
-#: cp/parser.c:23182
+#: cp/parser.c:23179
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr "impossible de résoudre le type de typename"
 
-#: cp/parser.c:23241
+#: cp/parser.c:23238
 #, gcc-internal-format
 msgid "previous definition of %q#T"
 msgstr "définition précédente de %q#T"
 
-#: cp/parser.c:23331 cp/parser.c:28499
+#: cp/parser.c:23328 cp/parser.c:28496
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr "mot-clé de type classe (class ou struct) attendu"
 
-#: cp/parser.c:23355
+#: cp/parser.c:23352
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++17 or -std=gnu++17"
 msgstr "le C++ ISO interdit le mot-clé typename dans un paramètre de patron qui est un patron; utilisez -std=c++17 ou -std=gnu++17"
 
-#: cp/parser.c:23359
+#: cp/parser.c:23356
 #, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "%<class%> ou %<typename%> attendu"
 
-#: cp/parser.c:23605
+#: cp/parser.c:23602
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr "en C++03, le mot-clé class (ou struct) doit être utilisé lors de la déclaration d'un ami"
 
-#: cp/parser.c:23623
+#: cp/parser.c:23620
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "la déclaration amie ne nomme pas une classe ou une fonction"
 
-#: cp/parser.c:23641
+#: cp/parser.c:23638
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr "une classe de stockage sur un agrégat anonyme dans une classe n'est pas permis"
 
-#: cp/parser.c:23738
+#: cp/parser.c:23735
 #, gcc-internal-format
 msgid "default member initializers for bit-fields only available with -std=c++2a or -std=gnu++2a"
 msgstr "les initialiseurs de membre par défaut pour les champs de bits sont uniquement disponibles avec -std=c++2a ou -std=gnu++2a"
 
-#: cp/parser.c:23745
+#: cp/parser.c:23742
 #, gcc-internal-format
 msgid "default member initializer for unnamed bit-field"
 msgstr "initialiseur d'un membre par défaut pour un champ de bits sans nom"
 
-#: cp/parser.c:23758
+#: cp/parser.c:23755
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr "le C++ ISO autorise les attributs de champs de bits uniquement avant l'élément %<:%>"
 
-#: cp/parser.c:23903
+#: cp/parser.c:23900
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr "spécificateur pur sur une définition de fonction"
 
-#: cp/parser.c:23923
+#: cp/parser.c:23920
 #, gcc-internal-format
 msgid "extra %<;%> after in-class function definition"
 msgstr "%<;%> supplémentaire après la définition dans la classe"
 
-#: cp/parser.c:23970
+#: cp/parser.c:23967
 #, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr "%<,%> égarée à la fin de la déclaration du membre"
 
-#: cp/parser.c:23984
+#: cp/parser.c:23981
 #, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "%<;%> attendu à la fin de la déclaration du membre"
 
-#: cp/parser.c:24058
+#: cp/parser.c:24055
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr "spécificateur pur invalide (seul %<= 0%> est autorisé)"
 
-#: cp/parser.c:24093
+#: cp/parser.c:24090
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "une initialisation entre accolades n'est par permise ici"
 
-#: cp/parser.c:24223
+#: cp/parser.c:24220
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr "%<virtual%> spécifié plus d'une fois dans le spécificateur de base"
 
-#: cp/parser.c:24243
+#: cp/parser.c:24240
 #, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr "plus d'un spécificateur d'accès dans le spécificateur de base"
 
-#: cp/parser.c:24267
+#: cp/parser.c:24264
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "le mot-clé %<typename%> n'est pas permis en dehors des patrons"
 
-#: cp/parser.c:24270
+#: cp/parser.c:24267
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "le mot-clé %<typename%> n'est pas permis dans ce contexte (la classe de base est implicitement un type)"
 
-#: cp/parser.c:24364 cp/parser.c:24442
+#: cp/parser.c:24361 cp/parser.c:24439
 #, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "les types ne peuvent pas être définis dans une spécification d'exception"
 
-#: cp/parser.c:24450
+#: cp/parser.c:24447
 #, gcc-internal-format
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "le C++17 ISO n'autorise pas la spécification dynamique des exceptions"
 
-#: cp/parser.c:24456
+#: cp/parser.c:24453
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr "les spécifications dynamiques d'exceptions sont dépréciées en C++11"
 
-#: cp/parser.c:24500
+#: cp/parser.c:24497
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "utilisation invalide de %<auto%> dans une spécification d'exception"
 
-#: cp/parser.c:24539
+#: cp/parser.c:24536
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr "%<try%> dans une fonction %<constexpr%>"
 
-#: cp/parser.c:24650
+#: cp/parser.c:24647
 #, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr "des types ne peuvent pas être définis dans une déclaration d'exception"
 
 # Je ne suis pas sûr du tout de la signification de « scoped attribute token »…
-#: cp/parser.c:25203
+#: cp/parser.c:25200
 #, gcc-internal-format
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr "l'attribut de préfixe « using » est utilisé en même temps qu'un élément d'attribut agissant sur une portée"
 
-#: cp/parser.c:25217
+#: cp/parser.c:25214
 #, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr "un identificateur est attendu pour le nom d'attribut"
 
-#: cp/parser.c:25301
+#: cp/parser.c:25298
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr "l'attribut %<noreturn%> ne peut apparaître qu'une seule fois au plus dans la liste d'attributs"
 
-#: cp/parser.c:25305
+#: cp/parser.c:25302
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr "l'attribut %<deprecated%> ne peut apparaître qu'une seule fois au plus dans la liste d'attributs"
 
-#: cp/parser.c:25342
+#: cp/parser.c:25339
 #, gcc-internal-format
 msgid "expected attribute before %<...%>"
 msgstr "attribut attendu avant %<...%>"
 
-#: cp/parser.c:25403
+#: cp/parser.c:25400
 #, gcc-internal-format
 msgid "attribute using prefix only available with -std=c++17 or -std=gnu++17"
 msgstr "l'attribut de préfixe « using » est uniquement disponible avec -std=c++17 ou -std=gnu++17"
 
-#: cp/parser.c:25721
+#: cp/parser.c:25718
 #, gcc-internal-format
 msgid "%<requires%> only available with -fconcepts"
 msgstr "%<requires%> uniquement disponible avec -fconcepts"
 
-#: cp/parser.c:25753
+#: cp/parser.c:25750
 #, gcc-internal-format
 msgid "a requires expression cannot appear outside a template"
 msgstr "une expression « requires » ne peut pas apparaître en dehors d'un patron"
 
-#: cp/parser.c:26467
+#: cp/parser.c:26464
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr "la syntaxe %<template<>%> est requise pour spécialiser %<%T::%E%>"
 
-#: cp/parser.c:26472
+#: cp/parser.c:26469
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "déclaration invalide de %<%T::%E%>"
 
-#: cp/parser.c:26476
+#: cp/parser.c:26473
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "trop peu de listes de paramètres pour le patron"
@@ -45947,453 +45995,453 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:26483
+#: cp/parser.c:26480
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "trop de listes de paramètres pour le patron"
 
-#: cp/parser.c:26832
+#: cp/parser.c:26829
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "les valeurs nommées à retourner ne sont plus supportées"
 
-#: cp/parser.c:26991
+#: cp/parser.c:26988
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr "le patron de l'opérateur littéral %qD a une liste de paramètres invalide. On attendait un paquet d'arguments de type non patron tels que <char...> ou <typename CharT, CharT...>"
 
-#: cp/parser.c:26996
+#: cp/parser.c:26993
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr "le patron de l'opérateur littéral %qD a une liste de paramètres invalide. On attendait un paquet d'arguments de type non patron tel que <char...>"
 
-#: cp/parser.c:27066
+#: cp/parser.c:27063
 #, gcc-internal-format
 msgid "empty introduction-list"
 msgstr "liste d'instructions vide"
 
-#: cp/parser.c:27090
+#: cp/parser.c:27087
 #, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr "pas de concept correspondant pour l'introduction du patron"
 
-#: cp/parser.c:27112
+#: cp/parser.c:27109
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "déclaration invalide du patron membre dans la classe locale"
 
-#: cp/parser.c:27121
+#: cp/parser.c:27118
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "patron avec liaison C"
 
-#: cp/parser.c:27141
+#: cp/parser.c:27138
 #, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "spécialisation explicite invalide"
 
-#: cp/parser.c:27245
+#: cp/parser.c:27242
 #, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "déclaration de patron de %<typedef%>"
 
-#: cp/parser.c:27296
+#: cp/parser.c:27293
 #, gcc-internal-format
 msgid "a class template declaration must not declare anything else"
 msgstr "une déclaration de patron de classe ne doit rien déclarer d'autre"
 
-#: cp/parser.c:27342
+#: cp/parser.c:27339
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "une spécialisation explicite de patron ne peut pas avoir une classe de stockage"
 
-#: cp/parser.c:27650
+#: cp/parser.c:27647
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%<>>%> devrait être %<> >%> à l'intérieur d'une liste d'arguments de patron imbriqués"
 
-#: cp/parser.c:27663
+#: cp/parser.c:27660
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "le %<>>%> est faux, utilisez %<>%> pour terminer la liste d'arguments du patron"
 
-#: cp/parser.c:27958
+#: cp/parser.c:27955
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr "l'argument %<sizeof...%> doit être entouré de parenthèses"
 
-#: cp/parser.c:28118
+#: cp/parser.c:28115
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "utilisation invalide de %qD dans la spécification de la classe de liaison"
 
-#: cp/parser.c:28133
+#: cp/parser.c:28130
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> avant %qD"
 
-#: cp/parser.c:28267
+#: cp/parser.c:28264
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "le C++ ISO 1998 ne permet pas %<long long%>"
 
-#: cp/parser.c:28275
+#: cp/parser.c:28272
 #, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "%<__thread%> et %<thread_local%> sont tous les deux spécifiés"
 
-#: cp/parser.c:28280
+#: cp/parser.c:28277
 #, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "%qD dupliqué"
 
-#: cp/parser.c:28304
+#: cp/parser.c:28301
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "%qs dupliqué"
 
-#: cp/parser.c:28356
+#: cp/parser.c:28353
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "%<new%> attendu"
 
-#: cp/parser.c:28359
+#: cp/parser.c:28356
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "%<delete%> attendu"
 
-#: cp/parser.c:28362
+#: cp/parser.c:28359
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "%<return%> attendu"
 
-#: cp/parser.c:28368
+#: cp/parser.c:28365
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "%<extern%> attendu"
 
-#: cp/parser.c:28371
+#: cp/parser.c:28368
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "%<static_assert%> attendu"
 
-#: cp/parser.c:28374
+#: cp/parser.c:28371
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "%<decltype%> attendu"
 
-#: cp/parser.c:28377
+#: cp/parser.c:28374
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "%<operator%> attendu"
 
-#: cp/parser.c:28380
+#: cp/parser.c:28377
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "%<class%> attendu"
 
-#: cp/parser.c:28383
+#: cp/parser.c:28380
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "%<template%> attendu"
 
-#: cp/parser.c:28386
+#: cp/parser.c:28383
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "%<namespace%> attendu"
 
-#: cp/parser.c:28389
+#: cp/parser.c:28386
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "%<using%> attendu"
 
-#: cp/parser.c:28392
+#: cp/parser.c:28389
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "%<asm%> attendu"
 
-#: cp/parser.c:28395
+#: cp/parser.c:28392
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "%<try%> attendu"
 
-#: cp/parser.c:28398
+#: cp/parser.c:28395
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "%<catch%> attendu"
 
-#: cp/parser.c:28401
+#: cp/parser.c:28398
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "%<throw%> attendu"
 
-#: cp/parser.c:28404
+#: cp/parser.c:28401
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "%<__label__%> attendu"
 
-#: cp/parser.c:28407
+#: cp/parser.c:28404
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "%<@try%> attendu"
 
-#: cp/parser.c:28410
+#: cp/parser.c:28407
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "%<@synchronized%> attendu"
 
-#: cp/parser.c:28413
+#: cp/parser.c:28410
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "%<@throw%> attendu"
 
-#: cp/parser.c:28416
+#: cp/parser.c:28413
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "%<__transaction_atomic%> attendu"
 
-#: cp/parser.c:28419
+#: cp/parser.c:28416
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "%<__transaction_relaxed%> attendu"
 
-#: cp/parser.c:28451
+#: cp/parser.c:28448
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "%<::%> attendu"
 
-#: cp/parser.c:28463
+#: cp/parser.c:28460
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "%<...%> attendu"
 
-#: cp/parser.c:28466
+#: cp/parser.c:28463
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "%<*%> attendu"
 
-#: cp/parser.c:28469
+#: cp/parser.c:28466
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "%<~%> attendu"
 
-#: cp/parser.c:28475
+#: cp/parser.c:28472
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "%<;%> ou %<::%> attendu"
 
-#: cp/parser.c:28502
+#: cp/parser.c:28499
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "%<class%>, %<typename%> ou %<template%> attendu"
 
-#: cp/parser.c:28772
+#: cp/parser.c:28769
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "étiquette %qs utilisée en nommant %q#T"
 
-#: cp/parser.c:28777
+#: cp/parser.c:28774
 #, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "%q#T a été précédemment déclaré ici"
 
-#: cp/parser.c:28798
+#: cp/parser.c:28795
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD redéclaré avec un accès différent"
 
-#: cp/parser.c:28819
+#: cp/parser.c:28816
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "en C++98, %<template%> (afin de lever une ambigüité) est seulement permis à l'intérieur des patrons"
 
-#: cp/parser.c:29062
+#: cp/parser.c:29059
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "fin de fichier dans l'argument par défaut"
 
-#: cp/parser.c:29303 cp/parser.c:30620 cp/parser.c:30808
+#: cp/parser.c:29300 cp/parser.c:30617 cp/parser.c:30805
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "construction Objective-C++ %<@%D%> mal placée"
 
-#: cp/parser.c:29372
+#: cp/parser.c:29369
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr "récepteur de message objective-c++ attendu"
 
-#: cp/parser.c:29442
+#: cp/parser.c:29439
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr "un ou des argument(s) de message objective-c++ est/sont attendu(s)"
 
-#: cp/parser.c:29473
+#: cp/parser.c:29470
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "%<@encode%> doit spécifier un type comme un argument"
 
-#: cp/parser.c:29883
+#: cp/parser.c:29880
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "nom de sélecteur Objective-C++ invalide"
 
-#: cp/parser.c:29958 cp/parser.c:29976
+#: cp/parser.c:29955 cp/parser.c:29973
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr "une déclaration de méthode objective-c++ est attendue"
 
-#: cp/parser.c:29970 cp/parser.c:30035
+#: cp/parser.c:29967 cp/parser.c:30032
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "les attributs de méthodes doivent être spécifiés à la fin"
 
-#: cp/parser.c:30078
+#: cp/parser.c:30075
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr "%qs égaré entre des méthodes Objective-C++"
 
-#: cp/parser.c:30284 cp/parser.c:30291 cp/parser.c:30298
+#: cp/parser.c:30281 cp/parser.c:30288 cp/parser.c:30295
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "type invalide pour la variable d'instance"
 
-#: cp/parser.c:30413
+#: cp/parser.c:30410
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "identificateur attendu après %<@protocol%>"
 
-#: cp/parser.c:30585
+#: cp/parser.c:30582
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr "des attributs ne peuvent pas être spécifiés avant le mot-clé %<@%D%> en Objective-C++"
 
-#: cp/parser.c:30592
+#: cp/parser.c:30589
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "les attributs de préfixes sont ignorés avant %<@%D%>"
 
-#: cp/parser.c:30867 cp/parser.c:30874 cp/parser.c:30881
+#: cp/parser.c:30864 cp/parser.c:30871 cp/parser.c:30878
 #, gcc-internal-format
 msgid "invalid type for property"
 msgstr "type invalide pour une propriété"
 
-#: cp/parser.c:32011
+#: cp/parser.c:32008
 #, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr "l'expression %<wait%> doit être un nombre entier"
 
-#: cp/parser.c:32724
+#: cp/parser.c:32721
 #, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr "identificateur de réduction invalide"
 
-#: cp/parser.c:34911
+#: cp/parser.c:34908
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr "une initialisation entre parenthèses n'est pas permise dans une boucle %<for%> de OpenMP"
 
-#: cp/parser.c:35231 cp/pt.c:16392
+#: cp/parser.c:35228 cp/pt.c:16414
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "la variable d'itération %qD ne devrait pas être une réduction"
 
-#: cp/parser.c:35316
+#: cp/parser.c:35313
 #, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr "pas assez de boucles « for » à combiner"
 
-#: cp/parser.c:37521
+#: cp/parser.c:37518
 #, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr "clause d'initialisation invalide"
 
-#: cp/parser.c:37549
+#: cp/parser.c:37546
 #, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "expression id (arguments) attendue"
 
-#: cp/parser.c:37561
+#: cp/parser.c:37558
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr "un des arguments de l'appel de l'initialisation devrait être %<omp_priv%> ou %<&omp_priv%>"
 
-#: cp/parser.c:37662
+#: cp/parser.c:37659
 #, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr "des types ne peuvent pas être définis dans une liste de types de réductions"
 
-#: cp/parser.c:37682 cp/semantics.c:5405
+#: cp/parser.c:37679 cp/semantics.c:5408
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr "type arithmétique %qT prédéclaré dans %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:37687 cp/semantics.c:5414
+#: cp/parser.c:37684 cp/semantics.c:5417
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr "type tableau ou fonction %qT dans %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:37690 cp/pt.c:12944 cp/semantics.c:5420
+#: cp/parser.c:37687 cp/pt.c:12966 cp/semantics.c:5423
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr "type référence %qT dans %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:37693 cp/semantics.c:5426
+#: cp/parser.c:37690 cp/semantics.c:5429
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr "type %qT qualifié avec const, volatile ou __restrict dans %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:38047
+#: cp/parser.c:38044
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr "%<#pragma acc routine%> nomme un ensemble de surcharges"
 
-#: cp/parser.c:38057
+#: cp/parser.c:38054
 #, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr "%qD ne fait pas référence à une fonction à l'intérieur de l'espace de noms"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:38392
+#: cp/parser.c:38389
 #, gcc-internal-format
 msgid "atomic_cancel"
 msgstr "atomic_cancel"
 
-#: cp/parser.c:38435 cp/semantics.c:8575
+#: cp/parser.c:38432 cp/semantics.c:8578
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr "%<__transaction_relaxed%> sans avoir activé le support pour la mémoire transactionnelle"
 
-#: cp/parser.c:38437 cp/semantics.c:8577
+#: cp/parser.c:38434 cp/semantics.c:8580
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr "%<__transaction_atomic%> sans avoir activé le support pour la mémoire transactionnelle"
 
-#: cp/parser.c:38631
+#: cp/parser.c:38628
 #, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "rebut à la fin de %<#pragma GCC pch_preprocess%>"
 
-#: cp/parser.c:38927
+#: cp/parser.c:38924
 #, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "%<#pragma GCC ivdep%> doit être à l'intérieur d'une fonction"
 
-#: cp/parser.c:38959
+#: cp/parser.c:38956
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr "%<#pragma GCC unroll%> doit être à l'intérieur d'une fonction"
 
-#: cp/parser.c:39039
+#: cp/parser.c:39036
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "les optimisations inter-modules ne sont pas implémentées pour le C++"
 
-#: cp/parser.c:39295
+#: cp/parser.c:39292
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr "les patrons implicites ne peuvent pas être %<virtual%>"
 
-#: cp/parser.c:39351
+#: cp/parser.c:39348
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr "édition de liens %<extern \"C\"%> démarrée ici"
@@ -46480,7 +46528,7 @@
 msgid "specialization of %qD after instantiation"
 msgstr "spécialisation de %qD après instanciation"
 
-#: cp/pt.c:1954 cp/semantics.c:5274
+#: cp/pt.c:1954 cp/semantics.c:5277
 #, gcc-internal-format
 msgid "%s %#qD"
 msgstr "%s %#qD"
@@ -46646,107 +46694,107 @@
 msgid "argument to __integer_pack must be between 0 and %d"
 msgstr "l'argument de __integer_pack doit être compris entre 0 et %d"
 
-#: cp/pt.c:3942
+#: cp/pt.c:3955
 #, gcc-internal-format
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr "l'expansion de l'initialisation de base %qT ne contient pas de paquet de paramètres"
 
-#: cp/pt.c:4010
+#: cp/pt.c:4023
 #, gcc-internal-format
 msgid "expansion pattern %qT contains no argument packs"
 msgstr "le motif d'expansion %qT ne contient pas de paquet d'arguments"
 
-#: cp/pt.c:4012
+#: cp/pt.c:4025
 #, gcc-internal-format
 msgid "expansion pattern %qE contains no argument packs"
 msgstr "le motif d'expansion %qE ne contient pas de paquet d'arguments"
 
-#: cp/pt.c:4063
+#: cp/pt.c:4077
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr "les paquets de paramètres ne sont pas étendus avec %<...%>"
 
-#: cp/pt.c:4080 cp/pt.c:4835
+#: cp/pt.c:4094 cp/pt.c:4849
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
 
-#: cp/pt.c:4082
+#: cp/pt.c:4096
 #, gcc-internal-format
 msgid "        <anonymous>"
 msgstr "        <anonyme>"
 
-#: cp/pt.c:4208
+#: cp/pt.c:4222
 #, gcc-internal-format
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr "la déclaration du paramètre de patron %q+D masque le paramètre de patron"
 
-#: cp/pt.c:4211
+#: cp/pt.c:4225
 #, gcc-internal-format
 msgid "declaration of %q+#D shadows template parameter"
 msgstr "la déclaration de %q+#D masque un paramètre de patron"
 
-#: cp/pt.c:4213
+#: cp/pt.c:4227
 #, gcc-internal-format
 msgid "template parameter %qD declared here"
 msgstr "le paramètre de patron %qD est déclaré ici"
 
-#: cp/pt.c:4771
+#: cp/pt.c:4785
 #, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr "spécialisation du concept de variable %q#D"
 
-#: cp/pt.c:4830
+#: cp/pt.c:4844
 #, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr "les paramètres du patron ne peuvent pas être déduits dans la spécialisation partielle:"
 
-#: cp/pt.c:4854
+#: cp/pt.c:4868
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr "la spécialisation partielle %q+D ne spécialise aucun argument du patron; pour définir le patron primaire, retirez la liste d'arguments du patron"
 
-#: cp/pt.c:4858
+#: cp/pt.c:4872
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr "la spécialisation partielle %q+D ne spécialise aucun argument du patron et n'a pas plus de contrainte que le patron primaire; pour définir le patron primaire, retirez la liste d'arguments du patron"
 
-#: cp/pt.c:4862 cp/pt.c:4873
+#: cp/pt.c:4876 cp/pt.c:4887
 #, gcc-internal-format
 msgid "primary template here"
 msgstr "le patron primaire ici"
 
-#: cp/pt.c:4870
+#: cp/pt.c:4884
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr "la spécialisation partielle n'est pas plus spécialisée que le patron primaire car elle remplace des paramètres multiples par une expansion d'un paquet"
 
-#: cp/pt.c:4885
+#: cp/pt.c:4899
 #, gcc-internal-format
 msgid "partial specialization %qD is not more specialized than"
 msgstr "la spécialisation partielle de %qD n'est pas plus spécialisée que"
 
-#: cp/pt.c:4887
+#: cp/pt.c:4901
 #, gcc-internal-format
 msgid "primary template %qD"
 msgstr "le patron primaire %qD"
 
-#: cp/pt.c:4934
+#: cp/pt.c:4948
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr "l'argument %qE du paquet de paramètres doit être à la fin de la liste des arguments du patron"
 
-#: cp/pt.c:4937
+#: cp/pt.c:4951
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr "l'argument %qT du paquet de paramètres doit être à la fin de la liste des arguments du patron"
 
-#: cp/pt.c:4958
+#: cp/pt.c:4972
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr "l'argument %qE du patron implique des paramètres du patron"
 
-#: cp/pt.c:5004
+#: cp/pt.c:5018
 #, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
@@ -46753,17 +46801,17 @@
 msgstr[0] "le type %qT de l'argument %qE du patron dépend d'un paramètre du patron"
 msgstr[1] "le type %qT de l'argument %qE du patron dépend de paramètres du patron"
 
-#: cp/pt.c:5066
+#: cp/pt.c:5080
 #, gcc-internal-format
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "la déclaration de %qD rend ambigüe l'instanciation précédente du patron pour %qD"
 
-#: cp/pt.c:5070
+#: cp/pt.c:5084
 #, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "spécialisation partielle de %qD après l'instanciation de %qD"
 
-#: cp/pt.c:5247
+#: cp/pt.c:5261
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "pas d'argument par défaut pour %qD"
@@ -46771,47 +46819,47 @@
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5269
+#: cp/pt.c:5283
 #, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "le paquet de paramètres %q+D doit être à la fin de la liste des paramètres du patron"
 
-#: cp/pt.c:5305
+#: cp/pt.c:5319
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "les arguments par défaut du patron ne peuvent pas être utilisés dans la redéclaration d'un ami d'un patron d'une fonction"
 
-#: cp/pt.c:5308
+#: cp/pt.c:5322
 #, gcc-internal-format
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "les arguments par défaut du patron ne peuvent pas être utilisés dans les déclarations d'un ami d'un patron"
 
-#: cp/pt.c:5311
+#: cp/pt.c:5325
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without -std=c++11 or -std=gnu++11"
 msgstr "les arguments par défaut du patron ne peuvent pas être utilisés dans des patrons de fonctions sans -std=c++11 ou -std=gnu++11"
 
-#: cp/pt.c:5314
+#: cp/pt.c:5328
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr "les arguments par défaut du patron ne peuvent pas être utilisés dans des spécialisations partielles"
 
-#: cp/pt.c:5317 cp/pt.c:5375
+#: cp/pt.c:5331 cp/pt.c:5389
 #, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "argument par défaut pour le paramètre de patron pour la classe englobant %qD"
 
-#: cp/pt.c:5489
+#: cp/pt.c:5503
 #, gcc-internal-format
 msgid "template %qD declared"
 msgstr "patron %qD déclaré"
 
-#: cp/pt.c:5496
+#: cp/pt.c:5510
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "patron de classe sans nom"
 
-#: cp/pt.c:5504
+#: cp/pt.c:5518
 #, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr "le patron de membre %qD ne peut pas avoir de spécificateur virtuel (virt-specifier)"
@@ -46821,57 +46869,57 @@
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5526
+#: cp/pt.c:5540
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "déclaration de patron %qD invalide"
 
-#: cp/pt.c:5669
+#: cp/pt.c:5683
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "définition de patron d'un non patron %q#D"
 
-#: cp/pt.c:5712
+#: cp/pt.c:5726
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "on attendait %d niveaux de paramètres du patron pour %q#D mais on en a obtenu %d"
 
-#: cp/pt.c:5726
+#: cp/pt.c:5740
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "a obtenu %d paramètres de patron pour %q#D"
 
-#: cp/pt.c:5729
+#: cp/pt.c:5743
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "a obtenu %d paramètres de patron pour %q#T"
 
-#: cp/pt.c:5731
+#: cp/pt.c:5745
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  mais %d son requis"
 
-#: cp/pt.c:5752
+#: cp/pt.c:5766
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "les arguments du patron %qD ne correspondent pas à ceux du patron original %qD"
 
-#: cp/pt.c:5755
+#: cp/pt.c:5769
 #, gcc-internal-format
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "utilisez %<template<>%> pour une spécialisation explicite"
 
-#: cp/pt.c:5882
+#: cp/pt.c:5896
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT n'est pas un type de patron"
 
-#: cp/pt.c:5895
+#: cp/pt.c:5909
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "spécificateurs de patron pas spécifiés dans la déclaration de %qD"
 
-#: cp/pt.c:5906
+#: cp/pt.c:5920
 #, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
@@ -46878,7 +46926,7 @@
 msgstr[0] "redéclaré avec %d paramètre dans le patron"
 msgstr[1] "redéclaré avec %d paramètres dans le patron"
 
-#: cp/pt.c:5910
+#: cp/pt.c:5924
 #, gcc-internal-format
 msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
@@ -46885,12 +46933,12 @@
 msgstr[0] "la déclaration précédente %qD utilisait %d paramètre dans le patron"
 msgstr[1] "la déclaration précédente %qD utilisait %d paramètres dans le patron"
 
-#: cp/pt.c:5947
+#: cp/pt.c:5961
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "paramètre %q+#D du patron"
 
-#: cp/pt.c:5948
+#: cp/pt.c:5962
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "redéclaré ici comme %q#D"
@@ -46899,117 +46947,117 @@
 #.
 #. A template-parameter may not be given default arguments
 #. by two different declarations in the same scope.
-#: cp/pt.c:5958
+#: cp/pt.c:5972
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "redéfinition de l'argument par défaut pour %q#D"
 
-#: cp/pt.c:5960
+#: cp/pt.c:5974
 #, gcc-internal-format
 msgid "original definition appeared here"
 msgstr "la définition originale apparaît ici"
 
-#: cp/pt.c:5988
+#: cp/pt.c:6002
 #, gcc-internal-format
 msgid "redeclaration %q#D with different constraints"
 msgstr "redéclaration de %q#D avec des contraintes différentes"
 
-#: cp/pt.c:5991
+#: cp/pt.c:6005
 #, gcc-internal-format
 msgid "original declaration appeared here"
 msgstr "la déclaration originale apparaît ici"
 
-#: cp/pt.c:6250 cp/pt.c:6318
+#: cp/pt.c:6264 cp/pt.c:6332
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%qE n'est pas un argument de patron valide pour le type %qT"
 
-#: cp/pt.c:6253
+#: cp/pt.c:6267
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr "il doit être l'adresse d'une fonction avec une classe de liaison externe"
 
-#: cp/pt.c:6256
+#: cp/pt.c:6270
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr "il doit être le nom d'une fonction avec une classe de liaison externe"
 
-#: cp/pt.c:6268
+#: cp/pt.c:6282
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%qE n'est pas un argument de patron valable pour le type %qT car %qD n'a pas de classe de liaison"
 
-#: cp/pt.c:6272
+#: cp/pt.c:6286
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%qE n'est pas un argument de patron valable pour le type %qT car %qD n'a pas de classe de liaison externe"
 
-#: cp/pt.c:6321
+#: cp/pt.c:6335
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "il doit être un pointeur vers un membre de la forme %<&X::Y%>"
 
-#: cp/pt.c:6323
+#: cp/pt.c:6337
 #, gcc-internal-format
 msgid "because it is a member of %qT"
 msgstr "car il est un membre de %qT"
 
-#: cp/pt.c:6383
+#: cp/pt.c:6397
 #, gcc-internal-format
 msgid "  couldn't deduce template parameter %qD"
 msgstr "  n'a pu déduire le paramètre %qD du patron"
 
-#: cp/pt.c:6392
+#: cp/pt.c:6406
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr "  les types %qT et %qT ont des qualificatifs CV incompatibles"
 
-#: cp/pt.c:6401
+#: cp/pt.c:6415
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr "  types %qT et %qT non concordants"
 
-#: cp/pt.c:6410
+#: cp/pt.c:6424
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr "  le paramètre %qD du patron n'est pas un paquet de paramètres mais l'argument %qD en est un"
 
-#: cp/pt.c:6421
+#: cp/pt.c:6435
 #, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "  l'argument %qE du patron ne correspond pas à la constante %qE qui est un pointeur vers un membre"
 
-#: cp/pt.c:6431
+#: cp/pt.c:6445
 #, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr "  %qE n'est pas équivalent à %qE"
 
-#: cp/pt.c:6440
+#: cp/pt.c:6454
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr "  déduction du paquet de paramètres inconsistante entre %qT et %qT"
 
-#: cp/pt.c:6452
+#: cp/pt.c:6466
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr "  types déduits conflictuels pour le paramètre %qT (%qT et %qT)"
 
-#: cp/pt.c:6456
+#: cp/pt.c:6470
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr "  valeurs déduites conflictuelles pour le paramètre non type %qE (%qE et %qE)"
 
-#: cp/pt.c:6467
+#: cp/pt.c:6481
 #, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "  le type tableau %qT dimensionné par une variable n'est pas un argument de patron valable"
 
-#: cp/pt.c:6478
+#: cp/pt.c:6492
 #, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr "  le type fonction membre %qT n'est pas un argument de patron valable"
 
-#: cp/pt.c:6490
+#: cp/pt.c:6504
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
@@ -47016,292 +47064,292 @@
 msgstr[0] "  le candidat attend au moins %d argument, %d fourni(s)"
 msgstr[1] "  le candidat attend au moins %d arguments, %d fourni(s)"
 
-#: cp/pt.c:6521
+#: cp/pt.c:6535
 #, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "  ne peut convertir %qE (type %qT) vers le type %qT"
 
-#: cp/pt.c:6534
+#: cp/pt.c:6548
 #, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "  %qT est une classe de base ambigüe de %qT"
 
-#: cp/pt.c:6538
+#: cp/pt.c:6552
 #, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "  %qT n'est pas dérivé de %qT"
 
-#: cp/pt.c:6549
+#: cp/pt.c:6563
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr "  les paramètres du patron d'un argument de patron qui est lui-même un patron sont inconsistants avec les autres arguments déduits pour le patron"
 
-#: cp/pt.c:6559
+#: cp/pt.c:6573
 #, gcc-internal-format
 msgid "  can't deduce a template for %qT from non-template type %qT"
 msgstr "  impossible de déduire un patron pour %qT depuis le type non patron %qT"
 
-#: cp/pt.c:6569
+#: cp/pt.c:6583
 #, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
 msgstr "  l'argument de patron %qE ne correspond pas à %qE"
 
-#: cp/pt.c:6609
+#: cp/pt.c:6623
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "%qE n'est pas un argument de patron valable pour le type %qT car les chaînes littérales ne peuvent jamais être utilisées dans ce contexte"
 
-#: cp/pt.c:6758
+#: cp/pt.c:6772
 #, gcc-internal-format
 msgid "in template argument for type %qT"
 msgstr "dans l'argument de patron pour le type %qT"
 
-#: cp/pt.c:6772
+#: cp/pt.c:6786
 #, gcc-internal-format
 msgid "template argument %qE for type %qT not a constant integer"
 msgstr "l'argument de patron %qE pour le type %qT n'est pas un entier constant"
 
-#: cp/pt.c:6833
+#: cp/pt.c:6847
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qD n'est pas un argument de patron valable car %qD est une variable, pas une adresse d'une variable"
 
-#: cp/pt.c:6841
+#: cp/pt.c:6855
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qE n'est pas un argument de patron valable pour %qT car ce n'est pas l'adresse d'une variable"
 
-#: cp/pt.c:6857
+#: cp/pt.c:6871
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "%qE n'est pas un argument de patron valable pour le type %qT car %qE n'est pas une variable"
 
-#: cp/pt.c:6864
+#: cp/pt.c:6878
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr "%qE n'est pas un argument de patron valable de type %qT car %qD n'a pas une classe de liaison externe"
 
-#: cp/pt.c:6873
+#: cp/pt.c:6887
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE n'est pas un argument de patron valable pour le type %qT car %qD n'a pas de classe de liaison"
 
-#: cp/pt.c:6888
+#: cp/pt.c:6902
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument"
 msgstr "l'adresse de %qD n'est pas un argument de patron valable"
 
-#: cp/pt.c:6897
+#: cp/pt.c:6911
 #, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr "l'adresse du sous-objet %qT de %qD n'est pas un argument de patron valable"
 
-#: cp/pt.c:6904
+#: cp/pt.c:6918
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "l'adresse de %qD n'est pas un argument de patron valable car elle n'a pas une durée de stockage statique"
 
-#: cp/pt.c:6933
+#: cp/pt.c:6947
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "%qE n'est pas un argument de patron valable pour le type %qT à cause de conflits dans les qualificatifs CV"
 
-#: cp/pt.c:6941
+#: cp/pt.c:6955
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE n'est pas un argument de patron valable pour le type %qT car ce n'est pas une l-valeur"
 
-#: cp/pt.c:6959
+#: cp/pt.c:6973
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%q#D n'est pas un argument de patron valable pour le type %qT car une variable de référence n'a pas une adresse constante"
 
-#: cp/pt.c:6975
+#: cp/pt.c:6989
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an object with linkage"
 msgstr "%qE n'est pas un argument de patron valable pour le type %qT car ce n'est pas un objet avec une classe de liaison"
 
-#: cp/pt.c:6986
+#: cp/pt.c:7000
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because object %qD does not have linkage"
 msgstr "%qE n'est pas un argument de patron valable pour le type %qT car l'objet %qD n'a pas de classe de liaison"
 
-#: cp/pt.c:7036
+#: cp/pt.c:7050
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE n'est pas un argument de patron valable pour le type %qT car il est un pointeur"
 
-#: cp/pt.c:7038
+#: cp/pt.c:7052
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "essayez d'utiliser %qE à la place"
 
-#: cp/pt.c:7092
+#: cp/pt.c:7106
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE n'est pas un argument de patron valable pour le type %qT car il est du type %qT"
 
-#: cp/pt.c:7654
+#: cp/pt.c:7668
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "les attributs sur l'argument %qT du patron sont ignorés"
 
-#: cp/pt.c:7670
+#: cp/pt.c:7684
 #, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr "les attributs dans l'argument %qE du patron sont ignorés"
 
-#: cp/pt.c:7805
+#: cp/pt.c:7819
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "nom de classe injecté %qD utilisé comme argument de patron qui est lui-même un patron"
 
-#: cp/pt.c:7834
+#: cp/pt.c:7848
 #, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "utilisation invalide du destructeur %qE comme un type"
 
-#: cp/pt.c:7839
+#: cp/pt.c:7853
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "pour faire référence à un membre type d'un paramètre de patron, utilisez %<typename %E%>"
 
-#: cp/pt.c:7855 cp/pt.c:7877 cp/pt.c:7931
+#: cp/pt.c:7869 cp/pt.c:7891 cp/pt.c:7945
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "non concordance de type/valeur pour l'argument %d dans la liste des paramètres du patron de %qD"
 
-#: cp/pt.c:7860
+#: cp/pt.c:7874
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  on attendait une constante de type %qT, on a obtenu %qT"
 
-#: cp/pt.c:7865
+#: cp/pt.c:7879
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  on attendait un patron de classe, on a obtenu %qE"
 
-#: cp/pt.c:7868
+#: cp/pt.c:7882
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  on attendait un type, on a obtenu %qE"
 
-#: cp/pt.c:7882
+#: cp/pt.c:7896
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  on attendait un type, on a obtenu %qT"
 
-#: cp/pt.c:7885
+#: cp/pt.c:7899
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  on attendait un patron de classe, on a obtenu %qT"
 
-#: cp/pt.c:7935
+#: cp/pt.c:7949
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  on attendait un patron de type %qD, on a obtenu %qT"
 
-#: cp/pt.c:7949
+#: cp/pt.c:7963
 #, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "désaccord de contrainte à l'argument %d dans la liste des paramètres du patron pour %qD"
 
-#: cp/pt.c:7952
+#: cp/pt.c:7966
 #, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr "  on attendait %qD, on a obtenu %qD"
 
-#: cp/pt.c:8012
+#: cp/pt.c:8026
 #, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "impossible de convertir l'argument %qE du patron de %qT vers %qT"
 
-#: cp/pt.c:8149 cp/pt.c:8465
+#: cp/pt.c:8163 cp/pt.c:8479
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "l'argument %d du patron est invalide"
 
-#: cp/pt.c:8164 cp/pt.c:8298
+#: cp/pt.c:8178 cp/pt.c:8312
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "nombre erroné d'arguments du patron (%d, devrait être %d)"
 
-#: cp/pt.c:8294
+#: cp/pt.c:8308
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "nombre erroné d'arguments du patron (%d, devrait être au moins %d)"
 
-#: cp/pt.c:8303
+#: cp/pt.c:8317
 #, gcc-internal-format
 msgid "provided for %qD"
 msgstr "fournis pour %qD"
 
-#: cp/pt.c:8328
+#: cp/pt.c:8342
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr "argument d'expansion du paquet pour le paramètre non paquet %qD du patron d'alias %qD"
 
-#: cp/pt.c:8332
+#: cp/pt.c:8346
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "argument d'expansion du paquet pour le paramètre non paquet %qD du concept %qD"
 
-#: cp/pt.c:8431
+#: cp/pt.c:8445
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr "ainsi, toute instanciation avec un paquet de paramètres non vide serait mal formée"
 
-#: cp/pt.c:9054
+#: cp/pt.c:9068
 #, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%q#D n'est pas un patron de fonction"
 
-#: cp/pt.c:9221
+#: cp/pt.c:9235
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "type non patron %qT utilisé comme un patron"
 
-#: cp/pt.c:9223
+#: cp/pt.c:9237
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "pour la déclaration du patron %q+D"
 
-#: cp/pt.c:9346
+#: cp/pt.c:9360
 #, gcc-internal-format
 msgid "template constraint failure"
 msgstr "échec de la contrainte du patron"
 
-#: cp/pt.c:9697
+#: cp/pt.c:9718
 #, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr "utilisation du patron de variable invalide %qE"
 
-#: cp/pt.c:10125
+#: cp/pt.c:10148
 #, gcc-internal-format, gfc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr "la profondeur d'instanciation du patron excède le maximum qui est %d (utilisez -ftemplate-depth= pour augmenter le maximum)"
 
-#: cp/pt.c:11202
+#: cp/pt.c:11225
 #, gcc-internal-format
 msgid "flexible array member %qD in union"
 msgstr "membre tableau flexible %qD dans l'union"
 
-#: cp/pt.c:11691
+#: cp/pt.c:11713
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr "repli de l'expansion vide sur %O"
 
-#: cp/pt.c:12160
+#: cp/pt.c:12182
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr "les longueurs des paquets d'arguments sont en désaccord durant l'expansion de %qT"
 
-#: cp/pt.c:12163
+#: cp/pt.c:12185
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr "les longueurs des paquets d'arguments sont en désaccord durant l'expansion de %qE"
 
-#: cp/pt.c:12747
+#: cp/pt.c:12769
 #, gcc-internal-format
 msgid "  when instantiating default argument for call to %qD"
 msgstr "  lors de l'instanciation de l'argument par défaut pour l'appel à %qD"
@@ -47319,276 +47367,276 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:13708
+#: cp/pt.c:13730
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "la variable %qD a un type fonction"
 
-#: cp/pt.c:13881
+#: cp/pt.c:13903
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "type de paramètre %qT invalide"
 
-#: cp/pt.c:13883
+#: cp/pt.c:13905
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "dans la déclaration de %q+D"
 
-#: cp/pt.c:14001
+#: cp/pt.c:14023
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "fonction retournant un tableau"
 
-#: cp/pt.c:14003
+#: cp/pt.c:14025
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "fonction retournant une fonction"
 
-#: cp/pt.c:14043
+#: cp/pt.c:14065
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "création d'un pointeur vers la fonction membre d'un type non classe %qT"
 
-#: cp/pt.c:14637
+#: cp/pt.c:14659
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "formation d'une référence vers void"
 
-#: cp/pt.c:14639
+#: cp/pt.c:14661
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "formation d'un pointeur vers le type de référence %qT"
 
-#: cp/pt.c:14641
+#: cp/pt.c:14663
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "formation d'une référence vers le type de référence %qT"
 
-#: cp/pt.c:14654
+#: cp/pt.c:14676
 #, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "formation d'un pointer vers le type de fonction qualifié %qT"
 
-#: cp/pt.c:14657
+#: cp/pt.c:14679
 #, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "formation d'une référence vers le type de fonction qualifié %qT"
 
-#: cp/pt.c:14705
+#: cp/pt.c:14727
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "création d'un pointeur vers le membre d'un type non classe %qT"
 
-#: cp/pt.c:14711
+#: cp/pt.c:14733
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "création d'un pointeur vers le type de référence au membre %qT"
 
-#: cp/pt.c:14717
+#: cp/pt.c:14739
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "création d'un pointeur vers le membre de type void"
 
-#: cp/pt.c:14783
+#: cp/pt.c:14805
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "création d'un tableau de %qT"
 
-#: cp/pt.c:14816
+#: cp/pt.c:14838
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT n'est pas un type class, struct ou union"
 
-#: cp/pt.c:14853
+#: cp/pt.c:14875
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT est résolu en %qT qui n'est pas un type d'énumération"
 
-#: cp/pt.c:14861
+#: cp/pt.c:14883
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr "%qT est résolu en %qT qui n'est pas un type de classe"
 
-#: cp/pt.c:14925
+#: cp/pt.c:14947
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr "initialisation vide dans l'initialisation par capture de la fonction lambda"
 
-#: cp/pt.c:15000
+#: cp/pt.c:15022
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "utilisation de %qs dans le patron"
 
-#: cp/pt.c:15178
+#: cp/pt.c:15200
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "le type qualifié %qT ne correspond pas au nom du destructeur ~%qT"
 
-#: cp/pt.c:15193
+#: cp/pt.c:15215
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "le nom dépendant %qE est analysé comme un non type, mais son instanciation produit un type"
 
-#: cp/pt.c:15195
+#: cp/pt.c:15217
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "utilisez %<typename %E%> si un type est désiré"
 
-#: cp/pt.c:15394
+#: cp/pt.c:15416
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "utilisation du champ %qD invalide"
 
-#: cp/pt.c:15883 cp/pt.c:17386
+#: cp/pt.c:15905 cp/pt.c:17408
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "utilisation invalide de l'expression d'expansion d'un paquet"
 
-#: cp/pt.c:15887 cp/pt.c:17390
+#: cp/pt.c:15909 cp/pt.c:17412
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "utilisez %<...%> pour dérouler le paquet d'arguments"
 
-#: cp/pt.c:18334
+#: cp/pt.c:18371
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr "%qD n'a pas été déclaré dans cette portée et aucune déclaration a été trouvée par le recherche dépendant des arguments au point d'instanciation"
 
-#: cp/pt.c:18362
+#: cp/pt.c:18399
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr "les déclarations dans la base dépendante %qT ne sont pas trouvées par une recherche non qualifiée"
 
-#: cp/pt.c:18367
+#: cp/pt.c:18404
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "utilisez plutôt %<this->%D%>"
 
-#: cp/pt.c:18370
+#: cp/pt.c:18407
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "utilisez plutôt %<%T::%D%>"
 
-#: cp/pt.c:18375
+#: cp/pt.c:18412
 #, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "%qD déclaré ici, plus loin dans l'unité de traduction"
 
-#: cp/pt.c:18712
+#: cp/pt.c:18752
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT n'est pas une classe ou un espace de noms"
 
-#: cp/pt.c:18715
+#: cp/pt.c:18755
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD n'est pas une classe ou un espace de noms"
 
-#: cp/pt.c:19026
+#: cp/pt.c:19066
 #, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr "%qT est/utilise un type anonyme"
 
-#: cp/pt.c:19028
+#: cp/pt.c:19068
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "l'argument du patron pour %qD utilise le type local %qT"
 
-#: cp/pt.c:19038
+#: cp/pt.c:19078
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT est un type modifié par une variable"
 
-#: cp/pt.c:19053
+#: cp/pt.c:19093
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "l'expression intégrale %qE n'est pas une constante"
 
-#: cp/pt.c:19071
+#: cp/pt.c:19111
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  tentative d'instancier %qD"
 
-#: cp/pt.c:22972
+#: cp/pt.c:23050
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "instanciation de patron ambiguë pour %q#T"
 
-#: cp/pt.c:22974
+#: cp/pt.c:23052
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "instanciation de patron ambiguë pour %q#D"
 
-#: cp/pt.c:22980
+#: cp/pt.c:23058
 msgid "%s %#qS"
 msgstr "%s %#qS"
 
-#: cp/pt.c:23004 cp/pt.c:23091
+#: cp/pt.c:23082 cp/pt.c:23169
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "instanciation explicite du non patron %q#D"
 
-#: cp/pt.c:23023
+#: cp/pt.c:23101
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD n'est pas un membre de données statique d'un patron de classe"
 
-#: cp/pt.c:23029 cp/pt.c:23086
+#: cp/pt.c:23107 cp/pt.c:23164
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "aucun patron correspondant trouvé pour %qD"
 
-#: cp/pt.c:23034
+#: cp/pt.c:23112
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "le type %qT pour l'instanciation explicite %qD ne correspond pas au type déclaré %qT"
 
-#: cp/pt.c:23042
+#: cp/pt.c:23120
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "instanciation explicite de %q#D"
 
-#: cp/pt.c:23078
+#: cp/pt.c:23156
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "instanciation explicite dupliquée pour %q#D"
 
-#: cp/pt.c:23101 cp/pt.c:23187
+#: cp/pt.c:23179 cp/pt.c:23265
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "le C++ ISO 1998 interdit l'utilisation de %<extern%> sur des instanciations explicites"
 
-#: cp/pt.c:23106 cp/pt.c:23204
+#: cp/pt.c:23184 cp/pt.c:23282
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "classe de stockage %qD appliquée à l'instanciation du patron"
 
-#: cp/pt.c:23163
+#: cp/pt.c:23241
 #, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "instanciation explicite du patron non classe %qD"
 
-#: cp/pt.c:23165
+#: cp/pt.c:23243
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "instanciation explicite du type non patron %qT"
 
-#: cp/pt.c:23174
+#: cp/pt.c:23252
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "instanciation explicite de %q#T avant la définition de patron"
 
-#: cp/pt.c:23192
+#: cp/pt.c:23270
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "le C++ ISO interdit l'utilisation de %qE sur des instanciations explicites"
 
-#: cp/pt.c:23238
+#: cp/pt.c:23316
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "instanciation explicite dupliquée de %q#T"
 
-#: cp/pt.c:23536
+#: cp/pt.c:23614
 #, gcc-internal-format
 msgid "exception specification of %qD depends on itself"
 msgstr "la spécification d'exception %qD dépend d'elle-même"
@@ -47600,107 +47648,107 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:23842
+#: cp/pt.c:23920
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "instanciation explicite de %qD mais pas de définition disponible"
 
-#: cp/pt.c:24043
+#: cp/pt.c:24121
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr "la profondeur d'instanciation du patron excède le maximum de %d lors de l'instanciation de %q+D, peut-être via la génération de la table virtuelle (utilisez -ftemplate-depth= pour augmenter le maximum)"
 
-#: cp/pt.c:24418
+#: cp/pt.c:24496
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "le paramètre non type du patron est invalide"
 
-#: cp/pt.c:24420
+#: cp/pt.c:24498
 #, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T n'est pas un type valide pour un paramètre non type du patron"
 
-#: cp/pt.c:25723
+#: cp/pt.c:25802
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "le mot-clé %<template%> n'est pas permis dans declarator-id"
 
-#: cp/pt.c:25961
+#: cp/pt.c:26040
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr "la déduction à partir d'une liste d'initialisation entre accolades requiert %<#include <initializer_list>%>"
 
-#: cp/pt.c:26440
+#: cp/pt.c:26519
 #, gcc-internal-format
 msgid "non-class template %qT used without template arguments"
 msgstr "le patron non classe %qT est utilisé sans arguments de patron"
 
-#: cp/pt.c:26586
+#: cp/pt.c:26665
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr "impossible de déduire les arguments du patron pour l'initialisation par copie de %qT car il n'a pas de guides de déduction non explicites ou de constructeur déclaré par l'utilisateur"
 
-#: cp/pt.c:26593
+#: cp/pt.c:26672
 #, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "impossible de déduire les arguments du patron de %qT car il n'a pas de guides de déduction viables"
 
-#: cp/pt.c:26607
+#: cp/pt.c:26686
 #, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "la déduction des arguments du patron de classe a échoué:"
 
-#: cp/pt.c:26614
+#: cp/pt.c:26693
 #, gcc-internal-format
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "les guides de déduction explicites ne sont pas pris en compte pour l'initialisation par copie"
 
-#: cp/pt.c:26676
+#: cp/pt.c:26755
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr "l'initialisation par liste directe de %<auto%> requiert exactement un élément"
 
-#: cp/pt.c:26679
+#: cp/pt.c:26758
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr "pour la déduction de %<std::initializer_list%>, utilisez l'initialisation par liste copiée (c-à-d ajoutez %<=%> avant le %<{%>)"
 
-#: cp/pt.c:26711
+#: cp/pt.c:26790
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr "%qT en tant que type plutôt qu'un simple %<decltype(auto)%>"
 
-#: cp/pt.c:26746
+#: cp/pt.c:26825
 #, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "impossible de déduire le type de retour de la lambda à partir de %qE"
 
-#: cp/pt.c:26748
+#: cp/pt.c:26827
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "impossible de déduire %qT à partir de %qE"
 
-#: cp/pt.c:26781
+#: cp/pt.c:26860
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr "les indications de contraintes ne sont pas satisfaites"
 
-#: cp/pt.c:26785
+#: cp/pt.c:26864
 #, gcc-internal-format
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "l'initialisation déduite ne satisfait pas les indications de contraintes"
 
-#: cp/pt.c:26789
+#: cp/pt.c:26868
 #, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "le type retourné déduit ne satisfait pas les indications de contraintes"
 
-#: cp/pt.c:26793
+#: cp/pt.c:26872
 #, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "le type déduit pour l'expression ne satisfait pas les indications de contraintes"
 
-#: cp/pt.c:26912
+#: cp/pt.c:26991
 #, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr "utilisation invalide de %qT dans un argument de patron"
@@ -47755,77 +47803,77 @@
 msgid "cannot dynamic_cast %qE (of type %q#T) to type %q#T (%s)"
 msgstr "ne peut effectuer un dynamic_cast %qE (du type %q#T) vers le type %q#T (%s)"
 
-#: cp/search.c:240
+#: cp/search.c:243
 #, gcc-internal-format
 msgid "%qT is an ambiguous base of %qT"
 msgstr "%qT est une base ambiguë de %qT"
 
-#: cp/search.c:256
+#: cp/search.c:259
 #, gcc-internal-format
 msgid "%qT is an inaccessible base of %qT"
 msgstr "%qT est une base inaccessible de %qT"
 
-#: cp/search.c:1905
+#: cp/search.c:1908
 #, gcc-internal-format
 msgid "invalid covariant return type for %q#D"
 msgstr "type de retour covariant invalide pour %q#D"
 
-#: cp/search.c:1907 cp/search.c:1922 cp/search.c:1928 cp/search.c:1957
+#: cp/search.c:1910 cp/search.c:1925 cp/search.c:1931 cp/search.c:1960
 #, gcc-internal-format
 msgid "overridden function is %q#D"
 msgstr "la fonction surchargée est %q#D"
 
-#: cp/search.c:1920
+#: cp/search.c:1923
 #, gcc-internal-format
 msgid "invalid covariant return type for %q+#D"
 msgstr "type de retour covariant invalide pour %q+#D"
 
-#: cp/search.c:1926
+#: cp/search.c:1929
 #, gcc-internal-format
 msgid "conflicting return type specified for %q+#D"
 msgstr "types retournés conflictuels spécifiés pour %q+#D"
 
-#: cp/search.c:1942
+#: cp/search.c:1945
 #, gcc-internal-format
 msgid "looser throw specifier for %q+#F"
 msgstr "génération d'exception plus lâche pour %q+#F"
 
-#: cp/search.c:1944
+#: cp/search.c:1947
 #, gcc-internal-format
 msgid "overridden function is %q#F"
 msgstr "la fonction surchargée est %q#F"
 
-#: cp/search.c:1955
+#: cp/search.c:1958
 #, gcc-internal-format
 msgid "conflicting type attributes specified for %q+#D"
 msgstr "attributs de type conflictuels spécifiés pour %q+#D"
 
-#: cp/search.c:1972
+#: cp/search.c:1975
 #, gcc-internal-format
 msgid "%qD declared %<transaction_safe_dynamic%>"
 msgstr "%qD est déclaré %<transaction_safe_dynamic%>"
 
-#: cp/search.c:1974
+#: cp/search.c:1977
 #, gcc-internal-format
 msgid "overriding %qD declared %<transaction_safe%>"
 msgstr "dans la surcharge de %qD déclaré %<transaction_safe%>"
 
-#: cp/search.c:1981
+#: cp/search.c:1984
 #, gcc-internal-format
 msgid "deleted function %q+D overriding non-deleted function"
 msgstr "la fonction supprimée %q+D surcharge une fonction non supprimée"
 
-#: cp/search.c:1984 cp/search.c:1992 cp/search.c:2000
+#: cp/search.c:1987 cp/search.c:1995 cp/search.c:2003
 #, gcc-internal-format
 msgid "overridden function is %qD"
 msgstr "la fonction surchargée est %qD"
 
-#: cp/search.c:1989
+#: cp/search.c:1992
 #, gcc-internal-format
 msgid "non-deleted function %q+D overriding deleted function"
 msgstr "la fonction non supprimée %q+D surcharge la fonction supprimée"
 
-#: cp/search.c:1998
+#: cp/search.c:2001
 #, gcc-internal-format
 msgid "virtual function %q+D overriding final function"
 msgstr "la fonction virtuelle %q+D surcharge une fonction finale"
@@ -47832,12 +47880,12 @@
 
 #. A static member function cannot match an inherited
 #. virtual member function.
-#: cp/search.c:2082
+#: cp/search.c:2085
 #, gcc-internal-format
 msgid "%q+#D cannot be declared"
 msgstr "%q+#D ne peut pas être déclaré"
 
-#: cp/search.c:2083
+#: cp/search.c:2086
 #, gcc-internal-format
 msgid "  since %q+#D declared in base class"
 msgstr "  puisque %q+#D est déclaré dans la classe de base"
@@ -47877,576 +47925,593 @@
 msgid "invalid use of member %qD in static member function"
 msgstr "utilisation invalide du membre %qD dans une fonction membre statique"
 
-#: cp/semantics.c:2153
+#: cp/semantics.c:2156
 #, gcc-internal-format
 msgid "a statement expression is an insufficient context for overload resolution"
 msgstr "une expression-instruction est un contexte insuffisant pour la résolution d'une surcharge"
 
-#: cp/semantics.c:2540
+#: cp/semantics.c:2543
 #, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr "le destructeur n'accepte pas d'argument"
 
-#: cp/semantics.c:2622
+#: cp/semantics.c:2625
 #, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr "%<this%> n'est pas disponible pour les fonctions membres statiques"
 
-#: cp/semantics.c:2624
+#: cp/semantics.c:2627
 #, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr "utilisation invalide de %<this%> dans une fonction non membre"
 
-#: cp/semantics.c:2626
+#: cp/semantics.c:2629
 #, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr "utilisation invalide de %<this%> hors de toute fonction"
 
-#: cp/semantics.c:2648
+#: cp/semantics.c:2651
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "étendue de qualification invalide dans le nom du pseudo-destructeur"
 
-#: cp/semantics.c:2656 cp/typeck.c:2604
+#: cp/semantics.c:2659 cp/typeck.c:2604
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "le type qualifié %qT ne concorde pas avec le nom du destructeur ~%qT"
 
-#: cp/semantics.c:2678
+#: cp/semantics.c:2681
 #, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr "%qE n'est pas un type %qT"
 
-#: cp/semantics.c:2751
+#: cp/semantics.c:2754
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr "littéral composé du type non objet %qT"
 
-#: cp/semantics.c:2892
+#: cp/semantics.c:2895
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr "les paramètres de type du patron doivent utiliser le mot-clé %<class%> ou %<typename%>"
 
-#: cp/semantics.c:2942
+#: cp/semantics.c:2945
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr "utilisation invalide du type %qT comme valeur par défaut pour un paramètre de patron qui est lui-même un patron"
 
-#: cp/semantics.c:2945
+#: cp/semantics.c:2948
 #, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr "argument par défaut invalide pour un paramètre de patron qui est un patron"
 
-#: cp/semantics.c:2962
+#: cp/semantics.c:2965
 #, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr "définition de %q#T à l'intérieur d'une liste de paramètres de patron"
 
-#: cp/semantics.c:2993
+#: cp/semantics.c:2996
 #, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr "définition invalide du type qualifié %qT"
 
-#: cp/semantics.c:3263
+#: cp/semantics.c:3266
 #, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "spécification de classe de base invalide"
 
-#: cp/semantics.c:3423
+#: cp/semantics.c:3426
 #, gcc-internal-format
 msgid "cannot capture member %qD of anonymous union"
 msgstr "impossible de capturer le membre %qD d'une union anonyme"
 
-#: cp/semantics.c:3443 cp/semantics.c:9269
+#: cp/semantics.c:3446 cp/semantics.c:9272
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qD n'est pas capturé"
 
-#: cp/semantics.c:3448
+#: cp/semantics.c:3451
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr "la lambda n'a pas de capture par défaut"
 
-#: cp/semantics.c:3450
+#: cp/semantics.c:3453
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr "la lambda dans la classe locale %q+T ne sait pas capturer des variables du contexte englobant"
 
-#: cp/semantics.c:3462
+#: cp/semantics.c:3465
 #, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr "utilisation d'une variable locale avec un stockage automatique dans la fonction contenante"
 
-#: cp/semantics.c:3464
+#: cp/semantics.c:3467
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr "utilisation d'un paramètre dans la fonction contenante"
 
-#: cp/semantics.c:3596
+#: cp/semantics.c:3599
 #, gcc-internal-format
 msgid "use of parameter outside function body"
 msgstr "utilisation du paramètre en dehors du corps de la fonction"
 
-#: cp/semantics.c:3606
+#: cp/semantics.c:3609
 #, gcc-internal-format
 msgid "missing template arguments"
 msgstr "arguments de patron manquants"
 
-#: cp/semantics.c:3633
+#: cp/semantics.c:3636
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr "le paramètre %qD du patron, du type %qT, n'est pas permis dans une expression constante intégrale parce qu'il n'est pas d'un type intégral ou énuméré"
 
-#: cp/semantics.c:3664
+#: cp/semantics.c:3667
 #, gcc-internal-format
 msgid "use of namespace %qD as expression"
 msgstr "utilisation de l'espace de noms %qD comme expression"
 
-#: cp/semantics.c:3669
+#: cp/semantics.c:3672
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr "utilisation du patron de classe %qT comme expression"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:3675
+#: cp/semantics.c:3678
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "l'accès au membre %qD est ambigu dans un réseau d'héritages multiples"
 
-#: cp/semantics.c:3702
+#: cp/semantics.c:3705
 #, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "%qD ne peut pas apparaître dans une expression constante"
 
-#: cp/semantics.c:3841
+#: cp/semantics.c:3844
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "le type de %qE est inconnu"
 
-#: cp/semantics.c:3870
+#: cp/semantics.c:3873
 #, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr "%qT n'est pas un type énuméré"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4009
+#: cp/semantics.c:4012
 #, gcc-internal-format
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr "Le paquet de paramètres __bases est uniquement valable dans la déclaration d'un patron"
 
-#: cp/semantics.c:4038
+#: cp/semantics.c:4041
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr "impossible d'appliquer %<offsetof%> au destructeur %<~%T%>"
 
-#: cp/semantics.c:4052
+#: cp/semantics.c:4055
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "impossible d'appliquer %<offsetof%> à la fonction membre %qD"
 
-#: cp/semantics.c:4056
+#: cp/semantics.c:4059
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function"
 msgstr "impossible d'appliquer %<offsetof%> à la fonction membre"
 
-#: cp/semantics.c:4061
+#: cp/semantics.c:4064
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr "impossible d'appliquer %<offsetof%> à un énumérateur %qD"
 
-#: cp/semantics.c:4072
+#: cp/semantics.c:4075
 #, gcc-internal-format
 msgid "offsetof within non-standard-layout type %qT is conditionally-supported"
 msgstr "l'utilisation de offsetof à l'intérieur du type %qT (qui ne respecte pas l'agencement standard) est supporté conditionnellement"
 
-#: cp/semantics.c:4583 cp/semantics.c:6069 cp/semantics.c:6140
-#: cp/semantics.c:6183 cp/semantics.c:6533 cp/semantics.c:6632
-#: cp/semantics.c:6775
+#: cp/semantics.c:4586 cp/semantics.c:6072 cp/semantics.c:6143
+#: cp/semantics.c:6186 cp/semantics.c:6536 cp/semantics.c:6635
+#: cp/semantics.c:6778
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr "%<this%> est autorisé dans OpenMP uniquement dans les clauses %<declare simd%>"
 
-#: cp/semantics.c:5271
+#: cp/semantics.c:5274
 #, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr "la recherche de la réduction définie par l'utilisateur est ambiguë"
 
-#: cp/semantics.c:5544
+#: cp/semantics.c:5547
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr "%qE dans la clause %<reduction%> est un tableau de taille nulle"
 
-#: cp/semantics.c:5592
+#: cp/semantics.c:5595
 #, gcc-internal-format
 msgid "%qE has const type for %<reduction%>"
 msgstr "%qE a le type const pour %<reduction%>"
 
-#: cp/semantics.c:5707
+#: cp/semantics.c:5710
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr "réduction définie par l'utilisateur avec une initialisation du constructeur pour la classe de base %qT"
 
-#: cp/semantics.c:5941
+#: cp/semantics.c:5944
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr "la clause linéaire avec le modificateur %qs est appliquée à la variable non référence ayant le type %qT"
 
-#: cp/semantics.c:5955
+#: cp/semantics.c:5958
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr "clause linéaire appliquée à la variable non entière non pointeur ayant le type %qT"
 
-#: cp/semantics.c:5977
+#: cp/semantics.c:5980
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr "l'expression du pas de « linear » doit être un entier"
 
-#: cp/semantics.c:6080
+#: cp/semantics.c:6083
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD n'est pas une variable dans la clause %qs"
 
-#: cp/semantics.c:6152
+#: cp/semantics.c:6155
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "%qD n'est pas une variable dans la clause %<firstprivate%>"
 
-#: cp/semantics.c:6195
+#: cp/semantics.c:6198
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "%qD n'est pas une variable dans la clause %<lastprivate%>"
 
-#: cp/semantics.c:6240
+#: cp/semantics.c:6243
 #, gcc-internal-format
 msgid "%<gang%> static expression must be integral"
 msgstr "l'expression statique %<gang%> doit être un entier"
 
-#: cp/semantics.c:6254
+#: cp/semantics.c:6257
 #, gcc-internal-format
 msgid "%<gang%> static value must be positive"
 msgstr "la valeur statique de %<gang%> doit être positive"
 
-#: cp/semantics.c:6288
+#: cp/semantics.c:6291
 #, gcc-internal-format
 msgid "%<gang%> num expression must be integral"
 msgstr "l'expression numérique de %<gang%> doit être un entier"
 
-#: cp/semantics.c:6291
+#: cp/semantics.c:6294
 #, gcc-internal-format
 msgid "%<vector%> length expression must be integral"
 msgstr "l'expression de longueur de %<vector%> doit être un entier"
 
-#: cp/semantics.c:6295
+#: cp/semantics.c:6298
 #, gcc-internal-format
 msgid "%<worker%> num expression must be integral"
 msgstr "l'expression numérique de %<worker%> doit être un entier"
 
-#: cp/semantics.c:6317
+#: cp/semantics.c:6320
 #, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr "la valeur numérique de %<gang%> doit être positive"
 
-#: cp/semantics.c:6321
+#: cp/semantics.c:6324
 #, gcc-internal-format
 msgid "%<vector%> length value must be positive"
 msgstr "la valeur de longueur de %<vector%> doit être positive"
 
-#: cp/semantics.c:6326
+#: cp/semantics.c:6329
 #, gcc-internal-format
 msgid "%<worker%> num value must be positive"
 msgstr "la valeur numérique de %<worker%> doit être positive"
 
-#: cp/semantics.c:6376
+#: cp/semantics.c:6379
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr "l'expression de taille des tranches d'ordonnancement doit être un entier"
 
-#: cp/semantics.c:6406
+#: cp/semantics.c:6409
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr "l'expression de longueur de %qs doit être un entier"
 
-#: cp/semantics.c:6419
+#: cp/semantics.c:6422
 #, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "l'expression de longueur %qs doit être une expression entière constante positive"
 
-#: cp/semantics.c:6438
+#: cp/semantics.c:6441
 #, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr "l'expression de %<async%> doit être un entier"
 
-#: cp/semantics.c:6466
+#: cp/semantics.c:6469
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr "l'expression de %<thread_limit%> doit être un entier"
 
-#: cp/semantics.c:6495
+#: cp/semantics.c:6498
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr "l'identifiant de %<device%> doit être entier"
 
-#: cp/semantics.c:6516
+#: cp/semantics.c:6519
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr "l'expression de la taille des tranches de %<dist_schedule%> doit être un entier"
 
-#: cp/semantics.c:6543
+#: cp/semantics.c:6546
 #, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qD n'est pas une variable dans la clause %<aligned%>"
 
-#: cp/semantics.c:6557
+#: cp/semantics.c:6560
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr "%qE dans la clause %<aligned%> n'est ni un pointeur ni un tableau ni une référence vers un pointeur ou un tableau"
 
-#: cp/semantics.c:6563
+#: cp/semantics.c:6566
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr "%qD apparaît plus d'une fois dans les clauses %<aligned%>"
 
-#: cp/semantics.c:6576
+#: cp/semantics.c:6579
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr "l'expression d'alignement de la clause %<aligned%> doit être un entier"
 
-#: cp/semantics.c:6625
+#: cp/semantics.c:6628
 #, gcc-internal-format
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr "%qD n'est pas une variable dans la clause %<depend%>"
 
-#: cp/semantics.c:6910
+#: cp/semantics.c:6913
 #, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr "patron %qE dans la clause %qs"
 
-#: cp/semantics.c:6914
+#: cp/semantics.c:6917
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr "nom de fonction surchargée %qE dans la clause %qs"
 
-#: cp/semantics.c:6979
+#: cp/semantics.c:6982
 #, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr "l'expression de %<grainsize%> doit être un entier"
 
-#: cp/semantics.c:7008
+#: cp/semantics.c:7011
 #, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr "l'expression de %<priority%> doit être un entier"
 
-#: cp/semantics.c:7037
+#: cp/semantics.c:7040
 #, gcc-internal-format
 msgid "%<num_tasks%> expression must be integral"
 msgstr "l'expression de %<num_tasks%> doit être un entier"
 
-#: cp/semantics.c:7066
+#: cp/semantics.c:7069
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr "la variable %qs n'est ni un pointeur ni un tableau ni une référence à un pointeur ou un tableau"
 
-#: cp/semantics.c:7105
+#: cp/semantics.c:7108
 #, gcc-internal-format
 msgid "%<tile%> argument needs integral type"
 msgstr "l'argument de %<tile%> doit être de type entier"
 
-#: cp/semantics.c:7524
+#: cp/semantics.c:7527
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr "%<threadprivate%> %qD n'est pas un fichier, un espace de noms ou une variable déclarée dans un bloc"
 
-#: cp/semantics.c:7538
+#: cp/semantics.c:7541
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "la directive %<threadprivate%> %qE n'est pas dans la définition de %qT"
 
-#: cp/semantics.c:7743
+#: cp/semantics.c:7746
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr "la différence entre %qE et %qD n'est pas un type entier"
 
-#: cp/semantics.c:8171
+#: cp/semantics.c:8174
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr "%<#pragma omp simd%> utilisé avec la variable d'itération de classe %qE"
 
-#: cp/semantics.c:8398 cp/semantics.c:8408
+#: cp/semantics.c:8401 cp/semantics.c:8411
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr "%<#pragma omp atomic update%> utilise deux expressions différentes pour la mémoire"
 
-#: cp/semantics.c:8702
+#: cp/semantics.c:8705
 #, gcc-internal-format
 msgid "static assertion failed"
 msgstr "l'assertion statique a échoué"
 
-#: cp/semantics.c:8704
+#: cp/semantics.c:8707
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr "l'assertion statique a échoué: %s"
 
-#: cp/semantics.c:8709
+#: cp/semantics.c:8712
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "condition non constante pour l'assertion statique"
 
-#: cp/semantics.c:8739
+#: cp/semantics.c:8742
 #, gcc-internal-format
 msgid "argument to decltype must be an expression"
 msgstr "l'argument de decltype doit être une expression"
 
-#: cp/semantics.c:8767
+#: cp/semantics.c:8770
 #, gcc-internal-format
 msgid "decltype cannot resolve address of overloaded function"
 msgstr "decltype ne sait pas résoudre l'adresse d'une fonction surchargée"
 
-#: cp/semantics.c:9308
+#: cp/semantics.c:9311
 #, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "l'opérande de l'expression fold n'a aucun paquet de paramètres non déroulé"
 
-#: cp/semantics.c:9361
+#: cp/semantics.c:9364
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "les deux arguments dans le fold binaire ont des paquets de paramètres non déroulés"
 
-#: cp/semantics.c:9363
+#: cp/semantics.c:9366
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr "aucun paquet de paramètres non déroulés dans le fold binaire"
 
-#: cp/semantics.c:9381
+#: cp/semantics.c:9384
 #, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "l'argument de %<__builtin_launder%> n'est pas un pointeur"
 
-#: cp/tree.c:1276
+#: cp/tree.c:1295
 #, gcc-internal-format
 msgid "%qV qualifiers cannot be applied to %qT"
 msgstr "les qualificatifs %qV ne peuvent pas être appliqués à %qT"
 
-#: cp/tree.c:1788
+#: cp/tree.c:1807
 #, gcc-internal-format
 msgid "lambda-expression in a constant expression"
 msgstr "expression lambda dans une expression constante"
 
-#: cp/tree.c:1792
+#: cp/tree.c:1811
 #, gcc-internal-format
 msgid "statement-expression in a constant expression"
 msgstr "expression instruction dans une expression constante"
 
-#: cp/tree.c:4050
+#: cp/tree.c:4083
 #, gcc-internal-format
-msgid "the calling convention for %qT changes in -fabi-version=12 (GCC 8)"
+msgid "-fabi-version=13 (GCC 8.2) fixes the calling convention for %qT, which was accidentally changed in 8.1"
+msgstr ""
+
+#: cp/tree.c:4087
+#, gcc-internal-format
+msgid "-fabi-version=12 (GCC 8.1) accidentally changes the calling convention for %qT"
+msgstr ""
+
+#: cp/tree.c:4090
+#, fuzzy, gcc-internal-format
+#| msgid "  declared here"
+msgid " declared here"
+msgstr "  déclaré ici"
+
+#: cp/tree.c:4094
+#, fuzzy, gcc-internal-format
+#| msgid "the calling convention for %qT changes in -fabi-version=12 (GCC 8)"
+msgid "the calling convention for %qT changes in -fabi-version=13 (GCC 8.2)"
 msgstr "la convention d'appel pour %qT change avec -fabi-version=12 (GCC 8)"
 
-#: cp/tree.c:4055
+#: cp/tree.c:4096
 #, gcc-internal-format
 msgid " because all of its copy and move constructors are deleted"
 msgstr " car tous ses constructeurs par copie et déplacement sont supprimés"
 
-#: cp/tree.c:4416
+#: cp/tree.c:4464
 #, gcc-internal-format
 msgid "%qE attribute applied to %qD with void return type"
 msgstr "attribut %qE appliqué à %qD avec un type de retour void"
 
-#: cp/tree.c:4423
+#: cp/tree.c:4471
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr "l'attribut %qE peut uniquement être appliqué aux fonctions ou aux classes ou aux types énumérés"
 
-#: cp/tree.c:4475
+#: cp/tree.c:4523
 #, gcc-internal-format
 msgid "requested init_priority is not an integer constant"
 msgstr "le init_priority demandé n'est pas une constante entière"
 
-#: cp/tree.c:4497
+#: cp/tree.c:4545
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr "l'attribut %qE peut uniquement être utilisé sur les définitions dans la portée du fichier d'objets de type classe"
 
-#: cp/tree.c:4505
+#: cp/tree.c:4553
 #, gcc-internal-format
 msgid "requested init_priority is out of range"
 msgstr "le init_priority demandé est hors limite"
 
-#: cp/tree.c:4515
+#: cp/tree.c:4563
 #, gcc-internal-format
 msgid "requested init_priority is reserved for internal use"
 msgstr "le init_priority demandé est réservé pour un usage interne"
 
-#: cp/tree.c:4526
+#: cp/tree.c:4574
 #, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr "l'attribut %qE n'est pas supporté sur cette plate-forme"
 
-#: cp/tree.c:4553
+#: cp/tree.c:4601
 #, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %qE"
 msgstr "la redéclaration de %qD ajoute l'étiquette d'ABI %qE"
 
-#: cp/tree.c:4573
+#: cp/tree.c:4621
 #, gcc-internal-format
 msgid "the %qE attribute requires arguments"
 msgstr "l'attribut %qE requiert des arguments"
 
-#: cp/tree.c:4584
+#: cp/tree.c:4632
 #, gcc-internal-format
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "les arguments de l'attribut %qE doivent être des chaînes littérales étroites"
 
-#: cp/tree.c:4597 cp/tree.c:4610
+#: cp/tree.c:4645 cp/tree.c:4658
 #, gcc-internal-format
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "les arguments de l'attribut %qE doivent contenir des identificateurs valables"
 
-#: cp/tree.c:4599
+#: cp/tree.c:4647
 #, gcc-internal-format
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "%<%c%> n'est pas un premier caractère valable pour un identificateur"
 
-#: cp/tree.c:4612
+#: cp/tree.c:4660
 #, gcc-internal-format
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "%<%c%> n'est pas un caractère valable dans un identificateur"
 
-#: cp/tree.c:4636
+#: cp/tree.c:4684
 #, gcc-internal-format
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "attribut %qE appliqué au type %qT qui n'est ni une classe ni un enum"
 
-#: cp/tree.c:4642
+#: cp/tree.c:4690
 #, gcc-internal-format
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "attribut %qE appliqué à %qT après sa définition"
 
-#: cp/tree.c:4649
+#: cp/tree.c:4697
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "l'attribut %qE est ignoré car il est appliqué à l'instanciation du patron %qT"
 
-#: cp/tree.c:4656
+#: cp/tree.c:4704
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "l'attribut %qE est ignoré car il est appliqué à la spécialisation du patron %qT"
 
-#: cp/tree.c:4678
+#: cp/tree.c:4726
 #, gcc-internal-format
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "attribut %qE appliqué à %qD qui n'est ni une fonction ni une variable"
 
-#: cp/tree.c:4684
+#: cp/tree.c:4732
 #, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "attribut %qE appliqué à la déclaration extern \"C\" %qD"
 
-#: cp/tree.c:5440
+#: cp/tree.c:5488
 #, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "zéro comme constante de pointeur nul"
 
-#: cp/tree.c:5453
+#: cp/tree.c:5501
 #, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr "vérification lang_* : échec dans %s, à %s:%d"
@@ -49530,107 +49595,107 @@
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "impossible d'initialiser l'agrégat du type %qT avec un littéral composé"
 
-#: cp/typeck2.c:1496 cp/typeck2.c:1523
+#: cp/typeck2.c:1499 cp/typeck2.c:1526
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "initialisation manquante pour le membre %qD"
 
-#: cp/typeck2.c:1504
+#: cp/typeck2.c:1507
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "le membre %qD est une référence non initialisée"
 
-#: cp/typeck2.c:1511
+#: cp/typeck2.c:1514
 #, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr "membre %qD avec des champs de référence non initialisés"
 
-#: cp/typeck2.c:1587
+#: cp/typeck2.c:1590
 #, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "l'ordre du désignateur pour le champ %qD ne correspond pas à l'ordre de la déclaration dans %qT"
 
-#: cp/typeck2.c:1660
+#: cp/typeck2.c:1663
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "pas de champ %qD trouvé dans l'union initialisée"
 
-#: cp/typeck2.c:1671
+#: cp/typeck2.c:1674
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "valeur d'index au lieu d'un nom de champ dans l'initialisation de l'union"
 
-#: cp/typeck2.c:1858
+#: cp/typeck2.c:1861
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "délégation de pointeur circulaire détectée"
 
-#: cp/typeck2.c:1872
+#: cp/typeck2.c:1875
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "l'opérande de base de %<->%> a un type non pointeur %qT"
 
-#: cp/typeck2.c:1898
+#: cp/typeck2.c:1901
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "le résultat de %<operator->()%> est un non pointeur"
 
-#: cp/typeck2.c:1900
+#: cp/typeck2.c:1903
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "l'opérande de base de %<->%> n'est pas un pointeur"
 
-#: cp/typeck2.c:1927
+#: cp/typeck2.c:1930
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE ne peut pas être utilisé comme pointeur de membre puisqu'il est de type %qT"
 
-#: cp/typeck2.c:1936
+#: cp/typeck2.c:1939
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "ne peut appliquer le pointeur membre %qE à %qE lequel est d'un type non classe %qT"
 
-#: cp/typeck2.c:1958
+#: cp/typeck2.c:1961
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "le pointeur vers le type membre %qT est incompatible avec le type d'objet %qT"
 
-#: cp/typeck2.c:2018
+#: cp/typeck2.c:2021
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "le type pointeur vers une fonction membre %qT requiert une r-valeur"
 
-#: cp/typeck2.c:2029
+#: cp/typeck2.c:2032
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "le type pointeur vers une fonction membre %qT requiert une l-valeur"
 
-#: cp/typeck2.c:2037
+#: cp/typeck2.c:2040
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++2a"
 msgstr "le type pointeur vers une fonction membre %qT requiert une l-valeur avant C++2a"
 
-#: cp/typeck2.c:2080
+#: cp/typeck2.c:2083
 #, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "transtypage fonctionnel vers le type tableau %qT"
 
-#: cp/typeck2.c:2096
+#: cp/typeck2.c:2099
 #, gcc-internal-format
 msgid "cannot deduce template arguments for %qT from ()"
 msgstr "impossible de déduire les arguments du patron pour %qT depuis ()"
 
-#: cp/typeck2.c:2114
+#: cp/typeck2.c:2117
 #, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "l'initialisation par valeur du type référence est invalide"
 
-#: cp/typeck2.c:2341
+#: cp/typeck2.c:2344
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "appel à la fonction %qD qui génère une exception du type incomplet %q#T"
 
-#: cp/typeck2.c:2344
+#: cp/typeck2.c:2347
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "appel à une fonction qui génère une exception du type incomplet %q#T"
@@ -49846,11 +49911,11 @@
 msgstr "La référence de tableau à %C ne peut pas avoir plus de %d dimensions"
 
 #: fortran/array.c:221 fortran/array.c:661 fortran/check.c:2849
-#: fortran/check.c:5222 fortran/check.c:5260 fortran/check.c:5302
-#: fortran/check.c:5329 fortran/check.c:5529 fortran/match.c:1821
+#: fortran/check.c:5225 fortran/check.c:5263 fortran/check.c:5305
+#: fortran/check.c:5332 fortran/check.c:5532 fortran/match.c:1821
 #: fortran/match.c:3174 fortran/match.c:3516 fortran/match.c:3712
-#: fortran/simplify.c:2909 fortran/simplify.c:2939 fortran/simplify.c:5764
-#: fortran/simplify.c:7658
+#: fortran/simplify.c:2909 fortran/simplify.c:2939 fortran/simplify.c:5769
+#: fortran/simplify.c:7663
 #, gcc-internal-format
 msgid "Coarrays disabled at %C, use %<-fcoarray=%> to enable"
 msgstr "Co-tableaux désactivés à %C, utilisez %<-fcoarray=%> pour l'activer"
@@ -49985,118 +50050,124 @@
 msgid "DO-iterator %qs at %L is inside iterator of the same name"
 msgstr "L'itérateur DO %qs à %L est à l'intérieur d'un itérateur du même nom"
 
-#: fortran/array.c:1073 fortran/array.c:1255
+#: fortran/array.c:1073 fortran/array.c:1264
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in array constructor at %C"
 msgstr "Erreur de syntaxe dans le constructeur du tableau à %C"
 
-#: fortran/array.c:1129
+#: fortran/array.c:1105
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "ENTRY statement at %C cannot appear in a contained procedure"
+msgid "NULL() at %C cannot appear in an array constructor"
+msgstr "L'instruction ENTRY à %C ne peut pas apparaître dans une procédure contenue"
+
+#: fortran/array.c:1138
 #, gcc-internal-format, gfc-internal-format
 msgid "[...] style array constructors at %C"
 msgstr "Constructeurs de tableau du style [...] à %C"
 
-#: fortran/array.c:1149
+#: fortran/array.c:1158
 #, gcc-internal-format, gfc-internal-format
 msgid "Array constructor including type specification at %C"
 msgstr "Constructeur de tableau incluant la spécification de type à %C"
 
-#: fortran/array.c:1155 fortran/match.c:4148
+#: fortran/array.c:1164 fortran/match.c:4148
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-spec at %L cannot contain a deferred type parameter"
 msgstr "La spécification de type à %L ne peut pas contenir de paramètre de type différé"
 
-#: fortran/array.c:1163
+#: fortran/array.c:1172
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-spec at %L cannot contain an asterisk for a type parameter"
 msgstr "La spécification de type à %L ne peut pas contenir un astérisque pour un paramètre de type"
 
-#: fortran/array.c:1181
+#: fortran/array.c:1190
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty array constructor at %C is not allowed"
 msgstr "Le constructeur de tableau vide à %C n'est pas permis"
 
-#: fortran/array.c:1218 fortran/array.c:1228
+#: fortran/array.c:1227 fortran/array.c:1237
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible typespec for array element at %L"
 msgstr "Typespec incompatible pour l'élément de tableau à %L"
 
-#: fortran/array.c:1302
+#: fortran/array.c:1311
 #, gcc-internal-format, gfc-internal-format
 msgid "Element in %s array constructor at %L is %s"
 msgstr "L'élément dans le constructeur du tableau %s à %L est %s"
 
-#: fortran/array.c:1633
+#: fortran/array.c:1642
 #, gcc-internal-format, gfc-internal-format
 msgid "Iterator step at %L cannot be zero"
 msgstr "Le pas de l'itération à %L ne peut pas être zéro"
 
-#: fortran/array.c:1770
+#: fortran/array.c:1779
 #, gcc-internal-format
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit.   See %<-fmax-array-constructor%> option"
 msgstr "Le nombre d'éléments dans le constructeur du tableau à %L requiert une augmentation de la limite supérieure autorisée %d.  Consultez l'option %<-fmax-array-constructor%>"
 
-#: fortran/array.c:1940
+#: fortran/array.c:1949
 #, gcc-internal-format, gfc-internal-format
 msgid "AC-IMPLIED-DO initial expression references control variable at %L"
 msgstr "L'expression initiale de AC-IMPLIED-DO fait référence à la variable de contrôle à %L"
 
-#: fortran/array.c:1947
+#: fortran/array.c:1956
 #, gcc-internal-format, gfc-internal-format
 msgid "AC-IMPLIED-DO final expression references control variable at %L"
 msgstr "L'expression finale de AC-IMPLIED-DO fait référence à la variable de contrôle à %L"
 
-#: fortran/array.c:1954
+#: fortran/array.c:1963
 #, gcc-internal-format, gfc-internal-format
 msgid "AC-IMPLIED-DO step expression references control variable at %L"
 msgstr "L'expression de pas de AC-IMPLIED-DO fait référence à la variable de contrôle à %L"
 
-#: fortran/array.c:1966
+#: fortran/array.c:1975
 #, gcc-internal-format, gfc-internal-format
 msgid "Array constructor value at %L shall not be unlimited polymorphic [F2008: C4106]"
 msgstr "La valeur du constructeur du tableau à %L ne sera point polymorphique sans limite [F2008: C4106]"
 
-#: fortran/array.c:2055
+#: fortran/array.c:2067
 #, gcc-internal-format, gfc-internal-format
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor at %L"
 msgstr "Longueurs de CHARACTER différentes (%ld/%ld) dans le constructeur du tableau à %L"
 
-#: fortran/array.c:2174
+#: fortran/array.c:2186
 #, gcc-internal-format
 msgid "spec_dimen_size(): Bad dimension"
 msgstr "spec_dimen_size(): Mauvaise dimension"
 
-#: fortran/array.c:2233
+#: fortran/array.c:2245
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimension"
 msgstr "gfc_ref_dimen_size(): Mauvaise dimension"
 
-#: fortran/array.c:2237
+#: fortran/array.c:2249
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array dimension at %L"
 msgstr "Mauvaise dimension de tableau à %L"
 
-#: fortran/array.c:2264 fortran/data.c:552 fortran/data.c:571
-#: fortran/data.c:585 fortran/data.c:714
+#: fortran/array.c:2276 fortran/data.c:563 fortran/data.c:582
+#: fortran/data.c:596 fortran/data.c:725
 #, gcc-internal-format
 msgid "Simplification error"
 msgstr "Erreur de simplification"
 
-#: fortran/array.c:2376
+#: fortran/array.c:2388
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimen_type"
 msgstr "gfc_ref_dimen_size(): Mauvais dimen_type"
 
-#: fortran/array.c:2427
+#: fortran/array.c:2439
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad dimension"
 msgstr "gfc_array_dimen_size(): Mauvaise dimension"
 
-#: fortran/array.c:2472
+#: fortran/array.c:2484
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad EXPR_ARRAY expr"
 msgstr "gfc_array_dimen_size(): Mauvaise expression EXPR_ARRAY"
 
-#: fortran/array.c:2620
+#: fortran/array.c:2632
 #, gcc-internal-format
 msgid "gfc_find_array_ref(): No ref found"
 msgstr "gfc_find_array_ref(): Pas de référence trouvée"
@@ -50147,7 +50218,7 @@
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or PROCEDURE"
 msgstr "L'argument %qs de l'intrinsèque %qs à %L doit être INTEGER ou PROCEDURE"
 
-#: fortran/check.c:205 fortran/check.c:6658
+#: fortran/check.c:205 fortran/check.c:6661
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a constant"
 msgstr "L'argument %qs de l'intrinsèque %qs à %L doit être une constante"
@@ -50262,7 +50333,7 @@
 msgid "Unequal character lengths (%ld/%ld) in %s at %L"
 msgstr "Longueurs de caractères inégales (%ld/%ld) dans %s à %L"
 
-#: fortran/check.c:946 fortran/check.c:6602
+#: fortran/check.c:946 fortran/check.c:6605
 #, gcc-internal-format
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have the same type"
 msgstr "Les arguments %qs et %qs de l'intrinsèque %qs à %L doivent avoir le même type"
@@ -50497,9 +50568,9 @@
 msgstr "L'argument %qs de l'intrinsèque %qs à %L sera du type entier, réel ou caractère"
 
 #: fortran/check.c:1939 fortran/check.c:2525 fortran/check.c:2628
-#: fortran/check.c:2835 fortran/check.c:2880 fortran/check.c:4256
-#: fortran/check.c:4390 fortran/check.c:4445 fortran/check.c:5515
-#: fortran/check.c:5644
+#: fortran/check.c:2835 fortran/check.c:2880 fortran/check.c:4259
+#: fortran/check.c:4393 fortran/check.c:4448 fortran/check.c:5518
+#: fortran/check.c:5647
 #, gcc-internal-format
 msgid "%qs intrinsic with KIND argument at %L"
 msgstr "Intrinsèque %qs avec l'argument KIND à %L"
@@ -50694,7 +50765,7 @@
 msgid "NULL intrinsic with allocatable MOLD at %L"
 msgstr "Intrinsèque NULL avec MOLD allouable à %L"
 
-#: fortran/check.c:3768 fortran/check.c:5591
+#: fortran/check.c:3768 fortran/check.c:5594
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must provide at least as many elements as there are .TRUE. values in %qs (%ld/%d)"
 msgstr "L'argument %qs de l'intrinsèque %qs à %L doit fournir au moins autant d'éléments qu'il y a de valeurs .TRUE. dans %qs (%ld/%d)"
@@ -50714,372 +50785,372 @@
 msgid "%qs argument of %qs intrinsic at %L must not be a subobject of %qs"
 msgstr "L'argument %qs de l'intrinsèque %qs à %L ne doit pas être un sous-objet de %qs"
 
-#: fortran/check.c:3901
+#: fortran/check.c:3904
 #, gcc-internal-format, gfc-internal-format
 msgid "The argument of the RANK intrinsic at %L must be a data object"
 msgstr "L'argument de l'intrinsèque RANK à %L doit être un objet de données"
 
-#: fortran/check.c:4005
+#: fortran/check.c:4008
 #, gcc-internal-format
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L must be an array of constant size"
 msgstr "L'argument %<shape%> de l'intrinsèque %<reshape%> à %L doit être un tableau de taille constante"
 
-#: fortran/check.c:4015
+#: fortran/check.c:4018
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L is empty"
 msgstr "L'argument %qs de l'intrinsèque %qs à %L est vide"
 
-#: fortran/check.c:4022
+#: fortran/check.c:4025
 #, gcc-internal-format
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L has more than %d elements"
 msgstr "L'argument %<shape%> de l'intrinsèque %<reshape%> à %L a plus de %d éléments"
 
-#: fortran/check.c:4039
+#: fortran/check.c:4042
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has negative element (%d)"
 msgstr "L'argument %qs de l'intrinsèque %qs à %L a un élément négatif (%d)"
 
-#: fortran/check.c:4071
+#: fortran/check.c:4074
 #, gcc-internal-format, gfc-internal-format
 msgid "Element %d of actual argument of RESHAPE at %L cannot be negative"
 msgstr "L'élément %d de l'argument effectif de RESHAPE à %L ne peut pas être négatif"
 
-#: fortran/check.c:4109
+#: fortran/check.c:4112
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has wrong number of elements (%d/%d)"
 msgstr "L'argument %qs de l'intrinsèque %qs à %L a un mauvais nombre d'éléments (%d/%d)"
 
-#: fortran/check.c:4127
+#: fortran/check.c:4130
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has out-of-range dimension (%d)"
 msgstr "L'argument %qs de l'intrinsèque %qs à %L a une dimension hors limite (%d)"
 
-#: fortran/check.c:4136
+#: fortran/check.c:4139
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has invalid permutation of dimensions (dimension %qd duplicated)"
 msgstr "L'argument %qs de l'intrinsèque %qs à %L a une permutation invalide des dimensions (dimension %qd dupliquée)"
 
-#: fortran/check.c:4172
+#: fortran/check.c:4175
 #, gcc-internal-format, gfc-internal-format
 msgid "Without padding, there are not enough elements in the intrinsic RESHAPE source at %L to match the shape"
 msgstr "Sans rembourrage, il n'y a pas assez d'éléments dans la source de l'intrinsèque RESHAPE à %L pour correspondre à la forme"
 
-#: fortran/check.c:4189 fortran/check.c:4208
+#: fortran/check.c:4192 fortran/check.c:4211
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L cannot be of type %s"
 msgstr "L'argument %qs de l'intrinsèque %qs à %L ne peut pas être du type %s"
 
-#: fortran/check.c:4199 fortran/check.c:4218
+#: fortran/check.c:4202 fortran/check.c:4221
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of an extensible type"
 msgstr "L'argument %qs de l'intrinsèque %qs à %L doit être d'un type extensible"
 
-#: fortran/check.c:4317
+#: fortran/check.c:4320
 #, gcc-internal-format
 msgid "SELECTED_REAL_KIND with neither %<P%> nor %<R%> argument at %L"
 msgstr "SELECTED_REAL_KIND sans argument %<P%> ni %<R%> à %L"
 
-#: fortran/check.c:4348
+#: fortran/check.c:4351
 #, gcc-internal-format
 msgid "%qs intrinsic with RADIX argument at %L"
 msgstr "Intrinsèque %qs avec un argument RADIX à %L"
 
-#: fortran/check.c:4383
+#: fortran/check.c:4386
 #, gcc-internal-format
 msgid "%<source%> argument of %<shape%> intrinsic at %L must not be an assumed size array"
 msgstr "L'argument %<source%> de l'intrinsèque %<shape%> à %L ne doit pas être un tableau de taille tacite"
 
-#: fortran/check.c:4460 fortran/check.c:6641
+#: fortran/check.c:4463 fortran/check.c:6644
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be a procedure"
 msgstr "L'argument %qs de l'intrinsèque %qs à %L ne sera point une procédure"
 
-#: fortran/check.c:4473 fortran/check.c:4612 fortran/check.c:6633
+#: fortran/check.c:4476 fortran/check.c:4615 fortran/check.c:6636
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be TYPE(*)"
 msgstr "L'argument %qs de l'intrinsèque %qs à %L ne sera point TYPE(*)"
 
-#: fortran/check.c:4484 fortran/check.c:4624
+#: fortran/check.c:4487 fortran/check.c:4627
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be an assumed-size array"
 msgstr "L'argument %qs de l'intrinsèque %qs à %L ne sera point un tableau de taille tacite"
 
-#: fortran/check.c:4554
+#: fortran/check.c:4557
 #, gcc-internal-format
 msgid "is_c_interoperable(): gfc_simplify_expr failed"
 msgstr "is_c_interoperable(): gfc_simplify_expr a échoué"
 
-#: fortran/check.c:4603
+#: fortran/check.c:4606
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be an interoperable data entity: %s"
 msgstr "L'argument %qs de l'intrinsèque %qs à %L doit être une entité de données interopérable: %s"
 
-#: fortran/check.c:4642
+#: fortran/check.c:4645
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_1 at %L to C_ASSOCIATED shall have the type TYPE(C_PTR) or TYPE(C_FUNPTR)"
 msgstr "L'argument C_PTR_1 à %L pour C_ASSOCIATED aura le type TYPE(C_PTR) ou TYPE(C_FUNPTR)"
 
-#: fortran/check.c:4656
+#: fortran/check.c:4659
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_2 at %L to C_ASSOCIATED shall have the same type as C_PTR_1: %s instead of %s"
 msgstr "L'argument C_PTR_2 à %L pour C_ASSOCIATED aura le même type que C_PTR_1: %s au lieu de %s"
 
-#: fortran/check.c:4680
+#: fortran/check.c:4683
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_POINTER shall have the type TYPE(C_PTR)"
 msgstr "L'argument CPTR à %L pour C_F_POINTER aura le type TYPE(C_PTR)"
 
-#: fortran/check.c:4692
+#: fortran/check.c:4695
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER must be a pointer"
 msgstr "L'argument FPTR à %L pour C_F_POINTER doit être un pointeur"
 
-#: fortran/check.c:4699
+#: fortran/check.c:4702
 #, gcc-internal-format, gfc-internal-format
 msgid "FPTR argument at %L to C_F_POINTER shall not be polymorphic"
 msgstr "L'argument FPTR à %L pour C_F_POINTER ne sera point polymorphique"
 
-#: fortran/check.c:4706
+#: fortran/check.c:4709
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER shall not be coindexed"
 msgstr "L'argument FPTR à %L pour C_F_POINTER ne sera point co-indexé"
 
-#: fortran/check.c:4713
+#: fortran/check.c:4716
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected SHAPE argument at %L to C_F_POINTER with scalar FPTR"
 msgstr "Argument SHAPE inattendu à %L pour C_F_POINTER avec FPTR scalaire"
 
-#: fortran/check.c:4719
+#: fortran/check.c:4722
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected SHAPE argument to C_F_POINTER with array FPTR at %L"
 msgstr "Argument SHAPE inattendu pour C_F_POINTER avec FPTR tableau à %L"
 
-#: fortran/check.c:4738
+#: fortran/check.c:4741
 #, gcc-internal-format, gfc-internal-format
 msgid "SHAPE argument at %L to C_F_POINTER must have the same size as the RANK of FPTR"
 msgstr "L'argument SHAPE à %L pour C_F_POINTER doit avoir la même taille que le RANK de FPTR"
 
-#: fortran/check.c:4748
+#: fortran/check.c:4751
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic FPTR at %L to C_F_POINTER"
 msgstr "FPTR polymorphique à %L pour C_F_POINTER"
 
-#: fortran/check.c:4753
+#: fortran/check.c:4756
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array FPTR at %L to C_F_POINTER: %s"
 msgstr "Tableau FPTR non interopérable à %L pour C_F_POINTER: %s"
 
-#: fortran/check.c:4769
+#: fortran/check.c:4772
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_PROCPOINTER shall have the type TYPE(C_FUNPTR)"
 msgstr "L'argument CPTR à %L pour C_F_PROCPOINTER n'aura point le type TYPE(C_FUNPTR)"
 
-#: fortran/check.c:4781
+#: fortran/check.c:4784
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall be a procedure pointer"
 msgstr "L'argument FPTR à %L pour C_F_PROCPOINTER sera un pointeur de procédure"
 
-#: fortran/check.c:4788
+#: fortran/check.c:4791
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall not be coindexed"
 msgstr "L'argument FPTR à %L pour C_F_PROCPOINTER ne sera point co-indexé"
 
-#: fortran/check.c:4794
+#: fortran/check.c:4797
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure pointer at %L to C_F_PROCPOINTER"
 msgstr "Pointeur de procédure non interopérable à %L pour C_F_PROCPOINTER"
 
-#: fortran/check.c:4808
+#: fortran/check.c:4811
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall not be coindexed"
 msgstr "L'argument X à %L pour C_FUNLOC ne sera point co-indexé"
 
-#: fortran/check.c:4823
+#: fortran/check.c:4826
 #, gcc-internal-format
 msgid "Function result %qs at %L is invalid as X argument to C_FUNLOC"
 msgstr "Le résultat %qs de la fonction à %L est invalide comme argument X pour C_FUNLOC"
 
-#: fortran/check.c:4831
+#: fortran/check.c:4834
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall be a procedure or a procedure pointer"
 msgstr "L'argument X à %L pour C_FUNLOC ne sera point une procédure ou un pointeur de procédure"
 
-#: fortran/check.c:4837
+#: fortran/check.c:4840
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure at %L to C_FUNLOC"
 msgstr "Procédure non interopérable à %L pour C_FUNLOC"
 
-#: fortran/check.c:4851
+#: fortran/check.c:4854
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall not be coindexed"
 msgstr "L'argument X à %L pour C_LOC ne sera point co-indexé"
 
-#: fortran/check.c:4857
+#: fortran/check.c:4860
 #, gcc-internal-format, gfc-internal-format
 msgid "X argument at %L to C_LOC shall not be polymorphic"
 msgstr "L'argument X à %L pour C_LOC ne sera point polymorphique"
 
-#: fortran/check.c:4868
+#: fortran/check.c:4871
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall have either the POINTER or the TARGET attribute"
 msgstr "L'argument X à %L pour C_LOC aura soit l'attribut POINTER ou soit l'attribut TARGET"
 
-#: fortran/check.c:4876
+#: fortran/check.c:4879
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall be not be a zero-sized string"
 msgstr "L'argument X à %L pour C_LOC ne sera point une chaîne de longueur nulle"
 
-#: fortran/check.c:4885
+#: fortran/check.c:4888
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument at %L to C_LOC shall not be polymorphic"
 msgstr "L'argument à %L pour C_LOC ne sera point polymorphique"
 
-#: fortran/check.c:4892
+#: fortran/check.c:4895
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array at %L as argument to C_LOC: %s"
 msgstr "Tableau non interopérable à %L comme argument pour C_LOC: %s"
 
-#: fortran/check.c:4903
+#: fortran/check.c:4906
 #, gcc-internal-format, gfc-internal-format
 msgid "Array of interoperable type at %L to C_LOC which is nonallocatable and neither assumed size nor explicit size"
 msgstr "Tableau d'un type interopérable à %L pour C_LOC qui n'est pas allouable et n'a pas de taille tacite ni de taille explicite"
 
-#: fortran/check.c:4908
+#: fortran/check.c:4911
 #, gcc-internal-format, gfc-internal-format
 msgid "Array section at %L to C_LOC"
 msgstr "Section de tableau à %L pour C_LOC"
 
-#: fortran/check.c:4936
+#: fortran/check.c:4939
 #, gcc-internal-format, gfc-internal-format
 msgid "non double precision REAL argument to %s intrinsic at %L"
 msgstr "argument REAL pas en double précision pour l'intrinsèque %s à %L"
 
-#: fortran/check.c:4949
+#: fortran/check.c:4952
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be less than rank %d"
 msgstr "L'argument %qs de l'intrinsèque %qs à %L doit être moins que le rang %d"
 
-#: fortran/check.c:4968
+#: fortran/check.c:4971
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L is not a valid dimension index"
 msgstr "L'argument %qs de l'intrinsèque %qs à %L n'est pas un index de dimension valide"
 
-#: fortran/check.c:5231
+#: fortran/check.c:5234
 #, gcc-internal-format, gfc-internal-format
 msgid "%s argument to IMAGE_INDEX must be a rank one array at %L"
 msgstr "L'argument %s pour IMAGE_INDEX doit être un tableau de rang un à %L"
 
-#: fortran/check.c:5242
+#: fortran/check.c:5245
 #, gcc-internal-format, gfc-internal-format
 msgid "The number of array elements of the SUB argument to IMAGE_INDEX at %L shall be %d (corank) not %d"
 msgstr "Le nombre d'éléments du tableau de l'argument SUB pour IMAGE_INDEX à %L sera %d (co-rang) et non %d"
 
-#: fortran/check.c:5275
+#: fortran/check.c:5278
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to NUM_IMAGES at %L"
 msgstr "Argument DISTANCE= pour NUM_IMAGES à %L"
 
-#: fortran/check.c:5288
+#: fortran/check.c:5291
 #, gcc-internal-format, gfc-internal-format
 msgid "FAILED= argument to NUM_IMAGES at %L"
 msgstr "Argument FAILED= pour NUM_IMAGES à %L"
 
-#: fortran/check.c:5312
+#: fortran/check.c:5315
 #, gcc-internal-format, gfc-internal-format
 msgid "TEAM argument at %L to the intrinsic TEAM_NUMBER shall be of type TEAM_TYPE"
 msgstr "L'argument TEAM à %L pour l'intrinsèque TEAM_NUMBER sera du type TEAM_TYPE"
 
-#: fortran/check.c:5338
+#: fortran/check.c:5341
 #, gcc-internal-format, gfc-internal-format
 msgid "DIM argument without COARRAY argument not allowed for THIS_IMAGE intrinsic at %L"
 msgstr "L'argument DIM sans argument COARRAY n'est pas permis pour l'intrinsèque THIS_IMAGE à %L"
 
-#: fortran/check.c:5345
+#: fortran/check.c:5348
 #, gcc-internal-format, gfc-internal-format
 msgid "The DISTANCE argument may not be specified together with the COARRAY or DIM argument in intrinsic at %L"
 msgstr "L'argument DISTANCE ne peut pas être spécifié avec l'argument COARRAY ou DIM dans l'intrinsèque à %L"
 
-#: fortran/check.c:5356
+#: fortran/check.c:5359
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected DIM argument with noncoarray argument at %L"
 msgstr "Argument DIM inattendu avec l'argument non co-tableau à %L"
 
-#: fortran/check.c:5374
+#: fortran/check.c:5377
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to THIS_IMAGE at %L"
 msgstr "Argument DISTANCE= pour THIS_IMAGE à %L"
 
-#: fortran/check.c:5454
+#: fortran/check.c:5457
 #, gcc-internal-format
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L must not be %s"
 msgstr "L'argument %<MOLD%> de l'intrinsèque %<TRANSFER%> à %L ne doit pas être %s"
 
-#: fortran/check.c:5483
+#: fortran/check.c:5486
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic TRANSFER at %L has partly undefined result: source size %ld < result size %ld"
 msgstr "L'intrinsèque TRANSFER à %L a un résultat partiellement indéfini: taille de la source %ld < taille du résultat %ld"
 
-#: fortran/check.c:5605
+#: fortran/check.c:5608
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must have the same rank as %qs or be a scalar"
 msgstr "L'argument %qs de l'intrinsèque %qs à %L doit avoir le même rang que %qs ou être un scalaire"
 
-#: fortran/check.c:5618
+#: fortran/check.c:5621
 #, gcc-internal-format
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have identical shape."
 msgstr "Les arguments %qs et %qs de l'intrinsèque %qs à %L doivent avoir des formes identiques."
 
-#: fortran/check.c:5861 fortran/check.c:5893
+#: fortran/check.c:5864 fortran/check.c:5896
 #, gcc-internal-format
 msgid "Size of %qs argument of %qs intrinsic at %L too small (%i/%i)"
 msgstr "La taille de l'argument %qs de l'intrinsèque %qs à %L est trop petite (%i/%i)"
 
-#: fortran/check.c:5901
+#: fortran/check.c:5904
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many arguments to %s at %L"
 msgstr "Trop d'arguments pour %s à %L"
 
-#: fortran/check.c:5919
+#: fortran/check.c:5922
 #, gcc-internal-format
 msgid "fe_runtime_error string must be null terminated"
 msgstr "La chaîne fe_runtime_error doit être terminée par un zéro"
 
-#: fortran/check.c:5931
+#: fortran/check.c:5934
 #, gcc-internal-format, gfc-internal-format
 msgid "fe_runtime_error: Wrong number of arguments (%d instead of %d)"
 msgstr "fe_runtime_error: Mauvais nombre d'arguments (%d au lieu de %d)"
 
-#: fortran/check.c:5971
+#: fortran/check.c:5974
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr "L'argument COUNT de SYSTEM_CLOCK à %L a un sous-type pas par défaut"
 
-#: fortran/check.c:5990
+#: fortran/check.c:5993
 #, gcc-internal-format, gfc-internal-format
 msgid "Real COUNT_RATE argument to SYSTEM_CLOCK at %L"
 msgstr "Argument réel COUNT_RATE de SYSTEM_CLOCK à %L"
 
-#: fortran/check.c:6000
+#: fortran/check.c:6003
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT_RATE argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr "L'argument COUNT_RATE de SYSTEM_CLOCK à %L a un sous-type pas par défaut"
 
-#: fortran/check.c:6017
+#: fortran/check.c:6020
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT_MAX argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr "L'argument COUNT_MAX de SYSTEM_CLOCK à %L a un sous-type pas par défaut"
 
-#: fortran/check.c:6234
+#: fortran/check.c:6237
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of a kind not wider than the default kind (%d)"
 msgstr "L'argument %qs de l'intrinsèque %qs à %L doit être d'un sous-type pas plus large que le sous-type par défaut (%d)"
 
-#: fortran/check.c:6586 fortran/check.c:6594
+#: fortran/check.c:6589 fortran/check.c:6597
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or LOGICAL"
 msgstr "L'argument %qs de l'intrinsèque %qs à %L doit être INTEGER ou LOGICAL"
 
-#: fortran/check.c:6625
+#: fortran/check.c:6628
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic function NULL at %L cannot be an actual argument to STORAGE_SIZE, because it returns a disassociated pointer"
 msgstr "La fonction intrinsèque NULL à %L ne peut pas être un argument effectif de STORAGE_SIZE car il retourne un pointeur dissocié"
@@ -51091,7 +51162,7 @@
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:727 fortran/decl.c:3636 fortran/decl.c:10066
+#: fortran/class.c:727 fortran/decl.c:3655 fortran/decl.c:10091
 #, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr "Niveau d'extension maximum atteint avec le type %qs à %L"
@@ -51116,42 +51187,48 @@
 msgid "non-constant array in DATA statement %L"
 msgstr "tableau non constant dans l'instruction DATA à %L"
 
-#: fortran/data.c:137
+#: fortran/data.c:140
 #, gcc-internal-format, gfc-internal-format
 msgid "failure to simplify substring reference in DATA statement at %L"
 msgstr "échec lors de la simplification de la référence à la sous-chaîne dans l'instruction DATA à %L"
 
-#: fortran/data.c:170
+#: fortran/data.c:173
 #, gcc-internal-format, gfc-internal-format
 msgid "Unused initialization string at %L because variable has zero length"
 msgstr "Chaîne d'initialisation inutilisée à %L car la variable a une longueur nulle"
 
-#: fortran/data.c:176
+#: fortran/data.c:179
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization string at %L was truncated to fit the variable (%ld/%ld)"
 msgstr "La chaine d'initialisation à %L a été tronquée pour tenir dans la variable (%ld/%ld)"
 
-#: fortran/data.c:265
+#: fortran/data.c:268
 #, gcc-internal-format
 msgid "%qs at %L already is initialized at %L"
 msgstr "%qs à %L a déjà été initialisé à %L"
 
-#: fortran/data.c:289
+#: fortran/data.c:292
 #, gcc-internal-format, gfc-internal-format
 msgid "Data element below array lower bound at %L"
 msgstr "Élément de donnée en dessous de la limite inférieure du tableau à %L"
 
-#: fortran/data.c:306 fortran/data.c:395
+#: fortran/data.c:309 fortran/data.c:398
 #, gcc-internal-format, gfc-internal-format
 msgid "Data element above array upper bound at %L"
 msgstr "Élément de donnée au dessus de la limite supérieure du tableau à %L"
 
-#: fortran/data.c:336 fortran/data.c:505
+#: fortran/data.c:339 fortran/data.c:496
 #, gcc-internal-format
 msgid "re-initialization of %qs at %L"
 msgstr "ré-initialisation de %qs à %L"
 
-#: fortran/data.c:727
+#: fortran/data.c:515
+#, fuzzy, gcc-internal-format
+#| msgid "Variable %qs at %C with an initializer already appears in a DATA statement"
+msgid "Nonpointer object %qs with default initialization shall not appear in a DATA statement at %L"
+msgstr "La variable %qs à %C avec une initialisation apparaît déjà dans une instruction DATA"
+
+#: fortran/data.c:738
 #, gcc-internal-format
 msgid "TODO: Vector sections in data statements"
 msgstr "TODO: Sections vecteurs dans les instructions data"
@@ -51176,784 +51253,785 @@
 msgid "Invalid initializer %s in Data statement at %C"
 msgstr "Initialisation %s invalide dans l'instruction Data à %C"
 
-#: fortran/decl.c:536
+#: fortran/decl.c:537
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C is not allowed in a PURE procedure"
 msgstr "L'initialisation à %C n'est pas permise dans une procédure PURE"
 
-#: fortran/decl.c:573
+#: fortran/decl.c:574
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %C cannot appear within an INTERFACE"
 msgstr "L'instruction DATA à %C ne peut pas apparaître dans une INTERFACE"
 
-#: fortran/decl.c:597
+#: fortran/decl.c:598
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid substring in data-implied-do at %L in DATA statement"
 msgstr "Sous-chaîne invalide dans le « do » avec donnée implicite à %L dans l'instruction DATA"
 
-#: fortran/decl.c:619
+#: fortran/decl.c:620
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %C is not allowed in a PURE procedure"
 msgstr "L'instruction DATA à %C n'est pas permise dans une procédure PURE"
 
-#: fortran/decl.c:664
+#: fortran/decl.c:662
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty old style initializer list at %C"
 msgstr "Liste d'initialisation vide dans l'ancien style à %C"
 
-#: fortran/decl.c:684
+#: fortran/decl.c:671
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "Array component of structure at %C must have an explicit shape"
+msgid "Array in initializer list at %L must have an explicit shape"
+msgstr "Le composant tableau de structures à %C doit avoir une forme explicite"
+
+#: fortran/decl.c:694
 #, gcc-internal-format, gfc-internal-format
 msgid "Repeat spec invalid in scalar initializer at %C"
 msgstr "Le spécificateur de répétition est invalide dans l'initialisation d'un scalaire à %C "
 
-#: fortran/decl.c:689
+#: fortran/decl.c:699
 #, gcc-internal-format, gfc-internal-format
 msgid "Repeat spec must be an integer at %C"
 msgstr "Le spécificateur de répétition doit être un entier à %C"
 
-#: fortran/decl.c:698
+#: fortran/decl.c:710
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected data constant after repeat spec at %C"
 msgstr "Donnée constante attendue après le spécificateur de répétition à %C"
 
-#: fortran/decl.c:729
+#: fortran/decl.c:742
 #, gcc-internal-format, gfc-internal-format
 msgid "End of scalar initializer expected at %C"
 msgstr "Fin de l'initialisation du scalaire attendue à %C"
 
-#: fortran/decl.c:758
+#: fortran/decl.c:773
 #, gcc-internal-format, gfc-internal-format
-msgid "Expected constant array-spec in initializer list at %L"
-msgstr "array-spec contant attendu dans la liste d'initialisation à %L"
-
-#: fortran/decl.c:767
-#, gcc-internal-format, gfc-internal-format
 msgid "Not enough elements in array initializer at %C"
 msgstr "Pas assez d'éléments dans l'initialisation du tableau à %C"
 
-#: fortran/decl.c:769
+#: fortran/decl.c:775
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many elements in array initializer at %C"
 msgstr "Trop d'éléments dans l'initialisation du tableau à %C"
 
-#: fortran/decl.c:790
+#: fortran/decl.c:795
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in old style initializer list at %C"
 msgstr "Erreur de syntaxe dans la liste d'initialisation dans l'ancien style à %C"
 
-#: fortran/decl.c:812
+#: fortran/decl.c:821
 #, gcc-internal-format, gfc-internal-format
 msgid "The assumed-rank array at %C shall not have a codimension"
 msgstr "Le tableau de rang tacite à %C n'aura point de co-dimension"
 
-#: fortran/decl.c:876
+#: fortran/decl.c:885
 #, gcc-internal-format, gfc-internal-format
 msgid "Sum of array rank %d and corank %d at %C exceeds maximum allowed dimensions of %d"
 msgstr "La somme du tableau de rang %d et de co-rang %d à %C excède les dimensions maximales autorisées de %d"
 
-#: fortran/decl.c:900
+#: fortran/decl.c:909
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad INTENT specification at %C"
 msgstr "Mauvaise spécification INTENT à %C"
 
-#: fortran/decl.c:921
+#: fortran/decl.c:930
 #, gcc-internal-format, gfc-internal-format
 msgid "deferred type parameter at %C"
 msgstr "paramètre de type différé à %C"
 
-#: fortran/decl.c:1004 fortran/resolve.c:11705
+#: fortran/decl.c:1013 fortran/resolve.c:11725
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr "Expression INTEGER scalaire attendue à %L"
 
-#: fortran/decl.c:1030
+#: fortran/decl.c:1039
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style character length at %C"
 msgstr "Longueur de caractère dans l'ancien style à %C"
 
-#: fortran/decl.c:1061
+#: fortran/decl.c:1070
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in character length specification at %C"
 msgstr "Erreur de syntaxe dans la spécification de la longueur de caractère à %C"
 
-#: fortran/decl.c:1212 fortran/decl.c:1217 fortran/decl.c:1266
+#: fortran/decl.c:1221 fortran/decl.c:1226 fortran/decl.c:1275
 #, gcc-internal-format
 msgid "Procedure %qs at %C is already defined at %L"
 msgstr "La procédure %qs à %C est déjà définie à %L"
 
-#: fortran/decl.c:1222
+#: fortran/decl.c:1231
 #, gcc-internal-format
 msgid "Contained procedure %qs at %C clashes with procedure defined at %L"
 msgstr "La procédure contenue %qs à %C entre en conflit avec la procédure définie à %L"
 
-#: fortran/decl.c:1231
+#: fortran/decl.c:1240
 #, gcc-internal-format
 msgid "Name %qs at %C is already defined as a generic interface at %L"
 msgstr "Le nom %qs à %C est déjà défini comme une interface générique à %L"
 
-#: fortran/decl.c:1244
+#: fortran/decl.c:1253
 #, gcc-internal-format
 msgid "Procedure %qs at %C has an explicit interface from a previous declaration"
 msgstr "La procédure %qs à %C a une interface explicite d'une déclaration précédente"
 
-#: fortran/decl.c:1257
+#: fortran/decl.c:1266
 #, gcc-internal-format
 msgid "Procedure %qs defined in interface body at %L clashes with internal procedure defined at %C"
 msgstr "La procédure %qs définie dans le corps de l'interface à %L entre en conflit avec la procédure interne définie à %C"
 
-#: fortran/decl.c:1335
+#: fortran/decl.c:1344
 #, gcc-internal-format
 msgid "Procedure %qs at %L must have the BIND(C) attribute to be C interoperable"
 msgstr "La procédure %qs à %L doit avoir l'attribut BIND(C) pour être interopérable avec le C"
 
-#: fortran/decl.c:1362
+#: fortran/decl.c:1371
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because derived type %qs is not C interoperable"
 msgstr "La variable %qs à %L est un argument muet de la procédure BIND(C) %qs mais elle n'est pas interopérable avec le C car le type dérivé %qs n'est pas interopérable avec le C"
 
-#: fortran/decl.c:1369
+#: fortran/decl.c:1378
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because it is polymorphic"
 msgstr "La variable %qs à %L est un argument muet de la procédure BIND(C) %qs mais elle n'est pas interopérable avec le C car elle est polymorphique"
 
-#: fortran/decl.c:1376
+#: fortran/decl.c:1385
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument of the BIND(C) procedure %qs but may not be C interoperable"
 msgstr "La variable %qs à %L est un argument muet de la procédure BIND(C) %qs mais elle pourrait ne pas être interopérable avec le C"
 
-#: fortran/decl.c:1391
+#: fortran/decl.c:1400
 #, gcc-internal-format
 msgid "Character argument %qs at %L must be length 1 because procedure %qs is BIND(C)"
 msgstr "L'argument caractère %qs à %L doit avoir la longueur 1 car la procédure %qs est BIND(C)"
 
-#: fortran/decl.c:1404
+#: fortran/decl.c:1413
 #, gcc-internal-format
 msgid "Variable %qs at %L with ALLOCATABLE attribute in procedure %qs with BIND(C)"
 msgstr "Variable %qs à %L avec l'attribut ALLOCATABLE dans la procédure %qs avec BIND(C)"
 
-#: fortran/decl.c:1412
+#: fortran/decl.c:1421
 #, gcc-internal-format
 msgid "Variable %qs at %L with POINTER attribute in procedure %qs with BIND(C)"
 msgstr "Variable %qs à %L avec l'attribut POINTER dans la procédure %qs avec BIND(C)"
 
-#: fortran/decl.c:1421
+#: fortran/decl.c:1430
 #, gcc-internal-format
 msgid "Scalar variable %qs at %L with POINTER or ALLOCATABLE in procedure %qs with BIND(C) is not yet supported"
 msgstr "La variable scalaire %qs à %L avec POINTER ou ALLOCATABLE dans la procédure %qs avec BIND(C) n'est pas encore supportée"
 
-#: fortran/decl.c:1430
+#: fortran/decl.c:1439
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the OPTIONAL and the VALUE attribute because procedure %qs is BIND(C)"
 msgstr "La variable %qs à %L ne peut pas avoir les deux attributs OPTIONAL et VALUE car la procédure %qs est BIND(C)"
 
-#: fortran/decl.c:1437
+#: fortran/decl.c:1446
 #, gcc-internal-format
 msgid "Variable %qs at %L with OPTIONAL attribute in procedure %qs which is BIND(C)"
 msgstr "Variable %qs à %L avec l'attribut OPTIONAL dans la procédure %qs qui est BIND(C)"
 
-#: fortran/decl.c:1448
+#: fortran/decl.c:1457
 #, gcc-internal-format
 msgid "Assumed-shape array %qs at %L as dummy argument to the BIND(C) procedure %qs at %L"
 msgstr "Tableau de forme tacite %qs à %L comme argument muet à la procédure BIND(C) %qs à %L"
 
-#: fortran/decl.c:1516
+#: fortran/decl.c:1525
 #, gcc-internal-format
 msgid "Symbol %qs at %C also declared as a type at %L"
 msgstr "Le symbole %qs à %C est aussi déclaré comme un type à %L"
 
-#: fortran/decl.c:1575
+#: fortran/decl.c:1584
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %C must be declared with a C interoperable kind since common block %qs is BIND(C)"
 msgstr "La variable %qs dans le bloc commun %qs à %C doit être déclarée avec un sous-type interopérable avec le C puisque le bloc commun %qs est BIND(C)"
 
-#: fortran/decl.c:1615
+#: fortran/decl.c:1624
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER length must be a constant at %L"
 msgstr "La longueur de CHARACTER doit être une constante à %L"
 
-#: fortran/decl.c:1630
+#: fortran/decl.c:1639
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression at %L is being truncated (%ld/%ld)"
 msgstr "L'expression CHARACTER à %L est tronquée (%ld/%ld)"
 
-#: fortran/decl.c:1638
+#: fortran/decl.c:1647
 #, gcc-internal-format, gfc-internal-format
 msgid "The CHARACTER elements of the array constructor at %L must have the same length (%ld/%ld)"
 msgstr "Les éléments CHARACTER dans le constructeur du tableau à %L doivent avoir la même longueur (%ld/%ld)"
 
-#: fortran/decl.c:1729
+#: fortran/decl.c:1738
 #, gcc-internal-format
 msgid "Initializer not allowed for PARAMETER %qs at %C"
 msgstr "Initialisation interdite pour PARAMETER %qs à %C"
 
-#: fortran/decl.c:1739
+#: fortran/decl.c:1748
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER at %L is missing an initializer"
 msgstr "Le PARAMETER à %L n'a pas d'initialisation"
 
-#: fortran/decl.c:1749
+#: fortran/decl.c:1758
 #, gcc-internal-format
 msgid "Variable %qs at %C with an initializer already appears in a DATA statement"
 msgstr "La variable %qs à %C avec une initialisation apparaît déjà dans une instruction DATA"
 
-#: fortran/decl.c:1792
+#: fortran/decl.c:1801
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot initialize parameter array at %L with variable length elements"
 msgstr "Impossible d'initialiser un tableau de paramètres à %L avec des éléments de longueur variable"
 
-#: fortran/decl.c:1861
+#: fortran/decl.c:1870
 #, gcc-internal-format, gfc-internal-format
 msgid "Can't initialize implied-shape array at %L with scalar"
 msgstr "Impossible d'initialiser un tableau de forme implicite à %L avec un scalaire"
 
-#: fortran/decl.c:1896
+#: fortran/decl.c:1905
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-constant lower bound in implied-shape declaration at %L"
 msgstr "Limite inférieure non constante dans la déclaration avec une forme implicite à %L"
 
-#: fortran/decl.c:1982 fortran/decl.c:1989
+#: fortran/decl.c:1991 fortran/decl.c:1998
 #, gcc-internal-format, gfc-internal-format
 msgid "Component at %C must have the POINTER attribute"
 msgstr "Le composant à %C doit avoir l'attribut POINTER"
 
-#: fortran/decl.c:1998
+#: fortran/decl.c:2007
 #, gcc-internal-format
 msgid "Component %qs with CLASS at %C must be allocatable or pointer"
 msgstr "Le composant %qs avec CLASS à %C doit être allouable ou un pointeur"
 
-#: fortran/decl.c:2007
+#: fortran/decl.c:2016
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr "Le composant tableau de structures à %C doit avoir une forme explicite ou différée"
 
-#: fortran/decl.c:2031 fortran/symbol.c:2230
+#: fortran/decl.c:2040 fortran/symbol.c:2244
 #, gcc-internal-format
 msgid "Component %qs at %C already declared at %L"
 msgstr "Le composant %qs à %C est déjà déclaré à %L"
 
-#: fortran/decl.c:2079
+#: fortran/decl.c:2088
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer array component of structure at %C must have a deferred shape"
 msgstr "Le composant tableau de pointeurs de structures à %C doit avoir une forme différée"
 
-#: fortran/decl.c:2088
+#: fortran/decl.c:2097
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component of structure at %C must have a deferred shape"
 msgstr "Le composant allouable de structures à %C doit avec une forme différée"
 
-#: fortran/decl.c:2097
+#: fortran/decl.c:2106
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have an explicit shape"
 msgstr "Le composant tableau de structures à %C doit avoir une forme explicite"
 
-#: fortran/decl.c:2114
+#: fortran/decl.c:2123
 #, gcc-internal-format
 msgid "Type parameter %qs at %C has no corresponding entry in the type parameter name list at %L"
 msgstr "Le paramètre de type %qs à %C n'a pas d'entrée correspondante dans la liste des noms de paramètres de types à %L"
 
-#: fortran/decl.c:2171
+#: fortran/decl.c:2180
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C is ambiguous"
 msgstr "L'initialisation NULL() à %C est ambiguë"
 
-#: fortran/decl.c:2188
+#: fortran/decl.c:2197
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C may not have MOLD"
 msgstr "L'initialisation NULL() à %C ne peut pas avoir MOLD"
 
-#: fortran/decl.c:2205
+#: fortran/decl.c:2214
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of pointer at %C is not allowed in a PURE procedure"
 msgstr "L'initialisation du pointeur à %C n'est pas permise dans une procédure PURE"
 
-#: fortran/decl.c:2226
+#: fortran/decl.c:2235
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in pointer initialization at %C"
 msgstr "Erreur dans l'initialisation du pointeur à %C"
 
-#: fortran/decl.c:2233
+#: fortran/decl.c:2242
 #, gcc-internal-format, gfc-internal-format
 msgid "non-NULL pointer initialization at %C"
 msgstr "Initialisation d'un pointeur non NULL à %C"
 
-#: fortran/decl.c:2256
+#: fortran/decl.c:2265
 #, gcc-internal-format
 msgid "RESULT variable %qs at %L prohibits FUNCTION name %qs at %C from appearing in a specification statement"
 msgstr "La variable RESULT %qs à %L interdit le nom de FUNCTION %qs à %C d'apparaître dans une instruction de spécification"
 
-#: fortran/decl.c:2318
+#: fortran/decl.c:2327
 #, gcc-internal-format
 msgid "%qs not allowed outside STRUCTURE at %C"
 msgstr "%qs n'est pas autorisé en dehors de STRUCTURE à %C"
 
-#: fortran/decl.c:2320
+#: fortran/decl.c:2329
 #, gcc-internal-format
 msgid "%qs at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr "%qs à %C est une extension DEC, activez-la avec %<-fdec-structure%>"
 
-#: fortran/decl.c:2327
+#: fortran/decl.c:2336
 #, gcc-internal-format
 msgid "%qs entity cannot have attributes at %C"
 msgstr "L'entité %qs ne peut pas avoir d'attribut à %C"
 
-#: fortran/decl.c:2367
+#: fortran/decl.c:2376
 #, gcc-internal-format
 msgid "Non-PARAMETER symbol %qs at %L can't be implied-shape"
 msgstr "Le symbole non PARAMETER %qs à %L ne peut pas avoir une forme implicite"
 
-#: fortran/decl.c:2377
+#: fortran/decl.c:2386
 #, gcc-internal-format, gfc-internal-format
 msgid "Implied-shape array at %L"
 msgstr "Tableau de forme implicite à %L"
 
-#: fortran/decl.c:2422
+#: fortran/decl.c:2431
 #, gcc-internal-format, gfc-internal-format
 msgid "Explicit shaped array with nonconstant bounds at %C"
 msgstr "Tableau de forme explicite avec des limites non constantes à %C"
 
-#: fortran/decl.c:2501
+#: fortran/decl.c:2510
 #, gcc-internal-format
 msgid "%qs at %C is a redefinition of the declaration in the corresponding interface for MODULE PROCEDURE %qs"
 msgstr "%qs à %C est une redéfinition de la déclaration dans l'interface correspondante pour MODULE PROCEDURE %qs"
 
-#: fortran/decl.c:2512
+#: fortran/decl.c:2521
 #, gcc-internal-format
 msgid "%qs entity cannot have an initializer at %C"
 msgstr "L'entité %qs ne peut pas avoir un initialiseur à %C"
 
-#: fortran/decl.c:2538 fortran/decl.c:8369
+#: fortran/decl.c:2547 fortran/decl.c:8388
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr "Spécificateur de tableau dupliqué pour le pointé de type Cray à %C"
 
-#: fortran/decl.c:2546
+#: fortran/decl.c:2555
 #, gcc-internal-format
 msgid "Couldn't set pointee array spec."
 msgstr "Impossible de définir la spécification du tableau pointé"
 
-#: fortran/decl.c:2609
+#: fortran/decl.c:2618
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style initialization at %C"
 msgstr "Initialisation dans l'ancien style à %C"
 
-#: fortran/decl.c:2617
+#: fortran/decl.c:2626
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr "Initialisation dans l'ancien style invalide pour le composant de type dérivé à %C"
 
-#: fortran/decl.c:2630
+#: fortran/decl.c:2639
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in old style initialization of %s at %C"
 msgstr "Erreur de syntaxe dans l'initialisation de %s dans l'ancien style à %C"
 
-#: fortran/decl.c:2650 fortran/decl.c:6661
+#: fortran/decl.c:2659 fortran/decl.c:6680
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr "L'initialisation à %C n'est pas pour une variable pointeur"
 
-#: fortran/decl.c:2663
+#: fortran/decl.c:2672
 #, gcc-internal-format
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr "L'initialisation du pointeur à %C requiert %<=>%> et non %<=%>"
 
-#: fortran/decl.c:2672 fortran/decl.c:10240
+#: fortran/decl.c:2681 fortran/decl.c:10265
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr "Une expression d'initialisation est attendue à %C"
 
-#: fortran/decl.c:2679
+#: fortran/decl.c:2688
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr "L'initialisation de la variable à %C n'est pas permise dans une procédure PURE"
 
-#: fortran/decl.c:2696
+#: fortran/decl.c:2705
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr "L'initialisation du composant allouable à %C n'est pas permise"
 
-#: fortran/decl.c:2710
+#: fortran/decl.c:2719
 #, gcc-internal-format, gfc-internal-format
 msgid "The component with KIND or LEN attribute at %C does not not appear in the type parameter list at %L"
 msgstr "Le composant avec l'attribut KIND ou LEN à %C n'apparaît pas dans la liste des paramètres de type à %L"
 
-#: fortran/decl.c:2718
+#: fortran/decl.c:2727
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C that appears in the type parameter list at %L has neither the KIND nor LEN attribute"
 msgstr "Le composant à %C qui apparaît dans la liste des paramètres de types à %L n'a ni l'attribut KIND ni l'attribut LEN"
 
-#: fortran/decl.c:2726
+#: fortran/decl.c:2735
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C which is a type parameter must be a scalar"
 msgstr "Le composant à %C, qui est un paramètre de type, doit être un scalaire"
 
-#: fortran/decl.c:2789 fortran/decl.c:2825
+#: fortran/decl.c:2798 fortran/decl.c:2834
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr "La déclaration du type %s*%d dans l'ancien style n'est pas supportée à %C"
 
-#: fortran/decl.c:2831
+#: fortran/decl.c:2840
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr "Déclaration du type non standard %s*%d à %C"
 
-#: fortran/decl.c:2890 fortran/decl.c:2967
+#: fortran/decl.c:2899 fortran/decl.c:2976
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis at %C"
 msgstr "Parenthèse droite manquante à %C"
 
-#: fortran/decl.c:2903 fortran/decl.c:3038
+#: fortran/decl.c:2912 fortran/decl.c:3047
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr "Expression d'initialisation attendue à %C"
 
-#: fortran/decl.c:2911 fortran/decl.c:3044
+#: fortran/decl.c:2920 fortran/decl.c:3053
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr "Expression d'initialisation d'un scalaire attendue à %C"
 
-#: fortran/decl.c:2941 fortran/decl.c:3657
+#: fortran/decl.c:2950 fortran/decl.c:3676
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr "Le sous-type %d n'est pas supporté pour le type %s à %C"
 
-#: fortran/decl.c:2954
+#: fortran/decl.c:2963
 #, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr "Le paramètre d'un type du sous-type C est pour le type %s mais le type à %L est %s"
 
-#: fortran/decl.c:2965
+#: fortran/decl.c:2974
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr "Parenthèse droite ou virgule manquante à %C"
 
-#: fortran/decl.c:3070
+#: fortran/decl.c:3079
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr "Le sous-type %d n'est pas supporté pour CHARACTER à %C"
 
-#: fortran/decl.c:3202
+#: fortran/decl.c:3211
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr "Erreur de syntaxe dans la déclaration CHARACTER à %C"
 
-#: fortran/decl.c:3291
+#: fortran/decl.c:3310
 #, gcc-internal-format, gfc-internal-format
 msgid "RECORD at %C is an extension, enable it with -fdec-structure"
 msgstr "RECORD à %C est une extension, activez-la avec -fdec-structure"
 
-#: fortran/decl.c:3304
+#: fortran/decl.c:3323
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected after RECORD at %C"
 msgstr "Nom de structure attendu après RECORD à %C"
 
-#: fortran/decl.c:3417
+#: fortran/decl.c:3436
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C cannot contain both ASSUMED and DEFERRED parameters"
 msgstr "La liste de spec des paramètres de type à %C ne peut pas contenir les paramètres ASSUMED et DEFERRED en même temps"
 
-#: fortran/decl.c:3441
+#: fortran/decl.c:3460
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C does not contain enough parameter expressions"
 msgstr "La liste de spec des paramètres de types à %C ne contient pas assez d'expressions de paramètres"
 
-#: fortran/decl.c:3465
+#: fortran/decl.c:3484
 #, gcc-internal-format
 msgid "The derived parameter %qs at %C does not have a default value"
 msgstr "Le paramètre dérivé %qs à %C n'a pas de valeur par défaut"
 
-#: fortran/decl.c:3497
+#: fortran/decl.c:3516
 #, gcc-internal-format, gfc-internal-format
 msgid "The parameter expression at %C must be of INTEGER type and not %s type"
 msgstr "L'expression paramètre à %C doit être de type INTEGER et non de type %s"
 
-#: fortran/decl.c:3525
+#: fortran/decl.c:3544
 #, gcc-internal-format
 msgid "The KIND parameter %qs at %C cannot either be ASSUMED or DEFERRED"
 msgstr "Le paramètre KIND %qs à %C ne peut pas être ASSUMED ou DEFERRED"
 
-#: fortran/decl.c:3532
+#: fortran/decl.c:3551
 #, gcc-internal-format
 msgid "The value for the KIND parameter %qs at %C does not reduce to a constant expression"
 msgstr "La valeur pour le paramètre KIND à %qs à %C ne se réduit pas en une expression constante"
 
-#: fortran/decl.c:3547
+#: fortran/decl.c:3566
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C contains too many parameter expressions"
 msgstr "La liste de spec des paramètres de type à %C contient trop d'expressions de paramètres"
 
-#: fortran/decl.c:3556
+#: fortran/decl.c:3575
 #, gcc-internal-format, gfc-internal-format
 msgid "Parameterized derived type at %C is ambiguous"
 msgstr "Le type dérivé paramétrisé à %C est ambigu"
 
-#: fortran/decl.c:3819
+#: fortran/decl.c:3838
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type at %C"
 msgstr "Type BYTE à %C"
 
-#: fortran/decl.c:3824
+#: fortran/decl.c:3843
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr "Le type BYTE utilisé à %C n'est pas disponible sur la machine cible"
 
-#: fortran/decl.c:3846
+#: fortran/decl.c:3865
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C is not allowed for components"
 msgstr "Le type tacite à %C n'est pas autorisé pour des composants"
 
-#: fortran/decl.c:3849
+#: fortran/decl.c:3868
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr "Type tacite à %C"
 
-#: fortran/decl.c:3872 fortran/decl.c:3903 fortran/decl.c:3932
-#: fortran/decl.c:4216
+#: fortran/decl.c:3891 fortran/decl.c:3922 fortran/decl.c:3951
+#: fortran/decl.c:4235
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr "TYPE avec une spécification de type intrinsèque à %C"
 
-#: fortran/decl.c:3928
+#: fortran/decl.c:3947
 #, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr "DOUBLE COMPLEX à %C"
 
-#: fortran/decl.c:3971 fortran/decl.c:4107 fortran/decl.c:4119
-#: fortran/decl.c:4133 fortran/decl.c:4611 fortran/decl.c:4619
+#: fortran/decl.c:3990 fortran/decl.c:4126 fortran/decl.c:4138
+#: fortran/decl.c:4152 fortran/decl.c:4630 fortran/decl.c:4638
 #, gcc-internal-format
 msgid "Type name %qs at %C is ambiguous"
 msgstr "Le nom de type %qs à %C est ambigu"
 
-#: fortran/decl.c:4066
+#: fortran/decl.c:4085
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS statement at %C"
 msgstr "Instruction CLASS à %C"
 
-#: fortran/decl.c:4148
+#: fortran/decl.c:4167
 #, gcc-internal-format
 msgid "Type name %qs at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr "Le nom du type %qs à %C est en conflit avec l'entité précédemment déclarée à %L qui a le même nom"
 
-#: fortran/decl.c:4287
+#: fortran/decl.c:4306
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr "Instruction IMPLCIT NONE dupliquée à %C"
 
-#: fortran/decl.c:4296
+#: fortran/decl.c:4315
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr "IMPORT NONE avec une liste de spécifications à %C"
 
-#: fortran/decl.c:4355
+#: fortran/decl.c:4374
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr "Plage de caractères manquante dans IMPLICIT à %C"
 
-#: fortran/decl.c:4401
+#: fortran/decl.c:4420
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr "Les lettres doivent être dans l'ordre alphabétique dans l'instruction IMPLICIT à %C"
 
-#: fortran/decl.c:4454
+#: fortran/decl.c:4473
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr "L'instruction IMPLICIT à %C suit une instruction IMPLICIT NONE (type)"
 
-#: fortran/decl.c:4464
+#: fortran/decl.c:4483
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr "Instruction IMPLICIT vide à %C"
 
-#: fortran/decl.c:4570
+#: fortran/decl.c:4589
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr "L'instruction IMPORT à %C est uniquement permise dans un corps d'INTERFACE"
 
-#: fortran/decl.c:4577
+#: fortran/decl.c:4596
 #, gcc-internal-format, gfc-internal-format
 msgid "F2008: C1210 IMPORT statement at %C is not permitted in a module procedure interface body"
 msgstr "F2008: l'instruction IMPORT C1210 à %C n'est pas permise dans le corps d'interface d'une procédure d'un module"
 
-#: fortran/decl.c:4582
+#: fortran/decl.c:4601
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C"
 msgstr "Instruction IMPORT à %C"
 
-#: fortran/decl.c:4596
+#: fortran/decl.c:4615
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr "Liste d'entités nommées attendue à %C"
 
-#: fortran/decl.c:4625
+#: fortran/decl.c:4644
 #, gcc-internal-format
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr "Impossible d'utiliser IMPORT %qs depuis l'unité dans la portée de l'hôte à %C – n'existe pas."
 
-#: fortran/decl.c:4632
+#: fortran/decl.c:4651
 #, gcc-internal-format
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr "%qs est déjà IMPORTé depuis l'unité dans la portée de l'hôte à %C"
 
-#: fortran/decl.c:4673
+#: fortran/decl.c:4692
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IMPORT statement at %C"
 msgstr "Erreur de syntaxe dans l'instruction IMPORT à %C"
 
-#: fortran/decl.c:5010
+#: fortran/decl.c:5029
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing codimension specification at %C"
 msgstr "Spécification de co-dimension manquante à %C"
 
-#: fortran/decl.c:5012
+#: fortran/decl.c:5031
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr "Spécification de dimension manquante à %C"
 
-#: fortran/decl.c:5107
+#: fortran/decl.c:5126
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr "Attribut %s dupliqué à %L"
 
-#: fortran/decl.c:5124
+#: fortran/decl.c:5143
 #, gcc-internal-format
 msgid "%s at %L is a DEC extension, enable with %<-fdec-static%>"
 msgstr "%s à %L est une extension DEC, activez-la avec %<-fdec-static%>"
 
-#: fortran/decl.c:5141
+#: fortran/decl.c:5160
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr "Attribut ALLOCATABLE à %C dans une définition TYPE"
 
-#: fortran/decl.c:5150
+#: fortran/decl.c:5169
 #, gcc-internal-format, gfc-internal-format
 msgid "KIND attribute at %C in a TYPE definition"
 msgstr "Attribut KIND à %C dans une définition TYPE"
 
-#: fortran/decl.c:5158
+#: fortran/decl.c:5177
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be INTEGER"
 msgstr "Le composant avec l'attribut KIND à %C doit être un INTEGER"
 
-#: fortran/decl.c:5165
+#: fortran/decl.c:5184
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be default integer kind (%d)"
 msgstr "Le composant avec l'attribut KIND à %C doit être du sous-type entier par défaut (%d)"
 
-#: fortran/decl.c:5174
+#: fortran/decl.c:5193
 #, gcc-internal-format, gfc-internal-format
 msgid "LEN attribute at %C in a TYPE definition"
 msgstr "Attribut LEN à %C dans une définition TYPE"
 
-#: fortran/decl.c:5182
+#: fortran/decl.c:5201
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be INTEGER"
 msgstr "Le composant avec l'attribut LEN à %C doit être un INTEGER"
 
-#: fortran/decl.c:5189
+#: fortran/decl.c:5208
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be default integer kind (%d)"
 msgstr "Le composant avec l'attribut LEN à %C doit être du sous-type entier par défaut (%d)"
 
-#: fortran/decl.c:5198
+#: fortran/decl.c:5217
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr "L'attribut à %L n'est pas permis dans une définition TYPE"
 
-#: fortran/decl.c:5216
+#: fortran/decl.c:5235
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr "Attribut %s à %L dans une définition TYPE"
 
-#: fortran/decl.c:5226
+#: fortran/decl.c:5245
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr "L'attribut %s à %L n'est pas permis en dehors de la partie de la spécification d'un module"
 
-#: fortran/decl.c:5236
+#: fortran/decl.c:5255
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed outside a TYPE definition"
 msgstr "L'attribut à %L n'est pas permis en dehors d'une définition TYPE"
 
-#: fortran/decl.c:5249
+#: fortran/decl.c:5268
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr "Attribut ASYNCHRONOUS à %C"
 
-#: fortran/decl.c:5260
+#: fortran/decl.c:5279
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr "Attribut CONTIGUOUS à %C"
 
-#: fortran/decl.c:5315 fortran/decl.c:8673
+#: fortran/decl.c:5334 fortran/decl.c:8692
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr "PROTECTED à %C est uniquement autorisé dans la partie de la spécification d'un module"
 
-#: fortran/decl.c:5321
+#: fortran/decl.c:5340
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute at %C"
 msgstr "Attribut PROTECTED à %C"
 
-#: fortran/decl.c:5355
+#: fortran/decl.c:5374
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE attribute at %C"
 msgstr "Attribut VALUE à %C"
 
-#: fortran/decl.c:5362
+#: fortran/decl.c:5381
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
 msgstr "Attribut VOLATILE à %C"
 
-#: fortran/decl.c:5369
+#: fortran/decl.c:5388
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr "match_attr_spec(): Mauvais attribut"
 
-#: fortran/decl.c:5410
+#: fortran/decl.c:5429
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr "Identificateurs multiples fournis avec un seul spécificateur NAME= à %C"
 
-#: fortran/decl.c:5508
+#: fortran/decl.c:5527
 #, gcc-internal-format
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr "La déclaration implicite de la fonction BIND(C) %qs à %L pourrait ne pas être interopérable avec le C"
 
-#: fortran/decl.c:5530
+#: fortran/decl.c:5549
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr "La variable %qs dans le bloc commun %qs à %L ne peut pas être un sous-type interopérable avec le C bien que le bloc commun %qs est BIND(C)"
 
-#: fortran/decl.c:5539
+#: fortran/decl.c:5558
 #, gcc-internal-format
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr "La déclaration de type %qs à %L n'est pas interopérable avec le C mais elle est BIND(C)"
 
-#: fortran/decl.c:5543
+#: fortran/decl.c:5562
 #, gcc-internal-format
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr "La variable %qs à %L peut ne pas être d'un sous-type interopérable avec le C mais elle est BIND(C)"
 
-#: fortran/decl.c:5555
+#: fortran/decl.c:5574
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr "La variable %qs dans le bloc commun %qs à %L ne peut pas être déclarée avec BIND(C) puisqu'elle n'est pas globale"
 
-#: fortran/decl.c:5569
+#: fortran/decl.c:5588
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr "La variable %qs à %L ne peut pas avoir les attributs POINTER et BIND(c) en même temps"
 
-#: fortran/decl.c:5577
+#: fortran/decl.c:5596
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr "La variable %qs à %L ne peut pas avoir les attributs ALLOCATABLE et BIND(C) en même temps"
 
-#: fortran/decl.c:5589
+#: fortran/decl.c:5608
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr "Le type de retour de la fonction BIND(C) %qs à %L ne peut pas être un tableau"
 
-#: fortran/decl.c:5597
+#: fortran/decl.c:5616
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be a character string"
 msgstr "Le type de retour de la fonction BIND(C) %qs à %L ne peut pas être une chaîne de caractères"
@@ -51960,951 +52038,957 @@
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:5608
+#: fortran/decl.c:5627
 #, gcc-internal-format
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr "Le symbole %qs à %L est marqué PRIVATE mais il a reçu l'étiquette de liaison %qs"
 
-#: fortran/decl.c:5682
+#: fortran/decl.c:5701
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr "L'instruction de spécification d'attribut a besoin de soit un nom d'entité ou soit un nom de bloc commun à %C"
 
-#: fortran/decl.c:5727
+#: fortran/decl.c:5746
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr "Il manque le nom d'entité ou le nom de bloc commun pour l'instruction de spécification d'attribut à %C"
 
-#: fortran/decl.c:5734
+#: fortran/decl.c:5753
 #, gcc-internal-format
 msgid "Missing symbol"
 msgstr "Symbole manquant"
 
-#: fortran/decl.c:5763
+#: fortran/decl.c:5782
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) statement at %C"
 msgstr "Instruction BIND(C) à %C"
 
-#: fortran/decl.c:5850
+#: fortran/decl.c:5869
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr "Le type dérivé à %C n'a pas été précédemment défini et, par conséquent, il ne peut pas apparaître dans une définition de type dérivé"
 
-#: fortran/decl.c:5892
+#: fortran/decl.c:5911
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in anonymous structure declaration at %C"
 msgstr "Erreur de syntaxe dans la déclaration de la structure anonyme à %C"
 
-#: fortran/decl.c:5901
+#: fortran/decl.c:5920
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr "Erreur de syntaxe dans la déclaration de donnée à %C"
 
-#: fortran/decl.c:5951
+#: fortran/decl.c:5970
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C"
 msgstr "Préfixe de MODULE à %C"
 
-#: fortran/decl.c:5996
+#: fortran/decl.c:6015
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPURE procedure at %C"
 msgstr "Procédure IMPURE à %C"
 
-#: fortran/decl.c:6008
+#: fortran/decl.c:6027
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr "PURE et IMPURE ne peuvent pas apparaître ensemble à %C"
 
-#: fortran/decl.c:6054
+#: fortran/decl.c:6073
 #, gcc-internal-format, gfc-internal-format
 msgid "ELEMENTAL prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr "Le préfixe ELEMENTAL dans l'interface MODULE PROCEDURE est manquant à %L"
 
-#: fortran/decl.c:6061
+#: fortran/decl.c:6080
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr "Le préfixe PURE dans l'interface MODULE PROCEDURE est manquant à %L"
 
-#: fortran/decl.c:6068
+#: fortran/decl.c:6087
 #, gcc-internal-format, gfc-internal-format
 msgid "RECURSIVE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr "Le préfixe RECURSIVE dans l'interface MODULE PROCEDURE est manquant à %L"
 
-#: fortran/decl.c:6134 fortran/primary.c:1820
+#: fortran/decl.c:6153 fortran/primary.c:1820
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate-return argument at %C"
 msgstr "Argument de retour alternatif à %C"
 
-#: fortran/decl.c:6140 fortran/decl.c:6148
+#: fortran/decl.c:6159 fortran/decl.c:6167
 #, gcc-internal-format, gfc-internal-format
 msgid "A parameter name is required at %C"
 msgstr "Un nom de paramètre est requis à %C"
 
-#: fortran/decl.c:6188
+#: fortran/decl.c:6207
 #, gcc-internal-format
 msgid "Name %qs at %C is the name of the procedure"
 msgstr "Le nom %qs à %C est le nom de la procédure"
 
-#: fortran/decl.c:6201
+#: fortran/decl.c:6220
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected parameter list in type declaration at %C"
 msgstr "Liste de paramètres attendue dans la déclaration du type à %C"
 
-#: fortran/decl.c:6204
+#: fortran/decl.c:6223
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr "Rebut inattendu dans la liste d'arguments formels à %C"
 
-#: fortran/decl.c:6222
+#: fortran/decl.c:6241
 #, gcc-internal-format
 msgid "Duplicate name %qs in parameter list at %C"
 msgstr "Nom %qs en double dans la liste des paramètres à %C"
 
-#: fortran/decl.c:6225
+#: fortran/decl.c:6244
 #, gcc-internal-format
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr "Symbole %qs dupliqué dans la liste d'arguments formels à %C"
 
-#: fortran/decl.c:6264
+#: fortran/decl.c:6283
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in MODULE PROCEDURE formal argument names (%s/%s) at %C"
 msgstr "Désaccord dans les noms des arguments formels de MODULE PROCEDURE (%s/%s) à %C"
 
-#: fortran/decl.c:6270
+#: fortran/decl.c:6289
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in number of MODULE PROCEDURE formal arguments at %C"
 msgstr "Désaccord dans le nombre d'arguments formels de MODULE PROCEDURE à %C"
 
-#: fortran/decl.c:6309
+#: fortran/decl.c:6328
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr "La variable RESULT à %C doit être différente du nom de la fonction"
 
-#: fortran/decl.c:6386
+#: fortran/decl.c:6405
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr "Rebut inattendu après la déclaration de la fonction à %C"
 
-#: fortran/decl.c:6396 fortran/decl.c:7494
+#: fortran/decl.c:6415 fortran/decl.c:7513
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr "L'attribut BIND(C) à %L ne peut pas être spécifié pour une procédure interne"
 
-#: fortran/decl.c:6600
+#: fortran/decl.c:6619
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr "L'attribut BIND(C) à %C requiert une interface avec BIND(C)"
 
-#: fortran/decl.c:6607
+#: fortran/decl.c:6626
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr "La procédure BIND(C) avec NAME ne peut pas avoir l'attribut POINTER à %C"
 
-#: fortran/decl.c:6613
+#: fortran/decl.c:6632
 #, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr "La procédure muette à %C ne peut pas avoir d'attribut BIND(C) avec NAME"
 
-#: fortran/decl.c:6636
+#: fortran/decl.c:6655
 #, gcc-internal-format
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr "La procédure %qs à %L a déjà le type de base de %s"
 
-#: fortran/decl.c:6682 fortran/decl.c:6870 fortran/decl.c:10723
+#: fortran/decl.c:6701 fortran/decl.c:6889 fortran/decl.c:10748
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr "Erreur de syntaxe dans l'instruction PROCEDURE à %C"
 
-#: fortran/decl.c:6731 fortran/decl.c:10623
+#: fortran/decl.c:6750 fortran/decl.c:10648
 #, gcc-internal-format
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr "%<::%> attendu après les attributs de liaison à %C"
 
-#: fortran/decl.c:6738
+#: fortran/decl.c:6757
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr "NOPASS ou interface explicite requise à %C"
 
-#: fortran/decl.c:6742
+#: fortran/decl.c:6761
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component at %C"
 msgstr "Composant de pointeur de procédure à %C"
 
-#: fortran/decl.c:6814
+#: fortran/decl.c:6833
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in procedure pointer component at %C"
 msgstr "Erreur de syntaxe dans un composant de pointeur de procédure à %C"
 
-#: fortran/decl.c:6832
+#: fortran/decl.c:6851
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr "PROCEDURE à %C doit être une interface générique"
 
-#: fortran/decl.c:6841 fortran/decl.c:9392
+#: fortran/decl.c:6860 fortran/decl.c:9411
 #, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr "double : dans l'instruction MODULE PROCEDURE à %L"
 
-#: fortran/decl.c:6911
+#: fortran/decl.c:6930
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE statement at %C"
 msgstr "Instruction PROCEDURE à %C"
 
-#: fortran/decl.c:6983
+#: fortran/decl.c:7002
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr "Liste d'arguments formels attendue dans la définition de la fonction à %C"
 
-#: fortran/decl.c:7007 fortran/decl.c:7011 fortran/decl.c:7266
-#: fortran/decl.c:7270 fortran/decl.c:7462 fortran/decl.c:7466
-#: fortran/symbol.c:1875
+#: fortran/decl.c:7026 fortran/decl.c:7030 fortran/decl.c:7285
+#: fortran/decl.c:7289 fortran/decl.c:7481 fortran/decl.c:7485
+#: fortran/symbol.c:1889
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr "L'attribut BIND(C) à %L peut uniquement être utilisé pour des variables ou des blocs communs"
 
-#: fortran/decl.c:7164
+#: fortran/decl.c:7183
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C"
 msgstr "Instruction ENTRY à %C"
 
-#: fortran/decl.c:7173
+#: fortran/decl.c:7192
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr "L'instruction ENTRY à %C ne peut pas apparaître dans un PROGRAM"
 
-#: fortran/decl.c:7176
+#: fortran/decl.c:7195
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr "L'instruction ENTRY à %C ne peut pas apparaître dans un MODULE"
 
-#: fortran/decl.c:7179
+#: fortran/decl.c:7198
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SUBMODULE"
 msgstr "L'instruction ENTRY à %C ne peut pas apparaître dans un SUBMODULE"
 
-#: fortran/decl.c:7182
+#: fortran/decl.c:7201
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr "L'instruction ENTRY à %C ne peut apparaître dans un BLOCK DATA"
 
-#: fortran/decl.c:7186 fortran/decl.c:7231
+#: fortran/decl.c:7205 fortran/decl.c:7250
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr "L'instruction ENTRY à %C ne peut pas apparaître dans une INTERFACE"
 
-#: fortran/decl.c:7190
+#: fortran/decl.c:7209
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a STRUCTURE block"
 msgstr "L'instruction ENTRY à %C ne peut pas apparaître dans un bloc STRUCTURE"
 
-#: fortran/decl.c:7194
+#: fortran/decl.c:7213
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr "L'instruction ENTRY à %C ne peut pas apparaître dans un bloc DERIVED TYPE"
 
-#: fortran/decl.c:7198
+#: fortran/decl.c:7217
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr "L'instruction ENTRY à %C ne peut pas apparaître dans un bloc IF-THEN"
 
-#: fortran/decl.c:7203
+#: fortran/decl.c:7222
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr "L'instruction ENTRY à %C ne peut pas apparaître dans un bloc DO"
 
-#: fortran/decl.c:7207
+#: fortran/decl.c:7226
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr "L'instruction ENTRY à %C ne peut pas apparaître dans un bloc SELECT"
 
-#: fortran/decl.c:7211
+#: fortran/decl.c:7230
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr "L'instruction ENTRY à %C ne peut pas apparaître dans un bloc FORALL"
 
-#: fortran/decl.c:7215
+#: fortran/decl.c:7234
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr "L'instruction ENTRY à %C ne peut pas apparaître dans un bloc WHERE"
 
-#: fortran/decl.c:7219
+#: fortran/decl.c:7238
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr "L'instruction ENTRY à %C ne peut pas apparaître dans un sous programme contenu"
 
-#: fortran/decl.c:7223
+#: fortran/decl.c:7242
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected ENTRY statement at %C"
 msgstr "Instruction ENTRY inattendue à %C"
 
-#: fortran/decl.c:7244
+#: fortran/decl.c:7263
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr "L'instruction ENTRY à %C ne peut pas apparaître dans une procédure contenue"
 
-#: fortran/decl.c:7295 fortran/decl.c:7501
+#: fortran/decl.c:7314 fortran/decl.c:7520
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr "Parenthèse requise manquante avant BIND(C) à %C"
 
-#: fortran/decl.c:7563 fortran/decl.c:7570
+#: fortran/decl.c:7582 fortran/decl.c:7589
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr "Identificateur C invalide dans le spécificateur NAME= à %C"
 
-#: fortran/decl.c:7610
+#: fortran/decl.c:7629
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr "Erreur de syntaxe dans le spécificateur NAME= pour l'étiquette de liaison à %C"
 
-#: fortran/decl.c:7626
+#: fortran/decl.c:7645
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr "Le spécificateur NAME= à %C devrait être une expression constante"
 
-#: fortran/decl.c:7634
+#: fortran/decl.c:7653
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr "Le spécificateur NAME= à %C devrait être un scalaire du sous-type de caractère par défaut"
 
-#: fortran/decl.c:7653
+#: fortran/decl.c:7672
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing closing paren for binding label at %C"
 msgstr "Parenthèse fermante manquante pour l'étiquette de liaison à %C"
 
-#: fortran/decl.c:7659
+#: fortran/decl.c:7678
 #, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr "Le nom de liaison n'est pas permis dans BIND(C) à %C"
 
-#: fortran/decl.c:7665
+#: fortran/decl.c:7684
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr "Pour la procédure muette %s, aucun nom de liaison est autorisé dans BIND(C) à %C"
 
-#: fortran/decl.c:7694
+#: fortran/decl.c:7713
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr "NAME pas autorisé sur BIND(C) pour ABSTRACT INTERFACE à %C"
 
-#: fortran/decl.c:7939
+#: fortran/decl.c:7958
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr "Instruction END inattendue à %C"
 
-#: fortran/decl.c:7948
+#: fortran/decl.c:7967
 #, gcc-internal-format, gfc-internal-format
 msgid "END statement instead of %s statement at %L"
 msgstr "Instruction END au lieu de l'instruction %s à %L"
 
 #. We would have required END [something].
-#: fortran/decl.c:7957
+#: fortran/decl.c:7976
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr "Instruction %s attendue à %L"
 
-#: fortran/decl.c:7968
+#: fortran/decl.c:7987
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s statement at %L"
 msgstr "On attendait l'instruction %s à %L"
 
-#: fortran/decl.c:7988
+#: fortran/decl.c:8007
 #, gcc-internal-format
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr "On attendait le nom du bloc de %qs dans l'instruction %s à %L"
 
-#: fortran/decl.c:8005
+#: fortran/decl.c:8024
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr "On attendait un nom de terminaison à %C"
 
-#: fortran/decl.c:8019 fortran/decl.c:8027
+#: fortran/decl.c:8038 fortran/decl.c:8046
 #, gcc-internal-format
 msgid "Expected label %qs for %s statement at %C"
 msgstr "On attendait l'étiquette %qs pour l'instruction %s à %C"
 
-#: fortran/decl.c:8126
+#: fortran/decl.c:8145
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr "Spécification de tableau manquante à %L dans l'instruction DIMENSION"
 
-#: fortran/decl.c:8134
+#: fortran/decl.c:8153
 #, gcc-internal-format, gfc-internal-format
 msgid "Dimensions specified for %s at %L after its initialization"
 msgstr "Dimensions spécifiées pour %s à %L après son initialisation"
 
-#: fortran/decl.c:8142
+#: fortran/decl.c:8161
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr "Spécification de tableau manquante à %L dans l'instruction CODIMENSION"
 
-#: fortran/decl.c:8151
+#: fortran/decl.c:8170
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr "La spécification de tableau doit être différée à %L"
 
-#: fortran/decl.c:8249
+#: fortran/decl.c:8268
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr "Caractère inattendu dans la liste de variable à %C"
 
-#: fortran/decl.c:8286
+#: fortran/decl.c:8305
 #, gcc-internal-format
 msgid "Expected %<(%> at %C"
 msgstr "%<(%> attendu à %C"
 
-#: fortran/decl.c:8300 fortran/decl.c:8340
+#: fortran/decl.c:8319 fortran/decl.c:8359
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr "Nom de variable attendu à %C"
 
-#: fortran/decl.c:8316
+#: fortran/decl.c:8335
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C must be an integer"
 msgstr "Le pointeur Cray à %C doit être un entier"
 
-#: fortran/decl.c:8320
+#: fortran/decl.c:8339
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr "Le pointeur Cray à %C a %d octets de précision; les adresses mémoire requièrent %d octets"
 
-#: fortran/decl.c:8326
+#: fortran/decl.c:8345
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr "« , » attendu à %C"
 
-#: fortran/decl.c:8365
+#: fortran/decl.c:8384
 #, gcc-internal-format
 msgid "Couldn't set Cray pointee array spec."
 msgstr "N'a pu définir la spécification de tableau dans le pointé de type Cray"
 
-#: fortran/decl.c:8389
+#: fortran/decl.c:8408
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr "« ) » attendue à %C"
 
-#: fortran/decl.c:8401
+#: fortran/decl.c:8420
 #, gcc-internal-format
 msgid "Expected %<,%> or end of statement at %C"
 msgstr "%<,%> ou fin d'instruction attendue à %C"
 
-#: fortran/decl.c:8427
+#: fortran/decl.c:8446
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr "INTENT n'est pas permis à l'intérieur de BLOCK à %C"
 
-#: fortran/decl.c:8459
+#: fortran/decl.c:8478
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr "OPTIONAL n'est pas permis à l'intérieur du BLOCK à %C"
 
-#: fortran/decl.c:8478
+#: fortran/decl.c:8497
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer declaration at %C requires -fcray-pointer flag"
 msgstr "La déclaration de pointeur Cray à %C requiert l'option -fcray-pointer"
 
-#: fortran/decl.c:8517
+#: fortran/decl.c:8536
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS statement at %C"
 msgstr "Instruction CONTIGUOUS à %C"
 
-#: fortran/decl.c:8623
+#: fortran/decl.c:8642
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr "La spécification d'accès de l'opérateur %s à %C a déjà été spécifiée"
 
-#: fortran/decl.c:8640
+#: fortran/decl.c:8659
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr "La spécification d'accès de l'opérateur .%s. à %C a déjà été spécifiée"
 
-#: fortran/decl.c:8679
+#: fortran/decl.c:8698
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED statement at %C"
 msgstr "Instruction PROTECTED à %C"
 
-#: fortran/decl.c:8717
+#: fortran/decl.c:8736
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr "Erreur de syntaxe dans l'instruction PROTECTED à %C"
 
-#: fortran/decl.c:8741
+#: fortran/decl.c:8760
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr "L'instruction PRIVATE à %C est uniquement permise dans la partie de la spécification d'un module"
 
-#: fortran/decl.c:8778
+#: fortran/decl.c:8797
 #, gcc-internal-format, gfc-internal-format
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr "L'instruction PUBLIC à %C est uniquement permise dans la partie de la spécification d'un module"
 
-#: fortran/decl.c:8806
+#: fortran/decl.c:8825
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr "Nom de variable attendu à %C dans l'instruction PARAMETER"
 
-#: fortran/decl.c:8813
+#: fortran/decl.c:8832
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr "Signe = attendu dans l'instruction PARAMETER à %C"
 
-#: fortran/decl.c:8819
+#: fortran/decl.c:8838
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr "Expression attendue à %C dans l'instruction PARAMETER"
 
-#: fortran/decl.c:8839
+#: fortran/decl.c:8858
 #, gcc-internal-format, gfc-internal-format
 msgid "Initializing already initialized variable at %C"
 msgstr "Initialisation d'une variable déjà initialisée à %C"
 
 #. With legacy PARAMETER statements, don't expect a terminating ')'.
-#: fortran/decl.c:8864
+#: fortran/decl.c:8883
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER without '()' at %C"
 msgstr "PARAMETER sans « () » à %C"
 
-#: fortran/decl.c:8880
+#: fortran/decl.c:8899
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr "Caractères inattendus dans l'instruction PARAMETER à %C"
 
-#: fortran/decl.c:8899 fortran/decl.c:8955
+#: fortran/decl.c:8918 fortran/decl.c:8974
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-static%>"
 msgstr "%s à %C est une extension DEC, activez-la avec %<-fdec-static%>"
 
-#: fortran/decl.c:8934
+#: fortran/decl.c:8953
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in AUTOMATIC statement at %C"
 msgstr "Liste d'entités attendue dans l'instruction AUTOMATIC à %C"
 
-#: fortran/decl.c:8941
+#: fortran/decl.c:8960
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in AUTOMATIC statement at %C"
 msgstr "Erreur de syntaxe dans l'instruction AUTOMATIC à %C"
 
-#: fortran/decl.c:8990
+#: fortran/decl.c:9009
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in STATIC statement at %C"
 msgstr "Liste d'entités attendue dans l'instruction STATIC à %C"
 
-#: fortran/decl.c:8997
+#: fortran/decl.c:9016
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in STATIC statement at %C"
 msgstr "Erreur de syntaxe dans l'instruction STATIC à %C"
 
-#: fortran/decl.c:9016
+#: fortran/decl.c:9035
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr "L'instruction SAVE générale à %C suit une instruction SAVE précédente"
 
-#: fortran/decl.c:9027
+#: fortran/decl.c:9046
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr "L'instruction SAVE à %C suit une instruction SAVE générale"
 
-#: fortran/decl.c:9073
+#: fortran/decl.c:9092
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr "Erreur de syntaxe dans l'instruction SAVE à %C"
 
-#: fortran/decl.c:9087
+#: fortran/decl.c:9106
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr "VALUE n'est pas autorisé à l'intérieur de BLOCK à %C"
 
-#: fortran/decl.c:9091
+#: fortran/decl.c:9110
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE statement at %C"
 msgstr "Instruction VALUE à %C"
 
-#: fortran/decl.c:9129
+#: fortran/decl.c:9148
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VALUE statement at %C"
 msgstr "Erreur de syntaxe dans l'instruction VALUE à %C"
 
-#: fortran/decl.c:9141
+#: fortran/decl.c:9160
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE statement at %C"
 msgstr "Instruction VOLATILE à %C"
 
-#: fortran/decl.c:9168
+#: fortran/decl.c:9187
 #, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr "Spécification de VOLATILE pour la variable co-tableau %qs à %C qui est associée à use ou à l'hôte"
 
-#: fortran/decl.c:9193
+#: fortran/decl.c:9212
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr "Erreur de syntaxe dans l'instruction VOLATILE à %C"
 
-#: fortran/decl.c:9205
+#: fortran/decl.c:9224
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS statement at %C"
 msgstr "Instruction ASYNCHRONOUS à %C"
 
-#: fortran/decl.c:9249
+#: fortran/decl.c:9268
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr "Erreur de syntaxe dans l'instruction ASYNCHRONOUS à %C"
 
-#: fortran/decl.c:9274
+#: fortran/decl.c:9293
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE declaration at %C"
 msgstr "Déclaration de MODULE PROCEDURE à %C"
 
-#: fortran/decl.c:9367
+#: fortran/decl.c:9386
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr "MODULE PROCEDURE à %C doit être dans une interface de module générique"
 
-#: fortran/decl.c:9425
+#: fortran/decl.c:9444
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr "La procédure intrinsèque à %L ne peut pas être un MODULE PROCEDURE"
 
-#: fortran/decl.c:9474
+#: fortran/decl.c:9493
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr "Symbole ambigu dans la définition TYPE à %C"
 
-#: fortran/decl.c:9483
+#: fortran/decl.c:9502
 #, gcc-internal-format
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr "Le symbole %qs à %C n'a pas été défini précédemment"
 
-#: fortran/decl.c:9489
+#: fortran/decl.c:9508
 #, gcc-internal-format
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr "%qs dans l'expression EXTENDS à %C n'est pas un type dérivé"
 
-#: fortran/decl.c:9496
+#: fortran/decl.c:9515
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr "%qs ne peut pas être étendu à %C car il est BIND(C)"
 
-#: fortran/decl.c:9503
+#: fortran/decl.c:9522
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr "%qs ne peut pas être étendu à %C car il est un type SEQUENCE"
 
-#: fortran/decl.c:9526
+#: fortran/decl.c:9545
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr "Le type dérivé à %C peut uniquement être PRIVATE dans la partie de spécification d'un module"
 
-#: fortran/decl.c:9538
+#: fortran/decl.c:9557
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr "Le type dérivé à %C peut uniquement être PUBLIC dans la partie de spécification d'un module"
 
-#: fortran/decl.c:9559
+#: fortran/decl.c:9578
 #, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
 msgstr "Type ABSTRACT à %C"
 
-#: fortran/decl.c:9605
+#: fortran/decl.c:9624
 #, gcc-internal-format, gfc-internal-format
 msgid "Failed to create structure type '%s' at %C"
 msgstr "Échec lors de la création du type structure « %s » à %C"
 
-#: fortran/decl.c:9611
+#: fortran/decl.c:9630
 #, gcc-internal-format
 msgid "Type definition of %qs at %C was already defined at %L"
 msgstr "La définition du type de %qs à %C a déjà été définie à %L"
 
-#: fortran/decl.c:9658
+#: fortran/decl.c:9677
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after MAP statement at %C"
 msgstr "Rebut après l'instruction MAP à %C"
 
-#: fortran/decl.c:9691
+#: fortran/decl.c:9710
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after UNION statement at %C"
 msgstr "Rebut après l'instruction UNION à %C"
 
-#: fortran/decl.c:9726
+#: fortran/decl.c:9745
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr "%s à %C est une extension DEC, activez-la avec %<-fdec-structure%>"
 
-#: fortran/decl.c:9740
+#: fortran/decl.c:9759
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected in non-nested structure declaration at %C"
 msgstr "Nom de structure attendu dans la déclaration de structure non imbriquée à %C"
 
-#: fortran/decl.c:9758
+#: fortran/decl.c:9777
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after non-nested STRUCTURE statement at %C"
 msgstr "Rebut après l'instruction STRUCTURE non imbriquée à %C"
 
-#: fortran/decl.c:9765
+#: fortran/decl.c:9784
 #, gcc-internal-format
 msgid "Structure name %qs at %C cannot be the same as an intrinsic type"
 msgstr "Le nom de structure %qs à %C ne peut pas être le même qu'un type intrinsèque"
 
-#: fortran/decl.c:9926
+#: fortran/decl.c:9947
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr ":: attendu dans la définition de TYPE à %C"
 
-#: fortran/decl.c:9954
+#: fortran/decl.c:9975
 #, gcc-internal-format
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr "Le nom de type %qs à %C ne peut pas être le même qu'un type intrinsèque"
 
-#: fortran/decl.c:9964
+#: fortran/decl.c:9986
 #, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr "Le nom du type dérivé %qs à %C a déjà le type de base %s"
 
-#: fortran/decl.c:9981
+#: fortran/decl.c:9989
+#, fuzzy, gcc-internal-format
+#| msgid "Derived type name %qs at %C already has a basic type of %s"
+msgid "Derived type name %qs at %C already has a basic type"
+msgstr "Le nom du type dérivé %qs à %C a déjà le type de base %s"
+
+#: fortran/decl.c:10006
 #, gcc-internal-format
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr "La définition du type dérivé %qs à %C a déjà été défini"
 
-#: fortran/decl.c:10042
+#: fortran/decl.c:10067
 #, gcc-internal-format, gfc-internal-format
 msgid "Garbage after PARAMETERIZED TYPE declaration at %C"
 msgstr "Rebut après la déclaration PARAMETERIZED TYPE à %C"
 
-#: fortran/decl.c:10126
+#: fortran/decl.c:10151
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr "Le pointé de type Cray à %C ne peut pas être un tableau de forme tacite"
 
-#: fortran/decl.c:10146
+#: fortran/decl.c:10171
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM and ENUMERATOR at %C"
 msgstr "ENUM et ENUMERATOR à %C"
 
-#: fortran/decl.c:10178
+#: fortran/decl.c:10203
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr "L'énumérateur excède le type entier du C à %C"
 
-#: fortran/decl.c:10257
+#: fortran/decl.c:10282
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr "ENUMERATOR %L pas initialisé avec une expression entière"
 
-#: fortran/decl.c:10305
+#: fortran/decl.c:10330
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr "Instruction de définition ENUM attendue avant %C"
 
-#: fortran/decl.c:10341
+#: fortran/decl.c:10366
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr "Erreur de syntaxe dans la définition ENUMERATOR à %C"
 
-#: fortran/decl.c:10388 fortran/decl.c:10403
+#: fortran/decl.c:10413 fortran/decl.c:10428
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate access-specifier at %C"
 msgstr "Spécificateurs d'accès dupliqués à %C"
 
-#: fortran/decl.c:10423
+#: fortran/decl.c:10448
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr "Les attributs de liaison spécifient déjà « PASS », NOPASS illégal à %C"
 
-#: fortran/decl.c:10443
+#: fortran/decl.c:10468
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr "Les attributs de liaison spécifient déjà « PASS »; PASS illégal à %C"
 
-#: fortran/decl.c:10470
+#: fortran/decl.c:10495
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate POINTER attribute at %C"
 msgstr "Attribut POINTER dupliqué à %C"
 
-#: fortran/decl.c:10488
+#: fortran/decl.c:10513
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr "NON_OVERRIDABLE dupliqué à %C"
 
-#: fortran/decl.c:10504
+#: fortran/decl.c:10529
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DEFERRED at %C"
 msgstr "DEFERRED dupliqué à %C"
 
-#: fortran/decl.c:10517
+#: fortran/decl.c:10542
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected access-specifier at %C"
 msgstr "Spécificateur d'accès attendu à %C"
 
-#: fortran/decl.c:10519
+#: fortran/decl.c:10544
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr "Attribut de liaison attendu à %C"
 
-#: fortran/decl.c:10527
+#: fortran/decl.c:10552
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED can't both appear at %C"
 msgstr "NON_OVERRIDABLE et DEFERRED ne peuvent pas apparaître tous les deux à %C"
 
-#: fortran/decl.c:10539
+#: fortran/decl.c:10564
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr "L'attribut POINTER est requis pour un composant de pointeur de procédure à %C"
 
-#: fortran/decl.c:10581
+#: fortran/decl.c:10606
 #, gcc-internal-format
 msgid "Interface-name expected after %<(%> at %C"
 msgstr "Nom d'interface attendu après %<(%> à %C"
 
-#: fortran/decl.c:10587
+#: fortran/decl.c:10612
 #, gcc-internal-format
 msgid "%<)%> expected at %C"
 msgstr "%<)%> attendu à %C"
 
-#: fortran/decl.c:10607
+#: fortran/decl.c:10632
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr "Une interface doit être spécifiée pour une liaison DEFERRED à %C"
 
-#: fortran/decl.c:10612
+#: fortran/decl.c:10637
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr "PROCEDURE(interface) à %C devrait être déclarée DEFERRED"
 
-#: fortran/decl.c:10635
+#: fortran/decl.c:10660
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr "Nom de liaison attendu à %C"
 
-#: fortran/decl.c:10639
+#: fortran/decl.c:10664
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
 msgstr "Liste PROCEDURE à %C"
 
-#: fortran/decl.c:10651
+#: fortran/decl.c:10676
 #, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr "%<=> target%> est invalide pour la liaison DEFERRED à %C"
 
-#: fortran/decl.c:10657
+#: fortran/decl.c:10682
 #, gcc-internal-format
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr "%<::%> nécessaire dans une liaison PROCEDURE avec une cible explicite à %C"
 
-#: fortran/decl.c:10667
+#: fortran/decl.c:10692
 #, gcc-internal-format
 msgid "Expected binding target after %<=>%> at %C"
 msgstr "Cible de liaison attendue après %<=>%> à %C"
 
-#: fortran/decl.c:10684
+#: fortran/decl.c:10709
 #, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr "Le type %qs contenant la liaison DEFERRED à %C n'est pas ABSTRACT"
 
-#: fortran/decl.c:10695
+#: fortran/decl.c:10720
 #, gcc-internal-format
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr "Il y a déjà une procédure avec le nom de liaison %qs pour le type dérivé %qs à %C"
 
-#: fortran/decl.c:10746
+#: fortran/decl.c:10771
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr "Le GENERIC à %C doit être à l'intérieur du type dérivé CONTAINS"
 
-#: fortran/decl.c:10766
+#: fortran/decl.c:10791
 #, gcc-internal-format
 msgid "Expected %<::%> at %C"
 msgstr "%<::%> attendu à %C"
 
-#: fortran/decl.c:10778
+#: fortran/decl.c:10803
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected generic name or operator descriptor at %C"
 msgstr "Nom générique ou descripteur d'opérateur attendu à %C"
 
-#: fortran/decl.c:10799
+#: fortran/decl.c:10824
 #, gcc-internal-format, gfc-internal-format
 msgid "Malformed GENERIC statement at %C"
 msgstr "Instruction GENERIC mal formée à %C"
 
-#: fortran/decl.c:10810
+#: fortran/decl.c:10835
 #, gcc-internal-format
 msgid "Expected %<=>%> at %C"
 msgstr "%<=>%> attendu à %C"
 
-#: fortran/decl.c:10846
+#: fortran/decl.c:10871
 #, gcc-internal-format
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr "Il y a déjà une procédure non générique avec le nom de liaison %qs pour le type dérivé %qs à %C"
 
-#: fortran/decl.c:10854
+#: fortran/decl.c:10879
 #, gcc-internal-format
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr "La liaison à %C doit avoir le même accès que la liaison %qs déjà définie"
 
-#: fortran/decl.c:10902
+#: fortran/decl.c:10927
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr "Nom de liaison spécifique attendu à %C"
 
-#: fortran/decl.c:10912
+#: fortran/decl.c:10937
 #, gcc-internal-format
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr "%qs est déjà défini comme liaison spécifique pour le %qs générique à %C"
 
-#: fortran/decl.c:10930
+#: fortran/decl.c:10955
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr "Rebut après la liaison GENERIC à %C"
 
-#: fortran/decl.c:10965
+#: fortran/decl.c:10990
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr "La déclaration FINAL à %C doit être à l'intérieur d'une section CONTAINS du type dérivé"
 
-#: fortran/decl.c:10976
+#: fortran/decl.c:11001
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr "La déclaration de type dérivé avec FINAL à %C doit être dans la partie de spécification d'un MODULE"
 
-#: fortran/decl.c:10998
+#: fortran/decl.c:11023
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr "FINAL vide à %C"
 
-#: fortran/decl.c:11005
+#: fortran/decl.c:11030
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr "Nom de procédure de module attendu à %C"
 
-#: fortran/decl.c:11015
+#: fortran/decl.c:11040
 #, gcc-internal-format
 msgid "Expected %<,%> at %C"
 msgstr "%<,%> attendu à %C"
 
-#: fortran/decl.c:11021
+#: fortran/decl.c:11046
 #, gcc-internal-format
 msgid "Unknown procedure name %qs at %C"
 msgstr "Nom de procédure %qs inconnu à %C"
 
-#: fortran/decl.c:11034
+#: fortran/decl.c:11059
 #, gcc-internal-format
 msgid "%qs at %C is already defined as FINAL procedure"
 msgstr "%qs à %C est déjà défini comme procédure FINAL"
 
-#: fortran/decl.c:11104
+#: fortran/decl.c:11129
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr "Attribut inconnu dans l'instruction !GCC$ ATTRIBUTES à %C"
 
-#: fortran/decl.c:11150
+#: fortran/decl.c:11175
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr "Erreur de syntaxe dans l'instruction !GCC$ ATTRIBUTES à %C"
 
-#: fortran/decl.c:11170
+#: fortran/decl.c:11195
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive requires a non-negative integral constant less than or equal to %u at %C"
 msgstr "Directive %<GCC unroll%> requiert une constante entière non négative plus petite ou égale à %u à %C"
 
-#: fortran/decl.c:11184
+#: fortran/decl.c:11209
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ UNROLL directive at %C"
 msgstr "Erreur de syntaxe dans la directive !GCC$ UNROLL à %C"
@@ -53239,27 +53323,27 @@
 msgid "BOZ literal at %L used to initialize non-integer variable %qs"
 msgstr "Un littéral BOZ à %L est utilisé pour initialiser la variable non entière %qs"
 
-#: fortran/expr.c:3369 fortran/resolve.c:10197
+#: fortran/expr.c:3369 fortran/resolve.c:10210
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal at %L outside a DATA statement and outside INT/REAL/DBLE/CMPLX"
 msgstr "Littéral BOZ à %L en dehors d'une instruction DATA et en dehors de INT/REAL/DBLE/CMPLX"
 
-#: fortran/expr.c:3380 fortran/resolve.c:10208
+#: fortran/expr.c:3380 fortran/resolve.c:10221
 #, gcc-internal-format
 msgid "BOZ literal at %L is bitwise transferred non-integer symbol %qs"
 msgstr "Le littéral BOZ à %L est le symbole non entier %qs transféré bit à bit"
 
-#: fortran/expr.c:3388 fortran/resolve.c:10217
+#: fortran/expr.c:3388 fortran/resolve.c:10230
 #, gcc-internal-format
 msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "Débordement arithmétique vers le bas du BOZ transféré bit à bit à %L. Cette vérification peut être désactivée avec l'option %<-fno-range-check%>"
 
-#: fortran/expr.c:3392 fortran/resolve.c:10221
+#: fortran/expr.c:3392 fortran/resolve.c:10234
 #, gcc-internal-format
 msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "Débordement arithmétique du BOZ transféré bit à bit à %L. Cette vérification peut être désactivée avec l'option %<-fno-range-check%>"
 
-#: fortran/expr.c:3396 fortran/resolve.c:10225
+#: fortran/expr.c:3396 fortran/resolve.c:10238
 #, gcc-internal-format
 msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "NaN (pas un nombre) arithmétique du BOZ transféré bit à bit à %L. Cette vérification peut être désactivée avec l'option %<-fno-range-check%>"
@@ -53269,147 +53353,147 @@
 msgid "The assignment to a KIND or LEN component of a parameterized type at %L is not allowed"
 msgstr "L'affectation à un composant KIND ou LEN d'un type paramétrisé à %L n'est pas permis"
 
-#: fortran/expr.c:3426
+#: fortran/expr.c:3429
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible types in DATA statement at %L; attempted conversion of %s to %s"
 msgstr "Types incompatibles dans l'instruction DATA à %L; tentative de conversion de %s en %s"
 
-#: fortran/expr.c:3465
+#: fortran/expr.c:3468
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is not a POINTER at %L"
 msgstr "La cible de l'affectation du pointeur n'est pas un POINTER à %L"
 
-#: fortran/expr.c:3473
+#: fortran/expr.c:3476
 #, gcc-internal-format
 msgid "%qs in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgstr "%qs dans l'affectation de pointeur à %L ne peut pas être une l-valeur puisqu'il est une procédure"
 
-#: fortran/expr.c:3496
+#: fortran/expr.c:3499
 #, gcc-internal-format
 msgid "Expected bounds specification for %qs at %L"
 msgstr "Spécification de limites attendue pour %qs à %L"
 
-#: fortran/expr.c:3501
+#: fortran/expr.c:3504
 #, gcc-internal-format
 msgid "Bounds specification for %qs in pointer assignment at %L"
 msgstr "Spécification des limites pour %qs dans une affectation de pointeur à %L"
 
-#: fortran/expr.c:3514
+#: fortran/expr.c:3517
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower bound has to be present at %L"
 msgstr "La limite inférieur doit être présente à %L"
 
-#: fortran/expr.c:3520
+#: fortran/expr.c:3523
 #, gcc-internal-format, gfc-internal-format
 msgid "Stride must not be present at %L"
 msgstr "Le pas ne doit pas être présent à %L"
 
-#: fortran/expr.c:3532
+#: fortran/expr.c:3535
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the upper bounds must be specified at %L"
 msgstr "Soit aucune ou soit toutes les limites supérieurs doivent être spécifiées à %L"
 
-#: fortran/expr.c:3558
+#: fortran/expr.c:3561
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %L shall not have a coindex"
 msgstr "L'objet pointeur à %L ne sera point un co-index"
 
-#: fortran/expr.c:3579
+#: fortran/expr.c:3582
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure pointer assignment at %L"
 msgstr "Affectation de pointeur de procédure invalide à %L"
 
-#: fortran/expr.c:3603
+#: fortran/expr.c:3606
 #, gcc-internal-format
 msgid "Function result %qs is invalid as proc-target in procedure pointer assignment at %L"
 msgstr "Le résultat de la fonction %qs est invalide comme cible de procédure dans l'affectation du pointeur de procédure à %L"
 
-#: fortran/expr.c:3612
+#: fortran/expr.c:3615
 #, gcc-internal-format
 msgid "Abstract interface %qs is invalid in procedure pointer assignment at %L"
 msgstr "L'interface abstraite %qs est invalide dans l'affectation du pointeur de procédure à %L"
 
-#: fortran/expr.c:3622
+#: fortran/expr.c:3625
 #, gcc-internal-format
 msgid "Statement function %qs is invalid in procedure pointer assignment at %L"
 msgstr "La fonction-instruction %qs est invalide dans l'affectation du pointeur de procédure à %L"
 
-#: fortran/expr.c:3628
+#: fortran/expr.c:3631
 #, gcc-internal-format
 msgid "Internal procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "La procédure interne %qs est invalide dans l'affectation du pointeur de procédure à %L"
 
-#: fortran/expr.c:3635
+#: fortran/expr.c:3638
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L is invalid in procedure pointer assignment"
 msgstr "L'intrinsèque %qs à %L est invalide dans une affectation du pointeur de procédure"
 
-#: fortran/expr.c:3643
+#: fortran/expr.c:3646
 #, gcc-internal-format
 msgid "Nonintrinsic elemental procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "La procédure élémentaire non intrinsèque %qs est invalide dans l'affectation du pointeur de procédure à %L"
 
-#: fortran/expr.c:3666
+#: fortran/expr.c:3669
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in the procedure pointer assignment at %L: mismatch in the calling convention"
 msgstr "Désaccord dans l'affectation du pointeur de procédure à %L: désaccord dans la convention d'appel"
 
-#: fortran/expr.c:3719
+#: fortran/expr.c:3722
 #, gcc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %qs is not a subroutine"
 msgstr "Désaccord d'interface dans l'affectation du pointeur de procédure à %L: %qs n'est pas une sous-routine"
 
-#: fortran/expr.c:3729 fortran/expr.c:3744
+#: fortran/expr.c:3732 fortran/expr.c:3747
 #, gcc-internal-format
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr "Interface explicite requise pour le composant %qs à %L: %s"
 
-#: fortran/expr.c:3735 fortran/expr.c:3750 fortran/resolve.c:2566
+#: fortran/expr.c:3738 fortran/expr.c:3753 fortran/resolve.c:2566
 #, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr "Interface explicite requise pour %qs à %L: %s"
 
-#: fortran/expr.c:3762
+#: fortran/expr.c:3765
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %s"
 msgstr "Interface non concordante dans l'affectation du pointeur de procédure à %L: %s"
 
-#: fortran/expr.c:3771
+#: fortran/expr.c:3774
 #, gcc-internal-format
 msgid "Procedure pointer target %qs at %L must be either an intrinsic, host or use associated, referenced or have the EXTERNAL attribute"
 msgstr "La cible du pointeur de procédure %qs à %L doit être un intrinsèque, associé à l'hôte or à use, référencé ou avoir l'attribut EXTERNAL"
 
-#: fortran/expr.c:3788
+#: fortran/expr.c:3791
 #, gcc-internal-format, gfc-internal-format
 msgid "Data-pointer-object at %L must be unlimited polymorphic, or of a type with the BIND or SEQUENCE attribute, to be compatible with an unlimited polymorphic target"
 msgstr "L'objet pointeur de données à %L doit être polymorphique illimité ou être d'un type avec l'attribut BIND ou SEQUENCE pour être compatible avec une cible polymorphique illimitée"
 
-#: fortran/expr.c:3793
+#: fortran/expr.c:3796
 #, gcc-internal-format, gfc-internal-format
 msgid "Different types in pointer assignment at %L; attempted assignment of %s to %s"
 msgstr "Types différents dans une affectation de pointeur à %L; tentative d'affecter %s à %s"
 
-#: fortran/expr.c:3802
+#: fortran/expr.c:3805
 #, gcc-internal-format, gfc-internal-format
 msgid "Different kind type parameters in pointer assignment at %L"
 msgstr "Paramètres de type de sous-type différents dans l'affectation de pointeur à %L"
 
-#: fortran/expr.c:3809
+#: fortran/expr.c:3812
 #, gcc-internal-format, gfc-internal-format
 msgid "Different ranks in pointer assignment at %L"
 msgstr "Rangs différents dans l'affectation du pointeur à %L"
 
-#: fortran/expr.c:3828
+#: fortran/expr.c:3831
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is smaller than size of the pointer (%ld < %ld) at %L"
 msgstr "La cible de réorganisation du rang est plus petite que la taille du pointeur (%ld < %ld) à %L"
 
-#: fortran/expr.c:3841
+#: fortran/expr.c:3844
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target must be rank 1 or simply contiguous at %L"
 msgstr "La cible de réorganisation du rang doit avoir le rang 1 ou être simplement contigüe à %L"
 
-#: fortran/expr.c:3845
+#: fortran/expr.c:3848
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is not rank 1 at %L"
 msgstr "La cible de réorganisation du rang n'a pas le rang 1 à %L"
@@ -53417,147 +53501,152 @@
 #. The test above might need to be extend when F08, Note 5.4 has to be
 #. interpreted in the way that target and pointer with the same coindex
 #. are allowed.
-#: fortran/expr.c:3877 fortran/expr.c:3925
+#: fortran/expr.c:3880 fortran/expr.c:3928
 #, gcc-internal-format, gfc-internal-format
 msgid "Data target at %L shall not have a coindex"
 msgstr "La cible de données à %L n'aura point de co-index"
 
-#: fortran/expr.c:3880
+#: fortran/expr.c:3883
 #, gcc-internal-format, gfc-internal-format
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr "L'expression cible dans l'affectation de pointeur à %L doit fournir un pointeur comme résultat"
 
-#: fortran/expr.c:3888
+#: fortran/expr.c:3891
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr "La cible de l'affectation du pointeur n'est ni TARGET ni POINTER à %L"
 
-#: fortran/expr.c:3895
+#: fortran/expr.c:3898
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr "Mauvaise cible dans l'affectation du pointeur dans la procédure PURE à %L"
 
-#: fortran/expr.c:3904
+#: fortran/expr.c:3907
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr "Affectation de pointeur avec un indice de vecteur dans le membre de droite à %L"
 
-#: fortran/expr.c:3912
+#: fortran/expr.c:3915
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr "La cible de l'affectation du pointeur a l'attribut PROTECTED à %L"
 
-#: fortran/expr.c:3936
+#: fortran/expr.c:3939
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to contiguous pointer from non-contiguous target at %L"
 msgstr "Affectation à un pointeur contigu depuis une cible non contigüe à %L"
 
-#: fortran/expr.c:3975
+#: fortran/expr.c:3978
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr "Le pointeur à %L dans l'affectation de pointeur pourrait vivre plus longtemps que la cible pointée"
 
-#: fortran/expr.c:4051 fortran/resolve.c:1452
+#: fortran/expr.c:4054 fortran/resolve.c:1452
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr "La cible de l'initialisation de pointeur à %L ne doit pas être ALLOCATABLE"
 
-#: fortran/expr.c:4057
+#: fortran/expr.c:4060
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr "La cible de l'initialisation du pointeur à %L ne doit pas avoir l'attribut TARGET"
 
-#: fortran/expr.c:4072 fortran/resolve.c:1458
+#: fortran/expr.c:4075 fortran/resolve.c:1458
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr "La cible de l'initialisation du pointeur à %L doit avoir l'attribut SAVE"
 
-#: fortran/expr.c:4084
+#: fortran/expr.c:4087
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr "La cible de l'initialisation du pointeur de procédure à %L ne peut pas être un pointeur de procédure"
 
-#: fortran/expr.c:5512
+#: fortran/expr.c:4557
+#, gcc-internal-format
+msgid "generate_isocbinding_initializer(): bad iso_c_binding type, expected %<c_ptr%> or %<c_funptr%>"
+msgstr ""
+
+#: fortran/expr.c:5568
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr "Fortran 2008: Fonctions pointeurs dans le contexte de la définition de variable (%s) à %L"
 
-#: fortran/expr.c:5520
+#: fortran/expr.c:5576
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr "Expression non variable dans le contexte de définition de variable (%s) à %L"
 
-#: fortran/expr.c:5528
+#: fortran/expr.c:5584
 #, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr "Constante nommée %qs dans le contexte de la définition de variable (%s) à %L"
 
-#: fortran/expr.c:5537
+#: fortran/expr.c:5593
 #, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr "%qs dans le contexte de définition de variable (%s) à %L n'est pas une variable"
 
-#: fortran/expr.c:5548
+#: fortran/expr.c:5604
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr "Non POINTER dans le contexte d'association de pointeur (%s) à %L"
 
-#: fortran/expr.c:5557
+#: fortran/expr.c:5613
 #, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr "Type inaccessible dans le contexte de définition de variable (%s) à %L"
 
-#: fortran/expr.c:5570
+#: fortran/expr.c:5626
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr "LOCK_TYPE dans le contexte de définition de variable (%s) à %L"
 
-#: fortran/expr.c:5583
+#: fortran/expr.c:5639
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr "LOCK_EVENT dans un contexte de définition de variable (%s) à %L"
 
-#: fortran/expr.c:5613
+#: fortran/expr.c:5669
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr "Argument muet %qs avec INTENT(IN) dans un contexte d'association de pointeur (%s) à %L"
 
-#: fortran/expr.c:5621
+#: fortran/expr.c:5677
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr "Argument muet %qs avec INTENT(IN) dans le contexte de définition de variable (%s) à %L"
 
-#: fortran/expr.c:5634
+#: fortran/expr.c:5690
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a pointer association context (%s) at %L"
 msgstr "La variable %qs est PROTECTED et ne peut pas apparaître dans le contexte d'association de pointeur (%s) à %L"
 
-#: fortran/expr.c:5642
+#: fortran/expr.c:5698
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a variable definition context (%s) at %L"
 msgstr "La variable %qs est PROTECTED et ne peut pas apparaître dans le contexte de définition de variable (%s) à %L"
 
-#: fortran/expr.c:5654
+#: fortran/expr.c:5710
 #, gcc-internal-format
 msgid "Variable %qs can not appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr "La variable %qs ne peut pas apparaître dans le contexte de définition de variable (%s) à %L dans la procédure PURE"
 
-#: fortran/expr.c:5713
+#: fortran/expr.c:5769
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
 msgstr "%qs à %L associé à la cible vecteur indexé ne peut pas être utilisé dans le contexte de définition de variable (%s)"
 
-#: fortran/expr.c:5717
+#: fortran/expr.c:5773
 #, gcc-internal-format
 msgid "%qs at %L associated to expression can not be used in a variable definition context (%s)"
 msgstr "%qs à %L associé a une expression ne peut pas être utilisé dans un contexte de définition de variable (%s)"
 
-#: fortran/expr.c:5728
+#: fortran/expr.c:5784
 #, gcc-internal-format
 msgid "Associate-name %qs can not appear in a variable definition context (%s) at %L because its target at %L can not, either"
 msgstr "Le nom associé %qs ne peut pas apparaître dans le contexte de définition de variable (%s) à %L car sa cible à %L ne le peut pas non plus"
 
-#: fortran/expr.c:5770
+#: fortran/expr.c:5826
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr "Éléments avec la même valeur à %L et %L dans l'indice de vecteur dans le contexte de définition de variable (%s)"
@@ -53567,22 +53656,22 @@
 msgid "can't open input file: %s"
 msgstr "ne peut ouvrir le fichier d'entrée: %s"
 
-#: fortran/frontend-passes.c:190
+#: fortran/frontend-passes.c:192
 #, gcc-internal-format
 msgid "No location in statement"
 msgstr "Pas d'emplacement dans l'instruction"
 
-#: fortran/frontend-passes.c:205
+#: fortran/frontend-passes.c:207
 #, gcc-internal-format, gfc-internal-format
 msgid "No location in expression near %L"
 msgstr "Pas d'emplacement dans l'expression près de %L"
 
-#: fortran/frontend-passes.c:409
+#: fortran/frontend-passes.c:414
 #, gcc-internal-format
 msgid "Illegal id in copy_walk_reduction_arg"
 msgstr "Identifiant illégal dans copy_walk_reduction_arg"
 
-#: fortran/frontend-passes.c:817 fortran/trans-array.c:1182
+#: fortran/frontend-passes.c:822 fortran/trans-array.c:1182
 #: fortran/trans-array.c:6440 fortran/trans-array.c:7864
 #: fortran/trans-intrinsic.c:7307
 #, gcc-internal-format, gfc-internal-format
@@ -53589,67 +53678,67 @@
 msgid "Creating array temporary at %L"
 msgstr "Création d'un tableau temporaire à %L"
 
-#: fortran/frontend-passes.c:842 fortran/frontend-passes.c:846
+#: fortran/frontend-passes.c:847 fortran/frontend-passes.c:851
 #, gcc-internal-format
 msgid "Removing call to function %qs at %L"
 msgstr "Suppression de l'appel à la fonction %qs à %L"
 
-#: fortran/frontend-passes.c:1273 fortran/frontend-passes.c:1312
+#: fortran/frontend-passes.c:1278 fortran/frontend-passes.c:1317
 #, gcc-internal-format
 msgid "bad expression"
 msgstr "mauvaise expression"
 
-#: fortran/frontend-passes.c:1308
+#: fortran/frontend-passes.c:1313
 #, gcc-internal-format
 msgid "bad op"
 msgstr "mauvais op"
 
-#: fortran/frontend-passes.c:2161
+#: fortran/frontend-passes.c:2166
 #, gcc-internal-format
 msgid "illegal OP in optimize_comparison"
 msgstr "OP illégal dans optimize_comparison"
 
-#: fortran/frontend-passes.c:2407
+#: fortran/frontend-passes.c:2412
 #, gcc-internal-format
 msgid "Variable %qs at %L set to undefined value inside loop  beginning at %L as INTENT(OUT) argument to subroutine %qs"
 msgstr "La variable %qs à %L a une valeur non définie à l'intérieur de la boucle commençant à %L comme argument INTENT(OUT) de la sous-routine %qs"
 
-#: fortran/frontend-passes.c:2414
+#: fortran/frontend-passes.c:2419
 #, gcc-internal-format
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to subroutine %qs"
 msgstr "La variable %qs à %L n'est pas définissable à l'intérieur de la boucle commençant à %L comme argument INTENT(INOUT) de la sous-routine %qs"
 
-#: fortran/frontend-passes.c:2637 fortran/frontend-passes.c:2661
+#: fortran/frontend-passes.c:2642 fortran/frontend-passes.c:2666
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L out of bounds (%ld < %ld) in loop beginning at %L"
 msgstr "La référence au tableau à %L est en dehors des limites (%ld < %ld) dans la boucle commençant à %L"
 
-#: fortran/frontend-passes.c:2646 fortran/frontend-passes.c:2670
+#: fortran/frontend-passes.c:2651 fortran/frontend-passes.c:2675
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L out of bounds (%ld > %ld) in loop beginning at %L"
 msgstr "La référence au tableau à %L est en dehors des limites (%ld > %ld) dans la boucle commençant à %L"
 
-#: fortran/frontend-passes.c:2730
+#: fortran/frontend-passes.c:2735
 #, gcc-internal-format
 msgid "Variable %qs at %L set to undefined value inside loop beginning at %L as INTENT(OUT) argument to function %qs"
 msgstr "La variable %qs à %L a une valeur non définie à l'intérieur de la boucle commençant à %L comme argument INTENT(OUT) de la fonction %qs"
 
-#: fortran/frontend-passes.c:2736
+#: fortran/frontend-passes.c:2741
 #, gcc-internal-format
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr "La variable %qs à %L n'est pas définissable à l'intérieur de la boucle commençant à %L comme argument INTENT(INOUT) de la fonction %qs"
 
-#: fortran/frontend-passes.c:3128 fortran/trans-expr.c:1581
+#: fortran/frontend-passes.c:3133 fortran/trans-expr.c:1581
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr "Le code pour réallouer le tableau allouable à %L sera ajouté"
 
-#: fortran/frontend-passes.c:3637
+#: fortran/frontend-passes.c:3642
 #, gcc-internal-format
 msgid "Scalarization using DIMEN_RANGE unimplemented"
 msgstr "La transformation en scalaire grâce à DIMEN_RANGE n'est pas implémentée"
 
-#: fortran/frontend-passes.c:4429
+#: fortran/frontend-passes.c:4434
 #, gcc-internal-format, gfc-internal-format
 msgid "Interchanging loops at %L"
 msgstr "Interchangeage de boucles à %L"
@@ -53769,12 +53858,12 @@
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "Le deuxième argument de l'affection définie à %L doit être INTENT(IN)"
 
-#: fortran/interface.c:970 fortran/resolve.c:16351
+#: fortran/interface.c:970 fortran/resolve.c:16378
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "Le premier argument de l'interface de l'opérateur à %L doit être INTENT(IN)"
 
-#: fortran/interface.c:977 fortran/resolve.c:16369
+#: fortran/interface.c:977 fortran/resolve.c:16396
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "Le deuxième argument de l'interface de l'opérateur à %L doit être INTENT(IN)"
@@ -54964,7 +55053,7 @@
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr "L'objet NAMELIST %qs dans la liste de noms %qs à %L est polymorphique et requiert une procédure d'entrée/sortie définie"
 
-#: fortran/io.c:3369 fortran/resolve.c:14263
+#: fortran/io.c:3369 fortran/resolve.c:14283
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr "Objet NAMELIST %qs dans la liste de noms %qs à %L avec des composants ALLOCATABLE ou POINTER"
@@ -55130,7 +55219,7 @@
 msgid "Integer too large at %C"
 msgstr "Entier trop grand à %C"
 
-#: fortran/match.c:580 fortran/parse.c:1132
+#: fortran/match.c:580 fortran/parse.c:1136
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many digits in statement label at %C"
 msgstr "Trop de chiffres dans l'étiquette de l'instruction à %C"
@@ -55891,57 +55980,57 @@
 msgid "Expected block name %qs of SELECT construct at %C"
 msgstr "Nom de bloc %qs attendu pour la construction SELECT à %C"
 
-#: fortran/match.c:6186
+#: fortran/match.c:6201
 #, gcc-internal-format, gfc-internal-format
 msgid "parse error in SELECT TYPE statement at %C"
 msgstr "erreur d'analyse dans l'instruction SELECT TYPE à %C"
 
-#: fortran/match.c:6211
+#: fortran/match.c:6226
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr "Le sélecteur dans SELECT TYPE à %C n'est pas une variable nommée; utilisez associate-name=>"
 
-#: fortran/match.c:6249
+#: fortran/match.c:6264
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr "Instruction CASE inattendue à %C"
 
-#: fortran/match.c:6301
+#: fortran/match.c:6316
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CASE specification at %C"
 msgstr "Erreur de syntaxe dans la spécification CASE à %C"
 
-#: fortran/match.c:6319
+#: fortran/match.c:6334
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected TYPE IS statement at %C"
 msgstr "Instruction TYPE IS inattendue à %C"
 
-#: fortran/match.c:6351
+#: fortran/match.c:6366
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr "La spécification de type ne spécifiera point un type dérivé d'une séquence ou un type avec l'attribut BIND dans SELECT TYPE à %C [F2003:C815]"
 
-#: fortran/match.c:6362
+#: fortran/match.c:6377
 #, gcc-internal-format, gfc-internal-format
 msgid "All the LEN type parameters in the TYPE IS statement at %C must be ASSUMED"
 msgstr "Tous les paramètres de type LEN dans l'instruction TYPE IS à %C doivent être ASSUMED"
 
-#: fortran/match.c:6373
+#: fortran/match.c:6388
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr "Erreur de syntaxe dans la spécification TYPE IS à %C"
 
-#: fortran/match.c:6449
+#: fortran/match.c:6464
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr "Erreur de syntaxe dans la spécification CLASS IS à %C"
 
-#: fortran/match.c:6572
+#: fortran/match.c:6587
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr "Instruction ELSEWHERE à %C pas englobée dans un bloc WHERE"
 
-#: fortran/match.c:6610
+#: fortran/match.c:6625
 #, gcc-internal-format
 msgid "Label %qs at %C doesn't match WHERE label %qs"
 msgstr "L'étiquette %qs à %C ne correspond pas à l'étiquette %qs de WHERE"
@@ -56092,189 +56181,189 @@
 msgid "mio_array_ref(): Unknown array ref"
 msgstr "mio_array_ref(): Référence de tableau inconnue"
 
-#: fortran/module.c:3716
+#: fortran/module.c:3718
 #, gcc-internal-format, gfc-internal-format
 msgid "Namelist %s cannot be renamed by USE association to %s"
 msgstr "La liste de noms %s ne peut pas être renommée par association USE à %s"
 
-#: fortran/module.c:4832
+#: fortran/module.c:4834
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr "!$OMP DECLARE REDUCTION ambigu dans le module %s à %L"
 
-#: fortran/module.c:4835
+#: fortran/module.c:4837
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr "!$OMP DECLARE REDUCTION précédent du module %s à %L"
 
-#: fortran/module.c:5029
+#: fortran/module.c:5031
 #, gcc-internal-format
 msgid "%qs of module %qs, imported at %C, is also the name of the current program unit"
 msgstr "%qs du module %qs, importé à %C, est aussi le nom de l'unité actuelle du programme"
 
-#: fortran/module.c:5381
+#: fortran/module.c:5383
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in module %qs"
 msgstr "Le symbole %qs référencé à %L n'est pas trouvé dans le module %qs"
 
-#: fortran/module.c:5388
+#: fortran/module.c:5390
 #, gcc-internal-format
 msgid "User operator %qs referenced at %L not found in module %qs"
 msgstr "L'opérateur utilisateur %qs référencé à %L n'est pas trouvé dans le module %qs"
 
-#: fortran/module.c:5393
+#: fortran/module.c:5395
 #, gcc-internal-format
 msgid "Intrinsic operator %qs referenced at %L not found in module %qs"
 msgstr "L'opérateur intrinsèque %qs référencé à %L n'est pas trouvé dans le module %qs"
 
-#: fortran/module.c:5628
+#: fortran/module.c:5630
 #, gcc-internal-format
 msgid "write_symbol(): bad module symbol %qs"
 msgstr "write_symbol(): mauvais symbole de module %qs"
 
-#: fortran/module.c:5961
+#: fortran/module.c:5963
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr "write_symtree(): Symbole pas écrit"
 
-#: fortran/module.c:6148
+#: fortran/module.c:6150
 #, gcc-internal-format
 msgid "Can't open module file %qs for writing at %C: %s"
 msgstr "N'a pu ouvrir le fichier module %qs en écriture à %C: %s"
 
-#: fortran/module.c:6169
+#: fortran/module.c:6171
 #, gcc-internal-format
 msgid "Error writing module file %qs for writing: %s"
 msgstr "Erreur en écrivant dans le fichier module %qs: %s"
 
-#: fortran/module.c:6180
+#: fortran/module.c:6182
 #, gcc-internal-format
 msgid "Can't delete module file %qs: %s"
 msgstr "Impossible d'effacer le fichier module %qs: %s"
 
-#: fortran/module.c:6183
+#: fortran/module.c:6185
 #, gcc-internal-format
 msgid "Can't rename module file %qs to %qs: %s"
 msgstr "Impossible de renommer le fichier module %qs en %qs: %s"
 
-#: fortran/module.c:6189
+#: fortran/module.c:6191
 #, gcc-internal-format
 msgid "Can't delete temporary module file %qs: %s"
 msgstr "Impossible de supprimer le fichier temporaire du module %qs: %s"
 
-#: fortran/module.c:6246
+#: fortran/module.c:6248
 #, gcc-internal-format
 msgid "Symbol %qs at %C already declared"
 msgstr "Symbole %qs à %C déjà déclaré"
 
-#: fortran/module.c:6317
+#: fortran/module.c:6319
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr "import_iso_c_binding_module(): Impossible de créer le symbole pour %s"
 
-#: fortran/module.c:6425 fortran/module.c:6769
+#: fortran/module.c:6427 fortran/module.c:6771
 #, gcc-internal-format
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr "Le symbole %qs, référencé à %L, n'est pas dans le standard sélectionné"
 
-#: fortran/module.c:6553
+#: fortran/module.c:6555
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr "Le symbole %qs référencé à %L n'est pas trouvé dans le module intrinsèque ISO_C_BINDING"
 
-#: fortran/module.c:6574 fortran/module.c:6607 fortran/module.c:6649
+#: fortran/module.c:6576 fortran/module.c:6609 fortran/module.c:6651
 #, gcc-internal-format
 msgid "Symbol %qs already declared"
 msgstr "Symbole %qs déjà déclaré"
 
-#: fortran/module.c:6754
+#: fortran/module.c:6756
 #, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr "L'utilisation du module intrinsèque %qs à %C est en conflit avec le nom de module non intrinsèque utilisé précédemment"
 
-#: fortran/module.c:6776
+#: fortran/module.c:6778
 #, gcc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr "L'utilisation de la constante nommée NUMERIC_STORAGE_SIZE du module intrinsèque ISO_FORTRAN_ENV à %L est incompatible avec l'option %qs"
 
-#: fortran/module.c:6844
+#: fortran/module.c:6846
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr "L'utilisation de la constante nommée NUMERIC_STORAGE_SIZE du module intrinsèque ISO_FORTRAN_ENV à %C est incompatible avec l'option %s"
 
-#: fortran/module.c:6898
+#: fortran/module.c:6900
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr "Le symbole %qs référencé à %L n'a pas été trouvé dans le modèle intrinsèque ISO_FORTRAN_ENV"
 
-#: fortran/module.c:6924
+#: fortran/module.c:6926
 #, gcc-internal-format, gfc-internal-format
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr "L'instruction USE à %C n'a pas de qualificatif ONLY"
 
-#: fortran/module.c:6953
+#: fortran/module.c:6955
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr "Module intrinsèque ISO_FORTRAN_ENV à %C"
 
-#: fortran/module.c:6965
+#: fortran/module.c:6967
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
 msgstr "Module ISO_C_BINDING à %C"
 
-#: fortran/module.c:6978
+#: fortran/module.c:6980
 #, gcc-internal-format
 msgid "Can't find an intrinsic module named %qs at %C"
 msgstr "N'a pu trouver un module intrinsèque nommé %qs à %C"
 
-#: fortran/module.c:6984
+#: fortran/module.c:6986
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr "Module IEEE_FEATURES à %C"
 
-#: fortran/module.c:6990
+#: fortran/module.c:6992
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr "Module IEEE_EXCEPTIONS à %C"
 
-#: fortran/module.c:6996
+#: fortran/module.c:6998
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr "Module IEEE_ARITHMETIC à %C"
 
-#: fortran/module.c:7006
+#: fortran/module.c:7008
 #, gcc-internal-format
 msgid "Can't open module file %qs for reading at %C: %s"
 msgstr "Ne peut ouvrir le fichier module %qs en lecture à %C: %s"
 
-#: fortran/module.c:7009
+#: fortran/module.c:7011
 #, gcc-internal-format
 msgid "Module file %qs has not been generated, either because the module does not contain a MODULE PROCEDURE or there is an error in the module."
 msgstr "Le fichier module %qs n'a pas été généré, soit parce que le module ne contient pas de MODULE PROCEDURE ou il y a une erreur dans le module."
 
-#: fortran/module.c:7020
+#: fortran/module.c:7022
 #, gcc-internal-format
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr "L'utilisation du module non intrinsèque %qs à %C est en conflit avec le nom de module intrinsèque utilisé précédemment"
 
-#: fortran/module.c:7043
+#: fortran/module.c:7045
 #, gcc-internal-format
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr "Le fichier %qs ouvert à %C n'est pas un fichier module GNU Fortran"
 
-#: fortran/module.c:7051
+#: fortran/module.c:7053
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr "Impossible de lire le fichier module %qs ouvert à %C car il a été créé par une version différente de GNU Fortran"
 
 # %s est « sub » ou rien.
-#: fortran/module.c:7066
+#: fortran/module.c:7068
 #, gcc-internal-format, gfc-internal-format
 msgid "Can't USE the same %smodule we're building"
 msgstr "Impossible d'utiliser le même %smodule que celui qui est en cours de construction"
 
 #: fortran/openmp.c:296 fortran/openmp.c:397 fortran/openmp.c:692
-#: fortran/openmp.c:3167
+#: fortran/openmp.c:3166
 #, gcc-internal-format, gfc-internal-format
 msgid "COMMON block /%s/ not found at %C"
 msgstr "Bloc COMMON /%s/ pas trouvé à %C"
@@ -56350,865 +56439,866 @@
 msgstr "%<acc update%> doit contenir au moins une clause %<device%> ou %<host%> ou %<self%> à %L"
 
 #: fortran/openmp.c:2180
-#, gcc-internal-format, gfc-internal-format
-msgid "Invalid argument to !$ACC WAIT at %L"
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "Invalid argument to !$ACC WAIT at %L"
+msgid "Invalid argument to !$ACC WAIT at %C"
 msgstr "Argument invalide pour !$ACC WAIT à %L"
 
-#: fortran/openmp.c:2188
+#: fortran/openmp.c:2187
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT clause at %L requires a scalar INTEGER expression"
 msgstr "La clause WAIT à %L requiert une expression INTEGER scalaire"
 
-#: fortran/openmp.c:2221
+#: fortran/openmp.c:2220
 #, gcc-internal-format, gfc-internal-format
 msgid "ACC CACHE directive must be inside of loop %C"
 msgstr "La directive ACC CACHE doit être à l'intérieur d'une boucle %C"
 
-#: fortran/openmp.c:2252
+#: fortran/openmp.c:2251
 #, gcc-internal-format
 msgid "Multiple loop axes specified for routine"
 msgstr "Plusieurs axes de boucles spécifiés pour la routine"
 
-#: fortran/openmp.c:2278
+#: fortran/openmp.c:2277
 #, gcc-internal-format, gfc-internal-format
 msgid "Only the !$ACC ROUTINE form without list is allowed in interface block at %C"
 msgstr "Seule la forme !$ACC ROUTINE sans liste est autorisée dans un bloc d'interface à %C"
 
-#: fortran/openmp.c:2306
+#: fortran/openmp.c:2305
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$ACC ROUTINE ( NAME ) at %C, invalid function name %s"
 msgstr "Erreur de syntaxe dans !$ACC ROUTINE ( NOM ) à %C, nom de fonction %s invalide"
 
-#: fortran/openmp.c:2315
+#: fortran/openmp.c:2314
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$ACC ROUTINE ( NAME ) at %C"
 msgstr "Erreur de syntaxe dans !$ACC ROUTINE ( NOM ) à %C"
 
-#: fortran/openmp.c:2322
+#: fortran/openmp.c:2321
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$ACC ROUTINE ( NAME ) at %C, expecting ')' after NAME"
 msgstr "Erreur de syntaxe dans !$ACC ROUTINE ( NOM ) à %C, « ) » attendue après NOM"
 
-#: fortran/openmp.c:2457 fortran/openmp.c:2481
+#: fortran/openmp.c:2456 fortran/openmp.c:2480
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP CRITICAL statement at %C"
 msgstr "Rebut inattendu après l'instruction $OMP CRITICAL à %C"
 
-#: fortran/openmp.c:2548
+#: fortran/openmp.c:2547
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP FLUSH statement at %C"
 msgstr "Rebut inattendu après l'instruction $OMP FLUSH à %C"
 
-#: fortran/openmp.c:2942 fortran/openmp.c:6225
+#: fortran/openmp.c:2941 fortran/openmp.c:6230
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined %s !$OMP DECLARE REDUCTION at %L"
 msgstr "Redéfinition de %s !$OMP DECLARE REDUCTION prédéfini à %L"
 
-#: fortran/openmp.c:2946 fortran/openmp.c:6229
+#: fortran/openmp.c:2945 fortran/openmp.c:6234
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined !$OMP DECLARE REDUCTION at %L"
 msgstr "Redéfinition de !$OMP DECLARE REDUCTION prédéfini à %L"
 
-#: fortran/openmp.c:2951
+#: fortran/openmp.c:2950
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of !$OMP DECLARE REDUCTION at %L"
 msgstr "Redéfinition de !$OMP DECLARE REDUCTION à %L"
 
-#: fortran/openmp.c:2953
+#: fortran/openmp.c:2952
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION at %L"
 msgstr "!$OMP DECLARE REDUCTION précédent à %L"
 
-#: fortran/openmp.c:2973
+#: fortran/openmp.c:2972
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after !$OMP DECLARE REDUCTION at %C"
 msgstr "Rebut inattendu après !$OMP DECLARE REDUCTION à %C"
 
-#: fortran/openmp.c:3010
+#: fortran/openmp.c:3009
 #, gcc-internal-format, gfc-internal-format
 msgid "Only the !$OMP DECLARE TARGET form without clauses is allowed in interface block at %C"
 msgstr "Seule la forme !$OMP DECLARE TARGET sans clause est autorisée dans un bloc d'interface à %C"
 
-#: fortran/openmp.c:3025
+#: fortran/openmp.c:3024
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after !$OMP DECLARE TARGET at %C"
 msgstr "Rebut inattendu après !$OMP DECLARE TARGET à %C"
 
-#: fortran/openmp.c:3048
+#: fortran/openmp.c:3047
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET variable at %L is an element of a COMMON block"
 msgstr "La variable OMP DECLARE TARGET à %L est un élément d'un bloc COMMON"
 
-#: fortran/openmp.c:3053
+#: fortran/openmp.c:3052
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET variable at %L previously mentioned in LINK clause and later in TO clause"
 msgstr "La variable OMP DECLARE TARGET à %L est précédemment mentionnée dans la clause LINK et plus tard dans la clause TO"
 
-#: fortran/openmp.c:3059
+#: fortran/openmp.c:3058
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET variable at %L previously mentioned in TO clause and later in LINK clause"
 msgstr "La variable OMP DECLARE TARGET à %L est précédemment mentionnée dans la clause TO et plus tard dans la clause LINK"
 
-#: fortran/openmp.c:3063
+#: fortran/openmp.c:3062
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable at %L mentioned multiple times in clauses of the same OMP DECLARE TARGET directive"
 msgstr "La variable à %L est mentionnée plusieurs fois dans des clauses ayant la même directive OMP DECLARE TARGET"
 
-#: fortran/openmp.c:3078
+#: fortran/openmp.c:3077
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET COMMON at %L previously mentioned in LINK clause and later in TO clause"
 msgstr "OMP DECLARE TARGET COMMON à %L précédemment mentionné dans une clause LINK et plus tard dans une clause TO"
 
-#: fortran/openmp.c:3084
+#: fortran/openmp.c:3083
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET COMMON at %L previously mentioned in TO clause and later in LINK clause"
 msgstr "OMP DECLARE TARGET COMMON à %L précédemment mentionné dans une clause TO et plus tard dans une clause LINK"
 
-#: fortran/openmp.c:3088
+#: fortran/openmp.c:3087
 #, gcc-internal-format, gfc-internal-format
 msgid "COMMON at %L mentioned multiple times in clauses of the same OMP DECLARE TARGET directive"
 msgstr "COMMON à %L mentionné plusieurs fois dans des clauses ayant la même directive OMP DECLARE TARGET"
 
-#: fortran/openmp.c:3115
+#: fortran/openmp.c:3114
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$OMP DECLARE TARGET list at %C"
 msgstr "Erreur de syntaxe dans la liste !$OMP DECLARE TARGET à %C"
 
-#: fortran/openmp.c:3147
+#: fortran/openmp.c:3146
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate variable at %C is an element of a COMMON block"
 msgstr "La variable threadprivate à %C est un élément d'un bloc COMMON"
 
-#: fortran/openmp.c:3184
+#: fortran/openmp.c:3183
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after OMP THREADPRIVATE at %C"
 msgstr "Rebut inattendu après OMP THREADPRIVATE à %C"
 
-#: fortran/openmp.c:3191
+#: fortran/openmp.c:3190
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$OMP THREADPRIVATE list at %C"
 msgstr "Erreur de syntaxe dans la liste !$OMP THREADPRIVATE à %C"
 
-#: fortran/openmp.c:3405
+#: fortran/openmp.c:3404
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after TASKWAIT clause at %C"
 msgstr "Rebut inattendu après la clause TASKWAIT à %C"
 
-#: fortran/openmp.c:3419
+#: fortran/openmp.c:3418
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after TASKYIELD clause at %C"
 msgstr "Rebut inattendu après la clause TASKYIELD à %C"
 
-#: fortran/openmp.c:3478
+#: fortran/openmp.c:3477
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP WORKSHARE statement at %C"
 msgstr "Rebut inattendu après l'instruction $OMP WORKSHARE à %C"
 
-#: fortran/openmp.c:3492
+#: fortran/openmp.c:3491
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP MASTER statement at %C"
 msgstr "Rebut inattendu après l'instruction $OMP MASTER à %C"
 
-#: fortran/openmp.c:3551
+#: fortran/openmp.c:3550
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP ATOMIC statement at %C"
 msgstr "Rebut inattendu après l'instruction $OMP ATOMIC à %C"
 
-#: fortran/openmp.c:3578
+#: fortran/openmp.c:3577
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP BARRIER statement at %C"
 msgstr "Rebut inattendu après l'instruction $OMP BARRIER à %C"
 
-#: fortran/openmp.c:3592
+#: fortran/openmp.c:3591
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP TASKGROUP statement at %C"
 msgstr "Rebut inattendu après l'instruction $OMP TASKGROUP à %C"
 
-#: fortran/openmp.c:3642
+#: fortran/openmp.c:3641
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP CANCELLATION POINT statement at %C"
 msgstr "Rebut inattendu après l'instruction $OMP CANCELLATION POINT à %C"
 
-#: fortran/openmp.c:3662
+#: fortran/openmp.c:3661
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after NOWAIT clause at %C"
 msgstr "Rebut inattendu après la clause NOWAIT à %C"
 
-#: fortran/openmp.c:3704
+#: fortran/openmp.c:3703
 #, gcc-internal-format, gfc-internal-format
 msgid "%s clause at %L requires a scalar INTEGER expression"
 msgstr "La clause %s à %L requiert une expression INTEGER scalaire"
 
-#: fortran/openmp.c:3715
+#: fortran/openmp.c:3714
 #, gcc-internal-format, gfc-internal-format
 msgid "INTEGER expression of %s clause at %L must be positive"
 msgstr "L'expression INTEGER de la clause %s à %L doit être positive"
 
-#: fortran/openmp.c:3726
+#: fortran/openmp.c:3725
 #, gcc-internal-format, gfc-internal-format
 msgid "INTEGER expression of %s clause at %L must be non-negative"
 msgstr "l'expression INTEGER de la clause %s à %L doit être non négative"
 
-#: fortran/openmp.c:3737
+#: fortran/openmp.c:3736
 #, gcc-internal-format
 msgid "POINTER object %qs of derived type in %s clause at %L"
 msgstr "Objet POINTER %qs du type dérivé dans la clause %s à %L"
 
-#: fortran/openmp.c:3740
+#: fortran/openmp.c:3739
 #, gcc-internal-format
 msgid "Cray pointer object %qs of derived type in %s clause at %L"
 msgstr "Objet pointeur Cray %qs du type dérivé dans la clause %s à %L"
 
-#: fortran/openmp.c:3743
+#: fortran/openmp.c:3742
 #, gcc-internal-format
 msgid "Cray pointee object %qs of derived type in %s clause at %L"
 msgstr "Objet pointé Cray %qs du type dérivé dans la clause %s à %L"
 
-#: fortran/openmp.c:3749 fortran/openmp.c:4687
+#: fortran/openmp.c:3748 fortran/openmp.c:4686
 #, gcc-internal-format
 msgid "POINTER object %qs of polymorphic type in %s clause at %L"
 msgstr "Objet POINTEUR %qs du type polymorphique dans la clause %s à %L"
 
-#: fortran/openmp.c:3754
+#: fortran/openmp.c:3753
 #, gcc-internal-format
 msgid "Cray pointer object %qs of polymorphic type in %s clause at %L"
 msgstr "Objet pointeur Cray %qs du type polymorphique dans la clause %s à %L"
 
-#: fortran/openmp.c:3759
+#: fortran/openmp.c:3758
 #, gcc-internal-format
 msgid "Cray pointee object %qs of polymorphic type in %s clause at %L"
 msgstr "Objet pointé Cray %qs du type polymorphique dans la clause %s à %L"
 
-#: fortran/openmp.c:3769 fortran/openmp.c:4385 fortran/openmp.c:4490
+#: fortran/openmp.c:3768 fortran/openmp.c:4384 fortran/openmp.c:4489
 #, gcc-internal-format
 msgid "Assumed size array %qs in %s clause at %L"
 msgstr "Tableau de taille tacite %qs dans la clause %s à %L"
 
-#: fortran/openmp.c:3772
+#: fortran/openmp.c:3771
 #, gcc-internal-format
 msgid "Assumed rank array %qs in %s clause at %L"
 msgstr "Tableau de rang tacite %s dans la clause %s à %L"
 
-#: fortran/openmp.c:3776
+#: fortran/openmp.c:3775
 #, gcc-internal-format
 msgid "Noncontiguous deferred shape array %qs in %s clause at %L"
 msgstr "Tableau de forme différée non contigu %qs dans la clause %s à %L"
 
-#: fortran/openmp.c:3784
+#: fortran/openmp.c:3783
 #, gcc-internal-format
 msgid "ALLOCATABLE object %qs of derived type in %s clause at %L"
 msgstr "Objet ALLOCATABLE %qs de type dérivé dans la clause %s à %L"
 
-#: fortran/openmp.c:3789
+#: fortran/openmp.c:3788
 #, gcc-internal-format
 msgid "ALLOCATABLE object %qs of polymorphic type in %s clause at %L"
 msgstr "Objet ALLOCATABLE %qs de type polymorphique dans la clause %s à %L"
 
-#: fortran/openmp.c:3801 fortran/openmp.c:4480
+#: fortran/openmp.c:3800 fortran/openmp.c:4479
 #, gcc-internal-format
 msgid "POINTER object %qs in %s clause at %L"
 msgstr "Objet POINTER %qs dans la clause %s à %L"
 
-#: fortran/openmp.c:3806 fortran/openmp.c:4691
+#: fortran/openmp.c:3805 fortran/openmp.c:4690
 #, gcc-internal-format
 msgid "Cray pointer object %qs in %s clause at %L"
 msgstr "Objet pointeur Cray %qs dans la clause %s à %L"
 
-#: fortran/openmp.c:3811 fortran/openmp.c:4694
+#: fortran/openmp.c:3810 fortran/openmp.c:4693
 #, gcc-internal-format
 msgid "Cray pointee object %qs in %s clause at %L"
 msgstr "Objet pointé Cray %qs dans la clause %s à %L"
 
-#: fortran/openmp.c:3816 fortran/openmp.c:4682
+#: fortran/openmp.c:3815 fortran/openmp.c:4681
 #, gcc-internal-format
 msgid "ALLOCATABLE object %qs in %s clause at %L"
 msgstr "Objet ALLOCATABLE %qs dans la clause %s à %L"
 
-#: fortran/openmp.c:3819
+#: fortran/openmp.c:3818
 #, gcc-internal-format
 msgid "VALUE object %qs in %s clause at %L"
 msgstr "Objet VALUE %qs dans la clause %s à %L"
 
-#: fortran/openmp.c:3862
+#: fortran/openmp.c:3861
 #, gcc-internal-format, gfc-internal-format
 msgid "Implicitly declared function %s used in !$OMP DECLARE REDUCTION at %L"
 msgstr "La fonction %s déclarée implicitement est utilisée dans !$OMP DECLARE REDUCTION à %L "
 
-#: fortran/openmp.c:3911
+#: fortran/openmp.c:3910
 #, gcc-internal-format, gfc-internal-format
 msgid "Implicitly declared subroutine %s used in !$OMP DECLARE REDUCTION at %L"
 msgstr "La sous-routine %s déclarée implicitement est utilisé dans !$OMP DECLARE REDUCTION à %L "
 
-#: fortran/openmp.c:3944
+#: fortran/openmp.c:3943
 #, gcc-internal-format, gfc-internal-format
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr "Le paramètre de la clause ORDERED est plus petit que COLLAPSE à %L"
 
-#: fortran/openmp.c:3952 fortran/openmp.c:3963 fortran/resolve.c:10028
-#: fortran/resolve.c:11295
+#: fortran/openmp.c:3951 fortran/openmp.c:3962 fortran/resolve.c:10041
+#: fortran/resolve.c:11315
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "La clause IF à %L requiert une expression LOGICAL scalaire"
 
-#: fortran/openmp.c:3967
+#: fortran/openmp.c:3966
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause without modifier at %L used together with IF clauses with modifiers"
 msgstr "La clause IF sans modificateur à %L est utilisée avec des clauses IF avec modificateurs"
 
-#: fortran/openmp.c:4044
+#: fortran/openmp.c:4043
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause modifier %s at %L not appropriate for the current OpenMP construct"
 msgstr "Le modificateur %s de la clause IF à %L n'est pas approprié pour la construction OpenMP actuelle"
 
-#: fortran/openmp.c:4054
+#: fortran/openmp.c:4053
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL clause at %L requires a scalar LOGICAL expression"
 msgstr "La clause FINAL à %L requiert une expression LOGICAL scalaire"
 
-#: fortran/openmp.c:4064
+#: fortran/openmp.c:4063
 #, gcc-internal-format, gfc-internal-format
 msgid "SCHEDULE clause's chunk_size at %L requires a scalar INTEGER expression"
 msgstr "Le chunk_size de la clause SCHEDULE à %L requiert une expression INTEGER scalaire"
 
-#: fortran/openmp.c:4069
+#: fortran/openmp.c:4068
 #, gcc-internal-format, gfc-internal-format
 msgid "INTEGER expression of SCHEDULE clause's chunk_size at %L must be positive"
 msgstr "L'expression INTEGER de chunk_size dans la clause SCHEDULE à %L doit être positive"
 
-#: fortran/openmp.c:4084
+#: fortran/openmp.c:4083
 #, gcc-internal-format
 msgid "Variable %qs is not a dummy argument at %L"
 msgstr "La variable %qs n'est pas un argument muet à %L"
 
-#: fortran/openmp.c:4116
+#: fortran/openmp.c:4115 fortran/openmp.c:5998
 #, gcc-internal-format
 msgid "Object %qs is not a variable at %L"
 msgstr "L'objet %qs n'est pas une variable à %L"
 
-#: fortran/openmp.c:4132 fortran/openmp.c:4143 fortran/openmp.c:4151
-#: fortran/openmp.c:4162 fortran/openmp.c:4174 fortran/openmp.c:4189
-#: fortran/openmp.c:6023
+#: fortran/openmp.c:4131 fortran/openmp.c:4142 fortran/openmp.c:4150
+#: fortran/openmp.c:4161 fortran/openmp.c:4173 fortran/openmp.c:4188
+#: fortran/openmp.c:6028
 #, gcc-internal-format
 msgid "Symbol %qs present on multiple clauses at %L"
 msgstr "Le symbole %qs est présent dans de multiples clauses à %L"
 
-#: fortran/openmp.c:4196
+#: fortran/openmp.c:4195
 #, gcc-internal-format
 msgid "Array %qs is not permitted in reduction at %L"
 msgstr "Le tableau %qs n'est pas permis dans la réduction à %L"
 
-#: fortran/openmp.c:4209
+#: fortran/openmp.c:4208
 #, gcc-internal-format
 msgid "Symbol %qs present on both FROM and TO clauses at %L"
 msgstr "Le symbole %qs est présent à la fois dans les clauses FROM et TO à %L"
 
-#: fortran/openmp.c:4231
+#: fortran/openmp.c:4230
 #, gcc-internal-format
 msgid "Non-THREADPRIVATE object %qs in COPYIN clause at %L"
 msgstr "Objet non THREADPRIVATE %qs dans la clause COPYIN à %L"
 
-#: fortran/openmp.c:4239
+#: fortran/openmp.c:4238
 #, gcc-internal-format
 msgid "Assumed size array %qs in COPYPRIVATE clause at %L"
 msgstr "Tableau de taille tacite %qs dans la clause COPYPRIVATE à %L"
 
-#: fortran/openmp.c:4242
+#: fortran/openmp.c:4241
 #, gcc-internal-format
 msgid "INTENT(IN) POINTER %qs in COPYPRIVATE clause at %L"
 msgstr "INTENT(IN) POINTER %qs dans la clause COPYPRIVATE à %L"
 
-#: fortran/openmp.c:4250
+#: fortran/openmp.c:4249
 #, gcc-internal-format
 msgid "THREADPRIVATE object %qs in SHARED clause at %L"
 msgstr "Objet THREADPRIVATE %qs dans la clause SHARED à %L"
 
-#: fortran/openmp.c:4253
+#: fortran/openmp.c:4252
 #, gcc-internal-format
 msgid "Cray pointee %qs in SHARED clause at %L"
 msgstr "Pointé Cray %qs dans la clause SHARED à %L"
 
-#: fortran/openmp.c:4256
+#: fortran/openmp.c:4255
 #, gcc-internal-format
 msgid "ASSOCIATE name %qs in SHARED clause at %L"
 msgstr "Nom ASSOCIATE %qs dans la clause SHARED à %L"
 
-#: fortran/openmp.c:4271
+#: fortran/openmp.c:4270
 #, gcc-internal-format
 msgid "%qs in ALIGNED clause must be POINTER, ALLOCATABLE, Cray pointer or C_PTR at %L"
 msgstr "%qs dans la clause ALIGNED doit être POINTER, ALLOCATABLE, pointeur Cray ou C_PTR à %L"
 
-#: fortran/openmp.c:4283
+#: fortran/openmp.c:4282
 #, gcc-internal-format
 msgid "%qs in ALIGNED clause at %L requires a scalar positive constant integer alignment expression"
 msgstr "%qs dans la clause ALIGNED à %L requiert une expression d'alignement qui est un entier constant positif et scalaire"
 
-#: fortran/openmp.c:4302
+#: fortran/openmp.c:4301
 #, gcc-internal-format, gfc-internal-format
 msgid "SINK dependence type only allowed on ORDERED directive at %L"
 msgstr "Type de dépendance SINK uniquement permis dans une directive ORDERED à %L"
 
-#: fortran/openmp.c:4306
+#: fortran/openmp.c:4305
 #, gcc-internal-format, gfc-internal-format
 msgid "DEPEND SINK used together with DEPEND SOURCE on the same construct at %L"
 msgstr "DEPEND SINK utilisé avec DEPEND SOURCE sur la même construction à %L"
 
-#: fortran/openmp.c:4316
+#: fortran/openmp.c:4315
 #, gcc-internal-format, gfc-internal-format
 msgid "SINK addend not a constant integer at %L"
 msgstr "Le terme SINK n'est pas un entier constant à %L"
 
-#: fortran/openmp.c:4322
+#: fortran/openmp.c:4321
 #, gcc-internal-format, gfc-internal-format
 msgid "Only SOURCE or SINK dependence types are allowed on ORDERED directive at %L"
 msgstr "Seuls les types de dépendances SOURCE et SINK sont permis dans la directive ORDERED à %L"
 
-#: fortran/openmp.c:4333 fortran/openmp.c:4354
+#: fortran/openmp.c:4332 fortran/openmp.c:4353
 #, gcc-internal-format
 msgid "%qs in %s clause at %L is not a proper array section"
 msgstr "%qs dans la clause %s à %L n'est pas une section de tableau convenable"
 
-#: fortran/openmp.c:4337
+#: fortran/openmp.c:4336
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarrays not supported in %s clause at %L"
 msgstr "Co-tableaux pas supportés dans la clause %s à %L"
 
-#: fortran/openmp.c:4346
+#: fortran/openmp.c:4345
 #, gcc-internal-format, gfc-internal-format
 msgid "Stride should not be specified for array section in %s clause at %L"
 msgstr "Le pas ne devrait pas être spécifié pour le section de tableau dans la clause %s à %L"
 
-#: fortran/openmp.c:4367
+#: fortran/openmp.c:4366
 #, gcc-internal-format
 msgid "%qs in DEPEND clause at %L is a zero size array section"
 msgstr "%qs dans la clause DEPEND à %L est une section de tableau de taille nulle"
 
 # %s est «  data » ou rien.
-#: fortran/openmp.c:4403
+#: fortran/openmp.c:4402
 #, gcc-internal-format, gfc-internal-format
 msgid "TARGET%s with map-type other than TO, FROM, TOFROM, or ALLOC on MAP clause at %L"
 msgstr "TARGET%s avec un type de correspondance autre que TO, FROM, TOFROM ou ALLOC sur la clause MAP à %L"
 
-#: fortran/openmp.c:4419
+#: fortran/openmp.c:4418
 #, gcc-internal-format, gfc-internal-format
 msgid "TARGET ENTER DATA with map-type other than TO, or ALLOC on MAP clause at %L"
 msgstr "TARGET ENTER DATA avec un type de correspondance autre que TO ou ALLOC sur la clause MAP à %L"
 
-#: fortran/openmp.c:4434
+#: fortran/openmp.c:4433
 #, gcc-internal-format, gfc-internal-format
 msgid "TARGET EXIT DATA with map-type other than FROM, RELEASE, or DELETE on MAP clause at %L"
 msgstr "TARGET EXIT DATA avec un type de correspondance autre que FROM, RELEASE ou DELETE sur la clause MAP à %L"
 
-#: fortran/openmp.c:4450 fortran/openmp.c:4466
+#: fortran/openmp.c:4449 fortran/openmp.c:4465
 #, gcc-internal-format
 msgid "THREADPRIVATE object %qs in %s clause at %L"
 msgstr "Objet THREADPRIVATE %qs dans la clause %s à %L"
 
-#: fortran/openmp.c:4453 fortran/openmp.c:4469
+#: fortran/openmp.c:4452 fortran/openmp.c:4468
 #, gcc-internal-format
 msgid "Cray pointee %qs in %s clause at %L"
 msgstr "Pointé Cray %qs dans la clause %s à %L"
 
-#: fortran/openmp.c:4472
+#: fortran/openmp.c:4471
 #, gcc-internal-format
 msgid "ASSOCIATE name %qs in %s clause at %L"
 msgstr "Nom ASSOCIATE %qs dans la clause %s à %L"
 
-#: fortran/openmp.c:4477
+#: fortran/openmp.c:4476
 #, gcc-internal-format
 msgid "Procedure pointer %qs in %s clause at %L"
 msgstr "Pointeur de procédure %qs dans la clause %s à %L"
 
-#: fortran/openmp.c:4483
+#: fortran/openmp.c:4482
 #, gcc-internal-format
 msgid "Cray pointer %qs in %s clause at %L"
 msgstr "Pointeur Cray %qs dans la clause %s à %L"
 
-#: fortran/openmp.c:4493
+#: fortran/openmp.c:4492
 #, gcc-internal-format
 msgid "Variable %qs in %s clause is used in NAMELIST statement at %L"
 msgstr "La variable %qs dans la clause %s est utilisée dans une instruction NAMELIST à %L"
 
 #. case OMP_LIST_REDUCTION:
-#: fortran/openmp.c:4503
+#: fortran/openmp.c:4502
 #, gcc-internal-format
 msgid "INTENT(IN) POINTER %qs in %s clause at %L"
 msgstr "INTENT(IN) POINTER %qs dans la clause %s à %L"
 
-#: fortran/openmp.c:4596
+#: fortran/openmp.c:4595
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP DECLARE REDUCTION %s not found for type %s at %L"
 msgstr "!$OMP DECLARE REDUCTION %s pas trouvé pour le type %s à %L"
 
-#: fortran/openmp.c:4622
+#: fortran/openmp.c:4621
 #, gcc-internal-format, gfc-internal-format
 msgid "LINEAR clause modifier used on DO or SIMD construct at %L"
 msgstr "Modificateur de clause LINEAR utilisé sur la construction DO ou SIMD à %L"
 
-#: fortran/openmp.c:4627
+#: fortran/openmp.c:4626
 #, gcc-internal-format, gfc-internal-format
 msgid "LINEAR clause specified together with ORDERED clause with argument at %L"
 msgstr "Clause LINEAR spécifiée avec la clause ORDERED avec argument à %L"
 
-#: fortran/openmp.c:4632
+#: fortran/openmp.c:4631
 #, gcc-internal-format
 msgid "LINEAR variable %qs must be INTEGER at %L"
 msgstr "La variable LINEAR %qs doit être INTEGER à %L"
 
-#: fortran/openmp.c:4637
+#: fortran/openmp.c:4636
 #, gcc-internal-format
 msgid "LINEAR dummy argument %qs with VALUE attribute with %s modifier at %L"
 msgstr "Argument muet LINEAR %qs avec l'attribut VALUE et le modificateur %s à %L"
 
-#: fortran/openmp.c:4648
+#: fortran/openmp.c:4647
 #, gcc-internal-format
 msgid "%qs in LINEAR clause at %L requires a scalar integer linear-step expression"
 msgstr "%qs dans la clause LINEAR à %L requiert une expression de pas linéaire qui soit un entier scalaire"
 
-#: fortran/openmp.c:4665
+#: fortran/openmp.c:4664
 #, gcc-internal-format
 msgid "%qs in LINEAR clause at %L requires a constant integer linear-step expression or dummy argument specified in UNIFORM clause"
 msgstr "%qs dans la clause LINEAR à %L requiert une expression de pas linéaire qui soit un entier constant ou un argument muet spécifié dans une clause UNIFORM"
 
-#: fortran/openmp.c:4699
+#: fortran/openmp.c:4698
 #, gcc-internal-format
 msgid "%s clause variable %qs at %L is neither a POINTER nor an array"
 msgstr "Dans la clause %s, la variable %qs à %L n'est ni un POINTER ni un tableau"
 
-#: fortran/openmp.c:4731
+#: fortran/openmp.c:4730
 #, gcc-internal-format, gfc-internal-format
 msgid "DIST_SCHEDULE clause's chunk_size at %L requires a scalar INTEGER expression"
 msgstr "Le chunk_size de la clause DIST_SCHEDULE à %L requiert une expression INTEGER scalaire"
 
-#: fortran/openmp.c:4763
+#: fortran/openmp.c:4762
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible use of TILE and COLLAPSE at %L"
 msgstr "Utilisation incompatible de TILE et COLLAPSE à %L"
 
-#: fortran/openmp.c:4765
+#: fortran/openmp.c:4764
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE dependence type only allowed on ORDERED directive at %L"
 msgstr "Type de dépendance SOURCE uniquement permis dans une directive ORDERED à %L"
 
-#: fortran/openmp.c:4778
+#: fortran/openmp.c:4777
 #, gcc-internal-format, gfc-internal-format
 msgid "%s must contain at least one MAP clause at %L"
 msgstr "%s doit contenir au moins une clause MAP à %L"
 
-#: fortran/openmp.c:4875
+#: fortran/openmp.c:4874
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected !$OMP ATOMIC expression at %L"
 msgstr "expression !$OMP ATOMIC inattendue à %L"
 
-#: fortran/openmp.c:4904
+#: fortran/openmp.c:4903
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC statement must set a scalar variable of intrinsic type at %L"
 msgstr "L'instruction !$OMP ATOMIC doit définir une variable scalaire ou un type intrinsèque à %L"
 
-#: fortran/openmp.c:4929
+#: fortran/openmp.c:4928
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC READ statement must read from a scalar variable of intrinsic type at %L"
 msgstr "L'instruction !$OMP ATOMIC READ doit lire depuis une variable scalaire ou un type intrinsèque à %L"
 
-#: fortran/openmp.c:4934
+#: fortran/openmp.c:4933
 #, gcc-internal-format, gfc-internal-format
 msgid "expr in !$OMP ATOMIC WRITE assignment var = expr must be scalar and cannot reference var at %L"
 msgstr "expr dans l'affectation var = expr de !$OMP ATOMIC WRITE doit être scalaire et ne peut pas faire référence à var à %L"
 
-#: fortran/openmp.c:4956 fortran/openmp.c:5247
+#: fortran/openmp.c:4955 fortran/openmp.c:5246
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE capture statement must read from a scalar variable of intrinsic type at %L"
 msgstr "L'instruction de capture !$OMP ATOMIC CAPTURE doit lire depuis une variable scalaire d'un type intrinsèque à %L"
 
-#: fortran/openmp.c:4971
+#: fortran/openmp.c:4970
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE update statement must set a scalar variable of intrinsic type at %L"
 msgstr "L'instruction de mise à jour !$OMP ATOMIC CAPTURE doit définir une variable scalaire d'un type intrinsèque à %L"
 
-#: fortran/openmp.c:4978 fortran/openmp.c:5254
+#: fortran/openmp.c:4977 fortran/openmp.c:5253
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE capture statement reads from different variable than update statement writes into at %L"
 msgstr "L'instruction de capture !$OMP ATOMIC CAPTURE lit depuis une variable différente de celle dans laquelle la mise à jour écrit à %L"
 
-#: fortran/openmp.c:4994
+#: fortran/openmp.c:4993
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC with ALLOCATABLE variable at %L"
 msgstr "!$OMP ATOMIC avec une variable ALLOCATABLE à %L"
 
-#: fortran/openmp.c:5036
+#: fortran/openmp.c:5035
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment operator must be binary +, *, -, /, .AND., .OR., .EQV. or .NEQV. at %L"
 msgstr "L'opérateur d'affectation !$OMP ATOMIC doit être un opérateur binaire dans la liste +, *, -, /, .AND., .OR., .EQV. ou .NEQV. à %L"
 
-#: fortran/openmp.c:5084
+#: fortran/openmp.c:5083
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment must be var = var op expr or var = expr op var at %L"
 msgstr "L'affectation !$OMP ATOMIC doit être var = var op expr ou var = expr op var à %L"
 
-#: fortran/openmp.c:5098
+#: fortran/openmp.c:5097
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC var = var op expr not mathematically equivalent to var = var op (expr) at %L"
 msgstr "!$OMP ATOMIC var = var op expr n'est pas mathématiquement équivalent à var = var op (expr) à %L"
 
-#: fortran/openmp.c:5130
+#: fortran/openmp.c:5129
 #, gcc-internal-format, gfc-internal-format
 msgid "expr in !$OMP ATOMIC assignment var = var op expr must be scalar and cannot reference var at %L"
 msgstr "expr dans l'affectation !$OMP ATOMIC var = var op expr doit être scalaire et ne peut pas faire référence à var à %L"
 
-#: fortran/openmp.c:5154
+#: fortran/openmp.c:5153
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment intrinsic IAND, IOR or IEOR must have two arguments at %L"
 msgstr "L'affectation intrinsèque IAND, IOR ou IEOR de !$OMP ATOMIC doit avoir deux arguments à %L"
 
-#: fortran/openmp.c:5161
+#: fortran/openmp.c:5160
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment intrinsic must be MIN, MAX, IAND, IOR or IEOR at %L"
 msgstr "L'affectation intrinsèque !$OMP ATOMIC doit être MIN, MAX, IAND, IOR ou IEOR à %L"
 
-#: fortran/openmp.c:5178
+#: fortran/openmp.c:5177
 #, gcc-internal-format
 msgid "!$OMP ATOMIC intrinsic arguments except one must not reference %qs at %L"
 msgstr "Les arguments intrinsèques de !$OMP ATOMIC sauf un ne doivent pas faire référence à %qs à %L"
 
-#: fortran/openmp.c:5185
+#: fortran/openmp.c:5184
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC intrinsic arguments must be scalar at %L"
 msgstr "Les arguments intrinsèques de !$OMP ATOMIC doivent être scalaires à %L"
 
-#: fortran/openmp.c:5193
+#: fortran/openmp.c:5192
 #, gcc-internal-format
 msgid "First or last !$OMP ATOMIC intrinsic argument must be %qs at %L"
 msgstr "Le premier ou le dernier argument intrinsèque de !$OMP ATOMIC doit être %qs à %L"
 
-#: fortran/openmp.c:5211
+#: fortran/openmp.c:5210
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment must have an operator or intrinsic on right hand side at %L"
 msgstr "L'affectation de !$OMP ATOMIC doit avoir un opérateur ou un intrinsèque dans le membre de droite à %L"
 
-#: fortran/openmp.c:5225
+#: fortran/openmp.c:5224
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE capture statement must set a scalar variable of intrinsic type at %L"
 msgstr "L'instruction de capture !$OMP ATOMIC CAPTURE doit définir une variable scalaire d'un type intrinsèque à %L"
 
-#: fortran/openmp.c:5544
+#: fortran/openmp.c:5543
 #, gcc-internal-format, gfc-internal-format
 msgid "%s cannot be a DO WHILE or DO without loop control at %L"
 msgstr "%s ne peut pas être DO WHILE ou DO sans contrôle de boucle à %L"
 
-#: fortran/openmp.c:5550
+#: fortran/openmp.c:5549
 #, gcc-internal-format, gfc-internal-format
 msgid "%s cannot be a DO CONCURRENT loop at %L"
 msgstr "%s ne peut pas être une boucle DO CONCURRENT à %L"
 
-#: fortran/openmp.c:5556
+#: fortran/openmp.c:5555
 #, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable must be of type integer at %L"
 msgstr "La variable d'itération %s doit être d'un type entier à %L"
 
-#: fortran/openmp.c:5560
+#: fortran/openmp.c:5559
 #, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable must not be THREADPRIVATE at %L"
 msgstr "La variable d'itération %s ne doit pas être THREADPRIVATE à %L"
 
-#: fortran/openmp.c:5573
+#: fortran/openmp.c:5572
 #, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable present on clause other than PRIVATE or LASTPRIVATE at %L"
 msgstr "Variable d'itération %s présente sur une clause autre que PRIVATE ou LASTPRIVATE à %L"
 
-#: fortran/openmp.c:5577
+#: fortran/openmp.c:5576
 #, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable present on clause other than LASTPRIVATE at %L"
 msgstr "Variable d'itération %s présente sur une clause autre que LASTPRIVATE à %L"
 
-#: fortran/openmp.c:5581
+#: fortran/openmp.c:5580
 #, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable present on clause other than LINEAR at %L"
 msgstr "Variable d'itération %s présente sur une clause autre que LINEAR à %L"
 
-#: fortran/openmp.c:5599
+#: fortran/openmp.c:5598
 #, gcc-internal-format, gfc-internal-format
 msgid "%s collapsed loops don't form rectangular iteration space at %L"
 msgstr "Les boucles coalescées %s ne forment pas un espace d'itération rectangulaire à %L"
 
-#: fortran/openmp.c:5611
+#: fortran/openmp.c:5610
 #, gcc-internal-format, gfc-internal-format
 msgid "collapsed %s loops not perfectly nested at %L"
 msgstr "boucles coalescées %s imparfaitement imbriquées à %L"
 
-#: fortran/openmp.c:5620 fortran/openmp.c:5628
+#: fortran/openmp.c:5619 fortran/openmp.c:5627
 #, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for collapsed %s at %L"
 msgstr "pas assez de boucle DO pour le %s coalescé à %L"
 
-#: fortran/openmp.c:5712 fortran/openmp.c:5725
+#: fortran/openmp.c:5711 fortran/openmp.c:5724
 #, gcc-internal-format, gfc-internal-format
 msgid "The %s directive cannot be specified within a %s region at %L"
 msgstr "La directive %s ne peut pas être spécifiée dans une région %s à %L"
 
-#: fortran/openmp.c:5744
+#: fortran/openmp.c:5743
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP cannot be a DO WHILE or DO without loop control at %L"
 msgstr "!$ACC LOOP ne peut pas être DO WHILE ou DO sans contrôle de boucle à %L"
 
-#: fortran/openmp.c:5750
+#: fortran/openmp.c:5749
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP iteration variable must be of type integer at %L"
 msgstr "La variable d'itération !$ACC LOOP doit être d'un type entier à %L"
 
 # %s peut être « tiled » ou « collapsed », sans traduction…
-#: fortran/openmp.c:5766
+#: fortran/openmp.c:5765
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s loops don't form rectangular iteration space at %L"
 msgstr "Les boucles %s !$ACC LOOP ne forment pas un espace d'itération rectangulaire à %L"
 
 # %s peut être « tiled » ou « collapsed », sans traduction…
-#: fortran/openmp.c:5778
+#: fortran/openmp.c:5777
 #, gcc-internal-format, gfc-internal-format
 msgid "%s !$ACC LOOP loops not perfectly nested at %L"
 msgstr "Les boucles %s !$ACC LOOP sont imparfaitement imbriquées à %L"
 
 # %s peut être « tiled » ou « collapsed », sans traduction…
-#: fortran/openmp.c:5788 fortran/openmp.c:5797
+#: fortran/openmp.c:5787 fortran/openmp.c:5796
 #, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for %s !$ACC LOOP at %L"
 msgstr "pas assez de boucles DO pour la boucle %s !$ACC LOOP à %L"
 
 # %s peut être « tiled » ou « collapsed », sans traduction…
-#: fortran/openmp.c:5812 fortran/openmp.c:5819
+#: fortran/openmp.c:5811 fortran/openmp.c:5818
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s in PARALLEL region doesn't allow %s arguments at %L"
 msgstr "La boucle %s !$ACC LOOP dans la région PARALLEL n'autorise pas les arguments %s à %L"
 
-#: fortran/openmp.c:5841
+#: fortran/openmp.c:5840
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside another loop parallelized across gangs at %L"
 msgstr "Une boucle parallélisée sur plusieurs « gangs » n'est pas permise à l'intérieur d'une autre boucle parallélisée sur plusieurs « gangs » à %L"
 
-#: fortran/openmp.c:5845 fortran/openmp.c:5849
+#: fortran/openmp.c:5844 fortran/openmp.c:5848
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside loop parallelized across workers at %L"
 msgstr "Une boucle parallélisée sur plusieurs « gangs » n'est pas permise à l'intérieur d'une boucle parallélisée sur plusieurs « workers » à %L"
 
-#: fortran/openmp.c:5856
+#: fortran/openmp.c:5855
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across workers at %L"
 msgstr "Une boucle parallélisée sur plusieurs « workers » n'est pas permise à l'intérieur d'une autre boucle parallélisée sur plusieurs « workers » à %L"
 
-#: fortran/openmp.c:5860
+#: fortran/openmp.c:5859
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across vectors at %L"
 msgstr "Une boucle parallélisée sur plusieurs « workers » n'est pas permise à l'intérieur d'une autre boucle parallélisée sur plusieurs vecteurs à %L"
 
-#: fortran/openmp.c:5866
+#: fortran/openmp.c:5865
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across vectors is not allowed inside another loop parallelized across vectors at %L"
 msgstr "Une boucle parallélisée sur plusieurs vecteurs n'est pas permise à l'intérieur d'une autre boucle parallélisée sur plusieurs vecteurs à %L"
 
-#: fortran/openmp.c:5878
+#: fortran/openmp.c:5877
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with INDEPENDENT at %L"
 msgstr "La clause SEQ est en conflit avec INDEPENDENT à %L"
 
-#: fortran/openmp.c:5880
+#: fortran/openmp.c:5879
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with GANG at %L"
 msgstr "La clause SEQ est en conflit avec GANG à %L"
 
-#: fortran/openmp.c:5882
+#: fortran/openmp.c:5881
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with WORKER at %L"
 msgstr "La clause SEQ est en conflit avec WORKER à %L"
 
-#: fortran/openmp.c:5884
+#: fortran/openmp.c:5883
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with VECTOR at %L"
 msgstr "La clause SEQ est en conflit avec VECTOR à %L"
 
-#: fortran/openmp.c:5886
+#: fortran/openmp.c:5885
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with AUTO at %L"
 msgstr "La clause SEQ est en conflit avec AUTO à %L"
 
-#: fortran/openmp.c:5891
+#: fortran/openmp.c:5890
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with GANG at %L"
 msgstr "La clause AUTO est en conflit avec GANG à %L"
 
-#: fortran/openmp.c:5893
+#: fortran/openmp.c:5892
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with WORKER at %L"
 msgstr "La clause AUTO est en conflit avec WORKER à %L"
 
-#: fortran/openmp.c:5895
+#: fortran/openmp.c:5894
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with VECTOR at %L"
 msgstr "La clause AUTO est en conflit avec VECTOR à %L"
 
-#: fortran/openmp.c:5899
+#: fortran/openmp.c:5898
 #, gcc-internal-format, gfc-internal-format
 msgid "Tiled loop cannot be parallelized across gangs, workers and vectors at the same time at %L"
 msgstr "Une boucle découpée en blocs ne peut pas être parallélisée sur plusieurs « gangs », « workers » ou vecteurs en même temps à %L"
 
-#: fortran/openmp.c:5934
+#: fortran/openmp.c:5933
 #, gcc-internal-format, gfc-internal-format
 msgid "TILE requires constant expression at %L"
 msgstr "TILE requiert une expression constante à %L"
 
-#: fortran/openmp.c:5999
+#: fortran/openmp.c:6004
 #, gcc-internal-format
 msgid "PARAMETER object %qs is not allowed at %L"
 msgstr "L'objet PARAMETER %qs n'est pas permis à %L"
 
-#: fortran/openmp.c:6006
+#: fortran/openmp.c:6011
 #, gcc-internal-format
 msgid "Array sections: %qs not allowed in !$ACC DECLARE at %L"
 msgstr "Les sections de tableaux %qs ne sont pas permises dans !$ACC DECLARE à %L"
 
-#: fortran/openmp.c:6133
+#: fortran/openmp.c:6138
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP TARGET UPDATE at %L requires at least one TO or FROM clause"
 msgstr "OMP TARGET UPDATE à %L requiert au moins une clause TO ou FROM"
 
-#: fortran/openmp.c:6155
+#: fortran/openmp.c:6160
 #, gcc-internal-format
 msgid "!$OMP DECLARE SIMD should refer to containing procedure %qs at %L"
 msgstr "!$OMP DECLARE SIMD devrait faire référence à la procédure contenante %qs à %L"
 
-#: fortran/openmp.c:6179
+#: fortran/openmp.c:6184
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_PRIV or OMP_ORIG used in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr "Une variable autre que OMP_PRIV ou OMP_ORIG est utilisée dans la clause INITIALIZER de !$OMP DECLARE REDUCTION à %L"
 
-#: fortran/openmp.c:6187
+#: fortran/openmp.c:6192
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_OUT or OMP_IN used in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr "Une variable autre que OMP_OUT ou OMP_IN est utilisée dans le combinateur de !$OMP DECLARE REDUCTION à %L"
 
-#: fortran/openmp.c:6216
+#: fortran/openmp.c:6221
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid operator for !$OMP DECLARE REDUCTION %s at %L"
 msgstr "Opérateur invalide pour !$OMP DECLARE REDUCTION %s à %L"
 
-#: fortran/openmp.c:6238
+#: fortran/openmp.c:6243
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER length in !$OMP DECLARE REDUCTION %s not constant at %L"
 msgstr "La longueur de CHARACTER dans !$OMP DECLARE REDUCTION %s n'est pas constante à %L"
 
-#: fortran/openmp.c:6254
+#: fortran/openmp.c:6259
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr "Appel à une sous-routine avec des retours alternatifs dans le combinateur de !$OMP DECLARE REDUCTION à %L"
 
-#: fortran/openmp.c:6269
+#: fortran/openmp.c:6274
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr "Appel à une sous-routine avec des retours alternatifs dans la clause INITIALIZER de !$OMP DECLARE REDUCTION à %L"
 
-#: fortran/openmp.c:6279
+#: fortran/openmp.c:6284
 #, gcc-internal-format, gfc-internal-format
 msgid "One of actual subroutine arguments in INITIALIZER clause of !$OMP DECLARE REDUCTION must be OMP_PRIV at %L"
 msgstr "Un des arguments effectifs de la sous-routine dans la clause INITIALIZER de !$OMP DECLARE REDUCTION doit être OMP_PRIV à %L"
 
-#: fortran/openmp.c:6287
+#: fortran/openmp.c:6292
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing INITIALIZER clause for !$OMP DECLARE REDUCTION of derived type without default initializer at %L"
 msgstr "Clause INITIALIZER manquante pour !$OMP DECLARE REDUCTION du type dérivé sans initialisation par défaut à %L"
@@ -57318,495 +57408,495 @@
 msgid "Unclassifiable statement at %C"
 msgstr "Instruction inclassable à %C"
 
-#: fortran/parse.c:629
+#: fortran/parse.c:631
 #, gcc-internal-format, gfc-internal-format
 msgid "OpenACC directives at %C may not appear in PURE procedures"
 msgstr "Les directives OpenACC à %C ne peuvent pas apparaître dans des procédures PURE"
 
-#: fortran/parse.c:705
+#: fortran/parse.c:707
 #, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable OpenACC directive at %C"
 msgstr "Directive OpenACC inclassable à %C"
 
-#: fortran/parse.c:831 fortran/parse.c:1040
+#: fortran/parse.c:835 fortran/parse.c:1044
 #, gcc-internal-format, gfc-internal-format
 msgid "OpenMP directives other than SIMD or DECLARE TARGET at %C may not appear in PURE or ELEMENTAL procedures"
 msgstr "Les directives OpenMP autres que SIMD ou DECLARE TARGET à %C ne peuvent pas apparaître dans des procédures PURE ou ELEMENTAL"
 
-#: fortran/parse.c:1024
+#: fortran/parse.c:1028
 #, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable OpenMP directive at %C"
 msgstr "Directive OpenMP inclassable à %C"
 
-#: fortran/parse.c:1076
+#: fortran/parse.c:1080
 #, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable GCC directive at %C"
 msgstr "Directive GCC inclassable à %C"
 
-#: fortran/parse.c:1135 fortran/parse.c:1362
+#: fortran/parse.c:1139 fortran/parse.c:1366
 #, gcc-internal-format, gfc-internal-format
 msgid "Zero is not a valid statement label at %C"
 msgstr "Zéro n'est pas une étiquette d'instruction valable à %C"
 
-#: fortran/parse.c:1142 fortran/parse.c:1354
+#: fortran/parse.c:1146 fortran/parse.c:1358
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-numeric character in statement label at %C"
 msgstr "Caractère non-numérique dans l'étiquette d'instruction à %C"
 
-#: fortran/parse.c:1154 fortran/parse.c:1403
+#: fortran/parse.c:1158 fortran/parse.c:1407
 #, gcc-internal-format, gfc-internal-format
 msgid "Semicolon at %C needs to be preceded by statement"
 msgstr "Le point-virgule à %C doit être précédé d'une instruction"
 
-#: fortran/parse.c:1161 fortran/parse.c:1418
+#: fortran/parse.c:1165 fortran/parse.c:1422
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label without statement at %L"
 msgstr "Étiquette d'instruction sans instruction à %L"
 
-#: fortran/parse.c:1224 fortran/parse.c:1405
+#: fortran/parse.c:1228 fortran/parse.c:1409
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Semicolon at %C without preceding statement"
 msgstr "Fortran 2008: Point-virgule à %C sans instruction avant lui"
 
-#: fortran/parse.c:1247 fortran/parse.c:1381
+#: fortran/parse.c:1251 fortran/parse.c:1385
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad continuation line at %C"
 msgstr "Mauvaise ligne de continuation à %C"
 
-#: fortran/parse.c:1679
+#: fortran/parse.c:1683
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT statement at %L does not have a statement label"
 msgstr "L'instruction FORMAT à %L n'a pas d'étiquette d'instruction"
 
-#: fortran/parse.c:2435
+#: fortran/parse.c:2439
 #, gcc-internal-format
 msgid "gfc_ascii_statement(): Bad statement code"
 msgstr "gfc_ascii_statement(): Mauvais code d'instruction"
 
-#: fortran/parse.c:2577
+#: fortran/parse.c:2581
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement at %C"
 msgstr "Instruction %s inattendue à %C"
 
 # Les %s peuvent être des chaînes traduites (par ex. IF arithmétique) ou des mots clés (par ex. ALLOCATE)
-#: fortran/parse.c:2732
+#: fortran/parse.c:2736
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot follow %s statement at %L"
 msgstr "L'instruction « %s » à %C ne peut pas suivre l'instruction « %s » à %L"
 
-#: fortran/parse.c:2749
+#: fortran/parse.c:2753
 #, gcc-internal-format
 msgid "Unexpected end of file in %qs"
 msgstr "Fin de fichier inattendue dans %qs"
 
-#: fortran/parse.c:2784
+#: fortran/parse.c:2788
 #, gcc-internal-format
 msgid "Derived-type %qs with SEQUENCE must not have a CONTAINS section at %C"
 msgstr "Le type dérivé %qs avec SEQUENCE ne doit pas avoir de section CONTAINS à %C"
 
-#: fortran/parse.c:2787
+#: fortran/parse.c:2791
 #, gcc-internal-format
 msgid "Derived-type %qs with BIND(C) must not have a CONTAINS section at %C"
 msgstr "Le type dérivé %qs avec BIND(C) ne doit pas avoir de section CONTAINS à %C"
 
-#: fortran/parse.c:2807
+#: fortran/parse.c:2811
 #, gcc-internal-format, gfc-internal-format
 msgid "Components in TYPE at %C must precede CONTAINS"
 msgstr "Les composants dans TYPE à %C doivent précéder CONTAINS"
 
-#: fortran/parse.c:2811
+#: fortran/parse.c:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound procedure at %C"
 msgstr "Procédure liée au type à %C"
 
-#: fortran/parse.c:2819
+#: fortran/parse.c:2823
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC binding at %C"
 msgstr "Liaison GENERIC à %C"
 
-#: fortran/parse.c:2827
+#: fortran/parse.c:2831
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure declaration at %C"
 msgstr "Déclaration de procédure FINAL à %C"
 
-#: fortran/parse.c:2839
+#: fortran/parse.c:2843
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type definition at %C with empty CONTAINS section"
 msgstr "Définition de type dérivé à %C avec une section CONTAINS vide"
 
-#: fortran/parse.c:2849 fortran/parse.c:3304
+#: fortran/parse.c:2853 fortran/parse.c:3308
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement in TYPE at %C must be inside a MODULE"
 msgstr "L'instruction PRIVATE dans TYPE à %C doit être à l'intérieur d'un MODULE"
 
-#: fortran/parse.c:2856
+#: fortran/parse.c:2860
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede procedure bindings"
 msgstr "L'instruction PRIVATE à %C doit précéder les liaisons de procédures"
 
-#: fortran/parse.c:2863 fortran/parse.c:3317
+#: fortran/parse.c:2867 fortran/parse.c:3321
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PRIVATE statement at %C"
 msgstr "Instruction PRIVATE dupliquée à %C"
 
-#: fortran/parse.c:2873
+#: fortran/parse.c:2877
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede CONTAINS"
 msgstr "L'instruction SEQUENCE à %C doit précéder CONTAINS"
 
-#: fortran/parse.c:2877
+#: fortran/parse.c:2881
 #, gcc-internal-format, gfc-internal-format
 msgid "Already inside a CONTAINS block at %C"
 msgstr "Déjà à l'intérieur d'un bloc CONTAINS à %C"
 
-#: fortran/parse.c:2996
+#: fortran/parse.c:3000
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s at %L of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray, which is not possible as the component has the pointer attribute"
 msgstr "Le composant %s à %L du type LOCK_TYPE doit avec une co-dimension ou être un sous-composant d'un co-tableau, ce qui est impossible puisque le composant a l'attribut pointeur"
 
-#: fortran/parse.c:3002
+#: fortran/parse.c:3006
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer component %s at %L has a noncoarray subcomponent of type LOCK_TYPE, which must have a codimension or be a subcomponent of a coarray"
 msgstr "Le composant pointeur %s à %L a un sous-composant non co-tableau de type LOCK_TYPE, qui doit avoir une co-dimension ou être un sous-composant d'un co-tableau"
 
-#: fortran/parse.c:3007
+#: fortran/parse.c:3011
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L of type LOCK_TYPE must have a codimension"
 msgstr "Le composant allouable %s à %L du type LOCK_TYPE doit avoir une co-dimension"
 
-#: fortran/parse.c:3011
+#: fortran/parse.c:3015
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L must have a codimension as it has a noncoarray subcomponent of type LOCK_TYPE"
 msgstr "Le composant allouable %s à %L doit avoir une co-dimension car il a un sous-composant non co-tableau de type LOCK_TYPE"
 
-#: fortran/parse.c:3016
+#: fortran/parse.c:3020
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as already a coarray subcomponent exists)"
 msgstr "Le composant non co-tableau %s à %L du type LOCK_TYPE ou avec un sous-composant de type LOCK_TYPE doit avoir une co-dimension ou être un sous-composant d'un co-tableau. (Les variables du type %s ne peuvent pas avoir une co-dimension puisqu'un sous-composant co-tableau existe déjà)"
 
-#: fortran/parse.c:3023
+#: fortran/parse.c:3027
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as %s at %L has a codimension or a coarray subcomponent)"
 msgstr "Le composant non co-tableau %s à %L du type LOCK_TYPE ou avec un sous-composant de type LOCK_TYPE doit avoir une co-dimension ou être un sous-composant d'un co-tableau. (Les variables du type %s ne peuvent pas avoir de co-dimension car %s à %L a une co-dimension ou un sous-composant qui est un co-tableau)"
 
-#: fortran/parse.c:3033
+#: fortran/parse.c:3037
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s at %L of type EVENT_TYPE must have a codimension or be a subcomponent of a coarray, which is not possible as the component has the pointer attribute"
 msgstr "Le composant %s à %L du type EVENT_TYPE doit avoir une co-dimension ou être un sous-composant d'un co-tableau, ce qui n'est pas possible puisque le composant a l'attribut pointeur"
 
-#: fortran/parse.c:3039
+#: fortran/parse.c:3043
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer component %s at %L has a noncoarray subcomponent of type EVENT_TYPE, which must have a codimension or be a subcomponent of a coarray"
 msgstr "Le composant pointeur %s à %L a un sous-composant non co-tableau du type EVENT_TYPE qui doit avoir une co-dimension ou être un sous-composant d'un co-tableau"
 
-#: fortran/parse.c:3044
+#: fortran/parse.c:3048
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L of type EVENT_TYPE must have a codimension"
 msgstr "Le composant allouable %s à %L du type EVENT_TYPE doit avoir une co-dimension"
 
-#: fortran/parse.c:3048
+#: fortran/parse.c:3052
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L must have a codimension as it has a noncoarray subcomponent of type EVENT_TYPE"
 msgstr "Le composant allouable %s à %L doit avoir une co-dimension car il a un sous-composant non co-tableau du type EVENT_TYPE"
 
-#: fortran/parse.c:3053
+#: fortran/parse.c:3057
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as already a coarray subcomponent exists)"
 msgstr "Le composant non co-tableau %s à %L du type EVENT_TYPE ou avec un sous-composant de type EVENT_TYPE doit avoir une co-dimension ou être un sous-composant d'un co-tableau. (Les variables du type %s ne peuvent pas avoir une co-dimension car un sous-composant de co-tableau existe déjà)"
 
-#: fortran/parse.c:3060
+#: fortran/parse.c:3064
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as %s at %L has a codimension or a coarray subcomponent)"
 msgstr "Le composant non co-tableau %s à %L du type EVENT_TYPE ou avec un sous-composant de type EVENT_TYPE doit avoir une co-dimension ou être un sous-composant d'un co-tableau. (Les variables du type %s ne peuvent pas avoir de co-dimension car %s à %L a une co-dimension ou un sous-composant co-tableau)"
 
-#: fortran/parse.c:3112
+#: fortran/parse.c:3116
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to create map component '%s'"
 msgstr "échec lors de la création du composant du tableau associatif « %s »"
 
-#: fortran/parse.c:3145
+#: fortran/parse.c:3149
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to create union component '%s'"
 msgstr "échec lors de la création du composant d'union « %s »"
 
-#: fortran/parse.c:3200
+#: fortran/parse.c:3204
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in nested structure declaration at %C"
 msgstr "Erreur de syntaxe dans la déclaration d'une structure imbriquée à %C"
 
-#: fortran/parse.c:3287
+#: fortran/parse.c:3291
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside CONTAINS"
 msgstr "La déclaration FINAL à %C doit être à l'intérieur de CONTAINS"
 
-#: fortran/parse.c:3295
+#: fortran/parse.c:3299
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type definition at %C without components"
 msgstr "Définition du type dérivé à %C sans composants"
 
-#: fortran/parse.c:3311
+#: fortran/parse.c:3315
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede structure components"
 msgstr "L'instruction PRIVATE à %C doit précéder les composants de la structure"
 
-#: fortran/parse.c:3328
+#: fortran/parse.c:3332
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede structure components"
 msgstr "L'instruction SEQUENCE à %C doit précéder les composants de la structure"
 
-#: fortran/parse.c:3334
+#: fortran/parse.c:3338
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE attribute at %C already specified in TYPE statement"
 msgstr "L'attribut SEQUENCE à %C est déjà spécifié dans l'instruction TYPE"
 
-#: fortran/parse.c:3339
+#: fortran/parse.c:3343
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SEQUENCE statement at %C"
 msgstr "Instruction SEQENCE dupliquée à %C"
 
-#: fortran/parse.c:3349
+#: fortran/parse.c:3353
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS block in derived type definition at %C"
 msgstr "Bloc CONTAINS dans une définition de type dérivé à %C"
 
-#: fortran/parse.c:3407
+#: fortran/parse.c:3411
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM declaration at %C has no ENUMERATORS"
 msgstr "La déclaration ENUM à %C n'a aucun ENUMERATOR"
 
-#: fortran/parse.c:3494
+#: fortran/parse.c:3498
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in INTERFACE block at %C"
 msgstr "Instruction %s inattendue dans le bloc INTERFACE à %C"
 
-#: fortran/parse.c:3518
+#: fortran/parse.c:3522
 #, gcc-internal-format
 msgid "Name %qs of ABSTRACT INTERFACE at %C cannot be the same as an intrinsic type"
 msgstr "Le nom %qs de ABSTRACT INTERFACE à %C ne peut pas être le même qu'un type intrinsèque"
 
-#: fortran/parse.c:3552
+#: fortran/parse.c:3556
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement at %C in INTERFACE body"
 msgstr "Instruction %s inattendue à %C dans le corps de INTERFACE"
 
-#: fortran/parse.c:3570
+#: fortran/parse.c:3574
 #, gcc-internal-format
 msgid "INTERFACE procedure %qs at %L has the same name as the enclosing procedure"
 msgstr "La procédure %qs de INTERFACE à %L a le même nom que la procédure englobante"
 
-#: fortran/parse.c:3700
+#: fortran/parse.c:3704
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement is not allowed inside of BLOCK at %C"
 msgstr "L'instruction %s n'est pas permise à l'intérieur de BLOCK à %C"
 
-#: fortran/parse.c:3732
+#: fortran/parse.c:3736
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement is not allowed inside of BLOCK DATA at %C"
 msgstr "L'instruction %s n'est pas permise à l'intérieur de BLOCK DATA à %C"
 
-#: fortran/parse.c:3822
+#: fortran/parse.c:3826
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement must appear in a MODULE"
 msgstr "L'instruction %s doit apparaître dans un MODULE"
 
-#: fortran/parse.c:3830
+#: fortran/parse.c:3834
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C follows another accessibility specification"
 msgstr "L'instruction %s à %C suit un autre spécificateur d'accessibilité"
 
-#: fortran/parse.c:3882
+#: fortran/parse.c:3886
 #, gcc-internal-format
 msgid "Bad kind expression for function %qs at %L"
 msgstr "Mauvaise expression « kind » pour la fonction %qs à %L"
 
-#: fortran/parse.c:3886
+#: fortran/parse.c:3890
 #, gcc-internal-format
 msgid "The type for function %qs at %L is not accessible"
 msgstr "Le type pour la fonction %qs à %L n'est pas accessible"
 
-#: fortran/parse.c:3946
+#: fortran/parse.c:3950
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C follows previous unmasked ELSEWHERE"
 msgstr "L'instruction ELSEWHERE à %C suit un ELSEWHERE précédent qui n'est pas masqué"
 
-#: fortran/parse.c:3968
+#: fortran/parse.c:3972
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in WHERE block at %C"
 msgstr "Instruction %s inattendue dans le bloc WHERE à %C"
 
-#: fortran/parse.c:4027
+#: fortran/parse.c:4031
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in FORALL block at %C"
 msgstr "Instruction %s inattendue dans le bloc FORALL à %C"
 
-#: fortran/parse.c:4078
+#: fortran/parse.c:4082
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSE IF statement at %C cannot follow ELSE statement at %L"
 msgstr "L'instruction ELSE IF à %C ne peut pas suivre une instruction ELSE à %L"
 
-#: fortran/parse.c:4096
+#: fortran/parse.c:4100
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ELSE statements at %L and %C"
 msgstr "Instructions ELSE dupliquées à %L et %C"
 
-#: fortran/parse.c:4157
+#: fortran/parse.c:4161
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected a CASE or END SELECT statement following SELECT CASE at %C"
 msgstr "Une instruction CASE ou END SELECT est attendue à la suite de SELECT CASE à %C"
 
-#: fortran/parse.c:4241
+#: fortran/parse.c:4245
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected TYPE IS, CLASS IS or END SELECT statement following SELECT TYPE at %C"
 msgstr "Une instruction TYPE IS, CLASS IS ou END SELECT est attendue à la suite de SELECT TYPE à %C"
 
-#: fortran/parse.c:4303
+#: fortran/parse.c:4307
 #, gcc-internal-format
 msgid "Variable %qs at %C cannot be redefined inside loop beginning at %L"
 msgstr "La variable %qs à %C ne peut pas être redéfinie à l'intérieur de la boucle commençant à %L"
 
-#: fortran/parse.c:4336
+#: fortran/parse.c:4340
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is within another block"
 msgstr "La fin de l'instruction DO non bloc à %C est à l'intérieur d'un autre bloc"
 
-#: fortran/parse.c:4346
+#: fortran/parse.c:4350
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is interwoven with another DO loop"
 msgstr "La fin de l'instruction DO non bloc à %C est enchevêtrée dans une autre boucle DO"
 
-#: fortran/parse.c:4372
+#: fortran/parse.c:4376
 #, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL block inside of OpenACC region at %C"
 msgstr "Bloc CRITICAL à l'intérieur d'une région OpenACC à %C"
 
-#: fortran/parse.c:4373
+#: fortran/parse.c:4377
 #, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL block inside of OpenMP region at %C"
 msgstr "Bloc CRITICAL à l'intérieur d'une région OpenMP à %C"
 
-#: fortran/parse.c:4399
+#: fortran/parse.c:4403
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label in END CRITICAL at %C does not match CRITICAL label"
 msgstr "L'étiquette d'instruction dans END CRITICAL à %C ne correspond pas à l'étiquette de CRITICAL"
 
-#: fortran/parse.c:4468
+#: fortran/parse.c:4472
 #, gcc-internal-format, gfc-internal-format
 msgid "BLOCK construct at %C"
 msgstr "Construction BLOCK à %C"
 
-#: fortran/parse.c:4502
+#: fortran/parse.c:4506
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSOCIATE construct at %C"
 msgstr "Construction ASSOCIATE à %C"
 
-#: fortran/parse.c:4690
+#: fortran/parse.c:4694
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label in ENDDO at %C doesn't match DO label"
 msgstr "L'étiquette d'instruction dans ENDDO à %C ne correspond pas à l'étiquette de DO"
 
-#: fortran/parse.c:4706
+#: fortran/parse.c:4710
 #, gcc-internal-format, gfc-internal-format
 msgid "Named block DO at %L requires matching ENDDO name"
 msgstr "Le bloc DO nommé à %L requiert un nom ENDDO correspondant"
 
-#: fortran/parse.c:4897
+#: fortran/parse.c:4901
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing !$OMP END ATOMIC after !$OMP ATOMIC CAPTURE at %C"
 msgstr "!$OMP END ATOMIC requis après !$OMP ATOMIC CAPTURE à %C"
 
-#: fortran/parse.c:4913 fortran/parse.c:4972
+#: fortran/parse.c:4917 fortran/parse.c:4976
 #, gcc-internal-format, gfc-internal-format
 msgid "OpenACC directive inside of CRITICAL block at %C"
 msgstr "Directive OpenACC à l'intérieur du bloc CRITICAL à %C"
 
-#: fortran/parse.c:4947
+#: fortran/parse.c:4951
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s at %C"
 msgstr "%s attendu à %C"
 
-#: fortran/parse.c:4991
+#: fortran/parse.c:4995
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected DO loop at %C"
 msgstr "Boucle DO attendue à %C"
 
-#: fortran/parse.c:5011
+#: fortran/parse.c:5015
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant !$ACC END LOOP at %C"
 msgstr "!$ACC END LOOP redondant à %C"
 
-#: fortran/parse.c:5225
+#: fortran/parse.c:5229
 #, gcc-internal-format, gfc-internal-format
 msgid "Name after !$omp critical and !$omp end critical does not match at %C"
 msgstr "Les noms après !$omp critical et !$omp end critical ne correspondent pas à %C"
 
-#: fortran/parse.c:5283
+#: fortran/parse.c:5287
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot terminate a non-block DO loop"
 msgstr "L'instruction %s à %C ne peut pas terminer une boucle DO non bloc"
 
-#: fortran/parse.c:5297
+#: fortran/parse.c:5301
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %C after the first executable statement"
 msgstr "Instruction DATA à %C après la première instruction exécutable"
 
-#: fortran/parse.c:5423
+#: fortran/parse.c:5427
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive does not commence a loop at %C"
 msgstr "la directive %<GCC unroll%> ne commence pas à la boucle à %C"
 
-#: fortran/parse.c:5538
+#: fortran/parse.c:5542
 #, gcc-internal-format
 msgid "Contained procedure %qs at %C is already ambiguous"
 msgstr "La procédure contenue %qs à %C est déjà ambigüe"
 
-#: fortran/parse.c:5595
+#: fortran/parse.c:5599
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in CONTAINS section at %C"
 msgstr "Instruction %s inattendue dans la section CONTAINS à %C"
 
-#: fortran/parse.c:5620
+#: fortran/parse.c:5624
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS statement without FUNCTION or SUBROUTINE statement at %L"
 msgstr "Instruction CONTAINS sans instruction FUNCTION ou SUBROUTINE à %L"
 
-#: fortran/parse.c:5732
+#: fortran/parse.c:5736
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS statement at %C is already in a contained program unit"
 msgstr "L'instruction CONTAINS à %C est déjà dans une unité de programme contenue"
 
 # Le dernier %s est un mot clé tel que « FUNCTION », « PROGRAM », « MODULE » etc, d'où le « un(e) »
-#: fortran/parse.c:5784
+#: fortran/parse.c:5788
 #, gcc-internal-format
 msgid "Global binding name %qs at %L is already being used as a %s at %L"
 msgstr "Le nom de liaison globale %qs à %L est déjà utilisé comme un(e) %s à %L"
 
 # Le dernier %s est un mot clé tel que « FUNCTION », « PROGRAM », « MODULE » etc, d'où le « un(e) »
-#: fortran/parse.c:5788
+#: fortran/parse.c:5792
 #, gcc-internal-format
 msgid "Global name %qs at %L is already being used as a %s at %L"
 msgstr "Le nom global %qs à %L est déjà utilisé comme un(e) %s à %L"
 
-#: fortran/parse.c:5794
+#: fortran/parse.c:5798
 #, gcc-internal-format
 msgid "Global binding name %qs at %L is already being used at %L"
 msgstr "Le nom de liaison globale %qs à %L est déjà utilisé à %L"
 
-#: fortran/parse.c:5797
+#: fortran/parse.c:5801
 #, gcc-internal-format
 msgid "Global name %qs at %L is already being used at %L"
 msgstr "Le nom global %qs à %L est déjà utilisé à %L"
 
-#: fortran/parse.c:5819
+#: fortran/parse.c:5823
 #, gcc-internal-format, gfc-internal-format
 msgid "Blank BLOCK DATA at %C conflicts with prior BLOCK DATA at %L"
 msgstr "Le BLOCK DATA blanc à %C est en conflit avec le BLOCK DATA précédent à %L"
 
-#: fortran/parse.c:5845
+#: fortran/parse.c:5849
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in BLOCK DATA at %C"
 msgstr "Instruction %s inattendue dans BLOCK DATA à %C"
 
-#: fortran/parse.c:5949
+#: fortran/parse.c:5953
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in MODULE at %C"
 msgstr "Instruction %s inattendue dans MODULE à %C"
@@ -57814,7 +57904,7 @@
 #. If we see a duplicate main program, shut down.  If the second
 #. instance is an implied main program, i.e. data decls or executable
 #. statements, we're in for lots of errors.
-#: fortran/parse.c:6333
+#: fortran/parse.c:6337
 #, gcc-internal-format, gfc-internal-format
 msgid "Two main PROGRAMs at %L and %C"
 msgstr "Deux PROGRAM principaux à %L et %C"
@@ -58564,7 +58654,7 @@
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr "La procédure non RECURSIVE %qs à %L semble s'appeler elle-même récursivement. Déclarez là RECURSIVE ou utilisez %<-frecursive%>"
 
-#: fortran/resolve.c:1893 fortran/resolve.c:9560 fortran/resolve.c:11225
+#: fortran/resolve.c:1893 fortran/resolve.c:9573 fortran/resolve.c:11245
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "L'étiquette %d référencée à %L n'est jamais définie"
@@ -58674,7 +58764,7 @@
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "La fonction %qs à %L n'a pas de type IMPLICIT, vouliez-vous employer %qs ?"
 
-#: fortran/resolve.c:2905 fortran/resolve.c:16283
+#: fortran/resolve.c:2905 fortran/resolve.c:16310
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr "La fonction %qs à %L n'a pas de type IMPLICIT"
@@ -58797,197 +58887,197 @@
 msgid "logical_to_bitwise(): Bad intrinsic"
 msgstr "logical_to_bitwise(): Mauvais intrinsèque"
 
-#: fortran/resolve.c:4059
+#: fortran/resolve.c:4065
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr "resolve_operator(): Mauvais intrinsèque"
 
-#: fortran/resolve.c:4229 fortran/resolve.c:4252
+#: fortran/resolve.c:4235 fortran/resolve.c:4258
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr "compare_bound_int(): Mauvaise expression"
 
-#: fortran/resolve.c:4347
+#: fortran/resolve.c:4353
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "La référence au tableau à %L est en dehors des limites (%ld < %ld) dans la dimension %d"
 
-#: fortran/resolve.c:4352
+#: fortran/resolve.c:4358
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr "La référence au tableau à %L est en dehors des limites (%ld < %ld) dans la co-dimension %d"
 
-#: fortran/resolve.c:4362
+#: fortran/resolve.c:4368
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "La référence au tableau à %L est en dehors des limites (%ld > %ld) dans la dimension %d"
 
-#: fortran/resolve.c:4367
+#: fortran/resolve.c:4373
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr "La référence au tableau à %L est en dehors des limites (%ld > %ld) dans la co-dimension %d"
 
-#: fortran/resolve.c:4387
+#: fortran/resolve.c:4393
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr "Pas nul illégal à %L"
 
-#: fortran/resolve.c:4404
+#: fortran/resolve.c:4410
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "La référence inférieure au tableau à %L est hors des limites (%ld < %ld) dans la dimension %d"
 
-#: fortran/resolve.c:4412
+#: fortran/resolve.c:4418
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "La référence inférieure au tableau à %L est en dehors des limites (%ld > %ld) dans la dimension %d"
 
-#: fortran/resolve.c:4428
+#: fortran/resolve.c:4434
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "La référence supérieure au tableau à %L est hors des limites (%ld < %ld) dans la dimension %d"
 
-#: fortran/resolve.c:4437
+#: fortran/resolve.c:4443
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "La référence supérieure au tableau à %L est hors des limites (%ld > %ld) dans la dimension %d"
 
-#: fortran/resolve.c:4453
+#: fortran/resolve.c:4459
 #, gcc-internal-format
 msgid "check_dimension(): Bad array reference"
 msgstr "check_dimension(): Mauvaise référence de tableau"
 
-#: fortran/resolve.c:4476
+#: fortran/resolve.c:4482
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr "La limite supérieure la plus à droite de la section du tableau de taille tacite n'est pas spécifiée à %L"
 
-#: fortran/resolve.c:4486
+#: fortran/resolve.c:4492
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr "Désaccord de rang dans la référence au tableau à %L (%d/%d)"
 
-#: fortran/resolve.c:4494
+#: fortran/resolve.c:4500
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr "Désaccord du rang du co-index dans la référence au tableau à %L (%d/%d)"
 
-#: fortran/resolve.c:4510
+#: fortran/resolve.c:4516
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr "Le co-index de la co-dimension %d doit être un scalaire à %L"
 
-#: fortran/resolve.c:4538
+#: fortran/resolve.c:4544
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr "L'index de tableau à %L doit être scalaire"
 
-#: fortran/resolve.c:4544
+#: fortran/resolve.c:4550
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr "L'index de tableau à %L doit être du type INTEGER, on a trouvé %s"
 
-#: fortran/resolve.c:4550
+#: fortran/resolve.c:4556
 #, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr "Index de tableau REAL à %L"
 
-#: fortran/resolve.c:4589
+#: fortran/resolve.c:4595
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr "L'argument dim à %L doit être scalaire"
 
-#: fortran/resolve.c:4596
+#: fortran/resolve.c:4602
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr "L'argument dim à %L doit être du type INTEGER"
 
-#: fortran/resolve.c:4641
+#: fortran/resolve.c:4647
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr "find_array_spec(): Spec manquante"
 
-#: fortran/resolve.c:4652
+#: fortran/resolve.c:4658
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr "find_array_spec(): « as » inutilisé(1)"
 
-#: fortran/resolve.c:4663
+#: fortran/resolve.c:4669
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr "find_array_spec(): « as » inutilisé(2)"
 
-#: fortran/resolve.c:4706
+#: fortran/resolve.c:4712
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr "L'index de tableau à %L est un tableau de rang %d"
 
-#: fortran/resolve.c:4804
+#: fortran/resolve.c:4810
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr "L'index de départ de la sous-chaîne à %L doit être du type INTEGER"
 
-#: fortran/resolve.c:4811
+#: fortran/resolve.c:4817
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr "L'index de départ de la sous-chaîne à %L doit être scalaire"
 
-#: fortran/resolve.c:4820
+#: fortran/resolve.c:4826
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr "L'index de départ de la sous-chaîne à %L est plus petit que un"
 
-#: fortran/resolve.c:4833
+#: fortran/resolve.c:4839
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr "L'index de fin de la sous-chaîne à %L doit être du type INTEGER"
 
-#: fortran/resolve.c:4840
+#: fortran/resolve.c:4846
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr "L'index de fin de la sous-chaîne à %L doit être scalaire"
 
-#: fortran/resolve.c:4850
+#: fortran/resolve.c:4856
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr "L'index de fin de la sous-chaîne à %L excède la longueur de la chaîne"
 
-#: fortran/resolve.c:4860
+#: fortran/resolve.c:4866
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr "L'index de fin de la sous-chaîne à %L est trop grand"
 
-#: fortran/resolve.c:5013
+#: fortran/resolve.c:5019
 #, gcc-internal-format
 msgid "resolve_ref(): Bad array reference"
 msgstr "resolve_ref(): Mauvaise référence de tableau"
 
-#: fortran/resolve.c:5027
+#: fortran/resolve.c:5033
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr "Le composant à droite d'une référence de partie avec un rang non nul ne doit pas avoir l'attribut POINTER à %L"
 
-#: fortran/resolve.c:5037
+#: fortran/resolve.c:5043
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr "Le composant à droite d'une référence de partie avec un rang non nul ne doit pas avoir l'attribut ALLOCATABLE à %L"
 
-#: fortran/resolve.c:5056
+#: fortran/resolve.c:5062
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr "Deux références de parties (ou plus) avec un rang non nul ne peuvent pas être spécifiées à %L"
 
-#: fortran/resolve.c:5154
+#: fortran/resolve.c:5160
 #, gcc-internal-format
 msgid "expression_rank(): Two array specs"
 msgstr "expression_rank(): Deux specs de tableau"
 
-#: fortran/resolve.c:5236
+#: fortran/resolve.c:5242
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr "La variable %s à %L avec l'attribut NO_ARG_CHECK peut uniquement être utilisée comme argument effectif"
 
-#: fortran/resolve.c:5246
+#: fortran/resolve.c:5252
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr "La variable de type tacite %s à %L peut uniquement être utilisée comme argument effectif"
@@ -58996,12 +59086,12 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5256
+#: fortran/resolve.c:5262
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr "La variable de type tacite %s à %L comme argument effectif à une fonction de requête sera le premier argument"
 
-#: fortran/resolve.c:5271
+#: fortran/resolve.c:5277
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr "La variable de rang tacite %s à %L peut uniquement être utilisée comme argument effectif"
@@ -59010,271 +59100,272 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5281
+#: fortran/resolve.c:5287
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr "La variable de rang tacite %s à %L comme argument effectif à une fonction intrinsèque sera le premier argument"
 
-#: fortran/resolve.c:5292
+#: fortran/resolve.c:5298
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr "La variable %s à %L avec l'attribut NO_ARG_CHECK n'aura point de référence à un sous-objet"
 
-#: fortran/resolve.c:5301
+#: fortran/resolve.c:5307
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr "La variable de type tacite %s à %L n'aura point de référence à un sous-objet"
 
-#: fortran/resolve.c:5316
+#: fortran/resolve.c:5322
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr "La variable de rang tacite %s à %L n'aura point de référence à un sous-objet"
 
-#: fortran/resolve.c:5478
+#: fortran/resolve.c:5484
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr "La variable %qs, utilisée dans une expression de spécification, est référencée à %L avant l'instruction ENTRY dans laquelle elle est un paramètre"
 
-#: fortran/resolve.c:5483
+#: fortran/resolve.c:5489
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr "La variable %qs est utilisée à %L avant l'instruction ENTRY dans laquelle elle est un paramètre"
 
-#: fortran/resolve.c:5553
+#: fortran/resolve.c:5559
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr "Sous-objet polymorphique d'un objet co-indexé à %L"
 
-#: fortran/resolve.c:5566
+#: fortran/resolve.c:5572
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr "Objet co-indexé avec un sous-composant allouable polymorphique à %L"
 
-#: fortran/resolve.c:5919
+#: fortran/resolve.c:5925
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "L'objet passé à %L doit être scalaire"
 
-#: fortran/resolve.c:5926
+#: fortran/resolve.c:5932
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr "L'objet de base pour l'appel de composant pointeur de procédure à %L est du type ABSTRACT %qs"
 
-#: fortran/resolve.c:5961
+#: fortran/resolve.c:5967
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr "L'objet de base pour l'appel de procédure liée au type à %L est du type ABSTRACT %qs"
 
-#: fortran/resolve.c:5970
+#: fortran/resolve.c:5976
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr "L'objet de base pour l'appel de procédure liée au type NOPASS à %L doit être scalaire"
 
 #. Nothing matching found!
-#: fortran/resolve.c:6158
+#: fortran/resolve.c:6164
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr "Aucune liaison spécifique correspondante pour l'appel à GENERIC %qs à %L"
 
-#: fortran/resolve.c:6185
+#: fortran/resolve.c:6191
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "%qs à %L devrait être une SUBROUTINE"
 
-#: fortran/resolve.c:6236
+#: fortran/resolve.c:6242
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr "%qs à %L devrait être une FUNCTION"
 
-#: fortran/resolve.c:6786
+#: fortran/resolve.c:6792
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "gfc_resolve_expr(): Mauvais type d'expression"
 
-#: fortran/resolve.c:6812
+#: fortran/resolve.c:6818
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s à %L doit être un scalaire"
 
-#: fortran/resolve.c:6822
+#: fortran/resolve.c:6828
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "%s à %L doit être un entier"
 
-#: fortran/resolve.c:6826 fortran/resolve.c:6833
+#: fortran/resolve.c:6832 fortran/resolve.c:6839
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s à %L doit être INTEGER"
 
-#: fortran/resolve.c:6875
+#: fortran/resolve.c:6881
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "L'expression de pas dans la boucle DO à %L ne peut pas être zéro"
 
-#: fortran/resolve.c:6911
+#: fortran/resolve.c:6917
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr "La boucle DO à %L sera exécutée zéro fois"
 
-#: fortran/resolve.c:6928
+#: fortran/resolve.c:6934
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr "La boucle DO à %L est indéfinie car elle déborde"
 
-#: fortran/resolve.c:6934
+#: fortran/resolve.c:6940
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr "La boucle DO à %L est indéfinie car elle déborde vers le bas"
 
-#: fortran/resolve.c:6995
+#: fortran/resolve.c:7001
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "Le nom d'index FORALL à %L doit être un INTEGER scalaire"
 
-#: fortran/resolve.c:7000
+#: fortran/resolve.c:7006
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "L'expression de départ de FORALL à %L doit être un INTEGER scalaire"
 
-#: fortran/resolve.c:7007
+#: fortran/resolve.c:7013
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "L'expression de fin de FORALL à %L doit être un INTEGER scalaire"
 
 # %s est toujours « INTEGER » et rien d'autre
-#: fortran/resolve.c:7015
+#: fortran/resolve.c:7021
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "L'expression de pas de FORALL à %L doit être un %s scalaire"
 
-#: fortran/resolve.c:7020
+#: fortran/resolve.c:7026
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "L'expression de pas de FORALL à %L ne peut pas être zéro"
 
-#: fortran/resolve.c:7033
+#: fortran/resolve.c:7039
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "L'index %qs de FORALL ne peut pas apparaître dans une spécification de triplet à %L"
 
-#: fortran/resolve.c:7136 fortran/resolve.c:7428
+#: fortran/resolve.c:7142 fortran/resolve.c:7434
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "L'objet allouable à %L doit être ALLOCATABLE ou un POINTER"
 
-#: fortran/resolve.c:7144 fortran/resolve.c:7393
+#: fortran/resolve.c:7150 fortran/resolve.c:7399
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr "Objet allouable co-indexé à %L"
 
-#: fortran/resolve.c:7250
+#: fortran/resolve.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr "L'expression source à %L doit être scalaire ou avoir le même rang que l'objet allouable à %L"
 
-#: fortran/resolve.c:7281
+#: fortran/resolve.c:7287
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr "L'expression source à %L et l'objet allouable à %L doivent avoir la même forme"
 
-#: fortran/resolve.c:7439
+#: fortran/resolve.c:7445
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr "Le type de l'entité à %L a un type incompatible avec l'expression source à %L"
 
-#: fortran/resolve.c:7451
+#: fortran/resolve.c:7457
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr "L'objet allouable à %L et l'expression source à %L auront le même paramètre de sous-type"
 
-#: fortran/resolve.c:7465
+#: fortran/resolve.c:7471
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr "L'expression source à %L n'aura ni le type LOCK_TYPE ni un composant LOCK_TYPE si l'objet allouable à %L est un co-tableau"
 
-#: fortran/resolve.c:7480
+#: fortran/resolve.c:7486
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr "L'expression source à %L n'aura ni le type EVENT_TYPE ni un composant EVENT_TYPE si l'objet allouable à %L est un co-tableau"
 
-#: fortran/resolve.c:7493
+#: fortran/resolve.c:7499
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr "L'allocation de %s du type de base ABSTRACT à %L requiert une spécification de type ou une expression source"
 
-#: fortran/resolve.c:7511
+#: fortran/resolve.c:7517
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr "L'allocation de %s à %L avec la spécification de type requiert la même longueur de caractères dans le paramètre que dans la déclaration"
 
-#: fortran/resolve.c:7592 fortran/resolve.c:7607
+#: fortran/resolve.c:7598 fortran/resolve.c:7613
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "Spécification de tableau requise dans l'instruction ALLOCATE à %L"
 
-#: fortran/resolve.c:7599
+#: fortran/resolve.c:7605
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "Une spécification de tableau ou une expression SOURCE= avec une valeur tableau est requise dans l'instruction ALLOCATE à %L"
 
-#: fortran/resolve.c:7622
+#: fortran/resolve.c:7628
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "Spécification de co-tableau requise dans l'instruction ALLOCATE à %L"
 
-#: fortran/resolve.c:7649
+#: fortran/resolve.c:7655
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "Mauvaise spécification de tableau dans l'instruction ALLOCATE à %L"
 
-#: fortran/resolve.c:7668
+#: fortran/resolve.c:7674
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr "%qs ne doit pas apparaître dans la spécification de tableau à %L dans la même instruction ALLOCATE où il est lui-même alloué"
 
-#: fortran/resolve.c:7683
+#: fortran/resolve.c:7689
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr "« * » attendu dans la spécification du co-index dans l'instruction ALLOCATE à %L"
 
-#: fortran/resolve.c:7694
+#: fortran/resolve.c:7700
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "Mauvaise spécification de co-tableau dans l'instruction ALLOCATE à %L"
 
-#: fortran/resolve.c:7726
+#: fortran/resolve.c:7732
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "La variable stat à %L doit être une variable INTEGER scalaire"
 
 # les deux %s sont le même mot-clé "ALLOCATE" ou "DEALLOCATE" utilisés une fois comme mot et comme instruction, merde les mecs, ils pourraient faire attention aux traducteurs…
-#: fortran/resolve.c:7749
+#: fortran/resolve.c:7755
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "La variable stat à %L ne sera point qualifiée par %s dans la même instruction %s"
 
-#: fortran/resolve.c:7760
+#: fortran/resolve.c:7766
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr "ERRMSG à %L est inutile sans la balise STAT"
 
-#: fortran/resolve.c:7771
-#, gcc-internal-format, gfc-internal-format
-msgid "Errmsg-variable at %L must be a scalar CHARACTER variable"
-msgstr "La variable errmsg à %L doit être une variable CHARACTER scalaire"
+#: fortran/resolve.c:7782
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
+msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
+msgstr "L'argument ERRMSG= à %L doit être une variable CHARACTER scalaire"
 
 # les deux %s sont le même mot-clé "ALLOCATE" ou "DEALLOCATE" utilisés une fois comme mot et comme instruction, merde les mecs, ils pourraient faire attention aux traducteurs…
-#: fortran/resolve.c:7794
+#: fortran/resolve.c:7805
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr "La variable errmsg à %L ne sera point qualifiée par %s dans la même instruction %s"
 
-#: fortran/resolve.c:7824
+#: fortran/resolve.c:7835
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr "L'objet alloué à %L apparaît aussi à %L"
 
-#: fortran/resolve.c:7830 fortran/resolve.c:7836
+#: fortran/resolve.c:7841 fortran/resolve.c:7847
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr "L'objet alloué à %L est un sous-objet d'un objet à %L"
@@ -59283,232 +59374,232 @@
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8064
+#: fortran/resolve.c:8075
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "L'étiquette CASE à %L chevauche l'étiquette CASE à %L"
 
-#: fortran/resolve.c:8115
+#: fortran/resolve.c:8126
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "L'expression dans l'instruction CASE à %L doit être du type %s"
 
-#: fortran/resolve.c:8126
+#: fortran/resolve.c:8137
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "L'expression dans l'instruction CASE à %L doit être du sous-type %d"
 
-#: fortran/resolve.c:8139
+#: fortran/resolve.c:8150
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "L'expression dans l'instruction CASE à %L doit être scalaire"
 
-#: fortran/resolve.c:8185
+#: fortran/resolve.c:8196
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "L'expression de sélection dans le GOTO calculé à %L doit être une expression entière scalaire"
 
-#: fortran/resolve.c:8204
+#: fortran/resolve.c:8215
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "L'argument de l'instruction SELECT à %L ne peut pas être %s"
 
-#: fortran/resolve.c:8214
+#: fortran/resolve.c:8225
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "L'argument de l'expression SELECT à %L doit être une expression scalaire"
 
-#: fortran/resolve.c:8232 fortran/resolve.c:8240
+#: fortran/resolve.c:8243 fortran/resolve.c:8251
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "L'expression dans l'instruction CASE à %L n'est pas dans la plage de %s"
 
-#: fortran/resolve.c:8302 fortran/resolve.c:8873
+#: fortran/resolve.c:8313 fortran/resolve.c:8884
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "Le DEFAULT CASE à %L ne peut pas être suivi par un second DEFAULT CASE à %L"
 
-#: fortran/resolve.c:8328
+#: fortran/resolve.c:8339
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "Une plage logique n'est pas permise dans l'instruction CASE à %L"
 
-#: fortran/resolve.c:8340
+#: fortran/resolve.c:8351
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "La valeur logique constante est répétée dans l'instruction CASE à %L"
 
-#: fortran/resolve.c:8355
+#: fortran/resolve.c:8366
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "La spécification d'étendue à %L ne peut jamais correspondre à quoi que ce soit"
 
-#: fortran/resolve.c:8458
+#: fortran/resolve.c:8469
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "Le bloc SELECT CASE logique à %L a plus de deux cas"
 
-#: fortran/resolve.c:8518
+#: fortran/resolve.c:8529
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr "Le sélecteur à %L ne peut pas NULL()"
 
-#: fortran/resolve.c:8523
+#: fortran/resolve.c:8534
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr "Le sélecteur à %L n'a pas de type"
 
-#: fortran/resolve.c:8545
+#: fortran/resolve.c:8556
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr "Le nom associé %qs à %L est utilisé comme tableau"
 
-#: fortran/resolve.c:8556
+#: fortran/resolve.c:8567
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr "Le sélecteur CLASS à %L a besoin d'un temporaire qui n'est pas encore implémenté"
 
-#: fortran/resolve.c:8763
+#: fortran/resolve.c:8774
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "Le sélecteur sera polymorphique dans l'instruction SELECT TYPE à %L"
 
-#: fortran/resolve.c:8783 fortran/resolve.c:8795
+#: fortran/resolve.c:8794 fortran/resolve.c:8806
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr "Le sélecteur à %L ne doit pas être co-indexé"
 
-#: fortran/resolve.c:8824
+#: fortran/resolve.c:8835
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "TYPE IS à %L chevauche TYPE IS à %L"
 
-#: fortran/resolve.c:8836
+#: fortran/resolve.c:8847
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr "Le type dérivé %qs à %L doit être extensible"
 
-#: fortran/resolve.c:8848
+#: fortran/resolve.c:8859
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "Le type dérivé %qs à %L doit être une extension de %qs"
 
-#: fortran/resolve.c:8851
+#: fortran/resolve.c:8862
 #, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "Type intrinsèque %qs inattendu à %L"
 
-#: fortran/resolve.c:8861
+#: fortran/resolve.c:8872
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr "La spécification de type à %L doit spécifier que chaque paramètre de type de longueur est tacite"
 
-#: fortran/resolve.c:9108
+#: fortran/resolve.c:9119
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr "Bloc CLASS IS en double dans l'instruction SELECT TYPE à %L"
 
-#: fortran/resolve.c:9204
+#: fortran/resolve.c:9215
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "Contexte invalide pour l'intrinsèque NULL () à %L"
 
-#: fortran/resolve.c:9257
+#: fortran/resolve.c:9268
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "La procédure DTIO %s à %L doit être récursive"
 
-#: fortran/resolve.c:9267
+#: fortran/resolve.c:9278
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr "L'élément de transfert de données à %L ne peut pas être polymorphique à moins qu'il soit traité par une procédure d'entrée/sortie définie"
 
-#: fortran/resolve.c:9280
+#: fortran/resolve.c:9291
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "L'élément de transfert de données à %L ne peut pas avoir de composants POINTER à moins qu'il soit traité par une procédure d'entrée/sortie définie"
 
-#: fortran/resolve.c:9289
+#: fortran/resolve.c:9300
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "L'élément de transfert de données à %L ne peut pas avoir de composants de pointeur de procédure"
 
-#: fortran/resolve.c:9296
+#: fortran/resolve.c:9307
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "L'élément de transfert de données à %L ne peut pas avoir de composants ALLOCATABLE à moins qu'il soit traité par une procédure d'entrée/sortie définie"
 
-#: fortran/resolve.c:9307
+#: fortran/resolve.c:9318
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "L'élément de transfert de données à %L ne peut pas avoir de composants PRIVATE"
 
-#: fortran/resolve.c:9313
+#: fortran/resolve.c:9324
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr "L'élément de transfert de données à %L ne peut pas avoir de composants PRIVATE à moins qu'il soit traité par une procédure d'entrée/sortie définie"
 
-#: fortran/resolve.c:9328
+#: fortran/resolve.c:9339
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "L'élément de transfert de données à %L ne peut pas être une référence complète à un tableau de taille tacite"
 
-#: fortran/resolve.c:9388
+#: fortran/resolve.c:9399
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "La variable verrou à %L doit être un scalaire de type LOCK_TYPE"
 
-#: fortran/resolve.c:9398
+#: fortran/resolve.c:9409
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr "La variable d'événement à %L doit être un scalaire de type EVENT_TYPE"
 
-#: fortran/resolve.c:9402
+#: fortran/resolve.c:9413
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "L'argument variable d'événement à %L doit être un co-tableau ou co-indexé"
 
-#: fortran/resolve.c:9405
+#: fortran/resolve.c:9416
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "L'argument variable d'événement à %L doit être un co-tableau mais pas co-indexé"
 
-#: fortran/resolve.c:9412 fortran/resolve.c:9533
+#: fortran/resolve.c:9423 fortran/resolve.c:9545
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "L'argument STAT= à %L doit être une variable INTEGER scalaire"
 
-#: fortran/resolve.c:9424 fortran/resolve.c:9540
+#: fortran/resolve.c:9435 fortran/resolve.c:9553
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "L'argument ERRMSG= à %L doit être une variable CHARACTER scalaire"
 
-#: fortran/resolve.c:9436
+#: fortran/resolve.c:9447
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "L'argument ACQUIRED_LOCK= à %L doit être une variable LOGICAL scalaire"
 
-#: fortran/resolve.c:9449
+#: fortran/resolve.c:9460
 #, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "L'argument UNTIL_COUNT= à %L doit être une expression INTEGER scalaire"
 
-#: fortran/resolve.c:9510
+#: fortran/resolve.c:9521
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "L'argument imageset à %L doit être une expression scalaire ou INTEGER de rang 1"
 
-#: fortran/resolve.c:9514 fortran/resolve.c:9524
+#: fortran/resolve.c:9525 fortran/resolve.c:9535
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "L'argument imageset à %L doit être entre 1 et num_images()"
 
-#: fortran/resolve.c:9567
+#: fortran/resolve.c:9580
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "L'instruction à %L n'est pas une instruction cible valable pour l'instruction de branchement à %L"
 
-#: fortran/resolve.c:9577
+#: fortran/resolve.c:9590
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr "Le branchement à %L peut conduire à une boucle infinie"
@@ -59515,12 +59606,12 @@
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:9594 fortran/resolve.c:9617
+#: fortran/resolve.c:9607 fortran/resolve.c:9630
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr "L'instruction GOTO à %L quitte une construction CRITICAL pour l'étiquette à %L"
 
-#: fortran/resolve.c:9598 fortran/resolve.c:9623
+#: fortran/resolve.c:9611 fortran/resolve.c:9636
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr "L'instruction GOTO à %L quitte une construction DO CONCURRENT pour l'étiquette à %L"
@@ -59528,107 +59619,107 @@
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:9638
+#: fortran/resolve.c:9651
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "L'étiquette à %L n'est pas dans le même bloc que l'instruction GOTO à %L"
 
-#: fortran/resolve.c:9710
+#: fortran/resolve.c:9723
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "Le masque WHERE à %L a une forme inconsistante"
 
-#: fortran/resolve.c:9726
+#: fortran/resolve.c:9739
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "La cible de l'affectation WHERE à %L a une forme inconsistante"
 
-#: fortran/resolve.c:9734 fortran/resolve.c:9821
+#: fortran/resolve.c:9747 fortran/resolve.c:9834
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr "Affectation définie par l'utilisateur non ELEMENTAL dans WHERE à %L"
 
-#: fortran/resolve.c:9744 fortran/resolve.c:9831
+#: fortran/resolve.c:9757 fortran/resolve.c:9844
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "Instruction non supportée à l'intérieur de WHERE à %L"
 
-#: fortran/resolve.c:9775
+#: fortran/resolve.c:9788
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "Affectation à une variable d'index FORALL à %L"
 
-#: fortran/resolve.c:9784
+#: fortran/resolve.c:9797
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "Le FORALL avec l'index %qs n'est pas utilisé dans le membre de gauche de l'affectation à %L et, par conséquent, pourrait causer de multiples affectations à cet objet"
 
-#: fortran/resolve.c:9949
+#: fortran/resolve.c:9962
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "Le nom d'index de FORALL à %L doit être une variable scalaire de type entier"
 
-#: fortran/resolve.c:9959
+#: fortran/resolve.c:9972
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "Une construction de boucle FORALL extérieure a déjà un index avec ce nom à %L"
 
-#: fortran/resolve.c:10036
+#: fortran/resolve.c:10049
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "La clause WHERE/ELSEWHERE à %L requiert un tableau LOGICAL"
 
-#: fortran/resolve.c:10138
+#: fortran/resolve.c:10151
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr "gfc_resolve_blocks(): Mauvais type de bloc"
 
-#: fortran/resolve.c:10251
+#: fortran/resolve.c:10264
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr "L'expression CHARACTER sera tronquée dans l'affectation (%ld/%ld) à %L"
 
-#: fortran/resolve.c:10283
+#: fortran/resolve.c:10296
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "L'expression co-indexée à %L est affectée à une variable de type dérivé avec un composant POINTER dans une procédure PURE"
 
-#: fortran/resolve.c:10288
+#: fortran/resolve.c:10301
 #, gcc-internal-format, gfc-internal-format
 msgid "The impure variable at %L is assigned to a derived type variable with a POINTER component in a PURE procedure (12.6)"
 msgstr "La variable impure à %L est affectée à une variable de type dérivé avec un composant POINTER dans une procédure PURE (12.6)"
 
-#: fortran/resolve.c:10298
+#: fortran/resolve.c:10311
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "Affectation à une variable co-indexée à %L dans une procédure PURE"
 
-#: fortran/resolve.c:10330
+#: fortran/resolve.c:10343
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr "L'affectation à un co-tableau polymorphique à %L n'est pas permise"
 
-#: fortran/resolve.c:10334
+#: fortran/resolve.c:10347
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "Affectation à une variable polymorphique allouable à %L"
 
-#: fortran/resolve.c:10339
+#: fortran/resolve.c:10352
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr "L'affectation à une variable polymorphique allouable à %L requiert %<-frealloc-lhs%>"
 
-#: fortran/resolve.c:10346
+#: fortran/resolve.c:10359
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr "La variable non allouable ne doit pas être polymorphique dans l'affectation intrinsèque à %L – vérifiez qu'il existe une sous-routine spécifique correspondante pour l'opérateur « = »"
 
-#: fortran/resolve.c:10357
+#: fortran/resolve.c:10370
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr "La variable co-indexée ne doit pas avoir un composant ultimement allouable dans l'affectation à %L"
 
-#: fortran/resolve.c:10663
+#: fortran/resolve.c:10683
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr "À FAIRE: la/les affectation(s) liée(s) au type à %L n'ont pas été réalisées car des références multiples à des parties de tableaux apparaîtraient dans des expressions intermédiaires."
@@ -59635,67 +59726,67 @@
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:10905
+#: fortran/resolve.c:10925
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr "Affectation à une procédure pointeur à %L"
 
-#: fortran/resolve.c:10917
+#: fortran/resolve.c:10937
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr "Le résultat de la fonction dans le membre de gauche de l'affectation à %L doit avoir l'attribut pointeur."
 
-#: fortran/resolve.c:11157
+#: fortran/resolve.c:11177
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgstr "L'instruction ASSIGNED GOTO à %L requiert une variable INTEGER"
 
-#: fortran/resolve.c:11160
+#: fortran/resolve.c:11180
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "Une étiquette cible n'a pas été affectée à la variable %qs à %L"
 
-#: fortran/resolve.c:11171
+#: fortran/resolve.c:11191
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "L'instruction RETURN alternatif à %L requiert un spécificateur de retour SCALAR-INTEGER"
 
-#: fortran/resolve.c:11233
+#: fortran/resolve.c:11253
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "L'instruction ASSIGN à %L requiert une variable scalaire INTEGER par défaut"
 
-#: fortran/resolve.c:11278
+#: fortran/resolve.c:11298
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid NULL at %L"
 msgstr "NULL invalide à %L"
 
-#: fortran/resolve.c:11282
+#: fortran/resolve.c:11302
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr "L'instruction IF arithmétique à %L requiert une expression scalaire REAL ou INTEGER"
 
-#: fortran/resolve.c:11339
+#: fortran/resolve.c:11359
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr "gfc_resolve_code(): Pas d'expression dans le DO WHILE"
 
-#: fortran/resolve.c:11344
+#: fortran/resolve.c:11364
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "La condition de sortie de la boucle DO WHILE à %L doit être une expression LOGICAL scalaire"
 
-#: fortran/resolve.c:11428
+#: fortran/resolve.c:11448
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "La clause de masque FORALL à %L requiert une expression scalaire LOGICAL"
 
-#: fortran/resolve.c:11507
+#: fortran/resolve.c:11527
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_resolve_code(): Mauvais code d'instruction"
 
-#: fortran/resolve.c:11617
+#: fortran/resolve.c:11637
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "La variable %qs avec l'étiquette de liaison %qs à %L utilise le même identificateur global que l'entité à %L"
@@ -59702,7 +59793,7 @@
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:11630
+#: fortran/resolve.c:11650
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr "La variable %qs du module %qs avec l'étiquette de liaison %qs à %L utilise le même identificateur global que l'entité à %L du module %qs"
@@ -59710,57 +59801,57 @@
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:11647
+#: fortran/resolve.c:11667
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "La procédure %qs avec l'étiquette de liaison %qs à %L utilise le même identificateur global que l'entité à %L"
 
-#: fortran/resolve.c:11732
+#: fortran/resolve.c:11752
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "La longueur de chaîne à %L est trop grande"
 
-#: fortran/resolve.c:11961
+#: fortran/resolve.c:11981
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "Le tableau allouable %qs à %L doit avoir une forme différée ou un rang tacite"
 
-#: fortran/resolve.c:11965
+#: fortran/resolve.c:11985
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "L'objet scalaire %qs à %L ne peut pas être ALLOCATABLE"
 
-#: fortran/resolve.c:11973
+#: fortran/resolve.c:11993
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "Le pointeur tableau %qs à %L doit avoir une forme différée ou un rang tacite"
 
-#: fortran/resolve.c:11983
+#: fortran/resolve.c:12003
 #, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "Le tableau %qs à %L ne peut pas avoir une forme différée"
 
-#: fortran/resolve.c:11998
+#: fortran/resolve.c:12018
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr "Le type %qs de la variable CLASS %qs à %L n'est pas extensible"
 
-#: fortran/resolve.c:12010
+#: fortran/resolve.c:12030
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr "La variable CLASS %qs à %L doit être muette, allouable ou pointeur"
 
-#: fortran/resolve.c:12041
+#: fortran/resolve.c:12061
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr "Le type %qs ne peut pas être associé à un hôte à %L car il est bloqué par un objet incompatible du même nom déclaré à %L"
 
-#: fortran/resolve.c:12063
+#: fortran/resolve.c:12083
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr "SAVE implicite pour la variable module %qs à %L, nécessaire à cause de l'initialisation par défaut"
 
-#: fortran/resolve.c:12090
+#: fortran/resolve.c:12110
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr "L'entité %qs à %L a un paramètre de type différé et requiert soit l'attribut POINTER ou ALLOCATABLE"
@@ -59767,627 +59858,627 @@
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12131
+#: fortran/resolve.c:12151
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "Le tableau %qs à %L du module ou du programme principal doit avoir une forme constante"
 
-#: fortran/resolve.c:12150
+#: fortran/resolve.c:12170
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "L'entité avec une longueur de caractère tacite à %L doit être un argument muet ou un PARAMETER"
 
-#: fortran/resolve.c:12171
+#: fortran/resolve.c:12191
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr "%qs à %L doit avoir une longueur de caractère constante dans ce contexte"
 
-#: fortran/resolve.c:12178
+#: fortran/resolve.c:12198
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "La variable COMMON %qs à %L doit avoir une longueur de caractère constante"
 
-#: fortran/resolve.c:12225
+#: fortran/resolve.c:12245
 #, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "L'allouable %qs à %L ne peut pas avoir une initialisation"
 
-#: fortran/resolve.c:12228
+#: fortran/resolve.c:12248
 #, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr "L'externe %qs à %L ne peut pas avoir une initialisation"
 
-#: fortran/resolve.c:12232
+#: fortran/resolve.c:12252
 #, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "Le muet %qs à %L ne peut pas avoir une initialisation"
 
-#: fortran/resolve.c:12235
+#: fortran/resolve.c:12255
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "L'intrinsèque %qs à %L ne peut pas avoir une initialisation"
 
-#: fortran/resolve.c:12238
+#: fortran/resolve.c:12258
 #, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "Le résultat de fonction %qs à %L ne peut pas avoir une initialisation"
 
-#: fortran/resolve.c:12241
+#: fortran/resolve.c:12261
 #, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "Le tableau automatique %qs à %L ne peut pas avoir une initialisation"
 
-#: fortran/resolve.c:12283
+#: fortran/resolve.c:12303
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L"
 msgstr "%s à %L"
 
-#: fortran/resolve.c:12310
+#: fortran/resolve.c:12330
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "La fonction-instruction %qs avec une valeur de caractère à %L doit avoir une longueur constante"
 
-#: fortran/resolve.c:12332
+#: fortran/resolve.c:12352
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "%qs est d'un type PRIVATE et ne peut pas être un argument muet de %qs, qui est PUBLIC à %L"
 
-#: fortran/resolve.c:12354
+#: fortran/resolve.c:12374
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr "La procédure %qs dans l'interface PUBLIC %qs à %L prend des arguments muets de %qs qui est PRIVATE"
 
-#: fortran/resolve.c:12372
+#: fortran/resolve.c:12392
 #, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "La fonction %qs à %L ne peut pas avoir une initialisation"
 
-#: fortran/resolve.c:12381
+#: fortran/resolve.c:12401
 #, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr "L'objet externe %qs à %L ne peut pas avoir d'initialisation"
 
-#: fortran/resolve.c:12389
+#: fortran/resolve.c:12409
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "La fonction ELEMENTAL %qs à %L doit avoir un résultat scalaire"
 
-#: fortran/resolve.c:12399
+#: fortran/resolve.c:12419
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "La fonction-instruction %qs à %L ne peut pas avoir l'attribut pointeur ou allouable"
 
-#: fortran/resolve.c:12418
+#: fortran/resolve.c:12438
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "La fonction CHARACTER(*) %qs à %L ne peut pas avoir la valeur d'un tableau"
 
-#: fortran/resolve.c:12422
+#: fortran/resolve.c:12442
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "La fonction CHARACTER(*) %qs à %L ne peut pas avoir la valeur d'un pointeur"
 
-#: fortran/resolve.c:12426
+#: fortran/resolve.c:12446
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "La fonction CHARACTER(*) %qs à %L ne peut pas être pure"
 
-#: fortran/resolve.c:12430
+#: fortran/resolve.c:12450
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "La fonction CHARACTER(*) %qs à %L ne peut pas être récursive"
 
-#: fortran/resolve.c:12443
+#: fortran/resolve.c:12463
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "Fonction CHARACTER(*) %qs à %L"
 
-#: fortran/resolve.c:12452
+#: fortran/resolve.c:12472
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "Le pointeur de procédure %qs à %L ne sera point élémental"
 
-#: fortran/resolve.c:12458
+#: fortran/resolve.c:12478
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "La procédure muette %qs à %L ne sera point élémentale"
 
-#: fortran/resolve.c:12470
+#: fortran/resolve.c:12490
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr "La variable résultat %qs de la fonction à %L de la fonction élémentale %qs n'aura point l'attribut ALLOCATABLE ou POINTER"
 
-#: fortran/resolve.c:12527
+#: fortran/resolve.c:12547
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "L'attribut PROCEDURE est en conflit avec l'attribut SAVE dans %qs à %L"
 
-#: fortran/resolve.c:12533
+#: fortran/resolve.c:12553
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "L'attribut PROCEDURE est en conflit avec l'attribut INTENT dans %qs à %L"
 
-#: fortran/resolve.c:12539
+#: fortran/resolve.c:12559
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "L'attribut PROCEDURE est en conflit avec l'attribut RESULT dans %qs à %L"
 
-#: fortran/resolve.c:12547
+#: fortran/resolve.c:12567
 #, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "L'attribut EXTERNAL est en conflit avec l'attribut FUNCTION dans %qs à %L"
 
-#: fortran/resolve.c:12553
+#: fortran/resolve.c:12573
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr "Le résultat du pointeur de procédure %qs à %L n'a pas d'attribut pointeur"
 
-#: fortran/resolve.c:12596
+#: fortran/resolve.c:12616
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "Désaccord sur l'attribut ELEMENTAL entre MODULE PROCEDURE à %L et son interface dans %s"
 
-#: fortran/resolve.c:12604
+#: fortran/resolve.c:12624
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "Désaccord sur l'attribut PURE entre MODULE PROCEDURE à %L et son interface dans %s"
 
-#: fortran/resolve.c:12612
+#: fortran/resolve.c:12632
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "Désaccord sur l'attribut RECURSIVE entre MODULE PROCEDURE à %L et son interface dans %s"
 
-#: fortran/resolve.c:12621
+#: fortran/resolve.c:12641
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr "%s entre la déclaration MODULE PROCEDURE dans MODULE %qs et la déclaration à %L dans (SUB)MODULE %qs"
 
-#: fortran/resolve.c:12705
+#: fortran/resolve.c:12725
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "La procédure FINAL %qs à %L n'est pas une SUBROUTINE"
 
-#: fortran/resolve.c:12714
+#: fortran/resolve.c:12734
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "La procédure FINAL à %L doit avoir exactement un argument"
 
-#: fortran/resolve.c:12723
+#: fortran/resolve.c:12743
 #, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "L'argument de la procédure FINAL à %L doit être du type %qs"
 
-#: fortran/resolve.c:12731
+#: fortran/resolve.c:12751
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "L'argument de la procédure FINAL à %L ne peut pas être un POINTER"
 
-#: fortran/resolve.c:12737
+#: fortran/resolve.c:12757
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "L'argument de la procédure FINAL à %L ne peut pas être ALLOCATABLE"
 
-#: fortran/resolve.c:12743
+#: fortran/resolve.c:12763
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "L'argument de la procédure FINAL à %L ne peut pas être OPTIONAL"
 
-#: fortran/resolve.c:12751
+#: fortran/resolve.c:12771
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "L'argument de la procédure FINAL à %L ne peut pas être INTENT(OUT)"
 
-#: fortran/resolve.c:12760
+#: fortran/resolve.c:12780
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "La procédure FINAL non scalaire à %L devrait avoir un argument de forme tacite"
 
-#: fortran/resolve.c:12782
+#: fortran/resolve.c:12802
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "La procédure FINAL %qs déclarée à %L a le même rang (%d) que %qs"
 
-#: fortran/resolve.c:12819
+#: fortran/resolve.c:12839
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr "Seules des procédures FINAL tableaux déclarées pour le type dérivé %qs à %L, une scalaire est également suggérée"
 
-#: fortran/resolve.c:12859
+#: fortran/resolve.c:12879
 #, gcc-internal-format
 msgid "%qs and %qs can't be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr "%qs et %qs ne peuvent pas être FUNCTION/SUBROUTINE mixte pour GENERIC %qs à %L"
 
-#: fortran/resolve.c:12895
+#: fortran/resolve.c:12915
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr "%qs et %qs pour GENERIC %qs à %L sont ambigus"
 
-#: fortran/resolve.c:12954
+#: fortran/resolve.c:12974
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr "Liaison spécifique %qs non définie comme cible du GENERIC %qs à %L"
 
-#: fortran/resolve.c:12966
+#: fortran/resolve.c:12986
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr "GENERIC %qs à %L doit cibler une liaison spécifique, %qs est GENERIC aussi"
 
-#: fortran/resolve.c:12994
+#: fortran/resolve.c:13014
 #, gcc-internal-format
 msgid "GENERIC %qs at %L can't overwrite specific binding with the same name"
 msgstr "GENERIC %qs à %L ne peut écraser la liaison spécifique avec le même nom"
 
-#: fortran/resolve.c:13050
+#: fortran/resolve.c:13070
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L can't be NOPASS"
 msgstr "L'opérateur lié au type à %L ne peut pas être NOPASS"
 
-#: fortran/resolve.c:13242
+#: fortran/resolve.c:13262
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "%qs doit être une procédure de module ou une procédure externe avec une interface explicite à %L"
 
-#: fortran/resolve.c:13284
+#: fortran/resolve.c:13304
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "La procédure %qs avec PASS(%s) à %L n'a pas d'argument %qs"
 
-#: fortran/resolve.c:13298
+#: fortran/resolve.c:13318
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "La procédure %qs avec PASS à %L doit avoir au moins un argument"
 
-#: fortran/resolve.c:13312 fortran/resolve.c:13778
+#: fortran/resolve.c:13332 fortran/resolve.c:13798
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "Argument muet passé comme objet non polymorphique de %qs à %L"
 
-#: fortran/resolve.c:13320
+#: fortran/resolve.c:13340
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "L'argument %qs de %qs avec PASS(%s) à %L doit être du type dérivé %qs"
 
-#: fortran/resolve.c:13329
+#: fortran/resolve.c:13349
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "L'argument muet de type objet passé de %qs à %L doit être scalaire"
 
-#: fortran/resolve.c:13335
+#: fortran/resolve.c:13355
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "L'argument muet de type objet passé de %qs à %L ne peut pas être ALLOCATABLE"
 
-#: fortran/resolve.c:13341
+#: fortran/resolve.c:13361
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "L'argument muet de type objet passé de %qs à %L ne peut pas être POINTER"
 
-#: fortran/resolve.c:13370
+#: fortran/resolve.c:13390
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "La procédure %qs à %L a le même nom qu'un composant de %qs"
 
-#: fortran/resolve.c:13380
+#: fortran/resolve.c:13400
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "La procédure %qs à %L a le même nom qu'un composant hérité de %qs"
 
-#: fortran/resolve.c:13472
+#: fortran/resolve.c:13492
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr "Le type dérivé %qs déclaré à %L doit être ABSTRACT car %qs est DEFERRED et pas surchargé"
 
-#: fortran/resolve.c:13574
+#: fortran/resolve.c:13594
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "Le composant co-tableau %qs à %L doit être allouable avec une forme différée"
 
-#: fortran/resolve.c:13583
+#: fortran/resolve.c:13603
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "Le composant %qs à %L ayant TYPE(C_PTR) ou TYPE(C_FUNPTR) ne sera point un co-tableau"
 
-#: fortran/resolve.c:13593
+#: fortran/resolve.c:13613
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr "Le composant %qs à %L avec le composant co-tableau sera un scalaire non pointeur, non allouable"
 
-#: fortran/resolve.c:13602
+#: fortran/resolve.c:13622
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr "Le composant %qs à %L a l'attribut CONTIGUOUS mais n'est pas un pointeur de tableau"
 
-#: fortran/resolve.c:13613
+#: fortran/resolve.c:13633
 #, gcc-internal-format
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "Le composant %qs du type BIND(C) à %L doit avoir la longueur un"
 
-#: fortran/resolve.c:13711
+#: fortran/resolve.c:13731
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "Le composant pointeur de procédure %qs avec PASS(%s) à %L n'a pas d'argument %qs"
 
-#: fortran/resolve.c:13725
+#: fortran/resolve.c:13745
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "Le composant pointeur de procédure %qs avec PASS à %L doit avoir au moins un argument"
 
-#: fortran/resolve.c:13741
+#: fortran/resolve.c:13761
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "L'argument %qs de %qs avec PASS(%s) à %L doit être du type dérivé %qs"
 
-#: fortran/resolve.c:13751
+#: fortran/resolve.c:13771
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "L'argument %qs de %qs avec PASS(%s) à %L doit être scalaire"
 
-#: fortran/resolve.c:13760
+#: fortran/resolve.c:13780
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "L'argument %qs de %qs avec PASS(%s) à %L ne peut pas avoir l'attribut POINTER"
 
-#: fortran/resolve.c:13769
+#: fortran/resolve.c:13789
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "L'argument %qs de %qs avec PASS(%s) à %L ne peut pas être ALLOCATABLE"
 
-#: fortran/resolve.c:13811
+#: fortran/resolve.c:13831
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "Le composant %qs de %qs à %L a le même nom qu'une procédure liée au type héritée"
 
-#: fortran/resolve.c:13824
+#: fortran/resolve.c:13844
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "La longueur de caractère du composant %qs doit être une expression de spécification constante à %L"
 
-#: fortran/resolve.c:13835
+#: fortran/resolve.c:13855
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr "Le composant caractère %qs de %qs à %L avec une longueur différée doit être POINTER ou ALLOCATABLE"
 
-#: fortran/resolve.c:13868
+#: fortran/resolve.c:13888
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "le composant %qs est un type PRIVATE et ne peut pas être un composant de %qs, qui est PUBLIC à %L"
 
-#: fortran/resolve.c:13876
+#: fortran/resolve.c:13896
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr "Le composant polymorphique %s à %L dans le type %s SEQUENCE ou BIND(C)"
 
-#: fortran/resolve.c:13885
+#: fortran/resolve.c:13905
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "Le composant %s du type SEQUENCE déclaré à %L n'a pas l'attribut SEQUENCE"
 
-#: fortran/resolve.c:13903 fortran/resolve.c:13915
+#: fortran/resolve.c:13923 fortran/resolve.c:13935
 #, gcc-internal-format
 msgid "The pointer component %qs of %qs at %L is a type that has not been declared"
 msgstr "Le composant pointeur %qs de %qs à %L est un type qui n'a pas été déclaré"
 
-#: fortran/resolve.c:13989
+#: fortran/resolve.c:14009
 #, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "Initialisations conflictuelles dans l'union à %L et %L"
 
-#: fortran/resolve.c:14034
+#: fortran/resolve.c:14054
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr "Puisque l'extension du type %qs à %L a un composant co-tableau, le type parent %qs en aura un aussi"
 
-#: fortran/resolve.c:14047
+#: fortran/resolve.c:14067
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "Le type dérivé non extensible %qs à %L ne peut pas être ABSTRACT"
 
-#: fortran/resolve.c:14111
+#: fortran/resolve.c:14131
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr "Le type paramétrisé %qs n'a pas de composant correspondant au paramètre %qs à %L"
 
-#: fortran/resolve.c:14144
+#: fortran/resolve.c:14164
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr "Nom générique %qs de la fonction %qs à %L étant le même nom que le type dérivé à %L"
 
-#: fortran/resolve.c:14216
+#: fortran/resolve.c:14236
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "Le tableau de taille tacite %qs dans la liste de noms %qs à %L n'est pas permis"
 
-#: fortran/resolve.c:14222
+#: fortran/resolve.c:14242
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "Objet tableau NAMELIST %qs avec la forme tacite dans la liste de noms %qs à %L"
 
-#: fortran/resolve.c:14228
+#: fortran/resolve.c:14248
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "Objet tableau NAMELIST %qs avec la forme non constante dans la liste de noms %qs à %L"
 
-#: fortran/resolve.c:14236
+#: fortran/resolve.c:14256
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "Objet NAMELIST %qs avec une longueur de caractère non constante dans la liste de noms %qs à %L"
 
-#: fortran/resolve.c:14253
+#: fortran/resolve.c:14273
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "L'objet NAMELIST %qs a été déclaré PRIVATE et ne peut pas être membre de la liste de noms PUBLIC %qs à %L"
 
-#: fortran/resolve.c:14275
+#: fortran/resolve.c:14295
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "L'objet NAMELIST %qs a des composants PRIVATE associés à USE et ne peut pas être membre de la liste de noms %qs à %L"
 
-#: fortran/resolve.c:14286
+#: fortran/resolve.c:14306
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "L'objet NAMELIST %qs a des composants PRIVATE et ne peut pas être un membre de la liste de noms PUBLIC %qs à %L"
 
-#: fortran/resolve.c:14313
+#: fortran/resolve.c:14333
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "L'attribut PROCEDURE est en conflit avec l'attribut NAMELIST dans %qs à %L"
 
-#: fortran/resolve.c:14337
+#: fortran/resolve.c:14357
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "Le tableau paramètre %qs à %L ne peut pas être automatique ou de forme différée"
 
-#: fortran/resolve.c:14353
+#: fortran/resolve.c:14373
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "Le PARAMETER %qs implicitement typé à %L ne concorde pas avec le type IMPLICIT ultérieur"
 
-#: fortran/resolve.c:14364
+#: fortran/resolve.c:14384
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "Type dérivé incompatible dans PARAMETER à %L"
 
-#: fortran/resolve.c:14372
+#: fortran/resolve.c:14392
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "La variable CLASS %qs à %L ne peut pas avoir l'attribut PARAMETER"
 
-#: fortran/resolve.c:14423
+#: fortran/resolve.c:14443
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr "L'objet %qs à %L a un paramètre LEN différé %qs et n'est ni allouable ni un pointeur"
 
-#: fortran/resolve.c:14434
+#: fortran/resolve.c:14454
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr "L'objet AUTOMATIC %qs à %L ne doit pas avoir l'attribut SAVE ou être une variable déclarée dans le programme principal, un module ou un sous-module(F08/C513)"
 
-#: fortran/resolve.c:14441
+#: fortran/resolve.c:14461
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr "L'objet %qs à %L avec des paramètres de type ASSUMED doit être fictif ou un sélecteur SELECT TYPE(F08/4.2)"
 
-#: fortran/resolve.c:14480
+#: fortran/resolve.c:14500
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr "Désolé, les composants allouables/pointeurs dans des co-tableaux de types polymorphiques (CLASS) à %L ne sont pas supportés"
 
-#: fortran/resolve.c:14544
+#: fortran/resolve.c:14564
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "L'attribut PROTECTED est en conflit avec l'attribut EXTERNAL à %L"
 
-#: fortran/resolve.c:14547
+#: fortran/resolve.c:14567
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "L'attribut PROCEDURE est en conflit avec l'attribut PROTECTED à %L"
 
-#: fortran/resolve.c:14643
+#: fortran/resolve.c:14663
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr "%qs à %L a l'attribut CONTIGUOUS mais il n'est pas un pointeur de tableau ou un tableau de forme tacite ou de rang tacite"
 
-#: fortran/resolve.c:14664
+#: fortran/resolve.c:14684
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr "Mauvaise spécification pour le tableau de taille tacite à %L"
 
-#: fortran/resolve.c:14677
+#: fortran/resolve.c:14697
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "Le tableau de taille tacite à %L doit être un argument muet"
 
-#: fortran/resolve.c:14680
+#: fortran/resolve.c:14700
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "Le tableau de forme tacite à %L doit être un argument muet"
 
-#: fortran/resolve.c:14688
+#: fortran/resolve.c:14708
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "Le tableau de rang tacite à %L doit être un argument muet"
 
-#: fortran/resolve.c:14695
+#: fortran/resolve.c:14715
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr "Le tableau de rang tacite à %L ne peut pas avoir les attributs VALUE ou CODIMENSION"
 
-#: fortran/resolve.c:14708
+#: fortran/resolve.c:14728
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "Le symbole à %L n'est pas une variable MUETTE"
 
-#: fortran/resolve.c:14714
+#: fortran/resolve.c:14734
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "%qs à %L ne peut pas avoir l'attribut VALUE car ce n'est pas un argument muet"
 
-#: fortran/resolve.c:14724
+#: fortran/resolve.c:14744
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "La variable muette caractère %qs à %L avec l'attribut VALUE doit avoir une longueur constante"
 
-#: fortran/resolve.c:14733
+#: fortran/resolve.c:14753
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "La variable muette caractère %qs, interopérable avec le C, à %L avec l'attribut VALUE doit avoir la longueur un"
 
-#: fortran/resolve.c:14746 fortran/resolve.c:14923
+#: fortran/resolve.c:14766 fortran/resolve.c:14943
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "Le type dérivé %qs à %L est du type %qs qui n'a pas été défini"
 
-#: fortran/resolve.c:14760
+#: fortran/resolve.c:14780
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr "La variable %s à %L avec l'attribut NO_ARG_CHECK sera un argument muet"
 
-#: fortran/resolve.c:14769
+#: fortran/resolve.c:14789
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr "La variable %s à %L avec l'attribut NO_ARG_CHECK sera du type TYPE(*) ou d'un type intrinsèque numérique"
 
-#: fortran/resolve.c:14778
+#: fortran/resolve.c:14798
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "La variable %s à %L avec l'attribut NO_ARG_CHECK ne peut pas avoir les attributs ALLOCATABLE, CODIMENSION, POINTER ou VALUE"
 
-#: fortran/resolve.c:14786
+#: fortran/resolve.c:14806
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "La variable %s à %L avec l'attribut NO_ARG_CHECK ne peut pas avoir l'attribut INTENT(OUT)"
 
-#: fortran/resolve.c:14793
+#: fortran/resolve.c:14813
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr "La variable %s à %L avec l'attribut NO_ARG_CHECK sera soit un scalaire ou un tableau de taille tacite"
 
-#: fortran/resolve.c:14813
+#: fortran/resolve.c:14833
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "Le type tacite de la variable %s à %L est uniquement permis pour des variables muettes"
 
-#: fortran/resolve.c:14820
+#: fortran/resolve.c:14840
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "La variable de type tacite %s à %L ne peut pas avoir les attributs ALLOCATABLE, CODIMENSION, POINTER ou VALUE"
 
-#: fortran/resolve.c:14827
+#: fortran/resolve.c:14847
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "La variable de type tacite %s à %L ne peut pas avoir l'attribut INTENT(OUT)"
 
-#: fortran/resolve.c:14834
+#: fortran/resolve.c:14854
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr "La variable de type tacite %s à %L ne sera point un tableau de forme explicite"
 
-#: fortran/resolve.c:14860
+#: fortran/resolve.c:14880
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr "La variable %qs à %L ne peut pas être BIND(C) car elle n'est ni un bloc COMMON ni déclarée au niveau du module"
 
-#: fortran/resolve.c:14870
+#: fortran/resolve.c:14890
 #, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "La variable BIND(C) %qs à %L doit avoir la longueur un"
@@ -60394,262 +60485,268 @@
 
 # %s est soit « parameter » ou « variable » sans traduction
 # voir bug #80195
-#: fortran/resolve.c:14949
+#: fortran/resolve.c:14969
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "PUBLIC %s %qs à %L du type dérivé PRIVATE %qs"
 
-#: fortran/resolve.c:14964
+#: fortran/resolve.c:14984
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr "La variable %s à %L du type LOCK_TYPE ou avec un sous-composant de type LOCK_TYPE doit être un co-tableau"
 
-#: fortran/resolve.c:14977
+#: fortran/resolve.c:14997
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr "La variable %s à %L du type EVENT_TYPE ou avec un sous-composant du type EVENT_TYPE doit être un co-tableau"
 
-#: fortran/resolve.c:14995
+#: fortran/resolve.c:15015
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "L'argument muet INTENT(OUT) %qs à %L est ASSUMED SIZE et, par conséquent, ne peut pas avoir une initialisation par défaut"
 
-#: fortran/resolve.c:15007
+#: fortran/resolve.c:15027
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "L'argument muet %qs à %L qui est LOCK_TYPE ne sera point INTENT(OUT)"
 
-#: fortran/resolve.c:15016
+#: fortran/resolve.c:15036
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "L'argument muet %qs à %L qui est EVENT_TYPE ne sera point INTENT(OUT)"
 
-#: fortran/resolve.c:15028
+#: fortran/resolve.c:15048
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "Le résultat %qs de la fonction à %L ne sera point un co-tableau et n'aura point un composant co-tableau"
 
-#: fortran/resolve.c:15037
+#: fortran/resolve.c:15057
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "La variable %qs à %L du TYPE(C_PTR) ou TYPE(C_FUNPTR) ne sera point un co-tableau"
 
-#: fortran/resolve.c:15049
+#: fortran/resolve.c:15069
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr "La variable %qs à %L avec un composant co-tableau doit être un scalaire non pointeur, non allouable qui n'est pas un co-tableau"
 
-#: fortran/resolve.c:15065
+#: fortran/resolve.c:15085
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr "La variable %qs à %L est un co-tableau qui n'est pas ALLOCATABLE, SAVE ni un argument muet"
 
-#: fortran/resolve.c:15073
+#: fortran/resolve.c:15093
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "La variable co-tableau %qs à %L n'aura pas de co-dimensions avec une forme différée"
 
-#: fortran/resolve.c:15080
+#: fortran/resolve.c:15100
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "La variable co-tableau allouable %qs à %L doit avoir une forme différée"
 
-#: fortran/resolve.c:15092
+#: fortran/resolve.c:15112
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "La variable %qs à %L est INTENT(OUT) et ne peut donc pas être un co-tableau allouable ou avoir des composants co-tableaux"
 
-#: fortran/resolve.c:15101
+#: fortran/resolve.c:15121
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "La variable muette co-tableau %qs à %L n'est pas permise dans la procédure BIND(C) %qs"
 
-#: fortran/resolve.c:15117
+#: fortran/resolve.c:15137
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "Argument muet LOGICAL %qs à %L avec le sous-type non C_Bool dans la procédure BIND(C) %qs"
 
-#: fortran/resolve.c:15123
+#: fortran/resolve.c:15143
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "Variable résultat LOGICAL %qs à %L avec le sous-type non C_Bool dans la procédure BIND(C) %qs"
 
-#: fortran/resolve.c:15148
+#: fortran/resolve.c:15168
 #, gcc-internal-format
 msgid "Namelist %qs can not be an argument to subroutine or function at %L"
 msgstr "La liste de noms %qs ne peut pas être un argument de la sous-routine ou de la fonction à %L"
 
-#: fortran/resolve.c:15218
+#: fortran/resolve.c:15238
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "Le threadprivate à %L n'est pas sauvegardé avec SAVE"
 
-#: fortran/resolve.c:15229
+#: fortran/resolve.c:15249
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr "La variable !$OMP DECLARE TARGET %qs à %L n'est pas sauvegardée avec SAVE"
 
-#: fortran/resolve.c:15333
+#: fortran/resolve.c:15353
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr "check_data_variable(): Mauvaise expression"
 
-#: fortran/resolve.c:15339
+#: fortran/resolve.c:15359
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "L'élément BLOCK DATA %qs à %L doit être dans COMMON"
 
-#: fortran/resolve.c:15345
+#: fortran/resolve.c:15365
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "Le tableau DATA %qs à %L doit être spécifié dans une déclaration précédente"
 
-#: fortran/resolve.c:15354
+#: fortran/resolve.c:15374
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "L'élément DATA %qs à %L ne peut pas avoir un co-index"
 
-#: fortran/resolve.c:15368
+#: fortran/resolve.c:15388
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr "L'élément DATA %qs à %L est un pointeur et doit donc être un tableau à part entière"
 
-#: fortran/resolve.c:15414
+#: fortran/resolve.c:15434
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "Section de tableau non constante à %L dans l'instruction DATA"
 
-#: fortran/resolve.c:15427
+#: fortran/resolve.c:15447
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "L'instruction DATA à %L a plus de variables que de valeurs"
 
-#: fortran/resolve.c:15526
+#: fortran/resolve.c:15546
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr "Le début de la boucle DO implicite à %L n'a pas pu être simplifiée en une valeur constante"
 
-#: fortran/resolve.c:15534
+#: fortran/resolve.c:15554
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr "La fin de la boucle DO implicite à %L n'a pas pu être simplifiée en une valeur constante"
 
-#: fortran/resolve.c:15542
+#: fortran/resolve.c:15562
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr "Le pas de la boucle DO implicite à %L n'a pas pu être simplifiée en une valeur constante"
 
-#: fortran/resolve.c:15667
+#: fortran/resolve.c:15687
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "L'instruction DATA à %L a plus de valeurs que de variables"
 
-#: fortran/resolve.c:15832
+#: fortran/resolve.c:15852
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "L'étiquette %d à %L est définie mais non utilisée"
 
-#: fortran/resolve.c:15838
+#: fortran/resolve.c:15858
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "L'étiquette %d à %L est définie mais ne peut pas être utilisée"
 
-#: fortran/resolve.c:15922
+#: fortran/resolve.c:15942
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "La variable de type dérivé %qs à %L doit avoir l'attribut SEQUENCE pour être un objet EQUIVALENCE"
 
-#: fortran/resolve.c:15931
+#: fortran/resolve.c:15951
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "La variable de type dérivé %qs à %L ne peut pas avoir des composants ALLOCATABLE pour être un objet EQUIVALENCE"
 
-#: fortran/resolve.c:15939
+#: fortran/resolve.c:15959
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "La variable de type dérivé %qs à %L avec une initialisation par défaut ne peut pas être dans une EQUIVALENCE avec une variable dans COMMON"
 
-#: fortran/resolve.c:15955
+#: fortran/resolve.c:15975
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "La variable de type dérivé %qs à %L avec un ou des composants pointeurs ne peut pas être dans un objet EQUIVALENCE"
 
-#: fortran/resolve.c:16058
+#: fortran/resolve.c:16078
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "Erreur de syntaxe dans l'instruction EQUIVALENCE à %L"
 
-#: fortran/resolve.c:16073
+#: fortran/resolve.c:16093
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr "Soit aucun ou tous les objets dans l'ensemble EQUIVALENCE à %L aura l'attribut PROTECTED"
 
-#: fortran/resolve.c:16098
+#: fortran/resolve.c:16118
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "Le membre %qs du bloc COMMON à %L ne peut pas être un objet EQUIVALENCE dans la procédure pure %qs"
 
-#: fortran/resolve.c:16107
+#: fortran/resolve.c:16127
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "La constante nommée %qs à %L ne peut pas être un objet EQUIVALENCE"
 
-#: fortran/resolve.c:16180
+#: fortran/resolve.c:16200
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "Le tableau %qs à %L avec des limites non constantes ne peut pas être un objet EQUIVALENCE"
 
-#: fortran/resolve.c:16191
+#: fortran/resolve.c:16211
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Le composant de structure %qs à %L ne peut pas être un objet EQUIVALENCE"
 
-#: fortran/resolve.c:16202
+#: fortran/resolve.c:16222
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "La sous-chaîne à %L a une longueur zéro"
 
-#: fortran/resolve.c:16293
+#: fortran/resolve.c:16253
+#, fuzzy, gcc-internal-format
+#| msgid "Syntax error in character length specification at %C"
+msgid "Self reference in character length expression for %qs at %L"
+msgstr "Erreur de syntaxe dans la spécification de la longueur de caractère à %C"
+
+#: fortran/resolve.c:16320
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "Fonction PUBLIC %qs à %L du type PRIVATE %qs"
 
-#: fortran/resolve.c:16306
+#: fortran/resolve.c:16333
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "ENTRY %qs à %L n'a pas de type IMPLICIT"
 
-#: fortran/resolve.c:16326
+#: fortran/resolve.c:16353
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "La procédure opérateur utilisateur %qs à %L doit être une FUNCTION"
 
-#: fortran/resolve.c:16336
+#: fortran/resolve.c:16363
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "La procédure opérateur utilisateur %qs à %L ne peut pas être une longueur de caractère tacite"
 
-#: fortran/resolve.c:16344
+#: fortran/resolve.c:16371
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "La procédure opérateur utilisateur %qs à %L doit avoir au moins un argument"
 
-#: fortran/resolve.c:16358
+#: fortran/resolve.c:16385
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "Le premier argument de l'interface opérateur à %L ne peut pas être optionnel"
 
-#: fortran/resolve.c:16376
+#: fortran/resolve.c:16403
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "Le deuxième argument de l'interface opérateur à %L ne peut pas être optionnel"
 
-#: fortran/resolve.c:16383
+#: fortran/resolve.c:16410
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "L'interface opérateur à %L doit avoir, au plus, deux arguments"
 
-#: fortran/resolve.c:16461
+#: fortran/resolve.c:16488
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr "La procédure contenue %qs à %L d'une procédure PURE doit aussi être PURE"
@@ -60975,19 +61072,13 @@
 msgid "simplify_min_max(): Bad type in arglist"
 msgstr "simplify_min_max(): Mauvais type dans la liste d'arguments"
 
-#. Result is processor-dependent.
-#: fortran/simplify.c:5472
-#, gcc-internal-format, gfc-internal-format
-msgid "Second argument MOD at %L is zero"
-msgstr "Le deuxième argument de MOD à %L est zéro"
+#: fortran/simplify.c:5470 fortran/simplify.c:5478
+#, fuzzy, gcc-internal-format
+#| msgid "Argument %<S%> of NEAREST at %L shall not be zero"
+msgid "Argument %qs of MOD at %L shall not be zero"
+msgstr "L'argument %<S%> de NEAREST à %L ne sera point zéro"
 
-#. Result is processor-dependent.
-#: fortran/simplify.c:5483
-#, gcc-internal-format, gfc-internal-format
-msgid "Second argument of MOD at %L is zero"
-msgstr "Le deuxième argument de MOD à %L est zéro"
-
-#: fortran/simplify.c:5494
+#: fortran/simplify.c:5484
 #, gcc-internal-format
 msgid "gfc_simplify_mod(): Bad arguments"
 msgstr "gfc_simplify_mod(): Mauvais arguments"
@@ -60995,97 +61086,97 @@
 #. Result is processor-dependent. This processor just opts
 #. to not handle it at all.
 #. Result is processor-dependent.
-#: fortran/simplify.c:5520 fortran/simplify.c:5532
+#: fortran/simplify.c:5525 fortran/simplify.c:5537
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of MODULO at %L is zero"
 msgstr "Le deuxième argument de MODULO à %L est zéro"
 
-#: fortran/simplify.c:5552
+#: fortran/simplify.c:5557
 #, gcc-internal-format
 msgid "gfc_simplify_modulo(): Bad arguments"
 msgstr "gfc_simplify_modulo(): Mauvais arguments"
 
-#: fortran/simplify.c:5600
+#: fortran/simplify.c:5605
 #, gcc-internal-format, gfc-internal-format
 msgid "Result of NEAREST is NaN at %L"
 msgstr "Le résultat de NEAREST est NaN à %L"
 
-#: fortran/simplify.c:6081
+#: fortran/simplify.c:6086
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative at %L"
 msgstr "L'argument NCOPIES de l'intrinsèque REPEAT est négatif à %L"
 
-#: fortran/simplify.c:6137
+#: fortran/simplify.c:6142
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument NCOPIES of REPEAT intrinsic is too large at %L"
 msgstr "L'argument NCOPIES de l'intrinsèque REPEAT est trop grand à %L"
 
-#: fortran/simplify.c:6174
+#: fortran/simplify.c:6179
 #, gcc-internal-format, gfc-internal-format
 msgid "Evaluation of string longer than 2**28 at %L deferred to runtime, expect bugs"
 msgstr "L'évaluation d'une chaîne plus grande que 2**28 à %L est différée à l'exécution, attendez-vous à des bogues"
 
-#: fortran/simplify.c:6302
+#: fortran/simplify.c:6307
 #, gcc-internal-format, gfc-internal-format
 msgid "Reshaped array too large at %C"
 msgstr "Le tableau qui a changé de forme est trop grand à %C"
 
-#: fortran/simplify.c:6416
+#: fortran/simplify.c:6421
 #, gcc-internal-format, gfc-internal-format
 msgid "Result of SCALE overflows its kind at %L"
 msgstr "Le résultat de SCALE déborde de son sous-type à %L"
 
-#: fortran/simplify.c:6995
+#: fortran/simplify.c:7000
 #, gcc-internal-format
 msgid "Bad type in gfc_simplify_sign"
 msgstr "Mauvais type dans gfc_simplify_sign"
 
-#: fortran/simplify.c:7024
+#: fortran/simplify.c:7029
 #, gcc-internal-format
 msgid "in gfc_simplify_sin(): Bad type"
 msgstr "dans gfc_simplify_sin(): Mauvais type"
 
-#: fortran/simplify.c:7151 fortran/simplify.c:7431
+#: fortran/simplify.c:7156 fortran/simplify.c:7436
 #, gcc-internal-format
 msgid "Failure getting length of a constant array."
 msgstr "Échec en récupérant la longueur d'un tableau constant."
 
-#: fortran/simplify.c:7161
+#: fortran/simplify.c:7166
 #, gcc-internal-format
 msgid "The number of elements (%d) in the array constructor at %L requires an increase of the allowed %d upper limit.  See %<-fmax-array-constructor%> option."
 msgstr "Le nombre d'éléments (%d) dans le constructeur du tableau à %L requiert une augmentation de la limite supérieure permise %d. Voyez l'option %<-fmax-array-constructor%>."
 
-#: fortran/simplify.c:7227
+#: fortran/simplify.c:7232
 #, gcc-internal-format, gfc-internal-format
 msgid "Simplification of SPREAD at %C not yet implemented"
 msgstr "La simplification de SPREAD à %C n'est pas encore implémentée"
 
-#: fortran/simplify.c:7251
+#: fortran/simplify.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SQRT at %L has a negative value"
 msgstr "L'argument de SQRT à %L a une valeur négative"
 
-#: fortran/simplify.c:7267
+#: fortran/simplify.c:7272
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid argument of SQRT at %L"
 msgstr "argument invalide pour SQRT à %L"
 
-#: fortran/simplify.c:7598
+#: fortran/simplify.c:7603
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY lower bound is %ld)"
 msgstr "Limites enfreintes dans IMAGE_INDEX à %L pour la dimension %d, SUB vaut %ld et la limite inférieure de COARRAY est %ld)"
 
-#: fortran/simplify.c:7621
+#: fortran/simplify.c:7626
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY upper bound is %ld)"
 msgstr "Limites enfreintes dans IMAGE_INDEX à %L pour la dimension %d, SUB vaut %ld et la limite supérieure de COARRAY est %ld)"
 
-#: fortran/simplify.c:7993
+#: fortran/simplify.c:7998
 #, gcc-internal-format
 msgid "gfc_convert_constant(): Unexpected type"
 msgstr "gfc_convert_constant(): Type inattendu"
 
-#: fortran/simplify.c:8078
+#: fortran/simplify.c:8083
 #, gcc-internal-format
 msgid "Character %qs in string at %L cannot be converted into character kind %d"
 msgstr "Le caractère %qs dans la chaîne à %L ne peut pas être converti en un caractère du sous-type %d"
@@ -61188,7 +61279,7 @@
 msgid "BIND(C) applied to %s %s at %L"
 msgstr "BIND(C) appliqué à %s %s à %L"
 
-#: fortran/symbol.c:901 fortran/symbol.c:912 fortran/symbol.c:1762
+#: fortran/symbol.c:901 fortran/symbol.c:912 fortran/symbol.c:1776
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute conflicts with %s attribute at %L"
 msgstr "L'attribut %s est en conflit avec l'attribut %s à %L"
@@ -61263,17 +61354,23 @@
 msgid "Duplicate VOLATILE attribute specified at %L"
 msgstr "Attribut VOLATILE spécifié en double à %L"
 
-#: fortran/symbol.c:1367
+#: fortran/symbol.c:1360
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "SAVE attribute at %L cannot be specified in a PURE procedure"
+msgid "VOLATILE attribute at %L cannot be specified in a PURE procedure"
+msgstr "L'attribut SAVE à %L ne peut pas être spécifié dans une procédure PURE"
+
+#: fortran/symbol.c:1381
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ASYNCHRONOUS attribute specified at %L"
 msgstr "Attribut ASYNCHRONOUS spécifié en double à %L"
 
-#: fortran/symbol.c:1758
+#: fortran/symbol.c:1772
 #, gcc-internal-format
 msgid "%s attribute of %qs conflicts with %s attribute at %L"
 msgstr "L'attribut %s de %qs est en conflit avec l'attribut %s à %L"
 
-#: fortran/symbol.c:1794
+#: fortran/symbol.c:1808
 #, gcc-internal-format, gfc-internal-format
 msgid ""
 "%s procedure at %L is already declared as %s procedure. \n"
@@ -61282,208 +61379,208 @@
 "La procédure %s à %L est déjà déclarée comme procédure %s.\n"
 "F2008: Une affectation à une fonction pointeur est ambigüe si elle est la première instruction exécutable après la spécification du bloc. Veuillez ajouter n'importe quel autre type d'instruction exécutable avant elle. FIXME"
 
-#: fortran/symbol.c:1802
+#: fortran/symbol.c:1816
 #, gcc-internal-format, gfc-internal-format
 msgid "%s procedure at %L is already declared as %s procedure"
 msgstr "La procédure %s à %L est déjà déclarée comme procédure %s"
 
-#: fortran/symbol.c:1837
+#: fortran/symbol.c:1851
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgstr "INTENT (%s) est en conflit avec INTENT(%s) à %L"
 
-#: fortran/symbol.c:1861
+#: fortran/symbol.c:1875
 #, gcc-internal-format, gfc-internal-format
 msgid "ACCESS specification at %L was already specified"
 msgstr "La spécification ACCESS à %L a déjà été spécifiée"
 
-#: fortran/symbol.c:1878
+#: fortran/symbol.c:1892
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate BIND attribute specified at %L"
 msgstr "L'attribut BIND est spécifié en double à %L"
 
-#: fortran/symbol.c:1885
+#: fortran/symbol.c:1899
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) at %L"
 msgstr "BIND(C) à %L"
 
-#: fortran/symbol.c:1901
+#: fortran/symbol.c:1915
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate EXTENDS attribute specified at %L"
 msgstr "L'attribut EXTENDS est spécifié en double à %L"
 
-#: fortran/symbol.c:1905
+#: fortran/symbol.c:1919
 #, gcc-internal-format, gfc-internal-format
 msgid "EXTENDS at %L"
 msgstr "EXTENDS à %L"
 
-#: fortran/symbol.c:1931
+#: fortran/symbol.c:1945
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has an explicit interface"
 msgstr "Le symbole %qs à %L a déjà une interface explicite"
 
-#: fortran/symbol.c:1938
+#: fortran/symbol.c:1952
 #, gcc-internal-format
 msgid "%qs at %L has attributes specified outside its INTERFACE body"
 msgstr "%qs à %L a des attributs spécifiés en dehors du corps de son INTERFACE"
 
-#: fortran/symbol.c:1976
+#: fortran/symbol.c:1990
 #, gcc-internal-format
 msgid "Symbol %qs at %L conflicts with symbol from module %qs, use-associated at %L"
 msgstr "Le symbole %qs à %L est en conflit avec le symbole du module %qs, associé à USE à %L"
 
-#: fortran/symbol.c:1980
+#: fortran/symbol.c:1994
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr "Le symbole %qs à %L a déjà le type de base %s"
 
-#: fortran/symbol.c:1987
+#: fortran/symbol.c:2001
 #, gcc-internal-format
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr "La procédure %qs à %L ne peut pas avoir le type de base %s"
 
-#: fortran/symbol.c:1999
+#: fortran/symbol.c:2013
 #, gcc-internal-format
 msgid "Symbol %qs at %L cannot have a type"
 msgstr "Le symbole %qs à %L ne peut pas avoir de type"
 
-#: fortran/symbol.c:2242
+#: fortran/symbol.c:2256
 #, gcc-internal-format
 msgid "Component %qs at %C already in the parent type at %L"
 msgstr "Le composant %qs à %C est déjà dans le type parent à %L"
 
-#: fortran/symbol.c:2327
+#: fortran/symbol.c:2341
 #, gcc-internal-format
 msgid "Symbol %qs at %C is ambiguous"
 msgstr "Le symbole %qs à %C est ambigu"
 
-#: fortran/symbol.c:2359
+#: fortran/symbol.c:2373
 #, gcc-internal-format
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr "Le type dérivé %qs à %C est utilisé avant sa définition"
 
-#: fortran/symbol.c:2508
+#: fortran/symbol.c:2522
 #, gcc-internal-format
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr "Le composant %qs à %C est un composant PRIVATE de %qs"
 
-#: fortran/symbol.c:2529
+#: fortran/symbol.c:2543
 #, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure; did you mean %qs?"
 msgstr "%qs à %C n'est pas un membre de la structure %qs; vouliez-vous employer %qs ?"
 
-#: fortran/symbol.c:2533
+#: fortran/symbol.c:2547
 #, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr "%qs à %C n'est pas un membre de la structure %qs"
 
-#: fortran/symbol.c:2697
+#: fortran/symbol.c:2711
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr "Étiquette d'instruction %d dupliquée à %L et %L"
 
-#: fortran/symbol.c:2708
+#: fortran/symbol.c:2722
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr "L'étiquette %d à %C est déjà référencée comme cible d'un branchement"
 
-#: fortran/symbol.c:2718
+#: fortran/symbol.c:2732
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr "L'étiquette %d à %C est déjà référencée comme une étiquette de format"
 
-#: fortran/symbol.c:2724
+#: fortran/symbol.c:2738
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr "Instruction de fin de DO qui n'est pas END DO ou CONTINUE avec l'étiquette %d à %C"
 
-#: fortran/symbol.c:2766
+#: fortran/symbol.c:2780
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr "Étiquette %d à %C précédemment utilisée comme étiquette de FORMAT"
 
-#: fortran/symbol.c:2775
+#: fortran/symbol.c:2789
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr "Étiquette %d à %C précédemment utilisée comme cible de branchement"
 
-#: fortran/symbol.c:2781
+#: fortran/symbol.c:2795
 #, gcc-internal-format, gfc-internal-format
 msgid "Shared DO termination label %d at %C"
 msgstr "Étiquette de fin de DO %d partagée à %C"
 
-#: fortran/symbol.c:3110
+#: fortran/symbol.c:3124
 #, gcc-internal-format
 msgid "new_symbol(): Symbol name too long"
 msgstr "new_symbol(): Nom de symbole trop long"
 
-#: fortran/symbol.c:3135
+#: fortran/symbol.c:3149
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr "Le nom %qs à %C est une référence ambigüe à %qs depuis le module %qs"
 
-#: fortran/symbol.c:3138
+#: fortran/symbol.c:3152
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
 msgstr "Le nom %qs à %C est une référence ambigüe à %qs depuis l'unité de programme actuelle"
 
 #. Symbol is from another namespace.
-#: fortran/symbol.c:3381
+#: fortran/symbol.c:3395
 #, gcc-internal-format
 msgid "Symbol %qs at %C has already been host associated"
 msgstr "Le symbole %qs à %C a déjà été associée à un hôte"
 
-#: fortran/symbol.c:4397
+#: fortran/symbol.c:4411
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr "verify_bind_c_derived_type(): Le symbole donné est NULL de manière inattendue"
 
-#: fortran/symbol.c:4410
+#: fortran/symbol.c:4424
 #, gcc-internal-format
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr "Le type dérivé %qs, déclaré à %L, doit avoir l'attribut BIND pour être interopérable avec le C"
 
-#: fortran/symbol.c:4428
+#: fortran/symbol.c:4442
 #, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr "Le type dérivé %qs avec l'attribut BIND(C) à %L est vide et peut être inaccessible pour le processeur C compagnon"
 
-#: fortran/symbol.c:4449
+#: fortran/symbol.c:4463
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr "Le composant %qs à %L ne peut pas avoir l'attribut POINTER car il est un membre du type dérivé BIND(C) %qs à %L"
 
-#: fortran/symbol.c:4459
+#: fortran/symbol.c:4473
 #, gcc-internal-format
 msgid "Procedure pointer component %qs at %L cannot be a member of the BIND(C) derived type %qs at %L"
 msgstr "Le composant pointeur de procédure %qs à %L ne peut pas être un membre du type dérivé BIND(C) %qs à %L"
 
-#: fortran/symbol.c:4470
+#: fortran/symbol.c:4484
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr "Le composant %qs à %L ne peut pas avoir l'attribut ALLOCATABLE car il est un membre du type dérivé BIND(C) %qs à %L"
 
-#: fortran/symbol.c:4509
+#: fortran/symbol.c:4523
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr "Le composant %qs dans le type dérivé %qs à %L peut ne pas être interopérable avec le C bien que le type dérivé %qs soit BIND(C)"
 
-#: fortran/symbol.c:4519
+#: fortran/symbol.c:4533
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr "Le composant %qs dans le type dérivé %qs à %L peut ne pas être interopérable avec le C"
 
-#: fortran/symbol.c:4533
+#: fortran/symbol.c:4547
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot be declared with both PRIVATE and BIND(C) attributes"
 msgstr "Le type dérivé %qs à %L ne peut pas être déclaré avec les deux attributs PRIVATE et BIND(C) à la fois"
 
-#: fortran/symbol.c:4541
+#: fortran/symbol.c:4555
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr "Le type dérivé %qs à %L ne peut pas avoir l'attribut SEQUENCE car il est BIND(C)"
 
-#: fortran/symbol.c:5018 fortran/symbol.c:5023
+#: fortran/symbol.c:5032 fortran/symbol.c:5037
 #, gcc-internal-format
 msgid "Symbol %qs is used before it is typed at %L"
 msgstr "Le symbole %qs est utilisé à %L avant qu'un type lui soit assigné"
@@ -61530,7 +61627,7 @@
 msgid "Creating array temporary at %L for argument %qs"
 msgstr "Création d'un temporaire pour le tableau à %L dans l'argument %qs"
 
-#: fortran/trans-array.c:10693
+#: fortran/trans-array.c:10724
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr "mauvais type d'expression durant le parcours (%d)"
@@ -61732,12 +61829,12 @@
 msgid "%<dim%> argument of %s intrinsic at %L is not a valid dimension index"
 msgstr "L'argument %<dim%> de l'intrinsèque %s à %L n'est pas un index de dimension valide"
 
-#: fortran/trans-intrinsic.c:10572 fortran/trans-stmt.c:1050
+#: fortran/trans-intrinsic.c:10574 fortran/trans-stmt.c:1050
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, the event component of derived type at %L is not yet supported"
 msgstr "Désolé, le composant de l'événement du type dérivé à %L n'est pas encore supporté"
 
-#: fortran/trans-intrinsic.c:10579
+#: fortran/trans-intrinsic.c:10581
 #, gcc-internal-format, gfc-internal-format
 msgid "The event variable at %L shall not be coindexed"
 msgstr "La variable d'événement à %L ne sera point co-indexée"
@@ -61777,7 +61874,7 @@
 msgid "Sorry, only support for integer kind %d implemented for image-set at %L"
 msgstr "Désolé, seul le support pour les entiers du sous-type %d est implémenté pour l'ensemble d'images à %L"
 
-#: fortran/trans-stmt.c:3346
+#: fortran/trans-stmt.c:3343
 #, gcc-internal-format
 msgid "gfc_trans_select(): Bad type for case expr."
 msgstr "gfc_trans_select(): Mauvais type pour l'expression case"
@@ -61903,7 +62000,7 @@
 msgid "two or more sections for %s"
 msgstr "deux sections ou plus pour %s"
 
-#: lto/lto-partition.c:516
+#: lto/lto-partition.c:570
 #, gcc-internal-format
 msgid "min partition size cannot be greater than max partition size"
 msgstr "la taille de partition minimale ne peut pas être plus grande que la taille de partition maximale"
@@ -62039,57 +62136,57 @@
 msgid "Cannot read %s"
 msgstr "Impossible de lire %s"
 
-#: lto/lto.c:2369
+#: lto/lto.c:2337
 #, gcc-internal-format
 msgid "lto_obj_file_open() failed"
 msgstr "lto_obj_file_open() a échoué"
 
-#: lto/lto.c:2394
+#: lto/lto.c:2362
 #, gcc-internal-format
 msgid "waitpid failed"
 msgstr "waitpid a échoué"
 
-#: lto/lto.c:2397
+#: lto/lto.c:2365
 #, gcc-internal-format
 msgid "streaming subprocess failed"
 msgstr "la mise en ligne du sous processus a échoué"
 
-#: lto/lto.c:2400
+#: lto/lto.c:2368
 #, gcc-internal-format
 msgid "streaming subprocess was killed by signal"
 msgstr "la mise en ligne du sous processus a été tuée par un signal"
 
-#: lto/lto.c:2476
+#: lto/lto.c:2445
 #, gcc-internal-format
 msgid "no LTRANS output list filename provided"
 msgstr "aucun nom de fichier fourni pour la liste de sortie LTRANS"
 
-#: lto/lto.c:2564
+#: lto/lto.c:2525
 #, gcc-internal-format
 msgid "opening LTRANS output list %s: %m"
 msgstr "ouverture de la liste de sortie LTRANS %s: %m"
 
-#: lto/lto.c:2570
+#: lto/lto.c:2532
 #, gcc-internal-format
 msgid "writing to LTRANS output list %s: %m"
 msgstr "écriture de la liste de sortie LTRANS %s: %m"
 
-#: lto/lto.c:2581
+#: lto/lto.c:2542
 #, gcc-internal-format
 msgid "closing LTRANS output list %s: %m"
 msgstr "fermeture de la liste de sortie LTRANS %s: %m"
 
-#: lto/lto.c:2833
+#: lto/lto.c:2794
 #, gcc-internal-format
 msgid "could not open symbol resolution file: %m"
 msgstr "n'a pu ouvrir le fichier de résolution des symboles: %m"
 
-#: lto/lto.c:2954
+#: lto/lto.c:2915
 #, gcc-internal-format, gfc-internal-format
 msgid "missing resolution data for %s"
 msgstr "donnée de résolution manquante pour %s"
 
-#: lto/lto.c:2986
+#: lto/lto.c:2947
 #, gcc-internal-format
 msgid "errors during merging of translation units"
 msgstr "erreurs durant la fusion des unités de traductions"
@@ -63031,6 +63128,21 @@
 msgid "creating selector for nonexistent method %qE"
 msgstr "création d'un sélecteur pour la méthode inexistante %qE"
 
+#~ msgid "Warn if the loop cannot be optimized due to nontrivial assumptions."
+#~ msgstr "Avertir si une boucle ne peut pas être optimisée à cause de suppositions non triviales."
+
+#~ msgid "Expected constant array-spec in initializer list at %L"
+#~ msgstr "array-spec contant attendu dans la liste d'initialisation à %L"
+
+#~ msgid "Errmsg-variable at %L must be a scalar CHARACTER variable"
+#~ msgstr "La variable errmsg à %L doit être une variable CHARACTER scalaire"
+
+#~ msgid "Second argument MOD at %L is zero"
+#~ msgstr "Le deuxième argument de MOD à %L est zéro"
+
+#~ msgid "Second argument of MOD at %L is zero"
+#~ msgstr "Le deuxième argument de MOD à %L est zéro"
+
 #~ msgid "Support Control-flow Enforcement Technology (CET) built-in functions and code generation."
 #~ msgstr "Supporter les fonctions internes CET (Control-flow Enforcement Technology) et la génération de code."
 
@@ -63981,9 +64093,6 @@
 #~ msgid "deduction guide %qD must be declared in the same scope as %qT"
 #~ msgstr "le guide de déduction %qD doit être déclaré dans la même portée que %qT"
 
-#~ msgid "  declared here"
-#~ msgstr "  déclaré ici"
-
 #, fuzzy
 #~| msgid "`%D' will be initialized after"
 #~ msgid "%q#D initialized"
Index: gcc/po/hr.po
===================================================================
--- gcc/po/hr.po	(.../tags/gcc_8_2_0_release)
+++ gcc/po/hr.po	(.../branches/gcc-8-branch)
@@ -7,7 +7,7 @@
 msgstr ""
 "Project-Id-Version: gcc 4.7.1\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2018-05-01 20:30+0000\n"
+"POT-Creation-Date: 2018-07-25 14:25+0000\n"
 "PO-Revision-Date: 2012-07-05 15:49+0200\n"
 "Last-Translator: Tomislav Krznar <tomislav.krznar@gmail.com>\n"
 "Language-Team: Croatian <lokalizacija@linux.hr>\n"
@@ -40,12 +40,12 @@
 msgid "[cannot find %s]"
 msgstr "[ne mogu naći %s]"
 
-#: collect2.c:1557
+#: collect2.c:1585
 #, c-format
 msgid "collect2 version %s\n"
 msgstr "collect2 inačica %s\n"
 
-#: collect2.c:1664
+#: collect2.c:1692
 #, c-format
 msgid "%d constructor found\n"
 msgid_plural "%d constructors found\n"
@@ -53,7 +53,7 @@
 msgstr[1] "%d konstruktora pronađena\n"
 msgstr[2] "%d konstruktora pronađeno\n"
 
-#: collect2.c:1668
+#: collect2.c:1696
 #, c-format
 msgid "%d destructor found\n"
 msgid_plural "%d destructors found\n"
@@ -61,7 +61,7 @@
 msgstr[1] "%d destruktora pronađena\n"
 msgstr[2] "%d destruktora pronađeno\n"
 
-#: collect2.c:1672
+#: collect2.c:1700
 #, c-format
 msgid "%d frame table found\n"
 msgid_plural "%d frame tables found\n"
@@ -69,12 +69,12 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: collect2.c:1836
+#: collect2.c:1864
 #, c-format
 msgid "[Leaving %s]\n"
 msgstr "[Napuštam %s]\n"
 
-#: collect2.c:2068
+#: collect2.c:2094
 #, c-format
 msgid ""
 "\n"
@@ -81,7 +81,7 @@
 "write_c_file - output name is %s, prefix is %s\n"
 msgstr ""
 
-#: collect2.c:2584
+#: collect2.c:2610
 #, c-format
 msgid ""
 "\n"
@@ -104,7 +104,7 @@
 msgid "%s: some warnings being treated as errors"
 msgstr ""
 
-#: diagnostic.c:324 input.c:222 input.c:1834 c-family/c-opts.c:1377
+#: diagnostic.c:324 input.c:222 input.c:1834 c-family/c-opts.c:1392
 #: fortran/cpp.c:576 fortran/error.c:1008 fortran/error.c:1028
 msgid "<built-in>"
 msgstr ""
@@ -202,13 +202,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:4164 config/arc/arc.c:5784 config/i386/i386.c:17302
+#: final.c:4164 config/arc/arc.c:5775 config/i386/i386.c:17305
 #: config/pdp11/pdp11.c:1715
 #, c-format
 msgid "floating constant misused"
 msgstr ""
 
-#: final.c:4222 config/arc/arc.c:5881 config/i386/i386.c:17393
+#: final.c:4222 config/arc/arc.c:5872 config/i386/i386.c:17396
 #: config/pdp11/pdp11.c:1756
 #, c-format
 msgid "invalid expression as operand"
@@ -1143,7 +1143,7 @@
 msgid "GCSE disabled"
 msgstr "GCSE onemogućen"
 
-#: gimple-ssa-isolate-paths.c:542 c/c-typeck.c:10240
+#: gimple-ssa-isolate-paths.c:542 c/c-typeck.c:10245
 #, gcc-internal-format
 msgid "function returns address of local variable"
 msgstr ""
@@ -1446,7 +1446,7 @@
 msgid "options enabled: "
 msgstr "omogućene opcije: "
 
-#: tree-diagnostic.c:299 c/c-decl.c:5419 c/c-typeck.c:7259 cp/error.c:1042
+#: tree-diagnostic.c:299 c/c-decl.c:5439 c/c-typeck.c:7264 cp/error.c:1042
 #: c-family/c-pretty-print.c:413
 #, gcc-internal-format
 msgid "<anonymous>"
@@ -2908,67 +2908,67 @@
 msgstr ""
 
 #. Handle deferred options from command-line.
-#: c-family/c-opts.c:1402 fortran/cpp.c:590
+#: c-family/c-opts.c:1417 fortran/cpp.c:590
 msgid "<command-line>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6613
+#: config/aarch64/aarch64.c:6629
 #, c-format
 msgid "unsupported operand for code '%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6624 config/aarch64/aarch64.c:6640
-#: config/aarch64/aarch64.c:6652 config/aarch64/aarch64.c:6663
-#: config/aarch64/aarch64.c:6673 config/aarch64/aarch64.c:6694
-#: config/aarch64/aarch64.c:6764 config/aarch64/aarch64.c:6775
-#: config/aarch64/aarch64.c:6789 config/aarch64/aarch64.c:7011
-#: config/aarch64/aarch64.c:7029
+#: config/aarch64/aarch64.c:6640 config/aarch64/aarch64.c:6656
+#: config/aarch64/aarch64.c:6668 config/aarch64/aarch64.c:6679
+#: config/aarch64/aarch64.c:6689 config/aarch64/aarch64.c:6710
+#: config/aarch64/aarch64.c:6780 config/aarch64/aarch64.c:6791
+#: config/aarch64/aarch64.c:6805 config/aarch64/aarch64.c:7027
+#: config/aarch64/aarch64.c:7045
 #, c-format
 msgid "invalid operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6709 config/aarch64/aarch64.c:6720
-#: config/aarch64/aarch64.c:6871 config/aarch64/aarch64.c:6882
+#: config/aarch64/aarch64.c:6725 config/aarch64/aarch64.c:6736
+#: config/aarch64/aarch64.c:6887 config/aarch64/aarch64.c:6898
 #, c-format
 msgid "invalid vector constant"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6732 config/aarch64/aarch64.c:6744
-#: config/aarch64/aarch64.c:6755
+#: config/aarch64/aarch64.c:6748 config/aarch64/aarch64.c:6760
+#: config/aarch64/aarch64.c:6771
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6823 config/arm/arm.c:22704
+#: config/aarch64/aarch64.c:6839 config/arm/arm.c:22704
 #, c-format
 msgid "missing operand"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6908
+#: config/aarch64/aarch64.c:6924
 #, fuzzy, c-format
 #| msgid "invalid %%-code"
 msgid "invalid constant"
 msgstr "neispravni %%-kod"
 
-#: config/aarch64/aarch64.c:6911
+#: config/aarch64/aarch64.c:6927
 #, fuzzy, c-format
 #| msgid "invalid expression as operand"
 msgid "invalid operand"
 msgstr "neispravni izraz kao operand"
 
-#: config/aarch64/aarch64.c:7040 config/aarch64/aarch64.c:7045
+#: config/aarch64/aarch64.c:7056 config/aarch64/aarch64.c:7061
 #, c-format
 msgid "invalid operand prefix '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:7062
+#: config/aarch64/aarch64.c:7078
 #, fuzzy, c-format
 #| msgid "invalid 'asm': "
 msgid "invalid address mode"
 msgstr "neispravni „asm”: "
 
-#: config/alpha/alpha.c:5125 config/i386/i386.c:18558
-#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21798
+#: config/alpha/alpha.c:5125 config/i386/i386.c:18561
+#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21875
 #: config/sparc/sparc.c:9290
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
@@ -2985,7 +2985,7 @@
 msgstr ""
 
 #: config/alpha/alpha.c:5223 config/ia64/ia64.c:5534
-#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21506
+#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21583
 #: config/xtensa/xtensa.c:2429
 #, c-format
 msgid "invalid %%R value"
@@ -2992,13 +2992,13 @@
 msgstr ""
 
 #: config/alpha/alpha.c:5229 config/powerpcspe/powerpcspe.c:23933
-#: config/rs6000/rs6000.c:21426 config/xtensa/xtensa.c:2396
+#: config/rs6000/rs6000.c:21503 config/xtensa/xtensa.c:2396
 #, c-format
 msgid "invalid %%N value"
 msgstr ""
 
 #: config/alpha/alpha.c:5237 config/powerpcspe/powerpcspe.c:23961
-#: config/rs6000/rs6000.c:21454
+#: config/rs6000/rs6000.c:21531
 #, c-format
 msgid "invalid %%P value"
 msgstr ""
@@ -3029,7 +3029,7 @@
 msgstr ""
 
 #: config/alpha/alpha.c:5323 config/powerpcspe/powerpcspe.c:24021
-#: config/rs6000/rs6000.c:21514
+#: config/rs6000/rs6000.c:21591
 #, c-format
 msgid "invalid %%s value"
 msgstr ""
@@ -3040,7 +3040,7 @@
 msgstr ""
 
 #: config/alpha/alpha.c:5371 config/powerpcspe/powerpcspe.c:23797
-#: config/rs6000/rs6000.c:21290
+#: config/rs6000/rs6000.c:21367
 #, c-format
 msgid "invalid %%E value"
 msgstr ""
@@ -3051,7 +3051,7 @@
 msgstr ""
 
 #: config/alpha/alpha.c:5405 config/cr16/cr16.c:1569
-#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21803
+#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21880
 #: config/spu/spu.c:1458
 #, c-format
 msgid "invalid %%xn code"
@@ -3062,62 +3062,62 @@
 msgid "invalid operand address"
 msgstr ""
 
-#: config/arc/arc.c:3810
+#: config/arc/arc.c:3808
 #, fuzzy, c-format
 #| msgid "invalid %%-code"
 msgid "invalid operand to %%Z code"
 msgstr "neispravni %%-kod"
 
-#: config/arc/arc.c:3818
+#: config/arc/arc.c:3816
 #, fuzzy, c-format
 #| msgid "invalid %%-code"
 msgid "invalid operand to %%z code"
 msgstr "neispravni %%-kod"
 
-#: config/arc/arc.c:3826
+#: config/arc/arc.c:3824
 #, fuzzy, c-format
 #| msgid "invalid %%-code"
 msgid "invalid operands to %%c code"
 msgstr "neispravni %%-kod"
 
-#: config/arc/arc.c:3834
+#: config/arc/arc.c:3832
 #, fuzzy, c-format
 #| msgid "invalid %%-code"
 msgid "invalid operand to %%M code"
 msgstr "neispravni %%-kod"
 
-#: config/arc/arc.c:3842 config/m32r/m32r.c:2100
+#: config/arc/arc.c:3840 config/m32r/m32r.c:2100
 #, c-format
 msgid "invalid operand to %%p code"
 msgstr ""
 
-#: config/arc/arc.c:3853 config/m32r/m32r.c:2093
+#: config/arc/arc.c:3851 config/m32r/m32r.c:2093
 #, c-format
 msgid "invalid operand to %%s code"
 msgstr ""
 
-#: config/arc/arc.c:4001 config/m32r/m32r.c:2126
+#: config/arc/arc.c:3999 config/m32r/m32r.c:2126
 #, c-format
 msgid "invalid operand to %%R code"
 msgstr ""
 
-#: config/arc/arc.c:4077 config/m32r/m32r.c:2149
+#: config/arc/arc.c:4075 config/m32r/m32r.c:2149
 #, c-format
 msgid "invalid operand to %%H/%%L code"
 msgstr ""
 
-#: config/arc/arc.c:4145 config/m32r/m32r.c:2220
+#: config/arc/arc.c:4143 config/m32r/m32r.c:2220
 #, c-format
 msgid "invalid operand to %%U code"
 msgstr ""
 
-#: config/arc/arc.c:4157
+#: config/arc/arc.c:4155
 #, fuzzy, c-format
 #| msgid "invalid %%-code"
 msgid "invalid operand to %%V code"
 msgstr "neispravni %%-kod"
 
-#: config/arc/arc.c:4214
+#: config/arc/arc.c:4212
 #, fuzzy, c-format
 #| msgid "invalid %%-code"
 msgid "invalid operand to %%O code"
@@ -3125,19 +3125,19 @@
 
 #. Unknown flag.
 #. Undocumented flag.
-#: config/arc/arc.c:4240 config/epiphany/epiphany.c:1305
-#: config/m32r/m32r.c:2247 config/nds32/nds32.c:3079 config/sparc/sparc.c:9569
+#: config/arc/arc.c:4238 config/epiphany/epiphany.c:1305
+#: config/m32r/m32r.c:2247 config/nds32/nds32.c:3080 config/sparc/sparc.c:9569
 #, c-format
 msgid "invalid operand output code"
 msgstr ""
 
-#: config/arc/arc.c:5869
+#: config/arc/arc.c:5860
 #, fuzzy, c-format
 #| msgid "invalid expression as operand"
 msgid "invalid UNSPEC as operand: %d"
 msgstr "neispravni izraz kao operand"
 
-#: config/arc/arc.c:6158 config/cris/cris.c:2568
+#: config/arc/arc.c:6149 config/cris/cris.c:2568
 msgid "unrecognized supposed constant"
 msgstr ""
 
@@ -3172,7 +3172,7 @@
 #: config/arm/arm.c:22685 config/arm/arm.c:22692 config/bfin/bfin.c:1441
 #: config/bfin/bfin.c:1448 config/bfin/bfin.c:1455 config/bfin/bfin.c:1462
 #: config/bfin/bfin.c:1471 config/bfin/bfin.c:1478 config/bfin/bfin.c:1485
-#: config/bfin/bfin.c:1492 config/nds32/nds32.c:3098
+#: config/bfin/bfin.c:1492 config/nds32/nds32.c:3099
 #, c-format
 msgid "invalid operand for code '%c'"
 msgstr ""
@@ -3511,101 +3511,101 @@
 msgid "bad output_condmove_single operand"
 msgstr ""
 
-#: config/i386/i386.c:17387
+#: config/i386/i386.c:17390
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr ""
 
-#: config/i386/i386.c:17925
+#: config/i386/i386.c:17928
 #, c-format
 msgid "invalid use of register '%s'"
 msgstr ""
 
-#: config/i386/i386.c:17930
+#: config/i386/i386.c:17933
 #, c-format
 msgid "invalid use of asm flag output"
 msgstr ""
 
-#: config/i386/i386.c:18160
+#: config/i386/i386.c:18163
 #, fuzzy, c-format
 #| msgid "invalid expression as operand"
 msgid "invalid operand size for operand code 'O'"
 msgstr "neispravni izraz kao operand"
 
-#: config/i386/i386.c:18195
+#: config/i386/i386.c:18198
 #, fuzzy, c-format
 #| msgid "invalid expression as operand"
 msgid "invalid operand size for operand code 'z'"
 msgstr "neispravni izraz kao operand"
 
-#: config/i386/i386.c:18264
+#: config/i386/i386.c:18267
 #, c-format
 msgid "invalid operand type used with operand code 'Z'"
 msgstr ""
 
-#: config/i386/i386.c:18269
+#: config/i386/i386.c:18272
 #, fuzzy, c-format
 #| msgid "invalid expression as operand"
 msgid "invalid operand size for operand code 'Z'"
 msgstr "neispravni izraz kao operand"
 
-#: config/i386/i386.c:18346
+#: config/i386/i386.c:18349
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr ""
 
-#: config/i386/i386.c:18425
+#: config/i386/i386.c:18428
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr ""
 
-#: config/i386/i386.c:18443
+#: config/i386/i386.c:18446
 #, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr ""
 
-#: config/i386/i386.c:18456
+#: config/i386/i386.c:18459
 #, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr ""
 
-#: config/i386/i386.c:18471
+#: config/i386/i386.c:18474
 #, c-format
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr ""
 
-#: config/i386/i386.c:18499
+#: config/i386/i386.c:18502
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr ""
 
-#: config/i386/i386.c:18517
+#: config/i386/i386.c:18520
 #, c-format
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr ""
 
-#: config/i386/i386.c:18540
+#: config/i386/i386.c:18543
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr ""
 
-#: config/i386/i386.c:18626
+#: config/i386/i386.c:18629
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr ""
 
-#: config/i386/i386.c:18688
+#: config/i386/i386.c:18691
 #, c-format
 msgid "invalid constraints for operand"
 msgstr ""
 
-#: config/i386/i386.c:18738
+#: config/i386/i386.c:18741
 #, fuzzy, c-format
 #| msgid "invalid %%-code"
 msgid "invalid vector immediate"
 msgstr "neispravni %%-kod"
 
-#: config/i386/i386.c:29572
+#: config/i386/i386.c:29575
 msgid "unknown insn mode"
 msgstr ""
 
@@ -3643,7 +3643,7 @@
 msgstr ""
 
 #: config/iq2000/iq2000.c:3185 config/powerpcspe/powerpcspe.c:23951
-#: config/rs6000/rs6000.c:21444
+#: config/rs6000/rs6000.c:21521
 #, c-format
 msgid "invalid %%p value"
 msgstr ""
@@ -3697,7 +3697,7 @@
 msgstr ""
 
 #: config/m32r/m32r.c:2350 config/m32r/m32r.c:2365
-#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33292
+#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33348
 msgid "bad address"
 msgstr ""
 
@@ -3817,186 +3817,186 @@
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4411 config/rs6000/rs6000.c:4258
+#: config/powerpcspe/powerpcspe.c:4411 config/rs6000/rs6000.c:4278
 msgid "-maltivec=le not allowed for big-endian targets"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4423 config/rs6000/rs6000.c:4273
+#: config/powerpcspe/powerpcspe.c:4423 config/rs6000/rs6000.c:4293
 msgid "-mvsx requires hardware floating point"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4431 config/rs6000/rs6000.c:4281
+#: config/powerpcspe/powerpcspe.c:4431 config/rs6000/rs6000.c:4301
 msgid "-mvsx and -mpaired are incompatible"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4433 config/rs6000/rs6000.c:4283
+#: config/powerpcspe/powerpcspe.c:4433 config/rs6000/rs6000.c:4303
 msgid "-mvsx needs indexed addressing"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4438 config/rs6000/rs6000.c:4288
+#: config/powerpcspe/powerpcspe.c:4438 config/rs6000/rs6000.c:4308
 msgid "-mvsx and -mno-altivec are incompatible"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4440 config/rs6000/rs6000.c:4290
+#: config/powerpcspe/powerpcspe.c:4440 config/rs6000/rs6000.c:4310
 msgid "-mno-altivec disables vsx"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4648 config/rs6000/rs6000.c:4416
+#: config/powerpcspe/powerpcspe.c:4648 config/rs6000/rs6000.c:4436
 msgid "-mquad-memory requires 64-bit mode"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4651 config/rs6000/rs6000.c:4419
+#: config/powerpcspe/powerpcspe.c:4651 config/rs6000/rs6000.c:4439
 msgid "-mquad-memory-atomic requires 64-bit mode"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4663 config/rs6000/rs6000.c:4431
+#: config/powerpcspe/powerpcspe.c:4663 config/rs6000/rs6000.c:4451
 msgid "-mquad-memory is not available in little endian mode"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4735 config/rs6000/rs6000.c:4512
+#: config/powerpcspe/powerpcspe.c:4735 config/rs6000/rs6000.c:4532
 msgid "-mtoc-fusion requires 64-bit"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4742 config/rs6000/rs6000.c:4519
+#: config/powerpcspe/powerpcspe.c:4742 config/rs6000/rs6000.c:4539
 msgid "-mtoc-fusion requires medium/large code model"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10915
+#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10947
 msgid "bad move"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21087
+#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21164
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21278
+#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21355
 #, fuzzy, c-format
 #| msgid "invalid %%-code"
 msgid "invalid %%e value"
 msgstr "neispravni %%-kod"
 
-#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21299
+#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21376
 #, c-format
 msgid "invalid %%f value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21308
+#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21385
 #, c-format
 msgid "invalid %%F value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21317
+#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21394
 #, c-format
 msgid "invalid %%G value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21352
+#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21429
 #, c-format
 msgid "invalid %%j code"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21362
+#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21439
 #, c-format
 msgid "invalid %%J code"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21372
+#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21449
 #, c-format
 msgid "invalid %%k value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21387
+#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21464
 #: config/xtensa/xtensa.c:2415
 #, c-format
 msgid "invalid %%K value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21434
+#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21511
 #, c-format
 msgid "invalid %%O value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21481
+#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21558
 #, c-format
 msgid "invalid %%q value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21534
+#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21611
 #, c-format
 msgid "invalid %%T value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21546
+#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21623
 #, c-format
 msgid "invalid %%u value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21560
+#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21637
 #: config/xtensa/xtensa.c:2384
 #, c-format
 msgid "invalid %%v value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21627
+#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21704
 #: config/xtensa/xtensa.c:2436
 #, c-format
 msgid "invalid %%x value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21747
+#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21824
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22282
+#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22359
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22288
+#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22365
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22294
+#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22371
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36572
+#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36628
 msgid "AltiVec argument passed to unprototyped function"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38739
+#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38795
 msgid "Could not generate addis value for fusion"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38809
+#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38865
 msgid "Unable to generate load/store offset for fusion"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38908
+#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38964
 msgid "Bad GPR fusion"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39126
+#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39182
 msgid "emit_fusion_p9_load, bad reg #1"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39172
+#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39228
 msgid "emit_fusion_p9_load, bad reg #2"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39175
+#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39231
 msgid "emit_fusion_p9_load not MEM"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39213
+#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39269
 msgid "emit_fusion_p9_store, bad reg #1"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39259
+#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39315
 msgid "emit_fusion_p9_store, bad reg #2"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39262
+#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39318
 msgid "emit_fusion_p9_store not MEM"
 msgstr ""
 
@@ -4373,14 +4373,14 @@
 #: c/gimple-parser.c:188 c/gimple-parser.c:197 c/gimple-parser.c:226
 #: c/gimple-parser.c:1375 c/gimple-parser.c:1404 c/gimple-parser.c:1484
 #: c/gimple-parser.c:1511 c/c-parser.c:3204 c/c-parser.c:9967
-#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27841
-#: cp/parser.c:28430
+#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27838
+#: cp/parser.c:28427
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "očekujem %<;%>"
 
 #: c/c-parser.c:2431 c/c-parser.c:7573 c/c-parser.c:8015 c/c-parser.c:8058
-#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27839 cp/parser.c:28448
+#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27836 cp/parser.c:28445
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "očekujem %<,%>"
@@ -4395,7 +4395,7 @@
 #: c/gimple-parser.c:821 c/gimple-parser.c:837 c/gimple-parser.c:853
 #: c/gimple-parser.c:880 c/gimple-parser.c:915 c/gimple-parser.c:1038
 #: c/gimple-parser.c:1209 c/gimple-parser.c:1220 c/gimple-parser.c:1342
-#: c/gimple-parser.c:1441 cp/parser.c:28478
+#: c/gimple-parser.c:1441 cp/parser.c:28475
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "očekujem %<)%>"
@@ -4403,7 +4403,7 @@
 #: c/c-parser.c:3824 c/c-parser.c:4733 c/c-parser.c:4769 c/c-parser.c:6441
 #: c/c-parser.c:8125 c/c-parser.c:8983 c/c-parser.c:9127 c/c-parser.c:11588
 #: c/c-parser.c:18220 c/c-parser.c:18222 c/gimple-parser.c:1015
-#: cp/parser.c:28442
+#: cp/parser.c:28439
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "očekujem %<]%>"
@@ -4417,7 +4417,7 @@
 #: c/c-parser.c:17792 c/gimple-parser.c:363 c/gimple-parser.c:811
 #: c/gimple-parser.c:873 c/gimple-parser.c:911 c/gimple-parser.c:1198
 #: c/gimple-parser.c:1339 c/gimple-parser.c:1438 c/c-parser.c:11911
-#: cp/parser.c:28433
+#: cp/parser.c:28430
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "očekujem %<(%>"
@@ -4424,7 +4424,7 @@
 
 #: c/c-parser.c:4903 c/c-parser.c:10310 c/c-parser.c:16212 c/c-parser.c:18449
 #: c/gimple-parser.c:141 c/gimple-parser.c:1444 c/c-parser.c:3018
-#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18155 cp/parser.c:28439
+#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18152 cp/parser.c:28436
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "očekujem %<{%>"
@@ -4434,13 +4434,13 @@
 #: c/c-parser.c:12351 c/c-parser.c:12493 c/c-parser.c:12864 c/c-parser.c:12957
 #: c/c-parser.c:13566 c/c-parser.c:17636 c/c-parser.c:17695
 #: c/gimple-parser.c:431 c/gimple-parser.c:1492 c/gimple-parser.c:1519
-#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28472 cp/parser.c:29597
-#: cp/parser.c:32279
+#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28469 cp/parser.c:29594
+#: cp/parser.c:32276
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "očekujem %<:%>"
 
-#: c/c-parser.c:5974 cp/parser.c:28365
+#: c/c-parser.c:5974 cp/parser.c:28362
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "očekujem %<while%>"
@@ -4449,18 +4449,18 @@
 msgid "expected %<.%>"
 msgstr "očekujem %<.%>"
 
-#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30172
-#: cp/parser.c:30246
+#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30169
+#: cp/parser.c:30243
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "očekujem %<@end%>"
 
-#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28457
+#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28454
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "očekujem %<>%>"
 
-#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28481
+#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28478
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "očekujem %<,%> ili %<)%>"
@@ -4468,32 +4468,32 @@
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15190 c/c-parser.c:15234 c/c-parser.c:15466 c/c-parser.c:15701
 #: c/c-parser.c:17833 c/gimple-parser.c:286 c/c-parser.c:4792
-#: cp/parser.c:28460
+#: cp/parser.c:28457
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "očekujem %<=%>"
 
-#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28436
-#: cp/parser.c:30389
+#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28433
+#: cp/parser.c:30386
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "očekujem %<}%>"
 
-#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35674
+#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35671
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr ""
 
-#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28445 cp/parser.c:31535
+#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28442 cp/parser.c:31532
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "očekujem %<[%>"
 
-#: c/c-typeck.c:7847
+#: c/c-typeck.c:7852
 msgid "(anonymous)"
 msgstr ""
 
-#: c/gimple-parser.c:795 cp/parser.c:15791 cp/parser.c:28454
+#: c/gimple-parser.c:795 cp/parser.c:15788 cp/parser.c:28451
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr ""
@@ -4748,11 +4748,11 @@
 msgid "%r%s:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr ""
 
-#: cp/pt.c:1949 cp/semantics.c:5268
+#: cp/pt.c:1949 cp/semantics.c:5271
 msgid "candidates are:"
 msgstr ""
 
-#: cp/pt.c:1951 cp/pt.c:22975
+#: cp/pt.c:1951 cp/pt.c:23053
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] ""
@@ -4799,27 +4799,27 @@
 msgid "source type is not polymorphic"
 msgstr ""
 
-#: cp/typeck.c:6083 c/c-typeck.c:4261
+#: cp/typeck.c:6083 c/c-typeck.c:4266
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr ""
 
-#: cp/typeck.c:6084 c/c-typeck.c:4248
+#: cp/typeck.c:6084 c/c-typeck.c:4253
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr ""
 
-#: cp/typeck.c:6111 c/c-typeck.c:4302
+#: cp/typeck.c:6111 c/c-typeck.c:4307
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr ""
 
-#: cp/typeck.c:6128 c/c-typeck.c:4310
+#: cp/typeck.c:6128 c/c-typeck.c:4315
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr ""
 
-#: cp/typeck.c:6140 c/c-typeck.c:4322
+#: cp/typeck.c:6140 c/c-typeck.c:4327
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr ""
@@ -5059,67 +5059,67 @@
 msgid "Expected attribute bit name"
 msgstr ""
 
-#: fortran/module.c:3223
+#: fortran/module.c:3225
 msgid "Expected integer string"
 msgstr ""
 
-#: fortran/module.c:3227
+#: fortran/module.c:3229
 msgid "Error converting integer"
 msgstr ""
 
-#: fortran/module.c:3249
+#: fortran/module.c:3251
 msgid "Expected real string"
 msgstr ""
 
-#: fortran/module.c:3474
+#: fortran/module.c:3476
 msgid "Expected expression type"
 msgstr ""
 
-#: fortran/module.c:3554
+#: fortran/module.c:3556
 msgid "Bad operator"
 msgstr ""
 
-#: fortran/module.c:3671
+#: fortran/module.c:3673
 msgid "Bad type in constant expression"
 msgstr ""
 
-#: fortran/module.c:7038
+#: fortran/module.c:7040
 msgid "Unexpected end of module"
 msgstr ""
 
-#: fortran/parse.c:1757
+#: fortran/parse.c:1761
 msgid "arithmetic IF"
 msgstr ""
 
-#: fortran/parse.c:1766
+#: fortran/parse.c:1770
 msgid "attribute declaration"
 msgstr ""
 
-#: fortran/parse.c:1802
+#: fortran/parse.c:1806
 msgid "data declaration"
 msgstr ""
 
-#: fortran/parse.c:1820
+#: fortran/parse.c:1824
 msgid "derived type declaration"
 msgstr ""
 
-#: fortran/parse.c:1947
+#: fortran/parse.c:1951
 msgid "block IF"
 msgstr ""
 
-#: fortran/parse.c:1956
+#: fortran/parse.c:1960
 msgid "implied END DO"
 msgstr ""
 
-#: fortran/parse.c:2050 fortran/resolve.c:11199
+#: fortran/parse.c:2054 fortran/resolve.c:11219
 msgid "assignment"
 msgstr ""
 
-#: fortran/parse.c:2053 fortran/resolve.c:11250 fortran/resolve.c:11253
+#: fortran/parse.c:2057 fortran/resolve.c:11270 fortran/resolve.c:11273
 msgid "pointer assignment"
 msgstr ""
 
-#: fortran/parse.c:2071
+#: fortran/parse.c:2075
 msgid "simple IF"
 msgstr ""
 
@@ -5211,106 +5211,111 @@
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:3878
+#: fortran/resolve.c:3879
 #, c-format
+msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
+msgstr ""
+
+#: fortran/resolve.c:3884
+#, c-format
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3893
+#: fortran/resolve.c:3899
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3926
+#: fortran/resolve.c:3932
 #, c-format
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3949
+#: fortran/resolve.c:3955
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:3963
+#: fortran/resolve.c:3969
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr ""
 
-#: fortran/resolve.c:4015
+#: fortran/resolve.c:4021
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr ""
 
-#: fortran/resolve.c:4021
+#: fortran/resolve.c:4027
 #, c-format
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4034
+#: fortran/resolve.c:4040
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L; did you mean '%s'?"
 msgstr ""
 
-#: fortran/resolve.c:4037
+#: fortran/resolve.c:4043
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr ""
 
-#: fortran/resolve.c:4040
+#: fortran/resolve.c:4046
 #, c-format
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:4044
+#: fortran/resolve.c:4050
 #, c-format
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4132
+#: fortran/resolve.c:4138
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr ""
 
-#: fortran/resolve.c:6849
+#: fortran/resolve.c:6855
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.c:6853
+#: fortran/resolve.c:6859
 msgid "iterator variable"
 msgstr ""
 
-#: fortran/resolve.c:6857
+#: fortran/resolve.c:6863
 msgid "Start expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:6861
+#: fortran/resolve.c:6867
 msgid "End expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:6865
+#: fortran/resolve.c:6871
 msgid "Step expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:7150 fortran/resolve.c:7153
+#: fortran/resolve.c:7156 fortran/resolve.c:7159
 msgid "DEALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.c:7525 fortran/resolve.c:7528
+#: fortran/resolve.c:7531 fortran/resolve.c:7534
 msgid "ALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.c:7720 fortran/resolve.c:9417
+#: fortran/resolve.c:7726 fortran/resolve.c:9428
 msgid "STAT variable"
 msgstr ""
 
-#: fortran/resolve.c:7764 fortran/resolve.c:9429
+#: fortran/resolve.c:7770 fortran/resolve.c:9440
 msgid "ERRMSG variable"
 msgstr ""
 
-#: fortran/resolve.c:9219
+#: fortran/resolve.c:9230
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.c:9441
+#: fortran/resolve.c:9452
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
@@ -5343,7 +5348,7 @@
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:10154
+#: fortran/trans-expr.c:10157
 msgid "Assignment of scalar to unallocated array"
 msgstr ""
 
@@ -5352,12 +5357,12 @@
 msgid "Unequal character lengths (%ld/%ld) in %s"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:8088
+#: fortran/trans-intrinsic.c:8090
 #, c-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative (its value is %ld)"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:8120
+#: fortran/trans-intrinsic.c:8122
 msgid "Argument NCOPIES of REPEAT intrinsic is too large"
 msgstr ""
 
@@ -5378,15 +5383,15 @@
 msgid "Invalid image number %d in SYNC IMAGES"
 msgstr ""
 
-#: fortran/trans-stmt.c:2180
+#: fortran/trans-stmt.c:2177
 msgid "Loop iterates infinitely"
 msgstr ""
 
-#: fortran/trans-stmt.c:2200 fortran/trans-stmt.c:2456
+#: fortran/trans-stmt.c:2197 fortran/trans-stmt.c:2453
 msgid "Loop variable has been modified"
 msgstr ""
 
-#: fortran/trans-stmt.c:2309
+#: fortran/trans-stmt.c:2306
 msgid "DO step value is zero"
 msgstr ""
 
@@ -5977,10 +5982,10 @@
 msgid "Allow dollar signs in entity names."
 msgstr ""
 
-#: fortran/lang.opt:485 config/alpha/alpha.opt:31 common.opt:783
-#: common.opt:985 common.opt:989 common.opt:993 common.opt:997 common.opt:1532
-#: common.opt:1588 common.opt:1712 common.opt:1716 common.opt:1946
-#: common.opt:2116 common.opt:2792
+#: fortran/lang.opt:485 config/alpha/alpha.opt:31 common.opt:649
+#: common.opt:783 common.opt:989 common.opt:993 common.opt:997 common.opt:1001
+#: common.opt:1536 common.opt:1592 common.opt:1716 common.opt:1720
+#: common.opt:1950 common.opt:2120 common.opt:2796
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr ""
 
@@ -6200,12 +6205,12 @@
 msgstr ""
 
 #: fortran/lang.opt:751 c-family/c.opt:1356 c-family/c.opt:1384
-#: c-family/c.opt:1634 config/pa/pa.opt:42 config/pa/pa.opt:70 common.opt:1154
-#: common.opt:1333 common.opt:1408 common.opt:1676 common.opt:1799
-#: common.opt:2169 common.opt:2205 common.opt:2298 common.opt:2302
-#: common.opt:2407 common.opt:2498 common.opt:2506 common.opt:2514
-#: common.opt:2522 common.opt:2623 common.opt:2675 common.opt:2755
-#: common.opt:2893 common.opt:2897 common.opt:2901 common.opt:2905
+#: c-family/c.opt:1634 config/pa/pa.opt:42 config/pa/pa.opt:70 common.opt:1158
+#: common.opt:1337 common.opt:1412 common.opt:1680 common.opt:1803
+#: common.opt:2173 common.opt:2209 common.opt:2302 common.opt:2306
+#: common.opt:2411 common.opt:2502 common.opt:2510 common.opt:2518
+#: common.opt:2526 common.opt:2627 common.opt:2679 common.opt:2759
+#: common.opt:2897 common.opt:2901 common.opt:2905 common.opt:2909
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr ""
 
@@ -6255,7 +6260,7 @@
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:220 c-family/c.opt:224
 #: c-family/c.opt:236 c-family/c.opt:1855 c-family/c.opt:1863 brig/lang.opt:39
-#: config/darwin.opt:56 common.opt:338 common.opt:341 common.opt:3046
+#: config/darwin.opt:56 common.opt:338 common.opt:341 common.opt:3050
 #, c-format
 msgid "missing filename after %qs"
 msgstr ""
@@ -6831,7 +6836,7 @@
 #: c-family/c.opt:1525 c-family/c.opt:1528 c-family/c.opt:1569
 #: c-family/c.opt:1704 c-family/c.opt:1731 c-family/c.opt:1771
 #: c-family/c.opt:1802 c-family/c.opt:1806 c-family/c.opt:1822
-#: config/ia64/ia64.opt:167 config/ia64/ia64.opt:170 c-family/c-opts.c:434
+#: config/ia64/ia64.opt:167 config/ia64/ia64.opt:170 c-family/c-opts.c:432
 #, gcc-internal-format
 msgid "switch %qs is no longer supported"
 msgstr ""
@@ -13888,10 +13893,6 @@
 msgid "Warn if dereferencing a NULL pointer may lead to erroneous or undefined behavior."
 msgstr ""
 
-#: common.opt:649
-msgid "Warn if the loop cannot be optimized due to nontrivial assumptions."
-msgstr ""
-
 #: common.opt:656
 msgid "Warn about some C++ One Definition Rule violations during link time optimization."
 msgstr ""
@@ -14060,1680 +14061,1680 @@
 msgid "-dumpdir <dir>\tSet the directory name to be used for dumps."
 msgstr ""
 
-#: common.opt:946
+#: common.opt:950
 msgid "The version of the C++ ABI in use."
 msgstr ""
 
-#: common.opt:950
+#: common.opt:954
 msgid "Aggressively optimize loops using language constraints."
 msgstr ""
 
-#: common.opt:954
+#: common.opt:958
 msgid "Align the start of functions."
 msgstr ""
 
-#: common.opt:964
+#: common.opt:968
 msgid "Align labels which are only reached by jumping."
 msgstr ""
 
-#: common.opt:971
+#: common.opt:975
 msgid "Align all labels."
 msgstr ""
 
-#: common.opt:978
+#: common.opt:982
 msgid "Align the start of loops."
 msgstr ""
 
-#: common.opt:1001
+#: common.opt:1005
 msgid "Select what to sanitize."
 msgstr ""
 
-#: common.opt:1005
+#: common.opt:1009
 msgid "Select type of coverage sanitization."
 msgstr ""
 
-#: common.opt:1009
+#: common.opt:1013
 msgid "-fasan-shadow-offset=<number>\tUse custom shadow memory offset."
 msgstr ""
 
-#: common.opt:1013
+#: common.opt:1017
 msgid "-fsanitize-sections=<sec1,sec2,...>\tSanitize global variables in user-defined sections."
 msgstr ""
 
-#: common.opt:1018
+#: common.opt:1022
 msgid "After diagnosing undefined behavior attempt to continue execution."
 msgstr ""
 
-#: common.opt:1022
+#: common.opt:1026
 msgid "This switch is deprecated; use -fsanitize-recover= instead."
 msgstr ""
 
-#: common.opt:1029
+#: common.opt:1033
 msgid "Use trap instead of a library function for undefined behavior sanitization."
 msgstr ""
 
-#: common.opt:1033
+#: common.opt:1037
 msgid "Generate unwind tables that are exact at each instruction boundary."
 msgstr ""
 
-#: common.opt:1037
+#: common.opt:1041
 msgid "Generate auto-inc/dec instructions."
 msgstr ""
 
-#: common.opt:1041
+#: common.opt:1045
 msgid "Use sample profile information for call graph node weights. The default profile file is fbdata.afdo in 'pwd'."
 msgstr ""
 
-#: common.opt:1046
+#: common.opt:1050
 msgid "Use sample profile information for call graph node weights. The profile file is specified in the argument."
 msgstr ""
 
-#: common.opt:1055
+#: common.opt:1059
 msgid "Generate code to check bounds before indexing arrays."
 msgstr ""
 
-#: common.opt:1059
+#: common.opt:1063
 msgid "Replace add, compare, branch with branch on count register."
 msgstr ""
 
-#: common.opt:1063
+#: common.opt:1067
 msgid "Use profiling information for branch probabilities."
 msgstr ""
 
-#: common.opt:1067
+#: common.opt:1071
 msgid "Perform branch target load optimization before prologue / epilogue threading."
 msgstr ""
 
-#: common.opt:1071
+#: common.opt:1075
 msgid "Perform branch target load optimization after prologue / epilogue threading."
 msgstr ""
 
-#: common.opt:1075
+#: common.opt:1079
 msgid "Restrict target load migration not to re-use registers in any basic block."
 msgstr ""
 
-#: common.opt:1079
+#: common.opt:1083
 msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions."
 msgstr ""
 
-#: common.opt:1083
+#: common.opt:1087
 msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls."
 msgstr ""
 
-#: common.opt:1090
+#: common.opt:1094
 msgid "Save registers around function calls."
 msgstr ""
 
-#: common.opt:1094
+#: common.opt:1098
 msgid "This switch is deprecated; do not use."
 msgstr ""
 
-#: common.opt:1098
+#: common.opt:1102
 msgid "Check the return value of new in C++."
 msgstr ""
 
-#: common.opt:1102 common.opt:1106
+#: common.opt:1106 common.opt:1110
 msgid "Perform internal consistency checkings."
 msgstr ""
 
-#: common.opt:1110
+#: common.opt:1114
 msgid "Enable code hoisting."
 msgstr ""
 
-#: common.opt:1114
+#: common.opt:1118
 msgid "Looks for opportunities to reduce stack adjustments and stack references."
 msgstr ""
 
-#: common.opt:1118
+#: common.opt:1122
 msgid "Do not put uninitialized globals in the common section."
 msgstr ""
 
-#: common.opt:1126
+#: common.opt:1130
 msgid "-fcompare-debug[=<opts>]\tCompile with and without e.g. -gtoggle, and compare the final-insns dump."
 msgstr ""
 
-#: common.opt:1130
+#: common.opt:1134
 msgid "Run only the second compilation of -fcompare-debug."
 msgstr ""
 
-#: common.opt:1134
+#: common.opt:1138
 msgid "Perform comparison elimination after register allocation has finished."
 msgstr ""
 
-#: common.opt:1138
+#: common.opt:1142
 msgid "Do not perform optimizations increasing noticeably stack usage."
 msgstr ""
 
-#: common.opt:1142
+#: common.opt:1146
 msgid "Perform a register copy-propagation optimization pass."
 msgstr ""
 
-#: common.opt:1146
+#: common.opt:1150
 msgid "Perform cross-jumping optimization."
 msgstr ""
 
-#: common.opt:1150
+#: common.opt:1154
 msgid "When running CSE, follow jumps to their targets."
 msgstr ""
 
-#: common.opt:1158
+#: common.opt:1162
 msgid "Omit range reduction step when performing complex division."
 msgstr ""
 
-#: common.opt:1162
+#: common.opt:1166
 msgid "Complex multiplication and division follow Fortran rules."
 msgstr ""
 
-#: common.opt:1166
+#: common.opt:1170
 msgid "Place data items into their own section."
 msgstr ""
 
-#: common.opt:1170
+#: common.opt:1174
 msgid "List all available debugging counters with their limits and counts."
 msgstr ""
 
-#: common.opt:1174
+#: common.opt:1178
 msgid "-fdbg-cnt=<counter>:<limit>[,<counter>:<limit>,...]\tSet the debug counter limit."
 msgstr ""
 
-#: common.opt:1178
+#: common.opt:1182
 msgid "-fdebug-prefix-map=<old>=<new> Map one directory name to another in debug information."
 msgstr ""
 
-#: common.opt:1182
+#: common.opt:1186
 msgid "-ffile-prefix-map=<old>=<new> Map one directory name to another in compilation result."
 msgstr ""
 
-#: common.opt:1186
+#: common.opt:1190
 msgid "Output .debug_types section when using DWARF v4 debuginfo."
 msgstr ""
 
-#: common.opt:1192
+#: common.opt:1196
 msgid "Defer popping functions args from stack until later."
 msgstr ""
 
-#: common.opt:1196
+#: common.opt:1200
 msgid "Attempt to fill delay slots of branch instructions."
 msgstr ""
 
-#: common.opt:1200
+#: common.opt:1204
 msgid "Delete dead instructions that may throw exceptions."
 msgstr ""
 
-#: common.opt:1204
+#: common.opt:1208
 msgid "Delete useless null pointer checks."
 msgstr ""
 
-#: common.opt:1208
+#: common.opt:1212
 msgid "Stream extra data to support more aggressive devirtualization in LTO local transformation mode."
 msgstr ""
 
-#: common.opt:1212
+#: common.opt:1216
 msgid "Perform speculative devirtualization."
 msgstr ""
 
-#: common.opt:1216
+#: common.opt:1220
 msgid "Try to convert virtual calls to direct ones."
 msgstr ""
 
-#: common.opt:1220
+#: common.opt:1224
 msgid "-fdiagnostics-show-location=[once|every-line]\tHow often to emit source location at the beginning of line-wrapped diagnostics."
 msgstr ""
 
-#: common.opt:1237
+#: common.opt:1241
 msgid "Show the source line with a caret indicating the column."
 msgstr ""
 
-#: common.opt:1245
+#: common.opt:1249
 msgid "-fdiagnostics-color=[never|always|auto]\tColorize diagnostics."
 msgstr ""
 
-#: common.opt:1265
+#: common.opt:1269
 msgid "Print fix-it hints in machine-readable form."
 msgstr ""
 
-#: common.opt:1269
+#: common.opt:1273
 msgid "Print fix-it hints to stderr in unified diff format."
 msgstr ""
 
-#: common.opt:1273
+#: common.opt:1277
 msgid "Amend appropriate diagnostic messages with the command line option that controls them."
 msgstr ""
 
-#: common.opt:1277
+#: common.opt:1281
 msgid "-fdisable-[tree|rtl|ipa]-<pass>=range1+range2 disables an optimization pass."
 msgstr ""
 
-#: common.opt:1281
+#: common.opt:1285
 msgid "-fenable-[tree|rtl|ipa]-<pass>=range1+range2 enables an optimization pass."
 msgstr ""
 
-#: common.opt:1285
+#: common.opt:1289
 msgid "-fdump-<type>\tDump various compiler internals to a file."
 msgstr ""
 
-#: common.opt:1292
+#: common.opt:1296
 msgid "-fdump-final-insns=filename\tDump to filename the insns at the end of translation."
 msgstr ""
 
-#: common.opt:1296
+#: common.opt:1300
 msgid "-fdump-go-spec=filename\tWrite all declarations to file as Go code."
 msgstr ""
 
-#: common.opt:1300
+#: common.opt:1304
 msgid "Suppress output of addresses in debugging dumps."
 msgstr ""
 
-#: common.opt:1304
+#: common.opt:1308
 msgid "Collect and dump debug information into temporary file if ICE in C/C++ compiler occurred."
 msgstr ""
 
-#: common.opt:1309
+#: common.opt:1313
 msgid "Dump detailed information on GCC's internal representation of source code locations."
 msgstr ""
 
-#: common.opt:1313
+#: common.opt:1317
 msgid "Dump optimization passes."
 msgstr ""
 
-#: common.opt:1317
+#: common.opt:1321
 msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps."
 msgstr ""
 
-#: common.opt:1321
+#: common.opt:1325
 msgid "Suppress output of previous and next insn numbers in debugging dumps."
 msgstr ""
 
-#: common.opt:1325
+#: common.opt:1329
 msgid "Enable CFI tables via GAS assembler directives."
 msgstr ""
 
-#: common.opt:1329
+#: common.opt:1333
 msgid "Perform early inlining."
 msgstr ""
 
-#: common.opt:1337
+#: common.opt:1341
 msgid "Perform interprocedural reduction of aggregates."
 msgstr ""
 
-#: common.opt:1341
+#: common.opt:1345
 msgid "Perform unused symbol elimination in debug info."
 msgstr ""
 
-#: common.opt:1345
+#: common.opt:1349
 msgid "Perform unused type elimination in debug info."
 msgstr ""
 
-#: common.opt:1349
+#: common.opt:1353
 msgid "Do not suppress C++ class debug information."
 msgstr ""
 
-#: common.opt:1353
+#: common.opt:1357
 msgid "Enable exception handling."
 msgstr ""
 
-#: common.opt:1357
+#: common.opt:1361
 msgid "Perform a number of minor, expensive optimizations."
 msgstr ""
 
-#: common.opt:1361
+#: common.opt:1365
 msgid "-fexcess-precision=[fast|standard]\tSpecify handling of excess floating-point precision."
 msgstr ""
 
-#: common.opt:1364
+#: common.opt:1368
 #, c-format
 msgid "unknown excess precision style %qs"
 msgstr ""
 
-#: common.opt:1376
+#: common.opt:1380
 msgid "-fpermitted-flt-eval-methods=[c11|ts-18661]\tSpecify which values of FLT_EVAL_METHOD are permitted."
 msgstr ""
 
-#: common.opt:1379
+#: common.opt:1383
 #, c-format
 msgid "unknown specification for the set of FLT_EVAL_METHOD values to permit %qs"
 msgstr ""
 
-#: common.opt:1392
+#: common.opt:1396
 msgid "Output lto objects containing both the intermediate language and binary output."
 msgstr ""
 
-#: common.opt:1396
+#: common.opt:1400
 msgid "Assume no NaNs or infinities are generated."
 msgstr ""
 
-#: common.opt:1400
+#: common.opt:1404
 msgid "-ffixed-<register>\tMark <register> as being unavailable to the compiler."
 msgstr ""
 
-#: common.opt:1404
+#: common.opt:1408
 msgid "Don't allocate floats and doubles in extended-precision registers."
 msgstr ""
 
-#: common.opt:1412
+#: common.opt:1416
 msgid "Perform a forward propagation pass on RTL."
 msgstr ""
 
-#: common.opt:1416
+#: common.opt:1420
 msgid "-ffp-contract=[off|on|fast]\tPerform floating-point expression contraction."
 msgstr ""
 
-#: common.opt:1419
+#: common.opt:1423
 #, c-format
 msgid "unknown floating point contraction style %qs"
 msgstr ""
 
-#: common.opt:1433
+#: common.opt:1437
 msgid "Allow built-in functions ceil, floor, round, trunc to raise \"inexact\" exceptions."
 msgstr ""
 
-#: common.opt:1440
+#: common.opt:1444
 msgid "Allow function addresses to be held in registers."
 msgstr ""
 
-#: common.opt:1444
+#: common.opt:1448
 msgid "Place each function into its own section."
 msgstr ""
 
-#: common.opt:1448
+#: common.opt:1452
 msgid "Perform global common subexpression elimination."
 msgstr ""
 
-#: common.opt:1452
+#: common.opt:1456
 msgid "Perform enhanced load motion during global common subexpression elimination."
 msgstr ""
 
-#: common.opt:1456
+#: common.opt:1460
 msgid "Perform store motion after global common subexpression elimination."
 msgstr ""
 
-#: common.opt:1460
+#: common.opt:1464
 msgid "Perform redundant load after store elimination in global common subexpression elimination."
 msgstr ""
 
-#: common.opt:1465
+#: common.opt:1469
 msgid "Perform global common subexpression elimination after register allocation has finished."
 msgstr ""
 
-#: common.opt:1482
+#: common.opt:1486
 msgid "-fgnat-encodings=[all|gdb|minimal]\tSelect the balance between GNAT encodings and standard DWARF emitted in the debug information"
 msgstr ""
 
-#: common.opt:1487
+#: common.opt:1491
 msgid "Enable in and out of Graphite representation."
 msgstr ""
 
-#: common.opt:1491
+#: common.opt:1495
 msgid "Enable Graphite Identity transformation."
 msgstr ""
 
-#: common.opt:1495
+#: common.opt:1499
 msgid "Enable hoisting adjacent loads to encourage generating conditional move instructions."
 msgstr ""
 
-#: common.opt:1504
+#: common.opt:1508
 msgid "Mark all loops as parallel."
 msgstr ""
 
-#: common.opt:1508 common.opt:1516 common.opt:2587
+#: common.opt:1512 common.opt:1520 common.opt:2591
 msgid "Enable loop nest transforms.  Same as -floop-nest-optimize."
 msgstr ""
 
-#: common.opt:1512
+#: common.opt:1516
 msgid "Enable loop interchange on trees."
 msgstr ""
 
-#: common.opt:1520
+#: common.opt:1524
 msgid "Perform unroll-and-jam on loops."
 msgstr ""
 
-#: common.opt:1524
+#: common.opt:1528
 msgid "Enable support for GNU transactional memory."
 msgstr ""
 
-#: common.opt:1528
+#: common.opt:1532
 msgid "Use STB_GNU_UNIQUE if supported by the assembler."
 msgstr ""
 
-#: common.opt:1536
+#: common.opt:1540
 msgid "Enable the loop nest optimizer."
 msgstr ""
 
-#: common.opt:1540
+#: common.opt:1544
 msgid "Force bitfield accesses to match their type width."
 msgstr ""
 
-#: common.opt:1544
+#: common.opt:1548
 msgid "Merge adjacent stores."
 msgstr ""
 
-#: common.opt:1548
+#: common.opt:1552
 msgid "Enable guessing of branch probabilities."
 msgstr ""
 
-#: common.opt:1556
+#: common.opt:1560
 msgid "Process #ident directives."
 msgstr ""
 
-#: common.opt:1560
+#: common.opt:1564
 msgid "Perform conversion of conditional jumps to branchless equivalents."
 msgstr ""
 
-#: common.opt:1564
+#: common.opt:1568
 msgid "Perform conversion of conditional jumps to conditional execution."
 msgstr ""
 
-#: common.opt:1568
+#: common.opt:1572
 msgid "-fstack-reuse=[all|named_vars|none]\tSet stack reuse level for local variables."
 msgstr ""
 
-#: common.opt:1571
+#: common.opt:1575
 #, c-format
 msgid "unknown Stack Reuse Level %qs"
 msgstr ""
 
-#: common.opt:1584
+#: common.opt:1588
 msgid "Convert conditional jumps in innermost loops to branchless equivalents."
 msgstr ""
 
-#: common.opt:1596
+#: common.opt:1600
 msgid "Do not generate .size directives."
 msgstr ""
 
-#: common.opt:1600
+#: common.opt:1604
 msgid "Perform indirect inlining."
 msgstr ""
 
-#: common.opt:1606
+#: common.opt:1610
 msgid "Enable inlining of function declared \"inline\", disabling disables all inlining."
 msgstr ""
 
-#: common.opt:1610
+#: common.opt:1614
 msgid "Integrate functions into their callers when code size is known not to grow."
 msgstr ""
 
-#: common.opt:1614
+#: common.opt:1618
 msgid "Integrate functions not declared \"inline\" into their callers when profitable."
 msgstr ""
 
-#: common.opt:1618
+#: common.opt:1622
 msgid "Integrate functions only required by their single caller."
 msgstr ""
 
-#: common.opt:1625
+#: common.opt:1629
 msgid "-finline-limit=<number>\tLimit the size of inlined functions to <number>."
 msgstr ""
 
-#: common.opt:1629
+#: common.opt:1633
 msgid "Inline __atomic operations when a lock free instruction sequence is available."
 msgstr ""
 
-#: common.opt:1636
+#: common.opt:1640
 msgid "-fcf-protection=[full|branch|return|none]\tInstrument functions with checks to verify jump/call/return control-flow transfer instructions have valid targets."
 msgstr ""
 
-#: common.opt:1640
+#: common.opt:1644
 #, c-format
 msgid "unknown Control-Flow Protection Level %qs"
 msgstr ""
 
-#: common.opt:1656
+#: common.opt:1660
 msgid "Instrument function entry and exit with profiling calls."
 msgstr ""
 
-#: common.opt:1660
+#: common.opt:1664
 msgid "-finstrument-functions-exclude-function-list=name,...  Do not instrument listed functions."
 msgstr ""
 
-#: common.opt:1664
+#: common.opt:1668
 msgid "-finstrument-functions-exclude-file-list=filename,...  Do not instrument functions listed in files."
 msgstr ""
 
-#: common.opt:1668
+#: common.opt:1672
 msgid "Perform interprocedural constant propagation."
 msgstr ""
 
-#: common.opt:1672
+#: common.opt:1676
 msgid "Perform cloning to make Interprocedural constant propagation stronger."
 msgstr ""
 
-#: common.opt:1680
+#: common.opt:1684
 msgid "Perform interprocedural bitwise constant propagation."
 msgstr ""
 
-#: common.opt:1684
+#: common.opt:1688
 msgid "Perform interprocedural profile propagation."
 msgstr ""
 
-#: common.opt:1688
+#: common.opt:1692
 msgid "Perform interprocedural points-to analysis."
 msgstr ""
 
-#: common.opt:1692
+#: common.opt:1696
 msgid "Discover pure and const functions."
 msgstr ""
 
-#: common.opt:1696
+#: common.opt:1700
 msgid "Perform Identical Code Folding for functions and read-only variables."
 msgstr ""
 
-#: common.opt:1700
+#: common.opt:1704
 msgid "Perform Identical Code Folding for functions."
 msgstr ""
 
-#: common.opt:1704
+#: common.opt:1708
 msgid "Perform Identical Code Folding for variables."
 msgstr ""
 
-#: common.opt:1708
+#: common.opt:1712
 msgid "Discover readonly and non addressable static variables."
 msgstr ""
 
-#: common.opt:1720
+#: common.opt:1724
 msgid "Perform IPA Value Range Propagation."
 msgstr ""
 
-#: common.opt:1724
+#: common.opt:1728
 msgid "-fira-algorithm=[CB|priority]\tSet the used IRA algorithm."
 msgstr ""
 
-#: common.opt:1727
+#: common.opt:1731
 #, c-format
 msgid "unknown IRA algorithm %qs"
 msgstr ""
 
-#: common.opt:1737
+#: common.opt:1741
 msgid "-fira-region=[one|all|mixed]\tSet regions for IRA."
 msgstr ""
 
-#: common.opt:1740
+#: common.opt:1744
 #, c-format
 msgid "unknown IRA region %qs"
 msgstr ""
 
-#: common.opt:1753
+#: common.opt:1757
 msgid "Use IRA based register pressure calculation in RTL hoist optimizations."
 msgstr ""
 
-#: common.opt:1758
+#: common.opt:1762
 msgid "Use IRA based register pressure calculation in RTL loop optimizations."
 msgstr ""
 
-#: common.opt:1763
+#: common.opt:1767
 msgid "Share slots for saving different hard registers."
 msgstr ""
 
-#: common.opt:1767
+#: common.opt:1771
 msgid "Share stack slots for spilled pseudo-registers."
 msgstr ""
 
-#: common.opt:1771
+#: common.opt:1775
 msgid "-fira-verbose=<number>\tControl IRA's level of diagnostic messages."
 msgstr ""
 
-#: common.opt:1775
+#: common.opt:1779
 msgid "Optimize induction variables on trees."
 msgstr ""
 
-#: common.opt:1779
+#: common.opt:1783
 msgid "Use jump tables for sufficiently large switch statements."
 msgstr ""
 
-#: common.opt:1783
+#: common.opt:1787
 msgid "Generate code for functions even if they are fully inlined."
 msgstr ""
 
-#: common.opt:1787
+#: common.opt:1791
 msgid "Generate code for static functions even if they are never called."
 msgstr ""
 
-#: common.opt:1791
+#: common.opt:1795
 msgid "Emit static const variables even if they are not used."
 msgstr ""
 
-#: common.opt:1795
+#: common.opt:1799
 msgid "Give external symbols a leading underscore."
 msgstr ""
 
-#: common.opt:1803
+#: common.opt:1807
 msgid "Do CFG-sensitive rematerialization in LRA."
 msgstr ""
 
-#: common.opt:1807
+#: common.opt:1811
 msgid "Enable link-time optimization."
 msgstr ""
 
-#: common.opt:1811
+#: common.opt:1815
 msgid "Link-time optimization with number of parallel jobs or jobserver."
 msgstr ""
 
-#: common.opt:1814
+#: common.opt:1818
 #, c-format
 msgid "unknown LTO partitioning model %qs"
 msgstr ""
 
-#: common.opt:1833
+#: common.opt:1837
 msgid "Specify the algorithm to partition symbols and vars at linktime."
 msgstr ""
 
-#: common.opt:1838
+#: common.opt:1842
 msgid "-flto-compression-level=<number>\tUse zlib compression level <number> for IL."
 msgstr ""
 
-#: common.opt:1842
+#: common.opt:1846
 msgid "Merge C++ types using One Definition Rule."
 msgstr ""
 
-#: common.opt:1846
+#: common.opt:1850
 msgid "Report various link-time optimization statistics."
 msgstr ""
 
-#: common.opt:1850
+#: common.opt:1854
 msgid "Report various link-time optimization statistics for WPA only."
 msgstr ""
 
-#: common.opt:1854
+#: common.opt:1858
 msgid "Set errno after built-in math functions."
 msgstr ""
 
-#: common.opt:1858
+#: common.opt:1862
 msgid "-fmax-errors=<number>\tMaximum number of errors to report."
 msgstr ""
 
-#: common.opt:1862
+#: common.opt:1866
 msgid "Report on permanent memory allocation."
 msgstr ""
 
-#: common.opt:1866
+#: common.opt:1870
 msgid "Report on permanent memory allocation in WPA only."
 msgstr ""
 
-#: common.opt:1873
+#: common.opt:1877
 msgid "Attempt to merge identical constants and constant variables."
 msgstr ""
 
-#: common.opt:1877
+#: common.opt:1881
 msgid "Attempt to merge identical constants across compilation units."
 msgstr ""
 
-#: common.opt:1881
+#: common.opt:1885
 msgid "Attempt to merge identical debug strings across compilation units."
 msgstr ""
 
-#: common.opt:1885
+#: common.opt:1889
 msgid "-fmessage-length=<number>\tLimit diagnostics to <number> characters per line.  0 suppresses line-wrapping."
 msgstr ""
 
-#: common.opt:1889
+#: common.opt:1893
 msgid "Perform SMS based modulo scheduling before the first scheduling pass."
 msgstr ""
 
-#: common.opt:1893
+#: common.opt:1897
 msgid "Perform SMS based modulo scheduling with register moves allowed."
 msgstr ""
 
-#: common.opt:1897
+#: common.opt:1901
 msgid "Move loop invariant computations out of loops."
 msgstr ""
 
-#: common.opt:1901
+#: common.opt:1905
 msgid "Use the RTL dead code elimination pass."
 msgstr ""
 
-#: common.opt:1905
+#: common.opt:1909
 msgid "Use the RTL dead store elimination pass."
 msgstr ""
 
-#: common.opt:1909
+#: common.opt:1913
 msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling."
 msgstr ""
 
-#: common.opt:1913
+#: common.opt:1917
 msgid "Support synchronous non-call exceptions."
 msgstr ""
 
-#: common.opt:1916
+#: common.opt:1920
 #, c-format
 msgid "options or targets missing after %qs"
 msgstr ""
 
-#: common.opt:1917
+#: common.opt:1921
 msgid "-foffload=<targets>=<options>  Specify offloading targets and options for them."
 msgstr ""
 
-#: common.opt:1921
+#: common.opt:1925
 msgid "-foffload-abi=[lp64|ilp32]     Set the ABI to use in an offload compiler."
 msgstr ""
 
-#: common.opt:1924
+#: common.opt:1928
 #, c-format
 msgid "unknown offload ABI %qs"
 msgstr ""
 
-#: common.opt:1934
+#: common.opt:1938
 msgid "When possible do not generate stack frames."
 msgstr ""
 
-#: common.opt:1938
+#: common.opt:1942
 msgid "Enable all optimization info dumps on stderr."
 msgstr ""
 
-#: common.opt:1942
+#: common.opt:1946
 msgid "-fopt-info[-<type>=filename]\tDump compiler optimization details."
 msgstr ""
 
-#: common.opt:1950
+#: common.opt:1954
 msgid "Optimize sibling and tail recursive calls."
 msgstr ""
 
-#: common.opt:1954
+#: common.opt:1958
 msgid "Perform partial inlining."
 msgstr ""
 
-#: common.opt:1958 common.opt:1962
+#: common.opt:1962 common.opt:1966
 msgid "Report on memory allocation before interprocedural optimization."
 msgstr ""
 
-#: common.opt:1966
+#: common.opt:1970
 msgid "Pack structure members together without holes."
 msgstr ""
 
-#: common.opt:1970
+#: common.opt:1974
 msgid "-fpack-struct=<number>\tSet initial maximum structure member alignment."
 msgstr ""
 
-#: common.opt:1974
+#: common.opt:1978
 msgid "Return small aggregates in memory, not registers."
 msgstr ""
 
-#: common.opt:1978
+#: common.opt:1982
 msgid "Perform loop peeling."
 msgstr ""
 
-#: common.opt:1982
+#: common.opt:1986
 msgid "Enable machine specific peephole optimizations."
 msgstr ""
 
-#: common.opt:1986
+#: common.opt:1990
 msgid "Enable an RTL peephole pass before sched2."
 msgstr ""
 
-#: common.opt:1990
+#: common.opt:1994
 msgid "Generate position-independent code if possible (large mode)."
 msgstr ""
 
-#: common.opt:1994
+#: common.opt:1998
 msgid "Generate position-independent code for executables if possible (large mode)."
 msgstr ""
 
-#: common.opt:1998
+#: common.opt:2002
 msgid "Generate position-independent code if possible (small mode)."
 msgstr ""
 
-#: common.opt:2002
+#: common.opt:2006
 msgid "Generate position-independent code for executables if possible (small mode)."
 msgstr ""
 
-#: common.opt:2006
+#: common.opt:2010
 msgid "Use PLT for PIC calls (-fno-plt: load the address from GOT at call site)."
 msgstr ""
 
-#: common.opt:2010
+#: common.opt:2014
 msgid "Specify a plugin to load."
 msgstr ""
 
-#: common.opt:2014
+#: common.opt:2018
 msgid "-fplugin-arg-<name>-<key>[=<value>]\tSpecify argument <key>=<value> for plugin <name>."
 msgstr ""
 
-#: common.opt:2018
+#: common.opt:2022
 msgid "Run predictive commoning optimization."
 msgstr ""
 
-#: common.opt:2022
+#: common.opt:2026
 msgid "Generate prefetch instructions, if available, for arrays in loops."
 msgstr ""
 
-#: common.opt:2026
+#: common.opt:2030
 msgid "Enable basic program profiling code."
 msgstr ""
 
-#: common.opt:2030
+#: common.opt:2034
 msgid "Generate absolute source path names for gcov."
 msgstr ""
 
-#: common.opt:2034
+#: common.opt:2038
 msgid "Insert arc-based program profiling code."
 msgstr ""
 
-#: common.opt:2038
+#: common.opt:2042
 msgid "Set the top-level directory for storing the profile data. The default is 'pwd'."
 msgstr ""
 
-#: common.opt:2043
+#: common.opt:2047
 msgid "Enable correction of flow inconsistent profile data input."
 msgstr ""
 
-#: common.opt:2047
+#: common.opt:2051
 msgid "-fprofile-update=[single|atomic|prefer-atomic]\tSet the profile update method."
 msgstr ""
 
-#: common.opt:2050
+#: common.opt:2054
 #, c-format
 msgid "unknown profile update method %qs"
 msgstr ""
 
-#: common.opt:2063
+#: common.opt:2067
 msgid "Enable common options for generating profile info for profile feedback directed optimizations."
 msgstr ""
 
-#: common.opt:2067
+#: common.opt:2071
 msgid "Enable common options for generating profile info for profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr ""
 
-#: common.opt:2071
+#: common.opt:2075
 msgid "Enable common options for performing profile feedback directed optimizations."
 msgstr ""
 
-#: common.opt:2075
+#: common.opt:2079
 msgid "Enable common options for performing profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr ""
 
-#: common.opt:2079
+#: common.opt:2083
 msgid "Insert code to profile values of expressions."
 msgstr ""
 
-#: common.opt:2083
+#: common.opt:2087
 msgid "Report on consistency of profile."
 msgstr ""
 
-#: common.opt:2087
+#: common.opt:2091
 msgid "Enable function reordering that improves code placement."
 msgstr ""
 
-#: common.opt:2091
+#: common.opt:2095
 msgid "Insert NOP instructions at each function entry."
 msgstr ""
 
-#: common.opt:2098
+#: common.opt:2102
 msgid "-frandom-seed=<string>\tMake compile reproducible using <string>."
 msgstr ""
 
-#: common.opt:2108
+#: common.opt:2112
 msgid "Record gcc command line switches in the object file."
 msgstr ""
 
-#: common.opt:2112
+#: common.opt:2116
 msgid "Return small aggregates in registers."
 msgstr ""
 
-#: common.opt:2120
+#: common.opt:2124
 msgid "Tell DSE that the storage for a C++ object is dead when the constructor starts and when the destructor finishes."
 msgstr ""
 
-#: common.opt:2128
+#: common.opt:2132
 msgid "Relief of register pressure through live range shrinkage."
 msgstr ""
 
-#: common.opt:2132
+#: common.opt:2136
 msgid "Perform a register renaming optimization pass."
 msgstr ""
 
-#: common.opt:2136
+#: common.opt:2140
 msgid "Perform a target dependent instruction fusion optimization pass."
 msgstr ""
 
-#: common.opt:2140
+#: common.opt:2144
 msgid "Reorder basic blocks to improve code placement."
 msgstr ""
 
-#: common.opt:2144
+#: common.opt:2148
 msgid "-freorder-blocks-algorithm=[simple|stc]\tSet the used basic block reordering algorithm."
 msgstr ""
 
-#: common.opt:2147
+#: common.opt:2151
 #, c-format
 msgid "unknown basic block reordering algorithm %qs"
 msgstr ""
 
-#: common.opt:2157
+#: common.opt:2161
 msgid "Reorder basic blocks and partition into hot and cold sections."
 msgstr ""
 
-#: common.opt:2161
+#: common.opt:2165
 msgid "Reorder functions to improve code placement."
 msgstr ""
 
-#: common.opt:2165
+#: common.opt:2169
 msgid "Add a common subexpression elimination pass after loop optimizations."
 msgstr ""
 
-#: common.opt:2173
+#: common.opt:2177
 msgid "Disable optimizations that assume default FP rounding behavior."
 msgstr ""
 
-#: common.opt:2177
+#: common.opt:2181
 msgid "Enable scheduling across basic blocks."
 msgstr ""
 
-#: common.opt:2181
+#: common.opt:2185
 msgid "Enable register pressure sensitive insn scheduling."
 msgstr ""
 
-#: common.opt:2185
+#: common.opt:2189
 msgid "Allow speculative motion of non-loads."
 msgstr ""
 
-#: common.opt:2189
+#: common.opt:2193
 msgid "Allow speculative motion of some loads."
 msgstr ""
 
-#: common.opt:2193
+#: common.opt:2197
 msgid "Allow speculative motion of more loads."
 msgstr ""
 
-#: common.opt:2197
+#: common.opt:2201
 msgid "-fsched-verbose=<number>\tSet the verbosity level of the scheduler."
 msgstr ""
 
-#: common.opt:2201
+#: common.opt:2205
 msgid "If scheduling post reload, do superblock scheduling."
 msgstr ""
 
-#: common.opt:2209
+#: common.opt:2213
 msgid "Reschedule instructions before register allocation."
 msgstr ""
 
-#: common.opt:2213
+#: common.opt:2217
 msgid "Reschedule instructions after register allocation."
 msgstr ""
 
-#: common.opt:2220
+#: common.opt:2224
 msgid "Schedule instructions using selective scheduling algorithm."
 msgstr ""
 
-#: common.opt:2224
+#: common.opt:2228
 msgid "Run selective scheduling after reload."
 msgstr ""
 
-#: common.opt:2228
+#: common.opt:2232
 msgid "Run self-tests, using the given path to locate test files."
 msgstr ""
 
-#: common.opt:2232
+#: common.opt:2236
 msgid "Perform software pipelining of inner loops during selective scheduling."
 msgstr ""
 
-#: common.opt:2236
+#: common.opt:2240
 msgid "Perform software pipelining of outer loops during selective scheduling."
 msgstr ""
 
-#: common.opt:2240
+#: common.opt:2244
 msgid "Reschedule pipelined regions without pipelining."
 msgstr ""
 
-#: common.opt:2244
+#: common.opt:2248
 msgid "Allow interposing function (or variables) by ones with different semantics (or initializer) respectively by dynamic linker."
 msgstr ""
 
-#: common.opt:2250
+#: common.opt:2254
 msgid "Allow premature scheduling of queued insns."
 msgstr ""
 
-#: common.opt:2254
+#: common.opt:2258
 msgid "-fsched-stalled-insns=<number>\tSet number of queued insns that can be prematurely scheduled."
 msgstr ""
 
-#: common.opt:2262
+#: common.opt:2266
 msgid "Set dependence distance checking in premature scheduling of queued insns."
 msgstr ""
 
-#: common.opt:2266
+#: common.opt:2270
 msgid "-fsched-stalled-insns-dep=<number>\tSet dependence distance checking in premature scheduling of queued insns."
 msgstr ""
 
-#: common.opt:2270
+#: common.opt:2274
 msgid "Enable the group heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2274
+#: common.opt:2278
 msgid "Enable the critical path heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2278
+#: common.opt:2282
 msgid "Enable the speculative instruction heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2282
+#: common.opt:2286
 msgid "Enable the rank heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2286
+#: common.opt:2290
 msgid "Enable the last instruction heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2290
+#: common.opt:2294
 msgid "Enable the dependent count heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2294
+#: common.opt:2298
 msgid "Access data in the same section from shared anchor points."
 msgstr ""
 
-#: common.opt:2306
+#: common.opt:2310
 msgid "Turn on Redundant Extensions Elimination pass."
 msgstr ""
 
-#: common.opt:2310
+#: common.opt:2314
 msgid "Show column numbers in diagnostics, when available.  Default on."
 msgstr ""
 
-#: common.opt:2314
+#: common.opt:2318
 msgid "Emit function prologues only before parts of the function that need it, rather than at the top of the function."
 msgstr ""
 
-#: common.opt:2319
+#: common.opt:2323
 msgid "Shrink-wrap parts of the prologue and epilogue separately."
 msgstr ""
 
-#: common.opt:2323
+#: common.opt:2327
 msgid "Disable optimizations observable by IEEE signaling NaNs."
 msgstr ""
 
-#: common.opt:2327
+#: common.opt:2331
 msgid "Disable floating point optimizations that ignore the IEEE signedness of zero."
 msgstr ""
 
-#: common.opt:2331
+#: common.opt:2335
 msgid "Convert floating point constants to single precision constants."
 msgstr ""
 
-#: common.opt:2335
+#: common.opt:2339
 msgid "Split lifetimes of induction variables when loops are unrolled."
 msgstr ""
 
-#: common.opt:2339
+#: common.opt:2343
 msgid "Generate discontiguous stack frames."
 msgstr ""
 
-#: common.opt:2343
+#: common.opt:2347
 msgid "Split wide types into independent registers."
 msgstr ""
 
-#: common.opt:2347
+#: common.opt:2351
 msgid "Enable backward propagation of use properties at the SSA level."
 msgstr ""
 
-#: common.opt:2351
+#: common.opt:2355
 msgid "Optimize conditional patterns using SSA PHI nodes."
 msgstr ""
 
-#: common.opt:2355
+#: common.opt:2359
 msgid "Optimize amount of stdarg registers saved to stack at start of function."
 msgstr ""
 
-#: common.opt:2359
+#: common.opt:2363
 msgid "Apply variable expansion when loops are unrolled."
 msgstr ""
 
-#: common.opt:2363
+#: common.opt:2367
 msgid "-fstack-check=[no|generic|specific]\tInsert stack checking code into the program."
 msgstr ""
 
-#: common.opt:2367
+#: common.opt:2371
 msgid "Insert stack checking code into the program.  Same as -fstack-check=specific."
 msgstr ""
 
-#: common.opt:2371
+#: common.opt:2375
 msgid "Insert code to probe each page of stack space as it is allocated to protect from stack-clash style attacks."
 msgstr ""
 
-#: common.opt:2379
+#: common.opt:2383
 msgid "-fstack-limit-register=<register>\tTrap if the stack goes past <register>."
 msgstr ""
 
-#: common.opt:2383
+#: common.opt:2387
 msgid "-fstack-limit-symbol=<name>\tTrap if the stack goes past symbol <name>."
 msgstr ""
 
-#: common.opt:2387
+#: common.opt:2391
 msgid "Use propolice as a stack protection method."
 msgstr ""
 
-#: common.opt:2391
+#: common.opt:2395
 msgid "Use a stack protection method for every function."
 msgstr ""
 
-#: common.opt:2395
+#: common.opt:2399
 msgid "Use a smart stack protection method for certain functions."
 msgstr ""
 
-#: common.opt:2399
+#: common.opt:2403
 msgid "Use stack protection method only for functions with the stack_protect attribute."
 msgstr ""
 
-#: common.opt:2403
+#: common.opt:2407
 msgid "Output stack usage information on a per-function basis."
 msgstr ""
 
-#: common.opt:2415
+#: common.opt:2419
 msgid "Assume strict aliasing rules apply."
 msgstr ""
 
-#: common.opt:2419
+#: common.opt:2423
 msgid "Treat signed overflow as undefined.  Negated as -fwrapv -fwrapv-pointer."
 msgstr ""
 
-#: common.opt:2423
+#: common.opt:2427
 msgid "Implement __atomic operations via libcalls to legacy __sync functions."
 msgstr ""
 
-#: common.opt:2427
+#: common.opt:2431
 msgid "Check for syntax errors, then stop."
 msgstr ""
 
-#: common.opt:2431
+#: common.opt:2435
 msgid "Create data files needed by \"gcov\"."
 msgstr ""
 
-#: common.opt:2435
+#: common.opt:2439
 msgid "Perform jump threading optimizations."
 msgstr ""
 
-#: common.opt:2439
+#: common.opt:2443
 msgid "Report the time taken by each compiler pass."
 msgstr ""
 
-#: common.opt:2443
+#: common.opt:2447
 msgid "Record times taken by sub-phases separately."
 msgstr ""
 
-#: common.opt:2447
+#: common.opt:2451
 msgid "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tSet the default thread-local storage code generation model."
 msgstr ""
 
-#: common.opt:2450
+#: common.opt:2454
 #, c-format
 msgid "unknown TLS model %qs"
 msgstr ""
 
-#: common.opt:2466
+#: common.opt:2470
 msgid "Reorder top level functions, variables, and asms."
 msgstr ""
 
-#: common.opt:2470
+#: common.opt:2474
 msgid "Perform superblock formation via tail duplication."
 msgstr ""
 
-#: common.opt:2474
+#: common.opt:2478
 msgid "For targets that normally need trampolines for nested functions, always generate them instead of using descriptors."
 msgstr ""
 
-#: common.opt:2482
+#: common.opt:2486
 msgid "Assume floating-point operations can trap."
 msgstr ""
 
-#: common.opt:2486
+#: common.opt:2490
 msgid "Trap for signed overflow in addition, subtraction and multiplication."
 msgstr ""
 
-#: common.opt:2490
+#: common.opt:2494
 msgid "Enable SSA-CCP optimization on trees."
 msgstr ""
 
-#: common.opt:2494
+#: common.opt:2498
 msgid "Enable SSA-BIT-CCP optimization on trees."
 msgstr ""
 
-#: common.opt:2502
+#: common.opt:2506
 msgid "Enable loop header copying on trees."
 msgstr ""
 
-#: common.opt:2510
+#: common.opt:2514
 msgid "Enable SSA coalescing of user variables."
 msgstr ""
 
-#: common.opt:2518
+#: common.opt:2522
 msgid "Enable copy propagation on trees."
 msgstr ""
 
-#: common.opt:2526
+#: common.opt:2530
 msgid "Transform condition stores into unconditional ones."
 msgstr ""
 
-#: common.opt:2530
+#: common.opt:2534
 msgid "Perform conversions of switch initializations."
 msgstr ""
 
-#: common.opt:2534
+#: common.opt:2538
 msgid "Enable SSA dead code elimination optimization on trees."
 msgstr ""
 
-#: common.opt:2538
+#: common.opt:2542
 msgid "Enable dominator optimizations."
 msgstr ""
 
-#: common.opt:2542
+#: common.opt:2546
 msgid "Enable tail merging on trees."
 msgstr ""
 
-#: common.opt:2546
+#: common.opt:2550
 msgid "Enable dead store elimination."
 msgstr ""
 
-#: common.opt:2550
+#: common.opt:2554
 msgid "Enable forward propagation on trees."
 msgstr ""
 
-#: common.opt:2554
+#: common.opt:2558
 msgid "Enable Full Redundancy Elimination (FRE) on trees."
 msgstr ""
 
-#: common.opt:2558
+#: common.opt:2562
 msgid "Enable string length optimizations on trees."
 msgstr ""
 
-#: common.opt:2562
+#: common.opt:2566
 msgid "Detect paths that trigger erroneous or undefined behavior due to dereferencing a null pointer.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
-#: common.opt:2568
+#: common.opt:2572
 msgid "Detect paths that trigger erroneous or undefined behavior due to a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
-#: common.opt:2575
+#: common.opt:2579
 msgid "Enable loop distribution on trees."
 msgstr ""
 
-#: common.opt:2579
+#: common.opt:2583
 msgid "Enable loop distribution for patterns transformed into a library call."
 msgstr ""
 
-#: common.opt:2583
+#: common.opt:2587
 msgid "Enable loop invariant motion on trees."
 msgstr ""
 
-#: common.opt:2591
+#: common.opt:2595
 msgid "Create canonical induction variables in loops."
 msgstr ""
 
-#: common.opt:2595
+#: common.opt:2599
 msgid "Enable loop optimizations on tree level."
 msgstr ""
 
-#: common.opt:2599
+#: common.opt:2603
 msgid "-ftree-parallelize-loops=<number>\tEnable automatic parallelization of loops."
 msgstr ""
 
-#: common.opt:2603
+#: common.opt:2607
 msgid "Enable hoisting loads from conditional pointers."
 msgstr ""
 
-#: common.opt:2607
+#: common.opt:2611
 msgid "Enable SSA-PRE optimization on trees."
 msgstr ""
 
-#: common.opt:2611
+#: common.opt:2615
 msgid "In SSA-PRE optimization on trees, enable partial-partial redundancy elimination."
 msgstr ""
 
-#: common.opt:2615
+#: common.opt:2619
 msgid "Perform function-local points-to analysis on trees."
 msgstr ""
 
-#: common.opt:2619
+#: common.opt:2623
 msgid "Enable reassociation on tree level."
 msgstr ""
 
-#: common.opt:2627
+#: common.opt:2631
 msgid "Enable SSA code sinking on trees."
 msgstr ""
 
-#: common.opt:2631
+#: common.opt:2635
 msgid "Perform straight-line strength reduction."
 msgstr ""
 
-#: common.opt:2635
+#: common.opt:2639
 msgid "Perform scalar replacement of aggregates."
 msgstr ""
 
-#: common.opt:2639
+#: common.opt:2643
 msgid "Replace temporary expressions in the SSA->normal pass."
 msgstr ""
 
-#: common.opt:2643
+#: common.opt:2647
 msgid "Perform live range splitting during the SSA->normal pass."
 msgstr ""
 
-#: common.opt:2647
+#: common.opt:2651
 msgid "Perform Value Range Propagation on trees."
 msgstr ""
 
-#: common.opt:2651
+#: common.opt:2655
 msgid "Split paths leading to loop backedges."
 msgstr ""
 
-#: common.opt:2655
+#: common.opt:2659
 msgid "Assume common declarations may be overridden with ones with a larger trailing array."
 msgstr ""
 
-#: common.opt:2660
+#: common.opt:2664
 msgid "Compile whole compilation unit at a time."
 msgstr ""
 
-#: common.opt:2664
+#: common.opt:2668
 msgid "Perform loop unrolling when iteration count is known."
 msgstr ""
 
-#: common.opt:2668
+#: common.opt:2672
 msgid "Perform loop unrolling for all loops."
 msgstr ""
 
-#: common.opt:2679
+#: common.opt:2683
 msgid "Allow optimization for floating-point arithmetic which may change the result of the operation due to rounding."
 msgstr ""
 
-#: common.opt:2684
+#: common.opt:2688
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr ""
 
-#: common.opt:2692
+#: common.opt:2696
 msgid "Allow math optimizations that may violate IEEE or ISO standards."
 msgstr ""
 
-#: common.opt:2696
+#: common.opt:2700
 msgid "Perform loop unswitching."
 msgstr ""
 
-#: common.opt:2700
+#: common.opt:2704
 msgid "Perform loop splitting."
 msgstr ""
 
-#: common.opt:2704
+#: common.opt:2708
 msgid "Just generate unwind tables for exception handling."
 msgstr ""
 
-#: common.opt:2708
+#: common.opt:2712
 msgid "Use the bfd linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2712
+#: common.opt:2716
 msgid "Use the gold linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2724
+#: common.opt:2728
 msgid "Perform variable tracking."
 msgstr ""
 
-#: common.opt:2732
+#: common.opt:2736
 msgid "Perform variable tracking by annotating assignments."
 msgstr ""
 
-#: common.opt:2738
+#: common.opt:2742
 msgid "Toggle -fvar-tracking-assignments."
 msgstr ""
 
-#: common.opt:2746
+#: common.opt:2750
 msgid "Perform variable tracking and also tag variables that are uninitialized."
 msgstr ""
 
-#: common.opt:2751
+#: common.opt:2755
 msgid "Enable vectorization on trees."
 msgstr ""
 
-#: common.opt:2759
+#: common.opt:2763
 msgid "Enable loop vectorization on trees."
 msgstr ""
 
-#: common.opt:2763
+#: common.opt:2767
 msgid "Enable basic block vectorization (SLP) on trees."
 msgstr ""
 
-#: common.opt:2767
+#: common.opt:2771
 msgid "Specifies the cost model for vectorization. -fvect-cost-model=[unlimited|dynamic|cheap]\tSpecifies the cost model for vectorization."
 msgstr ""
 
-#: common.opt:2772
+#: common.opt:2776
 msgid "-fsimd-cost-model=[unlimited|dynamic|cheap]\tSpecifies the vectorization cost model for code marked with a simd directive."
 msgstr ""
 
-#: common.opt:2775
+#: common.opt:2779
 #, c-format
 msgid "unknown vectorizer cost model %qs"
 msgstr ""
 
-#: common.opt:2788
+#: common.opt:2792
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr ""
 
-#: common.opt:2796
+#: common.opt:2800
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr ""
 
-#: common.opt:2806
+#: common.opt:2810
 msgid "Add extra commentary to assembler output."
 msgstr ""
 
-#: common.opt:2810
+#: common.opt:2814
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility."
 msgstr ""
 
-#: common.opt:2813
+#: common.opt:2817
 #, c-format
 msgid "unrecognized visibility value %qs"
 msgstr ""
 
-#: common.opt:2829
+#: common.opt:2833
 msgid "Validate vtable pointers before using them."
 msgstr ""
 
-#: common.opt:2832
+#: common.opt:2836
 #, c-format
 msgid "unknown vtable verify initialization priority %qs"
 msgstr ""
 
-#: common.opt:2845
+#: common.opt:2849
 msgid "Output vtable verification counters."
 msgstr ""
 
-#: common.opt:2849
+#: common.opt:2853
 msgid "Output vtable verification pointer sets information."
 msgstr ""
 
-#: common.opt:2853
+#: common.opt:2857
 msgid "Use expression value profiles in optimizations."
 msgstr ""
 
-#: common.opt:2857
+#: common.opt:2861
 msgid "Construct webs and split unrelated uses of single variable."
 msgstr ""
 
-#: common.opt:2861
+#: common.opt:2865
 msgid "Enable conditional dead code elimination for builtin calls."
 msgstr ""
 
-#: common.opt:2865
+#: common.opt:2869
 msgid "Perform whole program optimizations."
 msgstr ""
 
-#: common.opt:2869
+#: common.opt:2873
 msgid "Assume pointer overflow wraps around."
 msgstr ""
 
-#: common.opt:2873
+#: common.opt:2877
 msgid "Assume signed arithmetic overflow wraps around."
 msgstr ""
 
-#: common.opt:2877
+#: common.opt:2881
 msgid "Put zero initialized data in the bss section."
 msgstr ""
 
-#: common.opt:2881
+#: common.opt:2885
 msgid "Generate debug information in default format."
 msgstr ""
 
-#: common.opt:2885
+#: common.opt:2889
 msgid "Assume assembler support for (DWARF2+) .loc directives"
 msgstr ""
 
-#: common.opt:2889
+#: common.opt:2893
 msgid "Assume assembler support for view in (DWARF2+) .loc directives"
 msgstr ""
 
-#: common.opt:2892 common.opt:2896 common.opt:2900 common.opt:2904
+#: common.opt:2896 common.opt:2900 common.opt:2904 common.opt:2908
 #, c-format
 msgid "switch %qs no longer supported"
 msgstr ""
 
-#: common.opt:2909
+#: common.opt:2913
 msgid "Record DW_AT_decl_column and DW_AT_call_column in DWARF."
 msgstr ""
 
-#: common.opt:2913
+#: common.opt:2917
 msgid "Generate debug information in default version of DWARF format."
 msgstr ""
 
-#: common.opt:2917
+#: common.opt:2921
 msgid "Generate debug information in DWARF v2 (or later) format."
 msgstr ""
 
-#: common.opt:2921
+#: common.opt:2925
 msgid "Generate debug information in default extended format."
 msgstr ""
 
-#: common.opt:2925
+#: common.opt:2929
 msgid "Generate extended entry point information for inlined functions"
 msgstr ""
 
-#: common.opt:2929
+#: common.opt:2933
 msgid "Compute locview reset points based on insn length estimates"
 msgstr ""
 
-#: common.opt:2937
+#: common.opt:2941
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:2941
+#: common.opt:2945
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:2945
+#: common.opt:2949
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr ""
 
-#: common.opt:2949
+#: common.opt:2953
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr ""
 
-#: common.opt:2953
+#: common.opt:2957
 msgid "Generate debug information in separate .dwo files."
 msgstr ""
 
-#: common.opt:2957
+#: common.opt:2961
 msgid "Generate debug information in STABS format."
 msgstr ""
 
-#: common.opt:2961
+#: common.opt:2965
 msgid "Generate debug information in extended STABS format."
 msgstr ""
 
-#: common.opt:2965
+#: common.opt:2969
 msgid "Emit progressive recommended breakpoint locations."
 msgstr ""
 
-#: common.opt:2969
+#: common.opt:2973
 msgid "Don't emit DWARF additions beyond selected version."
 msgstr ""
 
-#: common.opt:2973
+#: common.opt:2977
 msgid "Toggle debug information generation."
 msgstr ""
 
-#: common.opt:2977
+#: common.opt:2981
 msgid "Augment variable location lists with progressive views."
 msgstr ""
 
-#: common.opt:2984
+#: common.opt:2988
 msgid "Generate debug information in VMS format."
 msgstr ""
 
-#: common.opt:2988
+#: common.opt:2992
 msgid "Generate debug information in XCOFF format."
 msgstr ""
 
-#: common.opt:2992
+#: common.opt:2996
 msgid "Generate debug information in extended XCOFF format."
 msgstr ""
 
-#: common.opt:3010
+#: common.opt:3014
 msgid "Generate compressed debug sections."
 msgstr ""
 
-#: common.opt:3014
+#: common.opt:3018
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>."
 msgstr ""
 
-#: common.opt:3021
+#: common.opt:3025
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory."
 msgstr ""
 
-#: common.opt:3025
+#: common.opt:3029
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory."
 msgstr ""
 
-#: common.opt:3047
+#: common.opt:3051
 #, fuzzy
 #| msgid "  -o <file>                Place the output into <file>\n"
 msgid "-o <file>\tPlace output into <file>."
 msgstr "  -o <datoteka>            Spremi izlaz u <datoteka>\n"
 
-#: common.opt:3051
+#: common.opt:3055
 msgid "Enable function profiling."
 msgstr ""
 
-#: common.opt:3061
+#: common.opt:3065
 msgid "Like -pedantic but issue them as errors."
 msgstr ""
 
-#: common.opt:3101
+#: common.opt:3105
 msgid "Do not display functions compiled or elapsed time."
 msgstr ""
 
-#: common.opt:3133
+#: common.opt:3137
 msgid "Enable verbose output."
 msgstr ""
 
-#: common.opt:3137
+#: common.opt:3141
 msgid "Display the compiler's version."
 msgstr ""
 
-#: common.opt:3141
+#: common.opt:3145
 msgid "Suppress warnings."
 msgstr ""
 
-#: common.opt:3151
+#: common.opt:3155
 #, fuzzy
 #| msgid "  -shared                  Create a shared library\n"
 msgid "Create a shared library."
 msgstr "  -shared                  Napravi dijeljenu biblioteku\n"
 
-#: common.opt:3196
+#: common.opt:3200
 msgid "Don't create a dynamically linked position independent executable."
 msgstr ""
 
-#: common.opt:3200
+#: common.opt:3204
 msgid "Create a dynamically linked position independent executable."
 msgstr ""
 
-#: common.opt:3204
+#: common.opt:3208
 msgid "Create a static position independent executable."
 msgstr ""
 
-#: common.opt:3211
+#: common.opt:3215
 msgid "Use caller save register across calls if possible."
 msgstr ""
 
-#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:598 cp/cvt.c:1308
+#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:599 cp/cvt.c:1308
 #: cp/cvt.c:1561
 #, gcc-internal-format
 msgid "value computed is not used"
@@ -15760,7 +15761,7 @@
 msgstr ""
 
 #: go/gofrontend/expressions.cc:4331 c/c-parser.c:13477 c/c-parser.c:13484
-#: cp/parser.c:33264 cp/parser.c:33271
+#: cp/parser.c:33261 cp/parser.c:33268
 #, fuzzy, gcc-internal-format
 #| msgid "expected end of line"
 msgid "expected integer"
@@ -16176,14 +16177,14 @@
 msgid "ignoring attribute %qE because it conflicts with attribute %qs"
 msgstr ""
 
-#: attribs.c:449 c-family/c-attribs.c:1894 cp/decl.c:13690 cp/friend.c:302
-#: cp/tree.c:4559
+#: attribs.c:449 c-family/c-attribs.c:1905 cp/decl.c:13714 cp/friend.c:302
+#: cp/tree.c:4607
 #, gcc-internal-format
 msgid "previous declaration here"
 msgstr ""
 
 #. Warn about and ignore all others for now, but store them.
-#: attribs.c:564 c-family/c-attribs.c:2717 objc/objc-act.c:4963
+#: attribs.c:564 c-family/c-attribs.c:2728 objc/objc-act.c:4963
 #: objc/objc-act.c:6932 objc/objc-act.c:8119 objc/objc-act.c:8170
 #, gcc-internal-format
 msgid "%qE attribute directive ignored"
@@ -16202,17 +16203,17 @@
 #. This is a c++11 attribute that appertains to a
 #. type-specifier, outside of the definition of, a class
 #. type.  Ignore it.
-#: attribs.c:590 cp/decl.c:10999
+#: attribs.c:590 cp/decl.c:11023
 #, gcc-internal-format
 msgid "attribute ignored"
 msgstr ""
 
-#: attribs.c:592 cp/decl.c:11000
+#: attribs.c:592 cp/decl.c:11024
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
 
-#: attribs.c:610 c-family/c-attribs.c:3219
+#: attribs.c:610 c-family/c-attribs.c:3230
 #, gcc-internal-format
 msgid "%qE attribute does not apply to types"
 msgstr ""
@@ -16228,40 +16229,40 @@
 msgstr ""
 
 #: attribs.c:691 attribs.c:1622 attribs.c:1632 attribs.c:1642
-#: c-family/c-attribs.c:540 c-family/c-attribs.c:559 c-family/c-attribs.c:577
-#: c-family/c-attribs.c:607 c-family/c-attribs.c:628 c-family/c-attribs.c:649
-#: c-family/c-attribs.c:690 c-family/c-attribs.c:717 c-family/c-attribs.c:733
-#: c-family/c-attribs.c:750 c-family/c-attribs.c:766 c-family/c-attribs.c:792
-#: c-family/c-attribs.c:807 c-family/c-attribs.c:835 c-family/c-attribs.c:852
-#: c-family/c-attribs.c:870 c-family/c-attribs.c:893 c-family/c-attribs.c:931
-#: c-family/c-attribs.c:954 c-family/c-attribs.c:971 c-family/c-attribs.c:1000
-#: c-family/c-attribs.c:1021 c-family/c-attribs.c:1042
-#: c-family/c-attribs.c:1069 c-family/c-attribs.c:1099
-#: c-family/c-attribs.c:1136 c-family/c-attribs.c:1189
-#: c-family/c-attribs.c:1255 c-family/c-attribs.c:1313
-#: c-family/c-attribs.c:1402 c-family/c-attribs.c:1432
-#: c-family/c-attribs.c:1483 c-family/c-attribs.c:1998
-#: c-family/c-attribs.c:2035 c-family/c-attribs.c:2096
-#: c-family/c-attribs.c:2152 c-family/c-attribs.c:2230
-#: c-family/c-attribs.c:2312 c-family/c-attribs.c:2371
-#: c-family/c-attribs.c:2390 c-family/c-attribs.c:2498
-#: c-family/c-attribs.c:2514 c-family/c-attribs.c:2530
-#: c-family/c-attribs.c:2551 c-family/c-attribs.c:2608
-#: c-family/c-attribs.c:2635 c-family/c-attribs.c:2690
-#: c-family/c-attribs.c:2870 c-family/c-attribs.c:2891
-#: c-family/c-attribs.c:3004 c-family/c-attribs.c:3031
-#: c-family/c-attribs.c:3221 c-family/c-attribs.c:3239
-#: c-family/c-attribs.c:3262 c-family/c-attribs.c:3301
-#: c-family/c-attribs.c:3383 c-family/c-attribs.c:3439
-#: c-family/c-attribs.c:3455 c-family/c-attribs.c:3549
-#: c-family/c-common.c:5600 config/darwin.c:2072 config/arm/arm.c:6868
+#: c-family/c-attribs.c:547 c-family/c-attribs.c:566 c-family/c-attribs.c:584
+#: c-family/c-attribs.c:614 c-family/c-attribs.c:635 c-family/c-attribs.c:656
+#: c-family/c-attribs.c:697 c-family/c-attribs.c:728 c-family/c-attribs.c:744
+#: c-family/c-attribs.c:761 c-family/c-attribs.c:777 c-family/c-attribs.c:803
+#: c-family/c-attribs.c:818 c-family/c-attribs.c:846 c-family/c-attribs.c:863
+#: c-family/c-attribs.c:881 c-family/c-attribs.c:904 c-family/c-attribs.c:942
+#: c-family/c-attribs.c:965 c-family/c-attribs.c:982 c-family/c-attribs.c:1011
+#: c-family/c-attribs.c:1032 c-family/c-attribs.c:1053
+#: c-family/c-attribs.c:1080 c-family/c-attribs.c:1110
+#: c-family/c-attribs.c:1147 c-family/c-attribs.c:1200
+#: c-family/c-attribs.c:1266 c-family/c-attribs.c:1324
+#: c-family/c-attribs.c:1413 c-family/c-attribs.c:1443
+#: c-family/c-attribs.c:1494 c-family/c-attribs.c:2009
+#: c-family/c-attribs.c:2046 c-family/c-attribs.c:2107
+#: c-family/c-attribs.c:2163 c-family/c-attribs.c:2241
+#: c-family/c-attribs.c:2323 c-family/c-attribs.c:2382
+#: c-family/c-attribs.c:2401 c-family/c-attribs.c:2509
+#: c-family/c-attribs.c:2525 c-family/c-attribs.c:2541
+#: c-family/c-attribs.c:2562 c-family/c-attribs.c:2619
+#: c-family/c-attribs.c:2646 c-family/c-attribs.c:2701
+#: c-family/c-attribs.c:2881 c-family/c-attribs.c:2902
+#: c-family/c-attribs.c:3015 c-family/c-attribs.c:3042
+#: c-family/c-attribs.c:3232 c-family/c-attribs.c:3250
+#: c-family/c-attribs.c:3273 c-family/c-attribs.c:3312
+#: c-family/c-attribs.c:3394 c-family/c-attribs.c:3450
+#: c-family/c-attribs.c:3466 c-family/c-attribs.c:3560
+#: c-family/c-common.c:5598 config/darwin.c:2072 config/arm/arm.c:6868
 #: config/arm/arm.c:6896 config/arm/arm.c:6913 config/avr/avr.c:9698
-#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6497
-#: config/i386/i386.c:41520 config/ia64/ia64.c:788
-#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33056
-#: config/spu/spu.c:3743 ada/gcc-interface/utils.c:6244
-#: ada/gcc-interface/utils.c:6261 ada/gcc-interface/utils.c:6277
-#: ada/gcc-interface/utils.c:6303 brig/brig-lang.c:476 lto/lto-lang.c:283
+#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6500
+#: config/i386/i386.c:41514 config/ia64/ia64.c:788
+#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33112
+#: config/spu/spu.c:3743 ada/gcc-interface/utils.c:6249
+#: ada/gcc-interface/utils.c:6266 ada/gcc-interface/utils.c:6282
+#: ada/gcc-interface/utils.c:6308 brig/brig-lang.c:476 lto/lto-lang.c:283
 #, gcc-internal-format
 msgid "%qE attribute ignored"
 msgstr ""
@@ -16633,88 +16634,103 @@
 msgid "%Kattempt to free a non-heap object"
 msgstr ""
 
-#: calls.c:1434
+#: calls.c:1291 file-prefix-map.c:50
 #, gcc-internal-format
-msgid "%Kargument %i value %qE is negative"
+msgid "invalid argument %qs to %qs"
 msgstr ""
 
 #: calls.c:1452
 #, gcc-internal-format
+msgid "%Kargument %i value %qE is negative"
+msgstr ""
+
+#: calls.c:1470
+#, gcc-internal-format
 msgid "%Kargument %i value is zero"
 msgstr ""
 
-#: calls.c:1469
+#: calls.c:1487
 #, gcc-internal-format
 msgid "%Kargument %i value %qE exceeds maximum object size %E"
 msgstr ""
 
-#: calls.c:1483
+#: calls.c:1501
 #, gcc-internal-format
 msgid "%Kargument %i range [%E, %E] is negative"
 msgstr ""
 
-#: calls.c:1490
+#: calls.c:1508
 #, gcc-internal-format
 msgid "%Kargument %i range [%E, %E] exceeds maximum object size %E"
 msgstr ""
 
-#: calls.c:1520
+#: calls.c:1538
 #, gcc-internal-format
 msgid "%Kproduct %<%E * %E%> of arguments %i and %i exceeds %<SIZE_MAX%>"
 msgstr ""
 
-#: calls.c:1526
+#: calls.c:1544
 #, gcc-internal-format
 msgid "%Kproduct %<%E * %E%> of arguments %i and %i exceeds maximum object size %E"
 msgstr ""
 
-#: calls.c:1537 calls.c:1540
+#: calls.c:1555 calls.c:1558
 #, gcc-internal-format
 msgid "argument %i in the range [%E, %E]"
 msgstr ""
 
-#: calls.c:1551
+#: calls.c:1569
 #, gcc-internal-format
 msgid "in a call to built-in allocation function %qD"
 msgstr ""
 
-#: calls.c:1554
+#: calls.c:1572
 #, gcc-internal-format
 msgid "in a call to allocation function %qD declared here"
 msgstr ""
 
-#: calls.c:1711
+#: calls.c:1835
 #, gcc-internal-format
-msgid "%qD argument %i declared attribute %<nonstring%> is smaller than the specified bound %E"
+msgid "%qD argument %i declared attribute %<nonstring%> is smaller than the specified bound %wu"
 msgstr ""
 
-#: calls.c:1716
+#: calls.c:1841
 #, gcc-internal-format
+msgid "%qD argument %i declared attribute %<nonstring%> is smaller than the specified bound [%E, %E]"
+msgstr ""
+
+#: calls.c:1847
+#, gcc-internal-format
+msgid "%qD argument %i declared attribute %<nonstring%> may be smaller than the specified bound [%E, %E]"
+msgstr ""
+
+#: calls.c:1857
+#, gcc-internal-format
 msgid "%qD argument %i declared attribute %<nonstring%>"
 msgstr ""
 
-#: calls.c:1721
+#: calls.c:1862
 #, gcc-internal-format
 msgid "argument %qD declared here"
 msgstr ""
 
-#: calls.c:1735
+#: calls.c:1876
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "[cannot find %s]"
 msgid "cannot tail-call: %s"
 msgstr "[ne mogu naći %s]"
 
-#: calls.c:3365
+#: calls.c:3506
 #, gcc-internal-format
 msgid "function call has aggregate value"
 msgstr ""
 
-#: calls.c:4059
+#: calls.c:4200
 #, gcc-internal-format
 msgid "passing too large argument on stack"
 msgstr ""
 
-#: cfgexpand.c:1665 function.c:1002 varasm.c:2231
+#: cfgexpand.c:1665 function.c:1002 varasm.c:2242
 #, gcc-internal-format
 msgid "size of variable %q+D is too large"
 msgstr ""
@@ -17286,237 +17302,237 @@
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr ""
 
-#: cgraph.c:3051
+#: cgraph.c:3056
 #, gcc-internal-format
 msgid "caller edge count invalid"
 msgstr ""
 
-#: cgraph.c:3135
+#: cgraph.c:3140
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr ""
 
-#: cgraph.c:3142
+#: cgraph.c:3147
 #, gcc-internal-format
 msgid "cgraph count invalid"
 msgstr ""
 
-#: cgraph.c:3147
+#: cgraph.c:3152
 #, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr ""
 
-#: cgraph.c:3152
+#: cgraph.c:3157
 #, gcc-internal-format
 msgid "local symbols must be defined"
 msgstr ""
 
-#: cgraph.c:3157
+#: cgraph.c:3162
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr ""
 
-#: cgraph.c:3162
+#: cgraph.c:3167
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr ""
 
-#: cgraph.c:3167
+#: cgraph.c:3172
 #, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr ""
 
-#: cgraph.c:3174
+#: cgraph.c:3179
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for indirect edge from %s"
 msgstr ""
 
-#: cgraph.c:3181
+#: cgraph.c:3186
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr ""
 
-#: cgraph.c:3196
+#: cgraph.c:3201
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr ""
 
-#: cgraph.c:3206
+#: cgraph.c:3211
 #, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr ""
 
-#: cgraph.c:3211
+#: cgraph.c:3216
 #, gcc-internal-format
 msgid "multiple inline callers"
 msgstr ""
 
-#: cgraph.c:3218
+#: cgraph.c:3223
 #, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr ""
 
-#: cgraph.c:3239
+#: cgraph.c:3244
 #, gcc-internal-format
 msgid "caller edge count does not match BB count"
 msgstr ""
 
-#: cgraph.c:3261
+#: cgraph.c:3266
 #, gcc-internal-format
 msgid "indirect call count does not match BB count"
 msgstr ""
 
-#: cgraph.c:3272
+#: cgraph.c:3277
 #, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr ""
 
-#: cgraph.c:3277
+#: cgraph.c:3282
 #, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr ""
 
-#: cgraph.c:3289
+#: cgraph.c:3294
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr ""
 
-#: cgraph.c:3301
+#: cgraph.c:3306
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr ""
 
-#: cgraph.c:3307
+#: cgraph.c:3312
 #, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr ""
 
-#: cgraph.c:3312
+#: cgraph.c:3317
 #, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr ""
 
-#: cgraph.c:3317
+#: cgraph.c:3322
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr ""
 
-#: cgraph.c:3329
+#: cgraph.c:3334
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr ""
 
-#: cgraph.c:3337
+#: cgraph.c:3342
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr ""
 
-#: cgraph.c:3342
+#: cgraph.c:3347
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr ""
 
-#: cgraph.c:3349
+#: cgraph.c:3354
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr ""
 
-#: cgraph.c:3358
+#: cgraph.c:3363
 #, gcc-internal-format
 msgid "Instrumentation clone does not reference original node"
 msgstr ""
 
-#: cgraph.c:3365
+#: cgraph.c:3370
 #, gcc-internal-format
 msgid "Not instrumented node has non-NULL original declaration"
 msgstr ""
 
-#: cgraph.c:3375
+#: cgraph.c:3380
 #, gcc-internal-format
 msgid "Instrumented node has wrong original declaration"
 msgstr ""
 
-#: cgraph.c:3393
+#: cgraph.c:3398
 #, gcc-internal-format
 msgid "Node has more than one chkp reference"
 msgstr ""
 
-#: cgraph.c:3398
+#: cgraph.c:3403
 #, gcc-internal-format
 msgid "Wrong node is referenced with chkp reference"
 msgstr ""
 
-#: cgraph.c:3406
+#: cgraph.c:3411
 #, gcc-internal-format
 msgid "Analyzed node has no reference to instrumented version"
 msgstr ""
 
-#: cgraph.c:3420
+#: cgraph.c:3425
 #, gcc-internal-format
 msgid "Alias chain for instrumented node is broken"
 msgstr ""
 
-#: cgraph.c:3429
+#: cgraph.c:3434
 #, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3434
+#: cgraph.c:3439
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3439
+#: cgraph.c:3444
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr ""
 
-#: cgraph.c:3445
+#: cgraph.c:3450
 #, gcc-internal-format
 msgid "Instrumentation thunk has wrong edge callee"
 msgstr ""
 
-#: cgraph.c:3481
+#: cgraph.c:3486
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr ""
 
-#: cgraph.c:3489
+#: cgraph.c:3494
 #, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr ""
 
-#: cgraph.c:3498
+#: cgraph.c:3503
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr ""
 
-#: cgraph.c:3508
+#: cgraph.c:3513
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr ""
 
-#: cgraph.c:3518
+#: cgraph.c:3523
 #, gcc-internal-format
 msgid "reference to dead statement"
 msgstr ""
 
-#: cgraph.c:3531
+#: cgraph.c:3536
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3543
+#: cgraph.c:3548
 #, gcc-internal-format, gfc-internal-format
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3554
+#: cgraph.c:3559
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr ""
 
-#: cgraph.c:3661 varpool.c:306
+#: cgraph.c:3666 varpool.c:306
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: section %s is missing"
 msgstr ""
@@ -17547,12 +17563,12 @@
 msgstr ""
 
 #. include_self=
-#: cgraphunit.c:981 c/c-decl.c:11282
+#: cgraphunit.c:981 c/c-decl.c:11302
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr ""
 
-#: cgraphunit.c:983 c/c-decl.c:11291
+#: cgraphunit.c:983 c/c-decl.c:11311
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr ""
@@ -17667,12 +17683,12 @@
 msgid "cannot find '%s'"
 msgstr ""
 
-#: collect-utils.c:183 collect2.c:2361 collect2.c:2560 gcc.c:3080 gcc.c:6856
+#: collect-utils.c:183 collect2.c:2387 collect2.c:2586 gcc.c:3080 gcc.c:6856
 #, gcc-internal-format
 msgid "pex_init failed: %m"
 msgstr ""
 
-#: collect-utils.c:192 collect2.c:2370 collect2.c:2568 gcc.c:8498
+#: collect-utils.c:192 collect2.c:2396 collect2.c:2594 gcc.c:8498
 #, gcc-internal-format
 msgid "%s: %m"
 msgstr ""
@@ -17682,93 +17698,93 @@
 msgid "COLLECT_LTO_WRAPPER must be set"
 msgstr ""
 
-#: collect2.c:966 gcc.c:7382 lto-wrapper.c:1666
+#: collect2.c:969 gcc.c:7382 lto-wrapper.c:1692
 #: config/i386/intelmic-mkoffload.c:556 config/nvptx/mkoffload.c:405
 #, gcc-internal-format
 msgid "atexit failed"
 msgstr ""
 
-#: collect2.c:1064
+#: collect2.c:1067
 #, gcc-internal-format
 msgid "no arguments"
 msgstr ""
 
-#: collect2.c:1303 opts.c:904
+#: collect2.c:1311 opts.c:904
 #, gcc-internal-format
 msgid "LTO support has not been enabled in this configuration"
 msgstr ""
 
-#: collect2.c:1344
+#: collect2.c:1352
 #, gcc-internal-format
 msgid "can't open %s: %m"
 msgstr ""
 
-#: collect2.c:1450
+#: collect2.c:1472
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown demangling style '%s'"
 msgstr ""
 
-#: collect2.c:1546 collect2.c:1729 collect2.c:1769
+#: collect2.c:1574 collect2.c:1757 collect2.c:1797
 #, gcc-internal-format
 msgid "fopen %s: %m"
 msgstr ""
 
-#: collect2.c:1549 collect2.c:1734 collect2.c:1772
+#: collect2.c:1577 collect2.c:1762 collect2.c:1800
 #, gcc-internal-format
 msgid "fclose %s: %m"
 msgstr ""
 
-#: collect2.c:2335
+#: collect2.c:2361
 #, gcc-internal-format
 msgid "cannot find 'nm'"
 msgstr ""
 
-#: collect2.c:2383
+#: collect2.c:2409
 #, gcc-internal-format
 msgid "can't open nm output: %m"
 msgstr ""
 
-#: collect2.c:2467
+#: collect2.c:2493
 #, gcc-internal-format, gfc-internal-format
 msgid "init function found in object %s"
 msgstr ""
 
-#: collect2.c:2478
+#: collect2.c:2504
 #, gcc-internal-format, gfc-internal-format
 msgid "fini function found in object %s"
 msgstr ""
 
-#: collect2.c:2535
+#: collect2.c:2561
 #, gcc-internal-format
 msgid "cannot find 'ldd'"
 msgstr ""
 
-#: collect2.c:2581
+#: collect2.c:2607
 #, gcc-internal-format
 msgid "can't open ldd output: %m"
 msgstr ""
 
-#: collect2.c:2599
+#: collect2.c:2625
 #, gcc-internal-format, gfc-internal-format
 msgid "dynamic dependency %s not found"
 msgstr ""
 
-#: collect2.c:2611
+#: collect2.c:2637
 #, gcc-internal-format, gfc-internal-format
 msgid "unable to open dynamic dependency '%s'"
 msgstr ""
 
-#: collect2.c:2765
+#: collect2.c:2791
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: not a COFF file"
 msgstr ""
 
-#: collect2.c:2930
+#: collect2.c:2961
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: cannot open as COFF file"
 msgstr ""
 
-#: collect2.c:2989
+#: collect2.c:3020
 #, gcc-internal-format, gfc-internal-format
 msgid "library lib%s not found"
 msgstr ""
@@ -17978,12 +17994,12 @@
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr ""
 
-#: dwarf2out.c:10901
+#: dwarf2out.c:10909
 #, gcc-internal-format
 msgid "-gdwarf-6 is output as version 5 with incompatibilities"
 msgstr ""
 
-#: dwarf2out.c:14415
+#: dwarf2out.c:14423
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
@@ -18103,11 +18119,6 @@
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr ""
 
-#: file-prefix-map.c:50
-#, gcc-internal-format
-msgid "invalid argument %qs to %qs"
-msgstr ""
-
 #: final.c:1868
 #, gcc-internal-format
 msgid "the frame size of %wd bytes is larger than %wd bytes"
@@ -18128,42 +18139,42 @@
 msgid "large fixed-point constant implicitly truncated to fixed-point type"
 msgstr ""
 
-#: fold-const.c:4151 fold-const.c:4161
+#: fold-const.c:4157 fold-const.c:4167
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d due to width of bit-field"
 msgstr ""
 
-#: fold-const.c:5478 tree-ssa-reassoc.c:2374 tree-ssa-reassoc.c:3214
+#: fold-const.c:5484 tree-ssa-reassoc.c:2379 tree-ssa-reassoc.c:3219
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
 
-#: fold-const.c:5928 fold-const.c:5942
+#: fold-const.c:5934 fold-const.c:5948
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr ""
 
-#: fold-const.c:6085
+#: fold-const.c:6091
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr ""
 
-#: fold-const.c:6090
+#: fold-const.c:6096
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr ""
 
-#: fold-const.c:8310
+#: fold-const.c:8316
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr ""
 
-#: fold-const.c:8710
+#: fold-const.c:8716
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr ""
 
-#: fold-const.c:12063
+#: fold-const.c:12069
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr ""
@@ -18173,7 +18184,7 @@
 msgid "total size of local objects too large"
 msgstr ""
 
-#: function.c:1776 gimplify.c:6270
+#: function.c:1776 gimplify.c:6273
 #, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr ""
@@ -18478,7 +18489,7 @@
 msgid "%s: linker input file unused because linking not done"
 msgstr ""
 
-#: gcc.c:8420 c-family/c-opts.c:770
+#: gcc.c:8420 c-family/c-opts.c:768
 #, gcc-internal-format
 msgid "cannot use %<-%> as input filename for a precompiled header"
 msgstr ""
@@ -18716,7 +18727,7 @@
 msgid "%G%qD destination unchanged after copying no bytes"
 msgstr ""
 
-#: gimple-fold.c:2052 tree-ssa-strlen.c:2050
+#: gimple-fold.c:2052 tree-ssa-strlen.c:2074
 msgid "%G%qD specified bound %E equals destination size"
 msgstr ""
 
@@ -18738,12 +18749,12 @@
 msgid "null pointer dereference"
 msgstr ""
 
-#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12451
-#: tree.c:12488 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10147
-#: c/c-typeck.c:10164 c/gimple-parser.c:1616 c/gimple-parser.c:1624
+#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12455
+#: tree.c:12492 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10152
+#: c/c-typeck.c:10169 c/gimple-parser.c:1616 c/gimple-parser.c:1624
 #: cp/call.c:6493 cp/call.c:8098 cp/constexpr.c:820 cp/constexpr.c:2309
-#: cp/cvt.c:1015 cp/cvt.c:1042 cp/decl.c:7334 cp/decl2.c:5256 cp/pt.c:8334
-#: cp/semantics.c:1836 cp/semantics.c:4053 cp/typeck.c:1700 cp/typeck.c:1895
+#: cp/cvt.c:1015 cp/cvt.c:1042 cp/decl.c:7355 cp/decl2.c:5246 cp/pt.c:8348
+#: cp/semantics.c:1836 cp/semantics.c:4056 cp/typeck.c:1700 cp/typeck.c:1895
 #: cp/typeck.c:3837
 #, gcc-internal-format
 msgid "declared here"
@@ -18754,27 +18765,27 @@
 msgid "nonnull argument %qD compared to NULL"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2517 gimple-ssa-sprintf.c:2637
+#: gimple-ssa-sprintf.c:2555 gimple-ssa-sprintf.c:2675
 #, gcc-internal-format
 msgid "%qE output may be truncated before the last format character"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2519 gimple-ssa-sprintf.c:2639
+#: gimple-ssa-sprintf.c:2557 gimple-ssa-sprintf.c:2677
 #, gcc-internal-format
 msgid "%qE output truncated before the last format character"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2522 gimple-ssa-sprintf.c:2642
+#: gimple-ssa-sprintf.c:2560 gimple-ssa-sprintf.c:2680
 #, gcc-internal-format
 msgid "%qE may write a terminating nul past the end of the destination"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2524 gimple-ssa-sprintf.c:2644
+#: gimple-ssa-sprintf.c:2562 gimple-ssa-sprintf.c:2682
 #, gcc-internal-format
 msgid "%qE writing a terminating nul past the end of the destination"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2534
+#: gimple-ssa-sprintf.c:2572
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size %wu"
@@ -18782,7 +18793,7 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: gimple-ssa-sprintf.c:2541
+#: gimple-ssa-sprintf.c:2579
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size %wu"
@@ -18790,7 +18801,7 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: gimple-ssa-sprintf.c:2548
+#: gimple-ssa-sprintf.c:2586
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size %wu"
@@ -18798,67 +18809,67 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: gimple-ssa-sprintf.c:2559
+#: gimple-ssa-sprintf.c:2597
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2562
+#: gimple-ssa-sprintf.c:2600
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2564
+#: gimple-ssa-sprintf.c:2602
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2576
+#: gimple-ssa-sprintf.c:2614
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2579
+#: gimple-ssa-sprintf.c:2617
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2582
+#: gimple-ssa-sprintf.c:2620
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2591
+#: gimple-ssa-sprintf.c:2629
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2594
+#: gimple-ssa-sprintf.c:2632
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2597
+#: gimple-ssa-sprintf.c:2635
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2606
+#: gimple-ssa-sprintf.c:2644
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2609
+#: gimple-ssa-sprintf.c:2647
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2611
+#: gimple-ssa-sprintf.c:2649
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2653
+#: gimple-ssa-sprintf.c:2691
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size between %wu and %wu"
@@ -18866,7 +18877,7 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: gimple-ssa-sprintf.c:2660
+#: gimple-ssa-sprintf.c:2698
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size between %wu and %wu"
@@ -18874,7 +18885,7 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: gimple-ssa-sprintf.c:2668
+#: gimple-ssa-sprintf.c:2706
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size between %wu and %wu"
@@ -18882,102 +18893,102 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: gimple-ssa-sprintf.c:2680
+#: gimple-ssa-sprintf.c:2718
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2683
+#: gimple-ssa-sprintf.c:2721
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2686
+#: gimple-ssa-sprintf.c:2724
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2699
+#: gimple-ssa-sprintf.c:2737
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2702
+#: gimple-ssa-sprintf.c:2740
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2705
+#: gimple-ssa-sprintf.c:2743
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2715
+#: gimple-ssa-sprintf.c:2753
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2718
+#: gimple-ssa-sprintf.c:2756
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2721
+#: gimple-ssa-sprintf.c:2759
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2730
+#: gimple-ssa-sprintf.c:2768
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2733
+#: gimple-ssa-sprintf.c:2771
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2736
+#: gimple-ssa-sprintf.c:2774
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2825
+#: gimple-ssa-sprintf.c:2863
 #, gcc-internal-format
 msgid "%<%.*s%> directive argument is null"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2890
+#: gimple-ssa-sprintf.c:2928
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes exceeds minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2897
+#: gimple-ssa-sprintf.c:2935
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may exceed minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2900
+#: gimple-ssa-sprintf.c:2938
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes exceeds minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2929
+#: gimple-ssa-sprintf.c:2967
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2936
+#: gimple-ssa-sprintf.c:2974
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2939
+#: gimple-ssa-sprintf.c:2977
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may cause result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2949
+#: gimple-ssa-sprintf.c:2987
 #, gcc-internal-format
 msgid "assuming directive output of %wu byte"
 msgid_plural "assuming directive output of %wu bytes"
@@ -18985,77 +18996,77 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: gimple-ssa-sprintf.c:2956
+#: gimple-ssa-sprintf.c:2994
 #, gcc-internal-format
 msgid "directive argument %qE"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2958
+#: gimple-ssa-sprintf.c:2996
 #, gcc-internal-format
 msgid "directive argument in the range [%E, %E]"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2962
+#: gimple-ssa-sprintf.c:3000
 #, gcc-internal-format
 msgid "using the range [%E, %E] for directive argument"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2982
+#: gimple-ssa-sprintf.c:3020
 #, gcc-internal-format
 msgid "%qE output %wu byte into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2983
+#: gimple-ssa-sprintf.c:3021
 #, gcc-internal-format
 msgid "%qE output %wu bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2987
+#: gimple-ssa-sprintf.c:3025
 #, gcc-internal-format
 msgid "%qE output between %wu and %wu bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2992
+#: gimple-ssa-sprintf.c:3030
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes (assuming %wu) into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2997
+#: gimple-ssa-sprintf.c:3035
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3368
+#: gimple-ssa-sprintf.c:3406
 #, gcc-internal-format
 msgid "%<%.*s%> directive width out of range"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3402
+#: gimple-ssa-sprintf.c:3440
 #, gcc-internal-format
 msgid "%<%.*s%> directive precision out of range"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3893
+#: gimple-ssa-sprintf.c:3931
 #, gcc-internal-format
 msgid "specified bound %wu exceeds maximum object size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3899
+#: gimple-ssa-sprintf.c:3937
 #, gcc-internal-format
 msgid "specified bound %wu exceeds %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3949
+#: gimple-ssa-sprintf.c:3987
 #, gcc-internal-format
 msgid "null destination pointer"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3966
+#: gimple-ssa-sprintf.c:4004
 #, gcc-internal-format
 msgid "specified bound %wu exceeds the size %wu of the destination object"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3978
+#: gimple-ssa-sprintf.c:4016
 #, gcc-internal-format
 msgid "null format string"
 msgstr ""
@@ -19279,10 +19290,10 @@
 msgstr ""
 
 #: gimple-ssa-warn-restrict.c:1678 c/c-decl.c:3603 c/c-decl.c:3874
-#: c/c-typeck.c:8345 cp/class.c:1346 cp/class.c:3098 cp/decl.c:3979
-#: cp/decl.c:10753 cp/decl.c:11151 cp/decl.c:11160 cp/friend.c:384
+#: c/c-typeck.c:8350 cp/class.c:1346 cp/class.c:3102 cp/decl.c:3979
+#: cp/decl.c:10777 cp/decl.c:11175 cp/decl.c:11184 cp/friend.c:384
 #: cp/friend.c:393 cp/parser.c:3275 cp/parser.c:3372 cp/parser.c:3422
-#: cp/parser.c:6327 cp/parser.c:21027
+#: cp/parser.c:6330 cp/parser.c:21024
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr ""
@@ -19350,217 +19361,217 @@
 msgid "using result of function returning %<void%>"
 msgstr ""
 
-#: gimplify.c:6128
+#: gimplify.c:6131
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid lvalue in asm output %d"
 msgstr ""
 
-#: gimplify.c:6271
+#: gimplify.c:6274
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr ""
 
-#: gimplify.c:6311 gimplify.c:6320
+#: gimplify.c:6314 gimplify.c:6323
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr ""
 
-#: gimplify.c:6928
+#: gimplify.c:6931
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in target region"
 msgstr ""
 
-#: gimplify.c:6930
+#: gimplify.c:6933
 #, gcc-internal-format
 msgid "enclosing target region"
 msgstr ""
 
-#: gimplify.c:6942
+#: gimplify.c:6945
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in untied task"
 msgstr ""
 
-#: gimplify.c:6944
+#: gimplify.c:6947
 #, gcc-internal-format
 msgid "enclosing task"
 msgstr ""
 
-#: gimplify.c:7016
+#: gimplify.c:7019
 #, gcc-internal-format
 msgid "%qE not specified in enclosing %qs"
 msgstr ""
 
-#: gimplify.c:7018
+#: gimplify.c:7021
 #, gcc-internal-format
 msgid "enclosing %qs"
 msgstr ""
 
-#: gimplify.c:7143
+#: gimplify.c:7146
 #, gcc-internal-format
 msgid "%qE not specified in enclosing OpenACC %qs construct"
 msgstr ""
 
-#: gimplify.c:7145
+#: gimplify.c:7148
 #, gcc-internal-format
 msgid "enclosing OpenACC %qs construct"
 msgstr ""
 
-#: gimplify.c:7198
+#: gimplify.c:7201
 #, gcc-internal-format
 msgid "%qE with %<link%> clause used in %<routine%> function"
 msgstr ""
 
-#: gimplify.c:7206
+#: gimplify.c:7209
 #, gcc-internal-format
 msgid "%qE requires a %<declare%> directive for use in a %<routine%> function"
 msgstr ""
 
-#: gimplify.c:7272 gimplify.c:7872
+#: gimplify.c:7275 gimplify.c:7875
 #, gcc-internal-format
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr ""
 
-#: gimplify.c:7293
+#: gimplify.c:7296
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr ""
 
-#: gimplify.c:7411 gimplify.c:7443
+#: gimplify.c:7414 gimplify.c:7446
 #, gcc-internal-format
 msgid "iteration variable %qE is predetermined linear"
 msgstr ""
 
-#: gimplify.c:7414
+#: gimplify.c:7417
 #, gcc-internal-format
 msgid "iteration variable %qE should be private"
 msgstr ""
 
-#: gimplify.c:7428
+#: gimplify.c:7431
 #, gcc-internal-format
 msgid "iteration variable %qE should not be firstprivate"
 msgstr ""
 
-#: gimplify.c:7431
+#: gimplify.c:7434
 #, gcc-internal-format
 msgid "iteration variable %qE should not be reduction"
 msgstr ""
 
-#: gimplify.c:7434
+#: gimplify.c:7437
 #, gcc-internal-format
 msgid "iteration variable %qE should not be linear"
 msgstr ""
 
-#: gimplify.c:7437
+#: gimplify.c:7440
 #, gcc-internal-format
 msgid "iteration variable %qE should not be lastprivate"
 msgstr ""
 
-#: gimplify.c:7440
+#: gimplify.c:7443
 #, gcc-internal-format
 msgid "iteration variable %qE should not be private"
 msgstr ""
 
-#: gimplify.c:7742
+#: gimplify.c:7745
 #, gcc-internal-format
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr ""
 
-#: gimplify.c:7949
+#: gimplify.c:7952
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr ""
 
-#: gimplify.c:8160
+#: gimplify.c:8163
 #, gcc-internal-format
 msgid "%qE appears more than once in map clauses"
 msgstr ""
 
-#: gimplify.c:8464
+#: gimplify.c:8467
 #, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr ""
 
-#: gimplify.c:8484
+#: gimplify.c:8487
 #, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr ""
 
-#: gimplify.c:8510
+#: gimplify.c:8513
 #, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr ""
 
-#: gimplify.c:8775
+#: gimplify.c:8778
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr ""
 
-#: gimplify.c:8808
+#: gimplify.c:8811
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:9000
+#: gimplify.c:9003
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:9051
+#: gimplify.c:9054
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr ""
 
-#: gimplify.c:9133
+#: gimplify.c:9136
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to present_or_copy"
 msgstr ""
 
-#: gimplify.c:9278
+#: gimplify.c:9281
 #, gcc-internal-format
 msgid "invalid private reduction on %qE"
 msgstr ""
 
-#: gimplify.c:11103 omp-low.c:2791
+#: gimplify.c:11106 omp-low.c:2791
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: gimplify.c:11121
+#: gimplify.c:11124
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr ""
 
-#: gimplify.c:11134
+#: gimplify.c:11137
 #, gcc-internal-format
 msgid "number of variables in %<depend(sink)%> clause does not match number of iteration variables"
 msgstr ""
 
-#: gimplify.c:11147
+#: gimplify.c:11150
 #, gcc-internal-format
 msgid "more than one %<depend(source)%> clause on an %<ordered%> construct"
 msgstr ""
 
-#: gimplify.c:11158
+#: gimplify.c:11161
 #, gcc-internal-format
 msgid "%<depend(source)%> clause specified together with %<depend(sink:)%> clauses on the same construct"
 msgstr ""
 
-#: gimplify.c:12393
+#: gimplify.c:12396
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr ""
 
-#: gimplify.c:12936
+#: gimplify.c:12939
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr ""
 
-#: gimplify.c:12941
+#: gimplify.c:12944
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr ""
 
-#: gimplify.c:12948
+#: gimplify.c:12951
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr ""
@@ -20039,47 +20050,47 @@
 msgid "Max. number of generated reload insns per insn is achieved (%d)\n"
 msgstr ""
 
-#: lto-cgraph.c:1294
+#: lto-cgraph.c:1296
 #, gcc-internal-format, gfc-internal-format
 msgid "bytecode stream: found multiple instances of cgraph node with uid %d"
 msgstr ""
 
-#: lto-cgraph.c:1472
+#: lto-cgraph.c:1474
 #, gcc-internal-format
 msgid "bytecode stream: no caller found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1478
+#: lto-cgraph.c:1480
 #, gcc-internal-format
 msgid "bytecode stream: no callee found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1552
+#: lto-cgraph.c:1554
 #, gcc-internal-format
 msgid "bytecode stream: found empty cgraph node"
 msgstr ""
 
-#: lto-cgraph.c:1730
+#: lto-cgraph.c:1732
 #, gcc-internal-format, gfc-internal-format
 msgid "At most %i profile runs is supported. Perhaps corrupted profile?"
 msgstr ""
 
-#: lto-cgraph.c:1817
+#: lto-cgraph.c:1819
 #, gcc-internal-format, gfc-internal-format
 msgid "Profile information in %s corrupted"
 msgstr ""
 
-#: lto-cgraph.c:1855
+#: lto-cgraph.c:1857
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO cgraph in %s"
 msgstr ""
 
-#: lto-cgraph.c:1865
+#: lto-cgraph.c:1867
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO section refs in %s"
 msgstr ""
 
-#: lto-cgraph.c:1946
+#: lto-cgraph.c:1948
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid offload table in %s"
 msgstr ""
@@ -20151,85 +20162,91 @@
 msgid "bytecode stream in file %qs generated with LTO version %d.%d instead of the expected %d.%d"
 msgstr ""
 
-#: lto-wrapper.c:117
+#: lto-wrapper.c:118
 #, fuzzy, gcc-internal-format
 #| msgid "deleting LTRANS file %s"
 msgid "deleting LTRANS file %s: %m"
 msgstr "uklanjam LTRANS datoteku %s"
 
-#: lto-wrapper.c:154
+#: lto-wrapper.c:155
 #, gcc-internal-format
 msgid "malformed COLLECT_GCC_OPTIONS"
 msgstr "izobličen COLLECT_GCC_OPTIONS"
 
-#: lto-wrapper.c:308
+#: lto-wrapper.c:309
 #, gcc-internal-format, gfc-internal-format
 msgid "Option %s with different values"
 msgstr ""
 
-#: lto-wrapper.c:392
+#: lto-wrapper.c:393
 #, gcc-internal-format, gfc-internal-format
 msgid "Option %s not used consistently in all LTO input files"
 msgstr ""
 
-#: lto-wrapper.c:832
+#: lto-wrapper.c:833
 #, gcc-internal-format, gfc-internal-format
 msgid "problem with building target image for %s\n"
 msgstr ""
 
-#: lto-wrapper.c:852
+#: lto-wrapper.c:853
 #, gcc-internal-format
 msgid "reading input file"
 msgstr ""
 
-#: lto-wrapper.c:857
+#: lto-wrapper.c:858
 #, gcc-internal-format
 msgid "writing output file"
 msgstr ""
 
-#: lto-wrapper.c:889
+#: lto-wrapper.c:890
 #, gcc-internal-format
 msgid "installation error, can't find crtoffloadtable.o"
 msgstr ""
 
-#: lto-wrapper.c:1000 lto-wrapper.c:1012
+#: lto-wrapper.c:1001 lto-wrapper.c:1013
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: %s\n"
 msgstr ""
 
-#: lto-wrapper.c:1056
+#: lto-wrapper.c:1064
 #, gcc-internal-format
 msgid "environment variable COLLECT_GCC must be set"
 msgstr "varijabla okoline COLLECT_GCC mora biti postavljena "
 
-#: lto-wrapper.c:1060 config/nvptx/mkoffload.c:363
+#: lto-wrapper.c:1068 config/nvptx/mkoffload.c:363
 #, gcc-internal-format
 msgid "environment variable COLLECT_GCC_OPTIONS must be set"
 msgstr "varijabla okoline COLLECT_GCC_OPTIONS mora biti postavljena"
 
-#: lto-wrapper.c:1229 lto-wrapper.c:1285
+#: lto-wrapper.c:1237 lto-wrapper.c:1293
 #, fuzzy, gcc-internal-format
 #| msgid "[cannot find %s]"
 msgid "cannot open %s: %m"
 msgstr "[ne mogu naći %s]"
 
-#: lto-wrapper.c:1232 lto-wrapper.c:1291
+#: lto-wrapper.c:1240 lto-wrapper.c:1299
 #, fuzzy, gcc-internal-format
 #| msgid "[cannot find %s]"
 msgid "cannot read %s: %m"
 msgstr "[ne mogu naći %s]"
 
-#: lto-wrapper.c:1259
+#: lto-wrapper.c:1267
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid format of %s"
 msgstr ""
 
-#: lto-wrapper.c:1482
+#: lto-wrapper.c:1491
 #, fuzzy, gcc-internal-format
 #| msgid "fopen: %s"
 msgid "fopen: %s: %m"
 msgstr "fopen: %s"
 
+#: lto-wrapper.c:1508
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "Could not open output file '%s'\n"
+msgid "Corrupted ltrans output file %s"
+msgstr "Ne mogu otvoriti izlaznu datoteku „%s”\n"
+
 #: multiple_target.c:76
 #, gcc-internal-format
 msgid "the call requires ifunc, which is not supported by this target"
@@ -20583,12 +20600,12 @@
 msgid "unrecognized argument in option %qs"
 msgstr ""
 
-#: opts-common.c:1198 config/i386/i386.c:3206
+#: opts-common.c:1198 config/i386/i386.c:3209
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr ""
 
-#: opts-common.c:1201 config/i386/i386.c:3209
+#: opts-common.c:1201 config/i386/i386.c:3212
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr ""
@@ -21175,22 +21192,22 @@
 msgid "output operand %d must use %<&%> constraint"
 msgstr ""
 
-#: regcprop.c:1187
+#: regcprop.c:1193
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad next_regno for empty chain (%u)"
 msgstr ""
 
-#: regcprop.c:1199
+#: regcprop.c:1205
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: Loop in regno chain (%u)"
 msgstr ""
 
-#: regcprop.c:1202
+#: regcprop.c:1208
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad oldest_regno (%u)"
 msgstr ""
 
-#: regcprop.c:1214
+#: regcprop.c:1220
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Non-empty reg in chain (%s %u %i)"
 msgstr ""
@@ -21234,7 +21251,7 @@
 msgstr ""
 
 #: reginfo.c:789 config/powerpcspe/powerpcspe.c:32259
-#: config/rs6000/rs6000.c:29453
+#: config/rs6000/rs6000.c:29530
 #, gcc-internal-format
 msgid "conflicts with %qD"
 msgstr ""
@@ -21479,152 +21496,157 @@
 msgid "function symbol is not function"
 msgstr ""
 
-#: symtab.c:1006
+#: symtab.c:1005
 #, gcc-internal-format
+msgid "inconsistent `ifunc' attribute"
+msgstr ""
+
+#: symtab.c:1013
+#, gcc-internal-format
 msgid "variable symbol is not variable"
 msgstr ""
 
-#: symtab.c:1012
+#: symtab.c:1019
 #, gcc-internal-format
 msgid "node has unknown type"
 msgstr ""
 
-#: symtab.c:1021
+#: symtab.c:1028
 #, gcc-internal-format
 msgid "node not found node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.c:1029
+#: symtab.c:1036
 #, gcc-internal-format
 msgid "node differs from node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.c:1038
+#: symtab.c:1045
 #, gcc-internal-format
 msgid "assembler name hash list corrupted"
 msgstr ""
 
-#: symtab.c:1051
+#: symtab.c:1058
 #, gcc-internal-format
 msgid "node not found in symtab assembler name hash"
 msgstr ""
 
-#: symtab.c:1058
+#: symtab.c:1065
 #, gcc-internal-format
 msgid "double linked list of assembler names corrupted"
 msgstr ""
 
-#: symtab.c:1063
+#: symtab.c:1070
 #, gcc-internal-format
 msgid "node has body_removed but is definition"
 msgstr ""
 
-#: symtab.c:1068
+#: symtab.c:1075
 #, gcc-internal-format
 msgid "node is analyzed but it is not a definition"
 msgstr ""
 
-#: symtab.c:1073
+#: symtab.c:1080
 #, gcc-internal-format
 msgid "node is alias but not implicit alias"
 msgstr ""
 
-#: symtab.c:1078
+#: symtab.c:1085
 #, gcc-internal-format
 msgid "node is alias but not definition"
 msgstr ""
 
-#: symtab.c:1083
+#: symtab.c:1090
 #, gcc-internal-format
 msgid "node is weakref but not an transparent_alias"
 msgstr ""
 
-#: symtab.c:1088
+#: symtab.c:1095
 #, gcc-internal-format
 msgid "node is transparent_alias but not an alias"
 msgstr ""
 
-#: symtab.c:1097
+#: symtab.c:1104
 #, gcc-internal-format
 msgid "node is in same_comdat_group list but has no comdat_group"
 msgstr ""
 
-#: symtab.c:1102
+#: symtab.c:1109
 #, gcc-internal-format
 msgid "same_comdat_group list across different groups"
 msgstr ""
 
-#: symtab.c:1107
+#: symtab.c:1114
 #, gcc-internal-format
 msgid "mixing different types of symbol in same comdat groups is not supported"
 msgstr ""
 
-#: symtab.c:1112
+#: symtab.c:1119
 #, gcc-internal-format
 msgid "node is alone in a comdat group"
 msgstr ""
 
-#: symtab.c:1119
+#: symtab.c:1126
 #, gcc-internal-format
 msgid "same_comdat_group is not a circular list"
 msgstr ""
 
-#: symtab.c:1134
+#: symtab.c:1141
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local symbol referred to by %s outside its comdat"
 msgstr ""
 
-#: symtab.c:1144
+#: symtab.c:1151
 #, gcc-internal-format
 msgid "implicit_section flag is set but section isn't"
 msgstr ""
 
-#: symtab.c:1151
+#: symtab.c:1158
 #, gcc-internal-format
 msgid "Both section and comdat group is set"
 msgstr ""
 
-#: symtab.c:1163
+#: symtab.c:1170
 #, gcc-internal-format
 msgid "Alias and target's section differs"
 msgstr ""
 
-#: symtab.c:1170
+#: symtab.c:1177
 #, gcc-internal-format
 msgid "Alias and target's comdat groups differs"
 msgstr ""
 
-#: symtab.c:1185
+#: symtab.c:1192
 #, gcc-internal-format
 msgid "Transparent alias and target's assembler names differs"
 msgstr ""
 
-#: symtab.c:1193
+#: symtab.c:1200
 #, gcc-internal-format
 msgid "Chained transparent aliases"
 msgstr ""
 
-#: symtab.c:1216 symtab.c:1253
+#: symtab.c:1223 symtab.c:1260
 #, gcc-internal-format
 msgid "symtab_node::verify failed"
 msgstr ""
 
-#: symtab.c:1249
+#: symtab.c:1256
 #, gcc-internal-format
 msgid "Two symbols with same comdat_group are not linked by the same_comdat_group list."
 msgstr ""
 
-#: symtab.c:1658
+#: symtab.c:1665
 #, gcc-internal-format
 msgid "function %q+D part of alias cycle"
 msgstr ""
 
-#: symtab.c:1660
+#: symtab.c:1667
 #, gcc-internal-format
 msgid "variable %q+D part of alias cycle"
 msgstr ""
 
-#: symtab.c:1688
+#: symtab.c:1695
 #, gcc-internal-format
 msgid "section of alias %q+D must match section of its target"
 msgstr ""
@@ -22426,7 +22448,7 @@
 msgid "the first argument of a VEC_COND_EXPR must be of a boolean vector type of the same number of elements as the result"
 msgstr ""
 
-#: tree-cfg.c:4395 c/c-typeck.c:5212
+#: tree-cfg.c:4395 c/c-typeck.c:5217
 #, gcc-internal-format
 msgid "type mismatch in conditional expression"
 msgstr ""
@@ -22776,22 +22798,22 @@
 msgid "missing edge %i->%i"
 msgstr ""
 
-#: tree-cfg.c:9379
+#: tree-cfg.c:9388
 #, gcc-internal-format
 msgid "%<noreturn%> function does return"
 msgstr ""
 
-#: tree-cfg.c:9400 tree-cfg.c:9432
+#: tree-cfg.c:9409 tree-cfg.c:9441
 #, gcc-internal-format
 msgid "control reaches end of non-void function"
 msgstr ""
 
-#: tree-cfg.c:9498 cp/cvt.c:1039
+#: tree-cfg.c:9507 cp/cvt.c:1039
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgstr ""
 
-#: tree-cfg.c:9503 cp/cvt.c:1046
+#: tree-cfg.c:9512 cp/cvt.c:1046
 #, gcc-internal-format
 msgid "ignoring return value of function declared with attribute warn_unused_result"
 msgstr ""
@@ -23056,7 +23078,7 @@
 msgid "stmt volatile flag not up-to-date"
 msgstr ""
 
-#: tree-ssa-strlen.c:1975
+#: tree-ssa-strlen.c:1999
 msgid "%G%qD output truncated before terminating nul copying %E byte from a string of the same length"
 msgid_plural "%G%qD output truncated before terminating nul copying %E bytes from a string of the same length"
 msgstr[0] ""
@@ -23063,7 +23085,7 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: tree-ssa-strlen.c:1989
+#: tree-ssa-strlen.c:2013
 msgid "%G%qD output truncated copying %E byte from a string of length %wu"
 msgid_plural "%G%qD output truncated copying %E bytes from a string of length %wu"
 msgstr[0] ""
@@ -23070,11 +23092,11 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: tree-ssa-strlen.c:1996
+#: tree-ssa-strlen.c:2020
 msgid "%G%qD output truncated copying between %wu and %wu bytes from a string of length %wu"
 msgstr ""
 
-#: tree-ssa-strlen.c:2008
+#: tree-ssa-strlen.c:2032
 msgid "%G%qD output may be truncated copying %E byte from a string of length %wu"
 msgid_plural "%G%qD output may be truncated copying %E bytes from a string of length %wu"
 msgstr[0] ""
@@ -23081,24 +23103,24 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: tree-ssa-strlen.c:2015 tree-ssa-strlen.c:2029
+#: tree-ssa-strlen.c:2039 tree-ssa-strlen.c:2053
 msgid "%G%qD output may be truncated copying between %wu and %wu bytes from a string of length %wu"
 msgstr ""
 
-#: tree-ssa-strlen.c:2150
+#: tree-ssa-strlen.c:2174
 msgid "%G%qD output truncated before terminating nul copying as many bytes from a string as its length"
 msgstr ""
 
-#: tree-ssa-strlen.c:2156
+#: tree-ssa-strlen.c:2180
 msgid "%G%qD specified bound depends on the length of the source argument"
 msgstr ""
 
-#: tree-ssa-strlen.c:2163
+#: tree-ssa-strlen.c:2187
 #, gcc-internal-format
 msgid "length computed here"
 msgstr ""
 
-#: tree-ssa-uninit.c:191 varasm.c:331
+#: tree-ssa-uninit.c:191 varasm.c:342
 #, gcc-internal-format
 msgid "%qD was declared here"
 msgstr ""
@@ -23273,27 +23295,27 @@
 msgid "target specific builtin not available"
 msgstr ""
 
-#: tree-vect-generic.c:287
+#: tree-vect-generic.c:283
 #, gcc-internal-format
 msgid "vector operation will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-generic.c:290
+#: tree-vect-generic.c:286
 #, gcc-internal-format
 msgid "vector operation will be expanded in parallel"
 msgstr ""
 
-#: tree-vect-generic.c:341
+#: tree-vect-generic.c:337
 #, gcc-internal-format
 msgid "vector operation will be expanded with a single scalar operation"
 msgstr ""
 
-#: tree-vect-generic.c:941
+#: tree-vect-generic.c:937
 #, gcc-internal-format
 msgid "vector condition will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-generic.c:1373
+#: tree-vect-generic.c:1369
 #, gcc-internal-format
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr ""
@@ -23303,27 +23325,27 @@
 msgid "vectorization did not happen for a simd loop"
 msgstr ""
 
-#: tree-vrp.c:4930 tree-vrp.c:4974
+#: tree-vrp.c:4931 tree-vrp.c:4975
 #, gcc-internal-format
 msgid "array subscript %E is above array bounds of %qT"
 msgstr ""
 
-#: tree-vrp.c:4956
+#: tree-vrp.c:4957
 #, gcc-internal-format
 msgid "array subscript [%E, %E] is outside array bounds of %qT"
 msgstr ""
 
-#: tree-vrp.c:4988
+#: tree-vrp.c:4989
 #, gcc-internal-format
 msgid "array subscript %E is below array bounds of %qT"
 msgstr ""
 
-#: tree-vrp.c:5046
+#: tree-vrp.c:5047
 #, gcc-internal-format
 msgid "array subscript %wi is below array bounds of %qT"
 msgstr ""
 
-#: tree-vrp.c:5060
+#: tree-vrp.c:5061
 #, gcc-internal-format
 msgid "array subscript %wu is above array bounds of %qT"
 msgstr ""
@@ -23338,92 +23360,92 @@
 msgid "side-effects element in no-side-effects CONSTRUCTOR"
 msgstr ""
 
-#: tree.c:7852
+#: tree.c:7856
 #, gcc-internal-format
 msgid "arrays of functions are not meaningful"
 msgstr ""
 
-#: tree.c:8019
+#: tree.c:8023
 #, gcc-internal-format
 msgid "function return type cannot be function"
 msgstr ""
 
-#: tree.c:9327 tree.c:9412 tree.c:9473
+#: tree.c:9331 tree.c:9416 tree.c:9477
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: %s, have %s in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9364
+#: tree.c:9368
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected none of %s, have %s in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9377
+#: tree.c:9381
 #, gcc-internal-format
 msgid "tree check: expected class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9426
+#: tree.c:9430
 #, gcc-internal-format
 msgid "tree check: did not expect class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9439
+#: tree.c:9443
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected omp_clause %s, have %s in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9499
+#: tree.c:9503
 #, gcc-internal-format
 msgid "tree check: expected tree that contains %qs structure, have %qs in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9513
+#: tree.c:9517
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_int_cst with %d elts in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9525
+#: tree.c:9529
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_vec with %d elts in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9538
+#: tree.c:9542
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of %s with %d operands in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9551
+#: tree.c:9555
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of omp_clause %s with %d operands in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:12446
+#: tree.c:12450
 #, gcc-internal-format
 msgid "%qD is deprecated: %s"
 msgstr ""
 
-#: tree.c:12449
+#: tree.c:12453
 #, gcc-internal-format
 msgid "%qD is deprecated"
 msgstr ""
 
-#: tree.c:12473 tree.c:12495
+#: tree.c:12477 tree.c:12499
 #, gcc-internal-format
 msgid "%qE is deprecated: %s"
 msgstr ""
 
-#: tree.c:12476 tree.c:12498
+#: tree.c:12480 tree.c:12502
 #, gcc-internal-format
 msgid "%qE is deprecated"
 msgstr ""
 
-#: tree.c:12482 tree.c:12503
+#: tree.c:12486 tree.c:12507
 #, gcc-internal-format, gfc-internal-format
 msgid "type is deprecated: %s"
 msgstr ""
 
-#: tree.c:12485 tree.c:12506
+#: tree.c:12489 tree.c:12510
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr ""
@@ -23448,242 +23470,242 @@
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.c:13043
+#: tree.c:13047
 #, gcc-internal-format, gfc-internal-format
 msgid "type variant differs by %s"
 msgstr ""
 
-#: tree.c:13084
+#: tree.c:13088
 #, gcc-internal-format
 msgid "type variant has different TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13086
+#: tree.c:13090
 #, gcc-internal-format
 msgid "type variant's TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13088
+#: tree.c:13092
 #, gcc-internal-format
 msgid "type's TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13108
+#: tree.c:13112
 #, gcc-internal-format
 msgid "type variant with TYPE_ALIAS_SET_KNOWN_P"
 msgstr ""
 
-#: tree.c:13121
+#: tree.c:13125
 #, gcc-internal-format
 msgid "type variant has different TYPE_VFIELD"
 msgstr ""
 
-#: tree.c:13157
+#: tree.c:13161
 #, gcc-internal-format
 msgid "type variant has different TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13159
+#: tree.c:13163
 #, gcc-internal-format
 msgid "type variant's TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13161
+#: tree.c:13165
 #, gcc-internal-format
 msgid "type's TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13199
+#: tree.c:13203
 #, gcc-internal-format
 msgid "type variant has different TYPE_FIELDS"
 msgstr ""
 
-#: tree.c:13201
+#: tree.c:13205
 #, gcc-internal-format
 msgid "first mismatch is field"
 msgstr ""
 
-#: tree.c:13203
+#: tree.c:13207
 #, gcc-internal-format
 msgid "and field"
 msgstr ""
 
-#: tree.c:13220
+#: tree.c:13224
 #, gcc-internal-format
 msgid "type variant has different TREE_TYPE"
 msgstr ""
 
-#: tree.c:13222 tree.c:13233
+#: tree.c:13226 tree.c:13237
 #, gcc-internal-format
 msgid "type variant's TREE_TYPE"
 msgstr ""
 
-#: tree.c:13224 tree.c:13235
+#: tree.c:13228 tree.c:13239
 #, gcc-internal-format
 msgid "type's TREE_TYPE"
 msgstr ""
 
-#: tree.c:13231
+#: tree.c:13235
 #, gcc-internal-format
 msgid "type is not compatible with its variant"
 msgstr ""
 
-#: tree.c:13534
+#: tree.c:13538
 #, gcc-internal-format
 msgid "Main variant is not defined"
 msgstr ""
 
-#: tree.c:13539
+#: tree.c:13543
 #, gcc-internal-format
 msgid "TYPE_MAIN_VARIANT has different TYPE_MAIN_VARIANT"
 msgstr ""
 
-#: tree.c:13551
+#: tree.c:13555
 #, gcc-internal-format
 msgid "TYPE_CANONICAL has different TYPE_CANONICAL"
 msgstr ""
 
-#: tree.c:13569
+#: tree.c:13573
 #, gcc-internal-format
 msgid "TYPE_CANONICAL is not compatible"
 msgstr ""
 
-#: tree.c:13577
+#: tree.c:13581
 #, gcc-internal-format
 msgid "TYPE_MODE of TYPE_CANONICAL is not compatible"
 msgstr ""
 
-#: tree.c:13583
+#: tree.c:13587
 #, gcc-internal-format
 msgid "TYPE_CANONICAL of main variant is not main variant"
 msgstr ""
 
-#: tree.c:13599
+#: tree.c:13603
 #, gcc-internal-format
 msgid "TYPE_VFIELD is not FIELD_DECL nor TREE_LIST"
 msgstr ""
 
-#: tree.c:13609
+#: tree.c:13613
 #, gcc-internal-format
 msgid "TYPE_NEXT_PTR_TO is not POINTER_TYPE"
 msgstr ""
 
-#: tree.c:13619
+#: tree.c:13623
 #, gcc-internal-format
 msgid "TYPE_NEXT_REF_TO is not REFERENCE_TYPE"
 msgstr ""
 
-#: tree.c:13640
+#: tree.c:13644
 #, gcc-internal-format
 msgid "TYPE_BINFO is not TREE_BINFO"
 msgstr ""
 
-#: tree.c:13646
+#: tree.c:13650
 #, gcc-internal-format
 msgid "TYPE_BINFO type is not TYPE_MAIN_VARIANT"
 msgstr ""
 
-#: tree.c:13657
+#: tree.c:13661
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not record nor union"
 msgstr ""
 
-#: tree.c:13668
+#: tree.c:13672
 #, gcc-internal-format
 msgid "TYPE_OFFSET_BASETYPE is not record nor union"
 msgstr ""
 
-#: tree.c:13686
+#: tree.c:13690
 #, gcc-internal-format
 msgid "TYPE_ARRAY_MAX_SIZE not INTEGER_CST"
 msgstr ""
 
-#: tree.c:13693
+#: tree.c:13697
 #, gcc-internal-format
 msgid "TYPE_MAX_VALUE_RAW non-NULL"
 msgstr ""
 
-#: tree.c:13700
+#: tree.c:13704
 #, gcc-internal-format
 msgid "TYPE_LANG_SLOT_1 (binfo) field is non-NULL"
 msgstr ""
 
-#: tree.c:13716
+#: tree.c:13720
 #, gcc-internal-format
 msgid "Enum value is not CONST_DECL or INTEGER_CST"
 msgstr ""
 
-#: tree.c:13724
+#: tree.c:13728
 #, gcc-internal-format
 msgid "Enum value type is not INTEGER_TYPE nor convertible to the enum"
 msgstr ""
 
-#: tree.c:13731
+#: tree.c:13735
 #, gcc-internal-format
 msgid "Enum value name is not IDENTIFIER_NODE"
 msgstr ""
 
-#: tree.c:13741
+#: tree.c:13745
 #, gcc-internal-format
 msgid "Array TYPE_DOMAIN is not integer type"
 msgstr ""
 
-#: tree.c:13750
+#: tree.c:13754
 #, gcc-internal-format
 msgid "TYPE_FIELDS defined in incomplete type"
 msgstr ""
 
-#: tree.c:13772
+#: tree.c:13776
 #, gcc-internal-format
 msgid "Wrong tree in TYPE_FIELDS list"
 msgstr ""
 
-#: tree.c:13787
+#: tree.c:13791
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is %i while TYPE_CACHED_VALUES is %p"
 msgstr ""
 
-#: tree.c:13793
+#: tree.c:13797
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES is not TREE_VEC"
 msgstr ""
 
-#: tree.c:13806
+#: tree.c:13810
 #, gcc-internal-format
 msgid "wrong TYPE_CACHED_VALUES entry"
 msgstr ""
 
-#: tree.c:13819
+#: tree.c:13823
 #, gcc-internal-format
 msgid "TREE_PURPOSE is non-NULL in TYPE_ARG_TYPES list"
 msgstr ""
 
-#: tree.c:13825
+#: tree.c:13829
 #, gcc-internal-format
 msgid "Wrong entry in TYPE_ARG_TYPES list"
 msgstr ""
 
-#: tree.c:13832
+#: tree.c:13836
 #, gcc-internal-format
 msgid "TYPE_VALUES_RAW field is non-NULL"
 msgstr ""
 
-#: tree.c:13844
+#: tree.c:13848
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is set while it should not"
 msgstr ""
 
-#: tree.c:13850
+#: tree.c:13854
 #, gcc-internal-format
 msgid "TYPE_STRING_FLAG is set on wrong type code"
 msgstr ""
 
-#: tree.c:13860
+#: tree.c:13864
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not main variant"
 msgstr ""
 
-#: tree.c:13867
+#: tree.c:13871
 #, fuzzy, gcc-internal-format
 #| msgid "pex_init failed"
 msgid "verify_type failed"
@@ -23709,182 +23731,182 @@
 msgid "corrupted value profile: %s profile counter (%d out of %d) inconsistent with basic-block count (%d)"
 msgstr ""
 
-#: var-tracking.c:7166
+#: var-tracking.c:7184
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded with -fvar-tracking-assignments, retrying without"
 msgstr ""
 
-#: var-tracking.c:7170
+#: var-tracking.c:7188
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded"
 msgstr ""
 
-#: varasm.c:326
+#: varasm.c:337
 #, gcc-internal-format
 msgid "%+qD causes a section type conflict with %qD"
 msgstr ""
 
-#: varasm.c:329
+#: varasm.c:340
 #, gcc-internal-format
 msgid "section type conflict with %qD"
 msgstr ""
 
-#: varasm.c:334
+#: varasm.c:345
 #, gcc-internal-format
 msgid "%+qD causes a section type conflict"
 msgstr ""
 
-#: varasm.c:336
+#: varasm.c:347
 #, gcc-internal-format
 msgid "section type conflict"
 msgstr ""
 
-#: varasm.c:1019
+#: varasm.c:1030
 #, gcc-internal-format
 msgid "alignment of %q+D is greater than maximum object file alignment %d"
 msgstr ""
 
-#: varasm.c:1172
+#: varasm.c:1183
 #, gcc-internal-format
 msgid "only zero initializers are allowed in section %qs"
 msgstr ""
 
-#: varasm.c:1378 varasm.c:1387
+#: varasm.c:1389 varasm.c:1398
 #, gcc-internal-format
 msgid "register name not specified for %q+D"
 msgstr ""
 
-#: varasm.c:1389
+#: varasm.c:1400
 #, gcc-internal-format
 msgid "invalid register name for %q+D"
 msgstr ""
 
-#: varasm.c:1391
+#: varasm.c:1402
 #, gcc-internal-format
 msgid "data type of %q+D isn%'t suitable for a register"
 msgstr ""
 
-#: varasm.c:1394
+#: varasm.c:1405
 #, gcc-internal-format
 msgid "the register specified for %q+D cannot be accessed by the current target"
 msgstr ""
 
-#: varasm.c:1397
+#: varasm.c:1408
 #, gcc-internal-format
 msgid "the register specified for %q+D is not general enough to be used as a register variable"
 msgstr ""
 
-#: varasm.c:1400
+#: varasm.c:1411
 #, gcc-internal-format
 msgid "register specified for %q+D isn%'t suitable for data type"
 msgstr ""
 
-#: varasm.c:1410
+#: varasm.c:1421
 #, gcc-internal-format
 msgid "global register variable has initial value"
 msgstr ""
 
-#: varasm.c:1414
+#: varasm.c:1425
 #, gcc-internal-format
 msgid "optimization may eliminate reads and/or writes to register variables"
 msgstr ""
 
-#: varasm.c:1460
+#: varasm.c:1471
 #, gcc-internal-format
 msgid "register name given for non-register variable %q+D"
 msgstr ""
 
-#: varasm.c:1870
+#: varasm.c:1881
 #, gcc-internal-format
 msgid "Patchable function entry > size"
 msgstr ""
 
-#: varasm.c:2069
+#: varasm.c:2080
 #, gcc-internal-format
 msgid "thread-local COMMON data not implemented"
 msgstr ""
 
-#: varasm.c:2102
+#: varasm.c:2113
 #, gcc-internal-format
 msgid "requested alignment for %q+D is greater than implemented alignment of %wu"
 msgstr ""
 
-#: varasm.c:2205 c/c-decl.c:5027 c/c-parser.c:1534
+#: varasm.c:2216 c/c-decl.c:5027 c/c-parser.c:1534
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t known"
 msgstr ""
 
-#: varasm.c:4910
+#: varasm.c:4921
 #, gcc-internal-format
 msgid "initializer for integer/fixed-point value is too complicated"
 msgstr ""
 
-#: varasm.c:4915
+#: varasm.c:4926
 #, gcc-internal-format
 msgid "initializer for floating value is not a floating constant"
 msgstr ""
 
-#: varasm.c:5227
+#: varasm.c:5238
 #, gcc-internal-format
 msgid "invalid initial value for member %qE"
 msgstr ""
 
-#: varasm.c:5487
+#: varasm.c:5498
 #, gcc-internal-format
 msgid "%+qD declared weak after being used"
 msgstr ""
 
-#: varasm.c:5539
+#: varasm.c:5550
 #, gcc-internal-format
 msgid "weak declaration of %q+D being applied to a already existing, static definition"
 msgstr ""
 
-#: varasm.c:5575
+#: varasm.c:5586
 #, gcc-internal-format
 msgid "weak declaration of %q+D must be public"
 msgstr ""
 
-#: varasm.c:5579
+#: varasm.c:5590
 #, gcc-internal-format
 msgid "weak declaration of %q+D not supported"
 msgstr ""
 
-#: varasm.c:5608 varasm.c:5912
+#: varasm.c:5619 varasm.c:5926
 #, gcc-internal-format
 msgid "only weak aliases are supported in this configuration"
 msgstr ""
 
-#: varasm.c:5802
+#: varasm.c:5813
 #, gcc-internal-format
 msgid "weakref is not supported in this configuration"
 msgstr ""
 
-#: varasm.c:5834
+#: varasm.c:5846
 #, gcc-internal-format
 msgid "ifunc is not supported on this target"
 msgstr ""
 
-#: varasm.c:5892
+#: varasm.c:5904
 #, gcc-internal-format
 msgid "weakref %q+D ultimately targets itself"
 msgstr ""
 
-#: varasm.c:5894
+#: varasm.c:5906
 #, gcc-internal-format
 msgid "weakref %q+D must have static linkage"
 msgstr ""
 
-#: varasm.c:5901
+#: varasm.c:5913
 #, gcc-internal-format
 msgid "alias definitions not supported in this configuration"
 msgstr ""
 
-#: varasm.c:5909
+#: varasm.c:5923
 #, gcc-internal-format
 msgid "ifunc is not supported in this configuration"
 msgstr ""
 
-#: varasm.c:6127 config/sol2.c:159 config/i386/winnt.c:265
+#: varasm.c:6141 config/sol2.c:159 config/i386/winnt.c:265
 #, gcc-internal-format
 msgid "visibility attribute not supported in this configuration; ignored"
 msgstr ""
@@ -23960,466 +23982,471 @@
 msgid "bytecode stream: tag %s is not in the expected range [%s, %s]"
 msgstr ""
 
-#: c-family/c-attribs.c:529
+#: c-family/c-attribs.c:524
 #, gcc-internal-format
+msgid "%qE attribute ignored for type %qT"
+msgstr ""
+
+#: c-family/c-attribs.c:536
+#, gcc-internal-format
 msgid "%qE attribute ignored for field of type %qT"
 msgstr ""
 
-#: c-family/c-attribs.c:696
+#: c-family/c-attribs.c:706
 #, gcc-internal-format
 msgid "no_sanitize argument not a string"
 msgstr ""
 
-#: c-family/c-attribs.c:826 ada/gcc-interface/utils.c:6235
+#: c-family/c-attribs.c:837 ada/gcc-interface/utils.c:6240
 #, gcc-internal-format
 msgid "%qE attribute ignored due to conflict with attribute %qs"
 msgstr ""
 
-#: c-family/c-attribs.c:875
+#: c-family/c-attribs.c:886
 #, gcc-internal-format
 msgid "%qE attribute ignored. Use -fcf-protection option to enable it"
 msgstr ""
 
-#: c-family/c-attribs.c:914 c-family/c-attribs.c:920 c-family/c-attribs.c:3388
-#: c-family/c-attribs.c:3423 c-family/c-attribs.c:3429
+#: c-family/c-attribs.c:925 c-family/c-attribs.c:931 c-family/c-attribs.c:3399
+#: c-family/c-attribs.c:3434 c-family/c-attribs.c:3440
 #, gcc-internal-format
 msgid "%qE attribute ignored due to conflict with %qs attribute"
 msgstr ""
 
-#: c-family/c-attribs.c:976 brig/brig-lang.c:482 lto/lto-lang.c:288
+#: c-family/c-attribs.c:987 brig/brig-lang.c:482 lto/lto-lang.c:288
 #, gcc-internal-format
 msgid "%qE attribute has no effect on unit local functions"
 msgstr ""
 
-#: c-family/c-attribs.c:1130
+#: c-family/c-attribs.c:1141
 #, gcc-internal-format
 msgid "%qE attribute have effect only on public objects"
 msgstr ""
 
-#: c-family/c-attribs.c:1159
+#: c-family/c-attribs.c:1170
 #, gcc-internal-format
 msgid "%qE attribute only affects top level objects"
 msgstr ""
 
-#: c-family/c-attribs.c:1198 c-family/c-attribs.c:2682
+#: c-family/c-attribs.c:1209 c-family/c-attribs.c:2693
 #, gcc-internal-format
 msgid "%qE attribute on function returning %<void%>"
 msgstr ""
 
-#: c-family/c-attribs.c:1221 c-family/c-pragma.c:419
+#: c-family/c-attribs.c:1232 c-family/c-pragma.c:419
 #, gcc-internal-format
 msgid "scalar_storage_order is not supported because endianness is not uniform"
 msgstr ""
 
-#: c-family/c-attribs.c:1238
+#: c-family/c-attribs.c:1249
 #, gcc-internal-format
 msgid "scalar_storage_order argument must be one of \"big-endian\" or \"little-endian\""
 msgstr ""
 
-#: c-family/c-attribs.c:1334
+#: c-family/c-attribs.c:1345
 #, gcc-internal-format
 msgid "destructor priorities are not supported"
 msgstr ""
 
-#: c-family/c-attribs.c:1336
+#: c-family/c-attribs.c:1347
 #, gcc-internal-format
 msgid "constructor priorities are not supported"
 msgstr ""
 
-#: c-family/c-attribs.c:1358
+#: c-family/c-attribs.c:1369
 #, gcc-internal-format, gfc-internal-format
 msgid "destructor priorities from 0 to %d are reserved for the implementation"
 msgstr ""
 
-#: c-family/c-attribs.c:1363
+#: c-family/c-attribs.c:1374
 #, gcc-internal-format, gfc-internal-format
 msgid "constructor priorities from 0 to %d are reserved for the implementation"
 msgstr ""
 
-#: c-family/c-attribs.c:1371
+#: c-family/c-attribs.c:1382
 #, gcc-internal-format, gfc-internal-format
 msgid "destructor priorities must be integers from 0 to %d inclusive"
 msgstr ""
 
-#: c-family/c-attribs.c:1374
+#: c-family/c-attribs.c:1385
 #, gcc-internal-format, gfc-internal-format
 msgid "constructor priorities must be integers from 0 to %d inclusive"
 msgstr ""
 
-#: c-family/c-attribs.c:1527
+#: c-family/c-attribs.c:1538
 #, gcc-internal-format
 msgid "unknown machine mode %qE"
 msgstr ""
 
-#: c-family/c-attribs.c:1557
+#: c-family/c-attribs.c:1568
 #, gcc-internal-format
 msgid "specifying vector types with __attribute__ ((mode)) is deprecated"
 msgstr ""
 
-#: c-family/c-attribs.c:1560
+#: c-family/c-attribs.c:1571
 #, gcc-internal-format
 msgid "use __attribute__ ((vector_size)) instead"
 msgstr ""
 
-#: c-family/c-attribs.c:1569
+#: c-family/c-attribs.c:1580
 #, gcc-internal-format
 msgid "unable to emulate %qs"
 msgstr ""
 
-#: c-family/c-attribs.c:1582
+#: c-family/c-attribs.c:1593
 #, gcc-internal-format
 msgid "invalid pointer mode %qs"
 msgstr ""
 
-#: c-family/c-attribs.c:1599
+#: c-family/c-attribs.c:1610
 #, gcc-internal-format
 msgid "signedness of type and machine mode %qs don%'t match"
 msgstr ""
 
-#: c-family/c-attribs.c:1610
+#: c-family/c-attribs.c:1621
 #, gcc-internal-format
 msgid "no data type for mode %qs"
 msgstr ""
 
-#: c-family/c-attribs.c:1620
+#: c-family/c-attribs.c:1631
 #, gcc-internal-format
 msgid "cannot use mode %qs for enumeral types"
 msgstr ""
 
-#: c-family/c-attribs.c:1647
+#: c-family/c-attribs.c:1658
 #, gcc-internal-format
 msgid "mode %qs applied to inappropriate type"
 msgstr ""
 
-#: c-family/c-attribs.c:1669
+#: c-family/c-attribs.c:1680
 #, gcc-internal-format
 msgid "section attributes are not supported for this target"
 msgstr ""
 
-#: c-family/c-attribs.c:1675
+#: c-family/c-attribs.c:1686
 #, gcc-internal-format
 msgid "section attribute not allowed for %q+D"
 msgstr ""
 
-#: c-family/c-attribs.c:1681
+#: c-family/c-attribs.c:1692
 #, gcc-internal-format
 msgid "section attribute argument not a string constant"
 msgstr ""
 
-#: c-family/c-attribs.c:1690
+#: c-family/c-attribs.c:1701
 #, gcc-internal-format
 msgid "section attribute cannot be specified for local variables"
 msgstr ""
 
-#: c-family/c-attribs.c:1700 config/bfin/bfin.c:4806 config/bfin/bfin.c:4857
+#: c-family/c-attribs.c:1711 config/bfin/bfin.c:4806 config/bfin/bfin.c:4857
 #: config/bfin/bfin.c:4883 config/bfin/bfin.c:4896
 #, gcc-internal-format
 msgid "section of %q+D conflicts with previous declaration"
 msgstr ""
 
-#: c-family/c-attribs.c:1708
+#: c-family/c-attribs.c:1719
 #, gcc-internal-format
 msgid "section of %q+D cannot be overridden"
 msgstr ""
 
-#: c-family/c-attribs.c:1773
+#: c-family/c-attribs.c:1784
 #, gcc-internal-format, gfc-internal-format
 msgid "requested alignment %d is larger than %d"
 msgstr ""
 
-#: c-family/c-attribs.c:1866
+#: c-family/c-attribs.c:1877
 #, gcc-internal-format
 msgid "alignment may not be specified for %q+D"
 msgstr ""
 
-#: c-family/c-attribs.c:1886
+#: c-family/c-attribs.c:1897
 #, gcc-internal-format
 msgid "ignoring attribute %<%E (%u)%> because it conflicts with attribute %<%E (%u)%>"
 msgstr ""
 
 #. Do not error out for attribute warn_if_not_aligned.
-#: c-family/c-attribs.c:1891 c-family/c-attribs.c:1920
+#: c-family/c-attribs.c:1902 c-family/c-attribs.c:1931
 #, gcc-internal-format
 msgid "alignment for %q+D must be at least %d"
 msgstr ""
 
-#: c-family/c-attribs.c:1916
+#: c-family/c-attribs.c:1927
 #, gcc-internal-format
 msgid "alignment for %q+D was previously specified as %d and may not be decreased"
 msgstr ""
 
-#: c-family/c-attribs.c:1943
+#: c-family/c-attribs.c:1954
 #, gcc-internal-format
 msgid "%<warn_if_not_aligned%> may not be specified for %q+D"
 msgstr ""
 
-#: c-family/c-attribs.c:1986
+#: c-family/c-attribs.c:1997
 #, gcc-internal-format
 msgid "inline function %q+D declared weak"
 msgstr ""
 
-#: c-family/c-attribs.c:1991
+#: c-family/c-attribs.c:2002
 #, gcc-internal-format
 msgid "indirect function %q+D cannot be declared weak"
 msgstr ""
 
-#: c-family/c-attribs.c:2015
+#: c-family/c-attribs.c:2026
 #, gcc-internal-format
 msgid "%qE attribute is only applicable on functions"
 msgstr ""
 
-#: c-family/c-attribs.c:2046
+#: c-family/c-attribs.c:2057
 #, gcc-internal-format
 msgid "%q+D defined both normally and as %qE attribute"
 msgstr ""
 
-#: c-family/c-attribs.c:2054
+#: c-family/c-attribs.c:2065
 #, gcc-internal-format
 msgid "weak %q+D cannot be defined %qE"
 msgstr ""
 
-#: c-family/c-attribs.c:2071 c-family/c-attribs.c:2582
+#: c-family/c-attribs.c:2082 c-family/c-attribs.c:2593
 #, gcc-internal-format
 msgid "attribute %qE argument not a string"
 msgstr ""
 
-#: c-family/c-attribs.c:2106
+#: c-family/c-attribs.c:2117
 #, gcc-internal-format
 msgid "%+qD declared alias after being used"
 msgstr ""
 
-#: c-family/c-attribs.c:2108
+#: c-family/c-attribs.c:2119
 #, gcc-internal-format
 msgid "%+qD declared ifunc after being used"
 msgstr ""
 
-#: c-family/c-attribs.c:2159
+#: c-family/c-attribs.c:2170
 #, gcc-internal-format
 msgid "indirect function %q+D cannot be declared weakref"
 msgstr ""
 
-#: c-family/c-attribs.c:2181
+#: c-family/c-attribs.c:2192
 #, gcc-internal-format
 msgid "weakref attribute must appear before alias attribute"
 msgstr ""
 
-#: c-family/c-attribs.c:2193
+#: c-family/c-attribs.c:2204
 #, gcc-internal-format
 msgid "%+qD declared weakref after being used"
 msgstr ""
 
-#: c-family/c-attribs.c:2217
+#: c-family/c-attribs.c:2228
 #, gcc-internal-format
 msgid "%qE attribute ignored on non-class types"
 msgstr ""
 
-#: c-family/c-attribs.c:2223
+#: c-family/c-attribs.c:2234
 #, gcc-internal-format
 msgid "%qE attribute ignored because %qT is already defined"
 msgstr ""
 
-#: c-family/c-attribs.c:2236
+#: c-family/c-attribs.c:2247
 #, gcc-internal-format
 msgid "visibility argument not a string"
 msgstr ""
 
-#: c-family/c-attribs.c:2248
+#: c-family/c-attribs.c:2259
 #, gcc-internal-format
 msgid "%qE attribute ignored on types"
 msgstr ""
 
-#: c-family/c-attribs.c:2264
+#: c-family/c-attribs.c:2275
 #, gcc-internal-format
 msgid "visibility argument must be one of \"default\", \"hidden\", \"protected\" or \"internal\""
 msgstr ""
 
-#: c-family/c-attribs.c:2275
+#: c-family/c-attribs.c:2286
 #, gcc-internal-format
 msgid "%qD redeclared with different visibility"
 msgstr ""
 
-#: c-family/c-attribs.c:2278 c-family/c-attribs.c:2282
+#: c-family/c-attribs.c:2289 c-family/c-attribs.c:2293
 #, gcc-internal-format
 msgid "%qD was declared %qs which implies default visibility"
 msgstr ""
 
-#: c-family/c-attribs.c:2320
+#: c-family/c-attribs.c:2331
 #, gcc-internal-format
 msgid "tls_model argument not a string"
 msgstr ""
 
-#: c-family/c-attribs.c:2333
+#: c-family/c-attribs.c:2344
 #, gcc-internal-format
 msgid "tls_model argument must be one of \"local-exec\", \"initial-exec\", \"local-dynamic\" or \"global-dynamic\""
 msgstr ""
 
-#: c-family/c-attribs.c:2353 c-family/c-attribs.c:2656
-#: c-family/c-attribs.c:3497 config/m32c/m32c.c:2944
+#: c-family/c-attribs.c:2364 c-family/c-attribs.c:2667
+#: c-family/c-attribs.c:3508 config/m32c/m32c.c:2944
 #, gcc-internal-format
 msgid "%qE attribute applies only to functions"
 msgstr ""
 
-#: c-family/c-attribs.c:2417
+#: c-family/c-attribs.c:2428
 #, gcc-internal-format
 msgid "alloc_size parameter outside range"
 msgstr ""
 
-#: c-family/c-attribs.c:2443
+#: c-family/c-attribs.c:2454
 #, gcc-internal-format
 msgid "alloc_align parameter outside range"
 msgstr ""
 
-#: c-family/c-attribs.c:2467
+#: c-family/c-attribs.c:2478
 #, gcc-internal-format
 msgid "assume_aligned parameter not integer constant"
 msgstr ""
 
-#: c-family/c-attribs.c:2595
+#: c-family/c-attribs.c:2606
 #, gcc-internal-format
 msgid "only %<inbranch%> and %<notinbranch%> flags are allowed for %<__simd__%> attribute"
 msgstr ""
 
-#: c-family/c-attribs.c:2662 c-family/c-attribs.c:3503
+#: c-family/c-attribs.c:2673 c-family/c-attribs.c:3514
 #, gcc-internal-format
 msgid "can%'t set %qE attribute after definition"
 msgstr ""
 
-#: c-family/c-attribs.c:2727
+#: c-family/c-attribs.c:2738
 #, gcc-internal-format
 msgid "%qE attribute duplicated"
 msgstr ""
 
-#: c-family/c-attribs.c:2729
+#: c-family/c-attribs.c:2740
 #, gcc-internal-format
 msgid "%qE attribute follows %qE"
 msgstr ""
 
-#: c-family/c-attribs.c:2828
+#: c-family/c-attribs.c:2839
 #, gcc-internal-format
 msgid "type was previously declared %qE"
 msgstr ""
 
-#: c-family/c-attribs.c:2841 cp/class.c:4397
+#: c-family/c-attribs.c:2852 cp/class.c:4401
 #, gcc-internal-format
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
 msgstr ""
 
-#: c-family/c-attribs.c:2899
+#: c-family/c-attribs.c:2910
 #, gcc-internal-format
 msgid "%qE argument not an identifier"
 msgstr ""
 
-#: c-family/c-attribs.c:2910
+#: c-family/c-attribs.c:2921
 #, gcc-internal-format
 msgid "%qD is not compatible with %qD"
 msgstr ""
 
-#: c-family/c-attribs.c:2913
+#: c-family/c-attribs.c:2924
 #, gcc-internal-format
 msgid "%qE argument is not a function"
 msgstr ""
 
-#: c-family/c-attribs.c:2961
+#: c-family/c-attribs.c:2972
 #, gcc-internal-format
 msgid "deprecated message is not a string"
 msgstr ""
 
-#: c-family/c-attribs.c:3002
+#: c-family/c-attribs.c:3013
 #, gcc-internal-format
 msgid "%qE attribute ignored for %qE"
 msgstr ""
 
-#: c-family/c-attribs.c:3065
+#: c-family/c-attribs.c:3076
 #, gcc-internal-format
 msgid "invalid vector type for attribute %qE"
 msgstr ""
 
-#: c-family/c-attribs.c:3071 ada/gcc-interface/utils.c:3896
+#: c-family/c-attribs.c:3082 ada/gcc-interface/utils.c:3899
 #, gcc-internal-format
 msgid "vector size not an integral multiple of component size"
 msgstr ""
 
-#: c-family/c-attribs.c:3077 ada/gcc-interface/utils.c:3903
+#: c-family/c-attribs.c:3088 ada/gcc-interface/utils.c:3906
 #, gcc-internal-format
 msgid "zero vector size"
 msgstr ""
 
-#: c-family/c-attribs.c:3085
+#: c-family/c-attribs.c:3096
 #, gcc-internal-format
 msgid "number of components of the vector not a power of two"
 msgstr ""
 
-#: c-family/c-attribs.c:3118 ada/gcc-interface/utils.c:6092
+#: c-family/c-attribs.c:3129 ada/gcc-interface/utils.c:6098
 #, gcc-internal-format
 msgid "nonnull attribute without arguments on a non-prototype"
 msgstr ""
 
-#: c-family/c-attribs.c:3137 ada/gcc-interface/utils.c:6106
+#: c-family/c-attribs.c:3148 ada/gcc-interface/utils.c:6112
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument has invalid operand number (argument %lu)"
 msgstr ""
 
-#: c-family/c-attribs.c:3159 ada/gcc-interface/utils.c:6128
+#: c-family/c-attribs.c:3170 ada/gcc-interface/utils.c:6134
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument with out-of-range operand number (argument %lu, operand %lu)"
 msgstr ""
 
-#: c-family/c-attribs.c:3168 ada/gcc-interface/utils.c:6137
+#: c-family/c-attribs.c:3179 ada/gcc-interface/utils.c:6143
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument references non-pointer operand (argument %lu, operand %lu)"
 msgstr ""
 
-#: c-family/c-attribs.c:3208
+#: c-family/c-attribs.c:3219
 #, gcc-internal-format
 msgid "%qE attribute ignored on objects of type %qT"
 msgstr ""
 
-#: c-family/c-attribs.c:3216
+#: c-family/c-attribs.c:3227
 #, gcc-internal-format
 msgid "%qE attribute does not apply to functions"
 msgstr ""
 
-#: c-family/c-attribs.c:3273
+#: c-family/c-attribs.c:3284
 #, gcc-internal-format
 msgid "cleanup argument not an identifier"
 msgstr ""
 
-#: c-family/c-attribs.c:3280
+#: c-family/c-attribs.c:3291
 #, gcc-internal-format
 msgid "cleanup argument not a function"
 msgstr ""
 
-#: c-family/c-attribs.c:3317
+#: c-family/c-attribs.c:3328
 #, gcc-internal-format
 msgid "%qE attribute requires prototypes with named arguments"
 msgstr ""
 
-#: c-family/c-attribs.c:3325
+#: c-family/c-attribs.c:3336
 #, gcc-internal-format
 msgid "%qE attribute only applies to variadic functions"
 msgstr ""
 
-#: c-family/c-attribs.c:3341 ada/gcc-interface/utils.c:6179
+#: c-family/c-attribs.c:3352 ada/gcc-interface/utils.c:6185
 #, gcc-internal-format
 msgid "requested position is not an integer constant"
 msgstr ""
 
-#: c-family/c-attribs.c:3349 ada/gcc-interface/utils.c:6186
+#: c-family/c-attribs.c:3360 ada/gcc-interface/utils.c:6192
 #, gcc-internal-format
 msgid "requested position is less than zero"
 msgstr ""
 
-#: c-family/c-attribs.c:3404
+#: c-family/c-attribs.c:3415
 #, gcc-internal-format
 msgid "empty string in attribute %<target%>"
 msgstr ""
 
-#: c-family/c-attribs.c:3520
+#: c-family/c-attribs.c:3531
 #, gcc-internal-format
 msgid "returns_nonnull attribute on a function not returning a pointer"
 msgstr ""
 
-#: c-family/c-attribs.c:3535
+#: c-family/c-attribs.c:3546
 #, gcc-internal-format
 msgid "%qE attribute is only valid on %<struct%> type"
 msgstr ""
@@ -24464,12 +24491,12 @@
 msgid "__builtin_shuffle argument vector(s) inner type must have the same size as inner type of the mask"
 msgstr ""
 
-#: c-family/c-common.c:1262 c-family/c-warn.c:1194
+#: c-family/c-common.c:1262 c-family/c-warn.c:1202
 #, gcc-internal-format
 msgid "unsigned conversion from %qT to %qT changes value from %qE to %qE"
 msgstr ""
 
-#: c-family/c-common.c:1267 c-family/c-warn.c:1202
+#: c-family/c-common.c:1267 c-family/c-warn.c:1210
 #, gcc-internal-format
 msgid "unsigned conversion from %qT to %qT changes the value of %qE"
 msgstr ""
@@ -24599,7 +24626,7 @@
 msgid "suggest parentheses around assignment used as truth value"
 msgstr ""
 
-#: c-family/c-common.c:3518 c/c-decl.c:4325 c/c-decl.c:6430 c/c-typeck.c:14177
+#: c-family/c-common.c:3518 c/c-decl.c:4325 c/c-decl.c:6450 c/c-typeck.c:14182
 #, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr ""
@@ -24679,7 +24706,7 @@
 msgid "duplicate case value"
 msgstr ""
 
-#: c-family/c-common.c:4867 c-family/c-warn.c:2216
+#: c-family/c-common.c:4867 c-family/c-warn.c:2225
 #, gcc-internal-format
 msgid "previously used here"
 msgstr ""
@@ -24724,193 +24751,193 @@
 msgid "missing sentinel in function call"
 msgstr ""
 
-#: c-family/c-common.c:5411
+#: c-family/c-common.c:5409
 #, gcc-internal-format, gfc-internal-format
 msgid "null argument where non-null required (argument %lu)"
 msgstr ""
 
-#: c-family/c-common.c:5506 c-family/c-common.c:5553
+#: c-family/c-common.c:5504 c-family/c-common.c:5551
 #, gcc-internal-format
 msgid "bad option %qs to attribute %<optimize%>"
 msgstr ""
 
-#: c-family/c-common.c:5509 c-family/c-common.c:5557
+#: c-family/c-common.c:5507 c-family/c-common.c:5555
 #, gcc-internal-format
 msgid "bad option %qs to pragma %<optimize%>"
 msgstr ""
 
-#: c-family/c-common.c:5589
+#: c-family/c-common.c:5587
 #, gcc-internal-format
 msgid "%<fallthrough%> attribute specified multiple times"
 msgstr ""
 
-#: c-family/c-common.c:5593
+#: c-family/c-common.c:5591
 #, gcc-internal-format
 msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr ""
 
-#: c-family/c-common.c:5733 c-family/c-common.c:6485 c-family/c-common.c:6558
+#: c-family/c-common.c:5731 c-family/c-common.c:6477 c-family/c-common.c:6550
 #: c/c-typeck.c:3555
 #, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr ""
 
-#: c-family/c-common.c:5738 c-family/c-common.c:6584 c/c-typeck.c:3284
+#: c-family/c-common.c:5736 c-family/c-common.c:6576 c/c-typeck.c:3284
 #, gcc-internal-format
 msgid "too many arguments to function %qE"
 msgstr ""
 
-#: c-family/c-common.c:5769
+#: c-family/c-common.c:5767
 #, gcc-internal-format
 msgid "third argument to function %qE must be a constant integer"
 msgstr ""
 
-#: c-family/c-common.c:5794
+#: c-family/c-common.c:5792
 #, gcc-internal-format
 msgid "second argument to function %qE must be a constant integer power of 2 between %qi and %qu bits"
 msgstr ""
 
-#: c-family/c-common.c:5815 c-family/c-common.c:5859
+#: c-family/c-common.c:5813 c-family/c-common.c:5857
 #, gcc-internal-format
 msgid "non-floating-point argument in call to function %qE"
 msgstr ""
 
-#: c-family/c-common.c:5838
+#: c-family/c-common.c:5836
 #, gcc-internal-format
 msgid "non-floating-point arguments in call to function %qE"
 msgstr ""
 
-#: c-family/c-common.c:5852
+#: c-family/c-common.c:5850
 #, gcc-internal-format
 msgid "non-const integer argument %u in call to function %qE"
 msgstr ""
 
-#: c-family/c-common.c:5872
+#: c-family/c-common.c:5870
 #, gcc-internal-format
 msgid "non-integer argument 3 in call to function %qE"
 msgstr ""
 
-#: c-family/c-common.c:5889 c-family/c-common.c:5925
+#: c-family/c-common.c:5887 c-family/c-common.c:5923
 #, gcc-internal-format
 msgid "argument %u in call to function %qE does not have integral type"
 msgstr ""
 
-#: c-family/c-common.c:5896
+#: c-family/c-common.c:5894
 #, gcc-internal-format
 msgid "argument 3 in call to function %qE does not have pointer to integral type"
 msgstr ""
 
-#: c-family/c-common.c:5902
+#: c-family/c-common.c:5900
 #, gcc-internal-format
 msgid "argument 3 in call to function %qE has pointer to enumerated type"
 msgstr ""
 
-#: c-family/c-common.c:5908
+#: c-family/c-common.c:5906
 #, gcc-internal-format
 msgid "argument 3 in call to function %qE has pointer to boolean type"
 msgstr ""
 
-#: c-family/c-common.c:5931
+#: c-family/c-common.c:5929
 #, gcc-internal-format
 msgid "argument 3 in call to function %qE has enumerated type"
 msgstr ""
 
-#: c-family/c-common.c:5937
+#: c-family/c-common.c:5935
 #, gcc-internal-format
 msgid "argument 3 in call to function %qE has boolean type"
 msgstr ""
 
-#: c-family/c-common.c:6184
+#: c-family/c-common.c:6183
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to static data member %qD"
 msgstr ""
 
-#: c-family/c-common.c:6189
+#: c-family/c-common.c:6188
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> when %<operator[]%> is overloaded"
 msgstr ""
 
-#: c-family/c-common.c:6196
+#: c-family/c-common.c:6195
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to a non constant address"
 msgstr ""
 
-#: c-family/c-common.c:6209
+#: c-family/c-common.c:6208
 #, gcc-internal-format
 msgid "attempt to take address of bit-field structure member %qD"
 msgstr ""
 
-#: c-family/c-common.c:6261
+#: c-family/c-common.c:6260
 #, gcc-internal-format
 msgid "index %E denotes an offset greater than size of %qT"
 msgstr ""
 
-#: c-family/c-common.c:6427 cp/init.c:3004 cp/init.c:3023
+#: c-family/c-common.c:6419 cp/init.c:3020 cp/init.c:3039
 #, gcc-internal-format
 msgid "size of array is too large"
 msgstr ""
 
-#: c-family/c-common.c:6517
+#: c-family/c-common.c:6509
 #, gcc-internal-format
 msgid "operand type %qT is incompatible with argument %d of %qE"
 msgstr ""
 
-#: c-family/c-common.c:6651
+#: c-family/c-common.c:6643
 #, gcc-internal-format
 msgid "incorrect number of arguments to function %qE"
 msgstr ""
 
-#: c-family/c-common.c:6665
+#: c-family/c-common.c:6657
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a non-void pointer type"
 msgstr ""
 
-#: c-family/c-common.c:6674
+#: c-family/c-common.c:6666
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a constant size type"
 msgstr ""
 
-#: c-family/c-common.c:6685
+#: c-family/c-common.c:6677
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a nonzero size object"
 msgstr ""
 
-#: c-family/c-common.c:6706
+#: c-family/c-common.c:6698
 #, gcc-internal-format
 msgid "argument %d of %qE must be a pointer type"
 msgstr ""
 
-#: c-family/c-common.c:6714
+#: c-family/c-common.c:6706
 #, gcc-internal-format
 msgid "argument %d of %qE must be a pointer to a constant size type"
 msgstr ""
 
-#: c-family/c-common.c:6720
+#: c-family/c-common.c:6712
 #, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a function"
 msgstr ""
 
-#: c-family/c-common.c:6728
+#: c-family/c-common.c:6720
 #, gcc-internal-format
 msgid "size mismatch in argument %d of %qE"
 msgstr ""
 
-#: c-family/c-common.c:6740
+#: c-family/c-common.c:6732
 #, gcc-internal-format
 msgid "non-integer memory model argument %d of %qE"
 msgstr ""
 
-#: c-family/c-common.c:6753
+#: c-family/c-common.c:6745
 #, gcc-internal-format
 msgid "invalid memory model argument %d of %qE"
 msgstr ""
 
-#: c-family/c-common.c:7672
+#: c-family/c-common.c:7664
 #, gcc-internal-format
 msgid "index value is out of bound"
 msgstr ""
 
-#: c-family/c-common.c:7714 c-family/c-common.c:7763 c-family/c-common.c:7779
+#: c-family/c-common.c:7706 c-family/c-common.c:7755 c-family/c-common.c:7771
 #, gcc-internal-format
 msgid "conversion of scalar %qT to vector %qT involves truncation"
 msgstr ""
@@ -24917,22 +24944,22 @@
 
 #. Reject arguments that are built-in functions with
 #. no library fallback.
-#: c-family/c-common.c:7867
+#: c-family/c-common.c:7859
 #, gcc-internal-format
 msgid "built-in function %qE must be directly called"
 msgstr ""
 
-#: c-family/c-common.c:7889 c/c-decl.c:6177
+#: c-family/c-common.c:7881 c/c-decl.c:6197
 #, gcc-internal-format
 msgid "size of array %qE is too large"
 msgstr ""
 
-#: c-family/c-common.c:7891 c/c-decl.c:6180
+#: c-family/c-common.c:7883 c/c-decl.c:6200
 #, gcc-internal-format
 msgid "size of unnamed array is too large"
 msgstr ""
 
-#: c-family/c-common.c:7921
+#: c-family/c-common.c:7913
 #, gcc-internal-format
 msgid "environment variable SOURCE_DATE_EPOCH must expand to a non-negative integer less than or equal to %wd"
 msgstr ""
@@ -25453,7 +25480,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr ""
 
-#: c-family/c-omp.c:557 cp/semantics.c:8186
+#: c-family/c-omp.c:557 cp/semantics.c:8189
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr ""
@@ -25468,22 +25495,22 @@
 msgid "%qE is not initialized"
 msgstr ""
 
-#: c-family/c-omp.c:599 cp/semantics.c:8076
+#: c-family/c-omp.c:599 cp/semantics.c:8079
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.c:704 cp/semantics.c:7732
+#: c-family/c-omp.c:704 cp/semantics.c:7735
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.c:711 cp/semantics.c:8082
+#: c-family/c-omp.c:711 cp/semantics.c:8085
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr ""
 
-#: c-family/c-omp.c:775 cp/semantics.c:7847
+#: c-family/c-omp.c:775 cp/semantics.c:7850
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr ""
@@ -25539,112 +25566,127 @@
 msgid "%<-Wabi=1%> is not supported, using =2"
 msgstr ""
 
-#: c-family/c-opts.c:612 fortran/cpp.c:350
+#: c-family/c-opts.c:610 fortran/cpp.c:350
 #, gcc-internal-format
 msgid "output filename specified twice"
 msgstr ""
 
-#: c-family/c-opts.c:799
+#: c-family/c-opts.c:797
 #, gcc-internal-format
 msgid "-fexcess-precision=standard for C++"
 msgstr ""
 
-#: c-family/c-opts.c:834
+#: c-family/c-opts.c:832
 #, gcc-internal-format
 msgid "-fno-gnu89-inline is only supported in GNU99 or C99 mode"
 msgstr ""
 
-#: c-family/c-opts.c:880
+#: c-family/c-opts.c:878
 #, gcc-internal-format
 msgid "-Wformat-y2k ignored without -Wformat"
 msgstr ""
 
-#: c-family/c-opts.c:882
+#: c-family/c-opts.c:880
 #, gcc-internal-format
 msgid "-Wformat-extra-args ignored without -Wformat"
 msgstr ""
 
-#: c-family/c-opts.c:884
+#: c-family/c-opts.c:882
 #, gcc-internal-format
 msgid "-Wformat-zero-length ignored without -Wformat"
 msgstr ""
 
-#: c-family/c-opts.c:886
+#: c-family/c-opts.c:884
 #, gcc-internal-format
 msgid "-Wformat-nonliteral ignored without -Wformat"
 msgstr ""
 
-#: c-family/c-opts.c:888
+#: c-family/c-opts.c:886
 #, gcc-internal-format
 msgid "-Wformat-contains-nul ignored without -Wformat"
 msgstr ""
 
-#: c-family/c-opts.c:890
+#: c-family/c-opts.c:888
 #, gcc-internal-format
 msgid "-Wformat-security ignored without -Wformat"
 msgstr ""
 
-#: c-family/c-opts.c:928
+#: c-family/c-opts.c:918
 #, gcc-internal-format
 msgid "%<-fabi-compat-version=1%> is not supported, using =2"
 msgstr ""
 
-#: c-family/c-opts.c:988
+#: c-family/c-opts.c:944
 #, gcc-internal-format
+msgid "-Wabi won't warn about anything"
+msgstr ""
+
+#: c-family/c-opts.c:946
+#, gcc-internal-format
+msgid "-Wabi warns about differences from the most up-to-date ABI, which is also used by default"
+msgstr ""
+
+#: c-family/c-opts.c:949
+#, gcc-internal-format
+msgid "use e.g. -Wabi=11 to warn about changes from GCC 7"
+msgstr ""
+
+#: c-family/c-opts.c:1003
+#, gcc-internal-format
 msgid "external TLS initialization functions not supported on this target"
 msgstr ""
 
-#: c-family/c-opts.c:1001
+#: c-family/c-opts.c:1016
 #, gcc-internal-format, gfc-internal-format
 msgid "too many filenames given.  Type %s --help for usage"
 msgstr ""
 
-#: c-family/c-opts.c:1016
+#: c-family/c-opts.c:1031
 #, gcc-internal-format
 msgid "opening output file %s: %m"
 msgstr ""
 
-#: c-family/c-opts.c:1036
+#: c-family/c-opts.c:1051
 #, gcc-internal-format, gfc-internal-format
 msgid "the \"%s\" debug format cannot be used with pre-compiled headers"
 msgstr ""
 
-#: c-family/c-opts.c:1190
+#: c-family/c-opts.c:1205
 #, gcc-internal-format
 msgid "opening dependency file %s: %m"
 msgstr ""
 
-#: c-family/c-opts.c:1201
+#: c-family/c-opts.c:1216
 #, gcc-internal-format
 msgid "closing dependency file %s: %m"
 msgstr ""
 
-#: c-family/c-opts.c:1204
+#: c-family/c-opts.c:1219
 #, gcc-internal-format
 msgid "when writing output to %s: %m"
 msgstr ""
 
-#: c-family/c-opts.c:1284
+#: c-family/c-opts.c:1299
 #, gcc-internal-format
 msgid "to generate dependencies you must specify either -M or -MM"
 msgstr ""
 
-#: c-family/c-opts.c:1307
+#: c-family/c-opts.c:1322
 #, gcc-internal-format
 msgid "-MG may only be used with -M or -MM"
 msgstr ""
 
-#: c-family/c-opts.c:1340
+#: c-family/c-opts.c:1355
 #, gcc-internal-format
 msgid "-fdirectives-only is incompatible with -Wunused_macros"
 msgstr ""
 
-#: c-family/c-opts.c:1342
+#: c-family/c-opts.c:1357
 #, gcc-internal-format
 msgid "-fdirectives-only is incompatible with -traditional"
 msgstr ""
 
-#: c-family/c-opts.c:1534
+#: c-family/c-opts.c:1549
 #, gcc-internal-format
 msgid "too late for # directive to set debug directory"
 msgstr ""
@@ -26029,709 +26071,709 @@
 msgid "wrong type argument to %s"
 msgstr ""
 
-#: c-family/c-warn.c:53 c-family/c-warn.c:66 cp/constexpr.c:1847
+#: c-family/c-warn.c:54 c-family/c-warn.c:67 cp/constexpr.c:1847
 #: cp/constexpr.c:4099
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr ""
 
-#: c-family/c-warn.c:93
+#: c-family/c-warn.c:94
 #, gcc-internal-format
 msgid "integer overflow in expression %qE of type %qT results in %qE"
 msgstr ""
 
-#: c-family/c-warn.c:95
+#: c-family/c-warn.c:96
 #, gcc-internal-format
 msgid "integer overflow in expression of type %qT results in %qE"
 msgstr ""
 
-#: c-family/c-warn.c:101
+#: c-family/c-warn.c:102
 #, gcc-internal-format
 msgid "floating point overflow in expression %qE of type %qT results in %qE"
 msgstr ""
 
-#: c-family/c-warn.c:103
+#: c-family/c-warn.c:104
 #, gcc-internal-format
 msgid "floating point overflow in expression of type %qT results in %qE"
 msgstr ""
 
-#: c-family/c-warn.c:109
+#: c-family/c-warn.c:110
 #, gcc-internal-format
 msgid "fixed-point overflow in expression %qE of type %qT results in %qE"
 msgstr ""
 
-#: c-family/c-warn.c:111
+#: c-family/c-warn.c:112
 #, gcc-internal-format
 msgid "fixed-point overflow in expression of type %qT results in %qE"
 msgstr ""
 
-#: c-family/c-warn.c:117
+#: c-family/c-warn.c:118
 #, gcc-internal-format
 msgid "vector overflow in expression %qE of type %qT results in %qE"
 msgstr ""
 
-#: c-family/c-warn.c:119
+#: c-family/c-warn.c:120
 #, gcc-internal-format
 msgid "vector overflow in expression of type %qT results in %qE"
 msgstr ""
 
-#: c-family/c-warn.c:126
+#: c-family/c-warn.c:127
 #, gcc-internal-format
 msgid "complex integer overflow in expression %qE of type %qT results in %qE"
 msgstr ""
 
-#: c-family/c-warn.c:128
+#: c-family/c-warn.c:129
 #, gcc-internal-format
 msgid "complex integer overflow in expression of type %qT results in %qE"
 msgstr ""
 
-#: c-family/c-warn.c:132
+#: c-family/c-warn.c:133
 #, gcc-internal-format
 msgid "complex floating point overflow in expression %qE of type %qT results in %qE"
 msgstr ""
 
-#: c-family/c-warn.c:134
+#: c-family/c-warn.c:135
 #, gcc-internal-format
 msgid "complex floating point overflow in expression of type %qT results in %qE"
 msgstr ""
 
-#: c-family/c-warn.c:216
+#: c-family/c-warn.c:217
 #, gcc-internal-format
 msgid "logical %<or%> applied to non-boolean constant"
 msgstr ""
 
-#: c-family/c-warn.c:219
+#: c-family/c-warn.c:220
 #, gcc-internal-format
 msgid "logical %<and%> applied to non-boolean constant"
 msgstr ""
 
-#: c-family/c-warn.c:289
+#: c-family/c-warn.c:290
 #, gcc-internal-format
 msgid "logical %<or%> of collectively exhaustive tests is always true"
 msgstr ""
 
-#: c-family/c-warn.c:293
+#: c-family/c-warn.c:294
 #, gcc-internal-format
 msgid "logical %<and%> of mutually exclusive tests is always false"
 msgstr ""
 
-#: c-family/c-warn.c:303
+#: c-family/c-warn.c:304
 #, gcc-internal-format
 msgid "logical %<or%> of equal expressions"
 msgstr ""
 
-#: c-family/c-warn.c:306
+#: c-family/c-warn.c:307
 #, gcc-internal-format
 msgid "logical %<and%> of equal expressions"
 msgstr ""
 
-#: c-family/c-warn.c:384
+#: c-family/c-warn.c:385
 #, gcc-internal-format
 msgid "bitwise comparison always evaluates to false"
 msgstr ""
 
-#: c-family/c-warn.c:387
+#: c-family/c-warn.c:388
 #, gcc-internal-format
 msgid "bitwise comparison always evaluates to true"
 msgstr ""
 
-#: c-family/c-warn.c:441
+#: c-family/c-warn.c:442
 #, gcc-internal-format
 msgid "self-comparison always evaluates to true"
 msgstr ""
 
-#: c-family/c-warn.c:444
+#: c-family/c-warn.c:445
 #, gcc-internal-format
 msgid "self-comparison always evaluates to false"
 msgstr ""
 
-#: c-family/c-warn.c:494
+#: c-family/c-warn.c:495
 #, gcc-internal-format
 msgid "logical not is only applied to the left hand side of comparison"
 msgstr ""
 
-#: c-family/c-warn.c:502
+#: c-family/c-warn.c:503
 #, gcc-internal-format
 msgid "add parentheses around left hand side expression to silence this warning"
 msgstr ""
 
-#: c-family/c-warn.c:636
+#: c-family/c-warn.c:637
 #, gcc-internal-format
 msgid "type-punning to incomplete type might break strict-aliasing rules"
 msgstr ""
 
-#: c-family/c-warn.c:654
+#: c-family/c-warn.c:655
 #, gcc-internal-format
 msgid "dereferencing type-punned pointer will break strict-aliasing rules"
 msgstr ""
 
-#: c-family/c-warn.c:662 c-family/c-warn.c:680
+#: c-family/c-warn.c:663 c-family/c-warn.c:681
 #, gcc-internal-format
 msgid "dereferencing type-punned pointer might break strict-aliasing rules"
 msgstr ""
 
-#: c-family/c-warn.c:803
+#: c-family/c-warn.c:811
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to use the size of the destination?"
 msgstr ""
 
-#: c-family/c-warn.c:834
+#: c-family/c-warn.c:842
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the destination; did you mean to remove the addressof?"
 msgstr ""
 
-#: c-family/c-warn.c:841
+#: c-family/c-warn.c:849
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the destination; did you mean to provide an explicit length?"
 msgstr ""
 
-#: c-family/c-warn.c:846
+#: c-family/c-warn.c:854
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the destination; did you mean to dereference it?"
 msgstr ""
 
-#: c-family/c-warn.c:858
+#: c-family/c-warn.c:866
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the destination; expected %qT or an explicit length"
 msgstr ""
 
-#: c-family/c-warn.c:874
+#: c-family/c-warn.c:882
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to remove the addressof?"
 msgstr ""
 
-#: c-family/c-warn.c:881
+#: c-family/c-warn.c:889
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to provide an explicit length?"
 msgstr ""
 
-#: c-family/c-warn.c:886
+#: c-family/c-warn.c:894
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to dereference it?"
 msgstr ""
 
-#: c-family/c-warn.c:898
+#: c-family/c-warn.c:906
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the source; expected %qT or an explicit length"
 msgstr ""
 
-#: c-family/c-warn.c:914
+#: c-family/c-warn.c:922
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the first source; did you mean to remove the addressof?"
 msgstr ""
 
-#: c-family/c-warn.c:921
+#: c-family/c-warn.c:929
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the first source; did you mean to provide an explicit length?"
 msgstr ""
 
-#: c-family/c-warn.c:926
+#: c-family/c-warn.c:934
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the first source; did you mean to dereference it?"
 msgstr ""
 
-#: c-family/c-warn.c:938
+#: c-family/c-warn.c:946
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the first source; expected %qT or an explicit length"
 msgstr ""
 
-#: c-family/c-warn.c:954
+#: c-family/c-warn.c:962
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the second source; did you mean to remove the addressof?"
 msgstr ""
 
-#: c-family/c-warn.c:961
+#: c-family/c-warn.c:969
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the second source; did you mean to provide an explicit length?"
 msgstr ""
 
-#: c-family/c-warn.c:966
+#: c-family/c-warn.c:974
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the second source; did you mean to dereference it?"
 msgstr ""
 
-#: c-family/c-warn.c:978
+#: c-family/c-warn.c:986
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the second source; expected %qT or an explicit length"
 msgstr ""
 
-#: c-family/c-warn.c:1007 c-family/c-warn.c:1014
+#: c-family/c-warn.c:1015 c-family/c-warn.c:1022
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified parameter type %qT of %q+D"
 msgstr ""
 
-#: c-family/c-warn.c:1024
+#: c-family/c-warn.c:1032
 #, gcc-internal-format
 msgid "first argument of %q+D should be %<int%>"
 msgstr ""
 
-#: c-family/c-warn.c:1033
+#: c-family/c-warn.c:1041
 #, gcc-internal-format
 msgid "second argument of %q+D should be %<char **%>"
 msgstr ""
 
-#: c-family/c-warn.c:1042
+#: c-family/c-warn.c:1050
 #, gcc-internal-format
 msgid "third argument of %q+D should probably be %<char **%>"
 msgstr ""
 
-#: c-family/c-warn.c:1053
+#: c-family/c-warn.c:1061
 #, gcc-internal-format
 msgid "%q+D takes only zero or two arguments"
 msgstr ""
 
-#: c-family/c-warn.c:1057
+#: c-family/c-warn.c:1065
 #, gcc-internal-format
 msgid "%q+D declared as variadic function"
 msgstr ""
 
-#: c-family/c-warn.c:1099
+#: c-family/c-warn.c:1107
 #, gcc-internal-format
 msgid "conversion to %qT from boolean expression"
 msgstr ""
 
-#: c-family/c-warn.c:1117 c-family/c-warn.c:1192
+#: c-family/c-warn.c:1125 c-family/c-warn.c:1200
 #, gcc-internal-format
 msgid "conversion from %qT to %qT changes value from %qE to %qE"
 msgstr ""
 
-#: c-family/c-warn.c:1121 c-family/c-warn.c:1200
+#: c-family/c-warn.c:1129 c-family/c-warn.c:1208
 #, gcc-internal-format
 msgid "conversion from %qT to %qT changes the value of %qE"
 msgstr ""
 
-#: c-family/c-warn.c:1141
+#: c-family/c-warn.c:1149
 #, gcc-internal-format
 msgid "conversion from %qT to %qT discards imaginary component"
 msgstr ""
 
-#: c-family/c-warn.c:1153
+#: c-family/c-warn.c:1161
 #, gcc-internal-format
 msgid "conversion from %qT to %qT may change value"
 msgstr ""
 
-#: c-family/c-warn.c:1213 c-family/c-warn.c:1230 c-family/c-warn.c:1247
+#: c-family/c-warn.c:1221 c-family/c-warn.c:1238 c-family/c-warn.c:1255
 #, gcc-internal-format
 msgid "overflow in conversion from %qT to %qT changes value from %qE to %qE"
 msgstr ""
 
-#: c-family/c-warn.c:1218 c-family/c-warn.c:1235 c-family/c-warn.c:1252
+#: c-family/c-warn.c:1226 c-family/c-warn.c:1243 c-family/c-warn.c:1260
 #, gcc-internal-format
 msgid "overflow in conversion from %qT to %qT changes the value of %qE"
 msgstr ""
 
-#: c-family/c-warn.c:1282
+#: c-family/c-warn.c:1290
 #, gcc-internal-format
 msgid "case value %qs not in enumerated type"
 msgstr ""
 
-#: c-family/c-warn.c:1287
+#: c-family/c-warn.c:1295
 #, gcc-internal-format
 msgid "case value %qs not in enumerated type %qT"
 msgstr ""
 
-#: c-family/c-warn.c:1348
+#: c-family/c-warn.c:1356
 #, gcc-internal-format
 msgid "switch missing default case"
 msgstr ""
 
-#: c-family/c-warn.c:1393
+#: c-family/c-warn.c:1401
 #, gcc-internal-format
 msgid "switch condition has boolean value"
 msgstr ""
 
-#: c-family/c-warn.c:1466
+#: c-family/c-warn.c:1474
 #, gcc-internal-format
 msgid "enumeration value %qE not handled in switch"
 msgstr ""
 
-#: c-family/c-warn.c:1494
+#: c-family/c-warn.c:1502
 #, gcc-internal-format
 msgid "the omitted middle operand in ?: will always be %<true%>, suggest explicit middle operand"
 msgstr ""
 
-#: c-family/c-warn.c:1515
+#: c-family/c-warn.c:1523
 #, gcc-internal-format
 msgid "assignment of member %qD in read-only object"
 msgstr ""
 
-#: c-family/c-warn.c:1517
+#: c-family/c-warn.c:1525
 #, gcc-internal-format
 msgid "increment of member %qD in read-only object"
 msgstr ""
 
-#: c-family/c-warn.c:1519
+#: c-family/c-warn.c:1527
 #, gcc-internal-format
 msgid "decrement of member %qD in read-only object"
 msgstr ""
 
-#: c-family/c-warn.c:1521
+#: c-family/c-warn.c:1529
 #, gcc-internal-format
 msgid "member %qD in read-only object used as %<asm%> output"
 msgstr ""
 
-#: c-family/c-warn.c:1525
+#: c-family/c-warn.c:1533
 #, gcc-internal-format
 msgid "assignment of read-only member %qD"
 msgstr ""
 
-#: c-family/c-warn.c:1526
+#: c-family/c-warn.c:1534
 #, gcc-internal-format
 msgid "increment of read-only member %qD"
 msgstr ""
 
-#: c-family/c-warn.c:1527
+#: c-family/c-warn.c:1535
 #, gcc-internal-format
 msgid "decrement of read-only member %qD"
 msgstr ""
 
-#: c-family/c-warn.c:1528
+#: c-family/c-warn.c:1536
 #, gcc-internal-format
 msgid "read-only member %qD used as %<asm%> output"
 msgstr ""
 
-#: c-family/c-warn.c:1532
+#: c-family/c-warn.c:1540
 #, gcc-internal-format
 msgid "assignment of read-only variable %qD"
 msgstr ""
 
-#: c-family/c-warn.c:1533
+#: c-family/c-warn.c:1541
 #, gcc-internal-format
 msgid "increment of read-only variable %qD"
 msgstr ""
 
-#: c-family/c-warn.c:1534
+#: c-family/c-warn.c:1542
 #, gcc-internal-format
 msgid "decrement of read-only variable %qD"
 msgstr ""
 
-#: c-family/c-warn.c:1535
+#: c-family/c-warn.c:1543
 #, gcc-internal-format
 msgid "read-only variable %qD used as %<asm%> output"
 msgstr ""
 
-#: c-family/c-warn.c:1538
+#: c-family/c-warn.c:1546
 #, gcc-internal-format
 msgid "assignment of read-only parameter %qD"
 msgstr ""
 
-#: c-family/c-warn.c:1539
+#: c-family/c-warn.c:1547
 #, gcc-internal-format
 msgid "increment of read-only parameter %qD"
 msgstr ""
 
-#: c-family/c-warn.c:1540
+#: c-family/c-warn.c:1548
 #, gcc-internal-format
 msgid "decrement of read-only parameter %qD"
 msgstr ""
 
-#: c-family/c-warn.c:1541
+#: c-family/c-warn.c:1549
 #, gcc-internal-format
 msgid "read-only parameter %qD use as %<asm%> output"
 msgstr ""
 
-#: c-family/c-warn.c:1546
+#: c-family/c-warn.c:1554
 #, gcc-internal-format
 msgid "assignment of read-only named return value %qD"
 msgstr ""
 
-#: c-family/c-warn.c:1548
+#: c-family/c-warn.c:1556
 #, gcc-internal-format
 msgid "increment of read-only named return value %qD"
 msgstr ""
 
-#: c-family/c-warn.c:1550
+#: c-family/c-warn.c:1558
 #, gcc-internal-format
 msgid "decrement of read-only named return value %qD"
 msgstr ""
 
-#: c-family/c-warn.c:1552
+#: c-family/c-warn.c:1560
 #, gcc-internal-format
 msgid "read-only named return value %qD used as %<asm%>output"
 msgstr ""
 
-#: c-family/c-warn.c:1557
+#: c-family/c-warn.c:1565
 #, gcc-internal-format
 msgid "assignment of function %qD"
 msgstr ""
 
-#: c-family/c-warn.c:1558
+#: c-family/c-warn.c:1566
 #, gcc-internal-format
 msgid "increment of function %qD"
 msgstr ""
 
-#: c-family/c-warn.c:1559
+#: c-family/c-warn.c:1567
 #, gcc-internal-format
 msgid "decrement of function %qD"
 msgstr ""
 
-#: c-family/c-warn.c:1560
+#: c-family/c-warn.c:1568
 #, gcc-internal-format
 msgid "function %qD used as %<asm%> output"
 msgstr ""
 
-#: c-family/c-warn.c:1563 c/c-typeck.c:4762
+#: c-family/c-warn.c:1571 c/c-typeck.c:4767
 #, gcc-internal-format
 msgid "assignment of read-only location %qE"
 msgstr ""
 
-#: c-family/c-warn.c:1564 c/c-typeck.c:4765
+#: c-family/c-warn.c:1572 c/c-typeck.c:4770
 #, gcc-internal-format
 msgid "increment of read-only location %qE"
 msgstr ""
 
-#: c-family/c-warn.c:1565 c/c-typeck.c:4768
+#: c-family/c-warn.c:1573 c/c-typeck.c:4773
 #, gcc-internal-format
 msgid "decrement of read-only location %qE"
 msgstr ""
 
-#: c-family/c-warn.c:1566
+#: c-family/c-warn.c:1574
 #, gcc-internal-format
 msgid "read-only location %qE used as %<asm%> output"
 msgstr ""
 
-#: c-family/c-warn.c:1580
+#: c-family/c-warn.c:1588
 #, gcc-internal-format
 msgid "lvalue required as left operand of assignment"
 msgstr ""
 
-#: c-family/c-warn.c:1583
+#: c-family/c-warn.c:1591
 #, gcc-internal-format
 msgid "lvalue required as increment operand"
 msgstr ""
 
-#: c-family/c-warn.c:1586
+#: c-family/c-warn.c:1594
 #, gcc-internal-format
 msgid "lvalue required as decrement operand"
 msgstr ""
 
-#: c-family/c-warn.c:1589
+#: c-family/c-warn.c:1597
 #, gcc-internal-format
 msgid "lvalue required as unary %<&%> operand"
 msgstr ""
 
-#: c-family/c-warn.c:1592
+#: c-family/c-warn.c:1600
 #, gcc-internal-format
 msgid "lvalue required in asm statement"
 msgstr ""
 
-#: c-family/c-warn.c:1609
+#: c-family/c-warn.c:1617
 #, gcc-internal-format
 msgid "invalid type argument (have %qT)"
 msgstr ""
 
-#: c-family/c-warn.c:1613
+#: c-family/c-warn.c:1621
 #, gcc-internal-format
 msgid "invalid type argument of array indexing (have %qT)"
 msgstr ""
 
-#: c-family/c-warn.c:1618
+#: c-family/c-warn.c:1626
 #, gcc-internal-format
 msgid "invalid type argument of unary %<*%> (have %qT)"
 msgstr ""
 
-#: c-family/c-warn.c:1623
+#: c-family/c-warn.c:1631
 #, gcc-internal-format
 msgid "invalid type argument of %<->%> (have %qT)"
 msgstr ""
 
-#: c-family/c-warn.c:1628
+#: c-family/c-warn.c:1636
 #, gcc-internal-format
 msgid "invalid type argument of %<->*%> (have %qT)"
 msgstr ""
 
-#: c-family/c-warn.c:1633
+#: c-family/c-warn.c:1641
 #, gcc-internal-format
 msgid "invalid type argument of implicit conversion (have %qT)"
 msgstr ""
 
-#: c-family/c-warn.c:1654
+#: c-family/c-warn.c:1662
 #, gcc-internal-format
 msgid "array subscript has type %<char%>"
 msgstr ""
 
-#: c-family/c-warn.c:1689 c-family/c-warn.c:1692
+#: c-family/c-warn.c:1697 c-family/c-warn.c:1700
 #, gcc-internal-format
 msgid "suggest parentheses around %<+%> inside %<<<%>"
 msgstr ""
 
-#: c-family/c-warn.c:1695 c-family/c-warn.c:1698
+#: c-family/c-warn.c:1703 c-family/c-warn.c:1706
 #, gcc-internal-format
 msgid "suggest parentheses around %<-%> inside %<<<%>"
 msgstr ""
 
-#: c-family/c-warn.c:1704 c-family/c-warn.c:1707
+#: c-family/c-warn.c:1712 c-family/c-warn.c:1715
 #, gcc-internal-format
 msgid "suggest parentheses around %<+%> inside %<>>%>"
 msgstr ""
 
-#: c-family/c-warn.c:1710 c-family/c-warn.c:1713
+#: c-family/c-warn.c:1718 c-family/c-warn.c:1721
 #, gcc-internal-format
 msgid "suggest parentheses around %<-%> inside %<>>%>"
 msgstr ""
 
-#: c-family/c-warn.c:1719 c-family/c-warn.c:1722
+#: c-family/c-warn.c:1727 c-family/c-warn.c:1730
 #, gcc-internal-format
 msgid "suggest parentheses around %<&&%> within %<||%>"
 msgstr ""
 
-#: c-family/c-warn.c:1729 c-family/c-warn.c:1733
+#: c-family/c-warn.c:1737 c-family/c-warn.c:1741
 #, gcc-internal-format
 msgid "suggest parentheses around arithmetic in operand of %<|%>"
 msgstr ""
 
-#: c-family/c-warn.c:1737 c-family/c-warn.c:1740
+#: c-family/c-warn.c:1745 c-family/c-warn.c:1748
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<|%>"
 msgstr ""
 
-#: c-family/c-warn.c:1745
+#: c-family/c-warn.c:1753
 #, gcc-internal-format
 msgid "suggest parentheses around operand of %<!%> or change %<|%> to %<||%> or %<!%> to %<~%>"
 msgstr ""
 
-#: c-family/c-warn.c:1753 c-family/c-warn.c:1757
+#: c-family/c-warn.c:1761 c-family/c-warn.c:1765
 #, gcc-internal-format
 msgid "suggest parentheses around arithmetic in operand of %<^%>"
 msgstr ""
 
-#: c-family/c-warn.c:1761 c-family/c-warn.c:1764
+#: c-family/c-warn.c:1769 c-family/c-warn.c:1772
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<^%>"
 msgstr ""
 
-#: c-family/c-warn.c:1770 c-family/c-warn.c:1773
+#: c-family/c-warn.c:1778 c-family/c-warn.c:1781
 #, gcc-internal-format
 msgid "suggest parentheses around %<+%> in operand of %<&%>"
 msgstr ""
 
-#: c-family/c-warn.c:1776 c-family/c-warn.c:1779
+#: c-family/c-warn.c:1784 c-family/c-warn.c:1787
 #, gcc-internal-format
 msgid "suggest parentheses around %<-%> in operand of %<&%>"
 msgstr ""
 
-#: c-family/c-warn.c:1783 c-family/c-warn.c:1786
+#: c-family/c-warn.c:1791 c-family/c-warn.c:1794
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<&%>"
 msgstr ""
 
-#: c-family/c-warn.c:1791
+#: c-family/c-warn.c:1799
 #, gcc-internal-format
 msgid "suggest parentheses around operand of %<!%> or change %<&%> to %<&&%> or %<!%> to %<~%>"
 msgstr ""
 
-#: c-family/c-warn.c:1798 c-family/c-warn.c:1801
+#: c-family/c-warn.c:1806 c-family/c-warn.c:1809
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<==%>"
 msgstr ""
 
-#: c-family/c-warn.c:1806 c-family/c-warn.c:1809
+#: c-family/c-warn.c:1814 c-family/c-warn.c:1817
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<!=%>"
 msgstr ""
 
-#: c-family/c-warn.c:1819 c-family/c-warn.c:1825
+#: c-family/c-warn.c:1827 c-family/c-warn.c:1833
 #, gcc-internal-format
 msgid "comparisons like %<X<=Y<=Z%> do not have their mathematical meaning"
 msgstr ""
 
-#: c-family/c-warn.c:1841
+#: c-family/c-warn.c:1849
 #, gcc-internal-format
 msgid "label %q+D defined but not used"
 msgstr ""
 
-#: c-family/c-warn.c:1843
+#: c-family/c-warn.c:1851
 #, gcc-internal-format
 msgid "label %q+D declared but not defined"
 msgstr ""
 
-#: c-family/c-warn.c:1866
+#: c-family/c-warn.c:1874
 #, gcc-internal-format
 msgid "division by zero"
 msgstr ""
 
-#: c-family/c-warn.c:1886
+#: c-family/c-warn.c:1894
 #, gcc-internal-format
 msgid "%<memset%> used with constant zero length parameter; this could be due to transposed parameters"
 msgstr ""
 
-#: c-family/c-warn.c:1909
+#: c-family/c-warn.c:1918
 #, gcc-internal-format
 msgid "%<memset%> used with length equal to number of elements without multiplication by element size"
 msgstr ""
 
-#: c-family/c-warn.c:1948 c/c-typeck.c:11499 c/c-typeck.c:11667
+#: c-family/c-warn.c:1957 c/c-typeck.c:11504 c/c-typeck.c:11672
 #: cp/typeck.c:5048
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr ""
 
-#: c-family/c-warn.c:1998
+#: c-family/c-warn.c:2007
 #, gcc-internal-format
 msgid "comparison of integer expressions of different signedness: %qT and %qT"
 msgstr ""
 
-#: c-family/c-warn.c:2051
+#: c-family/c-warn.c:2060
 #, gcc-internal-format
 msgid "promoted ~unsigned is always non-zero"
 msgstr ""
 
-#: c-family/c-warn.c:2054
+#: c-family/c-warn.c:2063
 #, gcc-internal-format
 msgid "comparison of promoted ~unsigned with constant"
 msgstr ""
 
-#: c-family/c-warn.c:2064
+#: c-family/c-warn.c:2073
 #, gcc-internal-format
 msgid "comparison of promoted ~unsigned with unsigned"
 msgstr ""
 
-#: c-family/c-warn.c:2118
+#: c-family/c-warn.c:2127
 #, gcc-internal-format
 msgid "unused parameter %qD"
 msgstr ""
 
-#: c-family/c-warn.c:2180
+#: c-family/c-warn.c:2189
 #, gcc-internal-format
 msgid "typedef %qD locally defined but not used"
 msgstr ""
 
-#: c-family/c-warn.c:2215
+#: c-family/c-warn.c:2224
 #, gcc-internal-format
 msgid "duplicated %<if%> condition"
 msgstr ""
 
-#: c-family/c-warn.c:2244
+#: c-family/c-warn.c:2253
 #, gcc-internal-format
 msgid "optimization attribute on %qD follows definition but the attribute doesn%'t match"
 msgstr ""
 
-#: c-family/c-warn.c:2254
+#: c-family/c-warn.c:2261
 #, gcc-internal-format
 msgid "inline declaration of %qD follows declaration with attribute %qs"
 msgstr ""
 
-#: c-family/c-warn.c:2259
+#: c-family/c-warn.c:2266
 #, gcc-internal-format
 msgid "declaration of %q+D with attribute %qs follows inline declaration"
 msgstr ""
 
-#: c-family/c-warn.c:2306
+#: c-family/c-warn.c:2313
 #, gcc-internal-format
 msgid "result of %qE requires %u bits to represent, but %qT only has %u bits"
 msgstr ""
 
-#: c-family/c-warn.c:2344 c-family/c-warn.c:2368
+#: c-family/c-warn.c:2351 c-family/c-warn.c:2375
 #, gcc-internal-format
 msgid "comparison of constant %qE with boolean expression is always false"
 msgstr ""
 
-#: c-family/c-warn.c:2347 c-family/c-warn.c:2365
+#: c-family/c-warn.c:2354 c-family/c-warn.c:2372
 #, gcc-internal-format
 msgid "comparison of constant %qE with boolean expression is always true"
 msgstr ""
 
-#: c-family/c-warn.c:2415
+#: c-family/c-warn.c:2422
 msgid "passing argument %i to restrict-qualified parameter aliases with argument %Z"
 msgid_plural "passing argument %i to restrict-qualified parameter aliases with arguments %Z"
 msgstr[0] ""
@@ -26738,17 +26780,17 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: c-family/c-warn.c:2480 c/c-typeck.c:5288 cp/call.c:5365
+#: c-family/c-warn.c:2487 c/c-typeck.c:5293 cp/call.c:5365
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr ""
 
-#: c-family/c-warn.c:2586
+#: c-family/c-warn.c:2593
 #, gcc-internal-format
 msgid "macro expands to multiple statements"
 msgstr ""
 
-#: c-family/c-warn.c:2587
+#: c-family/c-warn.c:2594
 #, gcc-internal-format
 msgid "some parts of macro expansion are not guarded by this %qs clause"
 msgstr ""
@@ -26763,7 +26805,7 @@
 msgid "too many input files"
 msgstr ""
 
-#: common/config/aarch64/aarch64-common.c:319 config/aarch64/aarch64.c:10686
+#: common/config/aarch64/aarch64-common.c:319 config/aarch64/aarch64.c:10702
 #, gcc-internal-format
 msgid "unknown value %qs for -mcpu"
 msgstr ""
@@ -26794,13 +26836,13 @@
 msgstr ""
 
 #: common/config/arm/arm-common.c:322 common/config/arm/arm-common.c:376
-#: common/config/arm/arm-common.c:423 config/aarch64/aarch64.c:10639
+#: common/config/arm/arm-common.c:423 config/aarch64/aarch64.c:10655
 #, gcc-internal-format
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr ""
 
 #: common/config/arm/arm-common.c:325 common/config/arm/arm-common.c:379
-#: common/config/arm/arm-common.c:426 config/aarch64/aarch64.c:10642
+#: common/config/arm/arm-common.c:426 config/aarch64/aarch64.c:10658
 #, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s"
 msgstr ""
@@ -27275,12 +27317,12 @@
 msgid "profiler support for VxWorks"
 msgstr ""
 
-#: config/aarch64/aarch64-builtins.c:1109 config/arm/arm-builtins.c:2262
+#: config/aarch64/aarch64-builtins.c:1109 config/arm/arm-builtins.c:2272
 #, gcc-internal-format
 msgid "%Kargument %d must be a constant immediate"
 msgstr ""
 
-#: config/aarch64/aarch64-builtins.c:1180 config/arm/arm-builtins.c:2492
+#: config/aarch64/aarch64-builtins.c:1180 config/arm/arm-builtins.c:2502
 #, gcc-internal-format
 msgid "%Klane index must be a constant immediate"
 msgstr ""
@@ -27290,176 +27332,176 @@
 msgid "%Ktotal size and element size must be a non-zero constant immediate"
 msgstr ""
 
-#: config/aarch64/aarch64.c:1053
+#: config/aarch64/aarch64.c:1069
 #, gcc-internal-format
 msgid "%qs is incompatible with %s %s"
 msgstr ""
 
-#: config/aarch64/aarch64.c:1055
+#: config/aarch64/aarch64.c:1071
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with %s %s"
 msgstr ""
 
-#: config/aarch64/aarch64.c:3772
+#: config/aarch64/aarch64.c:3788
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10287
+#: config/aarch64/aarch64.c:10303
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown flag passed in -moverride=%s (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10331
+#: config/aarch64/aarch64.c:10347
 #, gcc-internal-format, gfc-internal-format
 msgid "%s string ill-formed\n"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10388
+#: config/aarch64/aarch64.c:10404
 #, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10406
+#: config/aarch64/aarch64.c:10422
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s:unknown function '%u'\n"
 msgid "unknown tuning option (%s)"
 msgstr "%s:nepoznata funkcija „%u”\n"
 
-#: config/aarch64/aarch64.c:10683
+#: config/aarch64/aarch64.c:10699
 #, gcc-internal-format
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10690
+#: config/aarch64/aarch64.c:10706
 #, gcc-internal-format
 msgid "invalid feature modifier in %<-mcpu=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10717
+#: config/aarch64/aarch64.c:10733
 #, gcc-internal-format
 msgid "missing arch name in %<-march=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10720
+#: config/aarch64/aarch64.c:10736
 #, gcc-internal-format
 msgid "unknown value %qs for -march"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10724
+#: config/aarch64/aarch64.c:10740
 #, gcc-internal-format
 msgid "invalid feature modifier in %<-march=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10750
+#: config/aarch64/aarch64.c:10766
 #, gcc-internal-format
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10753
+#: config/aarch64/aarch64.c:10769
 #, gcc-internal-format
 msgid "unknown value %qs for -mtune"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10871 config/arm/arm.c:3173
+#: config/aarch64/aarch64.c:10887 config/arm/arm.c:3173
 #, gcc-internal-format, gfc-internal-format
 msgid "switch -mcpu=%s conflicts with -march=%s switch"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10906
+#: config/aarch64/aarch64.c:10922
 #, gcc-internal-format
 msgid "assembler does not support -mabi=ilp32"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10913
+#: config/aarch64/aarch64.c:10929
 #, gcc-internal-format
 msgid "return address signing is only supported for -mabi=lp64"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10975
+#: config/aarch64/aarch64.c:10991
 #, gcc-internal-format
 msgid "code model %qs with -f%s"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11138
+#: config/aarch64/aarch64.c:11154
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11141
+#: config/aarch64/aarch64.c:11157
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11145 config/aarch64/aarch64.c:11184
-#: config/aarch64/aarch64.c:11257
+#: config/aarch64/aarch64.c:11161 config/aarch64/aarch64.c:11200
+#: config/aarch64/aarch64.c:11273
 #, gcc-internal-format
 msgid "invalid value (\"%s\") in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11177
+#: config/aarch64/aarch64.c:11193
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11180
+#: config/aarch64/aarch64.c:11196
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11213
+#: config/aarch64/aarch64.c:11229
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"tune=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11253
+#: config/aarch64/aarch64.c:11269
 #, gcc-internal-format
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11306 config/aarch64/aarch64.c:11483
+#: config/aarch64/aarch64.c:11322 config/aarch64/aarch64.c:11499
 #, gcc-internal-format
 msgid "malformed %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11354
+#: config/aarch64/aarch64.c:11370
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11362
+#: config/aarch64/aarch64.c:11378
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11416
+#: config/aarch64/aarch64.c:11432
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11473 config/arm/arm.c:30742
-#: config/i386/i386.c:5440 config/powerpcspe/powerpcspe.c:39760
-#: config/rs6000/rs6000.c:36904 config/s390/s390.c:15746
+#: config/aarch64/aarch64.c:11489 config/arm/arm.c:30742
+#: config/i386/i386.c:5443 config/powerpcspe/powerpcspe.c:39760
+#: config/rs6000/rs6000.c:36960 config/s390/s390.c:15746
 #, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11500
+#: config/aarch64/aarch64.c:11516
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11509
+#: config/aarch64/aarch64.c:11525
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13571
+#: config/aarch64/aarch64.c:13587
 #, gcc-internal-format
 msgid "%Klane %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13573
+#: config/aarch64/aarch64.c:13589
 #, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr ""
@@ -27519,8 +27561,8 @@
 msgid "bad value %qs for -mmemory-latency"
 msgstr ""
 
-#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6526
-#: config/arc/arc.c:6800 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
+#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6517
+#: config/arc/arc.c:6791 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
 #: config/tilepro/tilepro.c:3108
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -27629,11 +27671,11 @@
 #: config/arm/arm.c:7029 config/avr/avr.c:9718 config/avr/avr.c:9734
 #: config/bfin/bfin.c:4705 config/bfin/bfin.c:4766 config/bfin/bfin.c:4795
 #: config/epiphany/epiphany.c:491 config/h8300/h8300.c:5459
-#: config/i386/i386.c:6452 config/i386/i386.c:12479 config/i386/i386.c:41424
-#: config/i386/i386.c:41474 config/i386/i386.c:41544 config/m68k/m68k.c:780
+#: config/i386/i386.c:6455 config/i386/i386.c:12482 config/i386/i386.c:41418
+#: config/i386/i386.c:41468 config/i386/i386.c:41538 config/m68k/m68k.c:780
 #: config/mcore/mcore.c:3070 config/nvptx/nvptx.c:4611
 #: config/powerpcspe/powerpcspe.c:35785 config/riscv/riscv.c:2698
-#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:32982
+#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:33038
 #: config/rx/rx.c:2719 config/rx/rx.c:2745 config/s390/s390.c:1056
 #: config/s390/s390.c:1143 config/sh/sh.c:8428 config/sh/sh.c:8446
 #: config/sh/sh.c:8470 config/sh/sh.c:8541 config/sh/sh.c:8564
@@ -27643,133 +27685,133 @@
 msgid "%qE attribute only applies to functions"
 msgstr ""
 
-#: config/arc/arc.c:6425
+#: config/arc/arc.c:6416
 #, gcc-internal-format
 msgid "__builtin_arc_aligned with non-constant alignment"
 msgstr ""
 
-#: config/arc/arc.c:6433
+#: config/arc/arc.c:6424
 #, gcc-internal-format
 msgid "invalid alignment value for __builtin_arc_aligned"
 msgstr ""
 
-#: config/arc/arc.c:6596
+#: config/arc/arc.c:6587
 #, gcc-internal-format
 msgid "operand 1 should be an unsigned 3-bit immediate"
 msgstr ""
 
-#: config/arc/arc.c:6637 config/arc/arc.c:6734
+#: config/arc/arc.c:6628 config/arc/arc.c:6725
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6670 config/arc/arc.c:6702
+#: config/arc/arc.c:6661 config/arc/arc.c:6693
 #, gcc-internal-format
 msgid "operand 1 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6674 config/arc/arc.c:6706
+#: config/arc/arc.c:6665 config/arc/arc.c:6697
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 8-bit value"
 msgstr ""
 
-#: config/arc/arc.c:6738
+#: config/arc/arc.c:6729
 #, gcc-internal-format
 msgid "operand 3 should be an unsigned 8-bit value"
 msgstr ""
 
-#: config/arc/arc.c:6771
+#: config/arc/arc.c:6762
 #, gcc-internal-format
 msgid "operand 4 should be an unsigned 8-bit value (0-255)"
 msgstr ""
 
-#: config/arc/arc.c:6775
+#: config/arc/arc.c:6766
 #, gcc-internal-format
 msgid "operand 3 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6782
+#: config/arc/arc.c:6773
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (subreg 0-7)"
 msgstr ""
 
-#: config/arc/arc.c:6785
+#: config/arc/arc.c:6776
 #, gcc-internal-format
 msgid "operand 2 should be an even 3-bit value (subreg 0,2,4,6)"
 msgstr ""
 
-#: config/arc/arc.c:6832
+#: config/arc/arc.c:6823
 #, gcc-internal-format, gfc-internal-format
 msgid "builtin requires an immediate for operand %d"
 msgstr ""
 
-#: config/arc/arc.c:6837
+#: config/arc/arc.c:6828
 #, gcc-internal-format, gfc-internal-format
 msgid "operand %d should be a 6 bit unsigned immediate"
 msgstr ""
 
-#: config/arc/arc.c:6841
+#: config/arc/arc.c:6832
 #, gcc-internal-format, gfc-internal-format
 msgid "operand %d should be a 8 bit unsigned immediate"
 msgstr ""
 
-#: config/arc/arc.c:6845
+#: config/arc/arc.c:6836
 #, gcc-internal-format, gfc-internal-format
 msgid "operand %d should be a 3 bit unsigned immediate"
 msgstr ""
 
-#: config/arc/arc.c:6848
+#: config/arc/arc.c:6839
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown builtin immediate operand type for operand %d"
 msgstr ""
 
-#: config/arc/arc.c:6899
+#: config/arc/arc.c:6890
 #, gcc-internal-format
 msgid "register number must be a compile-time constant. Try giving higher optimization levels"
 msgstr ""
 
-#: config/arc/arc.c:7685
+#: config/arc/arc.c:7747
 #, gcc-internal-format
 msgid "Insn addresses not set after shorten_branches"
 msgstr ""
 
-#: config/arc/arc.c:7894
+#: config/arc/arc.c:7956
 #, gcc-internal-format
 msgid "insn addresses not freed"
 msgstr ""
 
-#: config/arc/arc.c:10682
+#: config/arc/arc.c:10670
 #, gcc-internal-format
 msgid "%qE attribute only valid for ARCv2 architecture"
 msgstr ""
 
-#: config/arc/arc.c:10690 config/arc/arc.c:10729
+#: config/arc/arc.c:10678 config/arc/arc.c:10717
 #, gcc-internal-format
 msgid "argument of %qE attribute is missing"
 msgstr ""
 
-#: config/arc/arc.c:10701 config/arc/arc.c:10740 config/arc/arc.c:10842
+#: config/arc/arc.c:10689 config/arc/arc.c:10728 config/arc/arc.c:10830
 #: config/avr/avr.c:9790
 #, gcc-internal-format
 msgid "%qE attribute allows only an integer constant argument"
 msgstr ""
 
-#: config/arc/arc.c:10721
+#: config/arc/arc.c:10709
 #, gcc-internal-format
 msgid "%qE attribute only valid for ARC EM architecture"
 msgstr ""
 
-#: config/arc/arc.c:10776
+#: config/arc/arc.c:10764
 #, gcc-internal-format
 msgid "%qE attribute only applies to types"
 msgstr ""
 
-#: config/arc/arc.c:10782
+#: config/arc/arc.c:10770
 #, gcc-internal-format
 msgid "argument of %qE attribute ignored"
 msgstr ""
 
-#: config/arc/arc.c:10832 config/avr/avr.c:9777 config/bfin/bfin.c:4827
+#: config/arc/arc.c:10820 config/avr/avr.c:9777 config/bfin/bfin.c:4827
 #: config/i386/winnt.c:63 config/msp430/msp430.c:2018
 #: config/nvptx/nvptx.c:4634
 #, gcc-internal-format
@@ -27776,174 +27818,174 @@
 msgid "%qE attribute only applies to variables"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2370
+#: config/arm/arm-builtins.c:2380
 #, gcc-internal-format
 msgid "this builtin is not supported for this target"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2475
+#: config/arm/arm-builtins.c:2485
 #, gcc-internal-format
 msgid "You must enable NEON instructions (e.g. -mfloat-abi=softfp -mfpu=neon) to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2513
+#: config/arm/arm-builtins.c:2523
 #, gcc-internal-format
 msgid "You must enable VFP instructions to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2573
+#: config/arm/arm-builtins.c:2583
 #, gcc-internal-format
 msgid "You must enable crypto instructions (e.g. include -mfloat-abi=softfp -mfpu=crypto-neon...) to use these intrinsics."
 msgstr ""
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:2633 config/arm/arm-builtins.c:2737
+#: config/arm/arm-builtins.c:2643 config/arm/arm-builtins.c:2747
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2641 config/arm/arm-builtins.c:2686
-#: config/arm/arm-builtins.c:2744 config/arm/arm-builtins.c:2753
+#: config/arm/arm-builtins.c:2651 config/arm/arm-builtins.c:2696
+#: config/arm/arm-builtins.c:2754 config/arm/arm-builtins.c:2763
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2646 config/arm/arm-builtins.c:2755
+#: config/arm/arm-builtins.c:2656 config/arm/arm-builtins.c:2765
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2651 config/arm/arm-builtins.c:2757
+#: config/arm/arm-builtins.c:2661 config/arm/arm-builtins.c:2767
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2823
+#: config/arm/arm-builtins.c:2833
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2828
+#: config/arm/arm-builtins.c:2838
 #, gcc-internal-format
 msgid "the range of mask should be in 0 to 255"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3016
+#: config/arm/arm-builtins.c:3026
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3018
+#: config/arm/arm-builtins.c:3028
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3020
+#: config/arm/arm-builtins.c:3030
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3022
+#: config/arm/arm-builtins.c:3032
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3028
+#: config/arm/arm-builtins.c:3038
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3030
+#: config/arm/arm-builtins.c:3040
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3035
+#: config/arm/arm-builtins.c:3045
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3037
+#: config/arm/arm-builtins.c:3047
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3039
+#: config/arm/arm-builtins.c:3049
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3041
+#: config/arm/arm-builtins.c:3051
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3043
+#: config/arm/arm-builtins.c:3053
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3045
+#: config/arm/arm-builtins.c:3055
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3047
+#: config/arm/arm-builtins.c:3057
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3049
+#: config/arm/arm-builtins.c:3059
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3051
+#: config/arm/arm-builtins.c:3061
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3053
+#: config/arm/arm-builtins.c:3063
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3055
+#: config/arm/arm-builtins.c:3065
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3057
+#: config/arm/arm-builtins.c:3067
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3059
+#: config/arm/arm-builtins.c:3069
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3061
+#: config/arm/arm-builtins.c:3071
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3063
+#: config/arm/arm-builtins.c:3073
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3065
+#: config/arm/arm-builtins.c:3075
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3067
+#: config/arm/arm-builtins.c:3077
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3069
+#: config/arm/arm-builtins.c:3079
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr ""
@@ -28850,551 +28892,551 @@
 msgid "can%'t set position in PCH file: %m"
 msgstr ""
 
-#: config/i386/i386.c:3177
+#: config/i386/i386.c:3180
 #, gcc-internal-format
 msgid "wrong argument %qs to option %qs"
 msgstr ""
 
-#: config/i386/i386.c:3183
+#: config/i386/i386.c:3186
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr ""
 
-#: config/i386/i386.c:3193
+#: config/i386/i386.c:3196
 #, gcc-internal-format
 msgid "wrong strategy name %qs specified for option %qs"
 msgstr ""
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3219
+#: config/i386/i386.c:3222
 #, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386.c:3232
+#: config/i386/i386.c:3235
 #, gcc-internal-format
 msgid "unknown alignment %qs specified for option %qs"
 msgstr ""
 
-#: config/i386/i386.c:3242
+#: config/i386/i386.c:3245
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr ""
 
-#: config/i386/i386.c:3249
+#: config/i386/i386.c:3252
 #, gcc-internal-format
 msgid "too many size ranges specified in option %qs"
 msgstr ""
 
-#: config/i386/i386.c:3302
+#: config/i386/i386.c:3305
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown parameter to option -mtune-ctrl: %s"
 msgstr ""
 
-#: config/i386/i386.c:3726
+#: config/i386/i386.c:3729
 #, gcc-internal-format
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr ""
 
-#: config/i386/i386.c:3775
+#: config/i386/i386.c:3778
 #, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr ""
 
-#: config/i386/i386.c:3777
+#: config/i386/i386.c:3780
 #, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr ""
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3804
+#: config/i386/i386.c:3807
 #, gcc-internal-format
 msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386.c:3821
+#: config/i386/i386.c:3824
 #, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr ""
 
-#: config/i386/i386.c:3833
+#: config/i386/i386.c:3836
 #, gcc-internal-format
 msgid "-mabi=ms not supported with X32 ABI"
 msgstr ""
 
-#: config/i386/i386.c:3851 config/i386/i386.c:3860 config/i386/i386.c:3872
-#: config/i386/i386.c:3883 config/i386/i386.c:3894
+#: config/i386/i386.c:3854 config/i386/i386.c:3863 config/i386/i386.c:3875
+#: config/i386/i386.c:3886 config/i386/i386.c:3897
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr ""
 
-#: config/i386/i386.c:3863 config/i386/i386.c:3875
+#: config/i386/i386.c:3866 config/i386/i386.c:3878
 #, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr ""
 
-#: config/i386/i386.c:3881 config/i386/i386.c:3890 config/i386/i386.c:5213
+#: config/i386/i386.c:3884 config/i386/i386.c:3893 config/i386/i386.c:5216
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr ""
 
-#: config/i386/i386.c:3918
+#: config/i386/i386.c:3921
 #, gcc-internal-format
 msgid "-masm=intel not supported in this configuration"
 msgstr ""
 
-#: config/i386/i386.c:3923
+#: config/i386/i386.c:3926
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr ""
 
-#: config/i386/i386.c:3932
+#: config/i386/i386.c:3935
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386.c:3934
+#: config/i386/i386.c:3937
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386.c:3941
+#: config/i386/i386.c:3944
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386.c:3943
+#: config/i386/i386.c:3946
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386.c:3951 config/i386/i386.c:4265
+#: config/i386/i386.c:3954 config/i386/i386.c:4268
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr ""
 
-#: config/i386/i386.c:4197 config/i386/i386.c:4200
+#: config/i386/i386.c:4200 config/i386/i386.c:4203
 #, gcc-internal-format
 msgid "Intel MPX does not support x32"
 msgstr ""
 
-#: config/i386/i386.c:4205
+#: config/i386/i386.c:4208
 #, gcc-internal-format
 msgid "bad value (%qs) for %<-march=%> switch"
 msgstr ""
 
-#: config/i386/i386.c:4206
+#: config/i386/i386.c:4209
 #, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"arch=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386.c:4228
+#: config/i386/i386.c:4231
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4230
+#: config/i386/i386.c:4233
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4235
+#: config/i386/i386.c:4238
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr ""
 
-#: config/i386/i386.c:4236
+#: config/i386/i386.c:4239
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr ""
 
-#: config/i386/i386.c:4284
+#: config/i386/i386.c:4287
 #, gcc-internal-format
 msgid "bad value (%qs) for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386.c:4285
+#: config/i386/i386.c:4288
 #, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386.c:4305
+#: config/i386/i386.c:4308
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4307
+#: config/i386/i386.c:4310
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4312
+#: config/i386/i386.c:4315
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr ""
 
-#: config/i386/i386.c:4313
+#: config/i386/i386.c:4316
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr ""
 
-#: config/i386/i386.c:4379
+#: config/i386/i386.c:4382
 #, gcc-internal-format
 msgid "-mregparm is ignored in 64-bit mode"
 msgstr ""
 
-#: config/i386/i386.c:4381
+#: config/i386/i386.c:4384
 #, gcc-internal-format
 msgid "-mregparm is ignored for Intel MCU psABI"
 msgstr ""
 
-#: config/i386/i386.c:4384
+#: config/i386/i386.c:4387
 #, gcc-internal-format, gfc-internal-format
 msgid "-mregparm=%d is not between 0 and %d"
 msgstr ""
 
-#: config/i386/i386.c:4417
+#: config/i386/i386.c:4420
 #, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr ""
 
-#: config/i386/i386.c:4418
+#: config/i386/i386.c:4421
 #, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr ""
 
-#: config/i386/i386.c:4497
+#: config/i386/i386.c:4500
 #, gcc-internal-format
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr ""
 
-#: config/i386/i386.c:4500
+#: config/i386/i386.c:4503
 #, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr ""
 
-#: config/i386/i386.c:4523
+#: config/i386/i386.c:4526
 #, gcc-internal-format, gfc-internal-format
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr ""
 
-#: config/i386/i386.c:4536
+#: config/i386/i386.c:4539
 #, gcc-internal-format
 msgid "-mnop-mcount is not compatible with this target"
 msgstr ""
 
-#: config/i386/i386.c:4539
+#: config/i386/i386.c:4542
 #, gcc-internal-format
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr ""
 
-#: config/i386/i386.c:4545
+#: config/i386/i386.c:4548
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386.c:4546
+#: config/i386/i386.c:4549
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386.c:4556
+#: config/i386/i386.c:4559
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr ""
 
-#: config/i386/i386.c:4563
+#: config/i386/i386.c:4566
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr ""
 
-#: config/i386/i386.c:4613
+#: config/i386/i386.c:4616
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr ""
 
-#: config/i386/i386.c:4615
+#: config/i386/i386.c:4618
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr ""
 
-#: config/i386/i386.c:4629
+#: config/i386/i386.c:4632
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr ""
 
-#: config/i386/i386.c:4631
+#: config/i386/i386.c:4634
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr ""
 
-#: config/i386/i386.c:4741
+#: config/i386/i386.c:4744
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr ""
 
-#: config/i386/i386.c:4744
+#: config/i386/i386.c:4747
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr ""
 
-#: config/i386/i386.c:4748
+#: config/i386/i386.c:4751
 #, gcc-internal-format
 msgid "-mcall-ms2sysv-xlogues isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386.c:4813 config/powerpcspe/powerpcspe.c:5663
+#: config/i386/i386.c:4816 config/powerpcspe/powerpcspe.c:5663
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown option for -mrecip=%s"
 msgstr ""
 
-#: config/i386/i386.c:4870 config/powerpcspe/powerpcspe.c:5339
+#: config/i386/i386.c:4873 config/powerpcspe/powerpcspe.c:5339
 #, gcc-internal-format
 msgid "%qs is not a valid number in -mstack-protector-guard-offset="
 msgstr ""
 
-#: config/i386/i386.c:4875 config/powerpcspe/powerpcspe.c:5344
+#: config/i386/i386.c:4878 config/powerpcspe/powerpcspe.c:5344
 #, gcc-internal-format
 msgid "%qs is not a valid offset in -mstack-protector-guard-offset="
 msgstr ""
 
-#: config/i386/i386.c:4907 config/powerpcspe/powerpcspe.c:5356
+#: config/i386/i386.c:4910 config/powerpcspe/powerpcspe.c:5356
 #, gcc-internal-format
 msgid "%qs is not a valid base register in -mstack-protector-guard-reg="
 msgstr ""
 
-#: config/i386/i386.c:5506 config/i386/i386.c:5553 config/s390/s390.c:15812
+#: config/i386/i386.c:5509 config/i386/i386.c:5556 config/s390/s390.c:15812
 #: config/s390/s390.c:15862 config/s390/s390.c:15879
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr ""
 
-#: config/i386/i386.c:5534
+#: config/i386/i386.c:5537
 #, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr ""
 
-#: config/i386/i386.c:5837
+#: config/i386/i386.c:5840
 #, gcc-internal-format
 msgid "interrupt and naked attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5852
+#: config/i386/i386.c:5855
 #, gcc-internal-format
 msgid "Only DWARF debug format is supported for interrupt service routine."
 msgstr ""
 
-#: config/i386/i386.c:5901
+#: config/i386/i386.c:5904
 #, gcc-internal-format
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5913
+#: config/i386/i386.c:5916
 #, gcc-internal-format
 msgid "%<-mindirect-branch=thunk-extern%>, %<-fcf-protection=branch%> and %<-fcheck-pointer-bounds%> are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5949
+#: config/i386/i386.c:5952
 #, gcc-internal-format
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6047
+#: config/i386/i386.c:6050
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in %s service routine"
 msgstr ""
 
-#: config/i386/i386.c:6051
+#: config/i386/i386.c:6054
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in function with no_caller_saved_registers attribute"
 msgstr ""
 
-#: config/i386/i386.c:6465 config/i386/i386.c:6516
+#: config/i386/i386.c:6468 config/i386/i386.c:6519
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6470
+#: config/i386/i386.c:6473
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6477 config/i386/i386.c:41444
+#: config/i386/i386.c:6480 config/i386/i386.c:41438
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr ""
 
-#: config/i386/i386.c:6483
+#: config/i386/i386.c:6486
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr ""
 
-#: config/i386/i386.c:6508 config/i386/i386.c:6551
+#: config/i386/i386.c:6511 config/i386/i386.c:6554
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6512
+#: config/i386/i386.c:6515
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6520 config/i386/i386.c:6569
+#: config/i386/i386.c:6523 config/i386/i386.c:6572
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6530 config/i386/i386.c:6547
+#: config/i386/i386.c:6533 config/i386/i386.c:6550
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6534
+#: config/i386/i386.c:6537
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6538 config/i386/i386.c:6565
+#: config/i386/i386.c:6541 config/i386/i386.c:6568
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6555 config/i386/i386.c:6573
+#: config/i386/i386.c:6558 config/i386/i386.c:6576
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6561
+#: config/i386/i386.c:6564
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr ""
 
-#: config/i386/i386.c:6805
+#: config/i386/i386.c:6808
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:6808
+#: config/i386/i386.c:6811
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:7126
+#: config/i386/i386.c:7129
 #, gcc-internal-format
 msgid "X32 does not support ms_abi attribute"
 msgstr ""
 
-#: config/i386/i386.c:7160
+#: config/i386/i386.c:7163
 #, gcc-internal-format
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr ""
 
-#: config/i386/i386.c:7502
+#: config/i386/i386.c:7505
 #, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7508
+#: config/i386/i386.c:7511
 #, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7522
+#: config/i386/i386.c:7525
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7528
+#: config/i386/i386.c:7531
 #, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7544
+#: config/i386/i386.c:7547
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7550
+#: config/i386/i386.c:7553
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7566
+#: config/i386/i386.c:7569
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7572
+#: config/i386/i386.c:7575
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7754
+#: config/i386/i386.c:7757
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:7871
+#: config/i386/i386.c:7874
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:7989
+#: config/i386/i386.c:7992
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:8152
+#: config/i386/i386.c:8155
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.c:8158
+#: config/i386/i386.c:8161
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.c:8174
+#: config/i386/i386.c:8177
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr ""
 
-#: config/i386/i386.c:8471 config/i386/i386.c:8750 config/i386/i386.c:9276
+#: config/i386/i386.c:8474 config/i386/i386.c:8753 config/i386/i386.c:9279
 #, gcc-internal-format
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:8473 config/i386/i386.c:8752 config/i386/i386.c:9278
+#: config/i386/i386.c:8476 config/i386/i386.c:8755 config/i386/i386.c:9281
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr ""
 
-#: config/i386/i386.c:9178
+#: config/i386/i386.c:9181
 #, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr ""
 
-#: config/i386/i386.c:11601
+#: config/i386/i386.c:11604
 #, gcc-internal-format, gfc-internal-format
 msgid "-mcall-ms2sysv-xlogues is not compatible with %s"
 msgstr ""
 
-#: config/i386/i386.c:13593
+#: config/i386/i386.c:13596
 #, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr ""
 
-#: config/i386/i386.c:13683
+#: config/i386/i386.c:13686
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr ""
 
-#: config/i386/i386.c:14970
+#: config/i386/i386.c:14973
 #, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr ""
 
-#: config/i386/i386.c:14990
+#: config/i386/i386.c:14993
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
 msgstr ""
@@ -29401,311 +29443,311 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:15001
+#: config/i386/i386.c:15004
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr ""
 
-#: config/i386/i386.c:17939
+#: config/i386/i386.c:17942
 #, gcc-internal-format
 msgid "'V' modifier on non-integer register"
 msgstr ""
 
-#: config/i386/i386.c:17950 config/i386/i386.c:17964
+#: config/i386/i386.c:17953 config/i386/i386.c:17967
 #, gcc-internal-format
 msgid "unsupported size for integer register"
 msgstr ""
 
-#: config/i386/i386.c:17996
+#: config/i386/i386.c:17999
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr ""
 
-#: config/i386/i386.c:18011
+#: config/i386/i386.c:18014
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr ""
 
-#: config/i386/i386.c:18202
+#: config/i386/i386.c:18205
 #, gcc-internal-format
 msgid "non-integer operand used with operand code 'z'"
 msgstr ""
 
-#: config/i386/i386.c:28467
+#: config/i386/i386.c:28470
 #, gcc-internal-format
 msgid "interrupt service routine can't be called directly"
 msgstr ""
 
-#: config/i386/i386.c:29995
+#: config/i386/i386.c:29998
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in -fabi-version=12 (GCC 8)"
 msgstr ""
 
-#: config/i386/i386.c:32435
+#: config/i386/i386.c:32438
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr ""
 
-#: config/i386/i386.c:32485
+#: config/i386/i386.c:32488
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for %s"
 msgstr ""
 
-#: config/i386/i386.c:32495
+#: config/i386/i386.c:32498
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr ""
 
-#: config/i386/i386.c:32657
+#: config/i386/i386.c:32660
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386.c:32662 config/i386/i386.c:32938
-#: config/rs6000/rs6000.c:37850
+#: config/i386/i386.c:32665 config/i386/i386.c:32941
+#: config/rs6000/rs6000.c:37906
 #, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr ""
 
-#: config/i386/i386.c:32795 config/rs6000/rs6000.c:37607
+#: config/i386/i386.c:32798 config/rs6000/rs6000.c:37663
 #, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr ""
 
-#: config/i386/i386.c:33207
+#: config/i386/i386.c:33210
 #, gcc-internal-format
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr ""
 
-#: config/i386/i386.c:33232 config/i386/i386.c:33282
+#: config/i386/i386.c:33235 config/i386/i386.c:33285
 #, gcc-internal-format, gfc-internal-format
 msgid "Parameter to builtin not valid: %s"
 msgstr ""
 
-#: config/i386/i386.c:33975 config/i386/i386.c:35415
+#: config/i386/i386.c:33978 config/i386/i386.c:35418
 #, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:34370
+#: config/i386/i386.c:34373
 #, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:34465
+#: config/i386/i386.c:34468
 #, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:35346
+#: config/i386/i386.c:35349
 #, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:35361
+#: config/i386/i386.c:35364
 #, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:35394
+#: config/i386/i386.c:35397
 #, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:35434
+#: config/i386/i386.c:35437
 #, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:35447
+#: config/i386/i386.c:35450
 #, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:35457
+#: config/i386/i386.c:35460
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:35462 config/i386/i386.c:36249
+#: config/i386/i386.c:35465 config/i386/i386.c:36252
 #, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:35596
+#: config/i386/i386.c:35599
 #, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr ""
 
-#: config/i386/i386.c:35601
+#: config/i386/i386.c:35604
 #, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr ""
 
-#: config/i386/i386.c:35607 config/i386/i386.c:35814
+#: config/i386/i386.c:35610 config/i386/i386.c:35817
 #, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr ""
 
-#: config/i386/i386.c:35796
+#: config/i386/i386.c:35799
 #, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:35802
+#: config/i386/i386.c:35805
 #, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:35805
+#: config/i386/i386.c:35808
 #, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:36247
+#: config/i386/i386.c:36250
 #, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:36329 config/powerpcspe/powerpcspe.c:16219
-#: config/rs6000/rs6000.c:15304
+#: config/i386/i386.c:36332 config/powerpcspe/powerpcspe.c:16219
+#: config/rs6000/rs6000.c:15348
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr ""
 
-#: config/i386/i386.c:36539
+#: config/i386/i386.c:36542
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr ""
 
-#: config/i386/i386.c:36543
+#: config/i386/i386.c:36546
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr ""
 
-#: config/i386/i386.c:37381
+#: config/i386/i386.c:37375
 #, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr ""
 
-#: config/i386/i386.c:38108 config/i386/i386.c:38290
+#: config/i386/i386.c:38102 config/i386/i386.c:38284
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386.c:38343
+#: config/i386/i386.c:38337
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386.c:38349
+#: config/i386/i386.c:38343
 #, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr ""
 
-#: config/i386/i386.c:38368
+#: config/i386/i386.c:38362
 #, gcc-internal-format
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:41431
+#: config/i386/i386.c:41425
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr ""
 
-#: config/i386/i386.c:41452
+#: config/i386/i386.c:41446
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr ""
 
-#: config/i386/i386.c:41485 config/i386/i386.c:41494
+#: config/i386/i386.c:41479 config/i386/i386.c:41488
 #, gcc-internal-format
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:41530 config/powerpcspe/powerpcspe.c:35868
-#: config/rs6000/rs6000.c:33065
+#: config/i386/i386.c:41524 config/powerpcspe/powerpcspe.c:35868
+#: config/rs6000/rs6000.c:33121
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr ""
 
-#: config/i386/i386.c:41555 config/i386/i386.c:41577 config/ia64/ia64.c:815
+#: config/i386/i386.c:41549 config/i386/i386.c:41571 config/ia64/ia64.c:815
 #: config/s390/s390.c:1153
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr ""
 
-#: config/i386/i386.c:41565 config/i386/i386.c:41587 config/s390/s390.c:1182
+#: config/i386/i386.c:41559 config/i386/i386.c:41581 config/s390/s390.c:1182
 #, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr ""
 
-#: config/i386/i386.c:41619
+#: config/i386/i386.c:41613
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386.c:41626
+#: config/i386/i386.c:41620
 #, gcc-internal-format, gfc-internal-format
 msgid "interrupt service routine should have unsigned %sint as the second argument"
 msgstr ""
 
-#: config/i386/i386.c:41636
+#: config/i386/i386.c:41630
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386.c:41639
+#: config/i386/i386.c:41633
 #, gcc-internal-format
 msgid "interrupt service routine can't have non-void return value"
 msgstr ""
 
-#: config/i386/i386.c:44676
+#: config/i386/i386.c:44670
 #, gcc-internal-format
 msgid "alternatives not allowed in asm flag output"
 msgstr ""
 
-#: config/i386/i386.c:44740
+#: config/i386/i386.c:44734
 #, gcc-internal-format
 msgid "unknown asm flag output %qs"
 msgstr ""
 
-#: config/i386/i386.c:44769
+#: config/i386/i386.c:44763
 #, gcc-internal-format
 msgid "invalid type for asm flag output"
 msgstr ""
 
-#: config/i386/i386.c:50634
+#: config/i386/i386.c:50628
 #, gcc-internal-format
 msgid "unknown architecture specific memory model"
 msgstr ""
 
-#: config/i386/i386.c:50641
+#: config/i386/i386.c:50635
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50647
+#: config/i386/i386.c:50641
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50671 config/i386/i386.c:50787
+#: config/i386/i386.c:50665 config/i386/i386.c:50781
 #, gcc-internal-format, gfc-internal-format
 msgid "unsupported simdlen %d"
 msgstr ""
 
-#: config/i386/i386.c:50690
+#: config/i386/i386.c:50684
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd"
 msgstr ""
 
-#: config/i386/i386.c:50712
+#: config/i386/i386.c:50706
 #, gcc-internal-format
 msgid "unsupported argument type %qT for simd"
 msgstr ""
 
-#: config/i386/i386.c:51033
+#: config/i386/i386.c:51027
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr ""
@@ -29930,7 +29972,7 @@
 msgstr ""
 
 #: config/m68k/m68k.c:1128 config/powerpcspe/powerpcspe.c:28512
-#: config/rs6000/rs6000.c:25791
+#: config/rs6000/rs6000.c:25868
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr ""
@@ -30504,58 +30546,58 @@
 
 #. Trampoline is not supported on reduced-set registers yet.
 #: config/nds32/nds32.c:2327 config/nds32/nds32.c:2381
-#: config/nds32/nds32.c:3127 config/nds32/nds32.c:3201
-#: config/nds32/nds32.c:3216 config/nds32/nds32.c:3222
-#: config/nds32/nds32.c:3284 config/nds32/nds32.c:3290
-#: config/nds32/nds32.c:3322
+#: config/nds32/nds32.c:3128 config/nds32/nds32.c:3202
+#: config/nds32/nds32.c:3217 config/nds32/nds32.c:3223
+#: config/nds32/nds32.c:3285 config/nds32/nds32.c:3291
+#: config/nds32/nds32.c:3323
 #, gcc-internal-format
 msgid "a nested function is not supported for reduced registers"
 msgstr ""
 
 #. The enum index value for array size is out of range.
-#: config/nds32/nds32.c:3025
+#: config/nds32/nds32.c:3026
 #, gcc-internal-format
 msgid "intrinsic register index is out of range"
 msgstr ""
 
-#: config/nds32/nds32.c:3041 config/nds32/nds32.c:3048
-#: config/nds32/nds32.c:3055 config/nds32/nds32.c:3062
-#: config/nds32/nds32.c:3069
+#: config/nds32/nds32.c:3042 config/nds32/nds32.c:3049
+#: config/nds32/nds32.c:3056 config/nds32/nds32.c:3063
+#: config/nds32/nds32.c:3070
 #, gcc-internal-format
 msgid "CCTL intrinsic function subtype out of range!"
 msgstr ""
 
-#: config/nds32/nds32.c:3508
+#: config/nds32/nds32.c:3509
 #, gcc-internal-format
 msgid "invalid id value for interrupt/exception attribute"
 msgstr ""
 
-#: config/nds32/nds32.c:3536
+#: config/nds32/nds32.c:3537
 #, gcc-internal-format
 msgid "invalid id value for reset attribute"
 msgstr ""
 
-#: config/nds32/nds32.c:3552
+#: config/nds32/nds32.c:3553
 #, gcc-internal-format
 msgid "invalid nmi function for reset attribute"
 msgstr ""
 
-#: config/nds32/nds32.c:3565
+#: config/nds32/nds32.c:3566
 #, gcc-internal-format
 msgid "invalid warm function for reset attribute"
 msgstr ""
 
-#: config/nds32/nds32.c:3638
+#: config/nds32/nds32.c:3639
 #, gcc-internal-format
 msgid "Disable FPU ISA, the ABI option must be enable '-mfloat-abi=soft'"
 msgstr ""
 
-#: config/nds32/nds32.c:3641
+#: config/nds32/nds32.c:3642
 #, gcc-internal-format
 msgid "'-mabi=2fp+' option only support when FPU available, must be enable '-mext-fpu-sp' or '-mext-fpu-dp'"
 msgstr ""
 
-#: config/nds32/nds32.c:3647
+#: config/nds32/nds32.c:3648
 #, gcc-internal-format
 msgid "position-independent code not supported"
 msgstr ""
@@ -30891,12 +30933,12 @@
 msgid "junk at end of #pragma longcall"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6154
+#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6152
 #, gcc-internal-format
 msgid "vec_lvsl is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6158
+#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6156
 #, gcc-internal-format
 msgid "vec_lvsr is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
@@ -30946,7 +30988,7 @@
 msgid "vec_insert only accepts 3 arguments"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6868
+#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6866
 #, gcc-internal-format
 msgid "passing arg %d of %qE discards qualifiers from pointer target type"
 msgstr ""
@@ -31031,7 +31073,7 @@
 msgid "target attribute or pragma changes SPE ABI"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4351 config/rs6000/rs6000.c:4223
+#: config/powerpcspe/powerpcspe.c:4351 config/rs6000/rs6000.c:4243
 #, gcc-internal-format
 msgid "AltiVec not supported in this target"
 msgstr ""
@@ -31177,7 +31219,7 @@
 msgid "-mvsx-small-integer requires -mpower8-vector, -mupper-regs-di, and -mdirect-move"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4959 config/rs6000/rs6000.c:4601
+#: config/powerpcspe/powerpcspe.c:4959 config/rs6000/rs6000.c:4628
 #, gcc-internal-format
 msgid "target attribute or pragma changes long double size"
 msgstr ""
@@ -31218,22 +31260,22 @@
 msgstr ""
 
 #: config/powerpcspe/powerpcspe.c:5140 config/powerpcspe/powerpcspe.c:5155
-#: config/rs6000/rs6000.c:4766 config/rs6000/rs6000.c:4781
+#: config/rs6000/rs6000.c:4791 config/rs6000/rs6000.c:4806
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:5168 config/rs6000/rs6000.c:4794
+#: config/powerpcspe/powerpcspe.c:5168 config/rs6000/rs6000.c:4819
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:5234 config/rs6000/rs6000.c:4828
+#: config/powerpcspe/powerpcspe.c:5234 config/rs6000/rs6000.c:4853
 #, gcc-internal-format
 msgid "target attribute or pragma changes single precision floating point"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:5237 config/rs6000/rs6000.c:4831
+#: config/powerpcspe/powerpcspe.c:5237 config/rs6000/rs6000.c:4856
 #, gcc-internal-format
 msgid "target attribute or pragma changes double precision floating point"
 msgstr ""
@@ -31243,12 +31285,12 @@
 msgid "-mstack-protector-guard=tls needs a valid base register"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:8415 config/rs6000/rs6000.c:7925
+#: config/powerpcspe/powerpcspe.c:8415 config/rs6000/rs6000.c:7950
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11237
+#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11269
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
@@ -31258,7 +31300,7 @@
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11595
+#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11633
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr ""
@@ -31268,12 +31310,12 @@
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12604
+#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12648
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12779
+#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12823
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
@@ -31283,28 +31325,28 @@
 msgid "internal error: builtin function %s already processed"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:13971
+#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:14015
 #, gcc-internal-format
 msgid "argument 1 must be an 8-bit field value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14015
+#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14059
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr ""
 
 #: config/powerpcspe/powerpcspe.c:14934 config/powerpcspe/powerpcspe.c:16803
-#: config/rs6000/rs6000.c:14101
+#: config/rs6000/rs6000.c:14145
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14119
+#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14163
 #, gcc-internal-format
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14135
+#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14179
 #, gcc-internal-format
 msgid "argument 2 must be a 7-bit unsigned literal"
 msgstr ""
@@ -31324,12 +31366,12 @@
 msgid "builtin %s is only valid in 64-bit mode"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14791
+#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14835
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %d must be an unsigned literal"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14793
+#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14837
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr ""
@@ -31351,53 +31393,53 @@
 msgid "hwcap %s is an invalid argument to builtin %s"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15065
+#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15109
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15090
+#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15134
 #, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15110
+#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15154
 #, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15122
+#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15166
 #, gcc-internal-format
 msgid "argument 1 must be 0 or 2"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15134
+#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15178
 #, gcc-internal-format
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15148
+#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15192
 #, gcc-internal-format
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15160
+#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15204
 #, gcc-internal-format
 msgid "argument 2 must be 0 or 1"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15168
+#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15212
 #, gcc-internal-format
 msgid "argument 3 must be in the range 0..15"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15237
-#: config/rs6000/rs6000.c:15569
+#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15281
+#: config/rs6000/rs6000.c:15613
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15394
+#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15438
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr ""
@@ -31522,7 +31564,7 @@
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25758
+#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25835
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr ""
@@ -31532,12 +31574,12 @@
 msgid "-fsplit-stack uses register r29"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29459
+#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29536
 #, gcc-internal-format
 msgid "Stack frame larger than 2G is not supported for -fsplit-stack"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30447
+#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30524
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr ""
@@ -31547,22 +31589,22 @@
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32830
+#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32907
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32832
+#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32909
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32834
+#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32911
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32836
+#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32913
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr ""
@@ -31572,7 +31614,7 @@
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32845
+#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32922
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr ""
@@ -32114,71 +32156,71 @@
 "Please use an explicit cpu name.  Valid cpu names are: %s"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6168 config/rs6000/rs6000-c.c:6219
-#: config/rs6000/rs6000-c.c:6489 config/rs6000/rs6000-c.c:6555
-#: config/rs6000/rs6000-c.c:6916 config/rs6000/rs6000-c.c:6963
+#: config/rs6000/rs6000-c.c:6166 config/rs6000/rs6000-c.c:6217
+#: config/rs6000/rs6000-c.c:6487 config/rs6000/rs6000-c.c:6553
+#: config/rs6000/rs6000-c.c:6914 config/rs6000/rs6000-c.c:6961
 #, gcc-internal-format
 msgid "builtin %qs only accepts 2 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6292 config/rs6000/rs6000-c.c:6375
-#: config/rs6000/rs6000-c.c:6736
+#: config/rs6000/rs6000-c.c:6290 config/rs6000/rs6000-c.c:6373
+#: config/rs6000/rs6000-c.c:6734
 #, gcc-internal-format
 msgid "builtin %qs only accepts 3 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6484
+#: config/rs6000/rs6000-c.c:6482
 #, gcc-internal-format
 msgid "builtin %qs only accepts 1 argument"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:7054
+#: config/rs6000/rs6000-c.c:7052
 #, gcc-internal-format
 msgid "builtin %qs requires builtin %qs"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:7058
+#: config/rs6000/rs6000-c.c:7056
 #, gcc-internal-format
 msgid "builtin function %qs not supported in this compiler configuration"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:7068
+#: config/rs6000/rs6000-c.c:7066
 #, gcc-internal-format
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3754 config/rs6000/rs6000.c:3757
-#: config/rs6000/rs6000.c:3760
+#: config/rs6000/rs6000.c:3772 config/rs6000/rs6000.c:3775
+#: config/rs6000/rs6000.c:3778
 #, gcc-internal-format
 msgid "%qs requires %qs or %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3861
+#: config/rs6000/rs6000.c:3879
 #, gcc-internal-format
 msgid "%qs requires PowerPC64 architecture, enabling"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4037
+#: config/rs6000/rs6000.c:4057
 #, gcc-internal-format
 msgid "%qs command-line option is deprecated"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4048
+#: config/rs6000/rs6000.c:4068
 #, gcc-internal-format
 msgid "%qs is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4147
+#: config/rs6000/rs6000.c:4167
 #, gcc-internal-format
 msgid "will not generate %qs instructions because assembler lacks %qs support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4240
+#: config/rs6000/rs6000.c:4260
 #, gcc-internal-format
 msgid "%qs is not supported on little endian systems"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4333
+#: config/rs6000/rs6000.c:4353
 #, gcc-internal-format
 msgid "power9 target option is incompatible with %<%s=<xxx>%> for <xxx> less than power9"
 msgstr ""
@@ -32185,7 +32227,7 @@
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:4341
+#: config/rs6000/rs6000.c:4361
 #, gcc-internal-format
 msgid "%qs incompatible with explicitly disabled options"
 msgstr ""
@@ -32194,240 +32236,241 @@
 #. error messages.  However, if users have managed to select
 #. power9-fusion without selecting power8-fusion, they
 #. already know about undocumented flags.
-#: config/rs6000/rs6000.c:4366 config/rs6000/rs6000.c:4373
-#: config/rs6000/rs6000.c:4380 config/rs6000/rs6000.c:4388
-#: config/rs6000/rs6000.c:4407 config/rs6000/rs6000.c:4464
-#: config/rs6000/rs6000.c:4468 config/rs6000/rs6000.c:4485
-#: config/rs6000/rs6000.c:4538 config/rs6000/rs6000.c:4565
-#: config/rs6000/rs6000.c:4580 config/rs6000/rs6000.c:4588
-#: config/rs6000/rs6000.c:4684
+#: config/rs6000/rs6000.c:4386 config/rs6000/rs6000.c:4393
+#: config/rs6000/rs6000.c:4400 config/rs6000/rs6000.c:4408
+#: config/rs6000/rs6000.c:4427 config/rs6000/rs6000.c:4484
+#: config/rs6000/rs6000.c:4488 config/rs6000/rs6000.c:4505
+#: config/rs6000/rs6000.c:4558 config/rs6000/rs6000.c:4585
+#: config/rs6000/rs6000.c:4600 config/rs6000/rs6000.c:4608
+#: config/rs6000/rs6000.c:4709
 #, gcc-internal-format
 msgid "%qs requires %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4625
+#: config/rs6000/rs6000.c:4650
 #, gcc-internal-format
 msgid "Using IEEE extended precision long double"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4627
+#: config/rs6000/rs6000.c:4652
 #, gcc-internal-format
 msgid "Using IBM extended precision long double"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4644
+#: config/rs6000/rs6000.c:4669
 #, gcc-internal-format
 msgid "%qs requires VSX support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4653
+#: config/rs6000/rs6000.c:4678
 #, gcc-internal-format
 msgid "The -mfloat128 option may not be fully supported"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4676
+#: config/rs6000/rs6000.c:4701
 #, gcc-internal-format
 msgid "%qs requires full ISA 3.0 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4743
+#: config/rs6000/rs6000.c:4768
 #, gcc-internal-format
 msgid "unknown vectorization library ABI type (%qs) for %qs switch"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4930
+#: config/rs6000/rs6000.c:4955
 #, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4935
+#: config/rs6000/rs6000.c:4960
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4947
+#: config/rs6000/rs6000.c:4972
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4955
+#: config/rs6000/rs6000.c:4980
 #, gcc-internal-format
 msgid "%qs needs a valid base register"
 msgstr ""
 
-#: config/rs6000/rs6000.c:5253
+#: config/rs6000/rs6000.c:5278
 #, gcc-internal-format
 msgid "unknown option for %<%s=%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:5290
+#: config/rs6000/rs6000.c:5315
 #, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11401
+#: config/rs6000/rs6000.c:11439
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11862
+#: config/rs6000/rs6000.c:11906
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13572
+#: config/rs6000/rs6000.c:13616
 #, gcc-internal-format
 msgid "internal error: builtin function %qs already processed"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14150
+#: config/rs6000/rs6000.c:14194
 #, gcc-internal-format
 msgid "argument 2 must be a 1-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14189
+#: config/rs6000/rs6000.c:14233
 #, gcc-internal-format
 msgid "argument 1 of %qs must be a constant"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14247 config/rs6000/rs6000.c:15898
+#: config/rs6000/rs6000.c:14291 config/rs6000/rs6000.c:15942
 #, gcc-internal-format
 msgid "argument 1 of %qs is out of range"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14742
+#: config/rs6000/rs6000.c:14786
 #, gcc-internal-format
 msgid "builtin %qs is only valid in 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14939
+#: config/rs6000/rs6000.c:14983
 #, gcc-internal-format
 msgid "builtin %qs only accepts a string argument"
 msgstr ""
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000.c:14958
+#: config/rs6000/rs6000.c:15002
 #, gcc-internal-format
 msgid "cpu %qs is an invalid argument to builtin %qs"
 msgstr ""
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000.c:14986
+#: config/rs6000/rs6000.c:15030
 #, gcc-internal-format
 msgid "%s %qs is an invalid argument to builtin %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15012
+#: config/rs6000/rs6000.c:15056
 #, gcc-internal-format
 msgid "builtin %qs needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15616
+#: config/rs6000/rs6000.c:15660
 #, gcc-internal-format
 msgid "second argument to %qs must be 0..12"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15631
+#: config/rs6000/rs6000.c:15675
 #, gcc-internal-format
 msgid "third argument to %qs must be 0..12"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15850
+#: config/rs6000/rs6000.c:15894
 #, gcc-internal-format, gfc-internal-format
 msgid "argument 1 of %s must be a constant"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15932
+#: config/rs6000/rs6000.c:15976
 #, gcc-internal-format
 msgid "builtin function %qs is only valid for the cell processor"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15934 config/rs6000/rs6000.c:15936
-#: config/rs6000/rs6000.c:15938 config/rs6000/rs6000.c:15940
-#: config/rs6000/rs6000.c:15946 config/rs6000/rs6000.c:15948
-#: config/rs6000/rs6000.c:15955 config/rs6000/rs6000.c:15962
-#: config/rs6000/rs6000.c:15969 config/rs6000/rs6000.c:15975
+#: config/rs6000/rs6000.c:15978 config/rs6000/rs6000.c:15980
+#: config/rs6000/rs6000.c:15982 config/rs6000/rs6000.c:15984
+#: config/rs6000/rs6000.c:15990 config/rs6000/rs6000.c:15992
+#: config/rs6000/rs6000.c:15999 config/rs6000/rs6000.c:16006
+#: config/rs6000/rs6000.c:16011 config/rs6000/rs6000.c:16014
+#: config/rs6000/rs6000.c:16018 config/rs6000/rs6000.c:16024
 #, gcc-internal-format
 msgid "builtin function %qs requires the %qs option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15943 config/rs6000/rs6000.c:15952
-#: config/rs6000/rs6000.c:15959 config/rs6000/rs6000.c:15966
+#: config/rs6000/rs6000.c:15987 config/rs6000/rs6000.c:15996
+#: config/rs6000/rs6000.c:16003
 #, gcc-internal-format
 msgid "builtin function %qs requires the %qs and %qs options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15972
+#: config/rs6000/rs6000.c:16021
 #, gcc-internal-format
 msgid "builtin function %qs requires ISA 3.0 IEEE 128-bit floating point"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15978
+#: config/rs6000/rs6000.c:16027
 #, gcc-internal-format
 msgid "builtin function %qs requires the %qs (or newer), and %qs or %qs options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15982
+#: config/rs6000/rs6000.c:16031
 #, gcc-internal-format
 msgid "builtin function %qs is not supported with the current options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18218
+#: config/rs6000/rs6000.c:18290
 #, gcc-internal-format
 msgid "internal error: builtin function %qs had an unexpected return type %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18235
+#: config/rs6000/rs6000.c:18307
 #, gcc-internal-format
 msgid "internal error: builtin function %qs, argument %d had unexpected argument type %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:29451
+#: config/rs6000/rs6000.c:29528
 #, gcc-internal-format
 msgid "%qs uses register r29"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32748
+#: config/rs6000/rs6000.c:32825
 #, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32842
+#: config/rs6000/rs6000.c:32919
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32850
+#: config/rs6000/rs6000.c:32927
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32853
+#: config/rs6000/rs6000.c:32930
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:36876
+#: config/rs6000/rs6000.c:36932
 #, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:36879
+#: config/rs6000/rs6000.c:36935
 #, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr ""
 
-#: config/rs6000/rs6000.c:36881
+#: config/rs6000/rs6000.c:36937
 #, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:37416
+#: config/rs6000/rs6000.c:37472
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:37575
+#: config/rs6000/rs6000.c:37631
 #, gcc-internal-format
 msgid "target_clones attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
@@ -33164,48 +33207,48 @@
 msgid "subprogram %q+F not marked Inline"
 msgstr ""
 
-#: ada/gcc-interface/trans.c:6404
+#: ada/gcc-interface/trans.c:6401
 #, gcc-internal-format
 msgid "out-of-bounds access may be optimized away"
 msgstr ""
 
-#: ada/gcc-interface/trans.c:6406
+#: ada/gcc-interface/trans.c:6403
 #, gcc-internal-format
 msgid "containing loop"
 msgstr ""
 
-#: ada/gcc-interface/utils.c:3887
+#: ada/gcc-interface/utils.c:3890
 #, gcc-internal-format
 msgid "invalid element type for attribute %qs"
 msgstr ""
 
-#: ada/gcc-interface/utils.c:3911
+#: ada/gcc-interface/utils.c:3914
 #, gcc-internal-format
 msgid "number of components of vector not a power of two"
 msgstr ""
 
-#: ada/gcc-interface/utils.c:6037 ada/gcc-interface/utils.c:6215
-#: ada/gcc-interface/utils.c:6322
+#: ada/gcc-interface/utils.c:6043 ada/gcc-interface/utils.c:6220
+#: ada/gcc-interface/utils.c:6327
 #, gcc-internal-format
 msgid "%qs attribute ignored"
 msgstr ""
 
-#: ada/gcc-interface/utils.c:6158
+#: ada/gcc-interface/utils.c:6164
 #, gcc-internal-format
 msgid "%qs attribute requires prototypes with named arguments"
 msgstr ""
 
-#: ada/gcc-interface/utils.c:6167
+#: ada/gcc-interface/utils.c:6173
 #, gcc-internal-format
 msgid "%qs attribute only applies to variadic functions"
 msgstr ""
 
-#: ada/gcc-interface/utils.c:6282
+#: ada/gcc-interface/utils.c:6287
 #, gcc-internal-format
 msgid "%qE attribute has no effect"
 msgstr ""
 
-#: ada/gcc-interface/utils.c:6406
+#: ada/gcc-interface/utils.c:6411
 #, gcc-internal-format
 msgid "attribute %qs applies to array types only"
 msgstr ""
@@ -33221,7 +33264,7 @@
 #. an unprototyped function, it is compile-time undefined;
 #. making it a constraint in that case was rejected in
 #. DR#252.
-#: c/c-convert.c:101 c/c-typeck.c:2175 c/c-typeck.c:6507 c/c-typeck.c:12138
+#: c/c-convert.c:101 c/c-typeck.c:2175 c/c-typeck.c:6512 c/c-typeck.c:12143
 #: cp/typeck.c:2027 cp/typeck.c:7977 cp/typeck.c:8742
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
@@ -33282,7 +33325,7 @@
 msgid "type of array %q+D completed incompatibly with implicit initialization"
 msgstr ""
 
-#: c/c-decl.c:1567 c/c-decl.c:6701 c/c-decl.c:7574 c/c-decl.c:8381
+#: c/c-decl.c:1567 c/c-decl.c:6721 c/c-decl.c:7594 c/c-decl.c:8401
 #, gcc-internal-format
 msgid "originally defined here"
 msgstr ""
@@ -33687,16 +33730,11 @@
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.c:4548 c/c-decl.c:7147
+#: c/c-decl.c:4548 c/c-decl.c:7167
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr ""
 
-#: c/c-decl.c:4635 cp/decl2.c:1520
-#, gcc-internal-format
-msgid "%q+D in declare target directive does not have mappable type"
-msgstr ""
-
 #: c/c-decl.c:4693
 #, gcc-internal-format
 msgid "%q+D is usually a function"
@@ -33722,7 +33760,7 @@
 #. of VLAs themselves count as VLAs, it does not make
 #. sense to permit them to be initialized given that
 #. ordinary VLAs may not be initialized.
-#: c/c-decl.c:4732 c/c-decl.c:4747 c/c-typeck.c:7630
+#: c/c-decl.c:4732 c/c-decl.c:4747 c/c-typeck.c:7635
 #, gcc-internal-format
 msgid "variable-sized object may not be initialized"
 msgstr ""
@@ -33782,202 +33820,207 @@
 msgid "uninitialized const %qD is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:5268
+#: c/c-decl.c:5224 cp/decl.c:7318
 #, gcc-internal-format
+msgid "%q+D in declare target directive does not have mappable type"
+msgstr ""
+
+#: c/c-decl.c:5288
+#, gcc-internal-format
 msgid "ISO C forbids forward parameter declarations"
 msgstr ""
 
-#: c/c-decl.c:5371
+#: c/c-decl.c:5391
 #, gcc-internal-format
 msgid "defining a type in a compound literal is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:5425 c/c-decl.c:5440
+#: c/c-decl.c:5445 c/c-decl.c:5460
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant"
 msgstr ""
 
-#: c/c-decl.c:5435
+#: c/c-decl.c:5455
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant expression"
 msgstr ""
 
-#: c/c-decl.c:5446
+#: c/c-decl.c:5466
 #, gcc-internal-format
 msgid "negative width in bit-field %qs"
 msgstr ""
 
-#: c/c-decl.c:5451
+#: c/c-decl.c:5471
 #, gcc-internal-format
 msgid "zero width for bit-field %qs"
 msgstr ""
 
-#: c/c-decl.c:5461
+#: c/c-decl.c:5481
 #, gcc-internal-format
 msgid "bit-field %qs has invalid type"
 msgstr ""
 
-#: c/c-decl.c:5467
+#: c/c-decl.c:5487
 #, gcc-internal-format
 msgid "cannot declare bit-field %qs with %<warn_if_not_aligned%> type"
 msgstr ""
 
-#: c/c-decl.c:5478
+#: c/c-decl.c:5498
 #, gcc-internal-format
 msgid "type of bit-field %qs is a GCC extension"
 msgstr ""
 
-#: c/c-decl.c:5484
+#: c/c-decl.c:5504
 #, gcc-internal-format
 msgid "width of %qs exceeds its type"
 msgstr ""
 
-#: c/c-decl.c:5497
+#: c/c-decl.c:5517
 #, gcc-internal-format
 msgid "%qs is narrower than values of its type"
 msgstr ""
 
-#: c/c-decl.c:5512
+#: c/c-decl.c:5532
 #, gcc-internal-format
 msgid "ISO C90 forbids array %qE whose size can%'t be evaluated"
 msgstr ""
 
-#: c/c-decl.c:5515
+#: c/c-decl.c:5535
 #, gcc-internal-format
 msgid "ISO C90 forbids array whose size can%'t be evaluated"
 msgstr ""
 
-#: c/c-decl.c:5522
+#: c/c-decl.c:5542
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array %qE"
 msgstr ""
 
-#: c/c-decl.c:5524
+#: c/c-decl.c:5544
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array"
 msgstr ""
 
-#: c/c-decl.c:5733 c/c-decl.c:6107 c/c-decl.c:6117
+#: c/c-decl.c:5753 c/c-decl.c:6127 c/c-decl.c:6137
 #, gcc-internal-format
 msgid "variably modified %qE at file scope"
 msgstr ""
 
-#: c/c-decl.c:5735
+#: c/c-decl.c:5755
 #, gcc-internal-format
 msgid "variably modified field at file scope"
 msgstr ""
 
-#: c/c-decl.c:5755
+#: c/c-decl.c:5775
 #, gcc-internal-format
 msgid "type defaults to %<int%> in declaration of %qE"
 msgstr ""
 
-#: c/c-decl.c:5759
+#: c/c-decl.c:5779
 #, gcc-internal-format
 msgid "type defaults to %<int%> in type name"
 msgstr ""
 
-#: c/c-decl.c:5791
+#: c/c-decl.c:5811
 #, gcc-internal-format
 msgid "duplicate %<const%>"
 msgstr ""
 
-#: c/c-decl.c:5793
+#: c/c-decl.c:5813
 #, gcc-internal-format
 msgid "duplicate %<restrict%>"
 msgstr ""
 
-#: c/c-decl.c:5795
+#: c/c-decl.c:5815
 #, gcc-internal-format
 msgid "duplicate %<volatile%>"
 msgstr ""
 
-#: c/c-decl.c:5797
+#: c/c-decl.c:5817
 #, gcc-internal-format
 msgid "duplicate %<_Atomic%>"
 msgstr ""
 
-#: c/c-decl.c:5800
+#: c/c-decl.c:5820
 #, gcc-internal-format, gfc-internal-format
 msgid "conflicting named address spaces (%s vs %s)"
 msgstr ""
 
-#: c/c-decl.c:5823 c/c-parser.c:2821
+#: c/c-decl.c:5843 c/c-parser.c:2821
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified array type"
 msgstr ""
 
-#: c/c-decl.c:5837
+#: c/c-decl.c:5857
 #, gcc-internal-format
 msgid "function definition declared %<auto%>"
 msgstr ""
 
-#: c/c-decl.c:5839
+#: c/c-decl.c:5859
 #, gcc-internal-format
 msgid "function definition declared %<register%>"
 msgstr ""
 
-#: c/c-decl.c:5841
+#: c/c-decl.c:5861
 #, gcc-internal-format
 msgid "function definition declared %<typedef%>"
 msgstr ""
 
-#: c/c-decl.c:5843
+#: c/c-decl.c:5863
 #, gcc-internal-format
 msgid "function definition declared %qs"
 msgstr ""
 
-#: c/c-decl.c:5861
+#: c/c-decl.c:5881
 #, gcc-internal-format
 msgid "storage class specified for structure field %qE"
 msgstr ""
 
-#: c/c-decl.c:5864
+#: c/c-decl.c:5884
 #, gcc-internal-format
 msgid "storage class specified for structure field"
 msgstr ""
 
-#: c/c-decl.c:5868
+#: c/c-decl.c:5888
 #, gcc-internal-format
 msgid "storage class specified for parameter %qE"
 msgstr ""
 
-#: c/c-decl.c:5871
+#: c/c-decl.c:5891
 #, gcc-internal-format
 msgid "storage class specified for unnamed parameter"
 msgstr ""
 
-#: c/c-decl.c:5874 cp/decl.c:10935
+#: c/c-decl.c:5894 cp/decl.c:10959
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr ""
 
-#: c/c-decl.c:5891
+#: c/c-decl.c:5911
 #, gcc-internal-format
 msgid "%qE initialized and declared %<extern%>"
 msgstr ""
 
-#: c/c-decl.c:5895
+#: c/c-decl.c:5915
 #, gcc-internal-format
 msgid "%qE has both %<extern%> and initializer"
 msgstr ""
 
-#: c/c-decl.c:5900
+#: c/c-decl.c:5920
 #, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<auto%>"
 msgstr ""
 
-#: c/c-decl.c:5904
+#: c/c-decl.c:5924
 #, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<register%>"
 msgstr ""
 
-#: c/c-decl.c:5909
+#: c/c-decl.c:5929
 #, gcc-internal-format
 msgid "nested function %qE declared %<extern%>"
 msgstr ""
 
-#: c/c-decl.c:5912
+#: c/c-decl.c:5932
 #, gcc-internal-format
 msgid "function-scope %qE implicitly auto and declared %qs"
 msgstr ""
@@ -33985,701 +34028,701 @@
 #. Only the innermost declarator (making a parameter be of
 #. array type which is converted to pointer type)
 #. may have static or type qualifiers.
-#: c/c-decl.c:5959 c/c-decl.c:6328
+#: c/c-decl.c:5979 c/c-decl.c:6348
 #, gcc-internal-format
 msgid "static or type qualifiers in non-parameter array declarator"
 msgstr ""
 
-#: c/c-decl.c:6007
+#: c/c-decl.c:6027
 #, gcc-internal-format
 msgid "declaration of %qE as array of voids"
 msgstr ""
 
-#: c/c-decl.c:6009
+#: c/c-decl.c:6029
 #, gcc-internal-format
 msgid "declaration of type name as array of voids"
 msgstr ""
 
-#: c/c-decl.c:6016
+#: c/c-decl.c:6036
 #, gcc-internal-format
 msgid "declaration of %qE as array of functions"
 msgstr ""
 
-#: c/c-decl.c:6019
+#: c/c-decl.c:6039
 #, gcc-internal-format
 msgid "declaration of type name as array of functions"
 msgstr ""
 
-#: c/c-decl.c:6027 c/c-decl.c:8085
+#: c/c-decl.c:6047 c/c-decl.c:8105
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr ""
 
-#: c/c-decl.c:6053
+#: c/c-decl.c:6073
 #, gcc-internal-format
 msgid "size of array %qE has non-integer type"
 msgstr ""
 
-#: c/c-decl.c:6057
+#: c/c-decl.c:6077
 #, gcc-internal-format
 msgid "size of unnamed array has non-integer type"
 msgstr ""
 
-#: c/c-decl.c:6064
+#: c/c-decl.c:6084
 #, gcc-internal-format
 msgid "size of array %qE has incomplete type"
 msgstr ""
 
-#: c/c-decl.c:6067
+#: c/c-decl.c:6087
 #, gcc-internal-format
 msgid "size of unnamed array has incomplete type"
 msgstr ""
 
-#: c/c-decl.c:6078
+#: c/c-decl.c:6098
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array %qE"
 msgstr ""
 
-#: c/c-decl.c:6081
+#: c/c-decl.c:6101
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array"
 msgstr ""
 
-#: c/c-decl.c:6090
+#: c/c-decl.c:6110
 #, gcc-internal-format
 msgid "size of array %qE is negative"
 msgstr ""
 
-#: c/c-decl.c:6092
+#: c/c-decl.c:6112
 #, gcc-internal-format
 msgid "size of unnamed array is negative"
 msgstr ""
 
-#: c/c-decl.c:6216 c/c-decl.c:6871
+#: c/c-decl.c:6236 c/c-decl.c:6891
 #, gcc-internal-format
 msgid "ISO C90 does not support flexible array members"
 msgstr ""
 
 #. C99 6.7.5.2p4
-#: c/c-decl.c:6238
+#: c/c-decl.c:6258
 #, gcc-internal-format
 msgid "%<[*]%> not in a declaration"
 msgstr ""
 
-#: c/c-decl.c:6251
+#: c/c-decl.c:6271
 #, gcc-internal-format
 msgid "array type has incomplete element type %qT"
 msgstr ""
 
-#: c/c-decl.c:6257
+#: c/c-decl.c:6277
 #, gcc-internal-format
 msgid "declaration of %qE as multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: c/c-decl.c:6261
+#: c/c-decl.c:6281
 #, gcc-internal-format
 msgid "declaration of multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: c/c-decl.c:6364
+#: c/c-decl.c:6384
 #, gcc-internal-format
 msgid "%qE declared as function returning a function"
 msgstr ""
 
-#: c/c-decl.c:6367
+#: c/c-decl.c:6387
 #, gcc-internal-format
 msgid "type name declared as function returning a function"
 msgstr ""
 
-#: c/c-decl.c:6374
+#: c/c-decl.c:6394
 #, gcc-internal-format
 msgid "%qE declared as function returning an array"
 msgstr ""
 
-#: c/c-decl.c:6377
+#: c/c-decl.c:6397
 #, gcc-internal-format
 msgid "type name declared as function returning an array"
 msgstr ""
 
-#: c/c-decl.c:6418
+#: c/c-decl.c:6438
 #, gcc-internal-format
 msgid "function definition has qualified void return type"
 msgstr ""
 
-#: c/c-decl.c:6421 cp/decl.c:11201
+#: c/c-decl.c:6441 cp/decl.c:11225
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr ""
 
-#: c/c-decl.c:6459 c/c-decl.c:6668 c/c-decl.c:6721 c/c-decl.c:6805
-#: c/c-decl.c:6926 c/c-parser.c:2823
+#: c/c-decl.c:6479 c/c-decl.c:6688 c/c-decl.c:6741 c/c-decl.c:6825
+#: c/c-decl.c:6946 c/c-parser.c:2823
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified function type"
 msgstr ""
 
-#: c/c-decl.c:6465 c/c-decl.c:6674 c/c-decl.c:6810 c/c-decl.c:6931
+#: c/c-decl.c:6485 c/c-decl.c:6694 c/c-decl.c:6830 c/c-decl.c:6951
 #, gcc-internal-format
 msgid "ISO C forbids qualified function types"
 msgstr ""
 
-#: c/c-decl.c:6559
+#: c/c-decl.c:6579
 #, gcc-internal-format
 msgid "%qs combined with %<auto%> qualifier for %qE"
 msgstr ""
 
-#: c/c-decl.c:6563
+#: c/c-decl.c:6583
 #, gcc-internal-format
 msgid "%qs combined with %<register%> qualifier for %qE"
 msgstr ""
 
-#: c/c-decl.c:6569
+#: c/c-decl.c:6589
 #, gcc-internal-format
 msgid "%qs specified for auto variable %qE"
 msgstr ""
 
-#: c/c-decl.c:6585
+#: c/c-decl.c:6605
 #, gcc-internal-format
 msgid "%qs specified for parameter %qE"
 msgstr ""
 
-#: c/c-decl.c:6588
+#: c/c-decl.c:6608
 #, gcc-internal-format
 msgid "%qs specified for unnamed parameter"
 msgstr ""
 
-#: c/c-decl.c:6594
+#: c/c-decl.c:6614
 #, gcc-internal-format
 msgid "%qs specified for structure field %qE"
 msgstr ""
 
-#: c/c-decl.c:6597
+#: c/c-decl.c:6617
 #, gcc-internal-format
 msgid "%qs specified for structure field"
 msgstr ""
 
-#: c/c-decl.c:6612
+#: c/c-decl.c:6632
 #, gcc-internal-format
 msgid "bit-field %qE has atomic type"
 msgstr ""
 
-#: c/c-decl.c:6614
+#: c/c-decl.c:6634
 #, gcc-internal-format
 msgid "bit-field has atomic type"
 msgstr ""
 
-#: c/c-decl.c:6623
+#: c/c-decl.c:6643
 #, gcc-internal-format
 msgid "alignment specified for typedef %qE"
 msgstr ""
 
-#: c/c-decl.c:6625
+#: c/c-decl.c:6645
 #, gcc-internal-format
 msgid "alignment specified for %<register%> object %qE"
 msgstr ""
 
-#: c/c-decl.c:6630
+#: c/c-decl.c:6650
 #, gcc-internal-format
 msgid "alignment specified for parameter %qE"
 msgstr ""
 
-#: c/c-decl.c:6632
+#: c/c-decl.c:6652
 #, gcc-internal-format
 msgid "alignment specified for unnamed parameter"
 msgstr ""
 
-#: c/c-decl.c:6637
+#: c/c-decl.c:6657
 #, gcc-internal-format
 msgid "alignment specified for bit-field %qE"
 msgstr ""
 
-#: c/c-decl.c:6639
+#: c/c-decl.c:6659
 #, gcc-internal-format
 msgid "alignment specified for unnamed bit-field"
 msgstr ""
 
-#: c/c-decl.c:6642
+#: c/c-decl.c:6662
 #, gcc-internal-format
 msgid "alignment specified for function %qE"
 msgstr ""
 
-#: c/c-decl.c:6649
+#: c/c-decl.c:6669
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of %qE"
 msgstr ""
 
-#: c/c-decl.c:6652
+#: c/c-decl.c:6672
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of unnamed field"
 msgstr ""
 
-#: c/c-decl.c:6683
+#: c/c-decl.c:6703
 #, gcc-internal-format
 msgid "typedef %q+D declared %<inline%>"
 msgstr ""
 
-#: c/c-decl.c:6685
+#: c/c-decl.c:6705
 #, gcc-internal-format
 msgid "typedef %q+D declared %<_Noreturn%>"
 msgstr ""
 
-#: c/c-decl.c:6727
+#: c/c-decl.c:6747
 #, gcc-internal-format
 msgid "ISO C forbids const or volatile function types"
 msgstr ""
 
 #. C99 6.7.2.1p8
-#: c/c-decl.c:6738
+#: c/c-decl.c:6758
 #, gcc-internal-format
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr ""
 
-#: c/c-decl.c:6755 cp/decl.c:9989
+#: c/c-decl.c:6775 cp/decl.c:10010
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr ""
 
-#: c/c-decl.c:6795
+#: c/c-decl.c:6815
 #, gcc-internal-format
 msgid "attributes in parameter array declarator ignored"
 msgstr ""
 
-#: c/c-decl.c:6837
+#: c/c-decl.c:6857
 #, gcc-internal-format
 msgid "parameter %q+D declared %<inline%>"
 msgstr ""
 
-#: c/c-decl.c:6839
+#: c/c-decl.c:6859
 #, gcc-internal-format
 msgid "parameter %q+D declared %<_Noreturn%>"
 msgstr ""
 
-#: c/c-decl.c:6852
+#: c/c-decl.c:6872
 #, gcc-internal-format
 msgid "field %qE declared as a function"
 msgstr ""
 
-#: c/c-decl.c:6859
+#: c/c-decl.c:6879
 #, gcc-internal-format
 msgid "field %qE has incomplete type"
 msgstr ""
 
-#: c/c-decl.c:6861
+#: c/c-decl.c:6881
 #, gcc-internal-format
 msgid "unnamed field has incomplete type"
 msgstr ""
 
-#: c/c-decl.c:6897 c/c-decl.c:6908 c/c-decl.c:6911
+#: c/c-decl.c:6917 c/c-decl.c:6928 c/c-decl.c:6931
 #, gcc-internal-format
 msgid "invalid storage class for function %qE"
 msgstr ""
 
-#: c/c-decl.c:6968
+#: c/c-decl.c:6988
 #, gcc-internal-format
 msgid "cannot inline function %<main%>"
 msgstr ""
 
-#: c/c-decl.c:6970
+#: c/c-decl.c:6990
 #, gcc-internal-format
 msgid "%<main%> declared %<_Noreturn%>"
 msgstr ""
 
-#: c/c-decl.c:6981
+#: c/c-decl.c:7001
 #, gcc-internal-format
 msgid "ISO C99 does not support %<_Noreturn%>"
 msgstr ""
 
-#: c/c-decl.c:6984
+#: c/c-decl.c:7004
 #, gcc-internal-format
 msgid "ISO C90 does not support %<_Noreturn%>"
 msgstr ""
 
-#: c/c-decl.c:7013
+#: c/c-decl.c:7033
 #, gcc-internal-format
 msgid "variable previously declared %<static%> redeclared %<extern%>"
 msgstr ""
 
-#: c/c-decl.c:7023
+#: c/c-decl.c:7043
 #, gcc-internal-format
 msgid "variable %q+D declared %<inline%>"
 msgstr ""
 
-#: c/c-decl.c:7025
+#: c/c-decl.c:7045
 #, gcc-internal-format
 msgid "variable %q+D declared %<_Noreturn%>"
 msgstr ""
 
-#: c/c-decl.c:7060
+#: c/c-decl.c:7080
 #, gcc-internal-format
 msgid "non-nested function with variably modified type"
 msgstr ""
 
-#: c/c-decl.c:7062
+#: c/c-decl.c:7082
 #, gcc-internal-format
 msgid "object with variably modified type must have no linkage"
 msgstr ""
 
-#: c/c-decl.c:7153 c/c-decl.c:8821
+#: c/c-decl.c:7173 c/c-decl.c:8841
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr ""
 
-#: c/c-decl.c:7163
+#: c/c-decl.c:7183
 #, gcc-internal-format
 msgid "parameter names (without types) in function declaration"
 msgstr ""
 
-#: c/c-decl.c:7201
+#: c/c-decl.c:7221
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has incomplete type"
 msgstr ""
 
-#: c/c-decl.c:7205
+#: c/c-decl.c:7225
 #, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has incomplete type"
 msgstr ""
 
-#: c/c-decl.c:7216
+#: c/c-decl.c:7236
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has void type"
 msgstr ""
 
-#: c/c-decl.c:7220
+#: c/c-decl.c:7240
 #, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has void type"
 msgstr ""
 
-#: c/c-decl.c:7294
+#: c/c-decl.c:7314
 #, gcc-internal-format
 msgid "%<void%> as only parameter may not be qualified"
 msgstr ""
 
-#: c/c-decl.c:7298 c/c-decl.c:7334
+#: c/c-decl.c:7318 c/c-decl.c:7354
 #, gcc-internal-format
 msgid "%<void%> must be the only parameter"
 msgstr ""
 
-#: c/c-decl.c:7328
+#: c/c-decl.c:7348
 #, gcc-internal-format
 msgid "parameter %q+D has just a forward declaration"
 msgstr ""
 
-#: c/c-decl.c:7374
+#: c/c-decl.c:7394
 #, gcc-internal-format
 msgid "%<%s %E%> declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr ""
 
-#: c/c-decl.c:7380
+#: c/c-decl.c:7400
 #, gcc-internal-format, gfc-internal-format
 msgid "anonymous %s declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr ""
 
-#: c/c-decl.c:7482
+#: c/c-decl.c:7502
 #, gcc-internal-format
 msgid "enum type defined here"
 msgstr ""
 
-#: c/c-decl.c:7488
+#: c/c-decl.c:7508
 #, gcc-internal-format
 msgid "struct defined here"
 msgstr ""
 
-#: c/c-decl.c:7494
+#: c/c-decl.c:7514
 #, gcc-internal-format
 msgid "union defined here"
 msgstr ""
 
-#: c/c-decl.c:7570
+#: c/c-decl.c:7590
 #, gcc-internal-format
 msgid "redefinition of %<union %E%>"
 msgstr ""
 
-#: c/c-decl.c:7572
+#: c/c-decl.c:7592
 #, gcc-internal-format
 msgid "redefinition of %<struct %E%>"
 msgstr ""
 
-#: c/c-decl.c:7581
+#: c/c-decl.c:7601
 #, gcc-internal-format
 msgid "nested redefinition of %<union %E%>"
 msgstr ""
 
-#: c/c-decl.c:7583
+#: c/c-decl.c:7603
 #, gcc-internal-format
 msgid "nested redefinition of %<struct %E%>"
 msgstr ""
 
-#: c/c-decl.c:7613 c/c-decl.c:8400
+#: c/c-decl.c:7633 c/c-decl.c:8420
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:7680 cp/decl.c:4802
+#: c/c-decl.c:7700 cp/decl.c:4802
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr ""
 
-#: c/c-decl.c:7685
+#: c/c-decl.c:7705
 #, gcc-internal-format
 msgid "ISO C99 doesn%'t support unnamed structs/unions"
 msgstr ""
 
-#: c/c-decl.c:7688
+#: c/c-decl.c:7708
 #, gcc-internal-format
 msgid "ISO C90 doesn%'t support unnamed structs/unions"
 msgstr ""
 
-#: c/c-decl.c:7781 c/c-decl.c:7799 c/c-decl.c:7860
+#: c/c-decl.c:7801 c/c-decl.c:7819 c/c-decl.c:7880
 #, gcc-internal-format
 msgid "duplicate member %q+D"
 msgstr ""
 
-#: c/c-decl.c:7886
+#: c/c-decl.c:7906
 #, gcc-internal-format
 msgid "empty struct has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.c:7889
+#: c/c-decl.c:7909
 #, gcc-internal-format
 msgid "empty union has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.c:7994
+#: c/c-decl.c:8014
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr ""
 
-#: c/c-decl.c:7996
+#: c/c-decl.c:8016
 #, gcc-internal-format
 msgid "union has no members"
 msgstr ""
 
-#: c/c-decl.c:8001
+#: c/c-decl.c:8021
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr ""
 
-#: c/c-decl.c:8003
+#: c/c-decl.c:8023
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr ""
 
-#: c/c-decl.c:8064 cp/decl.c:12069
+#: c/c-decl.c:8084 cp/decl.c:12093
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr ""
 
-#: c/c-decl.c:8070
+#: c/c-decl.c:8090
 #, gcc-internal-format
 msgid "flexible array member not at end of struct"
 msgstr ""
 
-#: c/c-decl.c:8076
+#: c/c-decl.c:8096
 #, gcc-internal-format
 msgid "flexible array member in a struct with no named members"
 msgstr ""
 
-#: c/c-decl.c:8107
+#: c/c-decl.c:8127
 #, gcc-internal-format
 msgid "type %qT is too large"
 msgstr ""
 
-#: c/c-decl.c:8230
+#: c/c-decl.c:8250
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr ""
 
-#: c/c-decl.c:8372
+#: c/c-decl.c:8392
 #, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr ""
 
 #. This enum is a named one that has been declared already.
-#: c/c-decl.c:8379
+#: c/c-decl.c:8399
 #, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr ""
 
-#: c/c-decl.c:8458 cp/decl.c:14423
+#: c/c-decl.c:8478 cp/decl.c:14447
 #, gcc-internal-format
 msgid "specified mode too small for enumeral values"
 msgstr ""
 
-#: c/c-decl.c:8473
+#: c/c-decl.c:8493
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr ""
 
-#: c/c-decl.c:8587 c/c-decl.c:8603
+#: c/c-decl.c:8607 c/c-decl.c:8623
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr ""
 
-#: c/c-decl.c:8598
+#: c/c-decl.c:8618
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr ""
 
-#: c/c-decl.c:8622
+#: c/c-decl.c:8642
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr ""
 
-#: c/c-decl.c:8630
+#: c/c-decl.c:8650
 #, gcc-internal-format
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr ""
 
-#: c/c-decl.c:8715 cp/decl.c:5104 cp/decl.c:14955
+#: c/c-decl.c:8735 cp/decl.c:5104 cp/decl.c:14979
 #, gcc-internal-format
 msgid "inline function %qD given attribute noinline"
 msgstr ""
 
-#: c/c-decl.c:8733
+#: c/c-decl.c:8753
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr ""
 
-#: c/c-decl.c:8744
+#: c/c-decl.c:8764
 #, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr ""
 
-#: c/c-decl.c:8771
+#: c/c-decl.c:8791
 #, gcc-internal-format
 msgid "%q+D defined as variadic function without prototype"
 msgstr ""
 
-#: c/c-decl.c:8830
+#: c/c-decl.c:8850
 #, gcc-internal-format
 msgid "no previous prototype for %qD"
 msgstr ""
 
-#: c/c-decl.c:8839
+#: c/c-decl.c:8859
 #, gcc-internal-format
 msgid "%qD was used with no prototype before its definition"
 msgstr ""
 
-#: c/c-decl.c:8847 cp/decl.c:15090
+#: c/c-decl.c:8867 cp/decl.c:15114
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr ""
 
-#: c/c-decl.c:8857
+#: c/c-decl.c:8877
 #, gcc-internal-format
 msgid "%qD was used with no declaration before its definition"
 msgstr ""
 
-#: c/c-decl.c:8876
+#: c/c-decl.c:8896
 #, gcc-internal-format
 msgid "return type of %qD is not %<int%>"
 msgstr ""
 
-#: c/c-decl.c:8878
+#: c/c-decl.c:8898
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr ""
 
-#: c/c-decl.c:8885
+#: c/c-decl.c:8905
 #, gcc-internal-format
 msgid "%qD is normally a non-static function"
 msgstr ""
 
-#: c/c-decl.c:8922
+#: c/c-decl.c:8942
 #, gcc-internal-format
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr ""
 
-#: c/c-decl.c:8937
+#: c/c-decl.c:8957
 #, gcc-internal-format
 msgid "traditional C rejects ISO C style function definitions"
 msgstr ""
 
-#: c/c-decl.c:8953
+#: c/c-decl.c:8973
 #, gcc-internal-format
 msgid "parameter name omitted"
 msgstr ""
 
-#: c/c-decl.c:8990
+#: c/c-decl.c:9010
 #, gcc-internal-format
 msgid "old-style function definition"
 msgstr ""
 
-#: c/c-decl.c:8999
+#: c/c-decl.c:9019
 #, gcc-internal-format
 msgid "parameter name missing from parameter list"
 msgstr ""
 
-#: c/c-decl.c:9015
+#: c/c-decl.c:9035
 #, gcc-internal-format
 msgid "%qD declared as a non-parameter"
 msgstr ""
 
-#: c/c-decl.c:9023
+#: c/c-decl.c:9043
 #, gcc-internal-format
 msgid "multiple parameters named %qD"
 msgstr ""
 
-#: c/c-decl.c:9032
+#: c/c-decl.c:9052
 #, gcc-internal-format
 msgid "parameter %qD declared with void type"
 msgstr ""
 
-#: c/c-decl.c:9061 c/c-decl.c:9066
+#: c/c-decl.c:9081 c/c-decl.c:9086
 #, gcc-internal-format
 msgid "type of %qD defaults to %<int%>"
 msgstr ""
 
-#: c/c-decl.c:9086
+#: c/c-decl.c:9106
 #, gcc-internal-format
 msgid "parameter %qD has incomplete type"
 msgstr ""
 
-#: c/c-decl.c:9093
+#: c/c-decl.c:9113
 #, gcc-internal-format
 msgid "declaration for parameter %qD but no such parameter"
 msgstr ""
 
-#: c/c-decl.c:9146
+#: c/c-decl.c:9166
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr ""
 
-#: c/c-decl.c:9157
+#: c/c-decl.c:9177
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr ""
 
-#: c/c-decl.c:9160 c/c-decl.c:9207 c/c-decl.c:9221
+#: c/c-decl.c:9180 c/c-decl.c:9227 c/c-decl.c:9241
 #, gcc-internal-format
 msgid "prototype declaration"
 msgstr ""
 
-#: c/c-decl.c:9199
+#: c/c-decl.c:9219
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr ""
 
-#: c/c-decl.c:9204
+#: c/c-decl.c:9224
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr ""
 
-#: c/c-decl.c:9214
+#: c/c-decl.c:9234
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr ""
 
-#: c/c-decl.c:9219
+#: c/c-decl.c:9239
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr ""
 
-#: c/c-decl.c:9470 cp/decl.c:15873
+#: c/c-decl.c:9490 cp/decl.c:15897
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr ""
 
-#: c/c-decl.c:9490 cp/decl.c:15905
+#: c/c-decl.c:9510 cp/decl.c:15929
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr ""
@@ -34687,247 +34730,247 @@
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:9586
+#: c/c-decl.c:9606
 #, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr ""
 
-#: c/c-decl.c:9591
+#: c/c-decl.c:9611
 #, gcc-internal-format
 msgid "use option -std=c99, -std=gnu99, -std=c11 or -std=gnu11 to compile your code"
 msgstr ""
 
-#: c/c-decl.c:9626
+#: c/c-decl.c:9646
 #, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:9630
+#: c/c-decl.c:9650
 #, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:9637
+#: c/c-decl.c:9657
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:9642
+#: c/c-decl.c:9662
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:9646
+#: c/c-decl.c:9666
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:9650
+#: c/c-decl.c:9670
 #, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:9900
+#: c/c-decl.c:9920
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr ""
 
-#: c/c-decl.c:9958 c/c-decl.c:9965
+#: c/c-decl.c:9978 c/c-decl.c:9985
 #, gcc-internal-format
 msgid "duplicate %qE declaration specifier"
 msgstr ""
 
-#: c/c-decl.c:9992 c/c-decl.c:10376 c/c-decl.c:10766
+#: c/c-decl.c:10012 c/c-decl.c:10396 c/c-decl.c:10786
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr ""
 
-#: c/c-decl.c:10004 cp/parser.c:28261
+#: c/c-decl.c:10024 cp/parser.c:28258
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr ""
 
-#: c/c-decl.c:10017
+#: c/c-decl.c:10037
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr ""
 
-#: c/c-decl.c:10246 c/c-parser.c:8848
+#: c/c-decl.c:10266 c/c-parser.c:8848
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr ""
 
-#: c/c-decl.c:10292
+#: c/c-decl.c:10312
 #, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr ""
 
-#: c/c-decl.c:10363 c/c-decl.c:10923
+#: c/c-decl.c:10383 c/c-decl.c:10943
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr ""
 
-#: c/c-decl.c:10419
+#: c/c-decl.c:10439
 #, gcc-internal-format
 msgid "ISO C does not support %<__int%d%> types"
 msgstr ""
 
-#: c/c-decl.c:10441
+#: c/c-decl.c:10461
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr ""
 
-#: c/c-decl.c:10484
+#: c/c-decl.c:10504
 #, gcc-internal-format
 msgid "ISO C90 does not support boolean types"
 msgstr ""
 
-#: c/c-decl.c:10603
+#: c/c-decl.c:10623
 #, gcc-internal-format
 msgid "ISO C does not support the %<_Float%d%s%> type"
 msgstr ""
 
-#: c/c-decl.c:10653
+#: c/c-decl.c:10673
 #, gcc-internal-format
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr ""
 
-#: c/c-decl.c:10724
+#: c/c-decl.c:10744
 #, gcc-internal-format
 msgid "ISO C does not support decimal floating point"
 msgstr ""
 
-#: c/c-decl.c:10747 c/c-decl.c:11013 c/c-parser.c:7842
+#: c/c-decl.c:10767 c/c-decl.c:11033 c/c-parser.c:7842
 #, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr ""
 
-#: c/c-decl.c:10749
+#: c/c-decl.c:10769
 #, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr ""
 
-#: c/c-decl.c:10784
+#: c/c-decl.c:10804
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr ""
 
-#: c/c-decl.c:10797
+#: c/c-decl.c:10817
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr ""
 
-#: c/c-decl.c:10845
+#: c/c-decl.c:10865
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr ""
 
-#: c/c-decl.c:10866
+#: c/c-decl.c:10886
 #, gcc-internal-format
 msgid "%qE used with %<auto%>"
 msgstr ""
 
-#: c/c-decl.c:10868
+#: c/c-decl.c:10888
 #, gcc-internal-format
 msgid "%qE used with %<register%>"
 msgstr ""
 
-#: c/c-decl.c:10870
+#: c/c-decl.c:10890
 #, gcc-internal-format
 msgid "%qE used with %<typedef%>"
 msgstr ""
 
-#: c/c-decl.c:10884 c/c-parser.c:7360
+#: c/c-decl.c:10904 c/c-parser.c:7360
 #, gcc-internal-format
 msgid "ISO C99 does not support %qE"
 msgstr ""
 
-#: c/c-decl.c:10887 c/c-parser.c:7363
+#: c/c-decl.c:10907 c/c-parser.c:7363
 #, gcc-internal-format
 msgid "ISO C90 does not support %qE"
 msgstr ""
 
-#: c/c-decl.c:10899
+#: c/c-decl.c:10919
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr ""
 
-#: c/c-decl.c:10908
+#: c/c-decl.c:10928
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr ""
 
-#: c/c-decl.c:10921
+#: c/c-decl.c:10941
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr ""
 
-#: c/c-decl.c:10929
+#: c/c-decl.c:10949
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr ""
 
-#: c/c-decl.c:10937
+#: c/c-decl.c:10957
 #, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr ""
 
-#: c/c-decl.c:11010
+#: c/c-decl.c:11030
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr ""
 
-#: c/c-decl.c:11025
+#: c/c-decl.c:11045
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr ""
 
-#: c/c-decl.c:11076 c/c-decl.c:11092 c/c-decl.c:11118
+#: c/c-decl.c:11096 c/c-decl.c:11112 c/c-decl.c:11138
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr ""
 
-#: c/c-decl.c:11514 cp/semantics.c:5348
+#: c/c-decl.c:11534 cp/semantics.c:5351
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:11518 cp/semantics.c:5352
+#: c/c-decl.c:11538 cp/semantics.c:5355
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.c:385 c/c-typeck.c:11426 cp/typeck.c:4680
+#: c/c-fold.c:385 c/c-typeck.c:11431 cp/typeck.c:4680
 #, gcc-internal-format
 msgid "left shift of negative value"
 msgstr ""
 
-#: c/c-fold.c:395 c/c-typeck.c:11435 cp/typeck.c:4688
+#: c/c-fold.c:395 c/c-typeck.c:11440 cp/typeck.c:4688
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr ""
 
-#: c/c-fold.c:396 c/c-typeck.c:11365 cp/typeck.c:4633
+#: c/c-fold.c:396 c/c-typeck.c:11370 cp/typeck.c:4633
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr ""
 
-#: c/c-fold.c:404 c/c-typeck.c:11454 cp/typeck.c:4696
+#: c/c-fold.c:404 c/c-typeck.c:11459 cp/typeck.c:4696
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr ""
 
-#: c/c-fold.c:405 c/c-typeck.c:11389 cp/typeck.c:4641
+#: c/c-fold.c:405 c/c-typeck.c:11394 cp/typeck.c:4641
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr ""
 
-#: c/c-fold.c:412 c/c-typeck.c:11446
+#: c/c-fold.c:412 c/c-typeck.c:11451
 #, gcc-internal-format
 msgid "left shift count >= width of vector element"
 msgstr ""
 
-#: c/c-fold.c:413 c/c-typeck.c:11376
+#: c/c-fold.c:413 c/c-typeck.c:11381
 #, gcc-internal-format
 msgid "right shift count >= width of vector element"
 msgstr ""
@@ -34947,7 +34990,7 @@
 msgid "to match this %qs"
 msgstr ""
 
-#: c/c-parser.c:1216 cp/parser.c:28484
+#: c/c-parser.c:1216 cp/parser.c:28481
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr "očekujem kraj retka"
@@ -34988,7 +35031,7 @@
 msgstr ""
 
 #: c/c-parser.c:1848 c/c-parser.c:11129 c/c-parser.c:16147 c/c-parser.c:16585
-#: c/c-parser.c:17061 cp/parser.c:36007 cp/parser.c:38993
+#: c/c-parser.c:17061 cp/parser.c:36004 cp/parser.c:38990
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr ""
@@ -35003,7 +35046,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr ""
 
-#: c/c-parser.c:1906 cp/parser.c:30161 cp/parser.c:30235
+#: c/c-parser.c:1906 cp/parser.c:30158 cp/parser.c:30232
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr ""
@@ -35057,7 +35100,7 @@
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr ""
 
-#: c/c-parser.c:2220 cp/parser.c:13002 cp/parser.c:13159
+#: c/c-parser.c:2220 cp/parser.c:12999 cp/parser.c:13156
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr ""
@@ -35085,7 +35128,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr ""
 
-#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38634
+#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38631
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr ""
@@ -35149,13 +35192,13 @@
 #: c/c-parser.c:10745 c/c-parser.c:10798 c/c-parser.c:10814 c/c-parser.c:10860
 #: c/c-parser.c:11496 c/c-parser.c:11537 c/c-parser.c:13445 c/c-parser.c:13681
 #: c/c-parser.c:15544 c/c-parser.c:18218 c/gimple-parser.c:1058
-#: c/gimple-parser.c:1096 cp/parser.c:28487 cp/parser.c:31013
-#: cp/parser.c:31043 cp/parser.c:31113 cp/parser.c:33230 cp/parser.c:38350
+#: c/gimple-parser.c:1096 cp/parser.c:28484 cp/parser.c:31010
+#: cp/parser.c:31040 cp/parser.c:31110 cp/parser.c:33227 cp/parser.c:38347
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr ""
 
-#: c/c-parser.c:2995 cp/parser.c:18384
+#: c/c-parser.c:2995 cp/parser.c:18381
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr ""
@@ -35324,12 +35367,12 @@
 msgid "expected statement"
 msgstr ""
 
-#: c/c-parser.c:5639 cp/parser.c:12516
+#: c/c-parser.c:5639 cp/parser.c:12513
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr ""
 
-#: c/c-parser.c:5681 cp/parser.c:12519
+#: c/c-parser.c:5681 cp/parser.c:12516
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr ""
@@ -35668,7 +35711,7 @@
 msgid "%<__builtin_complex%> operands of different types"
 msgstr ""
 
-#: c/c-parser.c:8891 cp/parser.c:6918
+#: c/c-parser.c:8891 cp/parser.c:6921
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_shuffle%>"
 msgstr ""
@@ -35728,76 +35771,76 @@
 msgid "no type or storage class may be specified here,"
 msgstr ""
 
-#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31073
+#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31070
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr ""
 
-#: c/c-parser.c:10682 cp/parser.c:31033
+#: c/c-parser.c:10682 cp/parser.c:31030
 #, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr ""
 
-#: c/c-parser.c:10685 cp/parser.c:31036
+#: c/c-parser.c:10685 cp/parser.c:31033
 #, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr ""
 
-#: c/c-parser.c:10699 cp/parser.c:31051
+#: c/c-parser.c:10699 cp/parser.c:31048
 #, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr ""
 
-#: c/c-parser.c:10704 cp/parser.c:31057
+#: c/c-parser.c:10704 cp/parser.c:31054
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.c:10711 cp/parser.c:31065
+#: c/c-parser.c:10711 cp/parser.c:31062
 #, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr ""
 
-#: c/c-parser.c:10905 cp/parser.c:38674
+#: c/c-parser.c:10905 cp/parser.c:38671
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
 #: c/c-parser.c:10949 c/c-parser.c:16582 c/c-parser.c:16840 c/c-parser.c:16899
-#: c/c-parser.c:16983 cp/parser.c:36004 cp/parser.c:36298 cp/parser.c:36386
-#: cp/parser.c:36457 cp/parser.c:38721 cp/parser.c:38736 cp/parser.c:38752
-#: cp/parser.c:38768 cp/parser.c:38784 cp/parser.c:38811 cp/parser.c:38824
-#: cp/parser.c:38847 cp/parser.c:38860
+#: c/c-parser.c:16983 cp/parser.c:36001 cp/parser.c:36295 cp/parser.c:36383
+#: cp/parser.c:36454 cp/parser.c:38718 cp/parser.c:38733 cp/parser.c:38749
+#: cp/parser.c:38765 cp/parser.c:38781 cp/parser.c:38808 cp/parser.c:38821
+#: cp/parser.c:38844 cp/parser.c:38857
 #, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:10972 cp/parser.c:38837
+#: c/c-parser.c:10972 cp/parser.c:38834
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr ""
 
-#: c/c-parser.c:11050 cp/parser.c:38918
+#: c/c-parser.c:11050 cp/parser.c:38915
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr ""
 
-#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38947 cp/parser.c:38980
+#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38944 cp/parser.c:38977
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr ""
 
-#: c/c-parser.c:11111 cp/parser.c:38711
+#: c/c-parser.c:11111 cp/parser.c:38708
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr ""
 
-#: c/c-parser.c:11421 cp/parser.c:31457
+#: c/c-parser.c:11421 cp/parser.c:31454
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr ""
 
-#: c/c-parser.c:11443 cp/parser.c:31994
+#: c/c-parser.c:11443 cp/parser.c:31991
 #, gcc-internal-format
 msgid "expected integer expression before ')'"
 msgstr ""
@@ -35812,56 +35855,56 @@
 msgid "%qD is not a variable"
 msgstr ""
 
-#: c/c-parser.c:11746 cp/semantics.c:6808
+#: c/c-parser.c:11746 cp/semantics.c:6811
 #, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr ""
 
-#: c/c-parser.c:11788 cp/parser.c:32073
+#: c/c-parser.c:11788 cp/parser.c:32070
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:11865 cp/parser.c:32137
+#: c/c-parser.c:11865 cp/parser.c:32134
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%>"
 msgid "expected %<none%> or %<present%>"
 msgstr "očekujem %<,%> ili %<)%>"
 
-#: c/c-parser.c:11867 cp/parser.c:32139
+#: c/c-parser.c:11867 cp/parser.c:32136
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr ""
 
-#: c/c-parser.c:11968 cp/parser.c:32242
+#: c/c-parser.c:11968 cp/parser.c:32239
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "očekujem %<;%>, %<,%> ili %<)%>"
 
-#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32260
-#: cp/parser.c:36290 cp/parser.c:36378
+#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32257
+#: cp/parser.c:36287 cp/parser.c:36375
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>"
 msgid "expected %<data%>"
 msgstr "očekujem %<;%>"
 
-#: c/c-parser.c:12035 cp/parser.c:32313
+#: c/c-parser.c:12035 cp/parser.c:32310
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:12042 cp/parser.c:32320
+#: c/c-parser.c:12042 cp/parser.c:32317
 #, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr ""
 
-#: c/c-parser.c:12044 cp/parser.c:32322
+#: c/c-parser.c:12044 cp/parser.c:32319
 #, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr ""
 
-#: c/c-parser.c:12050 cp/parser.c:32328
+#: c/c-parser.c:12050 cp/parser.c:32325
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -35883,85 +35926,85 @@
 msgid "%<num_tasks%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:12229 cp/semantics.c:6992
+#: c/c-parser.c:12229 cp/semantics.c:6995
 #, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:12276 cp/semantics.c:7021
+#: c/c-parser.c:12276 cp/semantics.c:7024
 #, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr ""
 
-#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32545 cp/parser.c:32552
+#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32542 cp/parser.c:32549
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>"
 msgid "expected %<tofrom%>"
 msgstr "očekujem %<;%>"
 
-#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32561 cp/parser.c:32568
+#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32558 cp/parser.c:32565
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>"
 msgid "expected %<scalar%>"
 msgstr "očekujem %<;%>"
 
-#: c/c-parser.c:12425 cp/semantics.c:6299
+#: c/c-parser.c:12425 cp/semantics.c:6302
 #, gcc-internal-format
 msgid "%qs expression must be integral"
 msgstr ""
 
-#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6331
+#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6334
 #, gcc-internal-format
 msgid "%qs value must be positive"
 msgstr ""
 
-#: c/c-parser.c:12499 cp/parser.c:31853
+#: c/c-parser.c:12499 cp/parser.c:31850
 #, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr ""
 
-#: c/c-parser.c:12533 cp/parser.c:31886
+#: c/c-parser.c:12533 cp/parser.c:31883
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<@end%>"
 msgid "unexpected argument"
 msgstr "očekujem %<@end%>"
 
-#: c/c-parser.c:12699 cp/semantics.c:7120
+#: c/c-parser.c:12699 cp/semantics.c:7123
 #, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr ""
 
-#: c/c-parser.c:12765 cp/parser.c:32626
+#: c/c-parser.c:12765 cp/parser.c:32623
 #, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37643
+#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37640
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr ""
 
-#: c/c-parser.c:12967 cp/parser.c:32840
+#: c/c-parser.c:12967 cp/parser.c:32837
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr ""
 
-#: c/c-parser.c:13021 cp/parser.c:32856
+#: c/c-parser.c:13021 cp/parser.c:32853
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:13025 cp/parser.c:32859
+#: c/c-parser.c:13025 cp/parser.c:32856
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:13037 cp/semantics.c:6389
+#: c/c-parser.c:13037 cp/semantics.c:6392
 #, gcc-internal-format
 msgid "chunk size value must be positive"
 msgstr ""
 
-#: c/c-parser.c:13060 cp/parser.c:32879
+#: c/c-parser.c:13060 cp/parser.c:32876
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr ""
@@ -35971,12 +36014,12 @@
 msgid "%<num_teams%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:13226 cp/semantics.c:6479
+#: c/c-parser.c:13226 cp/semantics.c:6482
 #, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:13271 cp/semantics.c:6589
+#: c/c-parser.c:13271 cp/semantics.c:6592
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr ""
@@ -35996,19 +36039,19 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:13584 cp/parser.c:33374 cp/parser.c:33599
+#: c/c-parser.c:13584 cp/parser.c:33371 cp/parser.c:33596
 #, fuzzy, gcc-internal-format
 #| msgid "invalid expression as operand"
 msgid "invalid depend kind"
 msgstr "neispravni izraz kao operand"
 
-#: c/c-parser.c:13669 cp/parser.c:33447
+#: c/c-parser.c:13669 cp/parser.c:33444
 #, fuzzy, gcc-internal-format
 #| msgid "invalid 'asm': "
 msgid "invalid map kind"
 msgstr "neispravni „asm”: "
 
-#: c/c-parser.c:13767 cp/parser.c:33546
+#: c/c-parser.c:13767 cp/parser.c:33543
 #, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr ""
@@ -36018,68 +36061,68 @@
 msgid "invalid proc_bind kind"
 msgstr ""
 
-#: c/c-parser.c:14059 cp/parser.c:33825
+#: c/c-parser.c:14059 cp/parser.c:33822
 #, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr ""
 
-#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33836 cp/parser.c:34143
+#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33833 cp/parser.c:34140
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr ""
 
-#: c/c-parser.c:14214 cp/parser.c:34010
+#: c/c-parser.c:14214 cp/parser.c:34007
 #, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr ""
 
-#: c/c-parser.c:14334 cp/parser.c:34132
+#: c/c-parser.c:14334 cp/parser.c:34129
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr ""
 
-#: c/c-parser.c:14472 cp/parser.c:36803
+#: c/c-parser.c:14472 cp/parser.c:36800
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14482 cp/parser.c:36813
+#: c/c-parser.c:14482 cp/parser.c:36810
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14502 cp/parser.c:36833
+#: c/c-parser.c:14502 cp/parser.c:36830
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr ""
 
-#: c/c-parser.c:14513 cp/parser.c:36844
+#: c/c-parser.c:14513 cp/parser.c:36841
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr ""
 
-#: c/c-parser.c:14520 cp/parser.c:36851
+#: c/c-parser.c:14520 cp/parser.c:36848
 #, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14528 cp/parser.c:36859
+#: c/c-parser.c:14528 cp/parser.c:36856
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14540 cp/parser.c:36871
+#: c/c-parser.c:14540 cp/parser.c:36868
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14632 cp/parser.c:36957
+#: c/c-parser.c:14632 cp/parser.c:36954
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%>"
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "očekujem %<,%> ili %<)%>"
 
-#: c/c-parser.c:14648 cp/parser.c:36974
+#: c/c-parser.c:14648 cp/parser.c:36971
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr ""
@@ -36095,7 +36138,7 @@
 msgid "expected function name"
 msgstr "očekujem kraj retka"
 
-#: c/c-parser.c:14893 cp/parser.c:38064
+#: c/c-parser.c:14893 cp/parser.c:38061
 #, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr ""
@@ -36105,42 +36148,42 @@
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14953 cp/parser.c:38118 cp/parser.c:38160
+#: c/c-parser.c:14953 cp/parser.c:38115 cp/parser.c:38157
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14970 cp/parser.c:38174
+#: c/c-parser.c:14970 cp/parser.c:38171
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> already applied to %qD"
 msgstr ""
 
-#: c/c-parser.c:14979 cp/parser.c:38183
+#: c/c-parser.c:14979 cp/parser.c:38180
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr ""
 
-#: c/c-parser.c:14980 cp/parser.c:38184
+#: c/c-parser.c:14980 cp/parser.c:38181
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr ""
 
-#: c/c-parser.c:15023 cp/parser.c:37152
+#: c/c-parser.c:15023 cp/parser.c:37149
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
 
-#: c/c-parser.c:15435 cp/parser.c:34511 cp/parser.c:34537
+#: c/c-parser.c:15435 cp/parser.c:34508 cp/parser.c:34534
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr ""
 
-#: c/c-parser.c:15439 cp/parser.c:34568 cp/parser.c:34584
+#: c/c-parser.c:15439 cp/parser.c:34565 cp/parser.c:34581
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr ""
 
-#: c/c-parser.c:15488 cp/semantics.c:8401 cp/semantics.c:8411
+#: c/c-parser.c:15488 cp/semantics.c:8404 cp/semantics.c:8414
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
@@ -36150,22 +36193,22 @@
 msgid "expected %<(%> or end of line"
 msgstr ""
 
-#: c/c-parser.c:15619 cp/parser.c:35103
+#: c/c-parser.c:15619 cp/parser.c:35100
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:15630 cp/parser.c:35114
+#: c/c-parser.c:15630 cp/parser.c:35111
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:15648 cp/parser.c:35141
+#: c/c-parser.c:15648 cp/parser.c:35138
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr ""
 
-#: c/c-parser.c:15718 cp/semantics.c:8066 cp/semantics.c:8153
+#: c/c-parser.c:15718 cp/semantics.c:8069 cp/semantics.c:8156
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr ""
@@ -36175,74 +36218,74 @@
 msgid "not enough perfectly nested loops"
 msgstr ""
 
-#: c/c-parser.c:15862 cp/parser.c:35364
+#: c/c-parser.c:15862 cp/parser.c:35361
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.c:15909 cp/parser.c:35184 cp/parser.c:35226 cp/pt.c:16385
+#: c/c-parser.c:15909 cp/parser.c:35181 cp/parser.c:35223 cp/pt.c:16407
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr ""
 
-#: c/c-parser.c:16000 cp/parser.c:35437
+#: c/c-parser.c:16000 cp/parser.c:35434
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr ""
 
-#: c/c-parser.c:16166 cp/parser.c:35600
+#: c/c-parser.c:16166 cp/parser.c:35597
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:16374 cp/parser.c:35799
+#: c/c-parser.c:16374 cp/parser.c:35796
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%>"
 msgid "expected %<for%> after %qs"
 msgstr "očekujem %<,%> ili %<)%>"
 
-#: c/c-parser.c:16573 cp/parser.c:35995
+#: c/c-parser.c:16573 cp/parser.c:35992
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>"
 msgid "expected %<point%>"
 msgstr "očekujem %<;%>"
 
-#: c/c-parser.c:16793 cp/parser.c:36232
+#: c/c-parser.c:16793 cp/parser.c:36229
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16806 cp/parser.c:36245
+#: c/c-parser.c:16806 cp/parser.c:36242
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16853 cp/parser.c:36470
+#: c/c-parser.c:16853 cp/parser.c:36467
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:16925 cp/parser.c:36325
+#: c/c-parser.c:16925 cp/parser.c:36322
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16937 cp/parser.c:36337
+#: c/c-parser.c:16937 cp/parser.c:36334
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17011 cp/parser.c:36414
+#: c/c-parser.c:17011 cp/parser.c:36411
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17024 cp/parser.c:36427
+#: c/c-parser.c:17024 cp/parser.c:36424
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17238 cp/parser.c:36680
+#: c/c-parser.c:17238 cp/parser.c:36677
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -36262,34 +36305,34 @@
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17395 cp/parser.c:37273
+#: c/c-parser.c:17395 cp/parser.c:37270
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17474 cp/parser.c:37343
+#: c/c-parser.c:17474 cp/parser.c:37340
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> with clauses in between %<#pragma omp declare target%> without clauses and %<#pragma omp end declare target%>"
 msgstr ""
 
-#: c/c-parser.c:17493 cp/parser.c:37362
+#: c/c-parser.c:17493 cp/parser.c:37359
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17534 cp/parser.c:37409
+#: c/c-parser.c:17534 cp/parser.c:37406
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>"
 msgid "expected %<target%>"
 msgstr "očekujem %<;%>"
 
-#: c/c-parser.c:17541 cp/parser.c:37416
+#: c/c-parser.c:17541 cp/parser.c:37413
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<while%>"
 msgid "expected %<declare%>"
 msgstr "očekujem %<while%>"
 
-#: c/c-parser.c:17547 cp/parser.c:37423
+#: c/c-parser.c:17547 cp/parser.c:37420
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr ""
@@ -36345,48 +36388,48 @@
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:17947 cp/parser.c:37868
+#: c/c-parser.c:17947 cp/parser.c:37865
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr "očekujem %<;%>, %<,%> ili %<)%>"
 
-#: c/c-parser.c:18162 cp/semantics.c:7531
+#: c/c-parser.c:18162 cp/semantics.c:7534
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr ""
 
-#: c/c-parser.c:18164 cp/semantics.c:7533
+#: c/c-parser.c:18164 cp/semantics.c:7536
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr ""
 
-#: c/c-parser.c:18168 cp/semantics.c:7535
+#: c/c-parser.c:18168 cp/semantics.c:7538
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr ""
 
-#: c/c-parser.c:18368 cp/parser.c:38565
+#: c/c-parser.c:18368 cp/parser.c:38562
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:18374 cp/parser.c:38571
+#: c/c-parser.c:18374 cp/parser.c:38568
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
 
-#: c/c-parser.c:18383 cp/parser.c:38580
+#: c/c-parser.c:18383 cp/parser.c:38577
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.c:18385 cp/parser.c:38583
+#: c/c-parser.c:18385 cp/parser.c:38580
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.c:18391 cp/parser.c:38589
+#: c/c-parser.c:18391 cp/parser.c:38586
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
@@ -36401,7 +36444,7 @@
 msgid "%qD has an incomplete type %qT"
 msgstr ""
 
-#: c/c-typeck.c:237 c/c-typeck.c:9994 c/c-typeck.c:10036 cp/call.c:4147
+#: c/c-typeck.c:237 c/c-typeck.c:9999 c/c-typeck.c:10041 cp/call.c:4147
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr ""
@@ -36477,12 +36520,12 @@
 msgid "converting an array compound literal to a pointer is ill-formed in C++"
 msgstr ""
 
-#: c/c-typeck.c:2417 c/c-typeck.c:8641
+#: c/c-typeck.c:2417 c/c-typeck.c:8646
 #, gcc-internal-format
 msgid "%qT has no member named %qE; did you mean %qE?"
 msgstr ""
 
-#: c/c-typeck.c:2421 c/c-typeck.c:8645
+#: c/c-typeck.c:2421 c/c-typeck.c:8650
 #, gcc-internal-format
 msgid "%qT has no member named %qE"
 msgstr ""
@@ -36680,457 +36723,457 @@
 msgid "pointer to a function used in subtraction"
 msgstr ""
 
-#: c/c-typeck.c:3847
+#: c/c-typeck.c:3852
 #, gcc-internal-format
 msgid "arithmetic on pointer to an incomplete type"
 msgstr ""
 
-#: c/c-typeck.c:3852 cp/typeck.c:5562
+#: c/c-typeck.c:3857 cp/typeck.c:5562
 #, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr ""
 
-#: c/c-typeck.c:4283
+#: c/c-typeck.c:4288
 #, gcc-internal-format
 msgid "%<~%> on a boolean expression"
 msgstr ""
 
-#: c/c-typeck.c:4287
+#: c/c-typeck.c:4292
 #, gcc-internal-format
 msgid "did you mean to use logical not?"
 msgstr ""
 
-#: c/c-typeck.c:4296
+#: c/c-typeck.c:4301
 #, gcc-internal-format
 msgid "ISO C does not support %<~%> for complex conjugation"
 msgstr ""
 
-#: c/c-typeck.c:4335
+#: c/c-typeck.c:4340
 #, gcc-internal-format
 msgid "wrong type argument to unary exclamation mark"
 msgstr ""
 
-#: c/c-typeck.c:4393
+#: c/c-typeck.c:4398
 #, gcc-internal-format
 msgid "increment of enumeration value is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:4396
+#: c/c-typeck.c:4401
 #, gcc-internal-format
 msgid "decrement of enumeration value is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:4403
+#: c/c-typeck.c:4408
 #, gcc-internal-format
 msgid "increment of a boolean expression"
 msgstr ""
 
-#: c/c-typeck.c:4406
+#: c/c-typeck.c:4411
 #, gcc-internal-format
 msgid "decrement of a boolean expression"
 msgstr ""
 
-#: c/c-typeck.c:4422
+#: c/c-typeck.c:4427
 #, gcc-internal-format
 msgid "ISO C does not support %<++%> and %<--%> on complex types"
 msgstr ""
 
-#: c/c-typeck.c:4447 c/c-typeck.c:4481
+#: c/c-typeck.c:4452 c/c-typeck.c:4486
 #, gcc-internal-format
 msgid "wrong type argument to increment"
 msgstr ""
 
-#: c/c-typeck.c:4449 c/c-typeck.c:4484
+#: c/c-typeck.c:4454 c/c-typeck.c:4489
 #, gcc-internal-format
 msgid "wrong type argument to decrement"
 msgstr ""
 
-#: c/c-typeck.c:4469
+#: c/c-typeck.c:4474
 #, gcc-internal-format
 msgid "increment of pointer to an incomplete type %qT"
 msgstr ""
 
-#: c/c-typeck.c:4473
+#: c/c-typeck.c:4478
 #, gcc-internal-format
 msgid "decrement of pointer to an incomplete type %qT"
 msgstr ""
 
-#: c/c-typeck.c:4577
+#: c/c-typeck.c:4582
 #, gcc-internal-format
 msgid "taking address of expression of type %<void%>"
 msgstr ""
 
-#: c/c-typeck.c:4636
+#: c/c-typeck.c:4641
 #, gcc-internal-format
 msgid "cannot take address of bit-field %qD"
 msgstr ""
 
-#: c/c-typeck.c:4649
+#: c/c-typeck.c:4654
 #, gcc-internal-format
 msgid "cannot take address of scalar with reverse storage order"
 msgstr ""
 
-#: c/c-typeck.c:4657
+#: c/c-typeck.c:4662
 #, gcc-internal-format
 msgid "address of array with reverse scalar storage order requested"
 msgstr ""
 
-#: c/c-typeck.c:4838
+#: c/c-typeck.c:4843
 #, gcc-internal-format
 msgid "global register variable %qD used in nested function"
 msgstr ""
 
-#: c/c-typeck.c:4841
+#: c/c-typeck.c:4846
 #, gcc-internal-format
 msgid "register variable %qD used in nested function"
 msgstr ""
 
-#: c/c-typeck.c:4846
+#: c/c-typeck.c:4851
 #, gcc-internal-format
 msgid "address of global register variable %qD requested"
 msgstr ""
 
-#: c/c-typeck.c:4848
+#: c/c-typeck.c:4853
 #, gcc-internal-format
 msgid "address of register variable %qD requested"
 msgstr ""
 
-#: c/c-typeck.c:4951
+#: c/c-typeck.c:4956
 #, gcc-internal-format
 msgid "non-lvalue array in conditional expression"
 msgstr ""
 
-#: c/c-typeck.c:5033
+#: c/c-typeck.c:5038
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other result of conditional"
 msgstr ""
 
-#: c/c-typeck.c:5092 c/c-typeck.c:5098
+#: c/c-typeck.c:5097 c/c-typeck.c:5103
 #, gcc-internal-format
 msgid "operand of ?: changes signedness from %qT to %qT due to unsignedness of other operand"
 msgstr ""
 
-#: c/c-typeck.c:5115
+#: c/c-typeck.c:5120
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr with only one void side"
 msgstr ""
 
-#: c/c-typeck.c:5132
+#: c/c-typeck.c:5137
 #, gcc-internal-format
 msgid "pointers to disjoint address spaces used in conditional expression"
 msgstr ""
 
-#: c/c-typeck.c:5143 c/c-typeck.c:5160
+#: c/c-typeck.c:5148 c/c-typeck.c:5165
 #, gcc-internal-format
 msgid "pointer to array loses qualifier in conditional expression"
 msgstr ""
 
-#: c/c-typeck.c:5148 c/c-typeck.c:5165
+#: c/c-typeck.c:5153 c/c-typeck.c:5170
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr between %<void *%> and function pointer"
 msgstr ""
 
-#: c/c-typeck.c:5178
+#: c/c-typeck.c:5183
 #, gcc-internal-format
 msgid "pointer type mismatch in conditional expression"
 msgstr ""
 
-#: c/c-typeck.c:5187 c/c-typeck.c:5198
+#: c/c-typeck.c:5192 c/c-typeck.c:5203
 #, gcc-internal-format
 msgid "pointer/integer type mismatch in conditional expression"
 msgstr ""
 
-#: c/c-typeck.c:5336
+#: c/c-typeck.c:5341
 #, gcc-internal-format
 msgid "left-hand operand of comma expression has no effect"
 msgstr ""
 
-#: c/c-typeck.c:5354 c/c-typeck.c:10636
+#: c/c-typeck.c:5359 c/c-typeck.c:10641
 #, gcc-internal-format
 msgid "right-hand operand of comma expression has no effect"
 msgstr ""
 
-#: c/c-typeck.c:5423
+#: c/c-typeck.c:5428
 msgid "cast adds %q#v qualifier to function type"
 msgstr ""
 
-#: c/c-typeck.c:5429
+#: c/c-typeck.c:5434
 msgid "cast discards %qv qualifier from pointer target type"
 msgstr ""
 
-#: c/c-typeck.c:5464
+#: c/c-typeck.c:5469
 #, gcc-internal-format
 msgid "to be safe all intermediate pointers in cast from %qT to %qT must be %<const%> qualified"
 msgstr ""
 
-#: c/c-typeck.c:5554
+#: c/c-typeck.c:5559
 #, gcc-internal-format
 msgid "cast specifies array type"
 msgstr ""
 
-#: c/c-typeck.c:5560
+#: c/c-typeck.c:5565
 #, gcc-internal-format
 msgid "cast specifies function type"
 msgstr ""
 
-#: c/c-typeck.c:5575
+#: c/c-typeck.c:5580
 #, gcc-internal-format
 msgid "ISO C forbids casting nonscalar to the same type"
 msgstr ""
 
-#: c/c-typeck.c:5595
+#: c/c-typeck.c:5600
 #, gcc-internal-format
 msgid "ISO C forbids casts to union type"
 msgstr ""
 
-#: c/c-typeck.c:5605
+#: c/c-typeck.c:5610
 #, gcc-internal-format
 msgid "cast to union type from type not present in union"
 msgstr ""
 
-#: c/c-typeck.c:5640
+#: c/c-typeck.c:5645
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint generic address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5645
+#: c/c-typeck.c:5650
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to generic address space pointer from disjoint %s address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5650
+#: c/c-typeck.c:5655
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint %s address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5670
+#: c/c-typeck.c:5675
 #, gcc-internal-format
 msgid "cast increases required alignment of target type"
 msgstr ""
 
-#: c/c-typeck.c:5681
+#: c/c-typeck.c:5686
 #, gcc-internal-format
 msgid "cast from pointer to integer of different size"
 msgstr ""
 
-#: c/c-typeck.c:5686
+#: c/c-typeck.c:5691
 #, gcc-internal-format
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr ""
 
-#: c/c-typeck.c:5695 cp/typeck.c:7811
+#: c/c-typeck.c:5700 cp/typeck.c:7811
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr ""
 
-#: c/c-typeck.c:5709
+#: c/c-typeck.c:5714
 #, gcc-internal-format
 msgid "ISO C forbids conversion of function pointer to object pointer type"
 msgstr ""
 
-#: c/c-typeck.c:5718
+#: c/c-typeck.c:5723
 #, gcc-internal-format
 msgid "ISO C forbids conversion of object pointer to function pointer type"
 msgstr ""
 
-#: c/c-typeck.c:5728
+#: c/c-typeck.c:5733
 #, gcc-internal-format
 msgid "cast between incompatible function types from %qT to %qT"
 msgstr ""
 
-#: c/c-typeck.c:5815
+#: c/c-typeck.c:5820
 #, gcc-internal-format
 msgid "defining a type in a cast is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:5856
+#: c/c-typeck.c:5861
 #, gcc-internal-format
 msgid "assignment to expression with array type"
 msgstr ""
 
-#: c/c-typeck.c:5982
+#: c/c-typeck.c:5987
 #, gcc-internal-format
 msgid "enum conversion in assignment is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:6180 c/c-typeck.c:6202 c/c-typeck.c:6226
+#: c/c-typeck.c:6185 c/c-typeck.c:6207 c/c-typeck.c:6231
 #, gcc-internal-format
 msgid "(near initialization for %qs)"
 msgstr ""
 
-#: c/c-typeck.c:6241
+#: c/c-typeck.c:6246
 #, gcc-internal-format
 msgid "array initialized from parenthesized string constant"
 msgstr ""
 
-#: c/c-typeck.c:6284 c/c-typeck.c:6476 c/c-typeck.c:6908
+#: c/c-typeck.c:6289 c/c-typeck.c:6481 c/c-typeck.c:6913
 #, gcc-internal-format
 msgid "expected %qT but argument is of type %qT"
 msgstr ""
 
-#: c/c-typeck.c:6471
+#: c/c-typeck.c:6476
 #, gcc-internal-format
 msgid "enum conversion when passing argument %d of %qE is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:6480
+#: c/c-typeck.c:6485
 #, gcc-internal-format
 msgid "enum conversion from %qT to %qT in assignment is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:6484
+#: c/c-typeck.c:6489
 #, gcc-internal-format
 msgid "enum conversion from %qT to %qT in initialization is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:6489
+#: c/c-typeck.c:6494
 #, gcc-internal-format
 msgid "enum conversion from %qT to %qT in return is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:6523
+#: c/c-typeck.c:6528
 #, gcc-internal-format
 msgid "cannot pass rvalue to reference parameter"
 msgstr ""
 
-#: c/c-typeck.c:6656 c/c-typeck.c:6942
+#: c/c-typeck.c:6661 c/c-typeck.c:6947
 msgid "passing argument %d of %qE makes %q#v qualified function pointer from unqualified"
 msgstr ""
 
-#: c/c-typeck.c:6659 c/c-typeck.c:6945
+#: c/c-typeck.c:6664 c/c-typeck.c:6950
 msgid "assignment makes %q#v qualified function pointer from unqualified"
 msgstr ""
 
-#: c/c-typeck.c:6662 c/c-typeck.c:6947
+#: c/c-typeck.c:6667 c/c-typeck.c:6952
 msgid "initialization makes %q#v qualified function pointer from unqualified"
 msgstr ""
 
-#: c/c-typeck.c:6665 c/c-typeck.c:6949
+#: c/c-typeck.c:6670 c/c-typeck.c:6954
 msgid "return makes %q#v qualified function pointer from unqualified"
 msgstr ""
 
-#: c/c-typeck.c:6673 c/c-typeck.c:6840 c/c-typeck.c:6883
+#: c/c-typeck.c:6678 c/c-typeck.c:6845 c/c-typeck.c:6888
 msgid "passing argument %d of %qE discards %qv qualifier from pointer target type"
 msgstr ""
 
-#: c/c-typeck.c:6675 c/c-typeck.c:6842 c/c-typeck.c:6885
+#: c/c-typeck.c:6680 c/c-typeck.c:6847 c/c-typeck.c:6890
 msgid "assignment discards %qv qualifier from pointer target type"
 msgstr ""
 
-#: c/c-typeck.c:6677 c/c-typeck.c:6844 c/c-typeck.c:6887
+#: c/c-typeck.c:6682 c/c-typeck.c:6849 c/c-typeck.c:6892
 msgid "initialization discards %qv qualifier from pointer target type"
 msgstr ""
 
-#: c/c-typeck.c:6679 c/c-typeck.c:6846 c/c-typeck.c:6889
+#: c/c-typeck.c:6684 c/c-typeck.c:6851 c/c-typeck.c:6894
 msgid "return discards %qv qualifier from pointer target type"
 msgstr ""
 
-#: c/c-typeck.c:6688
+#: c/c-typeck.c:6693
 #, gcc-internal-format
 msgid "ISO C prohibits argument conversion to union type"
 msgstr ""
 
-#: c/c-typeck.c:6750
+#: c/c-typeck.c:6755
 #, gcc-internal-format
 msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgstr ""
 
-#: c/c-typeck.c:6762
+#: c/c-typeck.c:6767
 #, gcc-internal-format
 msgid "passing argument %d of %qE from pointer to non-enclosed address space"
 msgstr ""
 
-#: c/c-typeck.c:6766
+#: c/c-typeck.c:6771
 #, gcc-internal-format
 msgid "assignment from pointer to non-enclosed address space"
 msgstr ""
 
-#: c/c-typeck.c:6770
+#: c/c-typeck.c:6775
 #, gcc-internal-format
 msgid "initialization from pointer to non-enclosed address space"
 msgstr ""
 
-#: c/c-typeck.c:6774
+#: c/c-typeck.c:6779
 #, gcc-internal-format
 msgid "return from pointer to non-enclosed address space"
 msgstr ""
 
-#: c/c-typeck.c:6792
+#: c/c-typeck.c:6797
 #, gcc-internal-format
 msgid "argument %d of %qE might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:6798
+#: c/c-typeck.c:6803
 #, gcc-internal-format
 msgid "assignment left-hand side might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:6803
+#: c/c-typeck.c:6808
 #, gcc-internal-format
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:6808 cp/typeck.c:8891
+#: c/c-typeck.c:6813 cp/typeck.c:8891
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:6857
+#: c/c-typeck.c:6862
 #, gcc-internal-format
 msgid "ISO C forbids passing argument %d of %qE between function pointer and %<void *%>"
 msgstr ""
 
-#: c/c-typeck.c:6860
+#: c/c-typeck.c:6865
 #, gcc-internal-format
 msgid "ISO C forbids assignment between function pointer and %<void *%>"
 msgstr ""
 
-#: c/c-typeck.c:6862
+#: c/c-typeck.c:6867
 #, gcc-internal-format
 msgid "ISO C forbids initialization between function pointer and %<void *%>"
 msgstr ""
 
-#: c/c-typeck.c:6864
+#: c/c-typeck.c:6869
 #, gcc-internal-format
 msgid "ISO C forbids return between function pointer and %<void *%>"
 msgstr ""
 
-#: c/c-typeck.c:6904
+#: c/c-typeck.c:6909
 #, gcc-internal-format
 msgid "pointer targets in passing argument %d of %qE differ in signedness"
 msgstr ""
 
-#: c/c-typeck.c:6913
+#: c/c-typeck.c:6918
 #, gcc-internal-format
 msgid "pointer targets in assignment from %qT to %qT differ in signedness"
 msgstr ""
 
-#: c/c-typeck.c:6918
+#: c/c-typeck.c:6923
 #, gcc-internal-format
 msgid "pointer targets in initialization of %qT from %qT differ in signedness"
 msgstr ""
 
-#: c/c-typeck.c:6923
+#: c/c-typeck.c:6928
 #, gcc-internal-format
 msgid "pointer targets in returning %qT from a function with return type %qT differ in signedness"
 msgstr ""
 
-#: c/c-typeck.c:6961
+#: c/c-typeck.c:6966
 #, gcc-internal-format
 msgid "passing argument %d of %qE from incompatible pointer type"
 msgstr ""
 
-#: c/c-typeck.c:6967
+#: c/c-typeck.c:6972
 #, gcc-internal-format
 msgid "assignment to %qT from incompatible pointer type %qT"
 msgstr ""
 
-#: c/c-typeck.c:6972
+#: c/c-typeck.c:6977
 #, gcc-internal-format
 msgid "initialization of %qT from incompatible pointer type %qT"
 msgstr ""
 
-#: c/c-typeck.c:6977
+#: c/c-typeck.c:6982
 #, gcc-internal-format
 msgid "returning %qT from a function with incompatible return type %qT"
 msgstr ""
@@ -37137,782 +37180,782 @@
 
 #. ??? This should not be an error when inlining calls to
 #. unprototyped functions.
-#: c/c-typeck.c:6991 c/c-typeck.c:7514 cp/typeck.c:2063
+#: c/c-typeck.c:6996 c/c-typeck.c:7519 cp/typeck.c:2063
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr ""
 
-#: c/c-typeck.c:7004
+#: c/c-typeck.c:7009
 #, gcc-internal-format
 msgid "passing argument %d of %qE makes pointer from integer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7010
+#: c/c-typeck.c:7015
 #, gcc-internal-format
 msgid "assignment to %qT from %qT makes pointer from integer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7015
+#: c/c-typeck.c:7020
 #, gcc-internal-format
 msgid "initialization of %qT from %qT makes pointer from integer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7019
+#: c/c-typeck.c:7024
 #, gcc-internal-format
 msgid "returning %qT from a function with return type %qT makes pointer from integer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7035
+#: c/c-typeck.c:7040
 #, gcc-internal-format
 msgid "passing argument %d of %qE makes integer from pointer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7041
+#: c/c-typeck.c:7046
 #, gcc-internal-format
 msgid "assignment to %qT from %qT makes integer from pointer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7046
+#: c/c-typeck.c:7051
 #, gcc-internal-format
 msgid "initialization of %qT from %qT makes integer from pointer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7050
+#: c/c-typeck.c:7055
 #, gcc-internal-format
 msgid "returning %qT from a function with return type %qT makes integer from pointer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7073
+#: c/c-typeck.c:7078
 #, gcc-internal-format
 msgid "incompatible type for argument %d of %qE"
 msgstr ""
 
-#: c/c-typeck.c:7078
+#: c/c-typeck.c:7083
 #, gcc-internal-format
 msgid "incompatible types when assigning to type %qT from type %qT"
 msgstr ""
 
-#: c/c-typeck.c:7083
+#: c/c-typeck.c:7088
 #, gcc-internal-format
 msgid "incompatible types when initializing type %qT using type %qT"
 msgstr ""
 
-#: c/c-typeck.c:7088
+#: c/c-typeck.c:7093
 #, gcc-internal-format
 msgid "incompatible types when returning type %qT but %qT was expected"
 msgstr ""
 
-#: c/c-typeck.c:7152
+#: c/c-typeck.c:7157
 #, gcc-internal-format
 msgid "traditional C rejects automatic aggregate initialization"
 msgstr ""
 
-#: c/c-typeck.c:7388 c/c-typeck.c:8284 cp/typeck2.c:1045
+#: c/c-typeck.c:7393 c/c-typeck.c:8289 cp/typeck2.c:1045
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr ""
 
-#: c/c-typeck.c:7398 cp/typeck2.c:1059
+#: c/c-typeck.c:7403 cp/typeck2.c:1059
 #, gcc-internal-format
 msgid "char-array initialized from wide string"
 msgstr ""
 
-#: c/c-typeck.c:7407
+#: c/c-typeck.c:7412
 #, gcc-internal-format
 msgid "wide character array initialized from non-wide string"
 msgstr ""
 
-#: c/c-typeck.c:7413
+#: c/c-typeck.c:7418
 #, gcc-internal-format
 msgid "wide character array initialized from incompatible wide string"
 msgstr ""
 
-#: c/c-typeck.c:7446
+#: c/c-typeck.c:7451
 #, gcc-internal-format
 msgid "array of inappropriate type initialized from string constant"
 msgstr ""
 
-#: c/c-typeck.c:7533 c/c-typeck.c:7557 c/c-typeck.c:7560 c/c-typeck.c:7568
-#: c/c-typeck.c:7608 c/c-typeck.c:9131 c/c-typeck.c:9181
+#: c/c-typeck.c:7538 c/c-typeck.c:7562 c/c-typeck.c:7565 c/c-typeck.c:7573
+#: c/c-typeck.c:7613 c/c-typeck.c:9136 c/c-typeck.c:9186
 #, gcc-internal-format
 msgid "initializer element is not constant"
 msgstr ""
 
-#: c/c-typeck.c:7542
+#: c/c-typeck.c:7547
 #, gcc-internal-format
 msgid "array initialized from non-constant array expression"
 msgstr ""
 
-#: c/c-typeck.c:7573 c/c-typeck.c:7621 c/c-typeck.c:9191
+#: c/c-typeck.c:7578 c/c-typeck.c:7626 c/c-typeck.c:9196
 #, gcc-internal-format
 msgid "initializer element is not a constant expression"
 msgstr ""
 
-#: c/c-typeck.c:7615 c/c-typeck.c:9186
+#: c/c-typeck.c:7620 c/c-typeck.c:9191
 #, gcc-internal-format
 msgid "initializer element is not computable at load time"
 msgstr ""
 
-#: c/c-typeck.c:7634
+#: c/c-typeck.c:7639
 #, gcc-internal-format
 msgid "invalid initializer"
 msgstr ""
 
-#: c/c-typeck.c:7912 cp/decl.c:6396
+#: c/c-typeck.c:7917 cp/decl.c:6396
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr ""
 
-#: c/c-typeck.c:8132
+#: c/c-typeck.c:8137
 #, gcc-internal-format
 msgid "extra brace group at end of initializer"
 msgstr ""
 
-#: c/c-typeck.c:8215
+#: c/c-typeck.c:8220
 #, gcc-internal-format
 msgid "braces around scalar initializer"
 msgstr ""
 
-#: c/c-typeck.c:8281 c/c-typeck.c:9615 cp/typeck2.c:1084 cp/typeck2.c:1297
+#: c/c-typeck.c:8286 c/c-typeck.c:9620 cp/typeck2.c:1084 cp/typeck2.c:1297
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr ""
 
-#: c/c-typeck.c:8318
+#: c/c-typeck.c:8323
 #, gcc-internal-format
 msgid "missing braces around initializer"
 msgstr ""
 
-#: c/c-typeck.c:8341
+#: c/c-typeck.c:8346
 #, gcc-internal-format
 msgid "missing initializer for field %qD of %qT"
 msgstr ""
 
-#: c/c-typeck.c:8365
+#: c/c-typeck.c:8370
 #, gcc-internal-format
 msgid "empty scalar initializer"
 msgstr ""
 
-#: c/c-typeck.c:8370
+#: c/c-typeck.c:8375
 #, gcc-internal-format
 msgid "extra elements in scalar initializer"
 msgstr ""
 
-#: c/c-typeck.c:8483 c/c-typeck.c:8565
+#: c/c-typeck.c:8488 c/c-typeck.c:8570
 #, gcc-internal-format
 msgid "array index in non-array initializer"
 msgstr ""
 
-#: c/c-typeck.c:8488 c/c-typeck.c:8627
+#: c/c-typeck.c:8493 c/c-typeck.c:8632
 #, gcc-internal-format
 msgid "field name not in record or union initializer"
 msgstr ""
 
-#: c/c-typeck.c:8538
+#: c/c-typeck.c:8543
 #, gcc-internal-format
 msgid "array index in initializer not of integer type"
 msgstr ""
 
-#: c/c-typeck.c:8547 c/c-typeck.c:8556
+#: c/c-typeck.c:8552 c/c-typeck.c:8561
 #, gcc-internal-format
 msgid "array index in initializer is not an integer constant expression"
 msgstr ""
 
-#: c/c-typeck.c:8561 c/c-typeck.c:8563
+#: c/c-typeck.c:8566 c/c-typeck.c:8568
 #, gcc-internal-format
 msgid "nonconstant array index in initializer"
 msgstr ""
 
-#: c/c-typeck.c:8567 c/c-typeck.c:8570
+#: c/c-typeck.c:8572 c/c-typeck.c:8575
 #, gcc-internal-format
 msgid "array index in initializer exceeds array bounds"
 msgstr ""
 
-#: c/c-typeck.c:8589
+#: c/c-typeck.c:8594
 #, gcc-internal-format
 msgid "empty index range in initializer"
 msgstr ""
 
-#: c/c-typeck.c:8598
+#: c/c-typeck.c:8603
 #, gcc-internal-format
 msgid "array index range in initializer exceeds array bounds"
 msgstr ""
 
-#: c/c-typeck.c:8700 c/c-typeck.c:8730 c/c-typeck.c:9274
+#: c/c-typeck.c:8705 c/c-typeck.c:8735 c/c-typeck.c:9279
 #, gcc-internal-format
 msgid "initialized field with side-effects overwritten"
 msgstr ""
 
-#: c/c-typeck.c:8704 c/c-typeck.c:8734 c/c-typeck.c:9277
+#: c/c-typeck.c:8709 c/c-typeck.c:8739 c/c-typeck.c:9282
 #, gcc-internal-format
 msgid "initialized field overwritten"
 msgstr ""
 
-#: c/c-typeck.c:9208
+#: c/c-typeck.c:9213
 #, gcc-internal-format
 msgid "enum conversion in initialization is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:9496
+#: c/c-typeck.c:9501
 #, gcc-internal-format
 msgid "excess elements in char array initializer"
 msgstr ""
 
-#: c/c-typeck.c:9503 c/c-typeck.c:9574
+#: c/c-typeck.c:9508 c/c-typeck.c:9579
 #, gcc-internal-format
 msgid "excess elements in struct initializer"
 msgstr ""
 
-#: c/c-typeck.c:9518
+#: c/c-typeck.c:9523
 #, gcc-internal-format
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr ""
 
-#: c/c-typeck.c:9589
+#: c/c-typeck.c:9594
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr ""
 
-#: c/c-typeck.c:9687
+#: c/c-typeck.c:9692
 #, gcc-internal-format
 msgid "excess elements in union initializer"
 msgstr ""
 
-#: c/c-typeck.c:9709
+#: c/c-typeck.c:9714
 #, gcc-internal-format
 msgid "traditional C rejects initialization of unions"
 msgstr ""
 
-#: c/c-typeck.c:9777
+#: c/c-typeck.c:9782
 #, gcc-internal-format
 msgid "excess elements in array initializer"
 msgstr ""
 
-#: c/c-typeck.c:9811
+#: c/c-typeck.c:9816
 #, gcc-internal-format
 msgid "excess elements in vector initializer"
 msgstr ""
 
-#: c/c-typeck.c:9843
+#: c/c-typeck.c:9848
 #, gcc-internal-format
 msgid "excess elements in scalar initializer"
 msgstr ""
 
-#: c/c-typeck.c:10086
+#: c/c-typeck.c:10091
 #, gcc-internal-format
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr ""
 
-#: c/c-typeck.c:10113 c/gimple-parser.c:1604 cp/typeck.c:9113
+#: c/c-typeck.c:10118 c/gimple-parser.c:1604 cp/typeck.c:9113
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr ""
 
-#: c/c-typeck.c:10139 c/c-typeck.c:10143
+#: c/c-typeck.c:10144 c/c-typeck.c:10148
 #, gcc-internal-format
 msgid "%<return%> with no value, in function returning non-void"
 msgstr ""
 
-#: c/c-typeck.c:10157 c/gimple-parser.c:1614
+#: c/c-typeck.c:10162 c/gimple-parser.c:1614
 #, gcc-internal-format
 msgid "%<return%> with a value, in function returning void"
 msgstr ""
 
-#: c/c-typeck.c:10160
+#: c/c-typeck.c:10165
 #, gcc-internal-format
 msgid "ISO C forbids %<return%> with expression, in function returning void"
 msgstr ""
 
-#: c/c-typeck.c:10236
+#: c/c-typeck.c:10241
 #, gcc-internal-format
 msgid "function returns address of label"
 msgstr ""
 
-#: c/c-typeck.c:10327 cp/semantics.c:1171
+#: c/c-typeck.c:10332 cp/semantics.c:1171
 #, gcc-internal-format
 msgid "switch quantity not an integer"
 msgstr ""
 
-#: c/c-typeck.c:10352
+#: c/c-typeck.c:10357
 #, gcc-internal-format
 msgid "%<long%> switch expression not converted to %<int%> in ISO C"
 msgstr ""
 
-#: c/c-typeck.c:10390 c/c-typeck.c:10398
+#: c/c-typeck.c:10395 c/c-typeck.c:10403
 #, gcc-internal-format
 msgid "case label is not an integer constant expression"
 msgstr ""
 
-#: c/c-typeck.c:10404 cp/parser.c:11067
+#: c/c-typeck.c:10409 cp/parser.c:11067
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr ""
 
-#: c/c-typeck.c:10406
+#: c/c-typeck.c:10411
 #, gcc-internal-format
 msgid "%<default%> label not within a switch statement"
 msgstr ""
 
-#: c/c-typeck.c:10578 cp/parser.c:12356
+#: c/c-typeck.c:10583 cp/parser.c:12353
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr ""
 
-#: c/c-typeck.c:10580 cp/parser.c:12379
+#: c/c-typeck.c:10585 cp/parser.c:12376
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr ""
 
-#: c/c-typeck.c:10585 cp/parser.c:12369
+#: c/c-typeck.c:10590 cp/parser.c:12366
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr ""
 
-#: c/c-typeck.c:10590
+#: c/c-typeck.c:10595
 #, gcc-internal-format
 msgid "break statement within %<#pragma simd%> loop body"
 msgstr ""
 
-#: c/c-typeck.c:10592
+#: c/c-typeck.c:10597
 #, gcc-internal-format
 msgid "continue statement within %<#pragma simd%> loop body"
 msgstr ""
 
-#: c/c-typeck.c:10618 cp/cp-gimplify.c:432
+#: c/c-typeck.c:10623 cp/cp-gimplify.c:432
 #, gcc-internal-format
 msgid "statement with no effect"
 msgstr ""
 
-#: c/c-typeck.c:10662
+#: c/c-typeck.c:10667
 #, gcc-internal-format
 msgid "expression statement has incomplete type"
 msgstr ""
 
-#: c/c-typeck.c:11476 c/c-typeck.c:11644 cp/typeck.c:5017
+#: c/c-typeck.c:11481 c/c-typeck.c:11649 cp/typeck.c:5017
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr ""
 
-#: c/c-typeck.c:11484 c/c-typeck.c:11652 cp/typeck.c:5030
+#: c/c-typeck.c:11489 c/c-typeck.c:11657 cp/typeck.c:5030
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr ""
 
-#: c/c-typeck.c:11509 c/c-typeck.c:11677 cp/typeck.c:5058
+#: c/c-typeck.c:11514 c/c-typeck.c:11682 cp/typeck.c:5058
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr ""
 
-#: c/c-typeck.c:11523 cp/typeck.c:4743
+#: c/c-typeck.c:11528 cp/typeck.c:4743
 #, gcc-internal-format
 msgid "comparing floating point with == or != is unsafe"
 msgstr ""
 
-#: c/c-typeck.c:11541 c/c-typeck.c:11562
+#: c/c-typeck.c:11546 c/c-typeck.c:11567
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<false%> for the address of %qD will never be NULL"
 msgstr ""
 
-#: c/c-typeck.c:11547 c/c-typeck.c:11568
+#: c/c-typeck.c:11552 c/c-typeck.c:11573
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<true%> for the address of %qD will never be NULL"
 msgstr ""
 
-#: c/c-typeck.c:11589 c/c-typeck.c:11718
+#: c/c-typeck.c:11594 c/c-typeck.c:11723
 #, gcc-internal-format
 msgid "comparison of pointers to disjoint address spaces"
 msgstr ""
 
-#: c/c-typeck.c:11596 c/c-typeck.c:11602
+#: c/c-typeck.c:11601 c/c-typeck.c:11607
 #, gcc-internal-format
 msgid "ISO C forbids comparison of %<void *%> with function pointer"
 msgstr ""
 
-#: c/c-typeck.c:11609 c/c-typeck.c:11728
+#: c/c-typeck.c:11614 c/c-typeck.c:11733
 #, gcc-internal-format
 msgid "comparison of distinct pointer types lacks a cast"
 msgstr ""
 
-#: c/c-typeck.c:11621 c/c-typeck.c:11626 c/c-typeck.c:11754 c/c-typeck.c:11759
+#: c/c-typeck.c:11626 c/c-typeck.c:11631 c/c-typeck.c:11759 c/c-typeck.c:11764
 #, gcc-internal-format
 msgid "comparison between pointer and integer"
 msgstr ""
 
-#: c/c-typeck.c:11706
+#: c/c-typeck.c:11711
 #, gcc-internal-format
 msgid "comparison of complete and incomplete pointers"
 msgstr ""
 
-#: c/c-typeck.c:11708
+#: c/c-typeck.c:11713
 #, gcc-internal-format
 msgid "ISO C forbids ordered comparisons of pointers to functions"
 msgstr ""
 
-#: c/c-typeck.c:11713
+#: c/c-typeck.c:11718
 #, gcc-internal-format
 msgid "ordered comparison of pointer with null pointer"
 msgstr ""
 
-#: c/c-typeck.c:11736 c/c-typeck.c:11739 c/c-typeck.c:11746 c/c-typeck.c:11749
+#: c/c-typeck.c:11741 c/c-typeck.c:11744 c/c-typeck.c:11751 c/c-typeck.c:11754
 #: cp/typeck.c:5081 cp/typeck.c:5088
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr ""
 
-#: c/c-typeck.c:11811
+#: c/c-typeck.c:11816
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
 msgstr ""
 
-#: c/c-typeck.c:12126
+#: c/c-typeck.c:12131
 #, gcc-internal-format
 msgid "used array that cannot be converted to pointer where scalar is required"
 msgstr ""
 
-#: c/c-typeck.c:12130
+#: c/c-typeck.c:12135
 #, gcc-internal-format
 msgid "used struct type value where scalar is required"
 msgstr ""
 
-#: c/c-typeck.c:12134
+#: c/c-typeck.c:12139
 #, gcc-internal-format
 msgid "used union type value where scalar is required"
 msgstr ""
 
-#: c/c-typeck.c:12150
+#: c/c-typeck.c:12155
 #, gcc-internal-format
 msgid "used vector type where scalar is required"
 msgstr ""
 
-#: c/c-typeck.c:12340 cp/semantics.c:8508
+#: c/c-typeck.c:12345 cp/semantics.c:8511
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12379 cp/semantics.c:8545
+#: c/c-typeck.c:12384 cp/semantics.c:8548
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12423 c/c-typeck.c:13581 c/c-typeck.c:13642 c/c-typeck.c:13704
+#: c/c-typeck.c:12428 c/c-typeck.c:13586 c/c-typeck.c:13647 c/c-typeck.c:13709
 #, gcc-internal-format
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12436 c/c-typeck.c:13628 cp/semantics.c:4546
-#: cp/semantics.c:6717
+#: c/c-typeck.c:12441 c/c-typeck.c:13633 cp/semantics.c:4549
+#: cp/semantics.c:6720
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12445 c/c-typeck.c:13652 cp/semantics.c:4556
-#: cp/semantics.c:6735
+#: c/c-typeck.c:12450 c/c-typeck.c:13657 cp/semantics.c:4559
+#: cp/semantics.c:6738
 #, gcc-internal-format
 msgid "%qE is a member of a union"
 msgstr ""
 
-#: c/c-typeck.c:12455 cp/semantics.c:4570 cp/semantics.c:6760
+#: c/c-typeck.c:12460 cp/semantics.c:4573 cp/semantics.c:6763
 #, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12459 c/c-typeck.c:13669 cp/semantics.c:4574
-#: cp/semantics.c:6763
+#: c/c-typeck.c:12464 c/c-typeck.c:13674 cp/semantics.c:4577
+#: cp/semantics.c:6766
 #, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12466
+#: c/c-typeck.c:12471
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12475 c/c-typeck.c:13676 c/c-typeck.c:13778
-#: cp/semantics.c:4591 cp/semantics.c:6769 cp/semantics.c:6931
+#: c/c-typeck.c:12480 c/c-typeck.c:13681 c/c-typeck.c:13783
+#: cp/semantics.c:4594 cp/semantics.c:6772 cp/semantics.c:6934
 #, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12511 cp/semantics.c:4623
+#: c/c-typeck.c:12516 cp/semantics.c:4626
 #, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr ""
 
-#: c/c-typeck.c:12518 cp/semantics.c:4630
+#: c/c-typeck.c:12523 cp/semantics.c:4633
 #, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr ""
 
-#: c/c-typeck.c:12545 c/c-typeck.c:12609 c/c-typeck.c:12867
-#: cp/semantics.c:4666 cp/semantics.c:4730
+#: c/c-typeck.c:12550 c/c-typeck.c:12614 c/c-typeck.c:12872
+#: cp/semantics.c:4669 cp/semantics.c:4733
 #, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12564 cp/semantics.c:4685
+#: c/c-typeck.c:12569 cp/semantics.c:4688
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12572 cp/semantics.c:4693
+#: c/c-typeck.c:12577 cp/semantics.c:4696
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12581 c/c-typeck.c:12691 cp/semantics.c:4702
-#: cp/semantics.c:4812
+#: c/c-typeck.c:12586 c/c-typeck.c:12696 cp/semantics.c:4705
+#: cp/semantics.c:4815
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12598 cp/semantics.c:4719
+#: c/c-typeck.c:12603 cp/semantics.c:4722
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12635 cp/semantics.c:4756
+#: c/c-typeck.c:12640 cp/semantics.c:4759
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12650 cp/semantics.c:4771
+#: c/c-typeck.c:12655 cp/semantics.c:4774
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12683 cp/semantics.c:4804
+#: c/c-typeck.c:12688 cp/semantics.c:4807
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12701 c/c-typeck.c:12810 cp/semantics.c:4822
-#: cp/semantics.c:4934
+#: c/c-typeck.c:12706 c/c-typeck.c:12815 cp/semantics.c:4825
+#: cp/semantics.c:4937
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12709 cp/semantics.c:4830
+#: c/c-typeck.c:12714 cp/semantics.c:4833
 #, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr ""
 
-#: c/c-typeck.c:13103 c/c-typeck.c:13113
+#: c/c-typeck.c:13108 c/c-typeck.c:13118
 #, gcc-internal-format
 msgid "%qD in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: c/c-typeck.c:13130
+#: c/c-typeck.c:13135
 #, gcc-internal-format
 msgid "%<_Atomic%> %qE in %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13178
+#: c/c-typeck.c:13183
 #, gcc-internal-format
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr ""
 
-#: c/c-typeck.c:13187 cp/semantics.c:5755
+#: c/c-typeck.c:13192 cp/semantics.c:5758
 #, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr ""
 
-#: c/c-typeck.c:13275
+#: c/c-typeck.c:13280
 #, gcc-internal-format
 msgid "variable length element type in array %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13293 c/c-typeck.c:13836 cp/semantics.c:7249
+#: c/c-typeck.c:13298 c/c-typeck.c:13841 cp/semantics.c:7252
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13305 cp/semantics.c:7289
+#: c/c-typeck.c:13310 cp/semantics.c:7292
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr ""
 
-#: c/c-typeck.c:13319 cp/semantics.c:5929
+#: c/c-typeck.c:13324 cp/semantics.c:5932
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr ""
 
-#: c/c-typeck.c:13327
+#: c/c-typeck.c:13332
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with type %qT"
 msgstr ""
 
-#: c/c-typeck.c:13335
+#: c/c-typeck.c:13340
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13354 cp/semantics.c:5999
+#: c/c-typeck.c:13359 cp/semantics.c:6002
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
-#: c/c-typeck.c:13384 c/c-typeck.c:13771 cp/semantics.c:6083
-#: cp/semantics.c:6924
+#: c/c-typeck.c:13389 c/c-typeck.c:13776 cp/semantics.c:6086
+#: cp/semantics.c:6927
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr ""
 
-#: c/c-typeck.c:13393 cp/semantics.c:6092
+#: c/c-typeck.c:13398 cp/semantics.c:6095
 #, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr ""
 
-#: c/c-typeck.c:13404 c/c-typeck.c:13434 c/c-typeck.c:13463
+#: c/c-typeck.c:13409 c/c-typeck.c:13439 c/c-typeck.c:13468
 #, gcc-internal-format
 msgid "%qE appears more than once in data clauses"
 msgstr ""
 
-#: c/c-typeck.c:13411 c/c-typeck.c:13440 c/c-typeck.c:13600 c/c-typeck.c:13714
-#: c/c-typeck.c:13720 c/c-typeck.c:13733 c/c-typeck.c:13742
-#: cp/semantics.c:6102 cp/semantics.c:6109 cp/semantics.c:6160
-#: cp/semantics.c:6166 cp/semantics.c:6203 cp/semantics.c:6680
-#: cp/semantics.c:6817 cp/semantics.c:6823 cp/semantics.c:6836
-#: cp/semantics.c:6845
+#: c/c-typeck.c:13416 c/c-typeck.c:13445 c/c-typeck.c:13605 c/c-typeck.c:13719
+#: c/c-typeck.c:13725 c/c-typeck.c:13738 c/c-typeck.c:13747
+#: cp/semantics.c:6105 cp/semantics.c:6112 cp/semantics.c:6163
+#: cp/semantics.c:6169 cp/semantics.c:6206 cp/semantics.c:6683
+#: cp/semantics.c:6820 cp/semantics.c:6826 cp/semantics.c:6839
+#: cp/semantics.c:6848
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
-#: c/c-typeck.c:13413 c/c-typeck.c:13442 c/c-typeck.c:13722 c/c-typeck.c:13744
-#: cp/semantics.c:6111 cp/semantics.c:6168 cp/semantics.c:6825
-#: cp/semantics.c:6847
+#: c/c-typeck.c:13418 c/c-typeck.c:13447 c/c-typeck.c:13727 c/c-typeck.c:13749
+#: cp/semantics.c:6114 cp/semantics.c:6171 cp/semantics.c:6828
+#: cp/semantics.c:6850
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr ""
 
-#: c/c-typeck.c:13427 cp/semantics.c:6154
+#: c/c-typeck.c:13432 cp/semantics.c:6157
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13456 cp/semantics.c:6197
+#: c/c-typeck.c:13461 cp/semantics.c:6200
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13475 cp/semantics.c:6545
+#: c/c-typeck.c:13480 cp/semantics.c:6548
 #, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13482
+#: c/c-typeck.c:13487
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array"
 msgstr ""
 
-#: c/c-typeck.c:13489
+#: c/c-typeck.c:13494
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<aligned%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13496
+#: c/c-typeck.c:13501
 #, gcc-internal-format
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:13551 cp/semantics.c:6627
+#: c/c-typeck.c:13556 cp/semantics.c:6630
 #, gcc-internal-format
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13573 cp/semantics.c:6658
+#: c/c-typeck.c:13578 cp/semantics.c:6661
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13597 c/c-typeck.c:13731 cp/semantics.c:6677
-#: cp/semantics.c:6834
+#: c/c-typeck.c:13602 c/c-typeck.c:13736 cp/semantics.c:6680
+#: cp/semantics.c:6837
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr ""
 
-#: c/c-typeck.c:13603 c/c-typeck.c:13735 cp/semantics.c:6683
-#: cp/semantics.c:6838
+#: c/c-typeck.c:13608 c/c-typeck.c:13740 cp/semantics.c:6686
+#: cp/semantics.c:6841
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr ""
 
-#: c/c-typeck.c:13635 cp/semantics.c:6724
+#: c/c-typeck.c:13640 cp/semantics.c:6727
 #, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13695 c/c-typeck.c:13785 cp/semantics.c:6799
-#: cp/semantics.c:6938
+#: c/c-typeck.c:13700 c/c-typeck.c:13790 cp/semantics.c:6802
+#: cp/semantics.c:6941
 #, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13766 cp/semantics.c:6918
+#: c/c-typeck.c:13771 cp/semantics.c:6921
 #, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr ""
 
-#: c/c-typeck.c:13794 cp/semantics.c:6947
+#: c/c-typeck.c:13799 cp/semantics.c:6950
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr ""
 
-#: c/c-typeck.c:13808 cp/semantics.c:6962
+#: c/c-typeck.c:13813 cp/semantics.c:6965
 #, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13811 cp/semantics.c:6964
+#: c/c-typeck.c:13816 cp/semantics.c:6967
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13826
+#: c/c-typeck.c:13831
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer nor an array"
 msgstr ""
 
-#: c/c-typeck.c:13900 cp/semantics.c:6359
+#: c/c-typeck.c:13905 cp/semantics.c:6362
 #, gcc-internal-format
 msgid "%<nonmonotonic%> modifier specified for %qs schedule kind"
 msgstr ""
 
-#: c/c-typeck.c:13931 cp/semantics.c:7141
+#: c/c-typeck.c:13936 cp/semantics.c:7144
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:13981 cp/semantics.c:7332
+#: c/c-typeck.c:13986 cp/semantics.c:7335
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr ""
 
-#: c/c-typeck.c:14001 cp/semantics.c:7223
+#: c/c-typeck.c:14006 cp/semantics.c:7226
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:14013 cp/semantics.c:7236
+#: c/c-typeck.c:14018 cp/semantics.c:7239
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14031 cp/semantics.c:7203
+#: c/c-typeck.c:14036 cp/semantics.c:7206
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14204
+#: c/c-typeck.c:14209
 #, gcc-internal-format
 msgid "cannot use %<va_arg%> with reverse storage order"
 msgstr ""
 
-#: c/c-typeck.c:14209
+#: c/c-typeck.c:14214
 #, gcc-internal-format
 msgid "second argument to %<va_arg%> is of incomplete type %qT"
 msgstr ""
 
-#: c/c-typeck.c:14215
+#: c/c-typeck.c:14220
 #, gcc-internal-format
 msgid "C++ requires promoted type, not enum type, in %<va_arg%>"
 msgstr ""
@@ -38030,7 +38073,7 @@
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr ""
 
-#: cp/call.c:3441 cp/pt.c:6495
+#: cp/call.c:3441 cp/pt.c:6509
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -38322,7 +38365,7 @@
 msgid "%q#D is private within this context"
 msgstr ""
 
-#: cp/call.c:6478 cp/decl.c:7343
+#: cp/call.c:6478 cp/decl.c:7364
 #, gcc-internal-format
 msgid "declared private here"
 msgstr ""
@@ -38332,7 +38375,7 @@
 msgid "%q#D is protected within this context"
 msgstr ""
 
-#: cp/call.c:6486 cp/decl.c:7344
+#: cp/call.c:6486 cp/decl.c:7365
 #, gcc-internal-format
 msgid "declared protected here"
 msgstr ""
@@ -38631,7 +38674,7 @@
 msgid "call to non-function %qD"
 msgstr ""
 
-#: cp/call.c:9119 cp/pt.c:15053 cp/typeck.c:2901
+#: cp/call.c:9119 cp/pt.c:15075 cp/typeck.c:2901
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
@@ -38839,262 +38882,262 @@
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr ""
 
-#: cp/class.c:2098
+#: cp/class.c:2103
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr ""
 
-#: cp/class.c:2110
+#: cp/class.c:2115
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr ""
 
-#: cp/class.c:2152
+#: cp/class.c:2156
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr ""
 
-#: cp/class.c:2156
+#: cp/class.c:2160
 #, gcc-internal-format
 msgid "%q#D is public, but requires an existing %q#T object"
 msgstr ""
 
-#: cp/class.c:2430
+#: cp/class.c:2434
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr ""
 
-#: cp/class.c:2785
+#: cp/class.c:2789
 #, gcc-internal-format
 msgid "%qD can be marked override"
 msgstr ""
 
-#: cp/class.c:2797
+#: cp/class.c:2801
 #, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr ""
 
-#: cp/class.c:2799
+#: cp/class.c:2803
 #, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr ""
 
-#: cp/class.c:2861
+#: cp/class.c:2865
 #, gcc-internal-format
 msgid "%qD was hidden"
 msgstr ""
 
-#: cp/class.c:2863
+#: cp/class.c:2867
 #, gcc-internal-format
 msgid "  by %qD"
 msgstr ""
 
-#: cp/class.c:2896
+#: cp/class.c:2900
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr ""
 
-#: cp/class.c:2906 cp/name-lookup.c:3293 cp/parser.c:19720
+#: cp/class.c:2910 cp/name-lookup.c:3293 cp/parser.c:19717
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
 
-#: cp/class.c:3097
+#: cp/class.c:3101
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr ""
 
-#: cp/class.c:3213
+#: cp/class.c:3217
 #, gcc-internal-format
 msgid "bit-field %q+#D with non-integral type"
 msgstr ""
 
-#: cp/class.c:3229
+#: cp/class.c:3233
 #, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr ""
 
-#: cp/class.c:3234
+#: cp/class.c:3238
 #, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr ""
 
-#: cp/class.c:3239
+#: cp/class.c:3243
 #, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr ""
 
-#: cp/class.c:3249
+#: cp/class.c:3253
 #, gcc-internal-format
 msgid "width of %qD exceeds its type"
 msgstr ""
 
-#: cp/class.c:3255
+#: cp/class.c:3259
 #, gcc-internal-format
 msgid "%qD is too small to hold all values of %q#T"
 msgstr ""
 
-#: cp/class.c:3316
+#: cp/class.c:3320
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr ""
 
-#: cp/class.c:3319
+#: cp/class.c:3323
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr ""
 
-#: cp/class.c:3321
+#: cp/class.c:3325
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr ""
 
-#: cp/class.c:3325
+#: cp/class.c:3329
 #, gcc-internal-format
 msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/class.c:3453
+#: cp/class.c:3457
 #, gcc-internal-format
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr ""
 
-#: cp/class.c:3460
+#: cp/class.c:3464
 #, gcc-internal-format
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr ""
 
-#: cp/class.c:3470
+#: cp/class.c:3474
 #, gcc-internal-format
 msgid "field %q+D invalidly declared function type"
 msgstr ""
 
-#: cp/class.c:3476
+#: cp/class.c:3480
 #, gcc-internal-format
 msgid "field %q+D invalidly declared method type"
 msgstr ""
 
-#: cp/class.c:3536
+#: cp/class.c:3540
 #, gcc-internal-format
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr ""
 
-#: cp/class.c:3585
+#: cp/class.c:3589
 #, gcc-internal-format
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr ""
 
-#: cp/class.c:3591
+#: cp/class.c:3595
 #, gcc-internal-format
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr ""
 
-#: cp/class.c:3617
+#: cp/class.c:3621
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr ""
 
-#: cp/class.c:3658
+#: cp/class.c:3662
 #, gcc-internal-format
 msgid "field %q#D with same name as class"
 msgstr ""
 
-#: cp/class.c:3681
+#: cp/class.c:3685
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr ""
 
-#: cp/class.c:3686
+#: cp/class.c:3690
 #, gcc-internal-format
 msgid "  but does not override %<%T(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:3688
+#: cp/class.c:3692
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:3692
+#: cp/class.c:3696
 #, gcc-internal-format
 msgid "  but does not override %<operator=(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:4097
+#: cp/class.c:4101
 #, gcc-internal-format
 msgid "alignment of %qD increased in -fabi-version=9 (GCC 5.2)"
 msgstr ""
 
-#: cp/class.c:4100
+#: cp/class.c:4104
 #, gcc-internal-format
 msgid "alignment of %qD will increase in -fabi-version=9"
 msgstr ""
 
-#: cp/class.c:4378
+#: cp/class.c:4382
 #, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr ""
 
-#: cp/class.c:4813
+#: cp/class.c:4817
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr ""
 
-#: cp/class.c:4834
+#: cp/class.c:4838
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr ""
 
-#: cp/class.c:5350 cp/constexpr.c:237
+#: cp/class.c:5367 cp/constexpr.c:237
 #, gcc-internal-format
 msgid "enclosing class of %<constexpr%> non-static member function %q+#D is not a literal type"
 msgstr ""
 
-#: cp/class.c:5374
+#: cp/class.c:5391
 #, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr ""
 
-#: cp/class.c:5377
+#: cp/class.c:5394
 #, gcc-internal-format
 msgid "  %qT is a closure type, which is only literal in C++17 and later"
 msgstr ""
 
-#: cp/class.c:5380
+#: cp/class.c:5397
 #, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr ""
 
-#: cp/class.c:5387
+#: cp/class.c:5404
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no %<constexpr%> constructor that is not a copy or move constructor"
 msgstr ""
 
-#: cp/class.c:5420
+#: cp/class.c:5437
 #, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr ""
 
-#: cp/class.c:5435
+#: cp/class.c:5452
 #, gcc-internal-format
 msgid "  non-static data member %qD has non-literal type"
 msgstr ""
 
-#: cp/class.c:5442
+#: cp/class.c:5459
 #, gcc-internal-format
 msgid "  non-static data member %qD has volatile type"
 msgstr ""
 
-#: cp/class.c:5561
+#: cp/class.c:5578
 #, gcc-internal-format
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr ""
 
-#: cp/class.c:5590
+#: cp/class.c:5607
 #, gcc-internal-format
 msgid "non-static reference %q#D in class without a constructor"
 msgstr ""
 
-#: cp/class.c:5596
+#: cp/class.c:5613
 #, gcc-internal-format
 msgid "non-static const member %q#D in class without a constructor"
 msgstr ""
@@ -39101,152 +39144,152 @@
 
 #. If the function is defaulted outside the class, we just
 #. give the synthesis error.
-#: cp/class.c:5624
+#: cp/class.c:5641
 #, gcc-internal-format
 msgid "%q+D declared to take const reference, but implicit declaration would take non-const"
 msgstr ""
 
-#: cp/class.c:5898
+#: cp/class.c:5915
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:5910
+#: cp/class.c:5927
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:6133
+#: cp/class.c:6150
 #, gcc-internal-format
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr ""
 
-#: cp/class.c:6291
+#: cp/class.c:6308
 #, gcc-internal-format
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr ""
 
-#: cp/class.c:6576
+#: cp/class.c:6593
 #, gcc-internal-format
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr ""
 
-#: cp/class.c:6578
+#: cp/class.c:6595
 #, gcc-internal-format
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr ""
 
-#: cp/class.c:6583
+#: cp/class.c:6600
 #, gcc-internal-format
 msgid "array member %q#D declared here"
 msgstr ""
 
-#: cp/class.c:6610
+#: cp/class.c:6627
 #, gcc-internal-format
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr ""
 
-#: cp/class.c:6612
+#: cp/class.c:6629
 #, gcc-internal-format
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr ""
 
-#: cp/class.c:6620 cp/class.c:6650
+#: cp/class.c:6637 cp/class.c:6667
 #, gcc-internal-format
 msgid "in the definition of %q#T"
 msgstr ""
 
-#: cp/class.c:6628
+#: cp/class.c:6645
 #, gcc-internal-format
 msgid "flexible array member %qD not at end of %q#T"
 msgstr ""
 
-#: cp/class.c:6630
+#: cp/class.c:6647
 #, gcc-internal-format
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr ""
 
-#: cp/class.c:6648
+#: cp/class.c:6665
 #, gcc-internal-format
 msgid "next member %q#D declared here"
 msgstr ""
 
-#: cp/class.c:6760 cp/parser.c:23239
+#: cp/class.c:6777 cp/parser.c:23236
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr ""
 
-#: cp/class.c:6897
+#: cp/class.c:6914
 #, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr ""
 
-#: cp/class.c:6925
+#: cp/class.c:6942
 #, gcc-internal-format
 msgid "type transparent %q#T does not have any fields"
 msgstr ""
 
-#: cp/class.c:6931
+#: cp/class.c:6948
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr ""
 
-#: cp/class.c:6935
+#: cp/class.c:6952
 #, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr ""
 
-#: cp/class.c:6941
+#: cp/class.c:6958
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:7071
+#: cp/class.c:7088
 #, gcc-internal-format
 msgid "definition of %qD does not match %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/class.c:7082
+#: cp/class.c:7099
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr ""
 
-#: cp/class.c:7582
+#: cp/class.c:7599
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr ""
 
-#: cp/class.c:7672
+#: cp/class.c:7689
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr ""
 
-#: cp/class.c:7817
+#: cp/class.c:7834
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr ""
 
-#: cp/class.c:7844
+#: cp/class.c:7861
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr ""
 
-#: cp/class.c:7870
+#: cp/class.c:7887
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr ""
 
-#: cp/class.c:7873
+#: cp/class.c:7890
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr ""
 
-#: cp/class.c:7948 cp/class.c:7990
+#: cp/class.c:7965 cp/class.c:8007
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr ""
 
-#: cp/class.c:7968
+#: cp/class.c:7985
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr ""
@@ -39256,12 +39299,12 @@
 #. A name N used in a class S shall refer to the same declaration
 #. in its context and when re-evaluated in the completed scope of
 #. S.
-#: cp/class.c:8235
+#: cp/class.c:8252
 #, gcc-internal-format
 msgid "declaration of %q#D"
 msgstr ""
 
-#: cp/class.c:8237
+#: cp/class.c:8254
 #, gcc-internal-format
 msgid "changes meaning of %qD from %q#D"
 msgstr ""
@@ -39652,17 +39695,17 @@
 msgid "unexpected AST of kind %s"
 msgstr ""
 
-#: cp/cp-gimplify.c:1415
+#: cp/cp-gimplify.c:1416
 #, gcc-internal-format
 msgid "throw will always call terminate()"
 msgstr ""
 
-#: cp/cp-gimplify.c:1418
+#: cp/cp-gimplify.c:1419
 #, gcc-internal-format
 msgid "in C++11 destructors default to noexcept"
 msgstr ""
 
-#: cp/cp-gimplify.c:1429
+#: cp/cp-gimplify.c:1430
 #, gcc-internal-format
 msgid "in C++11 this throw will terminate because destructors default to noexcept"
 msgstr ""
@@ -40066,7 +40109,7 @@
 msgid "redeclaration %qD differs in %<constexpr%> from previous declaration"
 msgstr ""
 
-#: cp/decl.c:1304 cp/decl.c:13843
+#: cp/decl.c:1304 cp/decl.c:13867
 #, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr ""
@@ -40390,7 +40433,7 @@
 msgid "  enters OpenMP structured block"
 msgstr ""
 
-#: cp/decl.c:3434 cp/parser.c:12366 cp/parser.c:12387
+#: cp/decl.c:3434 cp/parser.c:12363 cp/parser.c:12384
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr ""
@@ -40400,7 +40443,7 @@
 msgid "%qD is not a type"
 msgstr ""
 
-#: cp/decl.c:3838 cp/parser.c:6366
+#: cp/decl.c:3838 cp/parser.c:6369
 #, gcc-internal-format
 msgid "%qD used without template parameters"
 msgstr ""
@@ -40776,8 +40819,8 @@
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.c:6011 cp/decl.c:6234 cp/typeck2.c:1310 cp/typeck2.c:1590
-#: cp/typeck2.c:1638 cp/typeck2.c:1685
+#: cp/decl.c:6011 cp/decl.c:6234 cp/typeck2.c:1310 cp/typeck2.c:1593
+#: cp/typeck2.c:1641 cp/typeck2.c:1688
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr ""
@@ -40852,12 +40895,12 @@
 msgid "assignment (not initialization) in declaration"
 msgstr ""
 
-#: cp/decl.c:6873 cp/decl.c:12605
+#: cp/decl.c:6873 cp/decl.c:12629
 #, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr ""
 
-#: cp/decl.c:6877 cp/decl.c:12609
+#: cp/decl.c:6877 cp/decl.c:12633
 #, gcc-internal-format
 msgid "%<register%> storage class specifier used"
 msgstr ""
@@ -40882,42 +40925,42 @@
 msgid "function %q#D is initialized like a variable"
 msgstr ""
 
-#: cp/decl.c:7329
+#: cp/decl.c:7350
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr ""
 
-#: cp/decl.c:7332
+#: cp/decl.c:7353
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.c:7339
+#: cp/decl.c:7360
 #, gcc-internal-format
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr ""
 
-#: cp/decl.c:7365
+#: cp/decl.c:7386
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:7374
+#: cp/decl.c:7395
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:7592
+#: cp/decl.c:7613
 #, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr ""
 
-#: cp/decl.c:7608
+#: cp/decl.c:7629
 #, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr ""
 
-#: cp/decl.c:7617 cp/decl.c:7702
+#: cp/decl.c:7638 cp/decl.c:7723
 #, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
@@ -40925,7 +40968,7 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/decl.c:7621
+#: cp/decl.c:7642
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
@@ -40933,7 +40976,7 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/decl.c:7624
+#: cp/decl.c:7645
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
@@ -40941,878 +40984,878 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/decl.c:7669
+#: cp/decl.c:7690
 #, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr ""
 
-#: cp/decl.c:7695
+#: cp/decl.c:7716
 #, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr ""
 
-#: cp/decl.c:7704
+#: cp/decl.c:7725
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.c:7725
+#: cp/decl.c:7746
 #, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr ""
 
-#: cp/decl.c:7751
+#: cp/decl.c:7772
 #, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr ""
 
-#: cp/decl.c:7756
+#: cp/decl.c:7777
 #, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr ""
 
-#: cp/decl.c:7761
+#: cp/decl.c:7782
 #, gcc-internal-format
 msgid "cannot decompose lambda closure type %qT"
 msgstr ""
 
-#: cp/decl.c:7765
+#: cp/decl.c:7786
 #, gcc-internal-format
 msgid "structured binding refers to incomplete class type %qT"
 msgstr ""
 
-#: cp/decl.c:7774
+#: cp/decl.c:7795
 #, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr ""
 
-#: cp/decl.c:8213
+#: cp/decl.c:8234
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:8216
+#: cp/decl.c:8237
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:8222
+#: cp/decl.c:8243
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:8450
+#: cp/decl.c:8471
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr ""
 
-#: cp/decl.c:8454
+#: cp/decl.c:8475
 #, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr ""
 
-#: cp/decl.c:8457
+#: cp/decl.c:8478
 #, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr ""
 
-#: cp/decl.c:8473
+#: cp/decl.c:8494
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.c:8475
+#: cp/decl.c:8496
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.c:8499
+#: cp/decl.c:8520
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr ""
 
-#: cp/decl.c:8501
+#: cp/decl.c:8522
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr ""
 
-#: cp/decl.c:8506
+#: cp/decl.c:8527
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr ""
 
-#: cp/decl.c:8508
+#: cp/decl.c:8529
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr ""
 
-#: cp/decl.c:8510
+#: cp/decl.c:8531
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:8515
+#: cp/decl.c:8536
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr ""
 
-#: cp/decl.c:8517
+#: cp/decl.c:8538
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr ""
 
-#: cp/decl.c:8519
+#: cp/decl.c:8540
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr ""
 
-#: cp/decl.c:8524
+#: cp/decl.c:8545
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr ""
 
-#: cp/decl.c:8526
+#: cp/decl.c:8547
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr ""
 
-#: cp/decl.c:8528
+#: cp/decl.c:8549
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr ""
 
-#: cp/decl.c:8535
+#: cp/decl.c:8556
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr ""
 
-#: cp/decl.c:8542
+#: cp/decl.c:8563
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr ""
 
-#: cp/decl.c:8574
+#: cp/decl.c:8595
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr ""
 
-#: cp/decl.c:8614
+#: cp/decl.c:8635
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr ""
 
-#: cp/decl.c:8624
+#: cp/decl.c:8645
 #, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr ""
 
-#: cp/decl.c:8630
+#: cp/decl.c:8651
 #, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr ""
 
-#: cp/decl.c:8632
+#: cp/decl.c:8653
 #, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr ""
 
-#: cp/decl.c:8703
+#: cp/decl.c:8724
 #, gcc-internal-format
 msgid "concept %qD has no definition"
 msgstr ""
 
-#: cp/decl.c:8772
+#: cp/decl.c:8793
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr ""
 
 #. Something like `template <class T> friend void f<T>()'.
-#: cp/decl.c:8782
+#: cp/decl.c:8803
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr ""
 
-#: cp/decl.c:8800
+#: cp/decl.c:8821
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:8808
+#: cp/decl.c:8829
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:8857
+#: cp/decl.c:8878
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr ""
 
-#: cp/decl.c:8859
+#: cp/decl.c:8880
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr ""
 
-#: cp/decl.c:8861
+#: cp/decl.c:8882
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be %<constexpr%>"
 msgstr ""
 
-#: cp/decl.c:8863
+#: cp/decl.c:8884
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr ""
 
-#: cp/decl.c:8920
+#: cp/decl.c:8941
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.c:8921
+#: cp/decl.c:8942
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.c:8929
+#: cp/decl.c:8950
 #, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr ""
 
-#: cp/decl.c:8930
+#: cp/decl.c:8951
 #, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr ""
 
-#: cp/decl.c:8940
+#: cp/decl.c:8961
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared at namespace scope"
 msgstr ""
 
-#: cp/decl.c:8946
+#: cp/decl.c:8967
 #, gcc-internal-format
 msgid "deduction guide %qD must not have a function body"
 msgstr ""
 
-#: cp/decl.c:8959
+#: cp/decl.c:8980
 #, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr ""
 
-#: cp/decl.c:8969
+#: cp/decl.c:8990
 #, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr ""
 
-#: cp/decl.c:8977
+#: cp/decl.c:8998
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:8983
+#: cp/decl.c:9004
 #, gcc-internal-format
 msgid "floating point suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:8991
+#: cp/decl.c:9012
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/decl.c:8996
+#: cp/decl.c:9017
 #, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr ""
 
-#: cp/decl.c:9076
+#: cp/decl.c:9097
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr ""
 
-#: cp/decl.c:9116
+#: cp/decl.c:9137
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr ""
 
-#: cp/decl.c:9121
+#: cp/decl.c:9142
 #, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr ""
 
-#: cp/decl.c:9123
+#: cp/decl.c:9144
 #, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr ""
 
-#: cp/decl.c:9140
+#: cp/decl.c:9161
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr ""
 
-#: cp/decl.c:9329
+#: cp/decl.c:9350
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr ""
 
-#: cp/decl.c:9337
+#: cp/decl.c:9358
 #, gcc-internal-format
 msgid "a non-template variable cannot be %<concept%>"
 msgstr ""
 
-#: cp/decl.c:9344
+#: cp/decl.c:9365
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.c:9464
+#: cp/decl.c:9485
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr ""
 
-#: cp/decl.c:9468
+#: cp/decl.c:9489
 #, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr ""
 
-#: cp/decl.c:9472
+#: cp/decl.c:9493
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr ""
 
-#: cp/decl.c:9486
+#: cp/decl.c:9507
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:9493
+#: cp/decl.c:9514
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr ""
 
-#: cp/decl.c:9498
+#: cp/decl.c:9519
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:9598
+#: cp/decl.c:9619
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:9600
+#: cp/decl.c:9621
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:9630 cp/decl.c:9680
+#: cp/decl.c:9651 cp/decl.c:9701
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr ""
 
-#: cp/decl.c:9646
+#: cp/decl.c:9667
 #, gcc-internal-format
 msgid "size of array %qD is negative"
 msgstr ""
 
-#: cp/decl.c:9648 cp/init.c:3651
+#: cp/decl.c:9669 cp/init.c:3667
 #, gcc-internal-format
 msgid "size of array is negative"
 msgstr ""
 
-#: cp/decl.c:9662
+#: cp/decl.c:9683
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr ""
 
-#: cp/decl.c:9664
+#: cp/decl.c:9685
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr ""
 
-#: cp/decl.c:9677
+#: cp/decl.c:9698
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr ""
 
-#: cp/decl.c:9686
+#: cp/decl.c:9707
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr ""
 
-#: cp/decl.c:9688
+#: cp/decl.c:9709
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr ""
 
-#: cp/decl.c:9694
+#: cp/decl.c:9715
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr ""
 
-#: cp/decl.c:9697
+#: cp/decl.c:9718
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr ""
 
-#: cp/decl.c:9746
+#: cp/decl.c:9767
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr ""
 
-#: cp/decl.c:9799
+#: cp/decl.c:9820
 #, gcc-internal-format
 msgid "%qD declared as array of %qT"
 msgstr ""
 
-#: cp/decl.c:9809
+#: cp/decl.c:9830
 #, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr ""
 
-#: cp/decl.c:9811
+#: cp/decl.c:9832
 #, gcc-internal-format
 msgid "creating array of void"
 msgstr ""
 
-#: cp/decl.c:9816
+#: cp/decl.c:9837
 #, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr ""
 
-#: cp/decl.c:9818
+#: cp/decl.c:9839
 #, gcc-internal-format
 msgid "creating array of functions"
 msgstr ""
 
-#: cp/decl.c:9823
+#: cp/decl.c:9844
 #, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr ""
 
-#: cp/decl.c:9825
+#: cp/decl.c:9846
 #, gcc-internal-format
 msgid "creating array of references"
 msgstr ""
 
-#: cp/decl.c:9830
+#: cp/decl.c:9851
 #, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr ""
 
-#: cp/decl.c:9832
+#: cp/decl.c:9853
 #, gcc-internal-format
 msgid "creating array of function members"
 msgstr ""
 
-#: cp/decl.c:9846
+#: cp/decl.c:9867
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.c:9850
+#: cp/decl.c:9871
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.c:9909
+#: cp/decl.c:9930
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr ""
 
-#: cp/decl.c:9912
+#: cp/decl.c:9933
 #, gcc-internal-format
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr ""
 
-#: cp/decl.c:9922
+#: cp/decl.c:9943
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr ""
 
-#: cp/decl.c:9925
+#: cp/decl.c:9946
 #, gcc-internal-format
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr ""
 
-#: cp/decl.c:9937
+#: cp/decl.c:9958
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr ""
 
-#: cp/decl.c:9940
+#: cp/decl.c:9961
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr ""
 
-#: cp/decl.c:9948
+#: cp/decl.c:9969
 #, gcc-internal-format
 msgid "return type specified for deduction guide"
 msgstr ""
 
-#: cp/decl.c:9951
+#: cp/decl.c:9972
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.c:9955
+#: cp/decl.c:9976
 #, gcc-internal-format
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.c:9964
+#: cp/decl.c:9985
 #, gcc-internal-format
 msgid "decl-specifier in declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.c:9985
+#: cp/decl.c:10006
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr ""
 
-#: cp/decl.c:9992
+#: cp/decl.c:10013
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr ""
 
-#: cp/decl.c:10007
+#: cp/decl.c:10028
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr ""
 
-#: cp/decl.c:10013
+#: cp/decl.c:10034
 #, gcc-internal-format
 msgid "inline variables are only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/decl.c:10268
+#: cp/decl.c:10292
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr ""
 
-#: cp/decl.c:10271 cp/decl.c:10291
+#: cp/decl.c:10295 cp/decl.c:10315
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr ""
 
-#: cp/decl.c:10274
+#: cp/decl.c:10298
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr ""
 
-#: cp/decl.c:10283
+#: cp/decl.c:10307
 #, gcc-internal-format
 msgid "%q#T is not a class or a namespace"
 msgstr ""
 
-#: cp/decl.c:10305 cp/decl.c:10398 cp/decl.c:10407 cp/decl.c:11970
+#: cp/decl.c:10329 cp/decl.c:10422 cp/decl.c:10431 cp/decl.c:11994
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr ""
 
-#: cp/decl.c:10311
+#: cp/decl.c:10335
 #, gcc-internal-format
 msgid "declaration of %qD as non-member"
 msgstr ""
 
-#: cp/decl.c:10339
+#: cp/decl.c:10363
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr ""
 
-#: cp/decl.c:10390
+#: cp/decl.c:10414
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr ""
 
-#: cp/decl.c:10415
+#: cp/decl.c:10439
 #, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr ""
 
-#: cp/decl.c:10420
+#: cp/decl.c:10444
 #, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr ""
 
-#: cp/decl.c:10454
+#: cp/decl.c:10478
 #, gcc-internal-format
 msgid "%<concept%> cannot appear in a typedef declaration"
 msgstr ""
 
-#: cp/decl.c:10460
+#: cp/decl.c:10484
 #, gcc-internal-format
 msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgstr ""
 
-#: cp/decl.c:10468
+#: cp/decl.c:10492
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr ""
 
-#: cp/decl.c:10474
+#: cp/decl.c:10498
 #, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr ""
 
-#: cp/decl.c:10515
+#: cp/decl.c:10539
 #, gcc-internal-format
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr ""
 
-#: cp/decl.c:10564 cp/decl.c:10567 cp/decl.c:10570
+#: cp/decl.c:10588 cp/decl.c:10591 cp/decl.c:10594
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr ""
 
-#: cp/decl.c:10586
+#: cp/decl.c:10610
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr ""
 
-#: cp/decl.c:10592
+#: cp/decl.c:10616
 #, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr ""
 
-#: cp/decl.c:10614 cp/decl.c:10634
+#: cp/decl.c:10638 cp/decl.c:10658
 #, gcc-internal-format
 msgid "%<signed%> or %<unsigned%> invalid for %qs"
 msgstr ""
 
-#: cp/decl.c:10616
+#: cp/decl.c:10640
 #, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgstr ""
 
-#: cp/decl.c:10618
+#: cp/decl.c:10642
 #, gcc-internal-format
 msgid "%<long long%> invalid for %qs"
 msgstr ""
 
-#: cp/decl.c:10620
+#: cp/decl.c:10644
 #, gcc-internal-format
 msgid "%<long%> invalid for %qs"
 msgstr ""
 
-#: cp/decl.c:10622
+#: cp/decl.c:10646
 #, gcc-internal-format
 msgid "%<short%> invalid for %qs"
 msgstr ""
 
-#: cp/decl.c:10624
+#: cp/decl.c:10648
 #, gcc-internal-format
 msgid "%<long%> or %<short%> invalid for %qs"
 msgstr ""
 
-#: cp/decl.c:10626
+#: cp/decl.c:10650
 #, gcc-internal-format
 msgid "%<long%>, %<int%>, %<short%>, or %<char%> invalid for %qs"
 msgstr ""
 
-#: cp/decl.c:10628
+#: cp/decl.c:10652
 #, gcc-internal-format
 msgid "%<long%> or %<short%> specified with char for %qs"
 msgstr ""
 
-#: cp/decl.c:10630
+#: cp/decl.c:10654
 #, gcc-internal-format
 msgid "%<long%> and %<short%> specified together for %qs"
 msgstr ""
 
-#: cp/decl.c:10636
+#: cp/decl.c:10660
 #, gcc-internal-format
 msgid "%<short%> or %<long%> invalid for %qs"
 msgstr ""
 
-#: cp/decl.c:10644
+#: cp/decl.c:10668
 #, gcc-internal-format
 msgid "long, short, signed or unsigned used invalidly for %qs"
 msgstr ""
 
-#: cp/decl.c:10712
+#: cp/decl.c:10736
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr ""
 
-#: cp/decl.c:10751
+#: cp/decl.c:10775
 #, gcc-internal-format
 msgid "template placeholder type %qT must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.c:10769
+#: cp/decl.c:10793
 #, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr ""
 
-#: cp/decl.c:10775
+#: cp/decl.c:10799
 #, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<constexpr%>"
 msgstr ""
 
-#: cp/decl.c:10785
+#: cp/decl.c:10809
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:10790
+#: cp/decl.c:10814
 #, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr ""
 
-#: cp/decl.c:10796
+#: cp/decl.c:10820
 #, gcc-internal-format
 msgid "storage class specifiers invalid in parameter declarations"
 msgstr ""
 
-#: cp/decl.c:10800
+#: cp/decl.c:10824
 #, gcc-internal-format
 msgid "a parameter cannot be declared %<concept%>"
 msgstr ""
 
-#: cp/decl.c:10805
+#: cp/decl.c:10829
 #, gcc-internal-format
 msgid "a parameter cannot be declared %<constexpr%>"
 msgstr ""
 
-#: cp/decl.c:10815
+#: cp/decl.c:10839
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr ""
 
-#: cp/decl.c:10825
+#: cp/decl.c:10849
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<inline%>"
 msgstr ""
 
-#: cp/decl.c:10828
+#: cp/decl.c:10852
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<typedef%>"
 msgstr ""
 
-#: cp/decl.c:10830
+#: cp/decl.c:10854
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<constexpr%>"
 msgstr ""
 
-#: cp/decl.c:10834
+#: cp/decl.c:10858
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr ""
 
-#: cp/decl.c:10839
+#: cp/decl.c:10863
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<concept%>"
 msgstr ""
 
-#: cp/decl.c:10845
+#: cp/decl.c:10869
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<register%>"
 msgstr ""
 
-#: cp/decl.c:10849
+#: cp/decl.c:10873
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<static%>"
 msgstr ""
 
-#: cp/decl.c:10853
+#: cp/decl.c:10877
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<extern%>"
 msgstr ""
 
-#: cp/decl.c:10857
+#: cp/decl.c:10881
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:10861
+#: cp/decl.c:10885
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10872
+#: cp/decl.c:10896
 #, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr ""
 
-#: cp/decl.c:10875
+#: cp/decl.c:10899
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10906
+#: cp/decl.c:10930
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr ""
 
-#: cp/decl.c:10929
+#: cp/decl.c:10953
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr ""
 
-#: cp/decl.c:10933
+#: cp/decl.c:10957
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr ""
 
-#: cp/decl.c:10946
+#: cp/decl.c:10970
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr ""
 
-#: cp/decl.c:10950
+#: cp/decl.c:10974
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10957
+#: cp/decl.c:10981
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr ""
 
-#: cp/decl.c:10969
+#: cp/decl.c:10993
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr ""
 
-#: cp/decl.c:11050
+#: cp/decl.c:11074
 #, gcc-internal-format
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr ""
 
-#: cp/decl.c:11098
+#: cp/decl.c:11122
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.c:11118
+#: cp/decl.c:11142
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.c:11121
+#: cp/decl.c:11145
 #, gcc-internal-format
 msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/decl.c:11127
+#: cp/decl.c:11151
 #, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr ""
 
-#: cp/decl.c:11134
+#: cp/decl.c:11158
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:11147
+#: cp/decl.c:11171
 #, gcc-internal-format
 msgid "deduced class type %qD in function return type"
 msgstr ""
 
-#: cp/decl.c:11156
+#: cp/decl.c:11180
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr ""
 
-#: cp/decl.c:11169
+#: cp/decl.c:11193
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
@@ -41819,459 +41862,459 @@
 
 #. Not using maybe_warn_cpp0x because this should
 #. always be an error.
-#: cp/decl.c:11180
+#: cp/decl.c:11204
 #, gcc-internal-format
 msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/decl.c:11183
+#: cp/decl.c:11207
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.c:11212
+#: cp/decl.c:11236
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr ""
 
-#: cp/decl.c:11218
+#: cp/decl.c:11242
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr ""
 
-#: cp/decl.c:11247
+#: cp/decl.c:11271
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.c:11248
+#: cp/decl.c:11272
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.c:11252
+#: cp/decl.c:11276
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.c:11253
+#: cp/decl.c:11277
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.c:11261
+#: cp/decl.c:11285
 #, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr ""
 
-#: cp/decl.c:11262
+#: cp/decl.c:11286
 #, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr ""
 
-#: cp/decl.c:11280
+#: cp/decl.c:11304
 #, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
 msgstr ""
 
 #. Cannot be both friend and virtual.
-#: cp/decl.c:11295
+#: cp/decl.c:11319
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr ""
 
-#: cp/decl.c:11299
+#: cp/decl.c:11323
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr ""
 
-#: cp/decl.c:11301
+#: cp/decl.c:11325
 #, gcc-internal-format
 msgid "can%'t define friend function %qs in a local class definition"
 msgstr ""
 
-#: cp/decl.c:11313
+#: cp/decl.c:11337
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr ""
 
-#: cp/decl.c:11339
+#: cp/decl.c:11363
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr ""
 
-#: cp/decl.c:11379
+#: cp/decl.c:11403
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr ""
 
-#: cp/decl.c:11392 cp/decl.c:11399
+#: cp/decl.c:11416 cp/decl.c:11423
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr ""
 
-#: cp/decl.c:11401
+#: cp/decl.c:11425
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr ""
 
-#: cp/decl.c:11430
+#: cp/decl.c:11454
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr ""
 
-#: cp/decl.c:11431
+#: cp/decl.c:11455
 #, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr ""
 
-#: cp/decl.c:11504
+#: cp/decl.c:11528
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.c:11574
+#: cp/decl.c:11598
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr ""
 
-#: cp/decl.c:11599
+#: cp/decl.c:11623
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr ""
 
-#: cp/decl.c:11605
+#: cp/decl.c:11629
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr ""
 
-#: cp/decl.c:11635
+#: cp/decl.c:11659
 #, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.c:11637
+#: cp/decl.c:11661
 #, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.c:11645
+#: cp/decl.c:11669
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.c:11685
+#: cp/decl.c:11709
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr ""
 
-#: cp/decl.c:11693
+#: cp/decl.c:11717
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.c:11695
+#: cp/decl.c:11719
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.c:11706
+#: cp/decl.c:11730
 #, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr ""
 
-#: cp/decl.c:11709
+#: cp/decl.c:11733
 #, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr ""
 
-#: cp/decl.c:11712
+#: cp/decl.c:11736
 #, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr ""
 
-#: cp/decl.c:11721
+#: cp/decl.c:11745
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:11726
+#: cp/decl.c:11750
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:11732
+#: cp/decl.c:11756
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:11737
+#: cp/decl.c:11761
 #, gcc-internal-format
 msgid "static %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:11742
+#: cp/decl.c:11766
 #, gcc-internal-format
 msgid "const %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:11747
+#: cp/decl.c:11771
 #, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:11778
+#: cp/decl.c:11802
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr ""
 
-#: cp/decl.c:11783
+#: cp/decl.c:11807
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.c:11787
+#: cp/decl.c:11811
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr ""
 
-#: cp/decl.c:11813
+#: cp/decl.c:11837
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr ""
 
-#: cp/decl.c:11900
+#: cp/decl.c:11924
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr ""
 
-#: cp/decl.c:11908
+#: cp/decl.c:11932
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr ""
 
-#: cp/decl.c:11910
+#: cp/decl.c:11934
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr ""
 
-#: cp/decl.c:11914
+#: cp/decl.c:11938
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr ""
 
-#: cp/decl.c:11927
+#: cp/decl.c:11951
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr ""
 
-#: cp/decl.c:11947
+#: cp/decl.c:11971
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr ""
 
-#: cp/decl.c:11951
+#: cp/decl.c:11975
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.c:11961
+#: cp/decl.c:11985
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr ""
 
-#: cp/decl.c:11976
+#: cp/decl.c:12000
 #, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr ""
 
-#: cp/decl.c:11995
+#: cp/decl.c:12019
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:12001
+#: cp/decl.c:12025
 #, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr ""
 
-#: cp/decl.c:12003
+#: cp/decl.c:12027
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12052 cp/parser.c:3270
+#: cp/decl.c:12076 cp/parser.c:3270
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr ""
 
-#: cp/decl.c:12056
+#: cp/decl.c:12080
 #, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr ""
 
-#: cp/decl.c:12080
+#: cp/decl.c:12104
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr ""
 
-#: cp/decl.c:12083
+#: cp/decl.c:12107
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array members"
 msgstr ""
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:12099
+#: cp/decl.c:12123
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr ""
 
-#: cp/decl.c:12121
+#: cp/decl.c:12145
 #, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr ""
 
-#: cp/decl.c:12130
+#: cp/decl.c:12154
 #, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr ""
 
-#: cp/decl.c:12139
+#: cp/decl.c:12163
 #, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr ""
 
-#: cp/decl.c:12153
+#: cp/decl.c:12177
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr ""
 
-#: cp/decl.c:12160
+#: cp/decl.c:12184
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr ""
 
-#: cp/decl.c:12166
+#: cp/decl.c:12190
 #, gcc-internal-format
 msgid "a destructor cannot be %<concept%>"
 msgstr ""
 
-#: cp/decl.c:12171
+#: cp/decl.c:12195
 #, gcc-internal-format
 msgid "a destructor cannot be %<constexpr%>"
 msgstr ""
 
-#: cp/decl.c:12177
+#: cp/decl.c:12201
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr ""
 
-#: cp/decl.c:12185
+#: cp/decl.c:12209
 #, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr ""
 
-#: cp/decl.c:12190
+#: cp/decl.c:12214
 #, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr ""
 
-#: cp/decl.c:12199
+#: cp/decl.c:12223
 #, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr ""
 
-#: cp/decl.c:12202
+#: cp/decl.c:12226
 #, gcc-internal-format
 msgid "variable template declared here"
 msgstr ""
 
-#: cp/decl.c:12257
+#: cp/decl.c:12281
 #, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr ""
 
-#: cp/decl.c:12262
+#: cp/decl.c:12286
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr ""
 
-#: cp/decl.c:12272
+#: cp/decl.c:12296
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr ""
 
-#: cp/decl.c:12318
+#: cp/decl.c:12342
 #, gcc-internal-format
 msgid "static data member %qE declared %<concept%>"
 msgstr ""
 
-#: cp/decl.c:12322
+#: cp/decl.c:12346
 #, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr ""
 
-#: cp/decl.c:12350
+#: cp/decl.c:12374
 #, gcc-internal-format
 msgid "non-static data member %qE declared %<concept%>"
 msgstr ""
 
-#: cp/decl.c:12354
+#: cp/decl.c:12378
 #, gcc-internal-format
 msgid "non-static data member %qE declared %<constexpr%>"
 msgstr ""
 
-#: cp/decl.c:12409
+#: cp/decl.c:12433
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:12411
+#: cp/decl.c:12435
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:12415
+#: cp/decl.c:12439
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:12418
+#: cp/decl.c:12442
 #, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:12423
+#: cp/decl.c:12447
 #, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr ""
 
-#: cp/decl.c:12434
+#: cp/decl.c:12458
 #, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.c:12438
+#: cp/decl.c:12462
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.c:12446
+#: cp/decl.c:12470
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr ""
 
-#: cp/decl.c:12453
+#: cp/decl.c:12477
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr ""
 
-#: cp/decl.c:12454
+#: cp/decl.c:12478
 #, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr ""
 
-#: cp/decl.c:12489
+#: cp/decl.c:12513
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr ""
@@ -42278,77 +42321,77 @@
 
 #. 7.1.1: There can be no static function declarations within a
 #. block.
-#: cp/decl.c:12497
+#: cp/decl.c:12521
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr ""
 
-#: cp/decl.c:12533
+#: cp/decl.c:12557
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr ""
 
-#: cp/decl.c:12540
+#: cp/decl.c:12564
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr ""
 
-#: cp/decl.c:12546
+#: cp/decl.c:12570
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr ""
 
-#: cp/decl.c:12553
+#: cp/decl.c:12577
 #, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr ""
 
-#: cp/decl.c:12574
+#: cp/decl.c:12598
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr ""
 
-#: cp/decl.c:12585
+#: cp/decl.c:12609
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr ""
 
-#: cp/decl.c:12589
+#: cp/decl.c:12613
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr ""
 
-#: cp/decl.c:12754
+#: cp/decl.c:12778
 #, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr ""
 
-#: cp/decl.c:12757
+#: cp/decl.c:12781
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr ""
 
-#: cp/decl.c:12841
+#: cp/decl.c:12865
 #, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:12845
+#: cp/decl.c:12869
 #, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:12868
+#: cp/decl.c:12892
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr ""
 
-#: cp/decl.c:12895
+#: cp/decl.c:12919
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.c:12897
+#: cp/decl.c:12921
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr ""
@@ -42368,169 +42411,169 @@
 #. or implicitly defined), there's no need to worry about their
 #. existence.  Theoretically, they should never even be
 #. instantiated, but that's hard to forestall.
-#: cp/decl.c:13150
+#: cp/decl.c:13174
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr ""
 
-#: cp/decl.c:13228
+#: cp/decl.c:13252
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr ""
 
-#: cp/decl.c:13234
+#: cp/decl.c:13258
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr ""
 
-#: cp/decl.c:13261
+#: cp/decl.c:13285
 #, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr ""
 
-#: cp/decl.c:13267
+#: cp/decl.c:13291
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr ""
 
-#: cp/decl.c:13277
+#: cp/decl.c:13301
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr ""
 
 #. 13.4.0.3
-#: cp/decl.c:13303
+#: cp/decl.c:13327
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading operator ?:"
 msgstr ""
 
 #. Variadic.
-#: cp/decl.c:13314
+#: cp/decl.c:13338
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr ""
 
-#: cp/decl.c:13338
+#: cp/decl.c:13362
 #, gcc-internal-format
 msgid "%qD must have either zero or one argument"
 msgstr ""
 
-#: cp/decl.c:13339
+#: cp/decl.c:13363
 #, gcc-internal-format
 msgid "%qD must have either one or two arguments"
 msgstr ""
 
-#: cp/decl.c:13350
+#: cp/decl.c:13374
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr ""
 
-#: cp/decl.c:13351
+#: cp/decl.c:13375
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr ""
 
-#: cp/decl.c:13361
+#: cp/decl.c:13385
 #, gcc-internal-format
 msgid "%qD must have no arguments"
 msgstr ""
 
-#: cp/decl.c:13362 cp/decl.c:13371
+#: cp/decl.c:13386 cp/decl.c:13395
 #, gcc-internal-format
 msgid "%qD must have exactly one argument"
 msgstr ""
 
-#: cp/decl.c:13372
+#: cp/decl.c:13396
 #, gcc-internal-format
 msgid "%qD must have exactly two arguments"
 msgstr ""
 
-#: cp/decl.c:13389 cp/decl.c:13392
+#: cp/decl.c:13413 cp/decl.c:13416
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr ""
 
-#: cp/decl.c:13419
+#: cp/decl.c:13443
 #, gcc-internal-format
 msgid "conversion to a reference to void will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13421
+#: cp/decl.c:13445
 #, gcc-internal-format
 msgid "conversion to void will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13428
+#: cp/decl.c:13452
 #, gcc-internal-format
 msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13430
+#: cp/decl.c:13454
 #, gcc-internal-format
 msgid "conversion to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13438
+#: cp/decl.c:13462
 #, gcc-internal-format
 msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13440
+#: cp/decl.c:13464
 #, gcc-internal-format
 msgid "conversion to a base class will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13455
+#: cp/decl.c:13479
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr ""
 
-#: cp/decl.c:13474
+#: cp/decl.c:13498
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.c:13480
+#: cp/decl.c:13504
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.c:13492
+#: cp/decl.c:13516
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr ""
 
-#: cp/decl.c:13547
+#: cp/decl.c:13571
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr ""
 
-#: cp/decl.c:13570
+#: cp/decl.c:13594
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr ""
 
-#: cp/decl.c:13573
+#: cp/decl.c:13597
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr ""
 
-#: cp/decl.c:13575
+#: cp/decl.c:13599
 #, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr ""
 
-#: cp/decl.c:13583
+#: cp/decl.c:13607
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr ""
 
-#: cp/decl.c:13584 cp/decl.c:13591
+#: cp/decl.c:13608 cp/decl.c:13615
 #, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr ""
 
-#: cp/decl.c:13590
+#: cp/decl.c:13614
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr ""
@@ -42542,94 +42585,94 @@
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:13605
+#: cp/decl.c:13629
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr ""
 
-#: cp/decl.c:13659 cp/name-lookup.c:4652
+#: cp/decl.c:13683 cp/name-lookup.c:4652
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr ""
 
-#: cp/decl.c:13689 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6425
-#: cp/pt.c:9209
+#: cp/decl.c:13713 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6428
+#: cp/pt.c:9223
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr ""
 
-#: cp/decl.c:13694
+#: cp/decl.c:13718
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:13703 cp/name-lookup.c:4079 cp/name-lookup.c:4086
-#: cp/name-lookup.c:4939 cp/parser.c:6376 cp/parser.c:26300
+#: cp/decl.c:13727 cp/name-lookup.c:4079 cp/name-lookup.c:4086
+#: cp/name-lookup.c:4939 cp/parser.c:6379 cp/parser.c:26297
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr ""
 
-#: cp/decl.c:13806
+#: cp/decl.c:13830
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr ""
 
-#: cp/decl.c:13842
+#: cp/decl.c:13866
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr ""
 
-#: cp/decl.c:13982
+#: cp/decl.c:14006
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr ""
 
-#: cp/decl.c:13989
+#: cp/decl.c:14013
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr ""
 
-#: cp/decl.c:14000
+#: cp/decl.c:14024
 #, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr ""
 
-#: cp/decl.c:14025
+#: cp/decl.c:14049
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr ""
 
-#: cp/decl.c:14055
+#: cp/decl.c:14079
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr ""
 
-#: cp/decl.c:14057
+#: cp/decl.c:14081
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr ""
 
-#: cp/decl.c:14202
+#: cp/decl.c:14226
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14205 cp/decl.c:14213 cp/decl.c:14225 cp/parser.c:18284
+#: cp/decl.c:14229 cp/decl.c:14237 cp/decl.c:14249 cp/parser.c:18281
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr ""
 
-#: cp/decl.c:14210
+#: cp/decl.c:14234
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14222
+#: cp/decl.c:14246
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14300
+#: cp/decl.c:14324
 #, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr ""
@@ -42638,77 +42681,77 @@
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:14447
+#: cp/decl.c:14471
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr ""
 
-#: cp/decl.c:14619
+#: cp/decl.c:14643
 #, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr ""
 
-#: cp/decl.c:14629
+#: cp/decl.c:14653
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr ""
 
-#: cp/decl.c:14678
+#: cp/decl.c:14702
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr ""
 
-#: cp/decl.c:14679
+#: cp/decl.c:14703
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr ""
 
-#: cp/decl.c:14690
+#: cp/decl.c:14714
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr ""
 
-#: cp/decl.c:14710
+#: cp/decl.c:14734
 #, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr ""
 
-#: cp/decl.c:14821
+#: cp/decl.c:14845
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr ""
 
-#: cp/decl.c:14999 cp/typeck.c:9286
+#: cp/decl.c:15023 cp/typeck.c:9286
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr ""
 
-#: cp/decl.c:15344
+#: cp/decl.c:15368
 #, gcc-internal-format
 msgid "invalid function declaration"
 msgstr ""
 
-#: cp/decl.c:15786
+#: cp/decl.c:15810
 #, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr ""
 
-#: cp/decl.c:15788 cp/typeck.c:9166
+#: cp/decl.c:15812 cp/typeck.c:9166
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr ""
 
-#: cp/decl.c:15996
+#: cp/decl.c:16020
 #, gcc-internal-format
 msgid "invalid member function declaration"
 msgstr ""
 
-#: cp/decl.c:16010
+#: cp/decl.c:16034
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr ""
 
-#: cp/decl.c:16386
+#: cp/decl.c:16410
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -42748,7 +42791,7 @@
 msgid "deleting %qT is undefined"
 msgstr ""
 
-#: cp/decl2.c:585 cp/pt.c:5552
+#: cp/decl2.c:585 cp/pt.c:5566
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr ""
@@ -42761,7 +42804,7 @@
 #. [temp.mem]
 #.
 #. A destructor shall not be a member template.
-#: cp/decl2.c:640 cp/pt.c:5511
+#: cp/decl2.c:640 cp/pt.c:5525
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr ""
@@ -42936,47 +42979,47 @@
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr ""
 
-#: cp/decl2.c:2660
+#: cp/decl2.c:2650
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2664
+#: cp/decl2.c:2654
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2669
+#: cp/decl2.c:2659
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2677
+#: cp/decl2.c:2667
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr ""
 
-#: cp/decl2.c:2695
+#: cp/decl2.c:2685
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2699
+#: cp/decl2.c:2689
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2704
+#: cp/decl2.c:2694
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2711
+#: cp/decl2.c:2701
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr ""
 
-#: cp/decl2.c:4309
+#: cp/decl2.c:4299
 #, gcc-internal-format
 msgid "%q#D, declared using unnamed type, is used but never defined"
 msgstr ""
@@ -42985,62 +43028,62 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4318
+#: cp/decl2.c:4308
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4322
+#: cp/decl2.c:4312
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4326
+#: cp/decl2.c:4316
 #, gcc-internal-format
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr ""
 
-#: cp/decl2.c:4334
+#: cp/decl2.c:4324
 #, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr ""
 
-#: cp/decl2.c:4338
+#: cp/decl2.c:4328
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4341
+#: cp/decl2.c:4331
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4529
+#: cp/decl2.c:4519
 #, gcc-internal-format
 msgid "mangling of %q#D as %qE conflicts with a previous mangle"
 msgstr ""
 
-#: cp/decl2.c:4532
+#: cp/decl2.c:4522
 #, gcc-internal-format
 msgid "previous mangling %q#D"
 msgstr ""
 
-#: cp/decl2.c:4534
+#: cp/decl2.c:4524
 #, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr ""
 
-#: cp/decl2.c:4606 cp/decl2.c:4609
+#: cp/decl2.c:4596 cp/decl2.c:4599
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.c:4956
+#: cp/decl2.c:4946
 #, gcc-internal-format
 msgid "inline function %qD used but never defined"
 msgstr ""
 
-#: cp/decl2.c:5143
+#: cp/decl2.c:5133
 #, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr ""
@@ -43047,17 +43090,17 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5251
+#: cp/decl2.c:5241
 #, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.c:5254
+#: cp/decl2.c:5244
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr ""
 
-#: cp/decl2.c:5307
+#: cp/decl2.c:5297
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr ""
@@ -43343,333 +43386,333 @@
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr ""
 
-#: cp/init.c:613
+#: cp/init.c:629
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr ""
 
-#: cp/init.c:615
+#: cp/init.c:631
 #, gcc-internal-format
 msgid "defined here"
 msgstr ""
 
-#: cp/init.c:673
+#: cp/init.c:689
 #, gcc-internal-format
 msgid "initializer for flexible array member %q#D"
 msgstr ""
 
-#: cp/init.c:699
+#: cp/init.c:715
 #, gcc-internal-format
 msgid "%qD should be initialized in the member initialization list"
 msgstr ""
 
-#: cp/init.c:720
+#: cp/init.c:736
 #, gcc-internal-format
 msgid "%qD is initialized with itself"
 msgstr ""
 
-#: cp/init.c:831
+#: cp/init.c:847
 #, gcc-internal-format
 msgid "invalid initializer for array member %q#D"
 msgstr ""
 
-#: cp/init.c:845 cp/init.c:869 cp/init.c:2410 cp/method.c:1368
+#: cp/init.c:861 cp/init.c:885 cp/init.c:2427 cp/method.c:1368
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr ""
 
-#: cp/init.c:847 cp/init.c:864 cp/init.c:871 cp/init.c:2395 cp/init.c:2423
+#: cp/init.c:863 cp/init.c:880 cp/init.c:887 cp/init.c:2412 cp/init.c:2440
 #: cp/method.c:1371 cp/method.c:1382
 #, gcc-internal-format
 msgid "%q#D should be initialized"
 msgstr ""
 
-#: cp/init.c:862 cp/init.c:2382 cp/method.c:1379
+#: cp/init.c:878 cp/init.c:2399 cp/method.c:1379
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr ""
 
-#: cp/init.c:1041
+#: cp/init.c:1057
 #, gcc-internal-format
 msgid "%qD will be initialized after"
 msgstr ""
 
-#: cp/init.c:1044
+#: cp/init.c:1060
 #, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr ""
 
-#: cp/init.c:1048
+#: cp/init.c:1064
 #, gcc-internal-format
 msgid "  %q#D"
 msgstr ""
 
-#: cp/init.c:1050
+#: cp/init.c:1066
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr ""
 
-#: cp/init.c:1052
+#: cp/init.c:1068
 #, gcc-internal-format
 msgid "  when initialized here"
 msgstr ""
 
-#: cp/init.c:1069
+#: cp/init.c:1085
 #, gcc-internal-format
 msgid "multiple initializations given for %qD"
 msgstr ""
 
-#: cp/init.c:1073
+#: cp/init.c:1089
 #, gcc-internal-format
 msgid "multiple initializations given for base %qT"
 msgstr ""
 
-#: cp/init.c:1158
+#: cp/init.c:1174
 #, gcc-internal-format
 msgid "initializations for multiple members of %qT"
 msgstr ""
 
-#: cp/init.c:1255
+#: cp/init.c:1271
 #, gcc-internal-format
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr ""
 
-#: cp/init.c:1482 cp/init.c:1501
+#: cp/init.c:1498 cp/init.c:1517
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr ""
 
-#: cp/init.c:1488
+#: cp/init.c:1504
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr ""
 
-#: cp/init.c:1495
+#: cp/init.c:1511
 #, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr ""
 
-#: cp/init.c:1534
+#: cp/init.c:1550
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr ""
 
-#: cp/init.c:1542
+#: cp/init.c:1558
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr ""
 
-#: cp/init.c:1589
+#: cp/init.c:1605
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr ""
 
-#: cp/init.c:1597
+#: cp/init.c:1613
 #, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr ""
 
-#: cp/init.c:1600
+#: cp/init.c:1616
 #, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr ""
 
-#: cp/init.c:1710 cp/init.c:4386 cp/typeck2.c:1175
+#: cp/init.c:1727 cp/init.c:4402 cp/typeck2.c:1175
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
 
-#: cp/init.c:2019 cp/semantics.c:3268
+#: cp/init.c:2036 cp/semantics.c:3271
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr ""
 
-#: cp/init.c:2075
+#: cp/init.c:2092
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr ""
 
-#: cp/init.c:2089
+#: cp/init.c:2106
 #, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr ""
 
-#: cp/init.c:2175 cp/typeck.c:1893
+#: cp/init.c:2192 cp/typeck.c:1893
 #, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr ""
 
-#: cp/init.c:2182 cp/semantics.c:1835
+#: cp/init.c:2199 cp/semantics.c:1835
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr ""
 
-#: cp/init.c:2379
+#: cp/init.c:2396
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2387
+#: cp/init.c:2404
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2391
+#: cp/init.c:2408
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr ""
 
-#: cp/init.c:2407
+#: cp/init.c:2424
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2415
+#: cp/init.c:2432
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2419
+#: cp/init.c:2436
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr ""
 
-#: cp/init.c:2710
+#: cp/init.c:2727
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2721
+#: cp/init.c:2738
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2732
+#: cp/init.c:2749
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2880
+#: cp/init.c:2896
 #, gcc-internal-format
 msgid "integer overflow in array size"
 msgstr ""
 
-#: cp/init.c:2890
+#: cp/init.c:2906
 #, gcc-internal-format
 msgid "array size in new-expression must be constant"
 msgstr ""
 
-#: cp/init.c:2904
+#: cp/init.c:2920
 #, gcc-internal-format
 msgid "variably modified type not allowed in new-expression"
 msgstr ""
 
-#: cp/init.c:2920
+#: cp/init.c:2936
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by typedef"
 msgstr ""
 
-#: cp/init.c:2922
+#: cp/init.c:2938
 #, gcc-internal-format
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr ""
 
-#: cp/init.c:2932
+#: cp/init.c:2948
 #, gcc-internal-format
 msgid "invalid type %<void%> for new"
 msgstr ""
 
-#: cp/init.c:2975
+#: cp/init.c:2991
 #, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr ""
 
-#: cp/init.c:3101
+#: cp/init.c:3117
 #, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr ""
 
-#: cp/init.c:3108 cp/search.c:1023
+#: cp/init.c:3124 cp/search.c:1026
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr ""
 
-#: cp/init.c:3181
+#: cp/init.c:3197
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr ""
 
-#: cp/init.c:3184
+#: cp/init.c:3200
 #, gcc-internal-format
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr ""
 
-#: cp/init.c:3187
+#: cp/init.c:3203
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr ""
 
-#: cp/init.c:3370
+#: cp/init.c:3386
 #, gcc-internal-format
 msgid "parenthesized initializer in array new"
 msgstr ""
 
-#: cp/init.c:3633
+#: cp/init.c:3649
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr ""
 
-#: cp/init.c:3665
+#: cp/init.c:3681
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr ""
 
-#: cp/init.c:3674
+#: cp/init.c:3690
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr ""
 
-#: cp/init.c:3743
+#: cp/init.c:3759
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete [] operator:"
 msgstr ""
 
-#: cp/init.c:3747
+#: cp/init.c:3763
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete [] will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4295
+#: cp/init.c:4311
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr ""
 
-#: cp/init.c:4599
+#: cp/init.c:4615
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr ""
 
-#: cp/init.c:4623
+#: cp/init.c:4639
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete operator:"
 msgstr ""
 
-#: cp/init.c:4628
+#: cp/init.c:4644
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4642
+#: cp/init.c:4658
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4647
+#: cp/init.c:4663
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4954
+#: cp/init.c:4970
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr ""
@@ -44143,7 +44186,7 @@
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr ""
 
-#: cp/name-lookup.c:5111 cp/name-lookup.c:7065
+#: cp/name-lookup.c:5111 cp/name-lookup.c:7073
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr ""
@@ -44191,53 +44234,53 @@
 msgid "it was later defined here"
 msgstr ""
 
-#: cp/name-lookup.c:6687
+#: cp/name-lookup.c:6695
 #, gcc-internal-format
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn't a template"
 msgstr ""
 
-#: cp/name-lookup.c:7059
+#: cp/name-lookup.c:7067
 #, gcc-internal-format
 msgid "strong using directive no longer supported"
 msgstr ""
 
-#: cp/name-lookup.c:7062
+#: cp/name-lookup.c:7070
 #, gcc-internal-format
 msgid "you may use an inline namespace instead"
 msgstr ""
 
-#: cp/name-lookup.c:7079
+#: cp/name-lookup.c:7087
 #, gcc-internal-format
 msgid "attributes ignored on local using directive"
 msgstr ""
 
-#: cp/name-lookup.c:7163
+#: cp/name-lookup.c:7171
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr ""
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:7183
+#: cp/name-lookup.c:7191
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot nest more than %d namespaces"
 msgstr ""
 
-#: cp/name-lookup.c:7218
+#: cp/name-lookup.c:7226
 #, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr ""
 
-#: cp/name-lookup.c:7219
+#: cp/name-lookup.c:7227
 #, gcc-internal-format
 msgid "%qD defined here"
 msgstr ""
 
-#: cp/name-lookup.c:7292
+#: cp/name-lookup.c:7300
 #, gcc-internal-format
 msgid "XXX entering pop_everything ()\n"
 msgstr ""
 
-#: cp/name-lookup.c:7301
+#: cp/name-lookup.c:7309
 #, gcc-internal-format
 msgid "XXX leaving pop_everything ()\n"
 msgstr ""
@@ -44257,7 +44300,7 @@
 msgid "LEXER_DEBUGGING_ENABLED_P is not set to true"
 msgstr ""
 
-#: cp/parser.c:1352 cp/parser.c:37254
+#: cp/parser.c:1352 cp/parser.c:37251
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -44282,7 +44325,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr ""
 
-#: cp/parser.c:2949 cp/parser.c:18221
+#: cp/parser.c:2949 cp/parser.c:18218
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr ""
@@ -44362,7 +44405,7 @@
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3143 cp/pt.c:17853
+#: cp/parser.c:3143 cp/pt.c:17890
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr ""
@@ -44584,7 +44627,7 @@
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr ""
 
-#: cp/parser.c:4587 cp/parser.c:12940
+#: cp/parser.c:4587 cp/parser.c:12937
 #, gcc-internal-format
 msgid "expected declaration"
 msgstr ""
@@ -44636,7 +44679,7 @@
 msgid "fold-expressions only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:5275 cp/parser.c:5452 cp/parser.c:5630 cp/semantics.c:3612
+#: cp/parser.c:5275 cp/parser.c:5452 cp/parser.c:5633 cp/semantics.c:3615
 #, gcc-internal-format
 msgid "expected primary-expression"
 msgstr ""
@@ -44656,92 +44699,92 @@
 msgid "local variable %qD may not appear in this context"
 msgstr ""
 
-#: cp/parser.c:5787
+#: cp/parser.c:5790
 #, gcc-internal-format
 msgid "expected id-expression"
 msgstr ""
 
-#: cp/parser.c:5919
+#: cp/parser.c:5922
 #, gcc-internal-format
 msgid "scope %qT before %<~%> is not a class-name"
 msgstr ""
 
-#: cp/parser.c:5948 cp/parser.c:7860
+#: cp/parser.c:5951 cp/parser.c:7860
 #, gcc-internal-format
 msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:6059
+#: cp/parser.c:6062
 #, gcc-internal-format
 msgid "declaration of %<~%T%> as member of %qT"
 msgstr ""
 
-#: cp/parser.c:6074
+#: cp/parser.c:6077
 #, gcc-internal-format
 msgid "typedef-name %qD used as destructor declarator"
 msgstr ""
 
-#: cp/parser.c:6111 cp/parser.c:20249
+#: cp/parser.c:6114 cp/parser.c:20246
 #, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr ""
 
-#: cp/parser.c:6220
+#: cp/parser.c:6223
 #, gcc-internal-format
 msgid "found %<:%> in nested-name-specifier, expected %<::%>"
 msgstr ""
 
-#: cp/parser.c:6288
+#: cp/parser.c:6291
 #, gcc-internal-format
 msgid "decltype evaluates to %qT, which is not a class or enumeration type"
 msgstr ""
 
-#: cp/parser.c:6314
+#: cp/parser.c:6317
 #, gcc-internal-format
 msgid "function template-id %qD in nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:6322
+#: cp/parser.c:6325
 #, gcc-internal-format
 msgid "variable template-id %qD in nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:6426 cp/typeck.c:2684 cp/typeck.c:2687 cp/typeck.c:2704
+#: cp/parser.c:6429 cp/typeck.c:2684 cp/typeck.c:2687 cp/typeck.c:2704
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr ""
 
-#: cp/parser.c:6504
+#: cp/parser.c:6507
 #, gcc-internal-format
 msgid "expected nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:6711 cp/parser.c:8950
+#: cp/parser.c:6714 cp/parser.c:8950
 #, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr ""
 
-#: cp/parser.c:6797
+#: cp/parser.c:6800
 #, gcc-internal-format
 msgid "types may not be defined in a %<typeid%> expression"
 msgstr ""
 
-#: cp/parser.c:6889
+#: cp/parser.c:6892
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr ""
 
-#: cp/parser.c:6901 cp/pt.c:18416
+#: cp/parser.c:6904 cp/pt.c:18453
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr ""
 
-#: cp/parser.c:6995
+#: cp/parser.c:6998
 #, gcc-internal-format
 msgid "ISO C++ forbids compound-literals"
 msgstr ""
 
-#: cp/parser.c:7054
+#: cp/parser.c:7057
 #, gcc-internal-format
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
@@ -44871,7 +44914,7 @@
 msgid "capture of non-variable %qE"
 msgstr ""
 
-#: cp/parser.c:10391 cp/parser.c:10401 cp/semantics.c:3453 cp/semantics.c:3465
+#: cp/parser.c:10391 cp/parser.c:10401 cp/semantics.c:3456 cp/semantics.c:3468
 #, gcc-internal-format
 msgid "%q#D declared here"
 msgstr ""
@@ -44956,7 +44999,7 @@
 msgid "init-statement in selection statements only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:11546 cp/parser.c:28490
+#: cp/parser.c:11546 cp/parser.c:28487
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr ""
@@ -44976,558 +45019,558 @@
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:12250 cp/parser.c:28493
+#: cp/parser.c:12250 cp/parser.c:28490
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr ""
 
-#: cp/parser.c:12298
+#: cp/parser.c:12297
 #, gcc-internal-format
 msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/parser.c:12426
+#: cp/parser.c:12423
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr ""
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:12434
+#: cp/parser.c:12431
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr ""
 
-#: cp/parser.c:12447 cp/parser.c:28496
+#: cp/parser.c:12444 cp/parser.c:28493
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr ""
 
-#: cp/parser.c:12620 cp/parser.c:23584
+#: cp/parser.c:12617 cp/parser.c:23581
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr ""
 
-#: cp/parser.c:12863
+#: cp/parser.c:12860
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr ""
 
-#: cp/parser.c:13083
+#: cp/parser.c:13080
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:13103
+#: cp/parser.c:13100
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr ""
 
-#: cp/parser.c:13124
+#: cp/parser.c:13121
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr ""
 
-#: cp/parser.c:13148
+#: cp/parser.c:13145
 #, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr ""
 
-#: cp/parser.c:13203
+#: cp/parser.c:13200
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13206
+#: cp/parser.c:13203
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13257
+#: cp/parser.c:13254
 #, gcc-internal-format
 msgid "structured bindings only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:13306
+#: cp/parser.c:13303
 #, gcc-internal-format
 msgid "empty structured binding declaration"
 msgstr ""
 
-#: cp/parser.c:13324
+#: cp/parser.c:13321
 #, gcc-internal-format
 msgid "invalid initializer for structured binding declaration"
 msgstr ""
 
-#: cp/parser.c:13491
+#: cp/parser.c:13488
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr ""
 
-#: cp/parser.c:13558
+#: cp/parser.c:13555
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr ""
 
-#: cp/parser.c:13594
+#: cp/parser.c:13591
 #, gcc-internal-format
 msgid "decl-specifier invalid in condition"
 msgstr ""
 
-#: cp/parser.c:13600
+#: cp/parser.c:13597
 #, gcc-internal-format
 msgid "%qD invalid in lambda"
 msgstr ""
 
-#: cp/parser.c:13693
+#: cp/parser.c:13690
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr ""
 
-#: cp/parser.c:13763 cp/parser.c:24064
+#: cp/parser.c:13760 cp/parser.c:24061
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:13805
+#: cp/parser.c:13802
 #, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr ""
 
-#: cp/parser.c:13909
+#: cp/parser.c:13906
 #, gcc-internal-format
 msgid "static_assert without a message only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:14111
+#: cp/parser.c:14108
 #, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr ""
 
-#: cp/parser.c:14264
+#: cp/parser.c:14261
 #, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr ""
 
-#: cp/parser.c:14291
+#: cp/parser.c:14288
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr ""
 
-#: cp/parser.c:14295
+#: cp/parser.c:14292
 #, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr ""
 
-#: cp/parser.c:14379
+#: cp/parser.c:14376
 #, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr ""
 
-#: cp/parser.c:14406
+#: cp/parser.c:14403
 #, gcc-internal-format
 msgid "cannot expand initializer for member %qD"
 msgstr ""
 
-#: cp/parser.c:14418 cp/pt.c:24255
+#: cp/parser.c:14415 cp/pt.c:24333
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr ""
 
-#: cp/parser.c:14430 cp/pt.c:24267
+#: cp/parser.c:14427 cp/pt.c:24345
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
 
-#: cp/parser.c:14482
+#: cp/parser.c:14479
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr ""
 
-#: cp/parser.c:14552
+#: cp/parser.c:14549
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:14927
+#: cp/parser.c:14924
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr ""
 
-#: cp/parser.c:14933
+#: cp/parser.c:14930
 #, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr ""
 
-#: cp/parser.c:14942
+#: cp/parser.c:14939
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr ""
 
-#: cp/parser.c:14948
+#: cp/parser.c:14945
 #, fuzzy, gcc-internal-format
 #| msgid "invalid expression as operand"
 msgid "invalid encoding prefix in literal operator"
 msgstr "neispravni izraz kao operand"
 
-#: cp/parser.c:14975
+#: cp/parser.c:14972
 #, gcc-internal-format
 msgid "expected operator"
 msgstr ""
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:15020
+#: cp/parser.c:15017
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr ""
 
-#: cp/parser.c:15190
+#: cp/parser.c:15187
 #, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr ""
 
-#: cp/parser.c:15198
+#: cp/parser.c:15195
 #, gcc-internal-format
 msgid "cv-qualified type parameter"
 msgstr ""
 
-#: cp/parser.c:15283
+#: cp/parser.c:15280
 #, gcc-internal-format
 msgid "variadic constraint introduced without %<...%>"
 msgstr ""
 
-#: cp/parser.c:15347
+#: cp/parser.c:15344
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr ""
 
-#: cp/parser.c:15582 cp/parser.c:15668 cp/parser.c:21694
+#: cp/parser.c:15579 cp/parser.c:15665 cp/parser.c:21691
 #, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:15586 cp/parser.c:15672
+#: cp/parser.c:15583 cp/parser.c:15669
 #, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr ""
 
-#: cp/parser.c:15738
+#: cp/parser.c:15735
 #, gcc-internal-format
 msgid "expected template-id"
 msgstr ""
 
-#: cp/parser.c:15798
+#: cp/parser.c:15795
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr ""
 
-#: cp/parser.c:15802
+#: cp/parser.c:15799
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr ""
 
-#: cp/parser.c:15806
+#: cp/parser.c:15803
 #, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr ""
 
-#: cp/parser.c:15924
+#: cp/parser.c:15921
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr ""
 
 #. The name does not name a template.
-#: cp/parser.c:15992 cp/parser.c:16122 cp/parser.c:16337
+#: cp/parser.c:15989 cp/parser.c:16119 cp/parser.c:16334
 #, gcc-internal-format
 msgid "expected template-name"
 msgstr ""
 
 #. Explain what went wrong.
-#: cp/parser.c:16038
+#: cp/parser.c:16035
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr ""
 
-#: cp/parser.c:16040
+#: cp/parser.c:16037
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr ""
 
-#: cp/parser.c:16189
+#: cp/parser.c:16186
 #, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr ""
 
-#: cp/parser.c:16298 cp/parser.c:16316 cp/parser.c:16483
+#: cp/parser.c:16295 cp/parser.c:16313 cp/parser.c:16480
 #, gcc-internal-format
 msgid "expected template-argument"
 msgstr ""
 
-#: cp/parser.c:16458
+#: cp/parser.c:16455
 #, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr ""
 
-#: cp/parser.c:16585
+#: cp/parser.c:16582
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr ""
 
-#: cp/parser.c:16589
+#: cp/parser.c:16586
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr ""
 
-#: cp/parser.c:16648
+#: cp/parser.c:16645
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr ""
 
-#: cp/parser.c:16869
+#: cp/parser.c:16866
 #, gcc-internal-format
 msgid "expected type specifier"
 msgstr ""
 
-#: cp/parser.c:17053
+#: cp/parser.c:17050
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:17059
+#: cp/parser.c:17056
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:17064
+#: cp/parser.c:17061
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -fconcepts"
 msgstr ""
 
-#: cp/parser.c:17209
+#: cp/parser.c:17206
 #, gcc-internal-format
 msgid "expected template-id for type"
 msgstr ""
 
-#: cp/parser.c:17278
+#: cp/parser.c:17275
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr ""
 
-#: cp/parser.c:17631
+#: cp/parser.c:17628
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr ""
 
-#: cp/parser.c:17854
+#: cp/parser.c:17851
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr ""
 
-#: cp/parser.c:17942
+#: cp/parser.c:17939
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr ""
 
-#: cp/parser.c:17946
+#: cp/parser.c:17943
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr ""
 
-#: cp/parser.c:17951
+#: cp/parser.c:17948
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr ""
 
-#: cp/parser.c:18085
+#: cp/parser.c:18082
 #, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr ""
 
-#: cp/parser.c:18096
+#: cp/parser.c:18093
 #, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr ""
 
-#: cp/parser.c:18111
+#: cp/parser.c:18108
 #, gcc-internal-format
 msgid "unnamed scoped enum is not allowed"
 msgstr ""
 
-#: cp/parser.c:18166
+#: cp/parser.c:18163
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr ""
 
-#: cp/parser.c:18215
+#: cp/parser.c:18212
 #, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr ""
 
-#: cp/parser.c:18229
+#: cp/parser.c:18226
 #, gcc-internal-format
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr ""
 
-#: cp/parser.c:18241 cp/parser.c:23070
+#: cp/parser.c:18238 cp/parser.c:23067
 #, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr ""
 
-#: cp/parser.c:18246 cp/parser.c:23075
+#: cp/parser.c:18243 cp/parser.c:23072
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr ""
 
-#: cp/parser.c:18258 cp/parser.c:23089
+#: cp/parser.c:18255 cp/parser.c:23086
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr ""
 
-#: cp/parser.c:18282
+#: cp/parser.c:18279
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr ""
 
-#: cp/parser.c:18295
+#: cp/parser.c:18292
 #, gcc-internal-format
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr ""
 
-#: cp/parser.c:18315
+#: cp/parser.c:18312
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:18318
+#: cp/parser.c:18315
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:18497
+#: cp/parser.c:18494
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr ""
 
-#: cp/parser.c:18503
+#: cp/parser.c:18500
 #, gcc-internal-format
 msgid "expected namespace-name"
 msgstr ""
 
-#: cp/parser.c:18570
+#: cp/parser.c:18567
 #, gcc-internal-format
 msgid "nested namespace definitions only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:18578
+#: cp/parser.c:18575
 #, gcc-internal-format
 msgid "nested namespace name required"
 msgstr ""
 
-#: cp/parser.c:18583
+#: cp/parser.c:18580
 #, gcc-internal-format
 msgid "namespace name required"
 msgstr ""
 
-#: cp/parser.c:18587
+#: cp/parser.c:18584
 #, gcc-internal-format
 msgid "a nested namespace definition cannot have attributes"
 msgstr ""
 
-#: cp/parser.c:18590
+#: cp/parser.c:18587
 #, gcc-internal-format
 msgid "a nested namespace definition cannot be inline"
 msgstr ""
 
-#: cp/parser.c:18597
+#: cp/parser.c:18594
 #, gcc-internal-format
 msgid "namespace %qD entered"
 msgstr ""
 
-#: cp/parser.c:18652
+#: cp/parser.c:18649
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr ""
 
-#: cp/parser.c:18803
+#: cp/parser.c:18800
 #, gcc-internal-format
 msgid "pack expansion in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:18818
+#: cp/parser.c:18815
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr ""
 
-#: cp/parser.c:18865
+#: cp/parser.c:18862
 #, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:18875
+#: cp/parser.c:18872
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:18940
+#: cp/parser.c:18937
 #, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr ""
 
-#: cp/parser.c:19106
+#: cp/parser.c:19103
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:19493
+#: cp/parser.c:19490
 #, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr ""
 
-#: cp/parser.c:19504
+#: cp/parser.c:19501
 #, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr ""
 
-#: cp/parser.c:19508
+#: cp/parser.c:19505
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr ""
 
-#: cp/parser.c:19559
+#: cp/parser.c:19556
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
 #. Anything else is an error.
-#: cp/parser.c:19598 cp/parser.c:21906
+#: cp/parser.c:19595 cp/parser.c:21903
 #, gcc-internal-format
 msgid "expected initializer"
 msgstr ""
 
-#: cp/parser.c:19679
+#: cp/parser.c:19676
 #, gcc-internal-format
 msgid "initializer provided for function"
 msgstr ""
 
-#: cp/parser.c:19713
+#: cp/parser.c:19710
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr ""
 
-#: cp/parser.c:19727
+#: cp/parser.c:19724
 #, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr ""
 
-#: cp/parser.c:20169
+#: cp/parser.c:20166
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr ""
 
-#: cp/parser.c:20295
+#: cp/parser.c:20292
 #, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr ""
 
-#: cp/parser.c:20299
+#: cp/parser.c:20296
 #, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr ""
@@ -45536,17 +45579,17 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:20328
+#: cp/parser.c:20325
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr ""
 
-#: cp/parser.c:20336
+#: cp/parser.c:20333
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr ""
 
-#: cp/parser.c:20338
+#: cp/parser.c:20335
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr ""
@@ -45553,384 +45596,384 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:20410
+#: cp/parser.c:20407
 #, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr ""
 
-#: cp/parser.c:20435
+#: cp/parser.c:20432
 #, gcc-internal-format
 msgid "expected declarator"
 msgstr ""
 
-#: cp/parser.c:20554
+#: cp/parser.c:20551
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr ""
 
-#: cp/parser.c:20556
+#: cp/parser.c:20553
 #, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr ""
 
-#: cp/parser.c:20577
+#: cp/parser.c:20574
 #, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr ""
 
-#: cp/parser.c:20638
+#: cp/parser.c:20635
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr ""
 
-#: cp/parser.c:20692
+#: cp/parser.c:20689
 #, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr ""
 
-#: cp/parser.c:20729
+#: cp/parser.c:20726
 #, gcc-internal-format
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr ""
 
-#: cp/parser.c:20787
+#: cp/parser.c:20784
 #, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr ""
 
-#: cp/parser.c:21025
+#: cp/parser.c:21022
 #, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr ""
 
-#: cp/parser.c:21031 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2090
+#: cp/parser.c:21028 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2093
 #, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr ""
 
-#: cp/parser.c:21052
+#: cp/parser.c:21049
 #, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr ""
 
-#: cp/parser.c:21057
+#: cp/parser.c:21054
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr ""
 
-#: cp/parser.c:21145
+#: cp/parser.c:21142
 #, gcc-internal-format
 msgid "expected type-specifier"
 msgstr ""
 
-#: cp/parser.c:21429
+#: cp/parser.c:21426
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr ""
 
-#: cp/parser.c:21504
+#: cp/parser.c:21501
 #, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr ""
 
-#: cp/parser.c:21678
+#: cp/parser.c:21675
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr ""
 
-#: cp/parser.c:21696
+#: cp/parser.c:21693
 #, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:21702
+#: cp/parser.c:21699
 #, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:21704
+#: cp/parser.c:21701
 #, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:22131
+#: cp/parser.c:22128
 #, gcc-internal-format
 msgid "C++ designated initializers only available with -std=c++2a or -std=gnu++2a"
 msgstr ""
 
-#: cp/parser.c:22151
+#: cp/parser.c:22148
 #, gcc-internal-format
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr ""
 
-#: cp/parser.c:22189
+#: cp/parser.c:22186
 #, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr ""
 
-#: cp/parser.c:22203
+#: cp/parser.c:22200
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr ""
 
-#: cp/parser.c:22228
+#: cp/parser.c:22225
 #, gcc-internal-format
 msgid "%<...%> not allowed in designated initializer list"
 msgstr ""
 
-#: cp/parser.c:22266
+#: cp/parser.c:22263
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr ""
 
-#: cp/parser.c:22322 cp/parser.c:22448
+#: cp/parser.c:22319 cp/parser.c:22445
 #, gcc-internal-format
 msgid "expected class-name"
 msgstr ""
 
-#: cp/parser.c:22650
+#: cp/parser.c:22647
 #, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr ""
 
-#: cp/parser.c:22653
+#: cp/parser.c:22650
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr ""
 
-#: cp/parser.c:22656
+#: cp/parser.c:22653
 #, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr ""
 
-#: cp/parser.c:23012
+#: cp/parser.c:23009
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr ""
 
-#: cp/parser.c:23023
+#: cp/parser.c:23020
 #, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr ""
 
-#: cp/parser.c:23031
+#: cp/parser.c:23028
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:23038
+#: cp/parser.c:23035
 #, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr ""
 
-#: cp/parser.c:23050
+#: cp/parser.c:23047
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr ""
 
-#: cp/parser.c:23056
+#: cp/parser.c:23053
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr ""
 
-#: cp/parser.c:23114
+#: cp/parser.c:23111
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr ""
 
-#: cp/parser.c:23146
+#: cp/parser.c:23143
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr ""
 
-#: cp/parser.c:23182
+#: cp/parser.c:23179
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr ""
 
-#: cp/parser.c:23241
+#: cp/parser.c:23238
 #, gcc-internal-format
 msgid "previous definition of %q#T"
 msgstr ""
 
-#: cp/parser.c:23331 cp/parser.c:28499
+#: cp/parser.c:23328 cp/parser.c:28496
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr ""
 
-#: cp/parser.c:23355
+#: cp/parser.c:23352
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:23359
+#: cp/parser.c:23356
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%>"
 msgid "expected %<class%> or %<typename%>"
 msgstr "očekujem %<,%> ili %<)%>"
 
-#: cp/parser.c:23605
+#: cp/parser.c:23602
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr ""
 
-#: cp/parser.c:23623
+#: cp/parser.c:23620
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr ""
 
-#: cp/parser.c:23641
+#: cp/parser.c:23638
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:23738
+#: cp/parser.c:23735
 #, gcc-internal-format
 msgid "default member initializers for bit-fields only available with -std=c++2a or -std=gnu++2a"
 msgstr ""
 
-#: cp/parser.c:23745
+#: cp/parser.c:23742
 #, gcc-internal-format
 msgid "default member initializer for unnamed bit-field"
 msgstr ""
 
-#: cp/parser.c:23758
+#: cp/parser.c:23755
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr ""
 
-#: cp/parser.c:23903
+#: cp/parser.c:23900
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr ""
 
-#: cp/parser.c:23923
+#: cp/parser.c:23920
 #, gcc-internal-format
 msgid "extra %<;%> after in-class function definition"
 msgstr ""
 
-#: cp/parser.c:23970
+#: cp/parser.c:23967
 #, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr ""
 
-#: cp/parser.c:23984
+#: cp/parser.c:23981
 #, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr ""
 
-#: cp/parser.c:24058
+#: cp/parser.c:24055
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr ""
 
-#: cp/parser.c:24093
+#: cp/parser.c:24090
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr ""
 
-#: cp/parser.c:24223
+#: cp/parser.c:24220
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr ""
 
-#: cp/parser.c:24243
+#: cp/parser.c:24240
 #, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr ""
 
-#: cp/parser.c:24267
+#: cp/parser.c:24264
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr ""
 
-#: cp/parser.c:24270
+#: cp/parser.c:24267
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:24364 cp/parser.c:24442
+#: cp/parser.c:24361 cp/parser.c:24439
 #, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr ""
 
-#: cp/parser.c:24450
+#: cp/parser.c:24447
 #, gcc-internal-format
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr ""
 
-#: cp/parser.c:24456
+#: cp/parser.c:24453
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr ""
 
-#: cp/parser.c:24500
+#: cp/parser.c:24497
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr ""
 
-#: cp/parser.c:24539
+#: cp/parser.c:24536
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:24650
+#: cp/parser.c:24647
 #, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr ""
 
-#: cp/parser.c:25203
+#: cp/parser.c:25200
 #, gcc-internal-format
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr ""
 
-#: cp/parser.c:25217
+#: cp/parser.c:25214
 #, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr ""
 
-#: cp/parser.c:25301
+#: cp/parser.c:25298
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:25305
+#: cp/parser.c:25302
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:25342
+#: cp/parser.c:25339
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%>"
 msgid "expected attribute before %<...%>"
 msgstr "očekujem %<,%> ili %<)%>"
 
-#: cp/parser.c:25403
+#: cp/parser.c:25400
 #, gcc-internal-format
 msgid "attribute using prefix only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:25721
+#: cp/parser.c:25718
 #, gcc-internal-format
 msgid "%<requires%> only available with -fconcepts"
 msgstr ""
 
-#: cp/parser.c:25753
+#: cp/parser.c:25750
 #, gcc-internal-format
 msgid "a requires expression cannot appear outside a template"
 msgstr ""
 
-#: cp/parser.c:26467
+#: cp/parser.c:26464
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:26472
+#: cp/parser.c:26469
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr ""
 
-#: cp/parser.c:26476
+#: cp/parser.c:26473
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr ""
@@ -45939,453 +45982,453 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:26483
+#: cp/parser.c:26480
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr ""
 
-#: cp/parser.c:26832
+#: cp/parser.c:26829
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr ""
 
-#: cp/parser.c:26991
+#: cp/parser.c:26988
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr ""
 
-#: cp/parser.c:26996
+#: cp/parser.c:26993
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr ""
 
-#: cp/parser.c:27066
+#: cp/parser.c:27063
 #, gcc-internal-format
 msgid "empty introduction-list"
 msgstr ""
 
-#: cp/parser.c:27090
+#: cp/parser.c:27087
 #, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr ""
 
-#: cp/parser.c:27112
+#: cp/parser.c:27109
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr ""
 
-#: cp/parser.c:27121
+#: cp/parser.c:27118
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr ""
 
-#: cp/parser.c:27141
+#: cp/parser.c:27138
 #, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr ""
 
-#: cp/parser.c:27245
+#: cp/parser.c:27242
 #, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr ""
 
-#: cp/parser.c:27296
+#: cp/parser.c:27293
 #, gcc-internal-format
 msgid "a class template declaration must not declare anything else"
 msgstr ""
 
-#: cp/parser.c:27342
+#: cp/parser.c:27339
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr ""
 
-#: cp/parser.c:27650
+#: cp/parser.c:27647
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr ""
 
-#: cp/parser.c:27663
+#: cp/parser.c:27660
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr ""
 
-#: cp/parser.c:27958
+#: cp/parser.c:27955
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:28118
+#: cp/parser.c:28115
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr ""
 
-#: cp/parser.c:28133
+#: cp/parser.c:28130
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr ""
 
-#: cp/parser.c:28267
+#: cp/parser.c:28264
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr ""
 
-#: cp/parser.c:28275
+#: cp/parser.c:28272
 #, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr ""
 
-#: cp/parser.c:28280
+#: cp/parser.c:28277
 #, gcc-internal-format
 msgid "duplicate %qD"
 msgstr ""
 
-#: cp/parser.c:28304
+#: cp/parser.c:28301
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr ""
 
-#: cp/parser.c:28356
+#: cp/parser.c:28353
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr ""
 
-#: cp/parser.c:28359
+#: cp/parser.c:28356
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr ""
 
-#: cp/parser.c:28362
+#: cp/parser.c:28359
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr ""
 
-#: cp/parser.c:28368
+#: cp/parser.c:28365
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr ""
 
-#: cp/parser.c:28371
+#: cp/parser.c:28368
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr ""
 
-#: cp/parser.c:28374
+#: cp/parser.c:28371
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr ""
 
-#: cp/parser.c:28377
+#: cp/parser.c:28374
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr ""
 
-#: cp/parser.c:28380
+#: cp/parser.c:28377
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr ""
 
-#: cp/parser.c:28383
+#: cp/parser.c:28380
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr ""
 
-#: cp/parser.c:28386
+#: cp/parser.c:28383
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr ""
 
-#: cp/parser.c:28389
+#: cp/parser.c:28386
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr ""
 
-#: cp/parser.c:28392
+#: cp/parser.c:28389
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr ""
 
-#: cp/parser.c:28395
+#: cp/parser.c:28392
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr ""
 
-#: cp/parser.c:28398
+#: cp/parser.c:28395
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr ""
 
-#: cp/parser.c:28401
+#: cp/parser.c:28398
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr ""
 
-#: cp/parser.c:28404
+#: cp/parser.c:28401
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr ""
 
-#: cp/parser.c:28407
+#: cp/parser.c:28404
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr ""
 
-#: cp/parser.c:28410
+#: cp/parser.c:28407
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr ""
 
-#: cp/parser.c:28413
+#: cp/parser.c:28410
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr ""
 
-#: cp/parser.c:28416
+#: cp/parser.c:28413
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.c:28419
+#: cp/parser.c:28416
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr ""
 
-#: cp/parser.c:28451
+#: cp/parser.c:28448
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr ""
 
-#: cp/parser.c:28463
+#: cp/parser.c:28460
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr ""
 
-#: cp/parser.c:28466
+#: cp/parser.c:28463
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr ""
 
-#: cp/parser.c:28469
+#: cp/parser.c:28466
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr ""
 
-#: cp/parser.c:28475
+#: cp/parser.c:28472
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr ""
 
-#: cp/parser.c:28502
+#: cp/parser.c:28499
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr ""
 
-#: cp/parser.c:28772
+#: cp/parser.c:28769
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr ""
 
-#: cp/parser.c:28777
+#: cp/parser.c:28774
 #, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr ""
 
-#: cp/parser.c:28798
+#: cp/parser.c:28795
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr ""
 
-#: cp/parser.c:28819
+#: cp/parser.c:28816
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr ""
 
-#: cp/parser.c:29062
+#: cp/parser.c:29059
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr ""
 
-#: cp/parser.c:29303 cp/parser.c:30620 cp/parser.c:30808
+#: cp/parser.c:29300 cp/parser.c:30617 cp/parser.c:30805
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr ""
 
-#: cp/parser.c:29372
+#: cp/parser.c:29369
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr ""
 
-#: cp/parser.c:29442
+#: cp/parser.c:29439
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:29473
+#: cp/parser.c:29470
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr ""
 
-#: cp/parser.c:29883
+#: cp/parser.c:29880
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr ""
 
-#: cp/parser.c:29958 cp/parser.c:29976
+#: cp/parser.c:29955 cp/parser.c:29973
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr ""
 
-#: cp/parser.c:29970 cp/parser.c:30035
+#: cp/parser.c:29967 cp/parser.c:30032
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr ""
 
-#: cp/parser.c:30078
+#: cp/parser.c:30075
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:30284 cp/parser.c:30291 cp/parser.c:30298
+#: cp/parser.c:30281 cp/parser.c:30288 cp/parser.c:30295
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr ""
 
-#: cp/parser.c:30413
+#: cp/parser.c:30410
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr ""
 
-#: cp/parser.c:30585
+#: cp/parser.c:30582
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:30592
+#: cp/parser.c:30589
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr ""
 
-#: cp/parser.c:30867 cp/parser.c:30874 cp/parser.c:30881
+#: cp/parser.c:30864 cp/parser.c:30871 cp/parser.c:30878
 #, gcc-internal-format
 msgid "invalid type for property"
 msgstr ""
 
-#: cp/parser.c:32011
+#: cp/parser.c:32008
 #, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr ""
 
-#: cp/parser.c:32724
+#: cp/parser.c:32721
 #, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr ""
 
-#: cp/parser.c:34911
+#: cp/parser.c:34908
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:35231 cp/pt.c:16392
+#: cp/parser.c:35228 cp/pt.c:16414
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr ""
 
-#: cp/parser.c:35316
+#: cp/parser.c:35313
 #, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr ""
 
-#: cp/parser.c:37521
+#: cp/parser.c:37518
 #, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr ""
 
-#: cp/parser.c:37549
+#: cp/parser.c:37546
 #, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr ""
 
-#: cp/parser.c:37561
+#: cp/parser.c:37558
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:37662
+#: cp/parser.c:37659
 #, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr ""
 
-#: cp/parser.c:37682 cp/semantics.c:5405
+#: cp/parser.c:37679 cp/semantics.c:5408
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37687 cp/semantics.c:5414
+#: cp/parser.c:37684 cp/semantics.c:5417
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37690 cp/pt.c:12944 cp/semantics.c:5420
+#: cp/parser.c:37687 cp/pt.c:12966 cp/semantics.c:5423
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37693 cp/semantics.c:5426
+#: cp/parser.c:37690 cp/semantics.c:5429
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:38047
+#: cp/parser.c:38044
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:38057
+#: cp/parser.c:38054
 #, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr ""
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:38392
+#: cp/parser.c:38389
 #, gcc-internal-format
 msgid "atomic_cancel"
 msgstr ""
 
-#: cp/parser.c:38435 cp/semantics.c:8575
+#: cp/parser.c:38432 cp/semantics.c:8578
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:38437 cp/semantics.c:8577
+#: cp/parser.c:38434 cp/semantics.c:8580
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:38631
+#: cp/parser.c:38628
 #, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr ""
 
-#: cp/parser.c:38927
+#: cp/parser.c:38924
 #, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr ""
 
-#: cp/parser.c:38959
+#: cp/parser.c:38956
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr ""
 
-#: cp/parser.c:39039
+#: cp/parser.c:39036
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr ""
 
-#: cp/parser.c:39295
+#: cp/parser.c:39292
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:39351
+#: cp/parser.c:39348
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
@@ -46472,7 +46515,7 @@
 msgid "specialization of %qD after instantiation"
 msgstr ""
 
-#: cp/pt.c:1954 cp/semantics.c:5274
+#: cp/pt.c:1954 cp/semantics.c:5277
 #, gcc-internal-format
 msgid "%s %#qD"
 msgstr ""
@@ -46638,107 +46681,107 @@
 msgid "argument to __integer_pack must be between 0 and %d"
 msgstr ""
 
-#: cp/pt.c:3942
+#: cp/pt.c:3955
 #, gcc-internal-format
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr ""
 
-#: cp/pt.c:4010
+#: cp/pt.c:4023
 #, gcc-internal-format
 msgid "expansion pattern %qT contains no argument packs"
 msgstr ""
 
-#: cp/pt.c:4012
+#: cp/pt.c:4025
 #, gcc-internal-format
 msgid "expansion pattern %qE contains no argument packs"
 msgstr ""
 
-#: cp/pt.c:4063
+#: cp/pt.c:4077
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr ""
 
-#: cp/pt.c:4080 cp/pt.c:4835
+#: cp/pt.c:4094 cp/pt.c:4849
 #, gcc-internal-format
 msgid "        %qD"
 msgstr ""
 
-#: cp/pt.c:4082
+#: cp/pt.c:4096
 #, gcc-internal-format
 msgid "        <anonymous>"
 msgstr ""
 
-#: cp/pt.c:4208
+#: cp/pt.c:4222
 #, gcc-internal-format
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr ""
 
-#: cp/pt.c:4211
+#: cp/pt.c:4225
 #, gcc-internal-format
 msgid "declaration of %q+#D shadows template parameter"
 msgstr ""
 
-#: cp/pt.c:4213
+#: cp/pt.c:4227
 #, gcc-internal-format
 msgid "template parameter %qD declared here"
 msgstr ""
 
-#: cp/pt.c:4771
+#: cp/pt.c:4785
 #, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr ""
 
-#: cp/pt.c:4830
+#: cp/pt.c:4844
 #, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr ""
 
-#: cp/pt.c:4854
+#: cp/pt.c:4868
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:4858
+#: cp/pt.c:4872
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:4862 cp/pt.c:4873
+#: cp/pt.c:4876 cp/pt.c:4887
 #, gcc-internal-format
 msgid "primary template here"
 msgstr ""
 
-#: cp/pt.c:4870
+#: cp/pt.c:4884
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:4885
+#: cp/pt.c:4899
 #, gcc-internal-format
 msgid "partial specialization %qD is not more specialized than"
 msgstr ""
 
-#: cp/pt.c:4887
+#: cp/pt.c:4901
 #, gcc-internal-format
 msgid "primary template %qD"
 msgstr ""
 
-#: cp/pt.c:4934
+#: cp/pt.c:4948
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:4937
+#: cp/pt.c:4951
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:4958
+#: cp/pt.c:4972
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr ""
 
-#: cp/pt.c:5004
+#: cp/pt.c:5018
 #, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
@@ -46746,17 +46789,17 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/pt.c:5066
+#: cp/pt.c:5080
 #, gcc-internal-format
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr ""
 
-#: cp/pt.c:5070
+#: cp/pt.c:5084
 #, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr ""
 
-#: cp/pt.c:5247
+#: cp/pt.c:5261
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr ""
@@ -46764,47 +46807,47 @@
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5269
+#: cp/pt.c:5283
 #, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr ""
 
-#: cp/pt.c:5305
+#: cp/pt.c:5319
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr ""
 
-#: cp/pt.c:5308
+#: cp/pt.c:5322
 #, gcc-internal-format
 msgid "default template arguments may not be used in template friend declarations"
 msgstr ""
 
-#: cp/pt.c:5311
+#: cp/pt.c:5325
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/pt.c:5314
+#: cp/pt.c:5328
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr ""
 
-#: cp/pt.c:5317 cp/pt.c:5375
+#: cp/pt.c:5331 cp/pt.c:5389
 #, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr ""
 
-#: cp/pt.c:5489
+#: cp/pt.c:5503
 #, gcc-internal-format
 msgid "template %qD declared"
 msgstr ""
 
-#: cp/pt.c:5496
+#: cp/pt.c:5510
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr ""
 
-#: cp/pt.c:5504
+#: cp/pt.c:5518
 #, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr ""
@@ -46814,57 +46857,57 @@
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5526
+#: cp/pt.c:5540
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr ""
 
-#: cp/pt.c:5669
+#: cp/pt.c:5683
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr ""
 
-#: cp/pt.c:5712
+#: cp/pt.c:5726
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr ""
 
-#: cp/pt.c:5726
+#: cp/pt.c:5740
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr ""
 
-#: cp/pt.c:5729
+#: cp/pt.c:5743
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr ""
 
-#: cp/pt.c:5731
+#: cp/pt.c:5745
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr ""
 
-#: cp/pt.c:5752
+#: cp/pt.c:5766
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr ""
 
-#: cp/pt.c:5755
+#: cp/pt.c:5769
 #, gcc-internal-format
 msgid "use %<template<>%> for an explicit specialization"
 msgstr ""
 
-#: cp/pt.c:5882
+#: cp/pt.c:5896
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr ""
 
-#: cp/pt.c:5895
+#: cp/pt.c:5909
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr ""
 
-#: cp/pt.c:5906
+#: cp/pt.c:5920
 #, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
@@ -46872,7 +46915,7 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/pt.c:5910
+#: cp/pt.c:5924
 #, gcc-internal-format
 msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
@@ -46880,12 +46923,12 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/pt.c:5947
+#: cp/pt.c:5961
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr ""
 
-#: cp/pt.c:5948
+#: cp/pt.c:5962
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr ""
@@ -46894,117 +46937,117 @@
 #.
 #. A template-parameter may not be given default arguments
 #. by two different declarations in the same scope.
-#: cp/pt.c:5958
+#: cp/pt.c:5972
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr ""
 
-#: cp/pt.c:5960
+#: cp/pt.c:5974
 #, gcc-internal-format
 msgid "original definition appeared here"
 msgstr ""
 
-#: cp/pt.c:5988
+#: cp/pt.c:6002
 #, gcc-internal-format
 msgid "redeclaration %q#D with different constraints"
 msgstr ""
 
-#: cp/pt.c:5991
+#: cp/pt.c:6005
 #, gcc-internal-format
 msgid "original declaration appeared here"
 msgstr ""
 
-#: cp/pt.c:6250 cp/pt.c:6318
+#: cp/pt.c:6264 cp/pt.c:6332
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr ""
 
-#: cp/pt.c:6253
+#: cp/pt.c:6267
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6256
+#: cp/pt.c:6270
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6268
+#: cp/pt.c:6282
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr ""
 
-#: cp/pt.c:6272
+#: cp/pt.c:6286
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr ""
 
-#: cp/pt.c:6321
+#: cp/pt.c:6335
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr ""
 
-#: cp/pt.c:6323
+#: cp/pt.c:6337
 #, gcc-internal-format
 msgid "because it is a member of %qT"
 msgstr ""
 
-#: cp/pt.c:6383
+#: cp/pt.c:6397
 #, gcc-internal-format
 msgid "  couldn't deduce template parameter %qD"
 msgstr ""
 
-#: cp/pt.c:6392
+#: cp/pt.c:6406
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.c:6401
+#: cp/pt.c:6415
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:6410
+#: cp/pt.c:6424
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr ""
 
-#: cp/pt.c:6421
+#: cp/pt.c:6435
 #, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr ""
 
-#: cp/pt.c:6431
+#: cp/pt.c:6445
 #, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr ""
 
-#: cp/pt.c:6440
+#: cp/pt.c:6454
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:6452
+#: cp/pt.c:6466
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.c:6456
+#: cp/pt.c:6470
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.c:6467
+#: cp/pt.c:6481
 #, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6478
+#: cp/pt.c:6492
 #, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6490
+#: cp/pt.c:6504
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
@@ -47012,292 +47055,292 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/pt.c:6521
+#: cp/pt.c:6535
 #, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr ""
 
-#: cp/pt.c:6534
+#: cp/pt.c:6548
 #, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr ""
 
-#: cp/pt.c:6538
+#: cp/pt.c:6552
 #, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr ""
 
-#: cp/pt.c:6549
+#: cp/pt.c:6563
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.c:6559
+#: cp/pt.c:6573
 #, gcc-internal-format
 msgid "  can't deduce a template for %qT from non-template type %qT"
 msgstr ""
 
-#: cp/pt.c:6569
+#: cp/pt.c:6583
 #, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
 msgstr ""
 
-#: cp/pt.c:6609
+#: cp/pt.c:6623
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr ""
 
-#: cp/pt.c:6758
+#: cp/pt.c:6772
 #, gcc-internal-format
 msgid "in template argument for type %qT"
 msgstr ""
 
-#: cp/pt.c:6772
+#: cp/pt.c:6786
 #, gcc-internal-format
 msgid "template argument %qE for type %qT not a constant integer"
 msgstr ""
 
-#: cp/pt.c:6833
+#: cp/pt.c:6847
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr ""
 
-#: cp/pt.c:6841
+#: cp/pt.c:6855
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr ""
 
-#: cp/pt.c:6857
+#: cp/pt.c:6871
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr ""
 
-#: cp/pt.c:6864
+#: cp/pt.c:6878
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr ""
 
-#: cp/pt.c:6873
+#: cp/pt.c:6887
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr ""
 
-#: cp/pt.c:6888
+#: cp/pt.c:6902
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6897
+#: cp/pt.c:6911
 #, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6904
+#: cp/pt.c:6918
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr ""
 
-#: cp/pt.c:6933
+#: cp/pt.c:6947
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr ""
 
-#: cp/pt.c:6941
+#: cp/pt.c:6955
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr ""
 
-#: cp/pt.c:6959
+#: cp/pt.c:6973
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr ""
 
-#: cp/pt.c:6975
+#: cp/pt.c:6989
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an object with linkage"
 msgstr ""
 
-#: cp/pt.c:6986
+#: cp/pt.c:7000
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because object %qD does not have linkage"
 msgstr ""
 
-#: cp/pt.c:7036
+#: cp/pt.c:7050
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr ""
 
-#: cp/pt.c:7038
+#: cp/pt.c:7052
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr ""
 
-#: cp/pt.c:7092
+#: cp/pt.c:7106
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr ""
 
-#: cp/pt.c:7654
+#: cp/pt.c:7668
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr ""
 
-#: cp/pt.c:7670
+#: cp/pt.c:7684
 #, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr ""
 
-#: cp/pt.c:7805
+#: cp/pt.c:7819
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr ""
 
-#: cp/pt.c:7834
+#: cp/pt.c:7848
 #, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr ""
 
-#: cp/pt.c:7839
+#: cp/pt.c:7853
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr ""
 
-#: cp/pt.c:7855 cp/pt.c:7877 cp/pt.c:7931
+#: cp/pt.c:7869 cp/pt.c:7891 cp/pt.c:7945
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.c:7860
+#: cp/pt.c:7874
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr ""
 
-#: cp/pt.c:7865
+#: cp/pt.c:7879
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr ""
 
-#: cp/pt.c:7868
+#: cp/pt.c:7882
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr ""
 
-#: cp/pt.c:7882
+#: cp/pt.c:7896
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr ""
 
-#: cp/pt.c:7885
+#: cp/pt.c:7899
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr ""
 
-#: cp/pt.c:7935
+#: cp/pt.c:7949
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr ""
 
-#: cp/pt.c:7949
+#: cp/pt.c:7963
 #, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.c:7952
+#: cp/pt.c:7966
 #, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr ""
 
-#: cp/pt.c:8012
+#: cp/pt.c:8026
 #, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr ""
 
-#: cp/pt.c:8149 cp/pt.c:8465
+#: cp/pt.c:8163 cp/pt.c:8479
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr ""
 
-#: cp/pt.c:8164 cp/pt.c:8298
+#: cp/pt.c:8178 cp/pt.c:8312
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr ""
 
-#: cp/pt.c:8294
+#: cp/pt.c:8308
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr ""
 
-#: cp/pt.c:8303
+#: cp/pt.c:8317
 #, gcc-internal-format
 msgid "provided for %qD"
 msgstr ""
 
-#: cp/pt.c:8328
+#: cp/pt.c:8342
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:8332
+#: cp/pt.c:8346
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr ""
 
-#: cp/pt.c:8431
+#: cp/pt.c:8445
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:9054
+#: cp/pt.c:9068
 #, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr ""
 
-#: cp/pt.c:9221
+#: cp/pt.c:9235
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr ""
 
-#: cp/pt.c:9223
+#: cp/pt.c:9237
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr ""
 
-#: cp/pt.c:9346
+#: cp/pt.c:9360
 #, gcc-internal-format
 msgid "template constraint failure"
 msgstr ""
 
-#: cp/pt.c:9697
+#: cp/pt.c:9718
 #, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr ""
 
-#: cp/pt.c:10125
+#: cp/pt.c:10148
 #, gcc-internal-format, gfc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:11202
+#: cp/pt.c:11225
 #, gcc-internal-format
 msgid "flexible array member %qD in union"
 msgstr ""
 
-#: cp/pt.c:11691
+#: cp/pt.c:11713
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:12160
+#: cp/pt.c:12182
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr ""
 
-#: cp/pt.c:12163
+#: cp/pt.c:12185
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr ""
 
-#: cp/pt.c:12747
+#: cp/pt.c:12769
 #, gcc-internal-format
 msgid "  when instantiating default argument for call to %qD"
 msgstr ""
@@ -47315,276 +47358,276 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:13708
+#: cp/pt.c:13730
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr ""
 
-#: cp/pt.c:13881
+#: cp/pt.c:13903
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr ""
 
-#: cp/pt.c:13883
+#: cp/pt.c:13905
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr ""
 
-#: cp/pt.c:14001
+#: cp/pt.c:14023
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr ""
 
-#: cp/pt.c:14003
+#: cp/pt.c:14025
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr ""
 
-#: cp/pt.c:14043
+#: cp/pt.c:14065
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr ""
 
-#: cp/pt.c:14637
+#: cp/pt.c:14659
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr ""
 
-#: cp/pt.c:14639
+#: cp/pt.c:14661
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr ""
 
-#: cp/pt.c:14641
+#: cp/pt.c:14663
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr ""
 
-#: cp/pt.c:14654
+#: cp/pt.c:14676
 #, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr ""
 
-#: cp/pt.c:14657
+#: cp/pt.c:14679
 #, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr ""
 
-#: cp/pt.c:14705
+#: cp/pt.c:14727
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr ""
 
-#: cp/pt.c:14711
+#: cp/pt.c:14733
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr ""
 
-#: cp/pt.c:14717
+#: cp/pt.c:14739
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr ""
 
-#: cp/pt.c:14783
+#: cp/pt.c:14805
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr ""
 
-#: cp/pt.c:14816
+#: cp/pt.c:14838
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr ""
 
-#: cp/pt.c:14853
+#: cp/pt.c:14875
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr ""
 
-#: cp/pt.c:14861
+#: cp/pt.c:14883
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr ""
 
-#: cp/pt.c:14925
+#: cp/pt.c:14947
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.c:15000
+#: cp/pt.c:15022
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr ""
 
-#: cp/pt.c:15178
+#: cp/pt.c:15200
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/pt.c:15193
+#: cp/pt.c:15215
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr ""
 
-#: cp/pt.c:15195
+#: cp/pt.c:15217
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr ""
 
-#: cp/pt.c:15394
+#: cp/pt.c:15416
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr ""
 
-#: cp/pt.c:15883 cp/pt.c:17386
+#: cp/pt.c:15905 cp/pt.c:17408
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr ""
 
-#: cp/pt.c:15887 cp/pt.c:17390
+#: cp/pt.c:15909 cp/pt.c:17412
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr ""
 
-#: cp/pt.c:18334
+#: cp/pt.c:18371
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:18362
+#: cp/pt.c:18399
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:18367
+#: cp/pt.c:18404
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.c:18370
+#: cp/pt.c:18407
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr ""
 
-#: cp/pt.c:18375
+#: cp/pt.c:18412
 #, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr ""
 
-#: cp/pt.c:18712
+#: cp/pt.c:18752
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr ""
 
-#: cp/pt.c:18715
+#: cp/pt.c:18755
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr ""
 
-#: cp/pt.c:19026
+#: cp/pt.c:19066
 #, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr ""
 
-#: cp/pt.c:19028
+#: cp/pt.c:19068
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr ""
 
-#: cp/pt.c:19038
+#: cp/pt.c:19078
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr ""
 
-#: cp/pt.c:19053
+#: cp/pt.c:19093
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr ""
 
-#: cp/pt.c:19071
+#: cp/pt.c:19111
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr ""
 
-#: cp/pt.c:22972
+#: cp/pt.c:23050
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr ""
 
-#: cp/pt.c:22974
+#: cp/pt.c:23052
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr ""
 
-#: cp/pt.c:22980
+#: cp/pt.c:23058
 msgid "%s %#qS"
 msgstr ""
 
-#: cp/pt.c:23004 cp/pt.c:23091
+#: cp/pt.c:23082 cp/pt.c:23169
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr ""
 
-#: cp/pt.c:23023
+#: cp/pt.c:23101
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr ""
 
-#: cp/pt.c:23029 cp/pt.c:23086
+#: cp/pt.c:23107 cp/pt.c:23164
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr ""
 
-#: cp/pt.c:23034
+#: cp/pt.c:23112
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr ""
 
-#: cp/pt.c:23042
+#: cp/pt.c:23120
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr ""
 
-#: cp/pt.c:23078
+#: cp/pt.c:23156
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr ""
 
-#: cp/pt.c:23101 cp/pt.c:23187
+#: cp/pt.c:23179 cp/pt.c:23265
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr ""
 
-#: cp/pt.c:23106 cp/pt.c:23204
+#: cp/pt.c:23184 cp/pt.c:23282
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr ""
 
-#: cp/pt.c:23163
+#: cp/pt.c:23241
 #, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr ""
 
-#: cp/pt.c:23165
+#: cp/pt.c:23243
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr ""
 
-#: cp/pt.c:23174
+#: cp/pt.c:23252
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr ""
 
-#: cp/pt.c:23192
+#: cp/pt.c:23270
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr ""
 
-#: cp/pt.c:23238
+#: cp/pt.c:23316
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr ""
 
-#: cp/pt.c:23536
+#: cp/pt.c:23614
 #, gcc-internal-format
 msgid "exception specification of %qD depends on itself"
 msgstr ""
@@ -47596,110 +47639,110 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:23842
+#: cp/pt.c:23920
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr ""
 
-#: cp/pt.c:24043
+#: cp/pt.c:24121
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:24418
+#: cp/pt.c:24496
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr ""
 
-#: cp/pt.c:24420
+#: cp/pt.c:24498
 #, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr ""
 
-#: cp/pt.c:25723
+#: cp/pt.c:25802
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr ""
 
-#: cp/pt.c:25961
+#: cp/pt.c:26040
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/pt.c:26440
+#: cp/pt.c:26519
 #, gcc-internal-format
 msgid "non-class template %qT used without template arguments"
 msgstr ""
 
-#: cp/pt.c:26586
+#: cp/pt.c:26665
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:26593
+#: cp/pt.c:26672
 #, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr ""
 
-#: cp/pt.c:26607
+#: cp/pt.c:26686
 #, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr ""
 
-#: cp/pt.c:26614
+#: cp/pt.c:26693
 #, gcc-internal-format
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr ""
 
-#: cp/pt.c:26676
+#: cp/pt.c:26755
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:26679
+#: cp/pt.c:26758
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:26711
+#: cp/pt.c:26790
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/pt.c:26746
+#: cp/pt.c:26825
 #, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr ""
 
-#: cp/pt.c:26748
+#: cp/pt.c:26827
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr ""
 
-#: cp/pt.c:26781
+#: cp/pt.c:26860
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:26785
+#: cp/pt.c:26864
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "insn ne zadovoljava svoja ograničenja:"
 
-#: cp/pt.c:26789
+#: cp/pt.c:26868
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "insn ne zadovoljava svoja ograničenja:"
 
-#: cp/pt.c:26793
+#: cp/pt.c:26872
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "insn ne zadovoljava svoja ograničenja:"
 
-#: cp/pt.c:26912
+#: cp/pt.c:26991
 #, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr ""
@@ -47754,77 +47797,77 @@
 msgid "cannot dynamic_cast %qE (of type %q#T) to type %q#T (%s)"
 msgstr ""
 
-#: cp/search.c:240
+#: cp/search.c:243
 #, gcc-internal-format
 msgid "%qT is an ambiguous base of %qT"
 msgstr ""
 
-#: cp/search.c:256
+#: cp/search.c:259
 #, gcc-internal-format
 msgid "%qT is an inaccessible base of %qT"
 msgstr ""
 
-#: cp/search.c:1905
+#: cp/search.c:1908
 #, gcc-internal-format
 msgid "invalid covariant return type for %q#D"
 msgstr ""
 
-#: cp/search.c:1907 cp/search.c:1922 cp/search.c:1928 cp/search.c:1957
+#: cp/search.c:1910 cp/search.c:1925 cp/search.c:1931 cp/search.c:1960
 #, gcc-internal-format
 msgid "overridden function is %q#D"
 msgstr ""
 
-#: cp/search.c:1920
+#: cp/search.c:1923
 #, gcc-internal-format
 msgid "invalid covariant return type for %q+#D"
 msgstr ""
 
-#: cp/search.c:1926
+#: cp/search.c:1929
 #, gcc-internal-format
 msgid "conflicting return type specified for %q+#D"
 msgstr ""
 
-#: cp/search.c:1942
+#: cp/search.c:1945
 #, gcc-internal-format
 msgid "looser throw specifier for %q+#F"
 msgstr ""
 
-#: cp/search.c:1944
+#: cp/search.c:1947
 #, gcc-internal-format
 msgid "overridden function is %q#F"
 msgstr ""
 
-#: cp/search.c:1955
+#: cp/search.c:1958
 #, gcc-internal-format
 msgid "conflicting type attributes specified for %q+#D"
 msgstr ""
 
-#: cp/search.c:1972
+#: cp/search.c:1975
 #, gcc-internal-format
 msgid "%qD declared %<transaction_safe_dynamic%>"
 msgstr ""
 
-#: cp/search.c:1974
+#: cp/search.c:1977
 #, gcc-internal-format
 msgid "overriding %qD declared %<transaction_safe%>"
 msgstr ""
 
-#: cp/search.c:1981
+#: cp/search.c:1984
 #, gcc-internal-format
 msgid "deleted function %q+D overriding non-deleted function"
 msgstr ""
 
-#: cp/search.c:1984 cp/search.c:1992 cp/search.c:2000
+#: cp/search.c:1987 cp/search.c:1995 cp/search.c:2003
 #, gcc-internal-format
 msgid "overridden function is %qD"
 msgstr ""
 
-#: cp/search.c:1989
+#: cp/search.c:1992
 #, gcc-internal-format
 msgid "non-deleted function %q+D overriding deleted function"
 msgstr ""
 
-#: cp/search.c:1998
+#: cp/search.c:2001
 #, gcc-internal-format
 msgid "virtual function %q+D overriding final function"
 msgstr ""
@@ -47831,12 +47874,12 @@
 
 #. A static member function cannot match an inherited
 #. virtual member function.
-#: cp/search.c:2082
+#: cp/search.c:2085
 #, gcc-internal-format
 msgid "%q+#D cannot be declared"
 msgstr ""
 
-#: cp/search.c:2083
+#: cp/search.c:2086
 #, gcc-internal-format
 msgid "  since %q+#D declared in base class"
 msgstr ""
@@ -47876,576 +47919,591 @@
 msgid "invalid use of member %qD in static member function"
 msgstr ""
 
-#: cp/semantics.c:2153
+#: cp/semantics.c:2156
 #, gcc-internal-format
 msgid "a statement expression is an insufficient context for overload resolution"
 msgstr ""
 
-#: cp/semantics.c:2540
+#: cp/semantics.c:2543
 #, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr ""
 
-#: cp/semantics.c:2622
+#: cp/semantics.c:2625
 #, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr ""
 
-#: cp/semantics.c:2624
+#: cp/semantics.c:2627
 #, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr ""
 
-#: cp/semantics.c:2626
+#: cp/semantics.c:2629
 #, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr ""
 
-#: cp/semantics.c:2648
+#: cp/semantics.c:2651
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr ""
 
-#: cp/semantics.c:2656 cp/typeck.c:2604
+#: cp/semantics.c:2659 cp/typeck.c:2604
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/semantics.c:2678
+#: cp/semantics.c:2681
 #, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr ""
 
-#: cp/semantics.c:2751
+#: cp/semantics.c:2754
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr ""
 
-#: cp/semantics.c:2892
+#: cp/semantics.c:2895
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr ""
 
-#: cp/semantics.c:2942
+#: cp/semantics.c:2945
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr ""
 
-#: cp/semantics.c:2945
+#: cp/semantics.c:2948
 #, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr ""
 
-#: cp/semantics.c:2962
+#: cp/semantics.c:2965
 #, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr ""
 
-#: cp/semantics.c:2993
+#: cp/semantics.c:2996
 #, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr ""
 
-#: cp/semantics.c:3263
+#: cp/semantics.c:3266
 #, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr ""
 
-#: cp/semantics.c:3423
+#: cp/semantics.c:3426
 #, gcc-internal-format
 msgid "cannot capture member %qD of anonymous union"
 msgstr ""
 
-#: cp/semantics.c:3443 cp/semantics.c:9269
+#: cp/semantics.c:3446 cp/semantics.c:9272
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr ""
 
-#: cp/semantics.c:3448
+#: cp/semantics.c:3451
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.c:3450
+#: cp/semantics.c:3453
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.c:3462
+#: cp/semantics.c:3465
 #, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr ""
 
-#: cp/semantics.c:3464
+#: cp/semantics.c:3467
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr ""
 
-#: cp/semantics.c:3596
+#: cp/semantics.c:3599
 #, gcc-internal-format
 msgid "use of parameter outside function body"
 msgstr ""
 
-#: cp/semantics.c:3606
+#: cp/semantics.c:3609
 #, gcc-internal-format
 msgid "missing template arguments"
 msgstr ""
 
-#: cp/semantics.c:3633
+#: cp/semantics.c:3636
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr ""
 
-#: cp/semantics.c:3664
+#: cp/semantics.c:3667
 #, gcc-internal-format
 msgid "use of namespace %qD as expression"
 msgstr ""
 
-#: cp/semantics.c:3669
+#: cp/semantics.c:3672
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr ""
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:3675
+#: cp/semantics.c:3678
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr ""
 
-#: cp/semantics.c:3702
+#: cp/semantics.c:3705
 #, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/semantics.c:3841
+#: cp/semantics.c:3844
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr ""
 
-#: cp/semantics.c:3870
+#: cp/semantics.c:3873
 #, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr ""
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4009
+#: cp/semantics.c:4012
 #, gcc-internal-format
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr ""
 
-#: cp/semantics.c:4038
+#: cp/semantics.c:4041
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr ""
 
-#: cp/semantics.c:4052
+#: cp/semantics.c:4055
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr ""
 
-#: cp/semantics.c:4056
+#: cp/semantics.c:4059
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function"
 msgstr ""
 
-#: cp/semantics.c:4061
+#: cp/semantics.c:4064
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr ""
 
-#: cp/semantics.c:4072
+#: cp/semantics.c:4075
 #, gcc-internal-format
 msgid "offsetof within non-standard-layout type %qT is conditionally-supported"
 msgstr ""
 
-#: cp/semantics.c:4583 cp/semantics.c:6069 cp/semantics.c:6140
-#: cp/semantics.c:6183 cp/semantics.c:6533 cp/semantics.c:6632
-#: cp/semantics.c:6775
+#: cp/semantics.c:4586 cp/semantics.c:6072 cp/semantics.c:6143
+#: cp/semantics.c:6186 cp/semantics.c:6536 cp/semantics.c:6635
+#: cp/semantics.c:6778
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5271
+#: cp/semantics.c:5274
 #, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr ""
 
-#: cp/semantics.c:5544
+#: cp/semantics.c:5547
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: cp/semantics.c:5592
+#: cp/semantics.c:5595
 #, gcc-internal-format
 msgid "%qE has const type for %<reduction%>"
 msgstr ""
 
-#: cp/semantics.c:5707
+#: cp/semantics.c:5710
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:5941
+#: cp/semantics.c:5944
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5955
+#: cp/semantics.c:5958
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5977
+#: cp/semantics.c:5980
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6080
+#: cp/semantics.c:6083
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6152
+#: cp/semantics.c:6155
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr ""
 
-#: cp/semantics.c:6195
+#: cp/semantics.c:6198
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr ""
 
-#: cp/semantics.c:6240
+#: cp/semantics.c:6243
 #, gcc-internal-format
 msgid "%<gang%> static expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6254
+#: cp/semantics.c:6257
 #, gcc-internal-format
 msgid "%<gang%> static value must be positive"
 msgstr ""
 
-#: cp/semantics.c:6288
+#: cp/semantics.c:6291
 #, gcc-internal-format
 msgid "%<gang%> num expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6291
+#: cp/semantics.c:6294
 #, gcc-internal-format
 msgid "%<vector%> length expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6295
+#: cp/semantics.c:6298
 #, gcc-internal-format
 msgid "%<worker%> num expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6317
+#: cp/semantics.c:6320
 #, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr ""
 
-#: cp/semantics.c:6321
+#: cp/semantics.c:6324
 #, gcc-internal-format
 msgid "%<vector%> length value must be positive"
 msgstr ""
 
-#: cp/semantics.c:6326
+#: cp/semantics.c:6329
 #, gcc-internal-format
 msgid "%<worker%> num value must be positive"
 msgstr ""
 
-#: cp/semantics.c:6376
+#: cp/semantics.c:6379
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6406
+#: cp/semantics.c:6409
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6419
+#: cp/semantics.c:6422
 #, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr ""
 
-#: cp/semantics.c:6438
+#: cp/semantics.c:6441
 #, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6466
+#: cp/semantics.c:6469
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6495
+#: cp/semantics.c:6498
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr ""
 
-#: cp/semantics.c:6516
+#: cp/semantics.c:6519
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6543
+#: cp/semantics.c:6546
 #, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr ""
 
-#: cp/semantics.c:6557
+#: cp/semantics.c:6560
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:6563
+#: cp/semantics.c:6566
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: cp/semantics.c:6576
+#: cp/semantics.c:6579
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6625
+#: cp/semantics.c:6628
 #, gcc-internal-format
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr ""
 
-#: cp/semantics.c:6910
+#: cp/semantics.c:6913
 #, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6914
+#: cp/semantics.c:6917
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6979
+#: cp/semantics.c:6982
 #, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7008
+#: cp/semantics.c:7011
 #, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7037
+#: cp/semantics.c:7040
 #, gcc-internal-format
 msgid "%<num_tasks%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7066
+#: cp/semantics.c:7069
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:7105
+#: cp/semantics.c:7108
 #, gcc-internal-format
 msgid "%<tile%> argument needs integral type"
 msgstr ""
 
-#: cp/semantics.c:7524
+#: cp/semantics.c:7527
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.c:7538
+#: cp/semantics.c:7541
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr ""
 
-#: cp/semantics.c:7743
+#: cp/semantics.c:7746
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.c:8171
+#: cp/semantics.c:8174
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.c:8398 cp/semantics.c:8408
+#: cp/semantics.c:8401 cp/semantics.c:8411
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.c:8702
+#: cp/semantics.c:8705
 #, gcc-internal-format
 msgid "static assertion failed"
 msgstr ""
 
-#: cp/semantics.c:8704
+#: cp/semantics.c:8707
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr ""
 
-#: cp/semantics.c:8709
+#: cp/semantics.c:8712
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr ""
 
-#: cp/semantics.c:8739
+#: cp/semantics.c:8742
 #, gcc-internal-format
 msgid "argument to decltype must be an expression"
 msgstr ""
 
-#: cp/semantics.c:8767
+#: cp/semantics.c:8770
 #, gcc-internal-format
 msgid "decltype cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/semantics.c:9308
+#: cp/semantics.c:9311
 #, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.c:9361
+#: cp/semantics.c:9364
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.c:9363
+#: cp/semantics.c:9366
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:9381
+#: cp/semantics.c:9384
 #, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr ""
 
-#: cp/tree.c:1276
+#: cp/tree.c:1295
 #, gcc-internal-format
 msgid "%qV qualifiers cannot be applied to %qT"
 msgstr ""
 
-#: cp/tree.c:1788
+#: cp/tree.c:1807
 #, gcc-internal-format
 msgid "lambda-expression in a constant expression"
 msgstr ""
 
-#: cp/tree.c:1792
+#: cp/tree.c:1811
 #, gcc-internal-format
 msgid "statement-expression in a constant expression"
 msgstr ""
 
-#: cp/tree.c:4050
+#: cp/tree.c:4083
 #, gcc-internal-format
-msgid "the calling convention for %qT changes in -fabi-version=12 (GCC 8)"
+msgid "-fabi-version=13 (GCC 8.2) fixes the calling convention for %qT, which was accidentally changed in 8.1"
 msgstr ""
 
-#: cp/tree.c:4055
+#: cp/tree.c:4087
 #, gcc-internal-format
+msgid "-fabi-version=12 (GCC 8.1) accidentally changes the calling convention for %qT"
+msgstr ""
+
+#: cp/tree.c:4090
+#, gcc-internal-format
+msgid " declared here"
+msgstr ""
+
+#: cp/tree.c:4094
+#, gcc-internal-format
+msgid "the calling convention for %qT changes in -fabi-version=13 (GCC 8.2)"
+msgstr ""
+
+#: cp/tree.c:4096
+#, gcc-internal-format
 msgid " because all of its copy and move constructors are deleted"
 msgstr ""
 
-#: cp/tree.c:4416
+#: cp/tree.c:4464
 #, gcc-internal-format
 msgid "%qE attribute applied to %qD with void return type"
 msgstr ""
 
-#: cp/tree.c:4423
+#: cp/tree.c:4471
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr ""
 
-#: cp/tree.c:4475
+#: cp/tree.c:4523
 #, gcc-internal-format
 msgid "requested init_priority is not an integer constant"
 msgstr ""
 
-#: cp/tree.c:4497
+#: cp/tree.c:4545
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr ""
 
-#: cp/tree.c:4505
+#: cp/tree.c:4553
 #, gcc-internal-format
 msgid "requested init_priority is out of range"
 msgstr ""
 
-#: cp/tree.c:4515
+#: cp/tree.c:4563
 #, gcc-internal-format
 msgid "requested init_priority is reserved for internal use"
 msgstr ""
 
-#: cp/tree.c:4526
+#: cp/tree.c:4574
 #, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr ""
 
-#: cp/tree.c:4553
+#: cp/tree.c:4601
 #, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %qE"
 msgstr ""
 
-#: cp/tree.c:4573
+#: cp/tree.c:4621
 #, gcc-internal-format
 msgid "the %qE attribute requires arguments"
 msgstr ""
 
-#: cp/tree.c:4584
+#: cp/tree.c:4632
 #, gcc-internal-format
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr ""
 
-#: cp/tree.c:4597 cp/tree.c:4610
+#: cp/tree.c:4645 cp/tree.c:4658
 #, gcc-internal-format
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr ""
 
-#: cp/tree.c:4599
+#: cp/tree.c:4647
 #, gcc-internal-format
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr ""
 
-#: cp/tree.c:4612
+#: cp/tree.c:4660
 #, gcc-internal-format
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr ""
 
-#: cp/tree.c:4636
+#: cp/tree.c:4684
 #, gcc-internal-format
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr ""
 
-#: cp/tree.c:4642
+#: cp/tree.c:4690
 #, gcc-internal-format
 msgid "%qE attribute applied to %qT after its definition"
 msgstr ""
 
-#: cp/tree.c:4649
+#: cp/tree.c:4697
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr ""
 
-#: cp/tree.c:4656
+#: cp/tree.c:4704
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr ""
 
-#: cp/tree.c:4678
+#: cp/tree.c:4726
 #, gcc-internal-format
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr ""
 
-#: cp/tree.c:4684
+#: cp/tree.c:4732
 #, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr ""
 
-#: cp/tree.c:5440
+#: cp/tree.c:5488
 #, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr ""
 
-#: cp/tree.c:5453
+#: cp/tree.c:5501
 #, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr ""
@@ -49531,107 +49589,107 @@
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr ""
 
-#: cp/typeck2.c:1496 cp/typeck2.c:1523
+#: cp/typeck2.c:1499 cp/typeck2.c:1526
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr ""
 
-#: cp/typeck2.c:1504
+#: cp/typeck2.c:1507
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr ""
 
-#: cp/typeck2.c:1511
+#: cp/typeck2.c:1514
 #, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr ""
 
-#: cp/typeck2.c:1587
+#: cp/typeck2.c:1590
 #, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr ""
 
-#: cp/typeck2.c:1660
+#: cp/typeck2.c:1663
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr ""
 
-#: cp/typeck2.c:1671
+#: cp/typeck2.c:1674
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr ""
 
-#: cp/typeck2.c:1858
+#: cp/typeck2.c:1861
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr ""
 
-#: cp/typeck2.c:1872
+#: cp/typeck2.c:1875
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr ""
 
-#: cp/typeck2.c:1898
+#: cp/typeck2.c:1901
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr ""
 
-#: cp/typeck2.c:1900
+#: cp/typeck2.c:1903
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr ""
 
-#: cp/typeck2.c:1927
+#: cp/typeck2.c:1930
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr ""
 
-#: cp/typeck2.c:1936
+#: cp/typeck2.c:1939
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr ""
 
-#: cp/typeck2.c:1958
+#: cp/typeck2.c:1961
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2018
+#: cp/typeck2.c:2021
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr ""
 
-#: cp/typeck2.c:2029
+#: cp/typeck2.c:2032
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr ""
 
-#: cp/typeck2.c:2037
+#: cp/typeck2.c:2040
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++2a"
 msgstr ""
 
-#: cp/typeck2.c:2080
+#: cp/typeck2.c:2083
 #, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2096
+#: cp/typeck2.c:2099
 #, gcc-internal-format
 msgid "cannot deduce template arguments for %qT from ()"
 msgstr ""
 
-#: cp/typeck2.c:2114
+#: cp/typeck2.c:2117
 #, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr ""
 
-#: cp/typeck2.c:2341
+#: cp/typeck2.c:2344
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr ""
 
-#: cp/typeck2.c:2344
+#: cp/typeck2.c:2347
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr ""
@@ -49846,11 +49904,11 @@
 msgstr ""
 
 #: fortran/array.c:221 fortran/array.c:661 fortran/check.c:2849
-#: fortran/check.c:5222 fortran/check.c:5260 fortran/check.c:5302
-#: fortran/check.c:5329 fortran/check.c:5529 fortran/match.c:1821
+#: fortran/check.c:5225 fortran/check.c:5263 fortran/check.c:5305
+#: fortran/check.c:5332 fortran/check.c:5532 fortran/match.c:1821
 #: fortran/match.c:3174 fortran/match.c:3516 fortran/match.c:3712
-#: fortran/simplify.c:2909 fortran/simplify.c:2939 fortran/simplify.c:5764
-#: fortran/simplify.c:7658
+#: fortran/simplify.c:2909 fortran/simplify.c:2939 fortran/simplify.c:5769
+#: fortran/simplify.c:7663
 #, gcc-internal-format
 msgid "Coarrays disabled at %C, use %<-fcoarray=%> to enable"
 msgstr ""
@@ -49985,118 +50043,123 @@
 msgid "DO-iterator %qs at %L is inside iterator of the same name"
 msgstr ""
 
-#: fortran/array.c:1073 fortran/array.c:1255
+#: fortran/array.c:1073 fortran/array.c:1264
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in array constructor at %C"
 msgstr ""
 
-#: fortran/array.c:1129
+#: fortran/array.c:1105
 #, gcc-internal-format, gfc-internal-format
+msgid "NULL() at %C cannot appear in an array constructor"
+msgstr ""
+
+#: fortran/array.c:1138
+#, gcc-internal-format, gfc-internal-format
 msgid "[...] style array constructors at %C"
 msgstr ""
 
-#: fortran/array.c:1149
+#: fortran/array.c:1158
 #, gcc-internal-format, gfc-internal-format
 msgid "Array constructor including type specification at %C"
 msgstr ""
 
-#: fortran/array.c:1155 fortran/match.c:4148
+#: fortran/array.c:1164 fortran/match.c:4148
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-spec at %L cannot contain a deferred type parameter"
 msgstr ""
 
-#: fortran/array.c:1163
+#: fortran/array.c:1172
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-spec at %L cannot contain an asterisk for a type parameter"
 msgstr ""
 
-#: fortran/array.c:1181
+#: fortran/array.c:1190
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty array constructor at %C is not allowed"
 msgstr ""
 
-#: fortran/array.c:1218 fortran/array.c:1228
+#: fortran/array.c:1227 fortran/array.c:1237
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible typespec for array element at %L"
 msgstr ""
 
-#: fortran/array.c:1302
+#: fortran/array.c:1311
 #, gcc-internal-format, gfc-internal-format
 msgid "Element in %s array constructor at %L is %s"
 msgstr ""
 
-#: fortran/array.c:1633
+#: fortran/array.c:1642
 #, gcc-internal-format, gfc-internal-format
 msgid "Iterator step at %L cannot be zero"
 msgstr ""
 
-#: fortran/array.c:1770
+#: fortran/array.c:1779
 #, gcc-internal-format
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit.   See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/array.c:1940
+#: fortran/array.c:1949
 #, gcc-internal-format, gfc-internal-format
 msgid "AC-IMPLIED-DO initial expression references control variable at %L"
 msgstr ""
 
-#: fortran/array.c:1947
+#: fortran/array.c:1956
 #, gcc-internal-format, gfc-internal-format
 msgid "AC-IMPLIED-DO final expression references control variable at %L"
 msgstr ""
 
-#: fortran/array.c:1954
+#: fortran/array.c:1963
 #, gcc-internal-format, gfc-internal-format
 msgid "AC-IMPLIED-DO step expression references control variable at %L"
 msgstr ""
 
-#: fortran/array.c:1966
+#: fortran/array.c:1975
 #, gcc-internal-format, gfc-internal-format
 msgid "Array constructor value at %L shall not be unlimited polymorphic [F2008: C4106]"
 msgstr ""
 
-#: fortran/array.c:2055
+#: fortran/array.c:2067
 #, gcc-internal-format, gfc-internal-format
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor at %L"
 msgstr ""
 
-#: fortran/array.c:2174
+#: fortran/array.c:2186
 #, gcc-internal-format
 msgid "spec_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2233
+#: fortran/array.c:2245
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2237
+#: fortran/array.c:2249
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array dimension at %L"
 msgstr ""
 
-#: fortran/array.c:2264 fortran/data.c:552 fortran/data.c:571
-#: fortran/data.c:585 fortran/data.c:714
+#: fortran/array.c:2276 fortran/data.c:563 fortran/data.c:582
+#: fortran/data.c:596 fortran/data.c:725
 #, gcc-internal-format
 msgid "Simplification error"
 msgstr ""
 
-#: fortran/array.c:2376
+#: fortran/array.c:2388
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimen_type"
 msgstr ""
 
-#: fortran/array.c:2427
+#: fortran/array.c:2439
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2472
+#: fortran/array.c:2484
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad EXPR_ARRAY expr"
 msgstr ""
 
-#: fortran/array.c:2620
+#: fortran/array.c:2632
 #, gcc-internal-format
 msgid "gfc_find_array_ref(): No ref found"
 msgstr ""
@@ -50147,7 +50210,7 @@
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or PROCEDURE"
 msgstr ""
 
-#: fortran/check.c:205 fortran/check.c:6658
+#: fortran/check.c:205 fortran/check.c:6661
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a constant"
 msgstr ""
@@ -50262,7 +50325,7 @@
 msgid "Unequal character lengths (%ld/%ld) in %s at %L"
 msgstr ""
 
-#: fortran/check.c:946 fortran/check.c:6602
+#: fortran/check.c:946 fortran/check.c:6605
 #, gcc-internal-format
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have the same type"
 msgstr ""
@@ -50497,9 +50560,9 @@
 msgstr ""
 
 #: fortran/check.c:1939 fortran/check.c:2525 fortran/check.c:2628
-#: fortran/check.c:2835 fortran/check.c:2880 fortran/check.c:4256
-#: fortran/check.c:4390 fortran/check.c:4445 fortran/check.c:5515
-#: fortran/check.c:5644
+#: fortran/check.c:2835 fortran/check.c:2880 fortran/check.c:4259
+#: fortran/check.c:4393 fortran/check.c:4448 fortran/check.c:5518
+#: fortran/check.c:5647
 #, gcc-internal-format
 msgid "%qs intrinsic with KIND argument at %L"
 msgstr ""
@@ -50694,7 +50757,7 @@
 msgid "NULL intrinsic with allocatable MOLD at %L"
 msgstr ""
 
-#: fortran/check.c:3768 fortran/check.c:5591
+#: fortran/check.c:3768 fortran/check.c:5594
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must provide at least as many elements as there are .TRUE. values in %qs (%ld/%d)"
 msgstr ""
@@ -50714,372 +50777,372 @@
 msgid "%qs argument of %qs intrinsic at %L must not be a subobject of %qs"
 msgstr ""
 
-#: fortran/check.c:3901
+#: fortran/check.c:3904
 #, gcc-internal-format, gfc-internal-format
 msgid "The argument of the RANK intrinsic at %L must be a data object"
 msgstr ""
 
-#: fortran/check.c:4005
+#: fortran/check.c:4008
 #, gcc-internal-format
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L must be an array of constant size"
 msgstr ""
 
-#: fortran/check.c:4015
+#: fortran/check.c:4018
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L is empty"
 msgstr ""
 
-#: fortran/check.c:4022
+#: fortran/check.c:4025
 #, gcc-internal-format
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L has more than %d elements"
 msgstr ""
 
-#: fortran/check.c:4039
+#: fortran/check.c:4042
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has negative element (%d)"
 msgstr ""
 
-#: fortran/check.c:4071
+#: fortran/check.c:4074
 #, gcc-internal-format, gfc-internal-format
 msgid "Element %d of actual argument of RESHAPE at %L cannot be negative"
 msgstr ""
 
-#: fortran/check.c:4109
+#: fortran/check.c:4112
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has wrong number of elements (%d/%d)"
 msgstr ""
 
-#: fortran/check.c:4127
+#: fortran/check.c:4130
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has out-of-range dimension (%d)"
 msgstr ""
 
-#: fortran/check.c:4136
+#: fortran/check.c:4139
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has invalid permutation of dimensions (dimension %qd duplicated)"
 msgstr ""
 
-#: fortran/check.c:4172
+#: fortran/check.c:4175
 #, gcc-internal-format, gfc-internal-format
 msgid "Without padding, there are not enough elements in the intrinsic RESHAPE source at %L to match the shape"
 msgstr ""
 
-#: fortran/check.c:4189 fortran/check.c:4208
+#: fortran/check.c:4192 fortran/check.c:4211
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L cannot be of type %s"
 msgstr ""
 
-#: fortran/check.c:4199 fortran/check.c:4218
+#: fortran/check.c:4202 fortran/check.c:4221
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of an extensible type"
 msgstr ""
 
-#: fortran/check.c:4317
+#: fortran/check.c:4320
 #, gcc-internal-format
 msgid "SELECTED_REAL_KIND with neither %<P%> nor %<R%> argument at %L"
 msgstr ""
 
-#: fortran/check.c:4348
+#: fortran/check.c:4351
 #, gcc-internal-format
 msgid "%qs intrinsic with RADIX argument at %L"
 msgstr ""
 
-#: fortran/check.c:4383
+#: fortran/check.c:4386
 #, gcc-internal-format
 msgid "%<source%> argument of %<shape%> intrinsic at %L must not be an assumed size array"
 msgstr ""
 
-#: fortran/check.c:4460 fortran/check.c:6641
+#: fortran/check.c:4463 fortran/check.c:6644
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be a procedure"
 msgstr ""
 
-#: fortran/check.c:4473 fortran/check.c:4612 fortran/check.c:6633
+#: fortran/check.c:4476 fortran/check.c:4615 fortran/check.c:6636
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be TYPE(*)"
 msgstr ""
 
-#: fortran/check.c:4484 fortran/check.c:4624
+#: fortran/check.c:4487 fortran/check.c:4627
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be an assumed-size array"
 msgstr ""
 
-#: fortran/check.c:4554
+#: fortran/check.c:4557
 #, gcc-internal-format
 msgid "is_c_interoperable(): gfc_simplify_expr failed"
 msgstr ""
 
-#: fortran/check.c:4603
+#: fortran/check.c:4606
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be an interoperable data entity: %s"
 msgstr ""
 
-#: fortran/check.c:4642
+#: fortran/check.c:4645
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_1 at %L to C_ASSOCIATED shall have the type TYPE(C_PTR) or TYPE(C_FUNPTR)"
 msgstr ""
 
-#: fortran/check.c:4656
+#: fortran/check.c:4659
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_2 at %L to C_ASSOCIATED shall have the same type as C_PTR_1: %s instead of %s"
 msgstr ""
 
-#: fortran/check.c:4680
+#: fortran/check.c:4683
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_POINTER shall have the type TYPE(C_PTR)"
 msgstr ""
 
-#: fortran/check.c:4692
+#: fortran/check.c:4695
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER must be a pointer"
 msgstr ""
 
-#: fortran/check.c:4699
+#: fortran/check.c:4702
 #, gcc-internal-format, gfc-internal-format
 msgid "FPTR argument at %L to C_F_POINTER shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:4706
+#: fortran/check.c:4709
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:4713
+#: fortran/check.c:4716
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected SHAPE argument at %L to C_F_POINTER with scalar FPTR"
 msgstr ""
 
-#: fortran/check.c:4719
+#: fortran/check.c:4722
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected SHAPE argument to C_F_POINTER with array FPTR at %L"
 msgstr ""
 
-#: fortran/check.c:4738
+#: fortran/check.c:4741
 #, gcc-internal-format, gfc-internal-format
 msgid "SHAPE argument at %L to C_F_POINTER must have the same size as the RANK of FPTR"
 msgstr ""
 
-#: fortran/check.c:4748
+#: fortran/check.c:4751
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic FPTR at %L to C_F_POINTER"
 msgstr ""
 
-#: fortran/check.c:4753
+#: fortran/check.c:4756
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array FPTR at %L to C_F_POINTER: %s"
 msgstr ""
 
-#: fortran/check.c:4769
+#: fortran/check.c:4772
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_PROCPOINTER shall have the type TYPE(C_FUNPTR)"
 msgstr ""
 
-#: fortran/check.c:4781
+#: fortran/check.c:4784
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall be a procedure pointer"
 msgstr ""
 
-#: fortran/check.c:4788
+#: fortran/check.c:4791
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:4794
+#: fortran/check.c:4797
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure pointer at %L to C_F_PROCPOINTER"
 msgstr ""
 
-#: fortran/check.c:4808
+#: fortran/check.c:4811
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:4823
+#: fortran/check.c:4826
 #, gcc-internal-format
 msgid "Function result %qs at %L is invalid as X argument to C_FUNLOC"
 msgstr ""
 
-#: fortran/check.c:4831
+#: fortran/check.c:4834
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall be a procedure or a procedure pointer"
 msgstr ""
 
-#: fortran/check.c:4837
+#: fortran/check.c:4840
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure at %L to C_FUNLOC"
 msgstr ""
 
-#: fortran/check.c:4851
+#: fortran/check.c:4854
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:4857
+#: fortran/check.c:4860
 #, gcc-internal-format, gfc-internal-format
 msgid "X argument at %L to C_LOC shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:4868
+#: fortran/check.c:4871
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall have either the POINTER or the TARGET attribute"
 msgstr ""
 
-#: fortran/check.c:4876
+#: fortran/check.c:4879
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall be not be a zero-sized string"
 msgstr ""
 
-#: fortran/check.c:4885
+#: fortran/check.c:4888
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument at %L to C_LOC shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:4892
+#: fortran/check.c:4895
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array at %L as argument to C_LOC: %s"
 msgstr ""
 
-#: fortran/check.c:4903
+#: fortran/check.c:4906
 #, gcc-internal-format, gfc-internal-format
 msgid "Array of interoperable type at %L to C_LOC which is nonallocatable and neither assumed size nor explicit size"
 msgstr ""
 
-#: fortran/check.c:4908
+#: fortran/check.c:4911
 #, gcc-internal-format, gfc-internal-format
 msgid "Array section at %L to C_LOC"
 msgstr ""
 
-#: fortran/check.c:4936
+#: fortran/check.c:4939
 #, gcc-internal-format, gfc-internal-format
 msgid "non double precision REAL argument to %s intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:4949
+#: fortran/check.c:4952
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be less than rank %d"
 msgstr ""
 
-#: fortran/check.c:4968
+#: fortran/check.c:4971
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L is not a valid dimension index"
 msgstr ""
 
-#: fortran/check.c:5231
+#: fortran/check.c:5234
 #, gcc-internal-format, gfc-internal-format
 msgid "%s argument to IMAGE_INDEX must be a rank one array at %L"
 msgstr ""
 
-#: fortran/check.c:5242
+#: fortran/check.c:5245
 #, gcc-internal-format, gfc-internal-format
 msgid "The number of array elements of the SUB argument to IMAGE_INDEX at %L shall be %d (corank) not %d"
 msgstr ""
 
-#: fortran/check.c:5275
+#: fortran/check.c:5278
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to NUM_IMAGES at %L"
 msgstr ""
 
-#: fortran/check.c:5288
+#: fortran/check.c:5291
 #, gcc-internal-format, gfc-internal-format
 msgid "FAILED= argument to NUM_IMAGES at %L"
 msgstr ""
 
-#: fortran/check.c:5312
+#: fortran/check.c:5315
 #, gcc-internal-format, gfc-internal-format
 msgid "TEAM argument at %L to the intrinsic TEAM_NUMBER shall be of type TEAM_TYPE"
 msgstr ""
 
-#: fortran/check.c:5338
+#: fortran/check.c:5341
 #, gcc-internal-format, gfc-internal-format
 msgid "DIM argument without COARRAY argument not allowed for THIS_IMAGE intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:5345
+#: fortran/check.c:5348
 #, gcc-internal-format, gfc-internal-format
 msgid "The DISTANCE argument may not be specified together with the COARRAY or DIM argument in intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:5356
+#: fortran/check.c:5359
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected DIM argument with noncoarray argument at %L"
 msgstr ""
 
-#: fortran/check.c:5374
+#: fortran/check.c:5377
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to THIS_IMAGE at %L"
 msgstr ""
 
-#: fortran/check.c:5454
+#: fortran/check.c:5457
 #, gcc-internal-format
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L must not be %s"
 msgstr ""
 
-#: fortran/check.c:5483
+#: fortran/check.c:5486
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic TRANSFER at %L has partly undefined result: source size %ld < result size %ld"
 msgstr ""
 
-#: fortran/check.c:5605
+#: fortran/check.c:5608
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must have the same rank as %qs or be a scalar"
 msgstr ""
 
-#: fortran/check.c:5618
+#: fortran/check.c:5621
 #, gcc-internal-format
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have identical shape."
 msgstr ""
 
-#: fortran/check.c:5861 fortran/check.c:5893
+#: fortran/check.c:5864 fortran/check.c:5896
 #, gcc-internal-format
 msgid "Size of %qs argument of %qs intrinsic at %L too small (%i/%i)"
 msgstr ""
 
-#: fortran/check.c:5901
+#: fortran/check.c:5904
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many arguments to %s at %L"
 msgstr ""
 
-#: fortran/check.c:5919
+#: fortran/check.c:5922
 #, gcc-internal-format
 msgid "fe_runtime_error string must be null terminated"
 msgstr ""
 
-#: fortran/check.c:5931
+#: fortran/check.c:5934
 #, gcc-internal-format, gfc-internal-format
 msgid "fe_runtime_error: Wrong number of arguments (%d instead of %d)"
 msgstr ""
 
-#: fortran/check.c:5971
+#: fortran/check.c:5974
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:5990
+#: fortran/check.c:5993
 #, gcc-internal-format, gfc-internal-format
 msgid "Real COUNT_RATE argument to SYSTEM_CLOCK at %L"
 msgstr ""
 
-#: fortran/check.c:6000
+#: fortran/check.c:6003
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT_RATE argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:6017
+#: fortran/check.c:6020
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT_MAX argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:6234
+#: fortran/check.c:6237
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of a kind not wider than the default kind (%d)"
 msgstr ""
 
-#: fortran/check.c:6586 fortran/check.c:6594
+#: fortran/check.c:6589 fortran/check.c:6597
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or LOGICAL"
 msgstr ""
 
-#: fortran/check.c:6625
+#: fortran/check.c:6628
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic function NULL at %L cannot be an actual argument to STORAGE_SIZE, because it returns a disassociated pointer"
 msgstr ""
@@ -51091,7 +51154,7 @@
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:727 fortran/decl.c:3636 fortran/decl.c:10066
+#: fortran/class.c:727 fortran/decl.c:3655 fortran/decl.c:10091
 #, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr ""
@@ -51117,43 +51180,48 @@
 msgid "non-constant array in DATA statement %L"
 msgstr ""
 
-#: fortran/data.c:137
+#: fortran/data.c:140
 #, gcc-internal-format, gfc-internal-format
 msgid "failure to simplify substring reference in DATA statement at %L"
 msgstr ""
 
-#: fortran/data.c:170
+#: fortran/data.c:173
 #, gcc-internal-format, gfc-internal-format
 msgid "Unused initialization string at %L because variable has zero length"
 msgstr ""
 
-#: fortran/data.c:176
+#: fortran/data.c:179
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization string at %L was truncated to fit the variable (%ld/%ld)"
 msgstr ""
 
-#: fortran/data.c:265
+#: fortran/data.c:268
 #, gcc-internal-format
 msgid "%qs at %L already is initialized at %L"
 msgstr ""
 
-#: fortran/data.c:289
+#: fortran/data.c:292
 #, gcc-internal-format, gfc-internal-format
 msgid "Data element below array lower bound at %L"
 msgstr ""
 
-#: fortran/data.c:306 fortran/data.c:395
+#: fortran/data.c:309 fortran/data.c:398
 #, gcc-internal-format, gfc-internal-format
 msgid "Data element above array upper bound at %L"
 msgstr ""
 
-#: fortran/data.c:336 fortran/data.c:505
+#: fortran/data.c:339 fortran/data.c:496
 #, gcc-internal-format
 msgid "re-initialization of %qs at %L"
 msgstr ""
 
-#: fortran/data.c:727
+#: fortran/data.c:515
 #, gcc-internal-format
+msgid "Nonpointer object %qs with default initialization shall not appear in a DATA statement at %L"
+msgstr ""
+
+#: fortran/data.c:738
+#, gcc-internal-format
 msgid "TODO: Vector sections in data statements"
 msgstr ""
 
@@ -51177,784 +51245,784 @@
 msgid "Invalid initializer %s in Data statement at %C"
 msgstr ""
 
-#: fortran/decl.c:536
+#: fortran/decl.c:537
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:573
+#: fortran/decl.c:574
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %C cannot appear within an INTERFACE"
 msgstr ""
 
-#: fortran/decl.c:597
+#: fortran/decl.c:598
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid substring in data-implied-do at %L in DATA statement"
 msgstr ""
 
-#: fortran/decl.c:619
+#: fortran/decl.c:620
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:664
+#: fortran/decl.c:662
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty old style initializer list at %C"
 msgstr ""
 
-#: fortran/decl.c:684
+#: fortran/decl.c:671
 #, gcc-internal-format, gfc-internal-format
+msgid "Array in initializer list at %L must have an explicit shape"
+msgstr ""
+
+#: fortran/decl.c:694
+#, gcc-internal-format, gfc-internal-format
 msgid "Repeat spec invalid in scalar initializer at %C"
 msgstr ""
 
-#: fortran/decl.c:689
+#: fortran/decl.c:699
 #, gcc-internal-format, gfc-internal-format
 msgid "Repeat spec must be an integer at %C"
 msgstr ""
 
-#: fortran/decl.c:698
+#: fortran/decl.c:710
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected data constant after repeat spec at %C"
 msgstr ""
 
-#: fortran/decl.c:729
+#: fortran/decl.c:742
 #, gcc-internal-format, gfc-internal-format
 msgid "End of scalar initializer expected at %C"
 msgstr ""
 
-#: fortran/decl.c:758
+#: fortran/decl.c:773
 #, gcc-internal-format, gfc-internal-format
-msgid "Expected constant array-spec in initializer list at %L"
-msgstr ""
-
-#: fortran/decl.c:767
-#, gcc-internal-format, gfc-internal-format
 msgid "Not enough elements in array initializer at %C"
 msgstr ""
 
-#: fortran/decl.c:769
+#: fortran/decl.c:775
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many elements in array initializer at %C"
 msgstr ""
 
-#: fortran/decl.c:790
+#: fortran/decl.c:795
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in old style initializer list at %C"
 msgstr ""
 
-#: fortran/decl.c:812
+#: fortran/decl.c:821
 #, gcc-internal-format, gfc-internal-format
 msgid "The assumed-rank array at %C shall not have a codimension"
 msgstr ""
 
-#: fortran/decl.c:876
+#: fortran/decl.c:885
 #, gcc-internal-format, gfc-internal-format
 msgid "Sum of array rank %d and corank %d at %C exceeds maximum allowed dimensions of %d"
 msgstr ""
 
-#: fortran/decl.c:900
+#: fortran/decl.c:909
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad INTENT specification at %C"
 msgstr ""
 
-#: fortran/decl.c:921
+#: fortran/decl.c:930
 #, gcc-internal-format, gfc-internal-format
 msgid "deferred type parameter at %C"
 msgstr ""
 
-#: fortran/decl.c:1004 fortran/resolve.c:11705
+#: fortran/decl.c:1013 fortran/resolve.c:11725
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
 
-#: fortran/decl.c:1030
+#: fortran/decl.c:1039
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style character length at %C"
 msgstr ""
 
-#: fortran/decl.c:1061
+#: fortran/decl.c:1070
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in character length specification at %C"
 msgstr ""
 
-#: fortran/decl.c:1212 fortran/decl.c:1217 fortran/decl.c:1266
+#: fortran/decl.c:1221 fortran/decl.c:1226 fortran/decl.c:1275
 #, gcc-internal-format
 msgid "Procedure %qs at %C is already defined at %L"
 msgstr ""
 
-#: fortran/decl.c:1222
+#: fortran/decl.c:1231
 #, gcc-internal-format
 msgid "Contained procedure %qs at %C clashes with procedure defined at %L"
 msgstr ""
 
-#: fortran/decl.c:1231
+#: fortran/decl.c:1240
 #, gcc-internal-format
 msgid "Name %qs at %C is already defined as a generic interface at %L"
 msgstr ""
 
-#: fortran/decl.c:1244
+#: fortran/decl.c:1253
 #, gcc-internal-format
 msgid "Procedure %qs at %C has an explicit interface from a previous declaration"
 msgstr ""
 
-#: fortran/decl.c:1257
+#: fortran/decl.c:1266
 #, gcc-internal-format
 msgid "Procedure %qs defined in interface body at %L clashes with internal procedure defined at %C"
 msgstr ""
 
-#: fortran/decl.c:1335
+#: fortran/decl.c:1344
 #, gcc-internal-format
 msgid "Procedure %qs at %L must have the BIND(C) attribute to be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:1362
+#: fortran/decl.c:1371
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because derived type %qs is not C interoperable"
 msgstr ""
 
-#: fortran/decl.c:1369
+#: fortran/decl.c:1378
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because it is polymorphic"
 msgstr ""
 
-#: fortran/decl.c:1376
+#: fortran/decl.c:1385
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument of the BIND(C) procedure %qs but may not be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:1391
+#: fortran/decl.c:1400
 #, gcc-internal-format
 msgid "Character argument %qs at %L must be length 1 because procedure %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1404
+#: fortran/decl.c:1413
 #, gcc-internal-format
 msgid "Variable %qs at %L with ALLOCATABLE attribute in procedure %qs with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1412
+#: fortran/decl.c:1421
 #, gcc-internal-format
 msgid "Variable %qs at %L with POINTER attribute in procedure %qs with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1421
+#: fortran/decl.c:1430
 #, gcc-internal-format
 msgid "Scalar variable %qs at %L with POINTER or ALLOCATABLE in procedure %qs with BIND(C) is not yet supported"
 msgstr ""
 
-#: fortran/decl.c:1430
+#: fortran/decl.c:1439
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the OPTIONAL and the VALUE attribute because procedure %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1437
+#: fortran/decl.c:1446
 #, gcc-internal-format
 msgid "Variable %qs at %L with OPTIONAL attribute in procedure %qs which is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1448
+#: fortran/decl.c:1457
 #, gcc-internal-format
 msgid "Assumed-shape array %qs at %L as dummy argument to the BIND(C) procedure %qs at %L"
 msgstr ""
 
-#: fortran/decl.c:1516
+#: fortran/decl.c:1525
 #, gcc-internal-format
 msgid "Symbol %qs at %C also declared as a type at %L"
 msgstr ""
 
-#: fortran/decl.c:1575
+#: fortran/decl.c:1584
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %C must be declared with a C interoperable kind since common block %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1615
+#: fortran/decl.c:1624
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER length must be a constant at %L"
 msgstr ""
 
-#: fortran/decl.c:1630
+#: fortran/decl.c:1639
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression at %L is being truncated (%ld/%ld)"
 msgstr ""
 
-#: fortran/decl.c:1638
+#: fortran/decl.c:1647
 #, gcc-internal-format, gfc-internal-format
 msgid "The CHARACTER elements of the array constructor at %L must have the same length (%ld/%ld)"
 msgstr ""
 
-#: fortran/decl.c:1729
+#: fortran/decl.c:1738
 #, gcc-internal-format
 msgid "Initializer not allowed for PARAMETER %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:1739
+#: fortran/decl.c:1748
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER at %L is missing an initializer"
 msgstr ""
 
-#: fortran/decl.c:1749
+#: fortran/decl.c:1758
 #, gcc-internal-format
 msgid "Variable %qs at %C with an initializer already appears in a DATA statement"
 msgstr ""
 
-#: fortran/decl.c:1792
+#: fortran/decl.c:1801
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot initialize parameter array at %L with variable length elements"
 msgstr ""
 
-#: fortran/decl.c:1861
+#: fortran/decl.c:1870
 #, gcc-internal-format, gfc-internal-format
 msgid "Can't initialize implied-shape array at %L with scalar"
 msgstr ""
 
-#: fortran/decl.c:1896
+#: fortran/decl.c:1905
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-constant lower bound in implied-shape declaration at %L"
 msgstr ""
 
-#: fortran/decl.c:1982 fortran/decl.c:1989
+#: fortran/decl.c:1991 fortran/decl.c:1998
 #, gcc-internal-format, gfc-internal-format
 msgid "Component at %C must have the POINTER attribute"
 msgstr ""
 
-#: fortran/decl.c:1998
+#: fortran/decl.c:2007
 #, gcc-internal-format
 msgid "Component %qs with CLASS at %C must be allocatable or pointer"
 msgstr ""
 
-#: fortran/decl.c:2007
+#: fortran/decl.c:2016
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr ""
 
-#: fortran/decl.c:2031 fortran/symbol.c:2230
+#: fortran/decl.c:2040 fortran/symbol.c:2244
 #, gcc-internal-format
 msgid "Component %qs at %C already declared at %L"
 msgstr ""
 
-#: fortran/decl.c:2079
+#: fortran/decl.c:2088
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer array component of structure at %C must have a deferred shape"
 msgstr ""
 
-#: fortran/decl.c:2088
+#: fortran/decl.c:2097
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component of structure at %C must have a deferred shape"
 msgstr ""
 
-#: fortran/decl.c:2097
+#: fortran/decl.c:2106
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have an explicit shape"
 msgstr ""
 
-#: fortran/decl.c:2114
+#: fortran/decl.c:2123
 #, gcc-internal-format
 msgid "Type parameter %qs at %C has no corresponding entry in the type parameter name list at %L"
 msgstr ""
 
-#: fortran/decl.c:2171
+#: fortran/decl.c:2180
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C is ambiguous"
 msgstr ""
 
-#: fortran/decl.c:2188
+#: fortran/decl.c:2197
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C may not have MOLD"
 msgstr ""
 
-#: fortran/decl.c:2205
+#: fortran/decl.c:2214
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of pointer at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:2226
+#: fortran/decl.c:2235
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in pointer initialization at %C"
 msgstr ""
 
-#: fortran/decl.c:2233
+#: fortran/decl.c:2242
 #, gcc-internal-format, gfc-internal-format
 msgid "non-NULL pointer initialization at %C"
 msgstr ""
 
-#: fortran/decl.c:2256
+#: fortran/decl.c:2265
 #, gcc-internal-format
 msgid "RESULT variable %qs at %L prohibits FUNCTION name %qs at %C from appearing in a specification statement"
 msgstr ""
 
-#: fortran/decl.c:2318
+#: fortran/decl.c:2327
 #, gcc-internal-format
 msgid "%qs not allowed outside STRUCTURE at %C"
 msgstr ""
 
-#: fortran/decl.c:2320
+#: fortran/decl.c:2329
 #, gcc-internal-format
 msgid "%qs at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr ""
 
-#: fortran/decl.c:2327
+#: fortran/decl.c:2336
 #, gcc-internal-format
 msgid "%qs entity cannot have attributes at %C"
 msgstr ""
 
-#: fortran/decl.c:2367
+#: fortran/decl.c:2376
 #, gcc-internal-format
 msgid "Non-PARAMETER symbol %qs at %L can't be implied-shape"
 msgstr ""
 
-#: fortran/decl.c:2377
+#: fortran/decl.c:2386
 #, gcc-internal-format, gfc-internal-format
 msgid "Implied-shape array at %L"
 msgstr ""
 
-#: fortran/decl.c:2422
+#: fortran/decl.c:2431
 #, gcc-internal-format, gfc-internal-format
 msgid "Explicit shaped array with nonconstant bounds at %C"
 msgstr ""
 
-#: fortran/decl.c:2501
+#: fortran/decl.c:2510
 #, gcc-internal-format
 msgid "%qs at %C is a redefinition of the declaration in the corresponding interface for MODULE PROCEDURE %qs"
 msgstr ""
 
-#: fortran/decl.c:2512
+#: fortran/decl.c:2521
 #, gcc-internal-format
 msgid "%qs entity cannot have an initializer at %C"
 msgstr ""
 
-#: fortran/decl.c:2538 fortran/decl.c:8369
+#: fortran/decl.c:2547 fortran/decl.c:8388
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr ""
 
-#: fortran/decl.c:2546
+#: fortran/decl.c:2555
 #, gcc-internal-format
 msgid "Couldn't set pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:2609
+#: fortran/decl.c:2618
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style initialization at %C"
 msgstr ""
 
-#: fortran/decl.c:2617
+#: fortran/decl.c:2626
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr ""
 
-#: fortran/decl.c:2630
+#: fortran/decl.c:2639
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in old style initialization of %s at %C"
 msgstr ""
 
-#: fortran/decl.c:2650 fortran/decl.c:6661
+#: fortran/decl.c:2659 fortran/decl.c:6680
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr ""
 
-#: fortran/decl.c:2663
+#: fortran/decl.c:2672
 #, gcc-internal-format
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr ""
 
-#: fortran/decl.c:2672 fortran/decl.c:10240
+#: fortran/decl.c:2681 fortran/decl.c:10265
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr ""
 
-#: fortran/decl.c:2679
+#: fortran/decl.c:2688
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:2696
+#: fortran/decl.c:2705
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr ""
 
-#: fortran/decl.c:2710
+#: fortran/decl.c:2719
 #, gcc-internal-format, gfc-internal-format
 msgid "The component with KIND or LEN attribute at %C does not not appear in the type parameter list at %L"
 msgstr ""
 
-#: fortran/decl.c:2718
+#: fortran/decl.c:2727
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C that appears in the type parameter list at %L has neither the KIND nor LEN attribute"
 msgstr ""
 
-#: fortran/decl.c:2726
+#: fortran/decl.c:2735
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C which is a type parameter must be a scalar"
 msgstr ""
 
-#: fortran/decl.c:2789 fortran/decl.c:2825
+#: fortran/decl.c:2798 fortran/decl.c:2834
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr ""
 
-#: fortran/decl.c:2831
+#: fortran/decl.c:2840
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr ""
 
-#: fortran/decl.c:2890 fortran/decl.c:2967
+#: fortran/decl.c:2899 fortran/decl.c:2976
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis at %C"
 msgstr ""
 
-#: fortran/decl.c:2903 fortran/decl.c:3038
+#: fortran/decl.c:2912 fortran/decl.c:3047
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr ""
 
-#: fortran/decl.c:2911 fortran/decl.c:3044
+#: fortran/decl.c:2920 fortran/decl.c:3053
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr ""
 
-#: fortran/decl.c:2941 fortran/decl.c:3657
+#: fortran/decl.c:2950 fortran/decl.c:3676
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr ""
 
-#: fortran/decl.c:2954
+#: fortran/decl.c:2963
 #, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr ""
 
-#: fortran/decl.c:2965
+#: fortran/decl.c:2974
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr ""
 
-#: fortran/decl.c:3070
+#: fortran/decl.c:3079
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr ""
 
-#: fortran/decl.c:3202
+#: fortran/decl.c:3211
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:3291
+#: fortran/decl.c:3310
 #, gcc-internal-format, gfc-internal-format
 msgid "RECORD at %C is an extension, enable it with -fdec-structure"
 msgstr ""
 
-#: fortran/decl.c:3304
+#: fortran/decl.c:3323
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected after RECORD at %C"
 msgstr ""
 
-#: fortran/decl.c:3417
+#: fortran/decl.c:3436
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C cannot contain both ASSUMED and DEFERRED parameters"
 msgstr ""
 
-#: fortran/decl.c:3441
+#: fortran/decl.c:3460
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C does not contain enough parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3465
+#: fortran/decl.c:3484
 #, gcc-internal-format
 msgid "The derived parameter %qs at %C does not have a default value"
 msgstr ""
 
-#: fortran/decl.c:3497
+#: fortran/decl.c:3516
 #, gcc-internal-format, gfc-internal-format
 msgid "The parameter expression at %C must be of INTEGER type and not %s type"
 msgstr ""
 
-#: fortran/decl.c:3525
+#: fortran/decl.c:3544
 #, gcc-internal-format
 msgid "The KIND parameter %qs at %C cannot either be ASSUMED or DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:3532
+#: fortran/decl.c:3551
 #, gcc-internal-format
 msgid "The value for the KIND parameter %qs at %C does not reduce to a constant expression"
 msgstr ""
 
-#: fortran/decl.c:3547
+#: fortran/decl.c:3566
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C contains too many parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3556
+#: fortran/decl.c:3575
 #, gcc-internal-format, gfc-internal-format
 msgid "Parameterized derived type at %C is ambiguous"
 msgstr ""
 
-#: fortran/decl.c:3819
+#: fortran/decl.c:3838
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type at %C"
 msgstr ""
 
-#: fortran/decl.c:3824
+#: fortran/decl.c:3843
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr ""
 
-#: fortran/decl.c:3846
+#: fortran/decl.c:3865
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C is not allowed for components"
 msgstr ""
 
-#: fortran/decl.c:3849
+#: fortran/decl.c:3868
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr ""
 
-#: fortran/decl.c:3872 fortran/decl.c:3903 fortran/decl.c:3932
-#: fortran/decl.c:4216
+#: fortran/decl.c:3891 fortran/decl.c:3922 fortran/decl.c:3951
+#: fortran/decl.c:4235
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr ""
 
-#: fortran/decl.c:3928
+#: fortran/decl.c:3947
 #, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr ""
 
-#: fortran/decl.c:3971 fortran/decl.c:4107 fortran/decl.c:4119
-#: fortran/decl.c:4133 fortran/decl.c:4611 fortran/decl.c:4619
+#: fortran/decl.c:3990 fortran/decl.c:4126 fortran/decl.c:4138
+#: fortran/decl.c:4152 fortran/decl.c:4630 fortran/decl.c:4638
 #, gcc-internal-format
 msgid "Type name %qs at %C is ambiguous"
 msgstr ""
 
-#: fortran/decl.c:4066
+#: fortran/decl.c:4085
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4148
+#: fortran/decl.c:4167
 #, gcc-internal-format
 msgid "Type name %qs at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr ""
 
-#: fortran/decl.c:4287
+#: fortran/decl.c:4306
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4296
+#: fortran/decl.c:4315
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr ""
 
-#: fortran/decl.c:4355
+#: fortran/decl.c:4374
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr ""
 
-#: fortran/decl.c:4401
+#: fortran/decl.c:4420
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4454
+#: fortran/decl.c:4473
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr ""
 
-#: fortran/decl.c:4464
+#: fortran/decl.c:4483
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4570
+#: fortran/decl.c:4589
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr ""
 
-#: fortran/decl.c:4577
+#: fortran/decl.c:4596
 #, gcc-internal-format, gfc-internal-format
 msgid "F2008: C1210 IMPORT statement at %C is not permitted in a module procedure interface body"
 msgstr ""
 
-#: fortran/decl.c:4582
+#: fortran/decl.c:4601
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4596
+#: fortran/decl.c:4615
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr ""
 
-#: fortran/decl.c:4625
+#: fortran/decl.c:4644
 #, gcc-internal-format
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr ""
 
-#: fortran/decl.c:4632
+#: fortran/decl.c:4651
 #, gcc-internal-format
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr ""
 
-#: fortran/decl.c:4673
+#: fortran/decl.c:4692
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IMPORT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5010
+#: fortran/decl.c:5029
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing codimension specification at %C"
 msgstr ""
 
-#: fortran/decl.c:5012
+#: fortran/decl.c:5031
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr ""
 
-#: fortran/decl.c:5107
+#: fortran/decl.c:5126
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr ""
 
-#: fortran/decl.c:5124
+#: fortran/decl.c:5143
 #, gcc-internal-format
 msgid "%s at %L is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:5141
+#: fortran/decl.c:5160
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5150
+#: fortran/decl.c:5169
 #, gcc-internal-format, gfc-internal-format
 msgid "KIND attribute at %C in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5158
+#: fortran/decl.c:5177
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be INTEGER"
 msgstr ""
 
-#: fortran/decl.c:5165
+#: fortran/decl.c:5184
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5174
+#: fortran/decl.c:5193
 #, gcc-internal-format, gfc-internal-format
 msgid "LEN attribute at %C in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5182
+#: fortran/decl.c:5201
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be INTEGER"
 msgstr ""
 
-#: fortran/decl.c:5189
+#: fortran/decl.c:5208
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5198
+#: fortran/decl.c:5217
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5216
+#: fortran/decl.c:5235
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5226
+#: fortran/decl.c:5245
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:5236
+#: fortran/decl.c:5255
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed outside a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5249
+#: fortran/decl.c:5268
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5260
+#: fortran/decl.c:5279
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5315 fortran/decl.c:8673
+#: fortran/decl.c:5334 fortran/decl.c:8692
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:5321
+#: fortran/decl.c:5340
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5355
+#: fortran/decl.c:5374
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5362
+#: fortran/decl.c:5381
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5369
+#: fortran/decl.c:5388
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr ""
 
-#: fortran/decl.c:5410
+#: fortran/decl.c:5429
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:5508
+#: fortran/decl.c:5527
 #, gcc-internal-format
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:5530
+#: fortran/decl.c:5549
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5539
+#: fortran/decl.c:5558
 #, gcc-internal-format
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5543
+#: fortran/decl.c:5562
 #, gcc-internal-format
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5555
+#: fortran/decl.c:5574
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr ""
 
-#: fortran/decl.c:5569
+#: fortran/decl.c:5588
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr ""
 
-#: fortran/decl.c:5577
+#: fortran/decl.c:5596
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr ""
 
-#: fortran/decl.c:5589
+#: fortran/decl.c:5608
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr ""
 
-#: fortran/decl.c:5597
+#: fortran/decl.c:5616
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be a character string"
 msgstr ""
@@ -51961,956 +52029,961 @@
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:5608
+#: fortran/decl.c:5627
 #, gcc-internal-format
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr ""
 
-#: fortran/decl.c:5682
+#: fortran/decl.c:5701
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5727
+#: fortran/decl.c:5746
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5734
+#: fortran/decl.c:5753
 #, gcc-internal-format
 msgid "Missing symbol"
 msgstr ""
 
-#: fortran/decl.c:5763
+#: fortran/decl.c:5782
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5850
+#: fortran/decl.c:5869
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr ""
 
-#: fortran/decl.c:5892
+#: fortran/decl.c:5911
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in anonymous structure declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:5901
+#: fortran/decl.c:5920
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:5951
+#: fortran/decl.c:5970
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C"
 msgstr ""
 
-#: fortran/decl.c:5996
+#: fortran/decl.c:6015
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPURE procedure at %C"
 msgstr ""
 
-#: fortran/decl.c:6008
+#: fortran/decl.c:6027
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr ""
 
-#: fortran/decl.c:6054
+#: fortran/decl.c:6073
 #, gcc-internal-format, gfc-internal-format
 msgid "ELEMENTAL prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6061
+#: fortran/decl.c:6080
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6068
+#: fortran/decl.c:6087
 #, gcc-internal-format, gfc-internal-format
 msgid "RECURSIVE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6134 fortran/primary.c:1820
+#: fortran/decl.c:6153 fortran/primary.c:1820
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate-return argument at %C"
 msgstr ""
 
-#: fortran/decl.c:6140 fortran/decl.c:6148
+#: fortran/decl.c:6159 fortran/decl.c:6167
 #, gcc-internal-format, gfc-internal-format
 msgid "A parameter name is required at %C"
 msgstr ""
 
-#: fortran/decl.c:6188
+#: fortran/decl.c:6207
 #, gcc-internal-format
 msgid "Name %qs at %C is the name of the procedure"
 msgstr ""
 
-#: fortran/decl.c:6201
+#: fortran/decl.c:6220
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected parameter list in type declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:6204
+#: fortran/decl.c:6223
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr ""
 
-#: fortran/decl.c:6222
+#: fortran/decl.c:6241
 #, gcc-internal-format
 msgid "Duplicate name %qs in parameter list at %C"
 msgstr ""
 
-#: fortran/decl.c:6225
+#: fortran/decl.c:6244
 #, gcc-internal-format
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr ""
 
-#: fortran/decl.c:6264
+#: fortran/decl.c:6283
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in MODULE PROCEDURE formal argument names (%s/%s) at %C"
 msgstr ""
 
-#: fortran/decl.c:6270
+#: fortran/decl.c:6289
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in number of MODULE PROCEDURE formal arguments at %C"
 msgstr ""
 
-#: fortran/decl.c:6309
+#: fortran/decl.c:6328
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr ""
 
-#: fortran/decl.c:6386
+#: fortran/decl.c:6405
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:6396 fortran/decl.c:7494
+#: fortran/decl.c:6415 fortran/decl.c:7513
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr ""
 
-#: fortran/decl.c:6600
+#: fortran/decl.c:6619
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:6607
+#: fortran/decl.c:6626
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:6613
+#: fortran/decl.c:6632
 #, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr ""
 
-#: fortran/decl.c:6636
+#: fortran/decl.c:6655
 #, gcc-internal-format
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr ""
 
-#: fortran/decl.c:6682 fortran/decl.c:6870 fortran/decl.c:10723
+#: fortran/decl.c:6701 fortran/decl.c:6889 fortran/decl.c:10748
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6731 fortran/decl.c:10623
+#: fortran/decl.c:6750 fortran/decl.c:10648
 #, gcc-internal-format
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr ""
 
-#: fortran/decl.c:6738
+#: fortran/decl.c:6757
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr ""
 
-#: fortran/decl.c:6742
+#: fortran/decl.c:6761
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:6814
+#: fortran/decl.c:6833
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:6832
+#: fortran/decl.c:6851
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr ""
 
-#: fortran/decl.c:6841 fortran/decl.c:9392
+#: fortran/decl.c:6860 fortran/decl.c:9411
 #, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr ""
 
-#: fortran/decl.c:6911
+#: fortran/decl.c:6930
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6983
+#: fortran/decl.c:7002
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr ""
 
-#: fortran/decl.c:7007 fortran/decl.c:7011 fortran/decl.c:7266
-#: fortran/decl.c:7270 fortran/decl.c:7462 fortran/decl.c:7466
-#: fortran/symbol.c:1875
+#: fortran/decl.c:7026 fortran/decl.c:7030 fortran/decl.c:7285
+#: fortran/decl.c:7289 fortran/decl.c:7481 fortran/decl.c:7485
+#: fortran/symbol.c:1889
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr ""
 
-#: fortran/decl.c:7164
+#: fortran/decl.c:7183
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7173
+#: fortran/decl.c:7192
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr ""
 
-#: fortran/decl.c:7176
+#: fortran/decl.c:7195
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr ""
 
-#: fortran/decl.c:7179
+#: fortran/decl.c:7198
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SUBMODULE"
 msgstr ""
 
-#: fortran/decl.c:7182
+#: fortran/decl.c:7201
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr ""
 
-#: fortran/decl.c:7186 fortran/decl.c:7231
+#: fortran/decl.c:7205 fortran/decl.c:7250
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr ""
 
-#: fortran/decl.c:7190
+#: fortran/decl.c:7209
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a STRUCTURE block"
 msgstr ""
 
-#: fortran/decl.c:7194
+#: fortran/decl.c:7213
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr ""
 
-#: fortran/decl.c:7198
+#: fortran/decl.c:7217
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr ""
 
-#: fortran/decl.c:7203
+#: fortran/decl.c:7222
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr ""
 
-#: fortran/decl.c:7207
+#: fortran/decl.c:7226
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr ""
 
-#: fortran/decl.c:7211
+#: fortran/decl.c:7230
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr ""
 
-#: fortran/decl.c:7215
+#: fortran/decl.c:7234
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr ""
 
-#: fortran/decl.c:7219
+#: fortran/decl.c:7238
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr ""
 
-#: fortran/decl.c:7223
+#: fortran/decl.c:7242
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected ENTRY statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7244
+#: fortran/decl.c:7263
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr ""
 
-#: fortran/decl.c:7295 fortran/decl.c:7501
+#: fortran/decl.c:7314 fortran/decl.c:7520
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7563 fortran/decl.c:7570
+#: fortran/decl.c:7582 fortran/decl.c:7589
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:7610
+#: fortran/decl.c:7629
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr ""
 
-#: fortran/decl.c:7626
+#: fortran/decl.c:7645
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr ""
 
-#: fortran/decl.c:7634
+#: fortran/decl.c:7653
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr ""
 
-#: fortran/decl.c:7653
+#: fortran/decl.c:7672
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing closing paren for binding label at %C"
 msgstr ""
 
-#: fortran/decl.c:7659
+#: fortran/decl.c:7678
 #, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7665
+#: fortran/decl.c:7684
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7694
+#: fortran/decl.c:7713
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr ""
 
-#: fortran/decl.c:7939
+#: fortran/decl.c:7958
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7948
+#: fortran/decl.c:7967
 #, gcc-internal-format, gfc-internal-format
 msgid "END statement instead of %s statement at %L"
 msgstr ""
 
 #. We would have required END [something].
-#: fortran/decl.c:7957
+#: fortran/decl.c:7976
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr ""
 
-#: fortran/decl.c:7968
+#: fortran/decl.c:7987
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s statement at %L"
 msgstr ""
 
-#: fortran/decl.c:7988
+#: fortran/decl.c:8007
 #, gcc-internal-format
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr ""
 
-#: fortran/decl.c:8005
+#: fortran/decl.c:8024
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr ""
 
-#: fortran/decl.c:8019 fortran/decl.c:8027
+#: fortran/decl.c:8038 fortran/decl.c:8046
 #, gcc-internal-format
 msgid "Expected label %qs for %s statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8126
+#: fortran/decl.c:8145
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr ""
 
-#: fortran/decl.c:8134
+#: fortran/decl.c:8153
 #, gcc-internal-format, gfc-internal-format
 msgid "Dimensions specified for %s at %L after its initialization"
 msgstr ""
 
-#: fortran/decl.c:8142
+#: fortran/decl.c:8161
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr ""
 
-#: fortran/decl.c:8151
+#: fortran/decl.c:8170
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr ""
 
-#: fortran/decl.c:8249
+#: fortran/decl.c:8268
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr ""
 
-#: fortran/decl.c:8286
+#: fortran/decl.c:8305
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<(%>"
 msgid "Expected %<(%> at %C"
 msgstr "očekujem %<(%>"
 
-#: fortran/decl.c:8300 fortran/decl.c:8340
+#: fortran/decl.c:8319 fortran/decl.c:8359
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr ""
 
-#: fortran/decl.c:8316
+#: fortran/decl.c:8335
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C must be an integer"
 msgstr ""
 
-#: fortran/decl.c:8320
+#: fortran/decl.c:8339
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr ""
 
-#: fortran/decl.c:8326
+#: fortran/decl.c:8345
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr ""
 
-#: fortran/decl.c:8365
+#: fortran/decl.c:8384
 #, gcc-internal-format
 msgid "Couldn't set Cray pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:8389
+#: fortran/decl.c:8408
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr ""
 
-#: fortran/decl.c:8401
+#: fortran/decl.c:8420
 #, gcc-internal-format
 msgid "Expected %<,%> or end of statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8427
+#: fortran/decl.c:8446
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:8459
+#: fortran/decl.c:8478
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:8478
+#: fortran/decl.c:8497
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer declaration at %C requires -fcray-pointer flag"
 msgstr ""
 
-#: fortran/decl.c:8517
+#: fortran/decl.c:8536
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8623
+#: fortran/decl.c:8642
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:8640
+#: fortran/decl.c:8659
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:8679
+#: fortran/decl.c:8698
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8717
+#: fortran/decl.c:8736
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8741
+#: fortran/decl.c:8760
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:8778
+#: fortran/decl.c:8797
 #, gcc-internal-format, gfc-internal-format
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:8806
+#: fortran/decl.c:8825
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr ""
 
-#: fortran/decl.c:8813
+#: fortran/decl.c:8832
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8819
+#: fortran/decl.c:8838
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr ""
 
-#: fortran/decl.c:8839
+#: fortran/decl.c:8858
 #, gcc-internal-format, gfc-internal-format
 msgid "Initializing already initialized variable at %C"
 msgstr ""
 
 #. With legacy PARAMETER statements, don't expect a terminating ')'.
-#: fortran/decl.c:8864
+#: fortran/decl.c:8883
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER without '()' at %C"
 msgstr ""
 
-#: fortran/decl.c:8880
+#: fortran/decl.c:8899
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8899 fortran/decl.c:8955
+#: fortran/decl.c:8918 fortran/decl.c:8974
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:8934
+#: fortran/decl.c:8953
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in AUTOMATIC statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8941
+#: fortran/decl.c:8960
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in AUTOMATIC statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8990
+#: fortran/decl.c:9009
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in STATIC statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8997
+#: fortran/decl.c:9016
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in STATIC statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9016
+#: fortran/decl.c:9035
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:9027
+#: fortran/decl.c:9046
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:9073
+#: fortran/decl.c:9092
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9087
+#: fortran/decl.c:9106
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:9091
+#: fortran/decl.c:9110
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9129
+#: fortran/decl.c:9148
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VALUE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9141
+#: fortran/decl.c:9160
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9168
+#: fortran/decl.c:9187
 #, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr ""
 
-#: fortran/decl.c:9193
+#: fortran/decl.c:9212
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9205
+#: fortran/decl.c:9224
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9249
+#: fortran/decl.c:9268
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9274
+#: fortran/decl.c:9293
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:9367
+#: fortran/decl.c:9386
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr ""
 
-#: fortran/decl.c:9425
+#: fortran/decl.c:9444
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr ""
 
-#: fortran/decl.c:9474
+#: fortran/decl.c:9493
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr ""
 
-#: fortran/decl.c:9483
+#: fortran/decl.c:9502
 #, gcc-internal-format
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr ""
 
-#: fortran/decl.c:9489
+#: fortran/decl.c:9508
 #, gcc-internal-format
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr ""
 
-#: fortran/decl.c:9496
+#: fortran/decl.c:9515
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:9503
+#: fortran/decl.c:9522
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr ""
 
-#: fortran/decl.c:9526
+#: fortran/decl.c:9545
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:9538
+#: fortran/decl.c:9557
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:9559
+#: fortran/decl.c:9578
 #, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
 msgstr ""
 
-#: fortran/decl.c:9605
+#: fortran/decl.c:9624
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "failed to close state file %s [%s]"
 msgid "Failed to create structure type '%s' at %C"
 msgstr "nisam uspio zatvoriti datoteku stanja %s [%s]"
 
-#: fortran/decl.c:9611
+#: fortran/decl.c:9630
 #, gcc-internal-format
 msgid "Type definition of %qs at %C was already defined at %L"
 msgstr ""
 
-#: fortran/decl.c:9658
+#: fortran/decl.c:9677
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after MAP statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9691
+#: fortran/decl.c:9710
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after UNION statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9726
+#: fortran/decl.c:9745
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr ""
 
-#: fortran/decl.c:9740
+#: fortran/decl.c:9759
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected in non-nested structure declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:9758
+#: fortran/decl.c:9777
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after non-nested STRUCTURE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9765
+#: fortran/decl.c:9784
 #, gcc-internal-format
 msgid "Structure name %qs at %C cannot be the same as an intrinsic type"
 msgstr ""
 
-#: fortran/decl.c:9926
+#: fortran/decl.c:9947
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr ""
 
-#: fortran/decl.c:9954
+#: fortran/decl.c:9975
 #, gcc-internal-format
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr ""
 
-#: fortran/decl.c:9964
+#: fortran/decl.c:9986
 #, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr ""
 
-#: fortran/decl.c:9981
+#: fortran/decl.c:9989
 #, gcc-internal-format
+msgid "Derived type name %qs at %C already has a basic type"
+msgstr ""
+
+#: fortran/decl.c:10006
+#, gcc-internal-format
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr ""
 
-#: fortran/decl.c:10042
+#: fortran/decl.c:10067
 #, gcc-internal-format, gfc-internal-format
 msgid "Garbage after PARAMETERIZED TYPE declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:10126
+#: fortran/decl.c:10151
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr ""
 
-#: fortran/decl.c:10146
+#: fortran/decl.c:10171
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM and ENUMERATOR at %C"
 msgstr ""
 
-#: fortran/decl.c:10178
+#: fortran/decl.c:10203
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr ""
 
-#: fortran/decl.c:10257
+#: fortran/decl.c:10282
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr ""
 
-#: fortran/decl.c:10305
+#: fortran/decl.c:10330
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr ""
 
-#: fortran/decl.c:10341
+#: fortran/decl.c:10366
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr ""
 
-#: fortran/decl.c:10388 fortran/decl.c:10403
+#: fortran/decl.c:10413 fortran/decl.c:10428
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate access-specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:10423
+#: fortran/decl.c:10448
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10443
+#: fortran/decl.c:10468
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10470
+#: fortran/decl.c:10495
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:10488
+#: fortran/decl.c:10513
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr ""
 
-#: fortran/decl.c:10504
+#: fortran/decl.c:10529
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DEFERRED at %C"
 msgstr ""
 
-#: fortran/decl.c:10517
+#: fortran/decl.c:10542
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected access-specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:10519
+#: fortran/decl.c:10544
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:10527
+#: fortran/decl.c:10552
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED can't both appear at %C"
 msgstr ""
 
-#: fortran/decl.c:10539
+#: fortran/decl.c:10564
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:10581
+#: fortran/decl.c:10606
 #, gcc-internal-format
 msgid "Interface-name expected after %<(%> at %C"
 msgstr ""
 
-#: fortran/decl.c:10587
+#: fortran/decl.c:10612
 #, gcc-internal-format
 msgid "%<)%> expected at %C"
 msgstr ""
 
-#: fortran/decl.c:10607
+#: fortran/decl.c:10632
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:10612
+#: fortran/decl.c:10637
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:10635
+#: fortran/decl.c:10660
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr ""
 
-#: fortran/decl.c:10639
+#: fortran/decl.c:10664
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
 msgstr ""
 
-#: fortran/decl.c:10651
+#: fortran/decl.c:10676
 #, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:10657
+#: fortran/decl.c:10682
 #, gcc-internal-format
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr ""
 
-#: fortran/decl.c:10667
+#: fortran/decl.c:10692
 #, gcc-internal-format
 msgid "Expected binding target after %<=>%> at %C"
 msgstr ""
 
-#: fortran/decl.c:10684
+#: fortran/decl.c:10709
 #, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr ""
 
-#: fortran/decl.c:10695
+#: fortran/decl.c:10720
 #, gcc-internal-format
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:10746
+#: fortran/decl.c:10771
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr ""
 
-#: fortran/decl.c:10766
+#: fortran/decl.c:10791
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%>"
 msgid "Expected %<::%> at %C"
 msgstr "očekujem %<:%>"
 
-#: fortran/decl.c:10778
+#: fortran/decl.c:10803
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected generic name or operator descriptor at %C"
 msgstr ""
 
-#: fortran/decl.c:10799
+#: fortran/decl.c:10824
 #, gcc-internal-format, gfc-internal-format
 msgid "Malformed GENERIC statement at %C"
 msgstr ""
 
-#: fortran/decl.c:10810
+#: fortran/decl.c:10835
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<=%>"
 msgid "Expected %<=>%> at %C"
 msgstr "očekujem %<=%>"
 
-#: fortran/decl.c:10846
+#: fortran/decl.c:10871
 #, gcc-internal-format
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:10854
+#: fortran/decl.c:10879
 #, gcc-internal-format
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr ""
 
-#: fortran/decl.c:10902
+#: fortran/decl.c:10927
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr ""
 
-#: fortran/decl.c:10912
+#: fortran/decl.c:10937
 #, gcc-internal-format
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:10930
+#: fortran/decl.c:10955
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr ""
 
-#: fortran/decl.c:10965
+#: fortran/decl.c:10990
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr ""
 
-#: fortran/decl.c:10976
+#: fortran/decl.c:11001
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr ""
 
-#: fortran/decl.c:10998
+#: fortran/decl.c:11023
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr ""
 
-#: fortran/decl.c:11005
+#: fortran/decl.c:11030
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr ""
 
-#: fortran/decl.c:11015
+#: fortran/decl.c:11040
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>"
 msgid "Expected %<,%> at %C"
 msgstr "očekujem %<,%>"
 
-#: fortran/decl.c:11021
+#: fortran/decl.c:11046
 #, gcc-internal-format
 msgid "Unknown procedure name %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:11034
+#: fortran/decl.c:11059
 #, gcc-internal-format
 msgid "%qs at %C is already defined as FINAL procedure"
 msgstr ""
 
-#: fortran/decl.c:11104
+#: fortran/decl.c:11129
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr ""
 
-#: fortran/decl.c:11150
+#: fortran/decl.c:11175
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr ""
 
-#: fortran/decl.c:11170
+#: fortran/decl.c:11195
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive requires a non-negative integral constant less than or equal to %u at %C"
 msgstr ""
 
-#: fortran/decl.c:11184
+#: fortran/decl.c:11209
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ UNROLL directive at %C"
 msgstr ""
@@ -53245,27 +53318,27 @@
 msgid "BOZ literal at %L used to initialize non-integer variable %qs"
 msgstr ""
 
-#: fortran/expr.c:3369 fortran/resolve.c:10197
+#: fortran/expr.c:3369 fortran/resolve.c:10210
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal at %L outside a DATA statement and outside INT/REAL/DBLE/CMPLX"
 msgstr ""
 
-#: fortran/expr.c:3380 fortran/resolve.c:10208
+#: fortran/expr.c:3380 fortran/resolve.c:10221
 #, gcc-internal-format
 msgid "BOZ literal at %L is bitwise transferred non-integer symbol %qs"
 msgstr ""
 
-#: fortran/expr.c:3388 fortran/resolve.c:10217
+#: fortran/expr.c:3388 fortran/resolve.c:10230
 #, gcc-internal-format
 msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3392 fortran/resolve.c:10221
+#: fortran/expr.c:3392 fortran/resolve.c:10234
 #, gcc-internal-format
 msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3396 fortran/resolve.c:10225
+#: fortran/expr.c:3396 fortran/resolve.c:10238
 #, gcc-internal-format
 msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
@@ -53275,147 +53348,147 @@
 msgid "The assignment to a KIND or LEN component of a parameterized type at %L is not allowed"
 msgstr ""
 
-#: fortran/expr.c:3426
+#: fortran/expr.c:3429
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible types in DATA statement at %L; attempted conversion of %s to %s"
 msgstr ""
 
-#: fortran/expr.c:3465
+#: fortran/expr.c:3468
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is not a POINTER at %L"
 msgstr ""
 
-#: fortran/expr.c:3473
+#: fortran/expr.c:3476
 #, gcc-internal-format
 msgid "%qs in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgstr ""
 
-#: fortran/expr.c:3496
+#: fortran/expr.c:3499
 #, gcc-internal-format
 msgid "Expected bounds specification for %qs at %L"
 msgstr ""
 
-#: fortran/expr.c:3501
+#: fortran/expr.c:3504
 #, gcc-internal-format
 msgid "Bounds specification for %qs in pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3514
+#: fortran/expr.c:3517
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower bound has to be present at %L"
 msgstr ""
 
-#: fortran/expr.c:3520
+#: fortran/expr.c:3523
 #, gcc-internal-format, gfc-internal-format
 msgid "Stride must not be present at %L"
 msgstr ""
 
-#: fortran/expr.c:3532
+#: fortran/expr.c:3535
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the upper bounds must be specified at %L"
 msgstr ""
 
-#: fortran/expr.c:3558
+#: fortran/expr.c:3561
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %L shall not have a coindex"
 msgstr ""
 
-#: fortran/expr.c:3579
+#: fortran/expr.c:3582
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3603
+#: fortran/expr.c:3606
 #, gcc-internal-format
 msgid "Function result %qs is invalid as proc-target in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3612
+#: fortran/expr.c:3615
 #, gcc-internal-format
 msgid "Abstract interface %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3622
+#: fortran/expr.c:3625
 #, gcc-internal-format
 msgid "Statement function %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3628
+#: fortran/expr.c:3631
 #, gcc-internal-format
 msgid "Internal procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3635
+#: fortran/expr.c:3638
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L is invalid in procedure pointer assignment"
 msgstr ""
 
-#: fortran/expr.c:3643
+#: fortran/expr.c:3646
 #, gcc-internal-format
 msgid "Nonintrinsic elemental procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3666
+#: fortran/expr.c:3669
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in the procedure pointer assignment at %L: mismatch in the calling convention"
 msgstr ""
 
-#: fortran/expr.c:3719
+#: fortran/expr.c:3722
 #, gcc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %qs is not a subroutine"
 msgstr ""
 
-#: fortran/expr.c:3729 fortran/expr.c:3744
+#: fortran/expr.c:3732 fortran/expr.c:3747
 #, gcc-internal-format
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr ""
 
-#: fortran/expr.c:3735 fortran/expr.c:3750 fortran/resolve.c:2566
+#: fortran/expr.c:3738 fortran/expr.c:3753 fortran/resolve.c:2566
 #, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr ""
 
-#: fortran/expr.c:3762
+#: fortran/expr.c:3765
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %s"
 msgstr ""
 
-#: fortran/expr.c:3771
+#: fortran/expr.c:3774
 #, gcc-internal-format
 msgid "Procedure pointer target %qs at %L must be either an intrinsic, host or use associated, referenced or have the EXTERNAL attribute"
 msgstr ""
 
-#: fortran/expr.c:3788
+#: fortran/expr.c:3791
 #, gcc-internal-format, gfc-internal-format
 msgid "Data-pointer-object at %L must be unlimited polymorphic, or of a type with the BIND or SEQUENCE attribute, to be compatible with an unlimited polymorphic target"
 msgstr ""
 
-#: fortran/expr.c:3793
+#: fortran/expr.c:3796
 #, gcc-internal-format, gfc-internal-format
 msgid "Different types in pointer assignment at %L; attempted assignment of %s to %s"
 msgstr ""
 
-#: fortran/expr.c:3802
+#: fortran/expr.c:3805
 #, gcc-internal-format, gfc-internal-format
 msgid "Different kind type parameters in pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3809
+#: fortran/expr.c:3812
 #, gcc-internal-format, gfc-internal-format
 msgid "Different ranks in pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3828
+#: fortran/expr.c:3831
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is smaller than size of the pointer (%ld < %ld) at %L"
 msgstr ""
 
-#: fortran/expr.c:3841
+#: fortran/expr.c:3844
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target must be rank 1 or simply contiguous at %L"
 msgstr ""
 
-#: fortran/expr.c:3845
+#: fortran/expr.c:3848
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is not rank 1 at %L"
 msgstr ""
@@ -53423,147 +53496,152 @@
 #. The test above might need to be extend when F08, Note 5.4 has to be
 #. interpreted in the way that target and pointer with the same coindex
 #. are allowed.
-#: fortran/expr.c:3877 fortran/expr.c:3925
+#: fortran/expr.c:3880 fortran/expr.c:3928
 #, gcc-internal-format, gfc-internal-format
 msgid "Data target at %L shall not have a coindex"
 msgstr ""
 
-#: fortran/expr.c:3880
+#: fortran/expr.c:3883
 #, gcc-internal-format, gfc-internal-format
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr ""
 
-#: fortran/expr.c:3888
+#: fortran/expr.c:3891
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr ""
 
-#: fortran/expr.c:3895
+#: fortran/expr.c:3898
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr ""
 
-#: fortran/expr.c:3904
+#: fortran/expr.c:3907
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr ""
 
-#: fortran/expr.c:3912
+#: fortran/expr.c:3915
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/expr.c:3936
+#: fortran/expr.c:3939
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to contiguous pointer from non-contiguous target at %L"
 msgstr ""
 
-#: fortran/expr.c:3975
+#: fortran/expr.c:3978
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr ""
 
-#: fortran/expr.c:4051 fortran/resolve.c:1452
+#: fortran/expr.c:4054 fortran/resolve.c:1452
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/expr.c:4057
+#: fortran/expr.c:4060
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr ""
 
-#: fortran/expr.c:4072 fortran/resolve.c:1458
+#: fortran/expr.c:4075 fortran/resolve.c:1458
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr ""
 
-#: fortran/expr.c:4084
+#: fortran/expr.c:4087
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr ""
 
-#: fortran/expr.c:5512
+#: fortran/expr.c:4557
+#, gcc-internal-format
+msgid "generate_isocbinding_initializer(): bad iso_c_binding type, expected %<c_ptr%> or %<c_funptr%>"
+msgstr ""
+
+#: fortran/expr.c:5568
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5520
+#: fortran/expr.c:5576
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5528
+#: fortran/expr.c:5584
 #, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5537
+#: fortran/expr.c:5593
 #, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr ""
 
-#: fortran/expr.c:5548
+#: fortran/expr.c:5604
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5557
+#: fortran/expr.c:5613
 #, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5570
+#: fortran/expr.c:5626
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5583
+#: fortran/expr.c:5639
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5613
+#: fortran/expr.c:5669
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5621
+#: fortran/expr.c:5677
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5634
+#: fortran/expr.c:5690
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5642
+#: fortran/expr.c:5698
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5654
+#: fortran/expr.c:5710
 #, gcc-internal-format
 msgid "Variable %qs can not appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr ""
 
-#: fortran/expr.c:5713
+#: fortran/expr.c:5769
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:5717
+#: fortran/expr.c:5773
 #, gcc-internal-format
 msgid "%qs at %L associated to expression can not be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:5728
+#: fortran/expr.c:5784
 #, gcc-internal-format
 msgid "Associate-name %qs can not appear in a variable definition context (%s) at %L because its target at %L can not, either"
 msgstr ""
 
-#: fortran/expr.c:5770
+#: fortran/expr.c:5826
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr ""
@@ -53573,22 +53651,22 @@
 msgid "can't open input file: %s"
 msgstr ""
 
-#: fortran/frontend-passes.c:190
+#: fortran/frontend-passes.c:192
 #, gcc-internal-format
 msgid "No location in statement"
 msgstr ""
 
-#: fortran/frontend-passes.c:205
+#: fortran/frontend-passes.c:207
 #, gcc-internal-format, gfc-internal-format
 msgid "No location in expression near %L"
 msgstr ""
 
-#: fortran/frontend-passes.c:409
+#: fortran/frontend-passes.c:414
 #, gcc-internal-format
 msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
-#: fortran/frontend-passes.c:817 fortran/trans-array.c:1182
+#: fortran/frontend-passes.c:822 fortran/trans-array.c:1182
 #: fortran/trans-array.c:6440 fortran/trans-array.c:7864
 #: fortran/trans-intrinsic.c:7307
 #, gcc-internal-format, gfc-internal-format
@@ -53595,68 +53673,68 @@
 msgid "Creating array temporary at %L"
 msgstr ""
 
-#: fortran/frontend-passes.c:842 fortran/frontend-passes.c:846
+#: fortran/frontend-passes.c:847 fortran/frontend-passes.c:851
 #, gcc-internal-format
 msgid "Removing call to function %qs at %L"
 msgstr ""
 
-#: fortran/frontend-passes.c:1273 fortran/frontend-passes.c:1312
+#: fortran/frontend-passes.c:1278 fortran/frontend-passes.c:1317
 #, fuzzy, gcc-internal-format
 #| msgid "invalid expression as operand"
 msgid "bad expression"
 msgstr "neispravni izraz kao operand"
 
-#: fortran/frontend-passes.c:1308
+#: fortran/frontend-passes.c:1313
 #, gcc-internal-format
 msgid "bad op"
 msgstr ""
 
-#: fortran/frontend-passes.c:2161
+#: fortran/frontend-passes.c:2166
 #, gcc-internal-format
 msgid "illegal OP in optimize_comparison"
 msgstr ""
 
-#: fortran/frontend-passes.c:2407
+#: fortran/frontend-passes.c:2412
 #, gcc-internal-format
 msgid "Variable %qs at %L set to undefined value inside loop  beginning at %L as INTENT(OUT) argument to subroutine %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:2414
+#: fortran/frontend-passes.c:2419
 #, gcc-internal-format
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to subroutine %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:2637 fortran/frontend-passes.c:2661
+#: fortran/frontend-passes.c:2642 fortran/frontend-passes.c:2666
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L out of bounds (%ld < %ld) in loop beginning at %L"
 msgstr ""
 
-#: fortran/frontend-passes.c:2646 fortran/frontend-passes.c:2670
+#: fortran/frontend-passes.c:2651 fortran/frontend-passes.c:2675
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L out of bounds (%ld > %ld) in loop beginning at %L"
 msgstr ""
 
-#: fortran/frontend-passes.c:2730
+#: fortran/frontend-passes.c:2735
 #, gcc-internal-format
 msgid "Variable %qs at %L set to undefined value inside loop beginning at %L as INTENT(OUT) argument to function %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:2736
+#: fortran/frontend-passes.c:2741
 #, gcc-internal-format
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:3128 fortran/trans-expr.c:1581
+#: fortran/frontend-passes.c:3133 fortran/trans-expr.c:1581
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr ""
 
-#: fortran/frontend-passes.c:3637
+#: fortran/frontend-passes.c:3642
 #, gcc-internal-format
 msgid "Scalarization using DIMEN_RANGE unimplemented"
 msgstr ""
 
-#: fortran/frontend-passes.c:4429
+#: fortran/frontend-passes.c:4434
 #, gcc-internal-format, gfc-internal-format
 msgid "Interchanging loops at %L"
 msgstr ""
@@ -53776,12 +53854,12 @@
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:970 fortran/resolve.c:16351
+#: fortran/interface.c:970 fortran/resolve.c:16378
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:977 fortran/resolve.c:16369
+#: fortran/interface.c:977 fortran/resolve.c:16396
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
@@ -54971,7 +55049,7 @@
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.c:3369 fortran/resolve.c:14263
+#: fortran/io.c:3369 fortran/resolve.c:14283
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -55137,7 +55215,7 @@
 msgid "Integer too large at %C"
 msgstr ""
 
-#: fortran/match.c:580 fortran/parse.c:1132
+#: fortran/match.c:580 fortran/parse.c:1136
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many digits in statement label at %C"
 msgstr ""
@@ -55899,57 +55977,57 @@
 msgid "Expected block name %qs of SELECT construct at %C"
 msgstr ""
 
-#: fortran/match.c:6186
+#: fortran/match.c:6201
 #, gcc-internal-format, gfc-internal-format
 msgid "parse error in SELECT TYPE statement at %C"
 msgstr ""
 
-#: fortran/match.c:6211
+#: fortran/match.c:6226
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr ""
 
-#: fortran/match.c:6249
+#: fortran/match.c:6264
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr ""
 
-#: fortran/match.c:6301
+#: fortran/match.c:6316
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CASE specification at %C"
 msgstr ""
 
-#: fortran/match.c:6319
+#: fortran/match.c:6334
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected TYPE IS statement at %C"
 msgstr ""
 
-#: fortran/match.c:6351
+#: fortran/match.c:6366
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr ""
 
-#: fortran/match.c:6362
+#: fortran/match.c:6377
 #, gcc-internal-format, gfc-internal-format
 msgid "All the LEN type parameters in the TYPE IS statement at %C must be ASSUMED"
 msgstr ""
 
-#: fortran/match.c:6373
+#: fortran/match.c:6388
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr ""
 
-#: fortran/match.c:6449
+#: fortran/match.c:6464
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr ""
 
-#: fortran/match.c:6572
+#: fortran/match.c:6587
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr ""
 
-#: fortran/match.c:6610
+#: fortran/match.c:6625
 #, gcc-internal-format
 msgid "Label %qs at %C doesn't match WHERE label %qs"
 msgstr ""
@@ -56100,192 +56178,192 @@
 msgid "mio_array_ref(): Unknown array ref"
 msgstr ""
 
-#: fortran/module.c:3716
+#: fortran/module.c:3718
 #, gcc-internal-format, gfc-internal-format
 msgid "Namelist %s cannot be renamed by USE association to %s"
 msgstr ""
 
-#: fortran/module.c:4832
+#: fortran/module.c:4834
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4835
+#: fortran/module.c:4837
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:5029
+#: fortran/module.c:5031
 #, gcc-internal-format
 msgid "%qs of module %qs, imported at %C, is also the name of the current program unit"
 msgstr ""
 
-#: fortran/module.c:5381
+#: fortran/module.c:5383
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5388
+#: fortran/module.c:5390
 #, gcc-internal-format
 msgid "User operator %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5393
+#: fortran/module.c:5395
 #, gcc-internal-format
 msgid "Intrinsic operator %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5628
+#: fortran/module.c:5630
 #, gcc-internal-format
 msgid "write_symbol(): bad module symbol %qs"
 msgstr ""
 
-#: fortran/module.c:5961
+#: fortran/module.c:5963
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr ""
 
-#: fortran/module.c:6148
+#: fortran/module.c:6150
 #, fuzzy, gcc-internal-format
 #| msgid "Failed to open file %s for writing state: %s"
 msgid "Can't open module file %qs for writing at %C: %s"
 msgstr "Nisam uspio otvoriti datoteku %s za pisanje stanja: %s"
 
-#: fortran/module.c:6169
+#: fortran/module.c:6171
 #, fuzzy, gcc-internal-format
 #| msgid "Failed to open file %s for writing state: %s"
 msgid "Error writing module file %qs for writing: %s"
 msgstr "Nisam uspio otvoriti datoteku %s za pisanje stanja: %s"
 
-#: fortran/module.c:6180
+#: fortran/module.c:6182
 #, fuzzy, gcc-internal-format
 #| msgid "Cannot open source file %s\n"
 msgid "Can't delete module file %qs: %s"
 msgstr "Ne mogu otvoriti datoteku koda %s\n"
 
-#: fortran/module.c:6183
+#: fortran/module.c:6185
 #, gcc-internal-format
 msgid "Can't rename module file %qs to %qs: %s"
 msgstr ""
 
-#: fortran/module.c:6189
+#: fortran/module.c:6191
 #, gcc-internal-format
 msgid "Can't delete temporary module file %qs: %s"
 msgstr ""
 
-#: fortran/module.c:6246
+#: fortran/module.c:6248
 #, gcc-internal-format
 msgid "Symbol %qs at %C already declared"
 msgstr ""
 
-#: fortran/module.c:6317
+#: fortran/module.c:6319
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr ""
 
-#: fortran/module.c:6425 fortran/module.c:6769
+#: fortran/module.c:6427 fortran/module.c:6771
 #, gcc-internal-format
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr ""
 
-#: fortran/module.c:6553
+#: fortran/module.c:6555
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr ""
 
-#: fortran/module.c:6574 fortran/module.c:6607 fortran/module.c:6649
+#: fortran/module.c:6576 fortran/module.c:6609 fortran/module.c:6651
 #, gcc-internal-format
 msgid "Symbol %qs already declared"
 msgstr ""
 
-#: fortran/module.c:6754
+#: fortran/module.c:6756
 #, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:6776
+#: fortran/module.c:6778
 #, gcc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr ""
 
-#: fortran/module.c:6844
+#: fortran/module.c:6846
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr ""
 
-#: fortran/module.c:6898
+#: fortran/module.c:6900
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr ""
 
-#: fortran/module.c:6924
+#: fortran/module.c:6926
 #, gcc-internal-format, gfc-internal-format
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr ""
 
-#: fortran/module.c:6953
+#: fortran/module.c:6955
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr ""
 
-#: fortran/module.c:6965
+#: fortran/module.c:6967
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
 msgstr ""
 
-#: fortran/module.c:6978
+#: fortran/module.c:6980
 #, gcc-internal-format
 msgid "Can't find an intrinsic module named %qs at %C"
 msgstr ""
 
-#: fortran/module.c:6984
+#: fortran/module.c:6986
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr ""
 
-#: fortran/module.c:6990
+#: fortran/module.c:6992
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr ""
 
-#: fortran/module.c:6996
+#: fortran/module.c:6998
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr ""
 
-#: fortran/module.c:7006
+#: fortran/module.c:7008
 #, fuzzy, gcc-internal-format
 #| msgid "Failed to open file %s for writing state: %s"
 msgid "Can't open module file %qs for reading at %C: %s"
 msgstr "Nisam uspio otvoriti datoteku %s za pisanje stanja: %s"
 
-#: fortran/module.c:7009
+#: fortran/module.c:7011
 #, gcc-internal-format
 msgid "Module file %qs has not been generated, either because the module does not contain a MODULE PROCEDURE or there is an error in the module."
 msgstr ""
 
-#: fortran/module.c:7020
+#: fortran/module.c:7022
 #, gcc-internal-format
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:7043
+#: fortran/module.c:7045
 #, gcc-internal-format
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr ""
 
-#: fortran/module.c:7051
+#: fortran/module.c:7053
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr ""
 
-#: fortran/module.c:7066
+#: fortran/module.c:7068
 #, gcc-internal-format, gfc-internal-format
 msgid "Can't USE the same %smodule we're building"
 msgstr ""
 
 #: fortran/openmp.c:296 fortran/openmp.c:397 fortran/openmp.c:692
-#: fortran/openmp.c:3167
+#: fortran/openmp.c:3166
 #, gcc-internal-format, gfc-internal-format
 msgid "COMMON block /%s/ not found at %C"
 msgstr ""
@@ -56362,859 +56440,859 @@
 
 #: fortran/openmp.c:2180
 #, gcc-internal-format, gfc-internal-format
-msgid "Invalid argument to !$ACC WAIT at %L"
+msgid "Invalid argument to !$ACC WAIT at %C"
 msgstr ""
 
-#: fortran/openmp.c:2188
+#: fortran/openmp.c:2187
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT clause at %L requires a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/openmp.c:2221
+#: fortran/openmp.c:2220
 #, gcc-internal-format, gfc-internal-format
 msgid "ACC CACHE directive must be inside of loop %C"
 msgstr ""
 
-#: fortran/openmp.c:2252
+#: fortran/openmp.c:2251
 #, gcc-internal-format
 msgid "Multiple loop axes specified for routine"
 msgstr ""
 
-#: fortran/openmp.c:2278
+#: fortran/openmp.c:2277
 #, gcc-internal-format, gfc-internal-format
 msgid "Only the !$ACC ROUTINE form without list is allowed in interface block at %C"
 msgstr ""
 
-#: fortran/openmp.c:2306
+#: fortran/openmp.c:2305
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$ACC ROUTINE ( NAME ) at %C, invalid function name %s"
 msgstr ""
 
-#: fortran/openmp.c:2315
+#: fortran/openmp.c:2314
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$ACC ROUTINE ( NAME ) at %C"
 msgstr ""
 
-#: fortran/openmp.c:2322
+#: fortran/openmp.c:2321
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$ACC ROUTINE ( NAME ) at %C, expecting ')' after NAME"
 msgstr ""
 
-#: fortran/openmp.c:2457 fortran/openmp.c:2481
+#: fortran/openmp.c:2456 fortran/openmp.c:2480
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP CRITICAL statement at %C"
 msgstr ""
 
-#: fortran/openmp.c:2548
+#: fortran/openmp.c:2547
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP FLUSH statement at %C"
 msgstr ""
 
-#: fortran/openmp.c:2942 fortran/openmp.c:6225
+#: fortran/openmp.c:2941 fortran/openmp.c:6230
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined %s !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2946 fortran/openmp.c:6229
+#: fortran/openmp.c:2945 fortran/openmp.c:6234
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2951
+#: fortran/openmp.c:2950
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2953
+#: fortran/openmp.c:2952
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2973
+#: fortran/openmp.c:2972
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after !$OMP DECLARE REDUCTION at %C"
 msgstr ""
 
-#: fortran/openmp.c:3010
+#: fortran/openmp.c:3009
 #, gcc-internal-format, gfc-internal-format
 msgid "Only the !$OMP DECLARE TARGET form without clauses is allowed in interface block at %C"
 msgstr ""
 
-#: fortran/openmp.c:3025
+#: fortran/openmp.c:3024
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after !$OMP DECLARE TARGET at %C"
 msgstr ""
 
-#: fortran/openmp.c:3048
+#: fortran/openmp.c:3047
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET variable at %L is an element of a COMMON block"
 msgstr ""
 
-#: fortran/openmp.c:3053
+#: fortran/openmp.c:3052
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET variable at %L previously mentioned in LINK clause and later in TO clause"
 msgstr ""
 
-#: fortran/openmp.c:3059
+#: fortran/openmp.c:3058
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET variable at %L previously mentioned in TO clause and later in LINK clause"
 msgstr ""
 
-#: fortran/openmp.c:3063
+#: fortran/openmp.c:3062
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable at %L mentioned multiple times in clauses of the same OMP DECLARE TARGET directive"
 msgstr ""
 
-#: fortran/openmp.c:3078
+#: fortran/openmp.c:3077
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET COMMON at %L previously mentioned in LINK clause and later in TO clause"
 msgstr ""
 
-#: fortran/openmp.c:3084
+#: fortran/openmp.c:3083
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET COMMON at %L previously mentioned in TO clause and later in LINK clause"
 msgstr ""
 
-#: fortran/openmp.c:3088
+#: fortran/openmp.c:3087
 #, gcc-internal-format, gfc-internal-format
 msgid "COMMON at %L mentioned multiple times in clauses of the same OMP DECLARE TARGET directive"
 msgstr ""
 
-#: fortran/openmp.c:3115
+#: fortran/openmp.c:3114
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$OMP DECLARE TARGET list at %C"
 msgstr ""
 
-#: fortran/openmp.c:3147
+#: fortran/openmp.c:3146
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate variable at %C is an element of a COMMON block"
 msgstr ""
 
-#: fortran/openmp.c:3184
+#: fortran/openmp.c:3183
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after OMP THREADPRIVATE at %C"
 msgstr ""
 
-#: fortran/openmp.c:3191
+#: fortran/openmp.c:3190
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$OMP THREADPRIVATE list at %C"
 msgstr ""
 
-#: fortran/openmp.c:3405
+#: fortran/openmp.c:3404
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after TASKWAIT clause at %C"
 msgstr ""
 
-#: fortran/openmp.c:3419
+#: fortran/openmp.c:3418
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after TASKYIELD clause at %C"
 msgstr ""
 
-#: fortran/openmp.c:3478
+#: fortran/openmp.c:3477
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP WORKSHARE statement at %C"
 msgstr ""
 
-#: fortran/openmp.c:3492
+#: fortran/openmp.c:3491
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP MASTER statement at %C"
 msgstr ""
 
-#: fortran/openmp.c:3551
+#: fortran/openmp.c:3550
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP ATOMIC statement at %C"
 msgstr ""
 
-#: fortran/openmp.c:3578
+#: fortran/openmp.c:3577
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP BARRIER statement at %C"
 msgstr ""
 
-#: fortran/openmp.c:3592
+#: fortran/openmp.c:3591
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP TASKGROUP statement at %C"
 msgstr ""
 
-#: fortran/openmp.c:3642
+#: fortran/openmp.c:3641
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP CANCELLATION POINT statement at %C"
 msgstr ""
 
-#: fortran/openmp.c:3662
+#: fortran/openmp.c:3661
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after NOWAIT clause at %C"
 msgstr ""
 
-#: fortran/openmp.c:3704
+#: fortran/openmp.c:3703
 #, gcc-internal-format, gfc-internal-format
 msgid "%s clause at %L requires a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/openmp.c:3715
+#: fortran/openmp.c:3714
 #, gcc-internal-format, gfc-internal-format
 msgid "INTEGER expression of %s clause at %L must be positive"
 msgstr ""
 
-#: fortran/openmp.c:3726
+#: fortran/openmp.c:3725
 #, gcc-internal-format, gfc-internal-format
 msgid "INTEGER expression of %s clause at %L must be non-negative"
 msgstr ""
 
-#: fortran/openmp.c:3737
+#: fortran/openmp.c:3736
 #, gcc-internal-format
 msgid "POINTER object %qs of derived type in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3740
+#: fortran/openmp.c:3739
 #, gcc-internal-format
 msgid "Cray pointer object %qs of derived type in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3743
+#: fortran/openmp.c:3742
 #, gcc-internal-format
 msgid "Cray pointee object %qs of derived type in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3749 fortran/openmp.c:4687
+#: fortran/openmp.c:3748 fortran/openmp.c:4686
 #, gcc-internal-format
 msgid "POINTER object %qs of polymorphic type in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3754
+#: fortran/openmp.c:3753
 #, gcc-internal-format
 msgid "Cray pointer object %qs of polymorphic type in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3759
+#: fortran/openmp.c:3758
 #, gcc-internal-format
 msgid "Cray pointee object %qs of polymorphic type in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3769 fortran/openmp.c:4385 fortran/openmp.c:4490
+#: fortran/openmp.c:3768 fortran/openmp.c:4384 fortran/openmp.c:4489
 #, gcc-internal-format
 msgid "Assumed size array %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3772
+#: fortran/openmp.c:3771
 #, gcc-internal-format
 msgid "Assumed rank array %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3776
+#: fortran/openmp.c:3775
 #, gcc-internal-format
 msgid "Noncontiguous deferred shape array %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3784
+#: fortran/openmp.c:3783
 #, gcc-internal-format
 msgid "ALLOCATABLE object %qs of derived type in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3789
+#: fortran/openmp.c:3788
 #, gcc-internal-format
 msgid "ALLOCATABLE object %qs of polymorphic type in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3801 fortran/openmp.c:4480
+#: fortran/openmp.c:3800 fortran/openmp.c:4479
 #, gcc-internal-format
 msgid "POINTER object %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3806 fortran/openmp.c:4691
+#: fortran/openmp.c:3805 fortran/openmp.c:4690
 #, gcc-internal-format
 msgid "Cray pointer object %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3811 fortran/openmp.c:4694
+#: fortran/openmp.c:3810 fortran/openmp.c:4693
 #, gcc-internal-format
 msgid "Cray pointee object %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3816 fortran/openmp.c:4682
+#: fortran/openmp.c:3815 fortran/openmp.c:4681
 #, gcc-internal-format
 msgid "ALLOCATABLE object %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3819
+#: fortran/openmp.c:3818
 #, gcc-internal-format
 msgid "VALUE object %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3862
+#: fortran/openmp.c:3861
 #, gcc-internal-format, gfc-internal-format
 msgid "Implicitly declared function %s used in !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:3911
+#: fortran/openmp.c:3910
 #, gcc-internal-format, gfc-internal-format
 msgid "Implicitly declared subroutine %s used in !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:3944
+#: fortran/openmp.c:3943
 #, gcc-internal-format, gfc-internal-format
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:3952 fortran/openmp.c:3963 fortran/resolve.c:10028
-#: fortran/resolve.c:11295
+#: fortran/openmp.c:3951 fortran/openmp.c:3962 fortran/resolve.c:10041
+#: fortran/resolve.c:11315
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/openmp.c:3967
+#: fortran/openmp.c:3966
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause without modifier at %L used together with IF clauses with modifiers"
 msgstr ""
 
-#: fortran/openmp.c:4044
+#: fortran/openmp.c:4043
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause modifier %s at %L not appropriate for the current OpenMP construct"
 msgstr ""
 
-#: fortran/openmp.c:4054
+#: fortran/openmp.c:4053
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/openmp.c:4064
+#: fortran/openmp.c:4063
 #, gcc-internal-format, gfc-internal-format
 msgid "SCHEDULE clause's chunk_size at %L requires a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/openmp.c:4069
+#: fortran/openmp.c:4068
 #, gcc-internal-format, gfc-internal-format
 msgid "INTEGER expression of SCHEDULE clause's chunk_size at %L must be positive"
 msgstr ""
 
-#: fortran/openmp.c:4084
+#: fortran/openmp.c:4083
 #, gcc-internal-format
 msgid "Variable %qs is not a dummy argument at %L"
 msgstr ""
 
-#: fortran/openmp.c:4116
+#: fortran/openmp.c:4115 fortran/openmp.c:5998
 #, gcc-internal-format
 msgid "Object %qs is not a variable at %L"
 msgstr ""
 
-#: fortran/openmp.c:4132 fortran/openmp.c:4143 fortran/openmp.c:4151
-#: fortran/openmp.c:4162 fortran/openmp.c:4174 fortran/openmp.c:4189
-#: fortran/openmp.c:6023
+#: fortran/openmp.c:4131 fortran/openmp.c:4142 fortran/openmp.c:4150
+#: fortran/openmp.c:4161 fortran/openmp.c:4173 fortran/openmp.c:4188
+#: fortran/openmp.c:6028
 #, gcc-internal-format
 msgid "Symbol %qs present on multiple clauses at %L"
 msgstr ""
 
-#: fortran/openmp.c:4196
+#: fortran/openmp.c:4195
 #, gcc-internal-format
 msgid "Array %qs is not permitted in reduction at %L"
 msgstr ""
 
-#: fortran/openmp.c:4209
+#: fortran/openmp.c:4208
 #, gcc-internal-format
 msgid "Symbol %qs present on both FROM and TO clauses at %L"
 msgstr ""
 
-#: fortran/openmp.c:4231
+#: fortran/openmp.c:4230
 #, gcc-internal-format
 msgid "Non-THREADPRIVATE object %qs in COPYIN clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4239
+#: fortran/openmp.c:4238
 #, gcc-internal-format
 msgid "Assumed size array %qs in COPYPRIVATE clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4242
+#: fortran/openmp.c:4241
 #, gcc-internal-format
 msgid "INTENT(IN) POINTER %qs in COPYPRIVATE clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4250
+#: fortran/openmp.c:4249
 #, gcc-internal-format
 msgid "THREADPRIVATE object %qs in SHARED clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4253
+#: fortran/openmp.c:4252
 #, gcc-internal-format
 msgid "Cray pointee %qs in SHARED clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4256
+#: fortran/openmp.c:4255
 #, gcc-internal-format
 msgid "ASSOCIATE name %qs in SHARED clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4271
+#: fortran/openmp.c:4270
 #, gcc-internal-format
 msgid "%qs in ALIGNED clause must be POINTER, ALLOCATABLE, Cray pointer or C_PTR at %L"
 msgstr ""
 
-#: fortran/openmp.c:4283
+#: fortran/openmp.c:4282
 #, gcc-internal-format
 msgid "%qs in ALIGNED clause at %L requires a scalar positive constant integer alignment expression"
 msgstr ""
 
-#: fortran/openmp.c:4302
+#: fortran/openmp.c:4301
 #, gcc-internal-format, gfc-internal-format
 msgid "SINK dependence type only allowed on ORDERED directive at %L"
 msgstr ""
 
-#: fortran/openmp.c:4306
+#: fortran/openmp.c:4305
 #, gcc-internal-format, gfc-internal-format
 msgid "DEPEND SINK used together with DEPEND SOURCE on the same construct at %L"
 msgstr ""
 
-#: fortran/openmp.c:4316
+#: fortran/openmp.c:4315
 #, gcc-internal-format, gfc-internal-format
 msgid "SINK addend not a constant integer at %L"
 msgstr ""
 
-#: fortran/openmp.c:4322
+#: fortran/openmp.c:4321
 #, gcc-internal-format, gfc-internal-format
 msgid "Only SOURCE or SINK dependence types are allowed on ORDERED directive at %L"
 msgstr ""
 
-#: fortran/openmp.c:4333 fortran/openmp.c:4354
+#: fortran/openmp.c:4332 fortran/openmp.c:4353
 #, gcc-internal-format
 msgid "%qs in %s clause at %L is not a proper array section"
 msgstr ""
 
-#: fortran/openmp.c:4337
+#: fortran/openmp.c:4336
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarrays not supported in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4346
+#: fortran/openmp.c:4345
 #, gcc-internal-format, gfc-internal-format
 msgid "Stride should not be specified for array section in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4367
+#: fortran/openmp.c:4366
 #, gcc-internal-format
 msgid "%qs in DEPEND clause at %L is a zero size array section"
 msgstr ""
 
-#: fortran/openmp.c:4403
+#: fortran/openmp.c:4402
 #, gcc-internal-format, gfc-internal-format
 msgid "TARGET%s with map-type other than TO, FROM, TOFROM, or ALLOC on MAP clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4419
+#: fortran/openmp.c:4418
 #, gcc-internal-format, gfc-internal-format
 msgid "TARGET ENTER DATA with map-type other than TO, or ALLOC on MAP clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4434
+#: fortran/openmp.c:4433
 #, gcc-internal-format, gfc-internal-format
 msgid "TARGET EXIT DATA with map-type other than FROM, RELEASE, or DELETE on MAP clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4450 fortran/openmp.c:4466
+#: fortran/openmp.c:4449 fortran/openmp.c:4465
 #, gcc-internal-format
 msgid "THREADPRIVATE object %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4453 fortran/openmp.c:4469
+#: fortran/openmp.c:4452 fortran/openmp.c:4468
 #, gcc-internal-format
 msgid "Cray pointee %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4472
+#: fortran/openmp.c:4471
 #, gcc-internal-format
 msgid "ASSOCIATE name %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4477
+#: fortran/openmp.c:4476
 #, gcc-internal-format
 msgid "Procedure pointer %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4483
+#: fortran/openmp.c:4482
 #, gcc-internal-format
 msgid "Cray pointer %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4493
+#: fortran/openmp.c:4492
 #, gcc-internal-format
 msgid "Variable %qs in %s clause is used in NAMELIST statement at %L"
 msgstr ""
 
 #. case OMP_LIST_REDUCTION:
-#: fortran/openmp.c:4503
+#: fortran/openmp.c:4502
 #, gcc-internal-format
 msgid "INTENT(IN) POINTER %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4596
+#: fortran/openmp.c:4595
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP DECLARE REDUCTION %s not found for type %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:4622
+#: fortran/openmp.c:4621
 #, gcc-internal-format, gfc-internal-format
 msgid "LINEAR clause modifier used on DO or SIMD construct at %L"
 msgstr ""
 
-#: fortran/openmp.c:4627
+#: fortran/openmp.c:4626
 #, gcc-internal-format, gfc-internal-format
 msgid "LINEAR clause specified together with ORDERED clause with argument at %L"
 msgstr ""
 
-#: fortran/openmp.c:4632
+#: fortran/openmp.c:4631
 #, gcc-internal-format
 msgid "LINEAR variable %qs must be INTEGER at %L"
 msgstr ""
 
-#: fortran/openmp.c:4637
+#: fortran/openmp.c:4636
 #, gcc-internal-format
 msgid "LINEAR dummy argument %qs with VALUE attribute with %s modifier at %L"
 msgstr ""
 
-#: fortran/openmp.c:4648
+#: fortran/openmp.c:4647
 #, gcc-internal-format
 msgid "%qs in LINEAR clause at %L requires a scalar integer linear-step expression"
 msgstr ""
 
-#: fortran/openmp.c:4665
+#: fortran/openmp.c:4664
 #, gcc-internal-format
 msgid "%qs in LINEAR clause at %L requires a constant integer linear-step expression or dummy argument specified in UNIFORM clause"
 msgstr ""
 
-#: fortran/openmp.c:4699
+#: fortran/openmp.c:4698
 #, gcc-internal-format
 msgid "%s clause variable %qs at %L is neither a POINTER nor an array"
 msgstr ""
 
-#: fortran/openmp.c:4731
+#: fortran/openmp.c:4730
 #, gcc-internal-format, gfc-internal-format
 msgid "DIST_SCHEDULE clause's chunk_size at %L requires a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/openmp.c:4763
+#: fortran/openmp.c:4762
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible use of TILE and COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:4765
+#: fortran/openmp.c:4764
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE dependence type only allowed on ORDERED directive at %L"
 msgstr ""
 
-#: fortran/openmp.c:4778
+#: fortran/openmp.c:4777
 #, gcc-internal-format, gfc-internal-format
 msgid "%s must contain at least one MAP clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4875
+#: fortran/openmp.c:4874
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected !$OMP ATOMIC expression at %L"
 msgstr ""
 
-#: fortran/openmp.c:4904
+#: fortran/openmp.c:4903
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC statement must set a scalar variable of intrinsic type at %L"
 msgstr ""
 
-#: fortran/openmp.c:4929
+#: fortran/openmp.c:4928
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC READ statement must read from a scalar variable of intrinsic type at %L"
 msgstr ""
 
-#: fortran/openmp.c:4934
+#: fortran/openmp.c:4933
 #, gcc-internal-format, gfc-internal-format
 msgid "expr in !$OMP ATOMIC WRITE assignment var = expr must be scalar and cannot reference var at %L"
 msgstr ""
 
-#: fortran/openmp.c:4956 fortran/openmp.c:5247
+#: fortran/openmp.c:4955 fortran/openmp.c:5246
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE capture statement must read from a scalar variable of intrinsic type at %L"
 msgstr ""
 
-#: fortran/openmp.c:4971
+#: fortran/openmp.c:4970
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE update statement must set a scalar variable of intrinsic type at %L"
 msgstr ""
 
-#: fortran/openmp.c:4978 fortran/openmp.c:5254
+#: fortran/openmp.c:4977 fortran/openmp.c:5253
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE capture statement reads from different variable than update statement writes into at %L"
 msgstr ""
 
-#: fortran/openmp.c:4994
+#: fortran/openmp.c:4993
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC with ALLOCATABLE variable at %L"
 msgstr ""
 
-#: fortran/openmp.c:5036
+#: fortran/openmp.c:5035
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment operator must be binary +, *, -, /, .AND., .OR., .EQV. or .NEQV. at %L"
 msgstr ""
 
-#: fortran/openmp.c:5084
+#: fortran/openmp.c:5083
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment must be var = var op expr or var = expr op var at %L"
 msgstr ""
 
-#: fortran/openmp.c:5098
+#: fortran/openmp.c:5097
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC var = var op expr not mathematically equivalent to var = var op (expr) at %L"
 msgstr ""
 
-#: fortran/openmp.c:5130
+#: fortran/openmp.c:5129
 #, gcc-internal-format, gfc-internal-format
 msgid "expr in !$OMP ATOMIC assignment var = var op expr must be scalar and cannot reference var at %L"
 msgstr ""
 
-#: fortran/openmp.c:5154
+#: fortran/openmp.c:5153
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment intrinsic IAND, IOR or IEOR must have two arguments at %L"
 msgstr ""
 
-#: fortran/openmp.c:5161
+#: fortran/openmp.c:5160
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment intrinsic must be MIN, MAX, IAND, IOR or IEOR at %L"
 msgstr ""
 
-#: fortran/openmp.c:5178
+#: fortran/openmp.c:5177
 #, gcc-internal-format
 msgid "!$OMP ATOMIC intrinsic arguments except one must not reference %qs at %L"
 msgstr ""
 
-#: fortran/openmp.c:5185
+#: fortran/openmp.c:5184
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC intrinsic arguments must be scalar at %L"
 msgstr ""
 
-#: fortran/openmp.c:5193
+#: fortran/openmp.c:5192
 #, gcc-internal-format
 msgid "First or last !$OMP ATOMIC intrinsic argument must be %qs at %L"
 msgstr ""
 
-#: fortran/openmp.c:5211
+#: fortran/openmp.c:5210
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment must have an operator or intrinsic on right hand side at %L"
 msgstr ""
 
-#: fortran/openmp.c:5225
+#: fortran/openmp.c:5224
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE capture statement must set a scalar variable of intrinsic type at %L"
 msgstr ""
 
-#: fortran/openmp.c:5544
+#: fortran/openmp.c:5543
 #, gcc-internal-format, gfc-internal-format
 msgid "%s cannot be a DO WHILE or DO without loop control at %L"
 msgstr ""
 
-#: fortran/openmp.c:5550
+#: fortran/openmp.c:5549
 #, gcc-internal-format, gfc-internal-format
 msgid "%s cannot be a DO CONCURRENT loop at %L"
 msgstr ""
 
-#: fortran/openmp.c:5556
+#: fortran/openmp.c:5555
 #, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable must be of type integer at %L"
 msgstr ""
 
-#: fortran/openmp.c:5560
+#: fortran/openmp.c:5559
 #, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable must not be THREADPRIVATE at %L"
 msgstr ""
 
-#: fortran/openmp.c:5573
+#: fortran/openmp.c:5572
 #, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable present on clause other than PRIVATE or LASTPRIVATE at %L"
 msgstr ""
 
-#: fortran/openmp.c:5577
+#: fortran/openmp.c:5576
 #, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable present on clause other than LASTPRIVATE at %L"
 msgstr ""
 
-#: fortran/openmp.c:5581
+#: fortran/openmp.c:5580
 #, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable present on clause other than LINEAR at %L"
 msgstr ""
 
-#: fortran/openmp.c:5599
+#: fortran/openmp.c:5598
 #, gcc-internal-format, gfc-internal-format
 msgid "%s collapsed loops don't form rectangular iteration space at %L"
 msgstr ""
 
-#: fortran/openmp.c:5611
+#: fortran/openmp.c:5610
 #, gcc-internal-format, gfc-internal-format
 msgid "collapsed %s loops not perfectly nested at %L"
 msgstr ""
 
-#: fortran/openmp.c:5620 fortran/openmp.c:5628
+#: fortran/openmp.c:5619 fortran/openmp.c:5627
 #, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for collapsed %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:5712 fortran/openmp.c:5725
+#: fortran/openmp.c:5711 fortran/openmp.c:5724
 #, gcc-internal-format, gfc-internal-format
 msgid "The %s directive cannot be specified within a %s region at %L"
 msgstr ""
 
-#: fortran/openmp.c:5744
+#: fortran/openmp.c:5743
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP cannot be a DO WHILE or DO without loop control at %L"
 msgstr ""
 
-#: fortran/openmp.c:5750
+#: fortran/openmp.c:5749
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP iteration variable must be of type integer at %L"
 msgstr ""
 
-#: fortran/openmp.c:5766
+#: fortran/openmp.c:5765
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s loops don't form rectangular iteration space at %L"
 msgstr ""
 
-#: fortran/openmp.c:5778
+#: fortran/openmp.c:5777
 #, gcc-internal-format, gfc-internal-format
 msgid "%s !$ACC LOOP loops not perfectly nested at %L"
 msgstr ""
 
-#: fortran/openmp.c:5788 fortran/openmp.c:5797
+#: fortran/openmp.c:5787 fortran/openmp.c:5796
 #, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for %s !$ACC LOOP at %L"
 msgstr ""
 
-#: fortran/openmp.c:5812 fortran/openmp.c:5819
+#: fortran/openmp.c:5811 fortran/openmp.c:5818
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s in PARALLEL region doesn't allow %s arguments at %L"
 msgstr ""
 
-#: fortran/openmp.c:5841
+#: fortran/openmp.c:5840
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside another loop parallelized across gangs at %L"
 msgstr ""
 
-#: fortran/openmp.c:5845 fortran/openmp.c:5849
+#: fortran/openmp.c:5844 fortran/openmp.c:5848
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside loop parallelized across workers at %L"
 msgstr ""
 
-#: fortran/openmp.c:5856
+#: fortran/openmp.c:5855
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across workers at %L"
 msgstr ""
 
-#: fortran/openmp.c:5860
+#: fortran/openmp.c:5859
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across vectors at %L"
 msgstr ""
 
-#: fortran/openmp.c:5866
+#: fortran/openmp.c:5865
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across vectors is not allowed inside another loop parallelized across vectors at %L"
 msgstr ""
 
-#: fortran/openmp.c:5878
+#: fortran/openmp.c:5877
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with INDEPENDENT at %L"
 msgstr ""
 
-#: fortran/openmp.c:5880
+#: fortran/openmp.c:5879
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with GANG at %L"
 msgstr ""
 
-#: fortran/openmp.c:5882
+#: fortran/openmp.c:5881
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with WORKER at %L"
 msgstr ""
 
-#: fortran/openmp.c:5884
+#: fortran/openmp.c:5883
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with VECTOR at %L"
 msgstr ""
 
-#: fortran/openmp.c:5886
+#: fortran/openmp.c:5885
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with AUTO at %L"
 msgstr ""
 
-#: fortran/openmp.c:5891
+#: fortran/openmp.c:5890
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with GANG at %L"
 msgstr ""
 
-#: fortran/openmp.c:5893
+#: fortran/openmp.c:5892
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with WORKER at %L"
 msgstr ""
 
-#: fortran/openmp.c:5895
+#: fortran/openmp.c:5894
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with VECTOR at %L"
 msgstr ""
 
-#: fortran/openmp.c:5899
+#: fortran/openmp.c:5898
 #, gcc-internal-format, gfc-internal-format
 msgid "Tiled loop cannot be parallelized across gangs, workers and vectors at the same time at %L"
 msgstr ""
 
-#: fortran/openmp.c:5934
+#: fortran/openmp.c:5933
 #, gcc-internal-format, gfc-internal-format
 msgid "TILE requires constant expression at %L"
 msgstr ""
 
-#: fortran/openmp.c:5999
+#: fortran/openmp.c:6004
 #, gcc-internal-format
 msgid "PARAMETER object %qs is not allowed at %L"
 msgstr ""
 
-#: fortran/openmp.c:6006
+#: fortran/openmp.c:6011
 #, gcc-internal-format
 msgid "Array sections: %qs not allowed in !$ACC DECLARE at %L"
 msgstr ""
 
-#: fortran/openmp.c:6133
+#: fortran/openmp.c:6138
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP TARGET UPDATE at %L requires at least one TO or FROM clause"
 msgstr ""
 
-#: fortran/openmp.c:6155
+#: fortran/openmp.c:6160
 #, gcc-internal-format
 msgid "!$OMP DECLARE SIMD should refer to containing procedure %qs at %L"
 msgstr ""
 
-#: fortran/openmp.c:6179
+#: fortran/openmp.c:6184
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_PRIV or OMP_ORIG used in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6187
+#: fortran/openmp.c:6192
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_OUT or OMP_IN used in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6216
+#: fortran/openmp.c:6221
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid operator for !$OMP DECLARE REDUCTION %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:6238
+#: fortran/openmp.c:6243
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER length in !$OMP DECLARE REDUCTION %s not constant at %L"
 msgstr ""
 
-#: fortran/openmp.c:6254
+#: fortran/openmp.c:6259
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6269
+#: fortran/openmp.c:6274
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6279
+#: fortran/openmp.c:6284
 #, gcc-internal-format, gfc-internal-format
 msgid "One of actual subroutine arguments in INITIALIZER clause of !$OMP DECLARE REDUCTION must be OMP_PRIV at %L"
 msgstr ""
 
-#: fortran/openmp.c:6287
+#: fortran/openmp.c:6292
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing INITIALIZER clause for !$OMP DECLARE REDUCTION of derived type without default initializer at %L"
 msgstr ""
@@ -57324,495 +57402,495 @@
 msgid "Unclassifiable statement at %C"
 msgstr ""
 
-#: fortran/parse.c:629
+#: fortran/parse.c:631
 #, gcc-internal-format, gfc-internal-format
 msgid "OpenACC directives at %C may not appear in PURE procedures"
 msgstr ""
 
-#: fortran/parse.c:705
+#: fortran/parse.c:707
 #, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable OpenACC directive at %C"
 msgstr ""
 
-#: fortran/parse.c:831 fortran/parse.c:1040
+#: fortran/parse.c:835 fortran/parse.c:1044
 #, gcc-internal-format, gfc-internal-format
 msgid "OpenMP directives other than SIMD or DECLARE TARGET at %C may not appear in PURE or ELEMENTAL procedures"
 msgstr ""
 
-#: fortran/parse.c:1024
+#: fortran/parse.c:1028
 #, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable OpenMP directive at %C"
 msgstr ""
 
-#: fortran/parse.c:1076
+#: fortran/parse.c:1080
 #, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable GCC directive at %C"
 msgstr ""
 
-#: fortran/parse.c:1135 fortran/parse.c:1362
+#: fortran/parse.c:1139 fortran/parse.c:1366
 #, gcc-internal-format, gfc-internal-format
 msgid "Zero is not a valid statement label at %C"
 msgstr ""
 
-#: fortran/parse.c:1142 fortran/parse.c:1354
+#: fortran/parse.c:1146 fortran/parse.c:1358
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-numeric character in statement label at %C"
 msgstr ""
 
-#: fortran/parse.c:1154 fortran/parse.c:1403
+#: fortran/parse.c:1158 fortran/parse.c:1407
 #, gcc-internal-format, gfc-internal-format
 msgid "Semicolon at %C needs to be preceded by statement"
 msgstr ""
 
-#: fortran/parse.c:1161 fortran/parse.c:1418
+#: fortran/parse.c:1165 fortran/parse.c:1422
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label without statement at %L"
 msgstr ""
 
-#: fortran/parse.c:1224 fortran/parse.c:1405
+#: fortran/parse.c:1228 fortran/parse.c:1409
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Semicolon at %C without preceding statement"
 msgstr ""
 
-#: fortran/parse.c:1247 fortran/parse.c:1381
+#: fortran/parse.c:1251 fortran/parse.c:1385
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad continuation line at %C"
 msgstr ""
 
-#: fortran/parse.c:1679
+#: fortran/parse.c:1683
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT statement at %L does not have a statement label"
 msgstr ""
 
-#: fortran/parse.c:2435
+#: fortran/parse.c:2439
 #, gcc-internal-format
 msgid "gfc_ascii_statement(): Bad statement code"
 msgstr ""
 
-#: fortran/parse.c:2577
+#: fortran/parse.c:2581
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement at %C"
 msgstr ""
 
-#: fortran/parse.c:2732
+#: fortran/parse.c:2736
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot follow %s statement at %L"
 msgstr ""
 
-#: fortran/parse.c:2749
+#: fortran/parse.c:2753
 #, fuzzy, gcc-internal-format
 #| msgid "expected end of line"
 msgid "Unexpected end of file in %qs"
 msgstr "očekujem kraj retka"
 
-#: fortran/parse.c:2784
+#: fortran/parse.c:2788
 #, gcc-internal-format
 msgid "Derived-type %qs with SEQUENCE must not have a CONTAINS section at %C"
 msgstr ""
 
-#: fortran/parse.c:2787
+#: fortran/parse.c:2791
 #, gcc-internal-format
 msgid "Derived-type %qs with BIND(C) must not have a CONTAINS section at %C"
 msgstr ""
 
-#: fortran/parse.c:2807
+#: fortran/parse.c:2811
 #, gcc-internal-format, gfc-internal-format
 msgid "Components in TYPE at %C must precede CONTAINS"
 msgstr ""
 
-#: fortran/parse.c:2811
+#: fortran/parse.c:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound procedure at %C"
 msgstr ""
 
-#: fortran/parse.c:2819
+#: fortran/parse.c:2823
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC binding at %C"
 msgstr ""
 
-#: fortran/parse.c:2827
+#: fortran/parse.c:2831
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure declaration at %C"
 msgstr ""
 
-#: fortran/parse.c:2839
+#: fortran/parse.c:2843
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type definition at %C with empty CONTAINS section"
 msgstr ""
 
-#: fortran/parse.c:2849 fortran/parse.c:3304
+#: fortran/parse.c:2853 fortran/parse.c:3308
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement in TYPE at %C must be inside a MODULE"
 msgstr ""
 
-#: fortran/parse.c:2856
+#: fortran/parse.c:2860
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede procedure bindings"
 msgstr ""
 
-#: fortran/parse.c:2863 fortran/parse.c:3317
+#: fortran/parse.c:2867 fortran/parse.c:3321
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PRIVATE statement at %C"
 msgstr ""
 
-#: fortran/parse.c:2873
+#: fortran/parse.c:2877
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede CONTAINS"
 msgstr ""
 
-#: fortran/parse.c:2877
+#: fortran/parse.c:2881
 #, gcc-internal-format, gfc-internal-format
 msgid "Already inside a CONTAINS block at %C"
 msgstr ""
 
-#: fortran/parse.c:2996
+#: fortran/parse.c:3000
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s at %L of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray, which is not possible as the component has the pointer attribute"
 msgstr ""
 
-#: fortran/parse.c:3002
+#: fortran/parse.c:3006
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer component %s at %L has a noncoarray subcomponent of type LOCK_TYPE, which must have a codimension or be a subcomponent of a coarray"
 msgstr ""
 
-#: fortran/parse.c:3007
+#: fortran/parse.c:3011
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L of type LOCK_TYPE must have a codimension"
 msgstr ""
 
-#: fortran/parse.c:3011
+#: fortran/parse.c:3015
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L must have a codimension as it has a noncoarray subcomponent of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/parse.c:3016
+#: fortran/parse.c:3020
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as already a coarray subcomponent exists)"
 msgstr ""
 
-#: fortran/parse.c:3023
+#: fortran/parse.c:3027
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as %s at %L has a codimension or a coarray subcomponent)"
 msgstr ""
 
-#: fortran/parse.c:3033
+#: fortran/parse.c:3037
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s at %L of type EVENT_TYPE must have a codimension or be a subcomponent of a coarray, which is not possible as the component has the pointer attribute"
 msgstr ""
 
-#: fortran/parse.c:3039
+#: fortran/parse.c:3043
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer component %s at %L has a noncoarray subcomponent of type EVENT_TYPE, which must have a codimension or be a subcomponent of a coarray"
 msgstr ""
 
-#: fortran/parse.c:3044
+#: fortran/parse.c:3048
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L of type EVENT_TYPE must have a codimension"
 msgstr ""
 
-#: fortran/parse.c:3048
+#: fortran/parse.c:3052
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L must have a codimension as it has a noncoarray subcomponent of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/parse.c:3053
+#: fortran/parse.c:3057
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as already a coarray subcomponent exists)"
 msgstr ""
 
-#: fortran/parse.c:3060
+#: fortran/parse.c:3064
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as %s at %L has a codimension or a coarray subcomponent)"
 msgstr ""
 
-#: fortran/parse.c:3112
+#: fortran/parse.c:3116
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "failed to open %s"
 msgid "failed to create map component '%s'"
 msgstr "nisam uspio otvoriti %s"
 
-#: fortran/parse.c:3145
+#: fortran/parse.c:3149
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "failed to open %s"
 msgid "failed to create union component '%s'"
 msgstr "nisam uspio otvoriti %s"
 
-#: fortran/parse.c:3200
+#: fortran/parse.c:3204
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in nested structure declaration at %C"
 msgstr ""
 
-#: fortran/parse.c:3287
+#: fortran/parse.c:3291
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside CONTAINS"
 msgstr ""
 
-#: fortran/parse.c:3295
+#: fortran/parse.c:3299
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type definition at %C without components"
 msgstr ""
 
-#: fortran/parse.c:3311
+#: fortran/parse.c:3315
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede structure components"
 msgstr ""
 
-#: fortran/parse.c:3328
+#: fortran/parse.c:3332
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede structure components"
 msgstr ""
 
-#: fortran/parse.c:3334
+#: fortran/parse.c:3338
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE attribute at %C already specified in TYPE statement"
 msgstr ""
 
-#: fortran/parse.c:3339
+#: fortran/parse.c:3343
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SEQUENCE statement at %C"
 msgstr ""
 
-#: fortran/parse.c:3349
+#: fortran/parse.c:3353
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS block in derived type definition at %C"
 msgstr ""
 
-#: fortran/parse.c:3407
+#: fortran/parse.c:3411
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM declaration at %C has no ENUMERATORS"
 msgstr ""
 
-#: fortran/parse.c:3494
+#: fortran/parse.c:3498
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in INTERFACE block at %C"
 msgstr ""
 
-#: fortran/parse.c:3518
+#: fortran/parse.c:3522
 #, gcc-internal-format
 msgid "Name %qs of ABSTRACT INTERFACE at %C cannot be the same as an intrinsic type"
 msgstr ""
 
-#: fortran/parse.c:3552
+#: fortran/parse.c:3556
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement at %C in INTERFACE body"
 msgstr ""
 
-#: fortran/parse.c:3570
+#: fortran/parse.c:3574
 #, gcc-internal-format
 msgid "INTERFACE procedure %qs at %L has the same name as the enclosing procedure"
 msgstr ""
 
-#: fortran/parse.c:3700
+#: fortran/parse.c:3704
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/parse.c:3732
+#: fortran/parse.c:3736
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement is not allowed inside of BLOCK DATA at %C"
 msgstr ""
 
-#: fortran/parse.c:3822
+#: fortran/parse.c:3826
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement must appear in a MODULE"
 msgstr ""
 
-#: fortran/parse.c:3830
+#: fortran/parse.c:3834
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C follows another accessibility specification"
 msgstr ""
 
-#: fortran/parse.c:3882
+#: fortran/parse.c:3886
 #, gcc-internal-format
 msgid "Bad kind expression for function %qs at %L"
 msgstr ""
 
-#: fortran/parse.c:3886
+#: fortran/parse.c:3890
 #, gcc-internal-format
 msgid "The type for function %qs at %L is not accessible"
 msgstr ""
 
-#: fortran/parse.c:3946
+#: fortran/parse.c:3950
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C follows previous unmasked ELSEWHERE"
 msgstr ""
 
-#: fortran/parse.c:3968
+#: fortran/parse.c:3972
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in WHERE block at %C"
 msgstr ""
 
-#: fortran/parse.c:4027
+#: fortran/parse.c:4031
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in FORALL block at %C"
 msgstr ""
 
-#: fortran/parse.c:4078
+#: fortran/parse.c:4082
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSE IF statement at %C cannot follow ELSE statement at %L"
 msgstr ""
 
-#: fortran/parse.c:4096
+#: fortran/parse.c:4100
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ELSE statements at %L and %C"
 msgstr ""
 
-#: fortran/parse.c:4157
+#: fortran/parse.c:4161
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected a CASE or END SELECT statement following SELECT CASE at %C"
 msgstr ""
 
-#: fortran/parse.c:4241
+#: fortran/parse.c:4245
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected TYPE IS, CLASS IS or END SELECT statement following SELECT TYPE at %C"
 msgstr ""
 
-#: fortran/parse.c:4303
+#: fortran/parse.c:4307
 #, gcc-internal-format
 msgid "Variable %qs at %C cannot be redefined inside loop beginning at %L"
 msgstr ""
 
-#: fortran/parse.c:4336
+#: fortran/parse.c:4340
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is within another block"
 msgstr ""
 
-#: fortran/parse.c:4346
+#: fortran/parse.c:4350
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is interwoven with another DO loop"
 msgstr ""
 
-#: fortran/parse.c:4372
+#: fortran/parse.c:4376
 #, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL block inside of OpenACC region at %C"
 msgstr ""
 
-#: fortran/parse.c:4373
+#: fortran/parse.c:4377
 #, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL block inside of OpenMP region at %C"
 msgstr ""
 
-#: fortran/parse.c:4399
+#: fortran/parse.c:4403
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label in END CRITICAL at %C does not match CRITICAL label"
 msgstr ""
 
-#: fortran/parse.c:4468
+#: fortran/parse.c:4472
 #, gcc-internal-format, gfc-internal-format
 msgid "BLOCK construct at %C"
 msgstr ""
 
-#: fortran/parse.c:4502
+#: fortran/parse.c:4506
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSOCIATE construct at %C"
 msgstr ""
 
-#: fortran/parse.c:4690
+#: fortran/parse.c:4694
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label in ENDDO at %C doesn't match DO label"
 msgstr ""
 
-#: fortran/parse.c:4706
+#: fortran/parse.c:4710
 #, gcc-internal-format, gfc-internal-format
 msgid "Named block DO at %L requires matching ENDDO name"
 msgstr ""
 
-#: fortran/parse.c:4897
+#: fortran/parse.c:4901
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing !$OMP END ATOMIC after !$OMP ATOMIC CAPTURE at %C"
 msgstr ""
 
-#: fortran/parse.c:4913 fortran/parse.c:4972
+#: fortran/parse.c:4917 fortran/parse.c:4976
 #, gcc-internal-format, gfc-internal-format
 msgid "OpenACC directive inside of CRITICAL block at %C"
 msgstr ""
 
-#: fortran/parse.c:4947
+#: fortran/parse.c:4951
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s at %C"
 msgstr ""
 
-#: fortran/parse.c:4991
+#: fortran/parse.c:4995
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected DO loop at %C"
 msgstr ""
 
-#: fortran/parse.c:5011
+#: fortran/parse.c:5015
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant !$ACC END LOOP at %C"
 msgstr ""
 
-#: fortran/parse.c:5225
+#: fortran/parse.c:5229
 #, gcc-internal-format, gfc-internal-format
 msgid "Name after !$omp critical and !$omp end critical does not match at %C"
 msgstr ""
 
-#: fortran/parse.c:5283
+#: fortran/parse.c:5287
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot terminate a non-block DO loop"
 msgstr ""
 
-#: fortran/parse.c:5297
+#: fortran/parse.c:5301
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %C after the first executable statement"
 msgstr ""
 
-#: fortran/parse.c:5423
+#: fortran/parse.c:5427
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive does not commence a loop at %C"
 msgstr ""
 
-#: fortran/parse.c:5538
+#: fortran/parse.c:5542
 #, gcc-internal-format
 msgid "Contained procedure %qs at %C is already ambiguous"
 msgstr ""
 
-#: fortran/parse.c:5595
+#: fortran/parse.c:5599
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in CONTAINS section at %C"
 msgstr ""
 
-#: fortran/parse.c:5620
+#: fortran/parse.c:5624
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS statement without FUNCTION or SUBROUTINE statement at %L"
 msgstr ""
 
-#: fortran/parse.c:5732
+#: fortran/parse.c:5736
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS statement at %C is already in a contained program unit"
 msgstr ""
 
-#: fortran/parse.c:5784
+#: fortran/parse.c:5788
 #, gcc-internal-format
 msgid "Global binding name %qs at %L is already being used as a %s at %L"
 msgstr ""
 
-#: fortran/parse.c:5788
+#: fortran/parse.c:5792
 #, gcc-internal-format
 msgid "Global name %qs at %L is already being used as a %s at %L"
 msgstr ""
 
-#: fortran/parse.c:5794
+#: fortran/parse.c:5798
 #, gcc-internal-format
 msgid "Global binding name %qs at %L is already being used at %L"
 msgstr ""
 
-#: fortran/parse.c:5797
+#: fortran/parse.c:5801
 #, gcc-internal-format
 msgid "Global name %qs at %L is already being used at %L"
 msgstr ""
 
-#: fortran/parse.c:5819
+#: fortran/parse.c:5823
 #, gcc-internal-format, gfc-internal-format
 msgid "Blank BLOCK DATA at %C conflicts with prior BLOCK DATA at %L"
 msgstr ""
 
-#: fortran/parse.c:5845
+#: fortran/parse.c:5849
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in BLOCK DATA at %C"
 msgstr ""
 
-#: fortran/parse.c:5949
+#: fortran/parse.c:5953
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in MODULE at %C"
 msgstr ""
@@ -57820,7 +57898,7 @@
 #. If we see a duplicate main program, shut down.  If the second
 #. instance is an implied main program, i.e. data decls or executable
 #. statements, we're in for lots of errors.
-#: fortran/parse.c:6333
+#: fortran/parse.c:6337
 #, gcc-internal-format, gfc-internal-format
 msgid "Two main PROGRAMs at %L and %C"
 msgstr ""
@@ -58567,7 +58645,7 @@
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.c:1893 fortran/resolve.c:9560 fortran/resolve.c:11225
+#: fortran/resolve.c:1893 fortran/resolve.c:9573 fortran/resolve.c:11245
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr ""
@@ -58677,7 +58755,7 @@
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr ""
 
-#: fortran/resolve.c:2905 fortran/resolve.c:16283
+#: fortran/resolve.c:2905 fortran/resolve.c:16310
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr ""
@@ -58798,197 +58876,197 @@
 msgid "logical_to_bitwise(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:4059
+#: fortran/resolve.c:4065
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:4229 fortran/resolve.c:4252
+#: fortran/resolve.c:4235 fortran/resolve.c:4258
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:4347
+#: fortran/resolve.c:4353
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4352
+#: fortran/resolve.c:4358
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4362
+#: fortran/resolve.c:4368
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4367
+#: fortran/resolve.c:4373
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4387
+#: fortran/resolve.c:4393
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr ""
 
-#: fortran/resolve.c:4404
+#: fortran/resolve.c:4410
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4412
+#: fortran/resolve.c:4418
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4428
+#: fortran/resolve.c:4434
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4437
+#: fortran/resolve.c:4443
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4453
+#: fortran/resolve.c:4459
 #, gcc-internal-format
 msgid "check_dimension(): Bad array reference"
 msgstr ""
 
-#: fortran/resolve.c:4476
+#: fortran/resolve.c:4482
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:4486
+#: fortran/resolve.c:4492
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.c:4494
+#: fortran/resolve.c:4500
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.c:4510
+#: fortran/resolve.c:4516
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr ""
 
-#: fortran/resolve.c:4538
+#: fortran/resolve.c:4544
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4544
+#: fortran/resolve.c:4550
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr ""
 
-#: fortran/resolve.c:4550
+#: fortran/resolve.c:4556
 #, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr ""
 
-#: fortran/resolve.c:4589
+#: fortran/resolve.c:4595
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4596
+#: fortran/resolve.c:4602
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr ""
 
-#: fortran/resolve.c:4641
+#: fortran/resolve.c:4647
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr ""
 
-#: fortran/resolve.c:4652
+#: fortran/resolve.c:4658
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.c:4663
+#: fortran/resolve.c:4669
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.c:4706
+#: fortran/resolve.c:4712
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr ""
 
-#: fortran/resolve.c:4804
+#: fortran/resolve.c:4810
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:4811
+#: fortran/resolve.c:4817
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4820
+#: fortran/resolve.c:4826
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr ""
 
-#: fortran/resolve.c:4833
+#: fortran/resolve.c:4839
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:4840
+#: fortran/resolve.c:4846
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4850
+#: fortran/resolve.c:4856
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr ""
 
-#: fortran/resolve.c:4860
+#: fortran/resolve.c:4866
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr ""
 
-#: fortran/resolve.c:5013
+#: fortran/resolve.c:5019
 #, gcc-internal-format
 msgid "resolve_ref(): Bad array reference"
 msgstr ""
 
-#: fortran/resolve.c:5027
+#: fortran/resolve.c:5033
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:5037
+#: fortran/resolve.c:5043
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:5056
+#: fortran/resolve.c:5062
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:5154
+#: fortran/resolve.c:5160
 #, gcc-internal-format
 msgid "expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.c:5236
+#: fortran/resolve.c:5242
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr ""
 
-#: fortran/resolve.c:5246
+#: fortran/resolve.c:5252
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -58997,12 +59075,12 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5256
+#: fortran/resolve.c:5262
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5271
+#: fortran/resolve.c:5277
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -59011,268 +59089,268 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5281
+#: fortran/resolve.c:5287
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5292
+#: fortran/resolve.c:5298
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5301
+#: fortran/resolve.c:5307
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5316
+#: fortran/resolve.c:5322
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5478
+#: fortran/resolve.c:5484
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5483
+#: fortran/resolve.c:5489
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5553
+#: fortran/resolve.c:5559
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.c:5566
+#: fortran/resolve.c:5572
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.c:5919
+#: fortran/resolve.c:5925
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:5926
+#: fortran/resolve.c:5932
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5961
+#: fortran/resolve.c:5967
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5970
+#: fortran/resolve.c:5976
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr ""
 
 #. Nothing matching found!
-#: fortran/resolve.c:6158
+#: fortran/resolve.c:6164
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:6185
+#: fortran/resolve.c:6191
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:6236
+#: fortran/resolve.c:6242
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:6786
+#: fortran/resolve.c:6792
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr ""
 
-#: fortran/resolve.c:6812
+#: fortran/resolve.c:6818
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr ""
 
-#: fortran/resolve.c:6822
+#: fortran/resolve.c:6828
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr ""
 
-#: fortran/resolve.c:6826 fortran/resolve.c:6833
+#: fortran/resolve.c:6832 fortran/resolve.c:6839
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6875
+#: fortran/resolve.c:6881
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:6911
+#: fortran/resolve.c:6917
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.c:6928
+#: fortran/resolve.c:6934
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.c:6934
+#: fortran/resolve.c:6940
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.c:6995
+#: fortran/resolve.c:7001
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7000
+#: fortran/resolve.c:7006
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7007
+#: fortran/resolve.c:7013
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7015
+#: fortran/resolve.c:7021
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr ""
 
-#: fortran/resolve.c:7020
+#: fortran/resolve.c:7026
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:7033
+#: fortran/resolve.c:7039
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr ""
 
-#: fortran/resolve.c:7136 fortran/resolve.c:7428
+#: fortran/resolve.c:7142 fortran/resolve.c:7434
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:7144 fortran/resolve.c:7393
+#: fortran/resolve.c:7150 fortran/resolve.c:7399
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7250
+#: fortran/resolve.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7281
+#: fortran/resolve.c:7287
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.c:7439
+#: fortran/resolve.c:7445
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.c:7451
+#: fortran/resolve.c:7457
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.c:7465
+#: fortran/resolve.c:7471
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7480
+#: fortran/resolve.c:7486
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7493
+#: fortran/resolve.c:7499
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.c:7511
+#: fortran/resolve.c:7517
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.c:7592 fortran/resolve.c:7607
+#: fortran/resolve.c:7598 fortran/resolve.c:7613
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7599
+#: fortran/resolve.c:7605
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7622
+#: fortran/resolve.c:7628
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7649
+#: fortran/resolve.c:7655
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7668
+#: fortran/resolve.c:7674
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.c:7683
+#: fortran/resolve.c:7689
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7694
+#: fortran/resolve.c:7700
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7726
+#: fortran/resolve.c:7732
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:7749
+#: fortran/resolve.c:7755
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:7760
+#: fortran/resolve.c:7766
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.c:7771
+#: fortran/resolve.c:7782
 #, gcc-internal-format, gfc-internal-format
-msgid "Errmsg-variable at %L must be a scalar CHARACTER variable"
+msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:7794
+#: fortran/resolve.c:7805
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:7824
+#: fortran/resolve.c:7835
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.c:7830 fortran/resolve.c:7836
+#: fortran/resolve.c:7841 fortran/resolve.c:7847
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -59281,232 +59359,232 @@
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8064
+#: fortran/resolve.c:8075
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr ""
 
-#: fortran/resolve.c:8115
+#: fortran/resolve.c:8126
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr ""
 
-#: fortran/resolve.c:8126
+#: fortran/resolve.c:8137
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr ""
 
-#: fortran/resolve.c:8139
+#: fortran/resolve.c:8150
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:8185
+#: fortran/resolve.c:8196
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr ""
 
-#: fortran/resolve.c:8204
+#: fortran/resolve.c:8215
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr ""
 
-#: fortran/resolve.c:8214
+#: fortran/resolve.c:8225
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr ""
 
-#: fortran/resolve.c:8232 fortran/resolve.c:8240
+#: fortran/resolve.c:8243 fortran/resolve.c:8251
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr ""
 
-#: fortran/resolve.c:8302 fortran/resolve.c:8873
+#: fortran/resolve.c:8313 fortran/resolve.c:8884
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr ""
 
-#: fortran/resolve.c:8328
+#: fortran/resolve.c:8339
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:8340
+#: fortran/resolve.c:8351
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:8355
+#: fortran/resolve.c:8366
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr ""
 
-#: fortran/resolve.c:8458
+#: fortran/resolve.c:8469
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr ""
 
-#: fortran/resolve.c:8518
+#: fortran/resolve.c:8529
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr ""
 
-#: fortran/resolve.c:8523
+#: fortran/resolve.c:8534
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr ""
 
-#: fortran/resolve.c:8545
+#: fortran/resolve.c:8556
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.c:8556
+#: fortran/resolve.c:8567
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:8763
+#: fortran/resolve.c:8774
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8783 fortran/resolve.c:8795
+#: fortran/resolve.c:8794 fortran/resolve.c:8806
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.c:8824
+#: fortran/resolve.c:8835
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr ""
 
-#: fortran/resolve.c:8836
+#: fortran/resolve.c:8847
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr ""
 
-#: fortran/resolve.c:8848
+#: fortran/resolve.c:8859
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr ""
 
-#: fortran/resolve.c:8851
+#: fortran/resolve.c:8862
 #, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:8861
+#: fortran/resolve.c:8872
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.c:9108
+#: fortran/resolve.c:9119
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9204
+#: fortran/resolve.c:9215
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr ""
 
-#: fortran/resolve.c:9257
+#: fortran/resolve.c:9268
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr ""
 
-#: fortran/resolve.c:9267
+#: fortran/resolve.c:9278
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9280
+#: fortran/resolve.c:9291
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9289
+#: fortran/resolve.c:9300
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr ""
 
-#: fortran/resolve.c:9296
+#: fortran/resolve.c:9307
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9307
+#: fortran/resolve.c:9318
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr ""
 
-#: fortran/resolve.c:9313
+#: fortran/resolve.c:9324
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9328
+#: fortran/resolve.c:9339
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:9388
+#: fortran/resolve.c:9399
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:9398
+#: fortran/resolve.c:9409
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:9402
+#: fortran/resolve.c:9413
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr ""
 
-#: fortran/resolve.c:9405
+#: fortran/resolve.c:9416
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr ""
 
-#: fortran/resolve.c:9412 fortran/resolve.c:9533
+#: fortran/resolve.c:9423 fortran/resolve.c:9545
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:9424 fortran/resolve.c:9540
+#: fortran/resolve.c:9435 fortran/resolve.c:9553
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:9436
+#: fortran/resolve.c:9447
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr ""
 
-#: fortran/resolve.c:9449
+#: fortran/resolve.c:9460
 #, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:9510
+#: fortran/resolve.c:9521
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:9514 fortran/resolve.c:9524
+#: fortran/resolve.c:9525 fortran/resolve.c:9535
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr ""
 
-#: fortran/resolve.c:9567
+#: fortran/resolve.c:9580
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9577
+#: fortran/resolve.c:9590
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr ""
@@ -59513,12 +59591,12 @@
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:9594 fortran/resolve.c:9617
+#: fortran/resolve.c:9607 fortran/resolve.c:9630
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.c:9598 fortran/resolve.c:9623
+#: fortran/resolve.c:9611 fortran/resolve.c:9636
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -59526,107 +59604,107 @@
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:9638
+#: fortran/resolve.c:9651
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9710
+#: fortran/resolve.c:9723
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:9726
+#: fortran/resolve.c:9739
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:9734 fortran/resolve.c:9821
+#: fortran/resolve.c:9747 fortran/resolve.c:9834
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:9744 fortran/resolve.c:9831
+#: fortran/resolve.c:9757 fortran/resolve.c:9844
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:9775
+#: fortran/resolve.c:9788
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:9784
+#: fortran/resolve.c:9797
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr ""
 
-#: fortran/resolve.c:9949
+#: fortran/resolve.c:9962
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr ""
 
-#: fortran/resolve.c:9959
+#: fortran/resolve.c:9972
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr ""
 
-#: fortran/resolve.c:10036
+#: fortran/resolve.c:10049
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr ""
 
-#: fortran/resolve.c:10138
+#: fortran/resolve.c:10151
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:10251
+#: fortran/resolve.c:10264
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr ""
 
-#: fortran/resolve.c:10283
+#: fortran/resolve.c:10296
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:10288
+#: fortran/resolve.c:10301
 #, gcc-internal-format, gfc-internal-format
 msgid "The impure variable at %L is assigned to a derived type variable with a POINTER component in a PURE procedure (12.6)"
 msgstr ""
 
-#: fortran/resolve.c:10298
+#: fortran/resolve.c:10311
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:10330
+#: fortran/resolve.c:10343
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:10334
+#: fortran/resolve.c:10347
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:10339
+#: fortran/resolve.c:10352
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.c:10346
+#: fortran/resolve.c:10359
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr ""
 
-#: fortran/resolve.c:10357
+#: fortran/resolve.c:10370
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:10663
+#: fortran/resolve.c:10683
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
@@ -59633,67 +59711,67 @@
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:10905
+#: fortran/resolve.c:10925
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:10917
+#: fortran/resolve.c:10937
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr ""
 
-#: fortran/resolve.c:11157
+#: fortran/resolve.c:11177
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:11160
+#: fortran/resolve.c:11180
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr ""
 
-#: fortran/resolve.c:11171
+#: fortran/resolve.c:11191
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr ""
 
-#: fortran/resolve.c:11233
+#: fortran/resolve.c:11253
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:11278
+#: fortran/resolve.c:11298
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid NULL at %L"
 msgstr ""
 
-#: fortran/resolve.c:11282
+#: fortran/resolve.c:11302
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:11339
+#: fortran/resolve.c:11359
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:11344
+#: fortran/resolve.c:11364
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:11428
+#: fortran/resolve.c:11448
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:11507
+#: fortran/resolve.c:11527
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr ""
 
-#: fortran/resolve.c:11617
+#: fortran/resolve.c:11637
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
@@ -59700,7 +59778,7 @@
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:11630
+#: fortran/resolve.c:11650
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr ""
@@ -59708,57 +59786,57 @@
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:11647
+#: fortran/resolve.c:11667
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.c:11732
+#: fortran/resolve.c:11752
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr ""
 
-#: fortran/resolve.c:11961
+#: fortran/resolve.c:11981
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:11965
+#: fortran/resolve.c:11985
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:11973
+#: fortran/resolve.c:11993
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:11983
+#: fortran/resolve.c:12003
 #, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:11998
+#: fortran/resolve.c:12018
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.c:12010
+#: fortran/resolve.c:12030
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.c:12041
+#: fortran/resolve.c:12061
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.c:12063
+#: fortran/resolve.c:12083
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
 
-#: fortran/resolve.c:12090
+#: fortran/resolve.c:12110
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
@@ -59765,887 +59843,892 @@
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12131
+#: fortran/resolve.c:12151
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr ""
 
-#: fortran/resolve.c:12150
+#: fortran/resolve.c:12170
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr ""
 
-#: fortran/resolve.c:12171
+#: fortran/resolve.c:12191
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr ""
 
-#: fortran/resolve.c:12178
+#: fortran/resolve.c:12198
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr ""
 
-#: fortran/resolve.c:12225
+#: fortran/resolve.c:12245
 #, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12228
+#: fortran/resolve.c:12248
 #, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12232
+#: fortran/resolve.c:12252
 #, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12235
+#: fortran/resolve.c:12255
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12238
+#: fortran/resolve.c:12258
 #, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12241
+#: fortran/resolve.c:12261
 #, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12283
+#: fortran/resolve.c:12303
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L"
 msgstr ""
 
-#: fortran/resolve.c:12310
+#: fortran/resolve.c:12330
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:12332
+#: fortran/resolve.c:12352
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:12354
+#: fortran/resolve.c:12374
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.c:12372
+#: fortran/resolve.c:12392
 #, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12381
+#: fortran/resolve.c:12401
 #, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12389
+#: fortran/resolve.c:12409
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr ""
 
-#: fortran/resolve.c:12399
+#: fortran/resolve.c:12419
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr ""
 
-#: fortran/resolve.c:12418
+#: fortran/resolve.c:12438
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr ""
 
-#: fortran/resolve.c:12422
+#: fortran/resolve.c:12442
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr ""
 
-#: fortran/resolve.c:12426
+#: fortran/resolve.c:12446
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr ""
 
-#: fortran/resolve.c:12430
+#: fortran/resolve.c:12450
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr ""
 
-#: fortran/resolve.c:12443
+#: fortran/resolve.c:12463
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12452
+#: fortran/resolve.c:12472
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:12458
+#: fortran/resolve.c:12478
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:12470
+#: fortran/resolve.c:12490
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:12527
+#: fortran/resolve.c:12547
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12533
+#: fortran/resolve.c:12553
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12539
+#: fortran/resolve.c:12559
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12547
+#: fortran/resolve.c:12567
 #, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12553
+#: fortran/resolve.c:12573
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.c:12596
+#: fortran/resolve.c:12616
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12604
+#: fortran/resolve.c:12624
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12612
+#: fortran/resolve.c:12632
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12621
+#: fortran/resolve.c:12641
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.c:12705
+#: fortran/resolve.c:12725
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:12714
+#: fortran/resolve.c:12734
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr ""
 
-#: fortran/resolve.c:12723
+#: fortran/resolve.c:12743
 #, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr ""
 
-#: fortran/resolve.c:12731
+#: fortran/resolve.c:12751
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:12737
+#: fortran/resolve.c:12757
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:12743
+#: fortran/resolve.c:12763
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr ""
 
-#: fortran/resolve.c:12751
+#: fortran/resolve.c:12771
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:12760
+#: fortran/resolve.c:12780
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr ""
 
-#: fortran/resolve.c:12782
+#: fortran/resolve.c:12802
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr ""
 
-#: fortran/resolve.c:12819
+#: fortran/resolve.c:12839
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr ""
 
-#: fortran/resolve.c:12859
+#: fortran/resolve.c:12879
 #, gcc-internal-format
 msgid "%qs and %qs can't be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12895
+#: fortran/resolve.c:12915
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.c:12954
+#: fortran/resolve.c:12974
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12966
+#: fortran/resolve.c:12986
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.c:12994
+#: fortran/resolve.c:13014
 #, gcc-internal-format
 msgid "GENERIC %qs at %L can't overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.c:13050
+#: fortran/resolve.c:13070
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L can't be NOPASS"
 msgstr ""
 
-#: fortran/resolve.c:13242
+#: fortran/resolve.c:13262
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr ""
 
-#: fortran/resolve.c:13284
+#: fortran/resolve.c:13304
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:13298
+#: fortran/resolve.c:13318
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:13312 fortran/resolve.c:13778
+#: fortran/resolve.c:13332 fortran/resolve.c:13798
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13320
+#: fortran/resolve.c:13340
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr ""
 
-#: fortran/resolve.c:13329
+#: fortran/resolve.c:13349
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:13335
+#: fortran/resolve.c:13355
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13341
+#: fortran/resolve.c:13361
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr ""
 
-#: fortran/resolve.c:13370
+#: fortran/resolve.c:13390
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:13380
+#: fortran/resolve.c:13400
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:13472
+#: fortran/resolve.c:13492
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.c:13574
+#: fortran/resolve.c:13594
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:13583
+#: fortran/resolve.c:13603
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13593
+#: fortran/resolve.c:13613
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.c:13602
+#: fortran/resolve.c:13622
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.c:13613
+#: fortran/resolve.c:13633
 #, gcc-internal-format
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.c:13711
+#: fortran/resolve.c:13731
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:13725
+#: fortran/resolve.c:13745
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:13741
+#: fortran/resolve.c:13761
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:13751
+#: fortran/resolve.c:13771
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:13760
+#: fortran/resolve.c:13780
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:13769
+#: fortran/resolve.c:13789
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13811
+#: fortran/resolve.c:13831
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr ""
 
-#: fortran/resolve.c:13824
+#: fortran/resolve.c:13844
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr ""
 
-#: fortran/resolve.c:13835
+#: fortran/resolve.c:13855
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13868
+#: fortran/resolve.c:13888
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:13876
+#: fortran/resolve.c:13896
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.c:13885
+#: fortran/resolve.c:13905
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr ""
 
-#: fortran/resolve.c:13903 fortran/resolve.c:13915
+#: fortran/resolve.c:13923 fortran/resolve.c:13935
 #, gcc-internal-format
 msgid "The pointer component %qs of %qs at %L is a type that has not been declared"
 msgstr ""
 
-#: fortran/resolve.c:13989
+#: fortran/resolve.c:14009
 #, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr ""
 
-#: fortran/resolve.c:14034
+#: fortran/resolve.c:14054
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.c:14047
+#: fortran/resolve.c:14067
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr ""
 
-#: fortran/resolve.c:14111
+#: fortran/resolve.c:14131
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14144
+#: fortran/resolve.c:14164
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.c:14216
+#: fortran/resolve.c:14236
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:14222
+#: fortran/resolve.c:14242
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14228
+#: fortran/resolve.c:14248
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14236
+#: fortran/resolve.c:14256
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14253
+#: fortran/resolve.c:14273
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14275
+#: fortran/resolve.c:14295
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14286
+#: fortran/resolve.c:14306
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14313
+#: fortran/resolve.c:14333
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14337
+#: fortran/resolve.c:14357
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:14353
+#: fortran/resolve.c:14373
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:14364
+#: fortran/resolve.c:14384
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr ""
 
-#: fortran/resolve.c:14372
+#: fortran/resolve.c:14392
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr ""
 
-#: fortran/resolve.c:14423
+#: fortran/resolve.c:14443
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr ""
 
-#: fortran/resolve.c:14434
+#: fortran/resolve.c:14454
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.c:14441
+#: fortran/resolve.c:14461
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.c:14480
+#: fortran/resolve.c:14500
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:14544
+#: fortran/resolve.c:14564
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:14547
+#: fortran/resolve.c:14567
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:14643
+#: fortran/resolve.c:14663
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:14664
+#: fortran/resolve.c:14684
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr ""
 
-#: fortran/resolve.c:14677
+#: fortran/resolve.c:14697
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14680
+#: fortran/resolve.c:14700
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14688
+#: fortran/resolve.c:14708
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14695
+#: fortran/resolve.c:14715
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:14708
+#: fortran/resolve.c:14728
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr ""
 
-#: fortran/resolve.c:14714
+#: fortran/resolve.c:14734
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14724
+#: fortran/resolve.c:14744
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:14733
+#: fortran/resolve.c:14753
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.c:14746 fortran/resolve.c:14923
+#: fortran/resolve.c:14766 fortran/resolve.c:14943
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.c:14760
+#: fortran/resolve.c:14780
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14769
+#: fortran/resolve.c:14789
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:14778
+#: fortran/resolve.c:14798
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14786
+#: fortran/resolve.c:14806
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:14793
+#: fortran/resolve.c:14813
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:14813
+#: fortran/resolve.c:14833
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.c:14820
+#: fortran/resolve.c:14840
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14827
+#: fortran/resolve.c:14847
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:14834
+#: fortran/resolve.c:14854
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:14860
+#: fortran/resolve.c:14880
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:14870
+#: fortran/resolve.c:14890
 #, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.c:14949
+#: fortran/resolve.c:14969
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:14964
+#: fortran/resolve.c:14984
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14977
+#: fortran/resolve.c:14997
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14995
+#: fortran/resolve.c:15015
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.c:15007
+#: fortran/resolve.c:15027
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:15016
+#: fortran/resolve.c:15036
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:15028
+#: fortran/resolve.c:15048
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr ""
 
-#: fortran/resolve.c:15037
+#: fortran/resolve.c:15057
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15049
+#: fortran/resolve.c:15069
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15065
+#: fortran/resolve.c:15085
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15073
+#: fortran/resolve.c:15093
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15080
+#: fortran/resolve.c:15100
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15092
+#: fortran/resolve.c:15112
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.c:15101
+#: fortran/resolve.c:15121
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15117
+#: fortran/resolve.c:15137
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15123
+#: fortran/resolve.c:15143
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15148
+#: fortran/resolve.c:15168
 #, gcc-internal-format
 msgid "Namelist %qs can not be an argument to subroutine or function at %L"
 msgstr ""
 
-#: fortran/resolve.c:15218
+#: fortran/resolve.c:15238
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:15229
+#: fortran/resolve.c:15249
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:15333
+#: fortran/resolve.c:15353
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:15339
+#: fortran/resolve.c:15359
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:15345
+#: fortran/resolve.c:15365
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.c:15354
+#: fortran/resolve.c:15374
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr ""
 
-#: fortran/resolve.c:15368
+#: fortran/resolve.c:15388
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:15414
+#: fortran/resolve.c:15434
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.c:15427
+#: fortran/resolve.c:15447
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.c:15526
+#: fortran/resolve.c:15546
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15534
+#: fortran/resolve.c:15554
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15542
+#: fortran/resolve.c:15562
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15667
+#: fortran/resolve.c:15687
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.c:15832
+#: fortran/resolve.c:15852
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr ""
 
-#: fortran/resolve.c:15838
+#: fortran/resolve.c:15858
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr ""
 
-#: fortran/resolve.c:15922
+#: fortran/resolve.c:15942
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15931
+#: fortran/resolve.c:15951
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15939
+#: fortran/resolve.c:15959
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:15955
+#: fortran/resolve.c:15975
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16058
+#: fortran/resolve.c:16078
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:16073
+#: fortran/resolve.c:16093
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:16098
+#: fortran/resolve.c:16118
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:16107
+#: fortran/resolve.c:16127
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16180
+#: fortran/resolve.c:16200
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16191
+#: fortran/resolve.c:16211
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16202
+#: fortran/resolve.c:16222
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr ""
 
-#: fortran/resolve.c:16293
+#: fortran/resolve.c:16253
 #, gcc-internal-format
+msgid "Self reference in character length expression for %qs at %L"
+msgstr ""
+
+#: fortran/resolve.c:16320
+#, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.c:16306
+#: fortran/resolve.c:16333
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:16326
+#: fortran/resolve.c:16353
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:16336
+#: fortran/resolve.c:16363
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr ""
 
-#: fortran/resolve.c:16344
+#: fortran/resolve.c:16371
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:16358
+#: fortran/resolve.c:16385
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:16376
+#: fortran/resolve.c:16403
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:16383
+#: fortran/resolve.c:16410
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr ""
 
-#: fortran/resolve.c:16461
+#: fortran/resolve.c:16488
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -60973,19 +61056,12 @@
 msgid "simplify_min_max(): Bad type in arglist"
 msgstr ""
 
-#. Result is processor-dependent.
-#: fortran/simplify.c:5472
-#, gcc-internal-format, gfc-internal-format
-msgid "Second argument MOD at %L is zero"
+#: fortran/simplify.c:5470 fortran/simplify.c:5478
+#, gcc-internal-format
+msgid "Argument %qs of MOD at %L shall not be zero"
 msgstr ""
 
-#. Result is processor-dependent.
-#: fortran/simplify.c:5483
-#, gcc-internal-format, gfc-internal-format
-msgid "Second argument of MOD at %L is zero"
-msgstr ""
-
-#: fortran/simplify.c:5494
+#: fortran/simplify.c:5484
 #, gcc-internal-format
 msgid "gfc_simplify_mod(): Bad arguments"
 msgstr ""
@@ -60993,97 +61069,97 @@
 #. Result is processor-dependent. This processor just opts
 #. to not handle it at all.
 #. Result is processor-dependent.
-#: fortran/simplify.c:5520 fortran/simplify.c:5532
+#: fortran/simplify.c:5525 fortran/simplify.c:5537
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of MODULO at %L is zero"
 msgstr ""
 
-#: fortran/simplify.c:5552
+#: fortran/simplify.c:5557
 #, gcc-internal-format
 msgid "gfc_simplify_modulo(): Bad arguments"
 msgstr ""
 
-#: fortran/simplify.c:5600
+#: fortran/simplify.c:5605
 #, gcc-internal-format, gfc-internal-format
 msgid "Result of NEAREST is NaN at %L"
 msgstr ""
 
-#: fortran/simplify.c:6081
+#: fortran/simplify.c:6086
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative at %L"
 msgstr ""
 
-#: fortran/simplify.c:6137
+#: fortran/simplify.c:6142
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument NCOPIES of REPEAT intrinsic is too large at %L"
 msgstr ""
 
-#: fortran/simplify.c:6174
+#: fortran/simplify.c:6179
 #, gcc-internal-format, gfc-internal-format
 msgid "Evaluation of string longer than 2**28 at %L deferred to runtime, expect bugs"
 msgstr ""
 
-#: fortran/simplify.c:6302
+#: fortran/simplify.c:6307
 #, gcc-internal-format, gfc-internal-format
 msgid "Reshaped array too large at %C"
 msgstr ""
 
-#: fortran/simplify.c:6416
+#: fortran/simplify.c:6421
 #, gcc-internal-format, gfc-internal-format
 msgid "Result of SCALE overflows its kind at %L"
 msgstr ""
 
-#: fortran/simplify.c:6995
+#: fortran/simplify.c:7000
 #, gcc-internal-format
 msgid "Bad type in gfc_simplify_sign"
 msgstr ""
 
-#: fortran/simplify.c:7024
+#: fortran/simplify.c:7029
 #, gcc-internal-format
 msgid "in gfc_simplify_sin(): Bad type"
 msgstr ""
 
-#: fortran/simplify.c:7151 fortran/simplify.c:7431
+#: fortran/simplify.c:7156 fortran/simplify.c:7436
 #, gcc-internal-format
 msgid "Failure getting length of a constant array."
 msgstr ""
 
-#: fortran/simplify.c:7161
+#: fortran/simplify.c:7166
 #, gcc-internal-format
 msgid "The number of elements (%d) in the array constructor at %L requires an increase of the allowed %d upper limit.  See %<-fmax-array-constructor%> option."
 msgstr ""
 
-#: fortran/simplify.c:7227
+#: fortran/simplify.c:7232
 #, gcc-internal-format, gfc-internal-format
 msgid "Simplification of SPREAD at %C not yet implemented"
 msgstr ""
 
-#: fortran/simplify.c:7251
+#: fortran/simplify.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SQRT at %L has a negative value"
 msgstr ""
 
-#: fortran/simplify.c:7267
+#: fortran/simplify.c:7272
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid argument of SQRT at %L"
 msgstr ""
 
-#: fortran/simplify.c:7598
+#: fortran/simplify.c:7603
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY lower bound is %ld)"
 msgstr ""
 
-#: fortran/simplify.c:7621
+#: fortran/simplify.c:7626
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY upper bound is %ld)"
 msgstr ""
 
-#: fortran/simplify.c:7993
+#: fortran/simplify.c:7998
 #, gcc-internal-format
 msgid "gfc_convert_constant(): Unexpected type"
 msgstr ""
 
-#: fortran/simplify.c:8078
+#: fortran/simplify.c:8083
 #, gcc-internal-format
 msgid "Character %qs in string at %L cannot be converted into character kind %d"
 msgstr ""
@@ -61186,7 +61262,7 @@
 msgid "BIND(C) applied to %s %s at %L"
 msgstr ""
 
-#: fortran/symbol.c:901 fortran/symbol.c:912 fortran/symbol.c:1762
+#: fortran/symbol.c:901 fortran/symbol.c:912 fortran/symbol.c:1776
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute conflicts with %s attribute at %L"
 msgstr ""
@@ -61261,17 +61337,22 @@
 msgid "Duplicate VOLATILE attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1367
+#: fortran/symbol.c:1360
 #, gcc-internal-format, gfc-internal-format
+msgid "VOLATILE attribute at %L cannot be specified in a PURE procedure"
+msgstr ""
+
+#: fortran/symbol.c:1381
+#, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ASYNCHRONOUS attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1758
+#: fortran/symbol.c:1772
 #, gcc-internal-format
 msgid "%s attribute of %qs conflicts with %s attribute at %L"
 msgstr ""
 
-#: fortran/symbol.c:1794
+#: fortran/symbol.c:1808
 #, gcc-internal-format, gfc-internal-format
 msgid ""
 "%s procedure at %L is already declared as %s procedure. \n"
@@ -61278,208 +61359,208 @@
 "F2008: A pointer function assignment is ambiguous if it is the first executable statement after the specification block. Please add any other kind of executable statement before it. FIXME"
 msgstr ""
 
-#: fortran/symbol.c:1802
+#: fortran/symbol.c:1816
 #, gcc-internal-format, gfc-internal-format
 msgid "%s procedure at %L is already declared as %s procedure"
 msgstr ""
 
-#: fortran/symbol.c:1837
+#: fortran/symbol.c:1851
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgstr ""
 
-#: fortran/symbol.c:1861
+#: fortran/symbol.c:1875
 #, gcc-internal-format, gfc-internal-format
 msgid "ACCESS specification at %L was already specified"
 msgstr ""
 
-#: fortran/symbol.c:1878
+#: fortran/symbol.c:1892
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate BIND attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1885
+#: fortran/symbol.c:1899
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) at %L"
 msgstr ""
 
-#: fortran/symbol.c:1901
+#: fortran/symbol.c:1915
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate EXTENDS attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1905
+#: fortran/symbol.c:1919
 #, gcc-internal-format, gfc-internal-format
 msgid "EXTENDS at %L"
 msgstr ""
 
-#: fortran/symbol.c:1931
+#: fortran/symbol.c:1945
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has an explicit interface"
 msgstr ""
 
-#: fortran/symbol.c:1938
+#: fortran/symbol.c:1952
 #, gcc-internal-format
 msgid "%qs at %L has attributes specified outside its INTERFACE body"
 msgstr ""
 
-#: fortran/symbol.c:1976
+#: fortran/symbol.c:1990
 #, gcc-internal-format
 msgid "Symbol %qs at %L conflicts with symbol from module %qs, use-associated at %L"
 msgstr ""
 
-#: fortran/symbol.c:1980
+#: fortran/symbol.c:1994
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr ""
 
-#: fortran/symbol.c:1987
+#: fortran/symbol.c:2001
 #, gcc-internal-format
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr ""
 
-#: fortran/symbol.c:1999
+#: fortran/symbol.c:2013
 #, gcc-internal-format
 msgid "Symbol %qs at %L cannot have a type"
 msgstr ""
 
-#: fortran/symbol.c:2242
+#: fortran/symbol.c:2256
 #, gcc-internal-format
 msgid "Component %qs at %C already in the parent type at %L"
 msgstr ""
 
-#: fortran/symbol.c:2327
+#: fortran/symbol.c:2341
 #, gcc-internal-format
 msgid "Symbol %qs at %C is ambiguous"
 msgstr ""
 
-#: fortran/symbol.c:2359
+#: fortran/symbol.c:2373
 #, gcc-internal-format
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr ""
 
-#: fortran/symbol.c:2508
+#: fortran/symbol.c:2522
 #, gcc-internal-format
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr ""
 
-#: fortran/symbol.c:2529
+#: fortran/symbol.c:2543
 #, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure; did you mean %qs?"
 msgstr ""
 
-#: fortran/symbol.c:2533
+#: fortran/symbol.c:2547
 #, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr ""
 
-#: fortran/symbol.c:2697
+#: fortran/symbol.c:2711
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr ""
 
-#: fortran/symbol.c:2708
+#: fortran/symbol.c:2722
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr ""
 
-#: fortran/symbol.c:2718
+#: fortran/symbol.c:2732
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr ""
 
-#: fortran/symbol.c:2724
+#: fortran/symbol.c:2738
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:2766
+#: fortran/symbol.c:2780
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr ""
 
-#: fortran/symbol.c:2775
+#: fortran/symbol.c:2789
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr ""
 
-#: fortran/symbol.c:2781
+#: fortran/symbol.c:2795
 #, gcc-internal-format, gfc-internal-format
 msgid "Shared DO termination label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:3110
+#: fortran/symbol.c:3124
 #, gcc-internal-format
 msgid "new_symbol(): Symbol name too long"
 msgstr ""
 
-#: fortran/symbol.c:3135
+#: fortran/symbol.c:3149
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr ""
 
-#: fortran/symbol.c:3138
+#: fortran/symbol.c:3152
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
 msgstr ""
 
 #. Symbol is from another namespace.
-#: fortran/symbol.c:3381
+#: fortran/symbol.c:3395
 #, gcc-internal-format
 msgid "Symbol %qs at %C has already been host associated"
 msgstr ""
 
-#: fortran/symbol.c:4397
+#: fortran/symbol.c:4411
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr ""
 
-#: fortran/symbol.c:4410
+#: fortran/symbol.c:4424
 #, gcc-internal-format
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr ""
 
-#: fortran/symbol.c:4428
+#: fortran/symbol.c:4442
 #, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr ""
 
-#: fortran/symbol.c:4449
+#: fortran/symbol.c:4463
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:4459
+#: fortran/symbol.c:4473
 #, gcc-internal-format
 msgid "Procedure pointer component %qs at %L cannot be a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:4470
+#: fortran/symbol.c:4484
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:4509
+#: fortran/symbol.c:4523
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.c:4519
+#: fortran/symbol.c:4533
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/symbol.c:4533
+#: fortran/symbol.c:4547
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot be declared with both PRIVATE and BIND(C) attributes"
 msgstr ""
 
-#: fortran/symbol.c:4541
+#: fortran/symbol.c:4555
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.c:5018 fortran/symbol.c:5023
+#: fortran/symbol.c:5032 fortran/symbol.c:5037
 #, gcc-internal-format
 msgid "Symbol %qs is used before it is typed at %L"
 msgstr ""
@@ -61527,7 +61608,7 @@
 msgid "Creating array temporary at %L for argument %qs"
 msgstr ""
 
-#: fortran/trans-array.c:10693
+#: fortran/trans-array.c:10724
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr ""
@@ -61729,12 +61810,12 @@
 msgid "%<dim%> argument of %s intrinsic at %L is not a valid dimension index"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:10572 fortran/trans-stmt.c:1050
+#: fortran/trans-intrinsic.c:10574 fortran/trans-stmt.c:1050
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, the event component of derived type at %L is not yet supported"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:10579
+#: fortran/trans-intrinsic.c:10581
 #, gcc-internal-format, gfc-internal-format
 msgid "The event variable at %L shall not be coindexed"
 msgstr ""
@@ -61774,7 +61855,7 @@
 msgid "Sorry, only support for integer kind %d implemented for image-set at %L"
 msgstr ""
 
-#: fortran/trans-stmt.c:3346
+#: fortran/trans-stmt.c:3343
 #, gcc-internal-format
 msgid "gfc_trans_select(): Bad type for case expr."
 msgstr ""
@@ -61901,7 +61982,7 @@
 msgid "two or more sections for %s"
 msgstr ""
 
-#: lto/lto-partition.c:516
+#: lto/lto-partition.c:570
 #, gcc-internal-format
 msgid "min partition size cannot be greater than max partition size"
 msgstr ""
@@ -62037,58 +62118,58 @@
 msgid "Cannot read %s"
 msgstr ""
 
-#: lto/lto.c:2369
+#: lto/lto.c:2337
 #, gcc-internal-format
 msgid "lto_obj_file_open() failed"
 msgstr ""
 
-#: lto/lto.c:2394
+#: lto/lto.c:2362
 #, fuzzy, gcc-internal-format
 #| msgid "pex_init failed"
 msgid "waitpid failed"
 msgstr "pex_init nije uspio"
 
-#: lto/lto.c:2397
+#: lto/lto.c:2365
 #, gcc-internal-format
 msgid "streaming subprocess failed"
 msgstr ""
 
-#: lto/lto.c:2400
+#: lto/lto.c:2368
 #, gcc-internal-format
 msgid "streaming subprocess was killed by signal"
 msgstr ""
 
-#: lto/lto.c:2476
+#: lto/lto.c:2445
 #, gcc-internal-format
 msgid "no LTRANS output list filename provided"
 msgstr ""
 
-#: lto/lto.c:2564
+#: lto/lto.c:2525
 #, gcc-internal-format
 msgid "opening LTRANS output list %s: %m"
 msgstr ""
 
-#: lto/lto.c:2570
+#: lto/lto.c:2532
 #, gcc-internal-format
 msgid "writing to LTRANS output list %s: %m"
 msgstr ""
 
-#: lto/lto.c:2581
+#: lto/lto.c:2542
 #, gcc-internal-format
 msgid "closing LTRANS output list %s: %m"
 msgstr ""
 
-#: lto/lto.c:2833
+#: lto/lto.c:2794
 #, gcc-internal-format
 msgid "could not open symbol resolution file: %m"
 msgstr ""
 
-#: lto/lto.c:2954
+#: lto/lto.c:2915
 #, gcc-internal-format, gfc-internal-format
 msgid "missing resolution data for %s"
 msgstr ""
 
-#: lto/lto.c:2986
+#: lto/lto.c:2947
 #, gcc-internal-format
 msgid "errors during merging of translation units"
 msgstr ""
Index: gcc/po/nl.po
===================================================================
--- gcc/po/nl.po	(.../tags/gcc_8_2_0_release)
+++ gcc/po/nl.po	(.../branches/gcc-8-branch)
@@ -8,7 +8,7 @@
 msgstr ""
 "Project-Id-Version: gcc 4.9-b20140202\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2018-05-01 20:30+0000\n"
+"POT-Creation-Date: 2018-07-25 14:25+0000\n"
 "PO-Revision-Date: 2014-02-05 12:25+0100\n"
 "Last-Translator: Benno Schulenberg <benno@vertaalt.nl>\n"
 "Language-Team: Dutch <vertaling@vrijschrift.org>\n"
@@ -42,12 +42,12 @@
 msgid "[cannot find %s]"
 msgstr "[kan %s niet vinden]"
 
-#: collect2.c:1557
+#: collect2.c:1585
 #, c-format
 msgid "collect2 version %s\n"
 msgstr "collect2 versie %s\n"
 
-#: collect2.c:1664
+#: collect2.c:1692
 #, c-format
 msgid "%d constructor found\n"
 msgid_plural "%d constructors found\n"
@@ -54,7 +54,7 @@
 msgstr[0] "%d constructor gevonden\n"
 msgstr[1] "%d constructors gevonden\n"
 
-#: collect2.c:1668
+#: collect2.c:1696
 #, c-format
 msgid "%d destructor found\n"
 msgid_plural "%d destructors found\n"
@@ -61,7 +61,7 @@
 msgstr[0] "%d destructor gevonden\n"
 msgstr[1] "%d destructors gevonden\n"
 
-#: collect2.c:1672
+#: collect2.c:1700
 #, c-format
 msgid "%d frame table found\n"
 msgid_plural "%d frame tables found\n"
@@ -68,12 +68,12 @@
 msgstr[0] "%d frame-tabel gevonden\n"
 msgstr[1] "%d frame-tabellen gevonden\n"
 
-#: collect2.c:1836
+#: collect2.c:1864
 #, c-format
 msgid "[Leaving %s]\n"
 msgstr "[%s wordt verlaten]\n"
 
-#: collect2.c:2068
+#: collect2.c:2094
 #, c-format
 msgid ""
 "\n"
@@ -82,7 +82,7 @@
 "\n"
 "write_c_file - uitvoernaam is %s, prefix is %s\n"
 
-#: collect2.c:2584
+#: collect2.c:2610
 #, c-format
 msgid ""
 "\n"
@@ -105,7 +105,7 @@
 msgid "%s: some warnings being treated as errors"
 msgstr "%s: sommige waarschuwingen worden als fouten behandeld"
 
-#: diagnostic.c:324 input.c:222 input.c:1834 c-family/c-opts.c:1377
+#: diagnostic.c:324 input.c:222 input.c:1834 c-family/c-opts.c:1392
 #: fortran/cpp.c:576 fortran/error.c:1008 fortran/error.c:1028
 msgid "<built-in>"
 msgstr "<ingebouwd>"
@@ -195,13 +195,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:4164 config/arc/arc.c:5784 config/i386/i386.c:17302
+#: final.c:4164 config/arc/arc.c:5775 config/i386/i386.c:17305
 #: config/pdp11/pdp11.c:1715
 #, c-format
 msgid "floating constant misused"
 msgstr "floating-point constante verkeerd gebruikt"
 
-#: final.c:4222 config/arc/arc.c:5881 config/i386/i386.c:17393
+#: final.c:4222 config/arc/arc.c:5872 config/i386/i386.c:17396
 #: config/pdp11/pdp11.c:1756
 #, c-format
 msgid "invalid expression as operand"
@@ -1082,7 +1082,7 @@
 msgid "GCSE disabled"
 msgstr "GCSE is uitgeschakeld"
 
-#: gimple-ssa-isolate-paths.c:542 c/c-typeck.c:10240
+#: gimple-ssa-isolate-paths.c:542 c/c-typeck.c:10245
 #, gcc-internal-format
 msgid "function returns address of local variable"
 msgstr "functie geeft adres van lokale variabele terug"
@@ -1394,7 +1394,7 @@
 msgid "options enabled: "
 msgstr "ingeschakelde opties: "
 
-#: tree-diagnostic.c:299 c/c-decl.c:5419 c/c-typeck.c:7259 cp/error.c:1042
+#: tree-diagnostic.c:299 c/c-decl.c:5439 c/c-typeck.c:7264 cp/error.c:1042
 #: c-family/c-pretty-print.c:413
 #, gcc-internal-format
 msgid "<anonymous>"
@@ -2865,66 +2865,66 @@
 msgstr "lengte-modifier in strfmon-formaat"
 
 #. Handle deferred options from command-line.
-#: c-family/c-opts.c:1402 fortran/cpp.c:590
+#: c-family/c-opts.c:1417 fortran/cpp.c:590
 msgid "<command-line>"
 msgstr "<opdrachtregel>"
 
-#: config/aarch64/aarch64.c:6613
+#: config/aarch64/aarch64.c:6629
 #, fuzzy, c-format
 msgid "unsupported operand for code '%c'"
 msgstr "ongeldige operand voor code '%c'"
 
-#: config/aarch64/aarch64.c:6624 config/aarch64/aarch64.c:6640
-#: config/aarch64/aarch64.c:6652 config/aarch64/aarch64.c:6663
-#: config/aarch64/aarch64.c:6673 config/aarch64/aarch64.c:6694
-#: config/aarch64/aarch64.c:6764 config/aarch64/aarch64.c:6775
-#: config/aarch64/aarch64.c:6789 config/aarch64/aarch64.c:7011
-#: config/aarch64/aarch64.c:7029
+#: config/aarch64/aarch64.c:6640 config/aarch64/aarch64.c:6656
+#: config/aarch64/aarch64.c:6668 config/aarch64/aarch64.c:6679
+#: config/aarch64/aarch64.c:6689 config/aarch64/aarch64.c:6710
+#: config/aarch64/aarch64.c:6780 config/aarch64/aarch64.c:6791
+#: config/aarch64/aarch64.c:6805 config/aarch64/aarch64.c:7027
+#: config/aarch64/aarch64.c:7045
 #, c-format
 msgid "invalid operand for '%%%c'"
 msgstr "ongeldige operand voor '%%%c'"
 
-#: config/aarch64/aarch64.c:6709 config/aarch64/aarch64.c:6720
-#: config/aarch64/aarch64.c:6871 config/aarch64/aarch64.c:6882
+#: config/aarch64/aarch64.c:6725 config/aarch64/aarch64.c:6736
+#: config/aarch64/aarch64.c:6887 config/aarch64/aarch64.c:6898
 #, fuzzy, c-format
 #| msgid "invalid constant"
 msgid "invalid vector constant"
 msgstr "ongeldige constante"
 
-#: config/aarch64/aarch64.c:6732 config/aarch64/aarch64.c:6744
-#: config/aarch64/aarch64.c:6755
+#: config/aarch64/aarch64.c:6748 config/aarch64/aarch64.c:6760
+#: config/aarch64/aarch64.c:6771
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6823 config/arm/arm.c:22704
+#: config/aarch64/aarch64.c:6839 config/arm/arm.c:22704
 #, c-format
 msgid "missing operand"
 msgstr "operand ontbreekt"
 
-#: config/aarch64/aarch64.c:6908
+#: config/aarch64/aarch64.c:6924
 #, c-format
 msgid "invalid constant"
 msgstr "ongeldige constante"
 
-#: config/aarch64/aarch64.c:6911
+#: config/aarch64/aarch64.c:6927
 #, c-format
 msgid "invalid operand"
 msgstr "ongeldige operand"
 
-#: config/aarch64/aarch64.c:7040 config/aarch64/aarch64.c:7045
+#: config/aarch64/aarch64.c:7056 config/aarch64/aarch64.c:7061
 #, c-format
 msgid "invalid operand prefix '%%%c'"
 msgstr "ongeldige operandprefix '%%%c'"
 
-#: config/aarch64/aarch64.c:7062
+#: config/aarch64/aarch64.c:7078
 #, fuzzy, c-format
 #| msgid "invalid addressing mode"
 msgid "invalid address mode"
 msgstr "ongeldige adresseringsmodus"
 
-#: config/alpha/alpha.c:5125 config/i386/i386.c:18558
-#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21798
+#: config/alpha/alpha.c:5125 config/i386/i386.c:18561
+#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21875
 #: config/sparc/sparc.c:9290
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
@@ -2941,7 +2941,7 @@
 msgstr "ongeldige waarde voor %%r"
 
 #: config/alpha/alpha.c:5223 config/ia64/ia64.c:5534
-#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21506
+#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21583
 #: config/xtensa/xtensa.c:2429
 #, c-format
 msgid "invalid %%R value"
@@ -2948,13 +2948,13 @@
 msgstr "ongeldige waarde voor %%R"
 
 #: config/alpha/alpha.c:5229 config/powerpcspe/powerpcspe.c:23933
-#: config/rs6000/rs6000.c:21426 config/xtensa/xtensa.c:2396
+#: config/rs6000/rs6000.c:21503 config/xtensa/xtensa.c:2396
 #, c-format
 msgid "invalid %%N value"
 msgstr "ongeldige waarde voor %%N"
 
 #: config/alpha/alpha.c:5237 config/powerpcspe/powerpcspe.c:23961
-#: config/rs6000/rs6000.c:21454
+#: config/rs6000/rs6000.c:21531
 #, c-format
 msgid "invalid %%P value"
 msgstr "ongeldige waarde voor %%P"
@@ -2985,7 +2985,7 @@
 msgstr "ongeldige waarde voor %%U"
 
 #: config/alpha/alpha.c:5323 config/powerpcspe/powerpcspe.c:24021
-#: config/rs6000/rs6000.c:21514
+#: config/rs6000/rs6000.c:21591
 #, c-format
 msgid "invalid %%s value"
 msgstr "ongeldige waarde voor %%s"
@@ -2996,7 +2996,7 @@
 msgstr "ongeldige waarde voor %%C"
 
 #: config/alpha/alpha.c:5371 config/powerpcspe/powerpcspe.c:23797
-#: config/rs6000/rs6000.c:21290
+#: config/rs6000/rs6000.c:21367
 #, c-format
 msgid "invalid %%E value"
 msgstr "ongeldige waarde voor %%E"
@@ -3008,7 +3008,7 @@
 msgstr "onbekende 'unspec' relocatie"
 
 #: config/alpha/alpha.c:5405 config/cr16/cr16.c:1569
-#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21803
+#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21880
 #: config/spu/spu.c:1458
 #, c-format
 msgid "invalid %%xn code"
@@ -3019,58 +3019,58 @@
 msgid "invalid operand address"
 msgstr "Ongeldige modus voor gen_tst_reg"
 
-#: config/arc/arc.c:3810
+#: config/arc/arc.c:3808
 #, c-format
 msgid "invalid operand to %%Z code"
 msgstr "ongeldige operand voor %%Z-code"
 
-#: config/arc/arc.c:3818
+#: config/arc/arc.c:3816
 #, c-format
 msgid "invalid operand to %%z code"
 msgstr "ongeldige operand voor %%z-code"
 
-#: config/arc/arc.c:3826
+#: config/arc/arc.c:3824
 #, fuzzy, c-format
 #| msgid "invalid operand to %%Z code"
 msgid "invalid operands to %%c code"
 msgstr "ongeldige operand voor %%Z-code"
 
-#: config/arc/arc.c:3834
+#: config/arc/arc.c:3832
 #, c-format
 msgid "invalid operand to %%M code"
 msgstr "ongeldige operand voor %%M-code"
 
-#: config/arc/arc.c:3842 config/m32r/m32r.c:2100
+#: config/arc/arc.c:3840 config/m32r/m32r.c:2100
 #, c-format
 msgid "invalid operand to %%p code"
 msgstr "ongeldige operand voor %%p-code"
 
-#: config/arc/arc.c:3853 config/m32r/m32r.c:2093
+#: config/arc/arc.c:3851 config/m32r/m32r.c:2093
 #, c-format
 msgid "invalid operand to %%s code"
 msgstr "ongeldige operand voor %%s-code"
 
-#: config/arc/arc.c:4001 config/m32r/m32r.c:2126
+#: config/arc/arc.c:3999 config/m32r/m32r.c:2126
 #, c-format
 msgid "invalid operand to %%R code"
 msgstr "ongeldige operand voor %%R-code"
 
-#: config/arc/arc.c:4077 config/m32r/m32r.c:2149
+#: config/arc/arc.c:4075 config/m32r/m32r.c:2149
 #, c-format
 msgid "invalid operand to %%H/%%L code"
 msgstr "ongeldige operand voor %%H/%%L-code"
 
-#: config/arc/arc.c:4145 config/m32r/m32r.c:2220
+#: config/arc/arc.c:4143 config/m32r/m32r.c:2220
 #, c-format
 msgid "invalid operand to %%U code"
 msgstr "ongeldige operand voor %%U-code"
 
-#: config/arc/arc.c:4157
+#: config/arc/arc.c:4155
 #, c-format
 msgid "invalid operand to %%V code"
 msgstr "ongeldige operand voor %%V-code"
 
-#: config/arc/arc.c:4214
+#: config/arc/arc.c:4212
 #, c-format
 msgid "invalid operand to %%O code"
 msgstr "ongeldige operand voor %%O-code"
@@ -3077,19 +3077,19 @@
 
 #. Unknown flag.
 #. Undocumented flag.
-#: config/arc/arc.c:4240 config/epiphany/epiphany.c:1305
-#: config/m32r/m32r.c:2247 config/nds32/nds32.c:3079 config/sparc/sparc.c:9569
+#: config/arc/arc.c:4238 config/epiphany/epiphany.c:1305
+#: config/m32r/m32r.c:2247 config/nds32/nds32.c:3080 config/sparc/sparc.c:9569
 #, c-format
 msgid "invalid operand output code"
 msgstr "ongeldige code voor operanduitvoer"
 
-#: config/arc/arc.c:5869
+#: config/arc/arc.c:5860
 #, c-format
 msgid "invalid UNSPEC as operand: %d"
 msgstr "ongeldige UNSPEC als operand: %d"
 
 # betere vertaling voor "supposed"?  "denkelijk"?
-#: config/arc/arc.c:6158 config/cris/cris.c:2568
+#: config/arc/arc.c:6149 config/cris/cris.c:2568
 msgid "unrecognized supposed constant"
 msgstr "vermoedelijke constante niet herkend"
 
@@ -3125,7 +3125,7 @@
 #: config/arm/arm.c:22685 config/arm/arm.c:22692 config/bfin/bfin.c:1441
 #: config/bfin/bfin.c:1448 config/bfin/bfin.c:1455 config/bfin/bfin.c:1462
 #: config/bfin/bfin.c:1471 config/bfin/bfin.c:1478 config/bfin/bfin.c:1485
-#: config/bfin/bfin.c:1492 config/nds32/nds32.c:3098
+#: config/bfin/bfin.c:1492 config/nds32/nds32.c:3099
 #, c-format
 msgid "invalid operand for code '%c'"
 msgstr "ongeldige operand voor code '%c'"
@@ -3472,99 +3472,99 @@
 msgid "bad output_condmove_single operand"
 msgstr "ongeldige output_condmove_single operand"
 
-#: config/i386/i386.c:17387
+#: config/i386/i386.c:17390
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "ongeldige UNSPEC als operand"
 
-#: config/i386/i386.c:17925
+#: config/i386/i386.c:17928
 #, fuzzy, c-format
 #| msgid "invalid use of %<restrict%>"
 msgid "invalid use of register '%s'"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: config/i386/i386.c:17930
+#: config/i386/i386.c:17933
 #, fuzzy, c-format
 msgid "invalid use of asm flag output"
 msgstr "ongeldige lvalue in toewijzing"
 
-#: config/i386/i386.c:18160
+#: config/i386/i386.c:18163
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr "ongeldige operand voor code '%c'"
 
-#: config/i386/i386.c:18195
+#: config/i386/i386.c:18198
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr "ongeldige operand voor code '%c'"
 
-#: config/i386/i386.c:18264
+#: config/i386/i386.c:18267
 #, fuzzy, c-format
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "ongeldige operand voor code '%c'"
 
-#: config/i386/i386.c:18269
+#: config/i386/i386.c:18272
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'Z'"
 msgstr "ongeldige operand voor code '%c'"
 
-#: config/i386/i386.c:18346
+#: config/i386/i386.c:18349
 #, fuzzy, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "operand is noch een constante, noch een conditiecode ⇒ ongeldige operandcode 'c'"
 
-#: config/i386/i386.c:18425
+#: config/i386/i386.c:18428
 #, fuzzy, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "operand is noch een constante, noch een conditiecode ⇒ ongeldige operandcode 'c'"
 
-#: config/i386/i386.c:18443
+#: config/i386/i386.c:18446
 #, fuzzy, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "operand is noch een constante, noch een conditiecode ⇒ ongeldige operandcode 'c'"
 
-#: config/i386/i386.c:18456
+#: config/i386/i386.c:18459
 #, fuzzy, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "operand is noch een constante, noch een conditiecode ⇒ ongeldige operandcode 'c'"
 
-#: config/i386/i386.c:18471
+#: config/i386/i386.c:18474
 #, fuzzy, c-format
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr "operand is noch een constante, noch een conditiecode ⇒ ongeldige operandcode 'c'"
 
-#: config/i386/i386.c:18499
+#: config/i386/i386.c:18502
 #, fuzzy, c-format
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr "operand is noch een constante, noch een conditiecode ⇒ ongeldige operandcode 'c'"
 
-#: config/i386/i386.c:18517
+#: config/i386/i386.c:18520
 #, fuzzy, c-format
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr "operand is noch een constante, noch een conditiecode ⇒ ongeldige operandcode 'c'"
 
-#: config/i386/i386.c:18540
+#: config/i386/i386.c:18543
 #, fuzzy, c-format
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "operand is noch een constante, noch een conditiecode ⇒ ongeldige operandcode 'c'"
 
-#: config/i386/i386.c:18626
+#: config/i386/i386.c:18629
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "ongeldige operand voor '%c'"
 
 # "constraints" hier te vertalen ("beperkingen"/"restricties") of niet?
-#: config/i386/i386.c:18688
+#: config/i386/i386.c:18691
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "ongeldige constraints voor operand"
 
-#: config/i386/i386.c:18738
+#: config/i386/i386.c:18741
 #, fuzzy, c-format
 msgid "invalid vector immediate"
 msgstr "Ongeldig token in expressie"
 
-#: config/i386/i386.c:29572
+#: config/i386/i386.c:29575
 msgid "unknown insn mode"
 msgstr "onbekende insn-modus"
 
@@ -3602,7 +3602,7 @@
 msgstr "ongeldige operand voor %%P"
 
 #: config/iq2000/iq2000.c:3185 config/powerpcspe/powerpcspe.c:23951
-#: config/rs6000/rs6000.c:21444
+#: config/rs6000/rs6000.c:21521
 #, c-format
 msgid "invalid %%p value"
 msgstr "ongeldige waarde voor %%p"
@@ -3660,7 +3660,7 @@
 msgstr "post-increment adres is geen register"
 
 #: config/m32r/m32r.c:2350 config/m32r/m32r.c:2365
-#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33292
+#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33348
 msgid "bad address"
 msgstr "slecht adres"
 
@@ -3781,192 +3781,192 @@
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4411 config/rs6000/rs6000.c:4258
+#: config/powerpcspe/powerpcspe.c:4411 config/rs6000/rs6000.c:4278
 msgid "-maltivec=le not allowed for big-endian targets"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4423 config/rs6000/rs6000.c:4273
+#: config/powerpcspe/powerpcspe.c:4423 config/rs6000/rs6000.c:4293
 #, fuzzy
 msgid "-mvsx requires hardware floating point"
 msgstr "lege declaratie"
 
-#: config/powerpcspe/powerpcspe.c:4431 config/rs6000/rs6000.c:4281
+#: config/powerpcspe/powerpcspe.c:4431 config/rs6000/rs6000.c:4301
 msgid "-mvsx and -mpaired are incompatible"
 msgstr "-mvsx en -mpaired zijn incompatibel"
 
-#: config/powerpcspe/powerpcspe.c:4433 config/rs6000/rs6000.c:4283
+#: config/powerpcspe/powerpcspe.c:4433 config/rs6000/rs6000.c:4303
 #, fuzzy
 msgid "-mvsx needs indexed addressing"
 msgstr "Schakel geïndexeerde adressering uit"
 
-#: config/powerpcspe/powerpcspe.c:4438 config/rs6000/rs6000.c:4288
+#: config/powerpcspe/powerpcspe.c:4438 config/rs6000/rs6000.c:4308
 msgid "-mvsx and -mno-altivec are incompatible"
 msgstr "-mvsx en -mno-altivec zijn incompatibel"
 
-#: config/powerpcspe/powerpcspe.c:4440 config/rs6000/rs6000.c:4290
+#: config/powerpcspe/powerpcspe.c:4440 config/rs6000/rs6000.c:4310
 msgid "-mno-altivec disables vsx"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4648 config/rs6000/rs6000.c:4416
+#: config/powerpcspe/powerpcspe.c:4648 config/rs6000/rs6000.c:4436
 msgid "-mquad-memory requires 64-bit mode"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4651 config/rs6000/rs6000.c:4419
+#: config/powerpcspe/powerpcspe.c:4651 config/rs6000/rs6000.c:4439
 msgid "-mquad-memory-atomic requires 64-bit mode"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4663 config/rs6000/rs6000.c:4431
+#: config/powerpcspe/powerpcspe.c:4663 config/rs6000/rs6000.c:4451
 #, fuzzy
 msgid "-mquad-memory is not available in little endian mode"
 msgstr "case-label niet in een switch-statement"
 
-#: config/powerpcspe/powerpcspe.c:4735 config/rs6000/rs6000.c:4512
+#: config/powerpcspe/powerpcspe.c:4735 config/rs6000/rs6000.c:4532
 msgid "-mtoc-fusion requires 64-bit"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4742 config/rs6000/rs6000.c:4519
+#: config/powerpcspe/powerpcspe.c:4742 config/rs6000/rs6000.c:4539
 msgid "-mtoc-fusion requires medium/large code model"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10915
+#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10947
 #, fuzzy
 msgid "bad move"
 msgstr "slechte test"
 
-#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21087
+#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21164
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21278
+#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21355
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%e value"
 msgstr "ongeldige waarde voor %%H"
 
-#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21299
+#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21376
 #, c-format
 msgid "invalid %%f value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21308
+#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21385
 #, c-format
 msgid "invalid %%F value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21317
+#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21394
 #, c-format
 msgid "invalid %%G value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21352
+#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21429
 #, c-format
 msgid "invalid %%j code"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21362
+#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21439
 #, c-format
 msgid "invalid %%J code"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21372
+#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21449
 #, c-format
 msgid "invalid %%k value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21387
+#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21464
 #: config/xtensa/xtensa.c:2415
 #, c-format
 msgid "invalid %%K value"
 msgstr "ongeldige waarde voor %%K"
 
-#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21434
+#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21511
 #, c-format
 msgid "invalid %%O value"
 msgstr "ongeldige waarde voor %%O"
 
-#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21481
+#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21558
 #, c-format
 msgid "invalid %%q value"
 msgstr "ongeldige waarde voor %%q"
 
-#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21534
+#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21611
 #, c-format
 msgid "invalid %%T value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21546
+#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21623
 #, c-format
 msgid "invalid %%u value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21560
+#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21637
 #: config/xtensa/xtensa.c:2384
 #, c-format
 msgid "invalid %%v value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21627
+#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21704
 #: config/xtensa/xtensa.c:2436
 #, c-format
 msgid "invalid %%x value"
 msgstr "ongeldige waarde voor %%x"
 
-#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21747
+#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21824
 #, fuzzy, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "twee %<u%>s in integerconstante"
 
-#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22282
+#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22359
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22288
+#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22365
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22294
+#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22371
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36572
+#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36628
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "AltiVec argument doorgegeven aan functie zonder prototype"
 
-#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38739
+#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38795
 #, fuzzy
 msgid "Could not generate addis value for fusion"
 msgstr "interne fout - slechte ingebouwde functie %qs"
 
-#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38809
+#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38865
 #, fuzzy
 msgid "Unable to generate load/store offset for fusion"
 msgstr "interne fout - slechte ingebouwde functie %qs"
 
-#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38908
+#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38964
 msgid "Bad GPR fusion"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39126
+#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39182
 msgid "emit_fusion_p9_load, bad reg #1"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39172
+#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39228
 msgid "emit_fusion_p9_load, bad reg #2"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39175
+#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39231
 msgid "emit_fusion_p9_load not MEM"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39213
+#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39269
 msgid "emit_fusion_p9_store, bad reg #1"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39259
+#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39315
 msgid "emit_fusion_p9_store, bad reg #2"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39262
+#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39318
 msgid "emit_fusion_p9_store not MEM"
 msgstr ""
 
@@ -4356,14 +4356,14 @@
 #: c/gimple-parser.c:188 c/gimple-parser.c:197 c/gimple-parser.c:226
 #: c/gimple-parser.c:1375 c/gimple-parser.c:1404 c/gimple-parser.c:1484
 #: c/gimple-parser.c:1511 c/c-parser.c:3204 c/c-parser.c:9967
-#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27841
-#: cp/parser.c:28430
+#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27838
+#: cp/parser.c:28427
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "ongeldige operand van %s"
 
 #: c/c-parser.c:2431 c/c-parser.c:7573 c/c-parser.c:8015 c/c-parser.c:8058
-#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27839 cp/parser.c:28448
+#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27836 cp/parser.c:28445
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "ongeldige operand van %s"
@@ -4378,7 +4378,7 @@
 #: c/gimple-parser.c:821 c/gimple-parser.c:837 c/gimple-parser.c:853
 #: c/gimple-parser.c:880 c/gimple-parser.c:915 c/gimple-parser.c:1038
 #: c/gimple-parser.c:1209 c/gimple-parser.c:1220 c/gimple-parser.c:1342
-#: c/gimple-parser.c:1441 cp/parser.c:28478
+#: c/gimple-parser.c:1441 cp/parser.c:28475
 #, fuzzy, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "ongeldige operand van %s"
@@ -4386,7 +4386,7 @@
 #: c/c-parser.c:3824 c/c-parser.c:4733 c/c-parser.c:4769 c/c-parser.c:6441
 #: c/c-parser.c:8125 c/c-parser.c:8983 c/c-parser.c:9127 c/c-parser.c:11588
 #: c/c-parser.c:18220 c/c-parser.c:18222 c/gimple-parser.c:1015
-#: cp/parser.c:28442
+#: cp/parser.c:28439
 #, fuzzy, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "ongeldige operand van %s"
@@ -4401,7 +4401,7 @@
 #: c/c-parser.c:17792 c/gimple-parser.c:363 c/gimple-parser.c:811
 #: c/gimple-parser.c:873 c/gimple-parser.c:911 c/gimple-parser.c:1198
 #: c/gimple-parser.c:1339 c/gimple-parser.c:1438 c/c-parser.c:11911
-#: cp/parser.c:28433
+#: cp/parser.c:28430
 #, fuzzy, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "ongeldige operand van %s"
@@ -4408,7 +4408,7 @@
 
 #: c/c-parser.c:4903 c/c-parser.c:10310 c/c-parser.c:16212 c/c-parser.c:18449
 #: c/gimple-parser.c:141 c/gimple-parser.c:1444 c/c-parser.c:3018
-#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18155 cp/parser.c:28439
+#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18152 cp/parser.c:28436
 #, fuzzy, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "ongeldige operand van %s"
@@ -4418,13 +4418,13 @@
 #: c/c-parser.c:12351 c/c-parser.c:12493 c/c-parser.c:12864 c/c-parser.c:12957
 #: c/c-parser.c:13566 c/c-parser.c:17636 c/c-parser.c:17695
 #: c/gimple-parser.c:431 c/gimple-parser.c:1492 c/gimple-parser.c:1519
-#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28472 cp/parser.c:29597
-#: cp/parser.c:32279
+#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28469 cp/parser.c:29594
+#: cp/parser.c:32276
 #, fuzzy, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:5974 cp/parser.c:28365
+#: c/c-parser.c:5974 cp/parser.c:28362
 #, fuzzy, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "ongeldige operand van %s"
@@ -4434,18 +4434,18 @@
 msgid "expected %<.%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30172
-#: cp/parser.c:30246
+#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30169
+#: cp/parser.c:30243
 #, fuzzy, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28457
+#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28454
 #, fuzzy, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28481
+#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28478
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "ongeldige operand van %s"
@@ -4453,32 +4453,32 @@
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15190 c/c-parser.c:15234 c/c-parser.c:15466 c/c-parser.c:15701
 #: c/c-parser.c:17833 c/gimple-parser.c:286 c/c-parser.c:4792
-#: cp/parser.c:28460
+#: cp/parser.c:28457
 #, fuzzy, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28436
-#: cp/parser.c:30389
+#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28433
+#: cp/parser.c:30386
 #, fuzzy, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35674
+#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35671
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "top-level declaratie van %qs specifieert %<auto%>"
 
-#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28445 cp/parser.c:31535
+#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28442 cp/parser.c:31532
 #, fuzzy, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-typeck.c:7847
+#: c/c-typeck.c:7852
 msgid "(anonymous)"
 msgstr "(anoniem)"
 
-#: c/gimple-parser.c:795 cp/parser.c:15791 cp/parser.c:28454
+#: c/gimple-parser.c:795 cp/parser.c:15788 cp/parser.c:28451
 #, fuzzy, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "ongeldige operand van %s"
@@ -4750,11 +4750,11 @@
 msgid "%r%s:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr ""
 
-#: cp/pt.c:1949 cp/semantics.c:5268
+#: cp/pt.c:1949 cp/semantics.c:5271
 msgid "candidates are:"
 msgstr "kandidaten zijn:"
 
-#: cp/pt.c:1951 cp/pt.c:22975
+#: cp/pt.c:1951 cp/pt.c:23053
 #, fuzzy
 msgid "candidate is:"
 msgid_plural "candidates are:"
@@ -4808,29 +4808,29 @@
 msgid "source type is not polymorphic"
 msgstr ""
 
-#: cp/typeck.c:6083 c/c-typeck.c:4261
+#: cp/typeck.c:6083 c/c-typeck.c:4266
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "argument van verkeerd type voor unaire min"
 
 # 'unary' = 'unair'?
-#: cp/typeck.c:6084 c/c-typeck.c:4248
+#: cp/typeck.c:6084 c/c-typeck.c:4253
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "argument van verkeerd type voor unaire plus"
 
-#: cp/typeck.c:6111 c/c-typeck.c:4302
+#: cp/typeck.c:6111 c/c-typeck.c:4307
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "argument van verkeerd type voor bit-complement"
 
-#: cp/typeck.c:6128 c/c-typeck.c:4310
+#: cp/typeck.c:6128 c/c-typeck.c:4315
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "argument van verkeerd type voor abs"
 
 # OK, ik geef het op: wat is hier een goede vertaling voor 'conjugation'?
-#: cp/typeck.c:6140 c/c-typeck.c:4322
+#: cp/typeck.c:6140 c/c-typeck.c:4327
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "argument van verkeerd type voor vervoeging"
@@ -5088,75 +5088,75 @@
 msgid "Expected attribute bit name"
 msgstr ""
 
-#: fortran/module.c:3223
+#: fortran/module.c:3225
 msgid "Expected integer string"
 msgstr "Verwachtte een integer-string"
 
-#: fortran/module.c:3227
+#: fortran/module.c:3229
 msgid "Error converting integer"
 msgstr ""
 
-#: fortran/module.c:3249
+#: fortran/module.c:3251
 msgid "Expected real string"
 msgstr "Verwachtte een real-string"
 
-#: fortran/module.c:3474
+#: fortran/module.c:3476
 msgid "Expected expression type"
 msgstr ""
 
-#: fortran/module.c:3554
+#: fortran/module.c:3556
 #, fuzzy
 msgid "Bad operator"
 msgstr "ongeldige operand voor %P"
 
-#: fortran/module.c:3671
+#: fortran/module.c:3673
 #, fuzzy
 msgid "Bad type in constant expression"
 msgstr "overflow in constante expressie"
 
-#: fortran/module.c:7038
+#: fortran/module.c:7040
 #, fuzzy
 msgid "Unexpected end of module"
 msgstr "ongeldige operand van %s"
 
-#: fortran/parse.c:1757
+#: fortran/parse.c:1761
 msgid "arithmetic IF"
 msgstr ""
 
-#: fortran/parse.c:1766
+#: fortran/parse.c:1770
 #, fuzzy
 msgid "attribute declaration"
 msgstr "lege declaratie"
 
-#: fortran/parse.c:1802
+#: fortran/parse.c:1806
 #, fuzzy
 msgid "data declaration"
 msgstr "lege declaratie"
 
-#: fortran/parse.c:1820
+#: fortran/parse.c:1824
 #, fuzzy
 msgid "derived type declaration"
 msgstr "lege declaratie"
 
-#: fortran/parse.c:1947
+#: fortran/parse.c:1951
 msgid "block IF"
 msgstr ""
 
-#: fortran/parse.c:1956
+#: fortran/parse.c:1960
 msgid "implied END DO"
 msgstr ""
 
-#: fortran/parse.c:2050 fortran/resolve.c:11199
+#: fortran/parse.c:2054 fortran/resolve.c:11219
 #, fuzzy
 msgid "assignment"
 msgstr "beginwaarde ontbreekt"
 
-#: fortran/parse.c:2053 fortran/resolve.c:11250 fortran/resolve.c:11253
+#: fortran/parse.c:2057 fortran/resolve.c:11270 fortran/resolve.c:11273
 #, fuzzy
 msgid "pointer assignment"
 msgstr "ongeldige lvalue in toewijzing"
 
-#: fortran/parse.c:2071
+#: fortran/parse.c:2075
 msgid "simple IF"
 msgstr ""
 
@@ -5260,108 +5260,113 @@
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:3878
+#: fortran/resolve.c:3879
 #, c-format
+msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
+msgstr ""
+
+#: fortran/resolve.c:3884
+#, c-format
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3893
+#: fortran/resolve.c:3899
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3926
+#: fortran/resolve.c:3932
 #, c-format
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3949
+#: fortran/resolve.c:3955
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:3963
+#: fortran/resolve.c:3969
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr ""
 
-#: fortran/resolve.c:4015
+#: fortran/resolve.c:4021
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr ""
 
-#: fortran/resolve.c:4021
+#: fortran/resolve.c:4027
 #, c-format
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4034
+#: fortran/resolve.c:4040
 #, fuzzy, c-format
 msgid "Unknown operator %%<%s%%> at %%L; did you mean '%s'?"
 msgstr "onbekende operator '%s' in %%:version-compare"
 
-#: fortran/resolve.c:4037
+#: fortran/resolve.c:4043
 #, fuzzy, c-format
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr "onbekende operator '%s' in %%:version-compare"
 
-#: fortran/resolve.c:4040
+#: fortran/resolve.c:4046
 #, c-format
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:4044
+#: fortran/resolve.c:4050
 #, c-format
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4132
+#: fortran/resolve.c:4138
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr ""
 
-#: fortran/resolve.c:6849
+#: fortran/resolve.c:6855
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.c:6853
+#: fortran/resolve.c:6859
 #, fuzzy
 msgid "iterator variable"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: fortran/resolve.c:6857
+#: fortran/resolve.c:6863
 msgid "Start expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:6861
+#: fortran/resolve.c:6867
 #, fuzzy
 msgid "End expression in DO loop"
 msgstr "ongeldige expressie als operand"
 
-#: fortran/resolve.c:6865
+#: fortran/resolve.c:6871
 msgid "Step expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:7150 fortran/resolve.c:7153
+#: fortran/resolve.c:7156 fortran/resolve.c:7159
 msgid "DEALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.c:7525 fortran/resolve.c:7528
+#: fortran/resolve.c:7531 fortran/resolve.c:7534
 msgid "ALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.c:7720 fortran/resolve.c:9417
+#: fortran/resolve.c:7726 fortran/resolve.c:9428
 msgid "STAT variable"
 msgstr ""
 
-#: fortran/resolve.c:7764 fortran/resolve.c:9429
+#: fortran/resolve.c:7770 fortran/resolve.c:9440
 msgid "ERRMSG variable"
 msgstr ""
 
-#: fortran/resolve.c:9219
+#: fortran/resolve.c:9230
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.c:9441
+#: fortran/resolve.c:9452
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
@@ -5394,7 +5399,7 @@
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:10154
+#: fortran/trans-expr.c:10157
 msgid "Assignment of scalar to unallocated array"
 msgstr ""
 
@@ -5403,12 +5408,12 @@
 msgid "Unequal character lengths (%ld/%ld) in %s"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:8088
+#: fortran/trans-intrinsic.c:8090
 #, fuzzy, c-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative (its value is %ld)"
 msgstr "functie-oproep heeft geaggregeerde waarde"
 
-#: fortran/trans-intrinsic.c:8120
+#: fortran/trans-intrinsic.c:8122
 msgid "Argument NCOPIES of REPEAT intrinsic is too large"
 msgstr ""
 
@@ -5431,15 +5436,15 @@
 msgid "Invalid image number %d in SYNC IMAGES"
 msgstr ""
 
-#: fortran/trans-stmt.c:2180
+#: fortran/trans-stmt.c:2177
 msgid "Loop iterates infinitely"
 msgstr ""
 
-#: fortran/trans-stmt.c:2200 fortran/trans-stmt.c:2456
+#: fortran/trans-stmt.c:2197 fortran/trans-stmt.c:2453
 msgid "Loop variable has been modified"
 msgstr ""
 
-#: fortran/trans-stmt.c:2309
+#: fortran/trans-stmt.c:2306
 msgid "DO step value is zero"
 msgstr ""
 
@@ -6064,10 +6069,10 @@
 msgid "Allow dollar signs in entity names."
 msgstr ""
 
-#: fortran/lang.opt:485 config/alpha/alpha.opt:31 common.opt:783
-#: common.opt:985 common.opt:989 common.opt:993 common.opt:997 common.opt:1532
-#: common.opt:1588 common.opt:1712 common.opt:1716 common.opt:1946
-#: common.opt:2116 common.opt:2792
+#: fortran/lang.opt:485 config/alpha/alpha.opt:31 common.opt:649
+#: common.opt:783 common.opt:989 common.opt:993 common.opt:997 common.opt:1001
+#: common.opt:1536 common.opt:1592 common.opt:1716 common.opt:1720
+#: common.opt:1950 common.opt:2120 common.opt:2796
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr ""
 
@@ -6298,12 +6303,12 @@
 msgstr ""
 
 #: fortran/lang.opt:751 c-family/c.opt:1356 c-family/c.opt:1384
-#: c-family/c.opt:1634 config/pa/pa.opt:42 config/pa/pa.opt:70 common.opt:1154
-#: common.opt:1333 common.opt:1408 common.opt:1676 common.opt:1799
-#: common.opt:2169 common.opt:2205 common.opt:2298 common.opt:2302
-#: common.opt:2407 common.opt:2498 common.opt:2506 common.opt:2514
-#: common.opt:2522 common.opt:2623 common.opt:2675 common.opt:2755
-#: common.opt:2893 common.opt:2897 common.opt:2901 common.opt:2905
+#: c-family/c.opt:1634 config/pa/pa.opt:42 config/pa/pa.opt:70 common.opt:1158
+#: common.opt:1337 common.opt:1412 common.opt:1680 common.opt:1803
+#: common.opt:2173 common.opt:2209 common.opt:2302 common.opt:2306
+#: common.opt:2411 common.opt:2502 common.opt:2510 common.opt:2518
+#: common.opt:2526 common.opt:2627 common.opt:2679 common.opt:2759
+#: common.opt:2897 common.opt:2901 common.opt:2905 common.opt:2909
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr ""
 
@@ -6359,7 +6364,7 @@
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:220 c-family/c.opt:224
 #: c-family/c.opt:236 c-family/c.opt:1855 c-family/c.opt:1863 brig/lang.opt:39
-#: config/darwin.opt:56 common.opt:338 common.opt:341 common.opt:3046
+#: config/darwin.opt:56 common.opt:338 common.opt:341 common.opt:3050
 #, fuzzy, c-format
 msgid "missing filename after %qs"
 msgstr "beginwaarde ontbreekt"
@@ -6994,7 +6999,7 @@
 #: c-family/c.opt:1525 c-family/c.opt:1528 c-family/c.opt:1569
 #: c-family/c.opt:1704 c-family/c.opt:1731 c-family/c.opt:1771
 #: c-family/c.opt:1802 c-family/c.opt:1806 c-family/c.opt:1822
-#: config/ia64/ia64.opt:167 config/ia64/ia64.opt:170 c-family/c-opts.c:434
+#: config/ia64/ia64.opt:167 config/ia64/ia64.opt:170 c-family/c-opts.c:432
 #, fuzzy, gcc-internal-format
 msgid "switch %qs is no longer supported"
 msgstr "-pipe wordt niet ondersteund"
@@ -14805,10 +14810,6 @@
 msgid "Warn if dereferencing a NULL pointer may lead to erroneous or undefined behavior."
 msgstr ""
 
-#: common.opt:649
-msgid "Warn if the loop cannot be optimized due to nontrivial assumptions."
-msgstr ""
-
 #: common.opt:656
 msgid "Warn about some C++ One Definition Rule violations during link time optimization."
 msgstr ""
@@ -15007,1786 +15008,1786 @@
 msgid "-dumpdir <dir>\tSet the directory name to be used for dumps."
 msgstr "Geef het register op dat voor PIC-adressering gebruikt moet worden"
 
-#: common.opt:946
+#: common.opt:950
 msgid "The version of the C++ ABI in use."
 msgstr ""
 
-#: common.opt:950
+#: common.opt:954
 msgid "Aggressively optimize loops using language constraints."
 msgstr ""
 
-#: common.opt:954
+#: common.opt:958
 #, fuzzy
 msgid "Align the start of functions."
 msgstr "impliciete declaratie van functie %qs"
 
-#: common.opt:964
+#: common.opt:968
 msgid "Align labels which are only reached by jumping."
 msgstr ""
 
-#: common.opt:971
+#: common.opt:975
 msgid "Align all labels."
 msgstr ""
 
-#: common.opt:978
+#: common.opt:982
 #, fuzzy
 msgid "Align the start of loops."
 msgstr "impliciete declaratie van functie %qs"
 
-#: common.opt:1001
+#: common.opt:1005
 msgid "Select what to sanitize."
 msgstr ""
 
-#: common.opt:1005
+#: common.opt:1009
 msgid "Select type of coverage sanitization."
 msgstr ""
 
-#: common.opt:1009
+#: common.opt:1013
 msgid "-fasan-shadow-offset=<number>\tUse custom shadow memory offset."
 msgstr ""
 
-#: common.opt:1013
+#: common.opt:1017
 msgid "-fsanitize-sections=<sec1,sec2,...>\tSanitize global variables in user-defined sections."
 msgstr ""
 
-#: common.opt:1018
+#: common.opt:1022
 msgid "After diagnosing undefined behavior attempt to continue execution."
 msgstr ""
 
-#: common.opt:1022
+#: common.opt:1026
 msgid "This switch is deprecated; use -fsanitize-recover= instead."
 msgstr ""
 
-#: common.opt:1029
+#: common.opt:1033
 msgid "Use trap instead of a library function for undefined behavior sanitization."
 msgstr ""
 
-#: common.opt:1033
+#: common.opt:1037
 msgid "Generate unwind tables that are exact at each instruction boundary."
 msgstr ""
 
-#: common.opt:1037
+#: common.opt:1041
 #, fuzzy
 msgid "Generate auto-inc/dec instructions."
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: common.opt:1041
+#: common.opt:1045
 msgid "Use sample profile information for call graph node weights. The default profile file is fbdata.afdo in 'pwd'."
 msgstr ""
 
-#: common.opt:1046
+#: common.opt:1050
 msgid "Use sample profile information for call graph node weights. The profile file is specified in the argument."
 msgstr ""
 
-#: common.opt:1055
+#: common.opt:1059
 #, fuzzy
 msgid "Generate code to check bounds before indexing arrays."
 msgstr "%qs gedeclareerd als een functie die een functie teruggeeft"
 
-#: common.opt:1059
+#: common.opt:1063
 msgid "Replace add, compare, branch with branch on count register."
 msgstr ""
 
-#: common.opt:1063
+#: common.opt:1067
 msgid "Use profiling information for branch probabilities."
 msgstr ""
 
-#: common.opt:1067
+#: common.opt:1071
 msgid "Perform branch target load optimization before prologue / epilogue threading."
 msgstr ""
 
-#: common.opt:1071
+#: common.opt:1075
 msgid "Perform branch target load optimization after prologue / epilogue threading."
 msgstr ""
 
-#: common.opt:1075
+#: common.opt:1079
 msgid "Restrict target load migration not to re-use registers in any basic block."
 msgstr ""
 
-#: common.opt:1079
+#: common.opt:1083
 #, fuzzy
 msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions."
 msgstr "registervariabele %qs gebruikt in geneste functie"
 
-#: common.opt:1083
+#: common.opt:1087
 #, fuzzy
 msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls."
 msgstr "registervariabele %qs gebruikt in geneste functie"
 
-#: common.opt:1090
+#: common.opt:1094
 msgid "Save registers around function calls."
 msgstr ""
 
-#: common.opt:1094
+#: common.opt:1098
 #, fuzzy
 msgid "This switch is deprecated; do not use."
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: common.opt:1098
+#: common.opt:1102
 msgid "Check the return value of new in C++."
 msgstr ""
 
-#: common.opt:1102 common.opt:1106
+#: common.opt:1106 common.opt:1110
 msgid "Perform internal consistency checkings."
 msgstr ""
 
 # of "preprocessing" behouden?
-#: common.opt:1110
+#: common.opt:1114
 #, fuzzy
 msgid "Enable code hoisting."
 msgstr "Schakel traditionele voorverwerking in"
 
-#: common.opt:1114
+#: common.opt:1118
 msgid "Looks for opportunities to reduce stack adjustments and stack references."
 msgstr ""
 
-#: common.opt:1118
+#: common.opt:1122
 #, fuzzy
 msgid "Do not put uninitialized globals in the common section."
 msgstr "%qs is hier niet gedeclareerd (eerste gebruik in deze functie)"
 
-#: common.opt:1126
+#: common.opt:1130
 msgid "-fcompare-debug[=<opts>]\tCompile with and without e.g. -gtoggle, and compare the final-insns dump."
 msgstr ""
 
-#: common.opt:1130
+#: common.opt:1134
 msgid "Run only the second compilation of -fcompare-debug."
 msgstr ""
 
-#: common.opt:1134
+#: common.opt:1138
 msgid "Perform comparison elimination after register allocation has finished."
 msgstr ""
 
-#: common.opt:1138
+#: common.opt:1142
 msgid "Do not perform optimizations increasing noticeably stack usage."
 msgstr ""
 
-#: common.opt:1142
+#: common.opt:1146
 #, fuzzy
 msgid "Perform a register copy-propagation optimization pass."
 msgstr "lege declaratie"
 
-#: common.opt:1146
+#: common.opt:1150
 #, fuzzy
 msgid "Perform cross-jumping optimization."
 msgstr "lege declaratie"
 
-#: common.opt:1150
+#: common.opt:1154
 msgid "When running CSE, follow jumps to their targets."
 msgstr ""
 
-#: common.opt:1158
+#: common.opt:1162
 msgid "Omit range reduction step when performing complex division."
 msgstr ""
 
-#: common.opt:1162
+#: common.opt:1166
 msgid "Complex multiplication and division follow Fortran rules."
 msgstr ""
 
-#: common.opt:1166
+#: common.opt:1170
 #, fuzzy
 msgid "Place data items into their own section."
 msgstr "keer vermeld voor elke functie waarin hij staat.)"
 
-#: common.opt:1170
+#: common.opt:1174
 msgid "List all available debugging counters with their limits and counts."
 msgstr ""
 
-#: common.opt:1174
+#: common.opt:1178
 msgid "-fdbg-cnt=<counter>:<limit>[,<counter>:<limit>,...]\tSet the debug counter limit."
 msgstr ""
 
-#: common.opt:1178
+#: common.opt:1182
 msgid "-fdebug-prefix-map=<old>=<new> Map one directory name to another in debug information."
 msgstr ""
 
-#: common.opt:1182
+#: common.opt:1186
 msgid "-ffile-prefix-map=<old>=<new> Map one directory name to another in compilation result."
 msgstr ""
 
-#: common.opt:1186
+#: common.opt:1190
 msgid "Output .debug_types section when using DWARF v4 debuginfo."
 msgstr ""
 
-#: common.opt:1192
+#: common.opt:1196
 msgid "Defer popping functions args from stack until later."
 msgstr ""
 
-#: common.opt:1196
+#: common.opt:1200
 msgid "Attempt to fill delay slots of branch instructions."
 msgstr ""
 
-#: common.opt:1200
+#: common.opt:1204
 msgid "Delete dead instructions that may throw exceptions."
 msgstr ""
 
-#: common.opt:1204
+#: common.opt:1208
 msgid "Delete useless null pointer checks."
 msgstr ""
 
-#: common.opt:1208
+#: common.opt:1212
 msgid "Stream extra data to support more aggressive devirtualization in LTO local transformation mode."
 msgstr ""
 
-#: common.opt:1212
+#: common.opt:1216
 msgid "Perform speculative devirtualization."
 msgstr ""
 
-#: common.opt:1216
+#: common.opt:1220
 msgid "Try to convert virtual calls to direct ones."
 msgstr ""
 
-#: common.opt:1220
+#: common.opt:1224
 msgid "-fdiagnostics-show-location=[once|every-line]\tHow often to emit source location at the beginning of line-wrapped diagnostics."
 msgstr ""
 
-#: common.opt:1237
+#: common.opt:1241
 msgid "Show the source line with a caret indicating the column."
 msgstr ""
 
-#: common.opt:1245
+#: common.opt:1249
 msgid "-fdiagnostics-color=[never|always|auto]\tColorize diagnostics."
 msgstr ""
 
-#: common.opt:1265
+#: common.opt:1269
 msgid "Print fix-it hints in machine-readable form."
 msgstr ""
 
-#: common.opt:1269
+#: common.opt:1273
 msgid "Print fix-it hints to stderr in unified diff format."
 msgstr ""
 
-#: common.opt:1273
+#: common.opt:1277
 msgid "Amend appropriate diagnostic messages with the command line option that controls them."
 msgstr ""
 
-#: common.opt:1277
+#: common.opt:1281
 msgid "-fdisable-[tree|rtl|ipa]-<pass>=range1+range2 disables an optimization pass."
 msgstr ""
 
-#: common.opt:1281
+#: common.opt:1285
 msgid "-fenable-[tree|rtl|ipa]-<pass>=range1+range2 enables an optimization pass."
 msgstr ""
 
-#: common.opt:1285
+#: common.opt:1289
 msgid "-fdump-<type>\tDump various compiler internals to a file."
 msgstr ""
 
-#: common.opt:1292
+#: common.opt:1296
 msgid "-fdump-final-insns=filename\tDump to filename the insns at the end of translation."
 msgstr ""
 
-#: common.opt:1296
+#: common.opt:1300
 msgid "-fdump-go-spec=filename\tWrite all declarations to file as Go code."
 msgstr ""
 
-#: common.opt:1300
+#: common.opt:1304
 msgid "Suppress output of addresses in debugging dumps."
 msgstr ""
 
-#: common.opt:1304
+#: common.opt:1308
 msgid "Collect and dump debug information into temporary file if ICE in C/C++ compiler occurred."
 msgstr ""
 
-#: common.opt:1309
+#: common.opt:1313
 msgid "Dump detailed information on GCC's internal representation of source code locations."
 msgstr ""
 
-#: common.opt:1313
+#: common.opt:1317
 #, fuzzy
 msgid "Dump optimization passes."
 msgstr "meegegeven opties: "
 
-#: common.opt:1317
+#: common.opt:1321
 msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps."
 msgstr ""
 
-#: common.opt:1321
+#: common.opt:1325
 msgid "Suppress output of previous and next insn numbers in debugging dumps."
 msgstr ""
 
-#: common.opt:1325
+#: common.opt:1329
 msgid "Enable CFI tables via GAS assembler directives."
 msgstr ""
 
-#: common.opt:1329
+#: common.opt:1333
 #, fuzzy
 msgid "Perform early inlining."
 msgstr "recursieve inlining"
 
-#: common.opt:1337
+#: common.opt:1341
 msgid "Perform interprocedural reduction of aggregates."
 msgstr ""
 
-#: common.opt:1341
+#: common.opt:1345
 msgid "Perform unused symbol elimination in debug info."
 msgstr ""
 
-#: common.opt:1345
+#: common.opt:1349
 msgid "Perform unused type elimination in debug info."
 msgstr ""
 
-#: common.opt:1349
+#: common.opt:1353
 msgid "Do not suppress C++ class debug information."
 msgstr ""
 
-#: common.opt:1353
+#: common.opt:1357
 msgid "Enable exception handling."
 msgstr ""
 
-#: common.opt:1357
+#: common.opt:1361
 #, fuzzy
 msgid "Perform a number of minor, expensive optimizations."
 msgstr "lege declaratie"
 
-#: common.opt:1361
+#: common.opt:1365
 msgid "-fexcess-precision=[fast|standard]\tSpecify handling of excess floating-point precision."
 msgstr ""
 
-#: common.opt:1364
+#: common.opt:1368
 #, fuzzy, c-format
 msgid "unknown excess precision style %qs"
 msgstr "onbekende machine-modus %qs"
 
-#: common.opt:1376
+#: common.opt:1380
 msgid "-fpermitted-flt-eval-methods=[c11|ts-18661]\tSpecify which values of FLT_EVAL_METHOD are permitted."
 msgstr ""
 
-#: common.opt:1379
+#: common.opt:1383
 #, c-format
 msgid "unknown specification for the set of FLT_EVAL_METHOD values to permit %qs"
 msgstr ""
 
-#: common.opt:1392
+#: common.opt:1396
 msgid "Output lto objects containing both the intermediate language and binary output."
 msgstr ""
 
-#: common.opt:1396
+#: common.opt:1400
 msgid "Assume no NaNs or infinities are generated."
 msgstr ""
 
-#: common.opt:1400
+#: common.opt:1404
 #, fuzzy
 msgid "-ffixed-<register>\tMark <register> as being unavailable to the compiler."
 msgstr "registervariabele %qs gebruikt in geneste functie"
 
-#: common.opt:1404
+#: common.opt:1408
 msgid "Don't allocate floats and doubles in extended-precision registers."
 msgstr ""
 
-#: common.opt:1412
+#: common.opt:1416
 #, fuzzy
 msgid "Perform a forward propagation pass on RTL."
 msgstr "lege declaratie"
 
-#: common.opt:1416
+#: common.opt:1420
 msgid "-ffp-contract=[off|on|fast]\tPerform floating-point expression contraction."
 msgstr ""
 
-#: common.opt:1419
+#: common.opt:1423
 #, fuzzy, c-format
 msgid "unknown floating point contraction style %qs"
 msgstr "niet-floating-point argument voor functie %qs"
 
-#: common.opt:1433
+#: common.opt:1437
 msgid "Allow built-in functions ceil, floor, round, trunc to raise \"inexact\" exceptions."
 msgstr ""
 
-#: common.opt:1440
+#: common.opt:1444
 msgid "Allow function addresses to be held in registers."
 msgstr ""
 
-#: common.opt:1444
+#: common.opt:1448
 #, fuzzy
 msgid "Place each function into its own section."
 msgstr "keer vermeld voor elke functie waarin hij staat.)"
 
-#: common.opt:1448
+#: common.opt:1452
 msgid "Perform global common subexpression elimination."
 msgstr ""
 
-#: common.opt:1452
+#: common.opt:1456
 msgid "Perform enhanced load motion during global common subexpression elimination."
 msgstr ""
 
-#: common.opt:1456
+#: common.opt:1460
 msgid "Perform store motion after global common subexpression elimination."
 msgstr ""
 
-#: common.opt:1460
+#: common.opt:1464
 msgid "Perform redundant load after store elimination in global common subexpression elimination."
 msgstr ""
 
-#: common.opt:1465
+#: common.opt:1469
 msgid "Perform global common subexpression elimination after register allocation has finished."
 msgstr ""
 
-#: common.opt:1482
+#: common.opt:1486
 msgid "-fgnat-encodings=[all|gdb|minimal]\tSelect the balance between GNAT encodings and standard DWARF emitted in the debug information"
 msgstr ""
 
-#: common.opt:1487
+#: common.opt:1491
 #, fuzzy
 msgid "Enable in and out of Graphite representation."
 msgstr "lege declaratie"
 
-#: common.opt:1491
+#: common.opt:1495
 #, fuzzy
 msgid "Enable Graphite Identity transformation."
 msgstr "lege declaratie"
 
-#: common.opt:1495
+#: common.opt:1499
 msgid "Enable hoisting adjacent loads to encourage generating conditional move instructions."
 msgstr ""
 
-#: common.opt:1504
+#: common.opt:1508
 msgid "Mark all loops as parallel."
 msgstr ""
 
-#: common.opt:1508 common.opt:1516 common.opt:2587
+#: common.opt:1512 common.opt:1520 common.opt:2591
 msgid "Enable loop nest transforms.  Same as -floop-nest-optimize."
 msgstr ""
 
-#: common.opt:1512
+#: common.opt:1516
 #, fuzzy
 msgid "Enable loop interchange on trees."
 msgstr "lege declaratie"
 
-#: common.opt:1520
+#: common.opt:1524
 msgid "Perform unroll-and-jam on loops."
 msgstr ""
 
-#: common.opt:1524
+#: common.opt:1528
 msgid "Enable support for GNU transactional memory."
 msgstr ""
 
-#: common.opt:1528
+#: common.opt:1532
 msgid "Use STB_GNU_UNIQUE if supported by the assembler."
 msgstr ""
 
-#: common.opt:1536
+#: common.opt:1540
 #, fuzzy
 msgid "Enable the loop nest optimizer."
 msgstr "lege declaratie"
 
-#: common.opt:1540
+#: common.opt:1544
 msgid "Force bitfield accesses to match their type width."
 msgstr ""
 
-#: common.opt:1544
+#: common.opt:1548
 msgid "Merge adjacent stores."
 msgstr ""
 
-#: common.opt:1548
+#: common.opt:1552
 msgid "Enable guessing of branch probabilities."
 msgstr ""
 
-#: common.opt:1556
+#: common.opt:1560
 #, fuzzy
 msgid "Process #ident directives."
 msgstr "ongeldig preprocessing-commando"
 
-#: common.opt:1560
+#: common.opt:1564
 msgid "Perform conversion of conditional jumps to branchless equivalents."
 msgstr ""
 
-#: common.opt:1564
+#: common.opt:1568
 #, fuzzy
 msgid "Perform conversion of conditional jumps to conditional execution."
 msgstr "types in voorwaardelijke expressie komen niet overeen"
 
-#: common.opt:1568
+#: common.opt:1572
 msgid "-fstack-reuse=[all|named_vars|none]\tSet stack reuse level for local variables."
 msgstr ""
 
-#: common.opt:1571
+#: common.opt:1575
 #, fuzzy, c-format
 msgid "unknown Stack Reuse Level %qs"
 msgstr "onbekende machine-modus %qs"
 
-#: common.opt:1584
+#: common.opt:1588
 msgid "Convert conditional jumps in innermost loops to branchless equivalents."
 msgstr ""
 
-#: common.opt:1596
+#: common.opt:1600
 #, fuzzy
 msgid "Do not generate .size directives."
 msgstr "interne fout - slechte ingebouwde functie %qs"
 
-#: common.opt:1600
+#: common.opt:1604
 #, fuzzy
 msgid "Perform indirect inlining."
 msgstr "recursieve inlining"
 
-#: common.opt:1606
+#: common.opt:1610
 msgid "Enable inlining of function declared \"inline\", disabling disables all inlining."
 msgstr ""
 
-#: common.opt:1610
+#: common.opt:1614
 #, fuzzy
 msgid "Integrate functions into their callers when code size is known not to grow."
 msgstr "pointer naar lid-functie gebruikt in rekensom"
 
-#: common.opt:1614
+#: common.opt:1618
 #, fuzzy
 msgid "Integrate functions not declared \"inline\" into their callers when profitable."
 msgstr "pointer naar lid-functie gebruikt in rekensom"
 
-#: common.opt:1618
+#: common.opt:1622
 #, fuzzy
 msgid "Integrate functions only required by their single caller."
 msgstr "pointer naar lid-functie gebruikt in rekensom"
 
-#: common.opt:1625
+#: common.opt:1629
 msgid "-finline-limit=<number>\tLimit the size of inlined functions to <number>."
 msgstr ""
 
-#: common.opt:1629
+#: common.opt:1633
 msgid "Inline __atomic operations when a lock free instruction sequence is available."
 msgstr ""
 
-#: common.opt:1636
+#: common.opt:1640
 msgid "-fcf-protection=[full|branch|return|none]\tInstrument functions with checks to verify jump/call/return control-flow transfer instructions have valid targets."
 msgstr ""
 
-#: common.opt:1640
+#: common.opt:1644
 #, fuzzy, c-format
 msgid "unknown Control-Flow Protection Level %qs"
 msgstr "onbekende machine-modus %qs"
 
-#: common.opt:1656
+#: common.opt:1660
 msgid "Instrument function entry and exit with profiling calls."
 msgstr ""
 
-#: common.opt:1660
+#: common.opt:1664
 msgid "-finstrument-functions-exclude-function-list=name,...  Do not instrument listed functions."
 msgstr ""
 
-#: common.opt:1664
+#: common.opt:1668
 msgid "-finstrument-functions-exclude-file-list=filename,...  Do not instrument functions listed in files."
 msgstr ""
 
-#: common.opt:1668
+#: common.opt:1672
 msgid "Perform interprocedural constant propagation."
 msgstr ""
 
-#: common.opt:1672
+#: common.opt:1676
 msgid "Perform cloning to make Interprocedural constant propagation stronger."
 msgstr ""
 
-#: common.opt:1680
+#: common.opt:1684
 msgid "Perform interprocedural bitwise constant propagation."
 msgstr ""
 
-#: common.opt:1684
+#: common.opt:1688
 msgid "Perform interprocedural profile propagation."
 msgstr ""
 
-#: common.opt:1688
+#: common.opt:1692
 msgid "Perform interprocedural points-to analysis."
 msgstr ""
 
-#: common.opt:1692
+#: common.opt:1696
 #, fuzzy
 msgid "Discover pure and const functions."
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: common.opt:1696
+#: common.opt:1700
 msgid "Perform Identical Code Folding for functions and read-only variables."
 msgstr ""
 
-#: common.opt:1700
+#: common.opt:1704
 msgid "Perform Identical Code Folding for functions."
 msgstr ""
 
-#: common.opt:1704
+#: common.opt:1708
 msgid "Perform Identical Code Folding for variables."
 msgstr ""
 
-#: common.opt:1708
+#: common.opt:1712
 msgid "Discover readonly and non addressable static variables."
 msgstr ""
 
-#: common.opt:1720
+#: common.opt:1724
 msgid "Perform IPA Value Range Propagation."
 msgstr ""
 
-#: common.opt:1724
+#: common.opt:1728
 msgid "-fira-algorithm=[CB|priority]\tSet the used IRA algorithm."
 msgstr ""
 
-#: common.opt:1727
+#: common.opt:1731
 #, fuzzy, c-format
 msgid "unknown IRA algorithm %qs"
 msgstr "onbekende machine-modus %qs"
 
-#: common.opt:1737
+#: common.opt:1741
 msgid "-fira-region=[one|all|mixed]\tSet regions for IRA."
 msgstr ""
 
-#: common.opt:1740
+#: common.opt:1744
 #, fuzzy, c-format
 msgid "unknown IRA region %qs"
 msgstr "onbekende 'unspec' relocatie"
 
-#: common.opt:1753
+#: common.opt:1757
 msgid "Use IRA based register pressure calculation in RTL hoist optimizations."
 msgstr ""
 
-#: common.opt:1758
+#: common.opt:1762
 msgid "Use IRA based register pressure calculation in RTL loop optimizations."
 msgstr ""
 
-#: common.opt:1763
+#: common.opt:1767
 msgid "Share slots for saving different hard registers."
 msgstr ""
 
-#: common.opt:1767
+#: common.opt:1771
 msgid "Share stack slots for spilled pseudo-registers."
 msgstr ""
 
-#: common.opt:1771
+#: common.opt:1775
 msgid "-fira-verbose=<number>\tControl IRA's level of diagnostic messages."
 msgstr ""
 
-#: common.opt:1775
+#: common.opt:1779
 msgid "Optimize induction variables on trees."
 msgstr ""
 
-#: common.opt:1779
+#: common.opt:1783
 #, fuzzy
 msgid "Use jump tables for sufficiently large switch statements."
 msgstr "case-label niet in een switch-statement"
 
-#: common.opt:1783
+#: common.opt:1787
 #, fuzzy
 msgid "Generate code for functions even if they are fully inlined."
 msgstr "de terugkeerwaarde van een functie kan geen funtie zijn"
 
-#: common.opt:1787
+#: common.opt:1791
 #, fuzzy
 msgid "Generate code for static functions even if they are never called."
 msgstr "de terugkeerwaarde van een functie kan geen funtie zijn"
 
-#: common.opt:1791
+#: common.opt:1795
 msgid "Emit static const variables even if they are not used."
 msgstr ""
 
-#: common.opt:1795
+#: common.opt:1799
 msgid "Give external symbols a leading underscore."
 msgstr ""
 
-#: common.opt:1803
+#: common.opt:1807
 msgid "Do CFG-sensitive rematerialization in LRA."
 msgstr ""
 
-#: common.opt:1807
+#: common.opt:1811
 #, fuzzy
 msgid "Enable link-time optimization."
 msgstr "lege declaratie"
 
-#: common.opt:1811
+#: common.opt:1815
 msgid "Link-time optimization with number of parallel jobs or jobserver."
 msgstr ""
 
-#: common.opt:1814
+#: common.opt:1818
 #, fuzzy, c-format
 msgid "unknown LTO partitioning model %qs"
 msgstr "onbekende machine-modus %qs"
 
-#: common.opt:1833
+#: common.opt:1837
 msgid "Specify the algorithm to partition symbols and vars at linktime."
 msgstr ""
 
-#: common.opt:1838
+#: common.opt:1842
 msgid "-flto-compression-level=<number>\tUse zlib compression level <number> for IL."
 msgstr ""
 
-#: common.opt:1842
+#: common.opt:1846
 msgid "Merge C++ types using One Definition Rule."
 msgstr ""
 
-#: common.opt:1846
+#: common.opt:1850
 #, fuzzy
 msgid "Report various link-time optimization statistics."
 msgstr "lege declaratie"
 
-#: common.opt:1850
+#: common.opt:1854
 msgid "Report various link-time optimization statistics for WPA only."
 msgstr ""
 
-#: common.opt:1854
+#: common.opt:1858
 #, fuzzy
 msgid "Set errno after built-in math functions."
 msgstr "interne fout - slechte ingebouwde functie %qs"
 
-#: common.opt:1858
+#: common.opt:1862
 msgid "-fmax-errors=<number>\tMaximum number of errors to report."
 msgstr ""
 
-#: common.opt:1862
+#: common.opt:1866
 msgid "Report on permanent memory allocation."
 msgstr ""
 
-#: common.opt:1866
+#: common.opt:1870
 msgid "Report on permanent memory allocation in WPA only."
 msgstr ""
 
-#: common.opt:1873
+#: common.opt:1877
 msgid "Attempt to merge identical constants and constant variables."
 msgstr ""
 
-#: common.opt:1877
+#: common.opt:1881
 msgid "Attempt to merge identical constants across compilation units."
 msgstr ""
 
-#: common.opt:1881
+#: common.opt:1885
 msgid "Attempt to merge identical debug strings across compilation units."
 msgstr ""
 
-#: common.opt:1885
+#: common.opt:1889
 msgid "-fmessage-length=<number>\tLimit diagnostics to <number> characters per line.  0 suppresses line-wrapping."
 msgstr ""
 
-#: common.opt:1889
+#: common.opt:1893
 msgid "Perform SMS based modulo scheduling before the first scheduling pass."
 msgstr ""
 
-#: common.opt:1893
+#: common.opt:1897
 msgid "Perform SMS based modulo scheduling with register moves allowed."
 msgstr ""
 
-#: common.opt:1897
+#: common.opt:1901
 msgid "Move loop invariant computations out of loops."
 msgstr ""
 
-#: common.opt:1901
+#: common.opt:1905
 #, fuzzy
 msgid "Use the RTL dead code elimination pass."
 msgstr "lege declaratie"
 
-#: common.opt:1905
+#: common.opt:1909
 #, fuzzy
 msgid "Use the RTL dead store elimination pass."
 msgstr "lege declaratie"
 
-#: common.opt:1909
+#: common.opt:1913
 msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling."
 msgstr ""
 
-#: common.opt:1913
+#: common.opt:1917
 msgid "Support synchronous non-call exceptions."
 msgstr ""
 
 # Assertie? Dat moet beter kunnen!
-#: common.opt:1916
+#: common.opt:1920
 #, fuzzy, c-format
 msgid "options or targets missing after %qs"
 msgstr "Assertie ontbreekt na -A optie"
 
-#: common.opt:1917
+#: common.opt:1921
 msgid "-foffload=<targets>=<options>  Specify offloading targets and options for them."
 msgstr ""
 
-#: common.opt:1921
+#: common.opt:1925
 msgid "-foffload-abi=[lp64|ilp32]     Set the ABI to use in an offload compiler."
 msgstr ""
 
-#: common.opt:1924
+#: common.opt:1928
 #, fuzzy, c-format
 msgid "unknown offload ABI %qs"
 msgstr "onbekende machine-modus %qs"
 
-#: common.opt:1934
+#: common.opt:1938
 msgid "When possible do not generate stack frames."
 msgstr ""
 
-#: common.opt:1938
+#: common.opt:1942
 #, fuzzy
 msgid "Enable all optimization info dumps on stderr."
 msgstr "lege declaratie"
 
-#: common.opt:1942
+#: common.opt:1946
 msgid "-fopt-info[-<type>=filename]\tDump compiler optimization details."
 msgstr ""
 
-#: common.opt:1950
+#: common.opt:1954
 msgid "Optimize sibling and tail recursive calls."
 msgstr ""
 
-#: common.opt:1954
+#: common.opt:1958
 #, fuzzy
 msgid "Perform partial inlining."
 msgstr "recursieve inlining"
 
-#: common.opt:1958 common.opt:1962
+#: common.opt:1962 common.opt:1966
 msgid "Report on memory allocation before interprocedural optimization."
 msgstr ""
 
-#: common.opt:1966
+#: common.opt:1970
 msgid "Pack structure members together without holes."
 msgstr ""
 
-#: common.opt:1970
+#: common.opt:1974
 msgid "-fpack-struct=<number>\tSet initial maximum structure member alignment."
 msgstr ""
 
-#: common.opt:1974
+#: common.opt:1978
 msgid "Return small aggregates in memory, not registers."
 msgstr ""
 
-#: common.opt:1978
+#: common.opt:1982
 #, fuzzy
 msgid "Perform loop peeling."
 msgstr "recursieve inlining"
 
-#: common.opt:1982
+#: common.opt:1986
 #, fuzzy
 msgid "Enable machine specific peephole optimizations."
 msgstr "lege declaratie"
 
-#: common.opt:1986
+#: common.opt:1990
 msgid "Enable an RTL peephole pass before sched2."
 msgstr ""
 
-#: common.opt:1990
+#: common.opt:1994
 #, fuzzy
 msgid "Generate position-independent code if possible (large mode)."
 msgstr "Positie-onafhankelijke code wordt niet ondersteund.  Genegeerd"
 
-#: common.opt:1994
+#: common.opt:1998
 #, fuzzy
 msgid "Generate position-independent code for executables if possible (large mode)."
 msgstr "Positie-onafhankelijke code wordt niet ondersteund.  Genegeerd"
 
-#: common.opt:1998
+#: common.opt:2002
 #, fuzzy
 msgid "Generate position-independent code if possible (small mode)."
 msgstr "Positie-onafhankelijke code wordt niet ondersteund.  Genegeerd"
 
-#: common.opt:2002
+#: common.opt:2006
 #, fuzzy
 msgid "Generate position-independent code for executables if possible (small mode)."
 msgstr "Positie-onafhankelijke code wordt niet ondersteund.  Genegeerd"
 
-#: common.opt:2006
+#: common.opt:2010
 msgid "Use PLT for PIC calls (-fno-plt: load the address from GOT at call site)."
 msgstr ""
 
-#: common.opt:2010
+#: common.opt:2014
 msgid "Specify a plugin to load."
 msgstr ""
 
-#: common.opt:2014
+#: common.opt:2018
 msgid "-fplugin-arg-<name>-<key>[=<value>]\tSpecify argument <key>=<value> for plugin <name>."
 msgstr ""
 
-#: common.opt:2018
+#: common.opt:2022
 msgid "Run predictive commoning optimization."
 msgstr ""
 
-#: common.opt:2022
+#: common.opt:2026
 msgid "Generate prefetch instructions, if available, for arrays in loops."
 msgstr ""
 
-#: common.opt:2026
+#: common.opt:2030
 msgid "Enable basic program profiling code."
 msgstr ""
 
-#: common.opt:2030
+#: common.opt:2034
 msgid "Generate absolute source path names for gcov."
 msgstr ""
 
-#: common.opt:2034
+#: common.opt:2038
 msgid "Insert arc-based program profiling code."
 msgstr ""
 
-#: common.opt:2038
+#: common.opt:2042
 msgid "Set the top-level directory for storing the profile data. The default is 'pwd'."
 msgstr ""
 
-#: common.opt:2043
+#: common.opt:2047
 msgid "Enable correction of flow inconsistent profile data input."
 msgstr ""
 
-#: common.opt:2047
+#: common.opt:2051
 msgid "-fprofile-update=[single|atomic|prefer-atomic]\tSet the profile update method."
 msgstr ""
 
-#: common.opt:2050
+#: common.opt:2054
 #, fuzzy, c-format
 msgid "unknown profile update method %qs"
 msgstr "onbekende machine-modus %qs"
 
-#: common.opt:2063
+#: common.opt:2067
 msgid "Enable common options for generating profile info for profile feedback directed optimizations."
 msgstr ""
 
-#: common.opt:2067
+#: common.opt:2071
 msgid "Enable common options for generating profile info for profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr ""
 
-#: common.opt:2071
+#: common.opt:2075
 msgid "Enable common options for performing profile feedback directed optimizations."
 msgstr ""
 
-#: common.opt:2075
+#: common.opt:2079
 msgid "Enable common options for performing profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr ""
 
-#: common.opt:2079
+#: common.opt:2083
 msgid "Insert code to profile values of expressions."
 msgstr ""
 
-#: common.opt:2083
+#: common.opt:2087
 msgid "Report on consistency of profile."
 msgstr ""
 
-#: common.opt:2087
+#: common.opt:2091
 msgid "Enable function reordering that improves code placement."
 msgstr ""
 
-#: common.opt:2091
+#: common.opt:2095
 #, fuzzy
 msgid "Insert NOP instructions at each function entry."
 msgstr "instructie met predicaat in voorwaardelijke sequentie"
 
-#: common.opt:2098
+#: common.opt:2102
 msgid "-frandom-seed=<string>\tMake compile reproducible using <string>."
 msgstr ""
 
-#: common.opt:2108
+#: common.opt:2112
 msgid "Record gcc command line switches in the object file."
 msgstr ""
 
-#: common.opt:2112
+#: common.opt:2116
 msgid "Return small aggregates in registers."
 msgstr ""
 
-#: common.opt:2120
+#: common.opt:2124
 msgid "Tell DSE that the storage for a C++ object is dead when the constructor starts and when the destructor finishes."
 msgstr ""
 
-#: common.opt:2128
+#: common.opt:2132
 msgid "Relief of register pressure through live range shrinkage."
 msgstr ""
 
-#: common.opt:2132
+#: common.opt:2136
 #, fuzzy
 msgid "Perform a register renaming optimization pass."
 msgstr "lege declaratie"
 
-#: common.opt:2136
+#: common.opt:2140
 msgid "Perform a target dependent instruction fusion optimization pass."
 msgstr ""
 
-#: common.opt:2140
+#: common.opt:2144
 msgid "Reorder basic blocks to improve code placement."
 msgstr ""
 
-#: common.opt:2144
+#: common.opt:2148
 msgid "-freorder-blocks-algorithm=[simple|stc]\tSet the used basic block reordering algorithm."
 msgstr ""
 
-#: common.opt:2147
+#: common.opt:2151
 #, fuzzy, c-format
 msgid "unknown basic block reordering algorithm %qs"
 msgstr "onbekende machine-modus %qs"
 
-#: common.opt:2157
+#: common.opt:2161
 msgid "Reorder basic blocks and partition into hot and cold sections."
 msgstr ""
 
-#: common.opt:2161
+#: common.opt:2165
 msgid "Reorder functions to improve code placement."
 msgstr ""
 
-#: common.opt:2165
+#: common.opt:2169
 msgid "Add a common subexpression elimination pass after loop optimizations."
 msgstr ""
 
-#: common.opt:2173
+#: common.opt:2177
 msgid "Disable optimizations that assume default FP rounding behavior."
 msgstr ""
 
-#: common.opt:2177
+#: common.opt:2181
 msgid "Enable scheduling across basic blocks."
 msgstr ""
 
-#: common.opt:2181
+#: common.opt:2185
 msgid "Enable register pressure sensitive insn scheduling."
 msgstr ""
 
-#: common.opt:2185
+#: common.opt:2189
 msgid "Allow speculative motion of non-loads."
 msgstr ""
 
-#: common.opt:2189
+#: common.opt:2193
 msgid "Allow speculative motion of some loads."
 msgstr ""
 
-#: common.opt:2193
+#: common.opt:2197
 msgid "Allow speculative motion of more loads."
 msgstr ""
 
-#: common.opt:2197
+#: common.opt:2201
 msgid "-fsched-verbose=<number>\tSet the verbosity level of the scheduler."
 msgstr ""
 
-#: common.opt:2201
+#: common.opt:2205
 msgid "If scheduling post reload, do superblock scheduling."
 msgstr ""
 
-#: common.opt:2209
+#: common.opt:2213
 msgid "Reschedule instructions before register allocation."
 msgstr ""
 
-#: common.opt:2213
+#: common.opt:2217
 #, fuzzy
 msgid "Reschedule instructions after register allocation."
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: common.opt:2220
+#: common.opt:2224
 msgid "Schedule instructions using selective scheduling algorithm."
 msgstr ""
 
-#: common.opt:2224
+#: common.opt:2228
 msgid "Run selective scheduling after reload."
 msgstr ""
 
-#: common.opt:2228
+#: common.opt:2232
 msgid "Run self-tests, using the given path to locate test files."
 msgstr ""
 
-#: common.opt:2232
+#: common.opt:2236
 msgid "Perform software pipelining of inner loops during selective scheduling."
 msgstr ""
 
-#: common.opt:2236
+#: common.opt:2240
 msgid "Perform software pipelining of outer loops during selective scheduling."
 msgstr ""
 
-#: common.opt:2240
+#: common.opt:2244
 msgid "Reschedule pipelined regions without pipelining."
 msgstr ""
 
-#: common.opt:2244
+#: common.opt:2248
 msgid "Allow interposing function (or variables) by ones with different semantics (or initializer) respectively by dynamic linker."
 msgstr ""
 
-#: common.opt:2250
+#: common.opt:2254
 msgid "Allow premature scheduling of queued insns."
 msgstr ""
 
-#: common.opt:2254
+#: common.opt:2258
 msgid "-fsched-stalled-insns=<number>\tSet number of queued insns that can be prematurely scheduled."
 msgstr ""
 
-#: common.opt:2262
+#: common.opt:2266
 msgid "Set dependence distance checking in premature scheduling of queued insns."
 msgstr ""
 
-#: common.opt:2266
+#: common.opt:2270
 msgid "-fsched-stalled-insns-dep=<number>\tSet dependence distance checking in premature scheduling of queued insns."
 msgstr ""
 
-#: common.opt:2270
+#: common.opt:2274
 #, fuzzy
 msgid "Enable the group heuristic in the scheduler."
 msgstr "lege declaratie"
 
-#: common.opt:2274
+#: common.opt:2278
 msgid "Enable the critical path heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2278
+#: common.opt:2282
 #, fuzzy
 msgid "Enable the speculative instruction heuristic in the scheduler."
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: common.opt:2282
+#: common.opt:2286
 #, fuzzy
 msgid "Enable the rank heuristic in the scheduler."
 msgstr "lege declaratie"
 
-#: common.opt:2286
+#: common.opt:2290
 #, fuzzy
 msgid "Enable the last instruction heuristic in the scheduler."
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: common.opt:2290
+#: common.opt:2294
 msgid "Enable the dependent count heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2294
+#: common.opt:2298
 msgid "Access data in the same section from shared anchor points."
 msgstr ""
 
-#: common.opt:2306
+#: common.opt:2310
 msgid "Turn on Redundant Extensions Elimination pass."
 msgstr ""
 
-#: common.opt:2310
+#: common.opt:2314
 msgid "Show column numbers in diagnostics, when available.  Default on."
 msgstr ""
 
-#: common.opt:2314
+#: common.opt:2318
 msgid "Emit function prologues only before parts of the function that need it, rather than at the top of the function."
 msgstr ""
 
-#: common.opt:2319
+#: common.opt:2323
 msgid "Shrink-wrap parts of the prologue and epilogue separately."
 msgstr ""
 
-#: common.opt:2323
+#: common.opt:2327
 msgid "Disable optimizations observable by IEEE signaling NaNs."
 msgstr ""
 
-#: common.opt:2327
+#: common.opt:2331
 msgid "Disable floating point optimizations that ignore the IEEE signedness of zero."
 msgstr ""
 
-#: common.opt:2331
+#: common.opt:2335
 #, fuzzy
 msgid "Convert floating point constants to single precision constants."
 msgstr "floating-point fout bij het uitschrijven van een constante"
 
-#: common.opt:2335
+#: common.opt:2339
 msgid "Split lifetimes of induction variables when loops are unrolled."
 msgstr ""
 
-#: common.opt:2339
+#: common.opt:2343
 msgid "Generate discontiguous stack frames."
 msgstr ""
 
-#: common.opt:2343
+#: common.opt:2347
 msgid "Split wide types into independent registers."
 msgstr ""
 
-#: common.opt:2347
+#: common.opt:2351
 #, fuzzy
 msgid "Enable backward propagation of use properties at the SSA level."
 msgstr "lege declaratie"
 
-#: common.opt:2351
+#: common.opt:2355
 msgid "Optimize conditional patterns using SSA PHI nodes."
 msgstr ""
 
-#: common.opt:2355
+#: common.opt:2359
 msgid "Optimize amount of stdarg registers saved to stack at start of function."
 msgstr ""
 
-#: common.opt:2359
+#: common.opt:2363
 msgid "Apply variable expansion when loops are unrolled."
 msgstr ""
 
-#: common.opt:2363
+#: common.opt:2367
 msgid "-fstack-check=[no|generic|specific]\tInsert stack checking code into the program."
 msgstr ""
 
-#: common.opt:2367
+#: common.opt:2371
 msgid "Insert stack checking code into the program.  Same as -fstack-check=specific."
 msgstr ""
 
-#: common.opt:2371
+#: common.opt:2375
 msgid "Insert code to probe each page of stack space as it is allocated to protect from stack-clash style attacks."
 msgstr ""
 
-#: common.opt:2379
+#: common.opt:2383
 msgid "-fstack-limit-register=<register>\tTrap if the stack goes past <register>."
 msgstr ""
 
-#: common.opt:2383
+#: common.opt:2387
 msgid "-fstack-limit-symbol=<name>\tTrap if the stack goes past symbol <name>."
 msgstr ""
 
-#: common.opt:2387
+#: common.opt:2391
 #, fuzzy
 msgid "Use propolice as a stack protection method."
 msgstr "ISO C verbiedt geneste functies"
 
-#: common.opt:2391
+#: common.opt:2395
 #, fuzzy
 msgid "Use a stack protection method for every function."
 msgstr "ISO C verbiedt geneste functies"
 
-#: common.opt:2395
+#: common.opt:2399
 #, fuzzy
 msgid "Use a smart stack protection method for certain functions."
 msgstr "ISO C verbiedt geneste functies"
 
-#: common.opt:2399
+#: common.opt:2403
 msgid "Use stack protection method only for functions with the stack_protect attribute."
 msgstr ""
 
-#: common.opt:2403
+#: common.opt:2407
 msgid "Output stack usage information on a per-function basis."
 msgstr ""
 
-#: common.opt:2415
+#: common.opt:2419
 msgid "Assume strict aliasing rules apply."
 msgstr ""
 
-#: common.opt:2419
+#: common.opt:2423
 msgid "Treat signed overflow as undefined.  Negated as -fwrapv -fwrapv-pointer."
 msgstr ""
 
-#: common.opt:2423
+#: common.opt:2427
 msgid "Implement __atomic operations via libcalls to legacy __sync functions."
 msgstr ""
 
-#: common.opt:2427
+#: common.opt:2431
 msgid "Check for syntax errors, then stop."
 msgstr ""
 
-#: common.opt:2431
+#: common.opt:2435
 msgid "Create data files needed by \"gcov\"."
 msgstr ""
 
-#: common.opt:2435
+#: common.opt:2439
 #, fuzzy
 msgid "Perform jump threading optimizations."
 msgstr "lege declaratie"
 
-#: common.opt:2439
+#: common.opt:2443
 msgid "Report the time taken by each compiler pass."
 msgstr ""
 
-#: common.opt:2443
+#: common.opt:2447
 msgid "Record times taken by sub-phases separately."
 msgstr ""
 
-#: common.opt:2447
+#: common.opt:2451
 msgid "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tSet the default thread-local storage code generation model."
 msgstr ""
 
-#: common.opt:2450
+#: common.opt:2454
 #, fuzzy, c-format
 msgid "unknown TLS model %qs"
 msgstr "onbekende machine-modus %qs"
 
-#: common.opt:2466
+#: common.opt:2470
 msgid "Reorder top level functions, variables, and asms."
 msgstr ""
 
-#: common.opt:2470
+#: common.opt:2474
 msgid "Perform superblock formation via tail duplication."
 msgstr ""
 
-#: common.opt:2474
+#: common.opt:2478
 msgid "For targets that normally need trampolines for nested functions, always generate them instead of using descriptors."
 msgstr ""
 
-#: common.opt:2482
+#: common.opt:2486
 #, fuzzy
 msgid "Assume floating-point operations can trap."
 msgstr "floating-point constante buiten bereik"
 
-#: common.opt:2486
+#: common.opt:2490
 msgid "Trap for signed overflow in addition, subtraction and multiplication."
 msgstr ""
 
-#: common.opt:2490
+#: common.opt:2494
 #, fuzzy
 msgid "Enable SSA-CCP optimization on trees."
 msgstr "lege declaratie"
 
-#: common.opt:2494
+#: common.opt:2498
 #, fuzzy
 msgid "Enable SSA-BIT-CCP optimization on trees."
 msgstr "lege declaratie"
 
-#: common.opt:2502
+#: common.opt:2506
 #, fuzzy
 msgid "Enable loop header copying on trees."
 msgstr "lege declaratie"
 
-#: common.opt:2510
+#: common.opt:2514
 #, fuzzy
 msgid "Enable SSA coalescing of user variables."
 msgstr "lege declaratie"
 
-#: common.opt:2518
+#: common.opt:2522
 #, fuzzy
 msgid "Enable copy propagation on trees."
 msgstr "lege declaratie"
 
-#: common.opt:2526
+#: common.opt:2530
 #, fuzzy
 msgid "Transform condition stores into unconditional ones."
 msgstr "types in voorwaardelijke expressie komen niet overeen"
 
-#: common.opt:2530
+#: common.opt:2534
 msgid "Perform conversions of switch initializations."
 msgstr ""
 
-#: common.opt:2534
+#: common.opt:2538
 #, fuzzy
 msgid "Enable SSA dead code elimination optimization on trees."
 msgstr "lege declaratie"
 
-#: common.opt:2538
+#: common.opt:2542
 #, fuzzy
 msgid "Enable dominator optimizations."
 msgstr "lege declaratie"
 
-#: common.opt:2542
+#: common.opt:2546
 #, fuzzy
 msgid "Enable tail merging on trees."
 msgstr "lege declaratie"
 
-#: common.opt:2546
+#: common.opt:2550
 #, fuzzy
 msgid "Enable dead store elimination."
 msgstr "lege declaratie"
 
-#: common.opt:2550
+#: common.opt:2554
 #, fuzzy
 msgid "Enable forward propagation on trees."
 msgstr "lege declaratie"
 
-#: common.opt:2554
+#: common.opt:2558
 #, fuzzy
 msgid "Enable Full Redundancy Elimination (FRE) on trees."
 msgstr "lege declaratie"
 
-#: common.opt:2558
+#: common.opt:2562
 #, fuzzy
 msgid "Enable string length optimizations on trees."
 msgstr "lege declaratie"
 
-#: common.opt:2562
+#: common.opt:2566
 msgid "Detect paths that trigger erroneous or undefined behavior due to dereferencing a null pointer.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
-#: common.opt:2568
+#: common.opt:2572
 msgid "Detect paths that trigger erroneous or undefined behavior due to a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
-#: common.opt:2575
+#: common.opt:2579
 #, fuzzy
 msgid "Enable loop distribution on trees."
 msgstr "lege declaratie"
 
-#: common.opt:2579
+#: common.opt:2583
 #, fuzzy
 msgid "Enable loop distribution for patterns transformed into a library call."
 msgstr "lege declaratie"
 
-#: common.opt:2583
+#: common.opt:2587
 #, fuzzy
 msgid "Enable loop invariant motion on trees."
 msgstr "lege declaratie"
 
-#: common.opt:2591
+#: common.opt:2595
 msgid "Create canonical induction variables in loops."
 msgstr ""
 
-#: common.opt:2595
+#: common.opt:2599
 #, fuzzy
 msgid "Enable loop optimizations on tree level."
 msgstr "lege declaratie"
 
-#: common.opt:2599
+#: common.opt:2603
 msgid "-ftree-parallelize-loops=<number>\tEnable automatic parallelization of loops."
 msgstr ""
 
-#: common.opt:2603
+#: common.opt:2607
 msgid "Enable hoisting loads from conditional pointers."
 msgstr ""
 
-#: common.opt:2607
+#: common.opt:2611
 #, fuzzy
 msgid "Enable SSA-PRE optimization on trees."
 msgstr "lege declaratie"
 
-#: common.opt:2611
+#: common.opt:2615
 msgid "In SSA-PRE optimization on trees, enable partial-partial redundancy elimination."
 msgstr ""
 
-#: common.opt:2615
+#: common.opt:2619
 msgid "Perform function-local points-to analysis on trees."
 msgstr ""
 
-#: common.opt:2619
+#: common.opt:2623
 #, fuzzy
 msgid "Enable reassociation on tree level."
 msgstr "lege declaratie"
 
-#: common.opt:2627
+#: common.opt:2631
 #, fuzzy
 msgid "Enable SSA code sinking on trees."
 msgstr "lege declaratie"
 
-#: common.opt:2631
+#: common.opt:2635
 msgid "Perform straight-line strength reduction."
 msgstr ""
 
-#: common.opt:2635
+#: common.opt:2639
 msgid "Perform scalar replacement of aggregates."
 msgstr ""
 
-#: common.opt:2639
+#: common.opt:2643
 msgid "Replace temporary expressions in the SSA->normal pass."
 msgstr ""
 
-#: common.opt:2643
+#: common.opt:2647
 msgid "Perform live range splitting during the SSA->normal pass."
 msgstr ""
 
-#: common.opt:2647
+#: common.opt:2651
 #, fuzzy
 msgid "Perform Value Range Propagation on trees."
 msgstr "lege declaratie"
 
-#: common.opt:2651
+#: common.opt:2655
 msgid "Split paths leading to loop backedges."
 msgstr ""
 
-#: common.opt:2655
+#: common.opt:2659
 msgid "Assume common declarations may be overridden with ones with a larger trailing array."
 msgstr ""
 
-#: common.opt:2660
+#: common.opt:2664
 msgid "Compile whole compilation unit at a time."
 msgstr ""
 
-#: common.opt:2664
+#: common.opt:2668
 msgid "Perform loop unrolling when iteration count is known."
 msgstr ""
 
-#: common.opt:2668
+#: common.opt:2672
 msgid "Perform loop unrolling for all loops."
 msgstr ""
 
-#: common.opt:2679
+#: common.opt:2683
 msgid "Allow optimization for floating-point arithmetic which may change the result of the operation due to rounding."
 msgstr ""
 
-#: common.opt:2684
+#: common.opt:2688
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr ""
 
-#: common.opt:2692
+#: common.opt:2696
 msgid "Allow math optimizations that may violate IEEE or ISO standards."
 msgstr ""
 
-#: common.opt:2696
+#: common.opt:2700
 #, fuzzy
 msgid "Perform loop unswitching."
 msgstr "recursieve inlining"
 
-#: common.opt:2700
+#: common.opt:2704
 #, fuzzy
 msgid "Perform loop splitting."
 msgstr "recursieve inlining"
 
-#: common.opt:2704
+#: common.opt:2708
 msgid "Just generate unwind tables for exception handling."
 msgstr ""
 
-#: common.opt:2708
+#: common.opt:2712
 msgid "Use the bfd linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2712
+#: common.opt:2716
 msgid "Use the gold linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2724
+#: common.opt:2728
 #, fuzzy
 msgid "Perform variable tracking."
 msgstr "recursieve inlining"
 
-#: common.opt:2732
+#: common.opt:2736
 msgid "Perform variable tracking by annotating assignments."
 msgstr ""
 
-#: common.opt:2738
+#: common.opt:2742
 msgid "Toggle -fvar-tracking-assignments."
 msgstr ""
 
-#: common.opt:2746
+#: common.opt:2750
 msgid "Perform variable tracking and also tag variables that are uninitialized."
 msgstr ""
 
-#: common.opt:2751
+#: common.opt:2755
 #, fuzzy
 msgid "Enable vectorization on trees."
 msgstr "lege declaratie"
 
-#: common.opt:2759
+#: common.opt:2763
 #, fuzzy
 msgid "Enable loop vectorization on trees."
 msgstr "lege declaratie"
 
-#: common.opt:2763
+#: common.opt:2767
 #, fuzzy
 msgid "Enable basic block vectorization (SLP) on trees."
 msgstr "lege declaratie"
 
-#: common.opt:2767
+#: common.opt:2771
 msgid "Specifies the cost model for vectorization. -fvect-cost-model=[unlimited|dynamic|cheap]\tSpecifies the cost model for vectorization."
 msgstr ""
 
-#: common.opt:2772
+#: common.opt:2776
 msgid "-fsimd-cost-model=[unlimited|dynamic|cheap]\tSpecifies the vectorization cost model for code marked with a simd directive."
 msgstr ""
 
-#: common.opt:2775
+#: common.opt:2779
 #, fuzzy, c-format
 msgid "unknown vectorizer cost model %qs"
 msgstr "onbekende machine-modus %qs"
 
-#: common.opt:2788
+#: common.opt:2792
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr ""
 
-#: common.opt:2796
+#: common.opt:2800
 #, fuzzy
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr "lege declaratie"
 
-#: common.opt:2806
+#: common.opt:2810
 msgid "Add extra commentary to assembler output."
 msgstr ""
 
-#: common.opt:2810
+#: common.opt:2814
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility."
 msgstr ""
 
-#: common.opt:2813
+#: common.opt:2817
 #, c-format
 msgid "unrecognized visibility value %qs"
 msgstr "niet-herkende zichtbaarheidswaarde %qs"
 
-#: common.opt:2829
+#: common.opt:2833
 msgid "Validate vtable pointers before using them."
 msgstr ""
 
-#: common.opt:2832
+#: common.opt:2836
 #, fuzzy, c-format
 msgid "unknown vtable verify initialization priority %qs"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: common.opt:2845
+#: common.opt:2849
 msgid "Output vtable verification counters."
 msgstr ""
 
-#: common.opt:2849
+#: common.opt:2853
 msgid "Output vtable verification pointer sets information."
 msgstr ""
 
-#: common.opt:2853
+#: common.opt:2857
 msgid "Use expression value profiles in optimizations."
 msgstr ""
 
-#: common.opt:2857
+#: common.opt:2861
 msgid "Construct webs and split unrelated uses of single variable."
 msgstr ""
 
-#: common.opt:2861
+#: common.opt:2865
 #, fuzzy
 msgid "Enable conditional dead code elimination for builtin calls."
 msgstr "ongeldig register in de move-instructie"
 
-#: common.opt:2865
+#: common.opt:2869
 #, fuzzy
 msgid "Perform whole program optimizations."
 msgstr "lege declaratie"
 
-#: common.opt:2869
+#: common.opt:2873
 msgid "Assume pointer overflow wraps around."
 msgstr ""
 
-#: common.opt:2873
+#: common.opt:2877
 #, fuzzy
 #| msgid "Arithmetic overflow at %L"
 msgid "Assume signed arithmetic overflow wraps around."
 msgstr "Arithmetische overflow op %L"
 
-#: common.opt:2877
+#: common.opt:2881
 #, fuzzy
 msgid "Put zero initialized data in the bss section."
 msgstr "%qs is hier niet gedeclareerd (eerste gebruik in deze functie)"
 
-#: common.opt:2881
+#: common.opt:2885
 #, fuzzy
 msgid "Generate debug information in default format."
 msgstr "case-label niet in een switch-statement"
 
-#: common.opt:2885
+#: common.opt:2889
 msgid "Assume assembler support for (DWARF2+) .loc directives"
 msgstr ""
 
-#: common.opt:2889
+#: common.opt:2893
 msgid "Assume assembler support for view in (DWARF2+) .loc directives"
 msgstr ""
 
-#: common.opt:2892 common.opt:2896 common.opt:2900 common.opt:2904
+#: common.opt:2896 common.opt:2900 common.opt:2904 common.opt:2908
 #, fuzzy, c-format
 msgid "switch %qs no longer supported"
 msgstr "-pipe wordt niet ondersteund"
 
-#: common.opt:2909
+#: common.opt:2913
 msgid "Record DW_AT_decl_column and DW_AT_call_column in DWARF."
 msgstr ""
 
-#: common.opt:2913
+#: common.opt:2917
 msgid "Generate debug information in default version of DWARF format."
 msgstr ""
 
-#: common.opt:2917
+#: common.opt:2921
 msgid "Generate debug information in DWARF v2 (or later) format."
 msgstr ""
 
-#: common.opt:2921
+#: common.opt:2925
 msgid "Generate debug information in default extended format."
 msgstr ""
 
-#: common.opt:2925
+#: common.opt:2929
 msgid "Generate extended entry point information for inlined functions"
 msgstr ""
 
-#: common.opt:2929
+#: common.opt:2933
 msgid "Compute locview reset points based on insn length estimates"
 msgstr ""
 
-#: common.opt:2937
+#: common.opt:2941
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:2941
+#: common.opt:2945
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:2945
+#: common.opt:2949
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr ""
 
-#: common.opt:2949
+#: common.opt:2953
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr ""
 
-#: common.opt:2953
+#: common.opt:2957
 #, fuzzy
 msgid "Generate debug information in separate .dwo files."
 msgstr "instructie met predicaat in voorwaardelijke sequentie"
 
-#: common.opt:2957
+#: common.opt:2961
 msgid "Generate debug information in STABS format."
 msgstr ""
 
-#: common.opt:2961
+#: common.opt:2965
 msgid "Generate debug information in extended STABS format."
 msgstr ""
 
-#: common.opt:2965
+#: common.opt:2969
 msgid "Emit progressive recommended breakpoint locations."
 msgstr ""
 
-#: common.opt:2969
+#: common.opt:2973
 msgid "Don't emit DWARF additions beyond selected version."
 msgstr ""
 
-#: common.opt:2973
+#: common.opt:2977
 msgid "Toggle debug information generation."
 msgstr ""
 
-#: common.opt:2977
+#: common.opt:2981
 msgid "Augment variable location lists with progressive views."
 msgstr ""
 
-#: common.opt:2984
+#: common.opt:2988
 #, fuzzy
 msgid "Generate debug information in VMS format."
 msgstr "case-label niet in een switch-statement"
 
-#: common.opt:2988
+#: common.opt:2992
 msgid "Generate debug information in XCOFF format."
 msgstr ""
 
-#: common.opt:2992
+#: common.opt:2996
 msgid "Generate debug information in extended XCOFF format."
 msgstr ""
 
-#: common.opt:3010
+#: common.opt:3014
 #, fuzzy
 msgid "Generate compressed debug sections."
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: common.opt:3014
+#: common.opt:3018
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>."
 msgstr ""
 
-#: common.opt:3021
+#: common.opt:3025
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory."
 msgstr ""
 
-#: common.opt:3025
+#: common.opt:3029
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory."
 msgstr ""
 
-#: common.opt:3047
+#: common.opt:3051
 msgid "-o <file>\tPlace output into <file>."
 msgstr ""
 
-#: common.opt:3051
+#: common.opt:3055
 #, fuzzy
 msgid "Enable function profiling."
 msgstr "ingebouwde functie %qs kan niet uitgeschakeld worden"
 
-#: common.opt:3061
+#: common.opt:3065
 #, fuzzy
 #| msgid "Like -pedantic but issue them as errors"
 msgid "Like -pedantic but issue them as errors."
 msgstr "Zoals -pedantic, maar beschouw problemen als fouten"
 
-#: common.opt:3101
+#: common.opt:3105
 msgid "Do not display functions compiled or elapsed time."
 msgstr ""
 
 # kan beter
-#: common.opt:3133
+#: common.opt:3137
 #, fuzzy
 #| msgid "Enable verbose output"
 msgid "Enable verbose output."
 msgstr "Schakel uitgebreide boodschappen in"
 
-#: common.opt:3137
+#: common.opt:3141
 msgid "Display the compiler's version."
 msgstr ""
 
-#: common.opt:3141
+#: common.opt:3145
 #, fuzzy
 #| msgid "Suppress warnings"
 msgid "Suppress warnings."
 msgstr "Onderdruk waarschuwingen"
 
-#: common.opt:3151
+#: common.opt:3155
 msgid "Create a shared library."
 msgstr ""
 
-#: common.opt:3196
+#: common.opt:3200
 #, fuzzy
 msgid "Don't create a dynamically linked position independent executable."
 msgstr "Positie-onafhankelijke code wordt niet ondersteund.  Genegeerd"
 
-#: common.opt:3200
+#: common.opt:3204
 #, fuzzy
 msgid "Create a dynamically linked position independent executable."
 msgstr "Positie-onafhankelijke code wordt niet ondersteund.  Genegeerd"
 
-#: common.opt:3204
+#: common.opt:3208
 #, fuzzy
 msgid "Create a static position independent executable."
 msgstr "Positie-onafhankelijke code wordt niet ondersteund.  Genegeerd"
 
-#: common.opt:3211
+#: common.opt:3215
 msgid "Use caller save register across calls if possible."
 msgstr ""
 
-#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:598 cp/cvt.c:1308
+#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:599 cp/cvt.c:1308
 #: cp/cvt.c:1561
 #, fuzzy, gcc-internal-format
 msgid "value computed is not used"
@@ -16818,7 +16819,7 @@
 msgstr "ongeldige operand van %s"
 
 #: go/gofrontend/expressions.cc:4331 c/c-parser.c:13477 c/c-parser.c:13484
-#: cp/parser.c:33264 cp/parser.c:33271
+#: cp/parser.c:33261 cp/parser.c:33268
 #, fuzzy, gcc-internal-format
 msgid "expected integer"
 msgstr "ongeldige operand van %s"
@@ -17281,14 +17282,14 @@
 msgid "ignoring attribute %qE because it conflicts with attribute %qs"
 msgstr "attribuut %qE botst met attribuut %s"
 
-#: attribs.c:449 c-family/c-attribs.c:1894 cp/decl.c:13690 cp/friend.c:302
-#: cp/tree.c:4559
+#: attribs.c:449 c-family/c-attribs.c:1905 cp/decl.c:13714 cp/friend.c:302
+#: cp/tree.c:4607
 #, fuzzy, gcc-internal-format
 msgid "previous declaration here"
 msgstr "eerdere declaratie van %qs"
 
 #. Warn about and ignore all others for now, but store them.
-#: attribs.c:564 c-family/c-attribs.c:2717 objc/objc-act.c:4963
+#: attribs.c:564 c-family/c-attribs.c:2728 objc/objc-act.c:4963
 #: objc/objc-act.c:6932 objc/objc-act.c:8119 objc/objc-act.c:8170
 #, gcc-internal-format
 msgid "%qE attribute directive ignored"
@@ -17307,17 +17308,17 @@
 #. This is a c++11 attribute that appertains to a
 #. type-specifier, outside of the definition of, a class
 #. type.  Ignore it.
-#: attribs.c:590 cp/decl.c:10999
+#: attribs.c:590 cp/decl.c:11023
 #, gcc-internal-format
 msgid "attribute ignored"
 msgstr "attribuut wordt genegeerd"
 
-#: attribs.c:592 cp/decl.c:11000
+#: attribs.c:592 cp/decl.c:11024
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
 
-#: attribs.c:610 c-family/c-attribs.c:3219
+#: attribs.c:610 c-family/c-attribs.c:3230
 #, gcc-internal-format
 msgid "%qE attribute does not apply to types"
 msgstr "attribuut %qE heeft geen betekenis voor types"
@@ -17333,40 +17334,40 @@
 msgstr ""
 
 #: attribs.c:691 attribs.c:1622 attribs.c:1632 attribs.c:1642
-#: c-family/c-attribs.c:540 c-family/c-attribs.c:559 c-family/c-attribs.c:577
-#: c-family/c-attribs.c:607 c-family/c-attribs.c:628 c-family/c-attribs.c:649
-#: c-family/c-attribs.c:690 c-family/c-attribs.c:717 c-family/c-attribs.c:733
-#: c-family/c-attribs.c:750 c-family/c-attribs.c:766 c-family/c-attribs.c:792
-#: c-family/c-attribs.c:807 c-family/c-attribs.c:835 c-family/c-attribs.c:852
-#: c-family/c-attribs.c:870 c-family/c-attribs.c:893 c-family/c-attribs.c:931
-#: c-family/c-attribs.c:954 c-family/c-attribs.c:971 c-family/c-attribs.c:1000
-#: c-family/c-attribs.c:1021 c-family/c-attribs.c:1042
-#: c-family/c-attribs.c:1069 c-family/c-attribs.c:1099
-#: c-family/c-attribs.c:1136 c-family/c-attribs.c:1189
-#: c-family/c-attribs.c:1255 c-family/c-attribs.c:1313
-#: c-family/c-attribs.c:1402 c-family/c-attribs.c:1432
-#: c-family/c-attribs.c:1483 c-family/c-attribs.c:1998
-#: c-family/c-attribs.c:2035 c-family/c-attribs.c:2096
-#: c-family/c-attribs.c:2152 c-family/c-attribs.c:2230
-#: c-family/c-attribs.c:2312 c-family/c-attribs.c:2371
-#: c-family/c-attribs.c:2390 c-family/c-attribs.c:2498
-#: c-family/c-attribs.c:2514 c-family/c-attribs.c:2530
-#: c-family/c-attribs.c:2551 c-family/c-attribs.c:2608
-#: c-family/c-attribs.c:2635 c-family/c-attribs.c:2690
-#: c-family/c-attribs.c:2870 c-family/c-attribs.c:2891
-#: c-family/c-attribs.c:3004 c-family/c-attribs.c:3031
-#: c-family/c-attribs.c:3221 c-family/c-attribs.c:3239
-#: c-family/c-attribs.c:3262 c-family/c-attribs.c:3301
-#: c-family/c-attribs.c:3383 c-family/c-attribs.c:3439
-#: c-family/c-attribs.c:3455 c-family/c-attribs.c:3549
-#: c-family/c-common.c:5600 config/darwin.c:2072 config/arm/arm.c:6868
+#: c-family/c-attribs.c:547 c-family/c-attribs.c:566 c-family/c-attribs.c:584
+#: c-family/c-attribs.c:614 c-family/c-attribs.c:635 c-family/c-attribs.c:656
+#: c-family/c-attribs.c:697 c-family/c-attribs.c:728 c-family/c-attribs.c:744
+#: c-family/c-attribs.c:761 c-family/c-attribs.c:777 c-family/c-attribs.c:803
+#: c-family/c-attribs.c:818 c-family/c-attribs.c:846 c-family/c-attribs.c:863
+#: c-family/c-attribs.c:881 c-family/c-attribs.c:904 c-family/c-attribs.c:942
+#: c-family/c-attribs.c:965 c-family/c-attribs.c:982 c-family/c-attribs.c:1011
+#: c-family/c-attribs.c:1032 c-family/c-attribs.c:1053
+#: c-family/c-attribs.c:1080 c-family/c-attribs.c:1110
+#: c-family/c-attribs.c:1147 c-family/c-attribs.c:1200
+#: c-family/c-attribs.c:1266 c-family/c-attribs.c:1324
+#: c-family/c-attribs.c:1413 c-family/c-attribs.c:1443
+#: c-family/c-attribs.c:1494 c-family/c-attribs.c:2009
+#: c-family/c-attribs.c:2046 c-family/c-attribs.c:2107
+#: c-family/c-attribs.c:2163 c-family/c-attribs.c:2241
+#: c-family/c-attribs.c:2323 c-family/c-attribs.c:2382
+#: c-family/c-attribs.c:2401 c-family/c-attribs.c:2509
+#: c-family/c-attribs.c:2525 c-family/c-attribs.c:2541
+#: c-family/c-attribs.c:2562 c-family/c-attribs.c:2619
+#: c-family/c-attribs.c:2646 c-family/c-attribs.c:2701
+#: c-family/c-attribs.c:2881 c-family/c-attribs.c:2902
+#: c-family/c-attribs.c:3015 c-family/c-attribs.c:3042
+#: c-family/c-attribs.c:3232 c-family/c-attribs.c:3250
+#: c-family/c-attribs.c:3273 c-family/c-attribs.c:3312
+#: c-family/c-attribs.c:3394 c-family/c-attribs.c:3450
+#: c-family/c-attribs.c:3466 c-family/c-attribs.c:3560
+#: c-family/c-common.c:5598 config/darwin.c:2072 config/arm/arm.c:6868
 #: config/arm/arm.c:6896 config/arm/arm.c:6913 config/avr/avr.c:9698
-#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6497
-#: config/i386/i386.c:41520 config/ia64/ia64.c:788
-#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33056
-#: config/spu/spu.c:3743 ada/gcc-interface/utils.c:6244
-#: ada/gcc-interface/utils.c:6261 ada/gcc-interface/utils.c:6277
-#: ada/gcc-interface/utils.c:6303 brig/brig-lang.c:476 lto/lto-lang.c:283
+#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6500
+#: config/i386/i386.c:41514 config/ia64/ia64.c:788
+#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33112
+#: config/spu/spu.c:3743 ada/gcc-interface/utils.c:6249
+#: ada/gcc-interface/utils.c:6266 ada/gcc-interface/utils.c:6282
+#: ada/gcc-interface/utils.c:6308 brig/brig-lang.c:476 lto/lto-lang.c:283
 #, gcc-internal-format
 msgid "%qE attribute ignored"
 msgstr "attribuut %qE wordt genegeerd"
@@ -17737,73 +17738,88 @@
 msgid "%Kattempt to free a non-heap object"
 msgstr ""
 
-#: calls.c:1434
+#: calls.c:1291 file-prefix-map.c:50
 #, fuzzy, gcc-internal-format
+msgid "invalid argument %qs to %qs"
+msgstr "ongeldige waarde voor %%C"
+
+#: calls.c:1452
+#, fuzzy, gcc-internal-format
 msgid "%Kargument %i value %qE is negative"
 msgstr "functie-oproep heeft geaggregeerde waarde"
 
-#: calls.c:1452
+#: calls.c:1470
 #, gcc-internal-format
 msgid "%Kargument %i value is zero"
 msgstr ""
 
-#: calls.c:1469
+#: calls.c:1487
 #, gcc-internal-format
 msgid "%Kargument %i value %qE exceeds maximum object size %E"
 msgstr ""
 
-#: calls.c:1483
+#: calls.c:1501
 #, fuzzy, gcc-internal-format
 msgid "%Kargument %i range [%E, %E] is negative"
 msgstr "functie-oproep heeft geaggregeerde waarde"
 
-#: calls.c:1490
+#: calls.c:1508
 #, gcc-internal-format
 msgid "%Kargument %i range [%E, %E] exceeds maximum object size %E"
 msgstr ""
 
-#: calls.c:1520
+#: calls.c:1538
 #, gcc-internal-format
 msgid "%Kproduct %<%E * %E%> of arguments %i and %i exceeds %<SIZE_MAX%>"
 msgstr ""
 
-#: calls.c:1526
+#: calls.c:1544
 #, gcc-internal-format
 msgid "%Kproduct %<%E * %E%> of arguments %i and %i exceeds maximum object size %E"
 msgstr ""
 
-#: calls.c:1537 calls.c:1540
+#: calls.c:1555 calls.c:1558
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be in the range 0..15"
 msgid "argument %i in the range [%E, %E]"
 msgstr "het derde argument moet in het bereik 0..15 liggen"
 
-#: calls.c:1551
+#: calls.c:1569
 #, fuzzy, gcc-internal-format
 msgid "in a call to built-in allocation function %qD"
 msgstr "kan functie %<main%> niet inline maken"
 
-#: calls.c:1554
+#: calls.c:1572
 #, fuzzy, gcc-internal-format
 msgid "in a call to allocation function %qD declared here"
 msgstr "%Jgeneste functie %qD gedeclareerd maar niet gedefinieerd"
 
-#: calls.c:1711
+#: calls.c:1835
 #, gcc-internal-format
-msgid "%qD argument %i declared attribute %<nonstring%> is smaller than the specified bound %E"
+msgid "%qD argument %i declared attribute %<nonstring%> is smaller than the specified bound %wu"
 msgstr ""
 
-#: calls.c:1716
+#: calls.c:1841
+#, gcc-internal-format
+msgid "%qD argument %i declared attribute %<nonstring%> is smaller than the specified bound [%E, %E]"
+msgstr ""
+
+#: calls.c:1847
+#, gcc-internal-format
+msgid "%qD argument %i declared attribute %<nonstring%> may be smaller than the specified bound [%E, %E]"
+msgstr ""
+
+#: calls.c:1857
 #, fuzzy, gcc-internal-format
 msgid "%qD argument %i declared attribute %<nonstring%>"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: calls.c:1721
+#: calls.c:1862
 #, fuzzy, gcc-internal-format
 msgid "argument %qD declared here"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: calls.c:1735
+#: calls.c:1876
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "[cannot find %s]"
 msgid "cannot tail-call: %s"
@@ -17810,17 +17826,17 @@
 msgstr "[kan %s niet vinden]"
 
 # dit klinkt niet al te best
-#: calls.c:3365
+#: calls.c:3506
 #, gcc-internal-format
 msgid "function call has aggregate value"
 msgstr "functie-oproep heeft geaggregeerde waarde"
 
-#: calls.c:4059
+#: calls.c:4200
 #, fuzzy, gcc-internal-format
 msgid "passing too large argument on stack"
 msgstr "%qs is geen iterator"
 
-#: cfgexpand.c:1665 function.c:1002 varasm.c:2231
+#: cfgexpand.c:1665 function.c:1002 varasm.c:2242
 #, fuzzy, gcc-internal-format
 msgid "size of variable %q+D is too large"
 msgstr "variabele %qs is te groot"
@@ -18393,237 +18409,237 @@
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr ""
 
-#: cgraph.c:3051
+#: cgraph.c:3056
 #, fuzzy, gcc-internal-format
 msgid "caller edge count invalid"
 msgstr "teller van links shift is negatief"
 
-#: cgraph.c:3135
+#: cgraph.c:3140
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr ""
 
-#: cgraph.c:3142
+#: cgraph.c:3147
 #, gcc-internal-format
 msgid "cgraph count invalid"
 msgstr ""
 
-#: cgraph.c:3147
+#: cgraph.c:3152
 #, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr ""
 
-#: cgraph.c:3152
+#: cgraph.c:3157
 #, gcc-internal-format
 msgid "local symbols must be defined"
 msgstr ""
 
-#: cgraph.c:3157
+#: cgraph.c:3162
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr ""
 
-#: cgraph.c:3162
+#: cgraph.c:3167
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr ""
 
-#: cgraph.c:3167
+#: cgraph.c:3172
 #, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr ""
 
-#: cgraph.c:3174
+#: cgraph.c:3179
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for indirect edge from %s"
 msgstr ""
 
-#: cgraph.c:3181
+#: cgraph.c:3186
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr ""
 
-#: cgraph.c:3196
+#: cgraph.c:3201
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr ""
 
-#: cgraph.c:3206
+#: cgraph.c:3211
 #, fuzzy, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr "sectie-pointer ontbreekt"
 
-#: cgraph.c:3211
+#: cgraph.c:3216
 #, gcc-internal-format
 msgid "multiple inline callers"
 msgstr ""
 
-#: cgraph.c:3218
+#: cgraph.c:3223
 #, fuzzy, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr "sectie-pointer ontbreekt"
 
-#: cgraph.c:3239
+#: cgraph.c:3244
 #, fuzzy, gcc-internal-format
 msgid "caller edge count does not match BB count"
 msgstr "teller van links shift is negatief"
 
-#: cgraph.c:3261
+#: cgraph.c:3266
 #, gcc-internal-format
 msgid "indirect call count does not match BB count"
 msgstr ""
 
-#: cgraph.c:3272
+#: cgraph.c:3277
 #, fuzzy, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr "sectie-pointer ontbreekt"
 
-#: cgraph.c:3277
+#: cgraph.c:3282
 #, fuzzy, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr "sectie-pointer ontbreekt"
 
-#: cgraph.c:3289
+#: cgraph.c:3294
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr ""
 
-#: cgraph.c:3301
+#: cgraph.c:3306
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr ""
 
-#: cgraph.c:3307
+#: cgraph.c:3312
 #, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr ""
 
-#: cgraph.c:3312
+#: cgraph.c:3317
 #, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr ""
 
-#: cgraph.c:3317
+#: cgraph.c:3322
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr ""
 
-#: cgraph.c:3329
+#: cgraph.c:3334
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr ""
 
-#: cgraph.c:3337
+#: cgraph.c:3342
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr ""
 
-#: cgraph.c:3342
+#: cgraph.c:3347
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr ""
 
-#: cgraph.c:3349
+#: cgraph.c:3354
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr ""
 
-#: cgraph.c:3358
+#: cgraph.c:3363
 #, gcc-internal-format
 msgid "Instrumentation clone does not reference original node"
 msgstr ""
 
-#: cgraph.c:3365
+#: cgraph.c:3370
 #, fuzzy, gcc-internal-format
 msgid "Not instrumented node has non-NULL original declaration"
 msgstr "de declaratie van %qs verbergt een parameter"
 
-#: cgraph.c:3375
+#: cgraph.c:3380
 #, fuzzy, gcc-internal-format
 msgid "Instrumented node has wrong original declaration"
 msgstr "de declaratie van %qs verbergt een parameter"
 
-#: cgraph.c:3393
+#: cgraph.c:3398
 #, gcc-internal-format
 msgid "Node has more than one chkp reference"
 msgstr ""
 
-#: cgraph.c:3398
+#: cgraph.c:3403
 #, fuzzy, gcc-internal-format
 msgid "Wrong node is referenced with chkp reference"
 msgstr "herhaald lid %qs"
 
-#: cgraph.c:3406
+#: cgraph.c:3411
 #, gcc-internal-format
 msgid "Analyzed node has no reference to instrumented version"
 msgstr ""
 
-#: cgraph.c:3420
+#: cgraph.c:3425
 #, gcc-internal-format
 msgid "Alias chain for instrumented node is broken"
 msgstr ""
 
-#: cgraph.c:3429
+#: cgraph.c:3434
 #, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3434
+#: cgraph.c:3439
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3439
+#: cgraph.c:3444
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr ""
 
-#: cgraph.c:3445
+#: cgraph.c:3450
 #, gcc-internal-format
 msgid "Instrumentation thunk has wrong edge callee"
 msgstr ""
 
-#: cgraph.c:3481
+#: cgraph.c:3486
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr ""
 
-#: cgraph.c:3489
+#: cgraph.c:3494
 #, fuzzy, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr "dit is een eerdere declaratie"
 
-#: cgraph.c:3498
+#: cgraph.c:3503
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr ""
 
-#: cgraph.c:3508
+#: cgraph.c:3513
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr ""
 
-#: cgraph.c:3518
+#: cgraph.c:3523
 #, fuzzy, gcc-internal-format
 msgid "reference to dead statement"
 msgstr "ongeldige beginwaarde"
 
-#: cgraph.c:3531
+#: cgraph.c:3536
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3543
+#: cgraph.c:3548
 #, gcc-internal-format, gfc-internal-format
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3554
+#: cgraph.c:3559
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr ""
 
-#: cgraph.c:3661 varpool.c:306
+#: cgraph.c:3666 varpool.c:306
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s: section %s is missing"
 msgstr "het argument van '-%s' ontbreekt"
@@ -18654,12 +18670,12 @@
 msgstr ""
 
 #. include_self=
-#: cgraphunit.c:981 c/c-decl.c:11282
+#: cgraphunit.c:981 c/c-decl.c:11302
 #, fuzzy, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "label %qs gebruikt maar niet gedefinieerd"
 
-#: cgraphunit.c:983 c/c-decl.c:11291
+#: cgraphunit.c:983 c/c-decl.c:11311
 #, fuzzy, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "label %qs gebruikt maar niet gedefinieerd"
@@ -18774,12 +18790,12 @@
 msgid "cannot find '%s'"
 msgstr "kan '%s' niet vinden"
 
-#: collect-utils.c:183 collect2.c:2361 collect2.c:2560 gcc.c:3080 gcc.c:6856
+#: collect-utils.c:183 collect2.c:2387 collect2.c:2586 gcc.c:3080 gcc.c:6856
 #, fuzzy, gcc-internal-format
 msgid "pex_init failed: %m"
 msgstr "pex_init mislukt"
 
-#: collect-utils.c:192 collect2.c:2370 collect2.c:2568 gcc.c:8498
+#: collect-utils.c:192 collect2.c:2396 collect2.c:2594 gcc.c:8498
 #, gcc-internal-format
 msgid "%s: %m"
 msgstr ""
@@ -18789,89 +18805,89 @@
 msgid "COLLECT_LTO_WRAPPER must be set"
 msgstr ""
 
-#: collect2.c:966 gcc.c:7382 lto-wrapper.c:1666
+#: collect2.c:969 gcc.c:7382 lto-wrapper.c:1692
 #: config/i386/intelmic-mkoffload.c:556 config/nvptx/mkoffload.c:405
 #, fuzzy, gcc-internal-format
 msgid "atexit failed"
 msgstr "pex_init mislukt"
 
-#: collect2.c:1064
+#: collect2.c:1067
 #, gcc-internal-format
 msgid "no arguments"
 msgstr "geen argumenten"
 
-#: collect2.c:1303 opts.c:904
+#: collect2.c:1311 opts.c:904
 #, fuzzy, gcc-internal-format
 msgid "LTO support has not been enabled in this configuration"
 msgstr "alias-definities worden niet ondersteund in deze configuratie; genegeerd"
 
-#: collect2.c:1344
+#: collect2.c:1352
 #, fuzzy, gcc-internal-format
 msgid "can't open %s: %m"
 msgstr "open %s"
 
-#: collect2.c:1450
+#: collect2.c:1472
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown demangling style '%s'"
 msgstr "onbekende machine-modus %qs"
 
-#: collect2.c:1546 collect2.c:1729 collect2.c:1769
+#: collect2.c:1574 collect2.c:1757 collect2.c:1797
 #, fuzzy, gcc-internal-format
 msgid "fopen %s: %m"
 msgstr "fopen %s"
 
-#: collect2.c:1549 collect2.c:1734 collect2.c:1772
+#: collect2.c:1577 collect2.c:1762 collect2.c:1800
 #, fuzzy, gcc-internal-format
 msgid "fclose %s: %m"
 msgstr "fclose %s"
 
-#: collect2.c:2335
+#: collect2.c:2361
 #, gcc-internal-format
 msgid "cannot find 'nm'"
 msgstr "kan 'nm' niet vinden"
 
-#: collect2.c:2383
+#: collect2.c:2409
 #, fuzzy, gcc-internal-format
 msgid "can't open nm output: %m"
 msgstr "kan uitvoer van nm niet openen"
 
-#: collect2.c:2467
+#: collect2.c:2493
 #, gcc-internal-format, gfc-internal-format
 msgid "init function found in object %s"
 msgstr "init-functie gevonden in object %s"
 
-#: collect2.c:2478
+#: collect2.c:2504
 #, gcc-internal-format, gfc-internal-format
 msgid "fini function found in object %s"
 msgstr "fini-functie gevonden in object %s"
 
-#: collect2.c:2535
+#: collect2.c:2561
 #, fuzzy, gcc-internal-format
 msgid "cannot find 'ldd'"
 msgstr "kan %<ldd%> niet vinden"
 
-#: collect2.c:2581
+#: collect2.c:2607
 #, fuzzy, gcc-internal-format
 msgid "can't open ldd output: %m"
 msgstr "kan uitvoer van ldd niet openen"
 
 # 'dependency'? 'afhankelijkheid' klinkt niet echt goed...
-#: collect2.c:2599
+#: collect2.c:2625
 #, gcc-internal-format, gfc-internal-format
 msgid "dynamic dependency %s not found"
 msgstr "dynamische dependency %s niet gevonden"
 
-#: collect2.c:2611
+#: collect2.c:2637
 #, gcc-internal-format, gfc-internal-format
 msgid "unable to open dynamic dependency '%s'"
 msgstr "kan dynamische dependency '%s' niet openen"
 
-#: collect2.c:2765
+#: collect2.c:2791
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: not a COFF file"
 msgstr "%s: geen COFF-bestand"
 
-#: collect2.c:2930
+#: collect2.c:2961
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: cannot open as COFF file"
 msgstr "%s: kan niet openen als COFF-bestand"
@@ -18880,7 +18896,7 @@
 # dikwijls 'bibliotheek' zien gebruiken.
 # De vertaalde boodschappen voor make gebruiken dat op het ogenblik wél, wat
 # jammer is (maar misschien is daar verandering in te brengen).
-#: collect2.c:2989
+#: collect2.c:3020
 #, gcc-internal-format, gfc-internal-format
 msgid "library lib%s not found"
 msgstr "library lib%s niet gevonden"
@@ -19091,12 +19107,12 @@
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr ""
 
-#: dwarf2out.c:10901
+#: dwarf2out.c:10909
 #, gcc-internal-format
 msgid "-gdwarf-6 is output as version 5 with incompatibilities"
 msgstr ""
 
-#: dwarf2out.c:14415
+#: dwarf2out.c:14423
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
@@ -19216,11 +19232,6 @@
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr ""
 
-#: file-prefix-map.c:50
-#, fuzzy, gcc-internal-format
-msgid "invalid argument %qs to %qs"
-msgstr "ongeldige waarde voor %%C"
-
 #: final.c:1868
 #, fuzzy, gcc-internal-format
 msgid "the frame size of %wd bytes is larger than %wd bytes"
@@ -19241,42 +19252,42 @@
 msgid "large fixed-point constant implicitly truncated to fixed-point type"
 msgstr "grote integer impliciet afgekapt naar 'unsigned' type"
 
-#: fold-const.c:4151 fold-const.c:4161
+#: fold-const.c:4157 fold-const.c:4167
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d due to width of bit-field"
 msgstr "vergelijking is altijd %d vanwege breedte van bit-veld"
 
-#: fold-const.c:5478 tree-ssa-reassoc.c:2374 tree-ssa-reassoc.c:3214
+#: fold-const.c:5484 tree-ssa-reassoc.c:2379 tree-ssa-reassoc.c:3219
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
 
-#: fold-const.c:5928 fold-const.c:5942
+#: fold-const.c:5934 fold-const.c:5948
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr ""
 
-#: fold-const.c:6085
+#: fold-const.c:6091
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr ""
 
-#: fold-const.c:6090
+#: fold-const.c:6096
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr ""
 
-#: fold-const.c:8310
+#: fold-const.c:8316
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr ""
 
-#: fold-const.c:8710
+#: fold-const.c:8716
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr ""
 
-#: fold-const.c:12063
+#: fold-const.c:12069
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr ""
@@ -19286,7 +19297,7 @@
 msgid "total size of local objects too large"
 msgstr "variabele %qs is te groot"
 
-#: function.c:1776 gimplify.c:6270
+#: function.c:1776 gimplify.c:6273
 #, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr ""
@@ -19592,7 +19603,7 @@
 msgid "%s: linker input file unused because linking not done"
 msgstr ""
 
-#: gcc.c:8420 c-family/c-opts.c:770
+#: gcc.c:8420 c-family/c-opts.c:768
 #, gcc-internal-format
 msgid "cannot use %<-%> as input filename for a precompiled header"
 msgstr ""
@@ -19829,7 +19840,7 @@
 msgid "%G%qD destination unchanged after copying no bytes"
 msgstr ""
 
-#: gimple-fold.c:2052 tree-ssa-strlen.c:2050
+#: gimple-fold.c:2052 tree-ssa-strlen.c:2074
 msgid "%G%qD specified bound %E equals destination size"
 msgstr ""
 
@@ -19851,12 +19862,12 @@
 msgid "null pointer dereference"
 msgstr "herhaald lid %qs"
 
-#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12451
-#: tree.c:12488 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10147
-#: c/c-typeck.c:10164 c/gimple-parser.c:1616 c/gimple-parser.c:1624
+#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12455
+#: tree.c:12492 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10152
+#: c/c-typeck.c:10169 c/gimple-parser.c:1616 c/gimple-parser.c:1624
 #: cp/call.c:6493 cp/call.c:8098 cp/constexpr.c:820 cp/constexpr.c:2309
-#: cp/cvt.c:1015 cp/cvt.c:1042 cp/decl.c:7334 cp/decl2.c:5256 cp/pt.c:8334
-#: cp/semantics.c:1836 cp/semantics.c:4053 cp/typeck.c:1700 cp/typeck.c:1895
+#: cp/cvt.c:1015 cp/cvt.c:1042 cp/decl.c:7355 cp/decl2.c:5246 cp/pt.c:8348
+#: cp/semantics.c:1836 cp/semantics.c:4056 cp/typeck.c:1700 cp/typeck.c:1895
 #: cp/typeck.c:3837
 #, fuzzy, gcc-internal-format
 msgid "declared here"
@@ -19867,27 +19878,27 @@
 msgid "nonnull argument %qD compared to NULL"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2517 gimple-ssa-sprintf.c:2637
+#: gimple-ssa-sprintf.c:2555 gimple-ssa-sprintf.c:2675
 #, gcc-internal-format
 msgid "%qE output may be truncated before the last format character"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2519 gimple-ssa-sprintf.c:2639
+#: gimple-ssa-sprintf.c:2557 gimple-ssa-sprintf.c:2677
 #, gcc-internal-format
 msgid "%qE output truncated before the last format character"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2522 gimple-ssa-sprintf.c:2642
+#: gimple-ssa-sprintf.c:2560 gimple-ssa-sprintf.c:2680
 #, gcc-internal-format
 msgid "%qE may write a terminating nul past the end of the destination"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2524 gimple-ssa-sprintf.c:2644
+#: gimple-ssa-sprintf.c:2562 gimple-ssa-sprintf.c:2682
 #, gcc-internal-format
 msgid "%qE writing a terminating nul past the end of the destination"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2534
+#: gimple-ssa-sprintf.c:2572
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size %wu"
@@ -19894,7 +19905,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.c:2541
+#: gimple-ssa-sprintf.c:2579
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size %wu"
@@ -19901,7 +19912,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.c:2548
+#: gimple-ssa-sprintf.c:2586
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size %wu"
@@ -19908,67 +19919,67 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.c:2559
+#: gimple-ssa-sprintf.c:2597
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2562
+#: gimple-ssa-sprintf.c:2600
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2564
+#: gimple-ssa-sprintf.c:2602
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2576
+#: gimple-ssa-sprintf.c:2614
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2579
+#: gimple-ssa-sprintf.c:2617
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2582
+#: gimple-ssa-sprintf.c:2620
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2591
+#: gimple-ssa-sprintf.c:2629
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2594
+#: gimple-ssa-sprintf.c:2632
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2597
+#: gimple-ssa-sprintf.c:2635
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2606
+#: gimple-ssa-sprintf.c:2644
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2609
+#: gimple-ssa-sprintf.c:2647
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2611
+#: gimple-ssa-sprintf.c:2649
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2653
+#: gimple-ssa-sprintf.c:2691
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size between %wu and %wu"
@@ -19975,7 +19986,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.c:2660
+#: gimple-ssa-sprintf.c:2698
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size between %wu and %wu"
@@ -19982,7 +19993,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.c:2668
+#: gimple-ssa-sprintf.c:2706
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size between %wu and %wu"
@@ -19989,102 +20000,102 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.c:2680
+#: gimple-ssa-sprintf.c:2718
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2683
+#: gimple-ssa-sprintf.c:2721
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2686
+#: gimple-ssa-sprintf.c:2724
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2699
+#: gimple-ssa-sprintf.c:2737
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2702
+#: gimple-ssa-sprintf.c:2740
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2705
+#: gimple-ssa-sprintf.c:2743
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2715
+#: gimple-ssa-sprintf.c:2753
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2718
+#: gimple-ssa-sprintf.c:2756
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2721
+#: gimple-ssa-sprintf.c:2759
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2730
+#: gimple-ssa-sprintf.c:2768
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2733
+#: gimple-ssa-sprintf.c:2771
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2736
+#: gimple-ssa-sprintf.c:2774
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2825
+#: gimple-ssa-sprintf.c:2863
 #, gcc-internal-format
 msgid "%<%.*s%> directive argument is null"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2890
+#: gimple-ssa-sprintf.c:2928
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes exceeds minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2897
+#: gimple-ssa-sprintf.c:2935
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may exceed minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2900
+#: gimple-ssa-sprintf.c:2938
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes exceeds minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2929
+#: gimple-ssa-sprintf.c:2967
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2936
+#: gimple-ssa-sprintf.c:2974
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2939
+#: gimple-ssa-sprintf.c:2977
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may cause result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2949
+#: gimple-ssa-sprintf.c:2987
 #, gcc-internal-format
 msgid "assuming directive output of %wu byte"
 msgid_plural "assuming directive output of %wu bytes"
@@ -20091,77 +20102,77 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.c:2956
+#: gimple-ssa-sprintf.c:2994
 #, fuzzy, gcc-internal-format
 msgid "directive argument %qE"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: gimple-ssa-sprintf.c:2958
+#: gimple-ssa-sprintf.c:2996
 #, gcc-internal-format
 msgid "directive argument in the range [%E, %E]"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2962
+#: gimple-ssa-sprintf.c:3000
 #, gcc-internal-format
 msgid "using the range [%E, %E] for directive argument"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2982
+#: gimple-ssa-sprintf.c:3020
 #, gcc-internal-format
 msgid "%qE output %wu byte into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2983
+#: gimple-ssa-sprintf.c:3021
 #, gcc-internal-format
 msgid "%qE output %wu bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2987
+#: gimple-ssa-sprintf.c:3025
 #, gcc-internal-format
 msgid "%qE output between %wu and %wu bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2992
+#: gimple-ssa-sprintf.c:3030
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes (assuming %wu) into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2997
+#: gimple-ssa-sprintf.c:3035
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3368
+#: gimple-ssa-sprintf.c:3406
 #, gcc-internal-format
 msgid "%<%.*s%> directive width out of range"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3402
+#: gimple-ssa-sprintf.c:3440
 #, gcc-internal-format
 msgid "%<%.*s%> directive precision out of range"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3893
+#: gimple-ssa-sprintf.c:3931
 #, gcc-internal-format
 msgid "specified bound %wu exceeds maximum object size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3899
+#: gimple-ssa-sprintf.c:3937
 #, gcc-internal-format
 msgid "specified bound %wu exceeds %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3949
+#: gimple-ssa-sprintf.c:3987
 #, fuzzy, gcc-internal-format
 msgid "null destination pointer"
 msgstr "lege declaratie"
 
-#: gimple-ssa-sprintf.c:3966
+#: gimple-ssa-sprintf.c:4004
 #, gcc-internal-format
 msgid "specified bound %wu exceeds the size %wu of the destination object"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3978
+#: gimple-ssa-sprintf.c:4016
 #, fuzzy, gcc-internal-format
 #| msgid "unterminated format string"
 msgid "null format string"
@@ -20377,10 +20388,10 @@
 msgstr ""
 
 #: gimple-ssa-warn-restrict.c:1678 c/c-decl.c:3603 c/c-decl.c:3874
-#: c/c-typeck.c:8345 cp/class.c:1346 cp/class.c:3098 cp/decl.c:3979
-#: cp/decl.c:10753 cp/decl.c:11151 cp/decl.c:11160 cp/friend.c:384
+#: c/c-typeck.c:8350 cp/class.c:1346 cp/class.c:3102 cp/decl.c:3979
+#: cp/decl.c:10777 cp/decl.c:11175 cp/decl.c:11184 cp/friend.c:384
 #: cp/friend.c:393 cp/parser.c:3275 cp/parser.c:3372 cp/parser.c:3422
-#: cp/parser.c:6327 cp/parser.c:21027
+#: cp/parser.c:6330 cp/parser.c:21024
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qs tevoren hier gedeclareerd"
@@ -20451,218 +20462,218 @@
 msgid "using result of function returning %<void%>"
 msgstr "%<return%> zonder waarde in een functie die een niet-void waarde teruggeeft"
 
-#: gimplify.c:6128
+#: gimplify.c:6131
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid lvalue in asm output %d"
 msgstr "ongeldige lvalue in toewijzing"
 
-#: gimplify.c:6271
+#: gimplify.c:6274
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr ""
 
-#: gimplify.c:6311 gimplify.c:6320
+#: gimplify.c:6314 gimplify.c:6323
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr ""
 
-#: gimplify.c:6928
+#: gimplify.c:6931
 #, fuzzy, gcc-internal-format
 msgid "threadprivate variable %qE used in target region"
 msgstr "registervariabele %qs gebruikt in geneste functie"
 
-#: gimplify.c:6930
+#: gimplify.c:6933
 #, gcc-internal-format
 msgid "enclosing target region"
 msgstr ""
 
-#: gimplify.c:6942
+#: gimplify.c:6945
 #, fuzzy, gcc-internal-format
 msgid "threadprivate variable %qE used in untied task"
 msgstr "registervariabele %qs gebruikt in geneste functie"
 
-#: gimplify.c:6944
+#: gimplify.c:6947
 #, gcc-internal-format
 msgid "enclosing task"
 msgstr ""
 
-#: gimplify.c:7016
+#: gimplify.c:7019
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D not declared in class"
 msgid "%qE not specified in enclosing %qs"
 msgstr "%q#D is niet gedeclareerd in class"
 
-#: gimplify.c:7018
+#: gimplify.c:7021
 #, fuzzy, gcc-internal-format
 msgid "enclosing %qs"
 msgstr "#error %s"
 
-#: gimplify.c:7143
+#: gimplify.c:7146
 #, gcc-internal-format
 msgid "%qE not specified in enclosing OpenACC %qs construct"
 msgstr ""
 
-#: gimplify.c:7145
+#: gimplify.c:7148
 #, gcc-internal-format
 msgid "enclosing OpenACC %qs construct"
 msgstr ""
 
-#: gimplify.c:7198
+#: gimplify.c:7201
 #, gcc-internal-format
 msgid "%qE with %<link%> clause used in %<routine%> function"
 msgstr ""
 
-#: gimplify.c:7206
+#: gimplify.c:7209
 #, fuzzy, gcc-internal-format
 msgid "%qE requires a %<declare%> directive for use in a %<routine%> function"
 msgstr "%qE is hier niet gedeclareerd (eerste gebruik in deze functie)"
 
-#: gimplify.c:7272 gimplify.c:7872
+#: gimplify.c:7275 gimplify.c:7875
 #, fuzzy, gcc-internal-format
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr "%Jvariabele %qD als %<inline%> gedeclareerd"
 
-#: gimplify.c:7293
+#: gimplify.c:7296
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr ""
 
-#: gimplify.c:7411 gimplify.c:7443
+#: gimplify.c:7414 gimplify.c:7446
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE is predetermined linear"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: gimplify.c:7414
+#: gimplify.c:7417
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should be private"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: gimplify.c:7428
+#: gimplify.c:7431
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be firstprivate"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: gimplify.c:7431
+#: gimplify.c:7434
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be reduction"
 msgstr "registervariabele %qs gebruikt in geneste functie"
 
-#: gimplify.c:7434
+#: gimplify.c:7437
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be linear"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: gimplify.c:7437
+#: gimplify.c:7440
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be lastprivate"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: gimplify.c:7440
+#: gimplify.c:7443
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be private"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: gimplify.c:7742
+#: gimplify.c:7745
 #, gcc-internal-format
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr ""
 
-#: gimplify.c:7949
+#: gimplify.c:7952
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr ""
 
-#: gimplify.c:8160
+#: gimplify.c:8163
 #, gcc-internal-format
 msgid "%qE appears more than once in map clauses"
 msgstr ""
 
-#: gimplify.c:8464
+#: gimplify.c:8467
 #, fuzzy, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr "registervariabele %qs gebruikt in geneste functie"
 
-#: gimplify.c:8484
+#: gimplify.c:8487
 #, fuzzy, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr "registervariabele %qs gebruikt in geneste functie"
 
-#: gimplify.c:8510
+#: gimplify.c:8513
 #, fuzzy, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr "ongeldige operand van %s"
 
-#: gimplify.c:8775
+#: gimplify.c:8778
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr ""
 
-#: gimplify.c:8808
+#: gimplify.c:8811
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:9000
+#: gimplify.c:9003
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:9051
+#: gimplify.c:9054
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr ""
 
-#: gimplify.c:9133
+#: gimplify.c:9136
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to present_or_copy"
 msgstr ""
 
-#: gimplify.c:9278
+#: gimplify.c:9281
 #, fuzzy, gcc-internal-format
 msgid "invalid private reduction on %qE"
 msgstr "herhaalde label-declaratie %qs"
 
-#: gimplify.c:11103 omp-low.c:2791
+#: gimplify.c:11106 omp-low.c:2791
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: gimplify.c:11121
+#: gimplify.c:11124
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr ""
 
-#: gimplify.c:11134
+#: gimplify.c:11137
 #, fuzzy, gcc-internal-format
 msgid "number of variables in %<depend(sink)%> clause does not match number of iteration variables"
 msgstr "aantal argumenten kom niet overeen met prototype"
 
-#: gimplify.c:11147
+#: gimplify.c:11150
 #, gcc-internal-format
 msgid "more than one %<depend(source)%> clause on an %<ordered%> construct"
 msgstr ""
 
-#: gimplify.c:11158
+#: gimplify.c:11161
 #, gcc-internal-format
 msgid "%<depend(source)%> clause specified together with %<depend(sink:)%> clauses on the same construct"
 msgstr ""
 
-#: gimplify.c:12393
+#: gimplify.c:12396
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr ""
 
-#: gimplify.c:12936
+#: gimplify.c:12939
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr "%qT wordt tot %qT gepromoveerd indien het via %<...%> wordt doorgegeven"
 
-#: gimplify.c:12941
+#: gimplify.c:12944
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr "(dus U zou %qT, en niet %qT, moeten doorgeven aan %<va_arg%>)"
 
-#: gimplify.c:12948
+#: gimplify.c:12951
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr "indien deze code bereikt wordt, zal het programma afgebroken worden"
@@ -21139,47 +21150,47 @@
 msgid "Max. number of generated reload insns per insn is achieved (%d)\n"
 msgstr ""
 
-#: lto-cgraph.c:1294
+#: lto-cgraph.c:1296
 #, gcc-internal-format, gfc-internal-format
 msgid "bytecode stream: found multiple instances of cgraph node with uid %d"
 msgstr ""
 
-#: lto-cgraph.c:1472
+#: lto-cgraph.c:1474
 #, gcc-internal-format
 msgid "bytecode stream: no caller found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1478
+#: lto-cgraph.c:1480
 #, gcc-internal-format
 msgid "bytecode stream: no callee found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1552
+#: lto-cgraph.c:1554
 #, gcc-internal-format
 msgid "bytecode stream: found empty cgraph node"
 msgstr ""
 
-#: lto-cgraph.c:1730
+#: lto-cgraph.c:1732
 #, gcc-internal-format, gfc-internal-format
 msgid "At most %i profile runs is supported. Perhaps corrupted profile?"
 msgstr ""
 
-#: lto-cgraph.c:1817
+#: lto-cgraph.c:1819
 #, gcc-internal-format, gfc-internal-format
 msgid "Profile information in %s corrupted"
 msgstr ""
 
-#: lto-cgraph.c:1855
+#: lto-cgraph.c:1857
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO cgraph in %s"
 msgstr "kan %s niet vinden"
 
-#: lto-cgraph.c:1865
+#: lto-cgraph.c:1867
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO section refs in %s"
 msgstr "geen eerdere declaratie voor %qs"
 
-#: lto-cgraph.c:1946
+#: lto-cgraph.c:1948
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid rotate insn"
 msgid "invalid offload table in %s"
@@ -21251,85 +21262,91 @@
 msgid "bytecode stream in file %qs generated with LTO version %d.%d instead of the expected %d.%d"
 msgstr ""
 
-#: lto-wrapper.c:117
+#: lto-wrapper.c:118
 #, fuzzy, gcc-internal-format
 msgid "deleting LTRANS file %s: %m"
 msgstr "kan bestand '%s' niet openen"
 
-#: lto-wrapper.c:154
+#: lto-wrapper.c:155
 #, gcc-internal-format
 msgid "malformed COLLECT_GCC_OPTIONS"
 msgstr ""
 
 # Vertaling voor "endianness"? Of niet nodig?
-#: lto-wrapper.c:308
+#: lto-wrapper.c:309
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "created and used with different endianness"
 msgid "Option %s with different values"
 msgstr "aangemaakt en gebruikt met verschillende \"endianness\""
 
-#: lto-wrapper.c:392
+#: lto-wrapper.c:393
 #, gcc-internal-format, gfc-internal-format
 msgid "Option %s not used consistently in all LTO input files"
 msgstr ""
 
-#: lto-wrapper.c:832
+#: lto-wrapper.c:833
 #, gcc-internal-format, gfc-internal-format
 msgid "problem with building target image for %s\n"
 msgstr ""
 
-#: lto-wrapper.c:852
+#: lto-wrapper.c:853
 #, fuzzy, gcc-internal-format
 #| msgid "no input files"
 msgid "reading input file"
 msgstr "geen invoerbestanden"
 
-#: lto-wrapper.c:857
+#: lto-wrapper.c:858
 #, fuzzy, gcc-internal-format
 #| msgid "Error writing output file '%s'\n"
 msgid "writing output file"
 msgstr "Fout bij schrijven van uitvoerbestand '%s'\n"
 
-#: lto-wrapper.c:889
+#: lto-wrapper.c:890
 #, gcc-internal-format
 msgid "installation error, can't find crtoffloadtable.o"
 msgstr ""
 
-#: lto-wrapper.c:1000 lto-wrapper.c:1012
+#: lto-wrapper.c:1001 lto-wrapper.c:1013
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s: %s\n"
 msgstr "%s: fout bij wachten op proces: %s\n"
 
-#: lto-wrapper.c:1056
+#: lto-wrapper.c:1064
 #, gcc-internal-format
 msgid "environment variable COLLECT_GCC must be set"
 msgstr ""
 
-#: lto-wrapper.c:1060 config/nvptx/mkoffload.c:363
+#: lto-wrapper.c:1068 config/nvptx/mkoffload.c:363
 #, gcc-internal-format
 msgid "environment variable COLLECT_GCC_OPTIONS must be set"
 msgstr ""
 
-#: lto-wrapper.c:1229 lto-wrapper.c:1285
+#: lto-wrapper.c:1237 lto-wrapper.c:1293
 #, fuzzy, gcc-internal-format
 msgid "cannot open %s: %m"
 msgstr "open %s"
 
-#: lto-wrapper.c:1232 lto-wrapper.c:1291
+#: lto-wrapper.c:1240 lto-wrapper.c:1299
 #, fuzzy, gcc-internal-format
 msgid "cannot read %s: %m"
 msgstr "open %s"
 
-#: lto-wrapper.c:1259
+#: lto-wrapper.c:1267
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid format of %s"
 msgstr "ongeldige operand voor %%R"
 
-#: lto-wrapper.c:1482
+#: lto-wrapper.c:1491
 #, fuzzy, gcc-internal-format
 msgid "fopen: %s: %m"
 msgstr "fopen %s"
 
+#: lto-wrapper.c:1508
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "Could not open output file '%s'\n"
+msgid "Corrupted ltrans output file %s"
+msgstr "Kan uitvoerbestand '%s' niet openen\n"
+
 #: multiple_target.c:76
 #, fuzzy, gcc-internal-format
 msgid "the call requires ifunc, which is not supported by this target"
@@ -21682,13 +21699,13 @@
 msgid "unrecognized argument in option %qs"
 msgstr "niet-herkend argument bij optie %qs"
 
-#: opts-common.c:1198 config/i386/i386.c:3206
+#: opts-common.c:1198 config/i386/i386.c:3209
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "geldige argumenten van %qs zijn: %s"
 
-#: opts-common.c:1201 config/i386/i386.c:3209
+#: opts-common.c:1201 config/i386/i386.c:3212
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "geldige argumenten van %qs zijn: %s"
@@ -22284,22 +22301,22 @@
 msgid "output operand %d must use %<&%> constraint"
 msgstr "operand %<%d%> is geen register"
 
-#: regcprop.c:1187
+#: regcprop.c:1193
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad next_regno for empty chain (%u)"
 msgstr ""
 
-#: regcprop.c:1199
+#: regcprop.c:1205
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: Loop in regno chain (%u)"
 msgstr ""
 
-#: regcprop.c:1202
+#: regcprop.c:1208
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad oldest_regno (%u)"
 msgstr ""
 
-#: regcprop.c:1214
+#: regcprop.c:1220
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Non-empty reg in chain (%s %u %i)"
 msgstr ""
@@ -22343,7 +22360,7 @@
 msgstr "registernaam opgegeven voor niet-registervariabele %qs"
 
 #: reginfo.c:789 config/powerpcspe/powerpcspe.c:32259
-#: config/rs6000/rs6000.c:29453
+#: config/rs6000/rs6000.c:29530
 #, fuzzy, gcc-internal-format
 msgid "conflicts with %qD"
 msgstr "conflicterende types voor %qs"
@@ -22588,152 +22605,157 @@
 msgid "function symbol is not function"
 msgstr "%qs gedeclareerd als een functie die een functie teruggeeft"
 
-#: symtab.c:1006
+#: symtab.c:1005
 #, gcc-internal-format
+msgid "inconsistent `ifunc' attribute"
+msgstr ""
+
+#: symtab.c:1013
+#, gcc-internal-format
 msgid "variable symbol is not variable"
 msgstr ""
 
-#: symtab.c:1012
+#: symtab.c:1019
 #, gcc-internal-format
 msgid "node has unknown type"
 msgstr ""
 
-#: symtab.c:1021
+#: symtab.c:1028
 #, gcc-internal-format
 msgid "node not found node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.c:1029
+#: symtab.c:1036
 #, gcc-internal-format
 msgid "node differs from node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.c:1038
+#: symtab.c:1045
 #, gcc-internal-format
 msgid "assembler name hash list corrupted"
 msgstr ""
 
-#: symtab.c:1051
+#: symtab.c:1058
 #, gcc-internal-format
 msgid "node not found in symtab assembler name hash"
 msgstr ""
 
-#: symtab.c:1058
+#: symtab.c:1065
 #, gcc-internal-format
 msgid "double linked list of assembler names corrupted"
 msgstr ""
 
-#: symtab.c:1063
+#: symtab.c:1070
 #, fuzzy, gcc-internal-format
 msgid "node has body_removed but is definition"
 msgstr "opgeroepen object is geen functie"
 
-#: symtab.c:1068
+#: symtab.c:1075
 #, fuzzy, gcc-internal-format
 msgid "node is analyzed but it is not a definition"
 msgstr "opgeroepen object is geen functie"
 
-#: symtab.c:1073
+#: symtab.c:1080
 #, gcc-internal-format
 msgid "node is alias but not implicit alias"
 msgstr ""
 
-#: symtab.c:1078
+#: symtab.c:1085
 #, fuzzy, gcc-internal-format
 msgid "node is alias but not definition"
 msgstr "%Jfunctiedefinitie in oude stijl"
 
-#: symtab.c:1083
+#: symtab.c:1090
 #, gcc-internal-format
 msgid "node is weakref but not an transparent_alias"
 msgstr ""
 
-#: symtab.c:1088
+#: symtab.c:1095
 #, fuzzy, gcc-internal-format
 msgid "node is transparent_alias but not an alias"
 msgstr "%Jfunctiedefinitie in oude stijl"
 
-#: symtab.c:1097
+#: symtab.c:1104
 #, gcc-internal-format
 msgid "node is in same_comdat_group list but has no comdat_group"
 msgstr ""
 
-#: symtab.c:1102
+#: symtab.c:1109
 #, gcc-internal-format
 msgid "same_comdat_group list across different groups"
 msgstr ""
 
-#: symtab.c:1107
+#: symtab.c:1114
 #, gcc-internal-format
 msgid "mixing different types of symbol in same comdat groups is not supported"
 msgstr ""
 
-#: symtab.c:1112
+#: symtab.c:1119
 #, gcc-internal-format
 msgid "node is alone in a comdat group"
 msgstr ""
 
-#: symtab.c:1119
+#: symtab.c:1126
 #, gcc-internal-format
 msgid "same_comdat_group is not a circular list"
 msgstr ""
 
-#: symtab.c:1134
+#: symtab.c:1141
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local symbol referred to by %s outside its comdat"
 msgstr ""
 
-#: symtab.c:1144
+#: symtab.c:1151
 #, gcc-internal-format
 msgid "implicit_section flag is set but section isn't"
 msgstr ""
 
-#: symtab.c:1151
+#: symtab.c:1158
 #, gcc-internal-format
 msgid "Both section and comdat group is set"
 msgstr ""
 
-#: symtab.c:1163
+#: symtab.c:1170
 #, gcc-internal-format
 msgid "Alias and target's section differs"
 msgstr ""
 
-#: symtab.c:1170
+#: symtab.c:1177
 #, gcc-internal-format
 msgid "Alias and target's comdat groups differs"
 msgstr ""
 
-#: symtab.c:1185
+#: symtab.c:1192
 #, gcc-internal-format
 msgid "Transparent alias and target's assembler names differs"
 msgstr ""
 
-#: symtab.c:1193
+#: symtab.c:1200
 #, gcc-internal-format
 msgid "Chained transparent aliases"
 msgstr ""
 
-#: symtab.c:1216 symtab.c:1253
+#: symtab.c:1223 symtab.c:1260
 #, gcc-internal-format
 msgid "symtab_node::verify failed"
 msgstr ""
 
-#: symtab.c:1249
+#: symtab.c:1256
 #, gcc-internal-format
 msgid "Two symbols with same comdat_group are not linked by the same_comdat_group list."
 msgstr ""
 
-#: symtab.c:1658
+#: symtab.c:1665
 #, fuzzy, gcc-internal-format
 msgid "function %q+D part of alias cycle"
 msgstr "functie %qs geherdeclareerd als inline"
 
-#: symtab.c:1660
+#: symtab.c:1667
 #, fuzzy, gcc-internal-format
 msgid "variable %q+D part of alias cycle"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: symtab.c:1688
+#: symtab.c:1695
 #, gcc-internal-format
 msgid "section of alias %q+D must match section of its target"
 msgstr ""
@@ -23535,7 +23557,7 @@
 msgid "the first argument of a VEC_COND_EXPR must be of a boolean vector type of the same number of elements as the result"
 msgstr ""
 
-#: tree-cfg.c:4395 c/c-typeck.c:5212
+#: tree-cfg.c:4395 c/c-typeck.c:5217
 #, gcc-internal-format
 msgid "type mismatch in conditional expression"
 msgstr "types in voorwaardelijke expressie komen niet overeen"
@@ -23885,22 +23907,22 @@
 msgid "missing edge %i->%i"
 msgstr "beginwaarde ontbreekt"
 
-#: tree-cfg.c:9379
+#: tree-cfg.c:9388
 #, fuzzy, gcc-internal-format
 msgid "%<noreturn%> function does return"
 msgstr "%<noreturn%> functie keert terug"
 
-#: tree-cfg.c:9400 tree-cfg.c:9432
+#: tree-cfg.c:9409 tree-cfg.c:9441
 #, fuzzy, gcc-internal-format
 msgid "control reaches end of non-void function"
 msgstr "einde van niet-void functie werd bereikt zonder teruggeefwaarde"
 
-#: tree-cfg.c:9498 cp/cvt.c:1039
+#: tree-cfg.c:9507 cp/cvt.c:1039
 #, fuzzy, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgstr "%Hde returnwaarde van %qD, gedeclareerd met het %<warn_unused_result%> atribuut, wordt genegeerd"
 
-#: tree-cfg.c:9503 cp/cvt.c:1046
+#: tree-cfg.c:9512 cp/cvt.c:1046
 #, fuzzy, gcc-internal-format
 msgid "ignoring return value of function declared with attribute warn_unused_result"
 msgstr "%Hde returnwaarde van een functie, gedeclareerd met het %<warn_unused_result%> atribuut, wordt genegeerd"
@@ -24167,48 +24189,48 @@
 msgid "stmt volatile flag not up-to-date"
 msgstr ""
 
-#: tree-ssa-strlen.c:1975
+#: tree-ssa-strlen.c:1999
 msgid "%G%qD output truncated before terminating nul copying %E byte from a string of the same length"
 msgid_plural "%G%qD output truncated before terminating nul copying %E bytes from a string of the same length"
 msgstr[0] ""
 msgstr[1] ""
 
-#: tree-ssa-strlen.c:1989
+#: tree-ssa-strlen.c:2013
 msgid "%G%qD output truncated copying %E byte from a string of length %wu"
 msgid_plural "%G%qD output truncated copying %E bytes from a string of length %wu"
 msgstr[0] ""
 msgstr[1] ""
 
-#: tree-ssa-strlen.c:1996
+#: tree-ssa-strlen.c:2020
 msgid "%G%qD output truncated copying between %wu and %wu bytes from a string of length %wu"
 msgstr ""
 
-#: tree-ssa-strlen.c:2008
+#: tree-ssa-strlen.c:2032
 msgid "%G%qD output may be truncated copying %E byte from a string of length %wu"
 msgid_plural "%G%qD output may be truncated copying %E bytes from a string of length %wu"
 msgstr[0] ""
 msgstr[1] ""
 
-#: tree-ssa-strlen.c:2015 tree-ssa-strlen.c:2029
+#: tree-ssa-strlen.c:2039 tree-ssa-strlen.c:2053
 msgid "%G%qD output may be truncated copying between %wu and %wu bytes from a string of length %wu"
 msgstr ""
 
-#: tree-ssa-strlen.c:2150
+#: tree-ssa-strlen.c:2174
 msgid "%G%qD output truncated before terminating nul copying as many bytes from a string as its length"
 msgstr ""
 
-#: tree-ssa-strlen.c:2156
+#: tree-ssa-strlen.c:2180
 msgid "%G%qD specified bound depends on the length of the source argument"
 msgstr ""
 
 # Goede vertaling voor modifier? "aanpasser" en "veranderaar" klinken nogal duf...
-#: tree-ssa-strlen.c:2163
+#: tree-ssa-strlen.c:2187
 #, fuzzy, gcc-internal-format
 #| msgid "length modifier"
 msgid "length computed here"
 msgstr "lengte-modifier"
 
-#: tree-ssa-uninit.c:191 varasm.c:331
+#: tree-ssa-uninit.c:191 varasm.c:342
 #, fuzzy, gcc-internal-format
 msgid "%qD was declared here"
 msgstr "%qs tevoren hier gedeclareerd"
@@ -24383,27 +24405,27 @@
 msgid "target specific builtin not available"
 msgstr ""
 
-#: tree-vect-generic.c:287
+#: tree-vect-generic.c:283
 #, gcc-internal-format
 msgid "vector operation will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-generic.c:290
+#: tree-vect-generic.c:286
 #, gcc-internal-format
 msgid "vector operation will be expanded in parallel"
 msgstr ""
 
-#: tree-vect-generic.c:341
+#: tree-vect-generic.c:337
 #, gcc-internal-format
 msgid "vector operation will be expanded with a single scalar operation"
 msgstr ""
 
-#: tree-vect-generic.c:941
+#: tree-vect-generic.c:937
 #, gcc-internal-format
 msgid "vector condition will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-generic.c:1373
+#: tree-vect-generic.c:1369
 #, gcc-internal-format
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr ""
@@ -24413,27 +24435,27 @@
 msgid "vectorization did not happen for a simd loop"
 msgstr ""
 
-#: tree-vrp.c:4930 tree-vrp.c:4974
+#: tree-vrp.c:4931 tree-vrp.c:4975
 #, fuzzy, gcc-internal-format
 msgid "array subscript %E is above array bounds of %qT"
 msgstr "array subscript is geen integer"
 
-#: tree-vrp.c:4956
+#: tree-vrp.c:4957
 #, fuzzy, gcc-internal-format
 msgid "array subscript [%E, %E] is outside array bounds of %qT"
 msgstr "array subscript is geen integer"
 
-#: tree-vrp.c:4988
+#: tree-vrp.c:4989
 #, fuzzy, gcc-internal-format
 msgid "array subscript %E is below array bounds of %qT"
 msgstr "array subscript is geen integer"
 
-#: tree-vrp.c:5046
+#: tree-vrp.c:5047
 #, fuzzy, gcc-internal-format
 msgid "array subscript %wi is below array bounds of %qT"
 msgstr "array subscript is geen integer"
 
-#: tree-vrp.c:5060
+#: tree-vrp.c:5061
 #, fuzzy, gcc-internal-format
 msgid "array subscript %wu is above array bounds of %qT"
 msgstr "array subscript is geen integer"
@@ -24448,92 +24470,92 @@
 msgid "side-effects element in no-side-effects CONSTRUCTOR"
 msgstr ""
 
-#: tree.c:7852
+#: tree.c:7856
 #, gcc-internal-format
 msgid "arrays of functions are not meaningful"
 msgstr "arrays van functies zijn niet betekenisvol"
 
-#: tree.c:8019
+#: tree.c:8023
 #, gcc-internal-format
 msgid "function return type cannot be function"
 msgstr "de terugkeerwaarde van een functie kan geen funtie zijn"
 
-#: tree.c:9327 tree.c:9412 tree.c:9473
+#: tree.c:9331 tree.c:9416 tree.c:9477
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: %s, have %s in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9364
+#: tree.c:9368
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected none of %s, have %s in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9377
+#: tree.c:9381
 #, gcc-internal-format
 msgid "tree check: expected class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9426
+#: tree.c:9430
 #, gcc-internal-format
 msgid "tree check: did not expect class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9439
+#: tree.c:9443
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected omp_clause %s, have %s in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9499
+#: tree.c:9503
 #, gcc-internal-format
 msgid "tree check: expected tree that contains %qs structure, have %qs in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9513
+#: tree.c:9517
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_int_cst with %d elts in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9525
+#: tree.c:9529
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_vec with %d elts in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9538
+#: tree.c:9542
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of %s with %d operands in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9551
+#: tree.c:9555
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of omp_clause %s with %d operands in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:12446
+#: tree.c:12450
 #, fuzzy, gcc-internal-format
 msgid "%qD is deprecated: %s"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: tree.c:12449
+#: tree.c:12453
 #, fuzzy, gcc-internal-format
 msgid "%qD is deprecated"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: tree.c:12473 tree.c:12495
+#: tree.c:12477 tree.c:12499
 #, fuzzy, gcc-internal-format
 msgid "%qE is deprecated: %s"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: tree.c:12476 tree.c:12498
+#: tree.c:12480 tree.c:12502
 #, fuzzy, gcc-internal-format
 msgid "%qE is deprecated"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: tree.c:12482 tree.c:12503
+#: tree.c:12486 tree.c:12507
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "type is deprecated: %s"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: tree.c:12485 tree.c:12506
+#: tree.c:12489 tree.c:12510
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr ""
@@ -24558,242 +24580,242 @@
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.c:13043
+#: tree.c:13047
 #, gcc-internal-format, gfc-internal-format
 msgid "type variant differs by %s"
 msgstr ""
 
-#: tree.c:13084
+#: tree.c:13088
 #, gcc-internal-format
 msgid "type variant has different TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13086
+#: tree.c:13090
 #, gcc-internal-format
 msgid "type variant's TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13088
+#: tree.c:13092
 #, gcc-internal-format
 msgid "type's TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13108
+#: tree.c:13112
 #, gcc-internal-format
 msgid "type variant with TYPE_ALIAS_SET_KNOWN_P"
 msgstr ""
 
-#: tree.c:13121
+#: tree.c:13125
 #, gcc-internal-format
 msgid "type variant has different TYPE_VFIELD"
 msgstr ""
 
-#: tree.c:13157
+#: tree.c:13161
 #, gcc-internal-format
 msgid "type variant has different TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13159
+#: tree.c:13163
 #, gcc-internal-format
 msgid "type variant's TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13161
+#: tree.c:13165
 #, gcc-internal-format
 msgid "type's TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13199
+#: tree.c:13203
 #, gcc-internal-format
 msgid "type variant has different TYPE_FIELDS"
 msgstr ""
 
-#: tree.c:13201
+#: tree.c:13205
 #, fuzzy, gcc-internal-format
 msgid "first mismatch is field"
 msgstr "types in voorwaardelijke expressie komen niet overeen"
 
-#: tree.c:13203
+#: tree.c:13207
 #, gcc-internal-format
 msgid "and field"
 msgstr ""
 
-#: tree.c:13220
+#: tree.c:13224
 #, gcc-internal-format
 msgid "type variant has different TREE_TYPE"
 msgstr ""
 
-#: tree.c:13222 tree.c:13233
+#: tree.c:13226 tree.c:13237
 #, gcc-internal-format
 msgid "type variant's TREE_TYPE"
 msgstr ""
 
-#: tree.c:13224 tree.c:13235
+#: tree.c:13228 tree.c:13239
 #, gcc-internal-format
 msgid "type's TREE_TYPE"
 msgstr ""
 
-#: tree.c:13231
+#: tree.c:13235
 #, fuzzy, gcc-internal-format
 msgid "type is not compatible with its variant"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: tree.c:13534
+#: tree.c:13538
 #, fuzzy, gcc-internal-format
 msgid "Main variant is not defined"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: tree.c:13539
+#: tree.c:13543
 #, gcc-internal-format
 msgid "TYPE_MAIN_VARIANT has different TYPE_MAIN_VARIANT"
 msgstr ""
 
-#: tree.c:13551
+#: tree.c:13555
 #, gcc-internal-format
 msgid "TYPE_CANONICAL has different TYPE_CANONICAL"
 msgstr ""
 
-#: tree.c:13569
+#: tree.c:13573
 #, gcc-internal-format
 msgid "TYPE_CANONICAL is not compatible"
 msgstr ""
 
-#: tree.c:13577
+#: tree.c:13581
 #, gcc-internal-format
 msgid "TYPE_MODE of TYPE_CANONICAL is not compatible"
 msgstr ""
 
-#: tree.c:13583
+#: tree.c:13587
 #, gcc-internal-format
 msgid "TYPE_CANONICAL of main variant is not main variant"
 msgstr ""
 
-#: tree.c:13599
+#: tree.c:13603
 #, gcc-internal-format
 msgid "TYPE_VFIELD is not FIELD_DECL nor TREE_LIST"
 msgstr ""
 
-#: tree.c:13609
+#: tree.c:13613
 #, gcc-internal-format
 msgid "TYPE_NEXT_PTR_TO is not POINTER_TYPE"
 msgstr ""
 
-#: tree.c:13619
+#: tree.c:13623
 #, gcc-internal-format
 msgid "TYPE_NEXT_REF_TO is not REFERENCE_TYPE"
 msgstr ""
 
-#: tree.c:13640
+#: tree.c:13644
 #, gcc-internal-format
 msgid "TYPE_BINFO is not TREE_BINFO"
 msgstr ""
 
-#: tree.c:13646
+#: tree.c:13650
 #, gcc-internal-format
 msgid "TYPE_BINFO type is not TYPE_MAIN_VARIANT"
 msgstr ""
 
-#: tree.c:13657
+#: tree.c:13661
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not record nor union"
 msgstr ""
 
-#: tree.c:13668
+#: tree.c:13672
 #, gcc-internal-format
 msgid "TYPE_OFFSET_BASETYPE is not record nor union"
 msgstr ""
 
-#: tree.c:13686
+#: tree.c:13690
 #, gcc-internal-format
 msgid "TYPE_ARRAY_MAX_SIZE not INTEGER_CST"
 msgstr ""
 
-#: tree.c:13693
+#: tree.c:13697
 #, gcc-internal-format
 msgid "TYPE_MAX_VALUE_RAW non-NULL"
 msgstr ""
 
-#: tree.c:13700
+#: tree.c:13704
 #, gcc-internal-format
 msgid "TYPE_LANG_SLOT_1 (binfo) field is non-NULL"
 msgstr ""
 
-#: tree.c:13716
+#: tree.c:13720
 #, gcc-internal-format
 msgid "Enum value is not CONST_DECL or INTEGER_CST"
 msgstr ""
 
-#: tree.c:13724
+#: tree.c:13728
 #, gcc-internal-format
 msgid "Enum value type is not INTEGER_TYPE nor convertible to the enum"
 msgstr ""
 
-#: tree.c:13731
+#: tree.c:13735
 #, gcc-internal-format
 msgid "Enum value name is not IDENTIFIER_NODE"
 msgstr ""
 
-#: tree.c:13741
+#: tree.c:13745
 #, fuzzy, gcc-internal-format
 msgid "Array TYPE_DOMAIN is not integer type"
 msgstr "grootte van array %qs is van een niet-integer type"
 
-#: tree.c:13750
+#: tree.c:13754
 #, fuzzy, gcc-internal-format
 msgid "TYPE_FIELDS defined in incomplete type"
 msgstr "veld %qs heeft een onvolledig type"
 
-#: tree.c:13772
+#: tree.c:13776
 #, gcc-internal-format
 msgid "Wrong tree in TYPE_FIELDS list"
 msgstr ""
 
-#: tree.c:13787
+#: tree.c:13791
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is %i while TYPE_CACHED_VALUES is %p"
 msgstr ""
 
-#: tree.c:13793
+#: tree.c:13797
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES is not TREE_VEC"
 msgstr ""
 
-#: tree.c:13806
+#: tree.c:13810
 #, gcc-internal-format
 msgid "wrong TYPE_CACHED_VALUES entry"
 msgstr ""
 
-#: tree.c:13819
+#: tree.c:13823
 #, gcc-internal-format
 msgid "TREE_PURPOSE is non-NULL in TYPE_ARG_TYPES list"
 msgstr ""
 
-#: tree.c:13825
+#: tree.c:13829
 #, gcc-internal-format
 msgid "Wrong entry in TYPE_ARG_TYPES list"
 msgstr ""
 
-#: tree.c:13832
+#: tree.c:13836
 #, gcc-internal-format
 msgid "TYPE_VALUES_RAW field is non-NULL"
 msgstr ""
 
-#: tree.c:13844
+#: tree.c:13848
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is set while it should not"
 msgstr ""
 
-#: tree.c:13850
+#: tree.c:13854
 #, gcc-internal-format
 msgid "TYPE_STRING_FLAG is set on wrong type code"
 msgstr ""
 
-#: tree.c:13860
+#: tree.c:13864
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not main variant"
 msgstr ""
 
-#: tree.c:13867
+#: tree.c:13871
 #, fuzzy, gcc-internal-format
 msgid "verify_type failed"
 msgstr "pex_init mislukt"
@@ -24818,182 +24840,182 @@
 msgid "corrupted value profile: %s profile counter (%d out of %d) inconsistent with basic-block count (%d)"
 msgstr ""
 
-#: var-tracking.c:7166
+#: var-tracking.c:7184
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded with -fvar-tracking-assignments, retrying without"
 msgstr ""
 
-#: var-tracking.c:7170
+#: var-tracking.c:7188
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded"
 msgstr ""
 
-#: varasm.c:326
+#: varasm.c:337
 #, fuzzy, gcc-internal-format
 msgid "%+qD causes a section type conflict with %qD"
 msgstr "%qs gedeclareerd als een functie die een functie teruggeeft"
 
-#: varasm.c:329
+#: varasm.c:340
 #, fuzzy, gcc-internal-format
 msgid "section type conflict with %qD"
 msgstr "conflicterende types voor %qs"
 
-#: varasm.c:334
+#: varasm.c:345
 #, fuzzy, gcc-internal-format
 msgid "%+qD causes a section type conflict"
 msgstr "%qs gedeclareerd als een functie die een functie teruggeeft"
 
-#: varasm.c:336
+#: varasm.c:347
 #, fuzzy, gcc-internal-format
 msgid "section type conflict"
 msgstr "%qs gedeclareerd als een functie die een functie teruggeeft"
 
-#: varasm.c:1019
+#: varasm.c:1030
 #, fuzzy, gcc-internal-format
 msgid "alignment of %q+D is greater than maximum object file alignment %d"
 msgstr "alignment van %qs is groter dan het maximale alignment van het objectbestand. %d wordt gebruikt."
 
-#: varasm.c:1172
+#: varasm.c:1183
 #, fuzzy, gcc-internal-format
 msgid "only zero initializers are allowed in section %qs"
 msgstr "Enkel variabelen met beginwaarde kunnen in het 8-bit gebied geplaatst worden."
 
-#: varasm.c:1378 varasm.c:1387
+#: varasm.c:1389 varasm.c:1398
 #, fuzzy, gcc-internal-format
 msgid "register name not specified for %q+D"
 msgstr "registernaam niet opgegeven voor %qs"
 
-#: varasm.c:1389
+#: varasm.c:1400
 #, fuzzy, gcc-internal-format
 msgid "invalid register name for %q+D"
 msgstr "ongeldige registernaam voor %qs"
 
-#: varasm.c:1391
+#: varasm.c:1402
 #, fuzzy, gcc-internal-format
 msgid "data type of %q+D isn%'t suitable for a register"
 msgstr "datatype van %qs is niet geschikt voor een register"
 
-#: varasm.c:1394
+#: varasm.c:1405
 #, fuzzy, gcc-internal-format
 msgid "the register specified for %q+D cannot be accessed by the current target"
 msgstr "het registernummer voor %qs is niet geschikt voor dat datatype"
 
-#: varasm.c:1397
+#: varasm.c:1408
 #, fuzzy, gcc-internal-format
 msgid "the register specified for %q+D is not general enough to be used as a register variable"
 msgstr "het registernummer voor %qs is niet geschikt voor dat datatype"
 
-#: varasm.c:1400
+#: varasm.c:1411
 #, fuzzy, gcc-internal-format
 msgid "register specified for %q+D isn%'t suitable for data type"
 msgstr "het registernummer voor %qs is niet geschikt voor dat datatype"
 
-#: varasm.c:1410
+#: varasm.c:1421
 #, gcc-internal-format
 msgid "global register variable has initial value"
 msgstr "globale registervariabele heeft beginwaarde"
 
-#: varasm.c:1414
+#: varasm.c:1425
 #, gcc-internal-format
 msgid "optimization may eliminate reads and/or writes to register variables"
 msgstr ""
 
-#: varasm.c:1460
+#: varasm.c:1471
 #, fuzzy, gcc-internal-format
 msgid "register name given for non-register variable %q+D"
 msgstr "registernaam opgegeven voor niet-registervariabele %qs"
 
-#: varasm.c:1870
+#: varasm.c:1881
 #, gcc-internal-format
 msgid "Patchable function entry > size"
 msgstr ""
 
-#: varasm.c:2069
+#: varasm.c:2080
 #, gcc-internal-format
 msgid "thread-local COMMON data not implemented"
 msgstr ""
 
-#: varasm.c:2102
+#: varasm.c:2113
 #, fuzzy, gcc-internal-format
 msgid "requested alignment for %q+D is greater than implemented alignment of %wu"
 msgstr "het gevraagde alignment voor %s is groter dan het geïmplementeerde aligment van %d."
 
-#: varasm.c:2205 c/c-decl.c:5027 c/c-parser.c:1534
+#: varasm.c:2216 c/c-decl.c:5027 c/c-parser.c:1534
 #, fuzzy, gcc-internal-format
 msgid "storage size of %q+D isn%'t known"
 msgstr "opslaggrootte van %qs is onbekend"
 
-#: varasm.c:4910
+#: varasm.c:4921
 #, fuzzy, gcc-internal-format
 msgid "initializer for integer/fixed-point value is too complicated"
 msgstr "initializer voor integerwaarde is te ingewikkeld"
 
-#: varasm.c:4915
+#: varasm.c:4926
 #, gcc-internal-format
 msgid "initializer for floating value is not a floating constant"
 msgstr "initializer voor floating-point waarde is geen floating-point constante"
 
-#: varasm.c:5227
+#: varasm.c:5238
 #, fuzzy, gcc-internal-format
 msgid "invalid initial value for member %qE"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: varasm.c:5487
+#: varasm.c:5498
 #, fuzzy, gcc-internal-format
 msgid "%+qD declared weak after being used"
 msgstr "%J%qD als inline gedeclareerd na oproep"
 
-#: varasm.c:5539
+#: varasm.c:5550
 #, fuzzy, gcc-internal-format
 msgid "weak declaration of %q+D being applied to a already existing, static definition"
 msgstr "de zwakke declaratie van %qs moet aan de definitie voorafgaan"
 
-#: varasm.c:5575
+#: varasm.c:5586
 #, fuzzy, gcc-internal-format
 msgid "weak declaration of %q+D must be public"
 msgstr "de zwakke declaratie van %qs moet publiek zijn"
 
-#: varasm.c:5579
+#: varasm.c:5590
 #, fuzzy, gcc-internal-format
 msgid "weak declaration of %q+D not supported"
 msgstr "de zwakke declaratie van %qs moet publiek zijn"
 
-#: varasm.c:5608 varasm.c:5912
+#: varasm.c:5619 varasm.c:5926
 #, gcc-internal-format
 msgid "only weak aliases are supported in this configuration"
 msgstr "enkel zwakke aliasen worden in deze configuratie ondersteund"
 
-#: varasm.c:5802
+#: varasm.c:5813
 #, fuzzy, gcc-internal-format
 msgid "weakref is not supported in this configuration"
 msgstr "alias-definities worden niet ondersteund in deze configuratie; genegeerd"
 
-#: varasm.c:5834
+#: varasm.c:5846
 #, fuzzy, gcc-internal-format
 msgid "ifunc is not supported on this target"
 msgstr "sectie-attributen worden niet ondersteund op dit doelsysteem"
 
-#: varasm.c:5892
+#: varasm.c:5904
 #, gcc-internal-format
 msgid "weakref %q+D ultimately targets itself"
 msgstr ""
 
-#: varasm.c:5894
+#: varasm.c:5906
 #, gcc-internal-format
 msgid "weakref %q+D must have static linkage"
 msgstr ""
 
-#: varasm.c:5901
+#: varasm.c:5913
 #, fuzzy, gcc-internal-format
 msgid "alias definitions not supported in this configuration"
 msgstr "alias-definities worden niet ondersteund in deze configuratie; genegeerd"
 
-#: varasm.c:5909
+#: varasm.c:5923
 #, fuzzy, gcc-internal-format
 msgid "ifunc is not supported in this configuration"
 msgstr "alias-definities worden niet ondersteund in deze configuratie; genegeerd"
 
-#: varasm.c:6127 config/sol2.c:159 config/i386/winnt.c:265
+#: varasm.c:6141 config/sol2.c:159 config/i386/winnt.c:265
 #, fuzzy, gcc-internal-format
 msgid "visibility attribute not supported in this configuration; ignored"
 msgstr "alias-definities worden niet ondersteund in deze configuratie; genegeerd"
@@ -25071,189 +25093,195 @@
 msgid "bytecode stream: tag %s is not in the expected range [%s, %s]"
 msgstr ""
 
-#: c-family/c-attribs.c:529
+#: c-family/c-attribs.c:524
+#, fuzzy, gcc-internal-format
+#| msgid "%qE attribute ignored for %qE"
+msgid "%qE attribute ignored for type %qT"
+msgstr "attribuut %qE wordt genegeerd wegens %qE"
+
+#: c-family/c-attribs.c:536
 #, gcc-internal-format
 msgid "%qE attribute ignored for field of type %qT"
 msgstr "attribuut %qE wordt genegeerd voor veld van type %qT"
 
 # Of moet dit vertaald worden als 'zichtbaarheidsargument is ...'?
-#: c-family/c-attribs.c:696
+#: c-family/c-attribs.c:706
 #, fuzzy, gcc-internal-format
 #| msgid "visibility argument not a string"
 msgid "no_sanitize argument not a string"
 msgstr "zichtbaarheidsargument is geen string"
 
-#: c-family/c-attribs.c:826 ada/gcc-interface/utils.c:6235
+#: c-family/c-attribs.c:837 ada/gcc-interface/utils.c:6240
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "%qE attribute ignored due to conflict with attribute %qs"
 msgstr "attribuut %qE botst met attribuut %s"
 
-#: c-family/c-attribs.c:875
+#: c-family/c-attribs.c:886
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute ignored. Use -fcf-protection option to enable it"
 msgstr "attribuut %qE wordt genegeerd voor non-class-types"
 
-#: c-family/c-attribs.c:914 c-family/c-attribs.c:920 c-family/c-attribs.c:3388
-#: c-family/c-attribs.c:3423 c-family/c-attribs.c:3429
+#: c-family/c-attribs.c:925 c-family/c-attribs.c:931 c-family/c-attribs.c:3399
+#: c-family/c-attribs.c:3434 c-family/c-attribs.c:3440
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "%qE attribute ignored due to conflict with %qs attribute"
 msgstr "attribuut %qE botst met attribuut %s"
 
-#: c-family/c-attribs.c:976 brig/brig-lang.c:482 lto/lto-lang.c:288
+#: c-family/c-attribs.c:987 brig/brig-lang.c:482 lto/lto-lang.c:288
 #, gcc-internal-format
 msgid "%qE attribute has no effect on unit local functions"
 msgstr ""
 
-#: c-family/c-attribs.c:1130
+#: c-family/c-attribs.c:1141
 #, gcc-internal-format
 msgid "%qE attribute have effect only on public objects"
 msgstr ""
 
-#: c-family/c-attribs.c:1159
+#: c-family/c-attribs.c:1170
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to variables"
 msgid "%qE attribute only affects top level objects"
 msgstr "attribuut %qE is enkel van toepassing op variabelen"
 
-#: c-family/c-attribs.c:1198 c-family/c-attribs.c:2682
+#: c-family/c-attribs.c:1209 c-family/c-attribs.c:2693
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute on function returning %<void%>"
 msgstr "%<return%> zonder waarde in een functie die een niet-void waarde teruggeeft"
 
-#: c-family/c-attribs.c:1221 c-family/c-pragma.c:419
+#: c-family/c-attribs.c:1232 c-family/c-pragma.c:419
 #, gcc-internal-format
 msgid "scalar_storage_order is not supported because endianness is not uniform"
 msgstr ""
 
-#: c-family/c-attribs.c:1238
+#: c-family/c-attribs.c:1249
 #, gcc-internal-format
 msgid "scalar_storage_order argument must be one of \"big-endian\" or \"little-endian\""
 msgstr ""
 
-#: c-family/c-attribs.c:1334
+#: c-family/c-attribs.c:1345
 #, fuzzy, gcc-internal-format
 msgid "destructor priorities are not supported"
 msgstr "-pipe wordt niet ondersteund"
 
-#: c-family/c-attribs.c:1336
+#: c-family/c-attribs.c:1347
 #, fuzzy, gcc-internal-format
 msgid "constructor priorities are not supported"
 msgstr "-pipe wordt niet ondersteund"
 
-#: c-family/c-attribs.c:1358
+#: c-family/c-attribs.c:1369
 #, gcc-internal-format, gfc-internal-format
 msgid "destructor priorities from 0 to %d are reserved for the implementation"
 msgstr ""
 
-#: c-family/c-attribs.c:1363
+#: c-family/c-attribs.c:1374
 #, gcc-internal-format, gfc-internal-format
 msgid "constructor priorities from 0 to %d are reserved for the implementation"
 msgstr ""
 
-#: c-family/c-attribs.c:1371
+#: c-family/c-attribs.c:1382
 #, gcc-internal-format, gfc-internal-format
 msgid "destructor priorities must be integers from 0 to %d inclusive"
 msgstr ""
 
-#: c-family/c-attribs.c:1374
+#: c-family/c-attribs.c:1385
 #, gcc-internal-format, gfc-internal-format
 msgid "constructor priorities must be integers from 0 to %d inclusive"
 msgstr ""
 
-#: c-family/c-attribs.c:1527
+#: c-family/c-attribs.c:1538
 #, fuzzy, gcc-internal-format
 msgid "unknown machine mode %qE"
 msgstr "onbekende machine-modus %qs"
 
-#: c-family/c-attribs.c:1557
+#: c-family/c-attribs.c:1568
 #, gcc-internal-format
 msgid "specifying vector types with __attribute__ ((mode)) is deprecated"
 msgstr "het aanduiden van vector-types via __attribute__ ((mode)) zal niet lang meer ondersteund worden"
 
-#: c-family/c-attribs.c:1560
+#: c-family/c-attribs.c:1571
 #, gcc-internal-format
 msgid "use __attribute__ ((vector_size)) instead"
 msgstr "gebruik ter vervanging __attribute__ ((vector_size))"
 
-#: c-family/c-attribs.c:1569
+#: c-family/c-attribs.c:1580
 #, gcc-internal-format
 msgid "unable to emulate %qs"
 msgstr "kan %qs niet emuleren"
 
-#: c-family/c-attribs.c:1582
+#: c-family/c-attribs.c:1593
 #, gcc-internal-format
 msgid "invalid pointer mode %qs"
 msgstr "%qs is geen geldige pointer-modus"
 
-#: c-family/c-attribs.c:1599
+#: c-family/c-attribs.c:1610
 #, gcc-internal-format
 msgid "signedness of type and machine mode %qs don%'t match"
 msgstr ""
 
-#: c-family/c-attribs.c:1610
+#: c-family/c-attribs.c:1621
 #, gcc-internal-format
 msgid "no data type for mode %qs"
 msgstr "geen datatype voor modus %qs"
 
 # volgens dict is "enumeral" geen echt woord - maakt het dus lastig te vertalen
-#: c-family/c-attribs.c:1620
+#: c-family/c-attribs.c:1631
 #, gcc-internal-format
 msgid "cannot use mode %qs for enumeral types"
 msgstr "kan %qs-modus niet gebruiken voor enumeratie-types"
 
 # zou leterlijk "ontoepasselijk" moeten zijn, maar dat klinkt zo stom vanwege de "toegepast"
-#: c-family/c-attribs.c:1647
+#: c-family/c-attribs.c:1658
 #, gcc-internal-format
 msgid "mode %qs applied to inappropriate type"
 msgstr "%qs-modus toegepast op ongeschikt type"
 
-#: c-family/c-attribs.c:1669
+#: c-family/c-attribs.c:1680
 #, fuzzy, gcc-internal-format
 msgid "section attributes are not supported for this target"
 msgstr "%Jsectie-attributen worden niet ondersteund voor dit doelsysteem"
 
-#: c-family/c-attribs.c:1675
+#: c-family/c-attribs.c:1686
 #, gcc-internal-format
 msgid "section attribute not allowed for %q+D"
 msgstr "sectie-attribuut is niet toegestaan voor %q+D"
 
 # XXX FIXME:  duplicate
-#: c-family/c-attribs.c:1681
+#: c-family/c-attribs.c:1692
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute argument not a string constant"
 msgid "section attribute argument not a string constant"
 msgstr "het argument van attribuut %qE is geen string-constante"
 
-#: c-family/c-attribs.c:1690
+#: c-family/c-attribs.c:1701
 #, gcc-internal-format
 msgid "section attribute cannot be specified for local variables"
 msgstr "sectie-attribuut kan niet opgegeven worden voor lokale variabelen"
 
-#: c-family/c-attribs.c:1700 config/bfin/bfin.c:4806 config/bfin/bfin.c:4857
+#: c-family/c-attribs.c:1711 config/bfin/bfin.c:4806 config/bfin/bfin.c:4857
 #: config/bfin/bfin.c:4883 config/bfin/bfin.c:4896
 #, fuzzy, gcc-internal-format
 msgid "section of %q+D conflicts with previous declaration"
 msgstr "%Jsectie van %qD geeft een conflict met een eerdere declaratie"
 
-#: c-family/c-attribs.c:1708
+#: c-family/c-attribs.c:1719
 #, fuzzy, gcc-internal-format
 msgid "section of %q+D cannot be overridden"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: c-family/c-attribs.c:1773
+#: c-family/c-attribs.c:1784
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "requested alignment %d is larger than %d"
 msgstr "gevraagd alignment is te groot"
 
-#: c-family/c-attribs.c:1866
+#: c-family/c-attribs.c:1877
 #, fuzzy, gcc-internal-format
 msgid "alignment may not be specified for %q+D"
 msgstr "%Jer kan geen alignment opgegeven worden voor %qD"
 
-#: c-family/c-attribs.c:1886
+#: c-family/c-attribs.c:1897
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "ignoring attribute %<%E (%u)%> because it conflicts with attribute %<%E (%u)%>"
@@ -25260,293 +25288,293 @@
 msgstr "attribuut %qE botst met attribuut %s"
 
 #. Do not error out for attribute warn_if_not_aligned.
-#: c-family/c-attribs.c:1891 c-family/c-attribs.c:1920
+#: c-family/c-attribs.c:1902 c-family/c-attribs.c:1931
 #, fuzzy, gcc-internal-format
 msgid "alignment for %q+D must be at least %d"
 msgstr "Alignment moet een kleine macht van twee zijn, en niet %d, in #pragma pack"
 
-#: c-family/c-attribs.c:1916
+#: c-family/c-attribs.c:1927
 #, gcc-internal-format
 msgid "alignment for %q+D was previously specified as %d and may not be decreased"
 msgstr ""
 
-#: c-family/c-attribs.c:1943
+#: c-family/c-attribs.c:1954
 #, fuzzy, gcc-internal-format
 msgid "%<warn_if_not_aligned%> may not be specified for %q+D"
 msgstr "%Jer kan geen alignment opgegeven worden voor %qD"
 
-#: c-family/c-attribs.c:1986
+#: c-family/c-attribs.c:1997
 #, fuzzy, gcc-internal-format
 msgid "inline function %q+D declared weak"
 msgstr "%Jgeneste functie %qD gedeclareerd maar niet gedefinieerd"
 
-#: c-family/c-attribs.c:1991
+#: c-family/c-attribs.c:2002
 #, fuzzy, gcc-internal-format
 msgid "indirect function %q+D cannot be declared weak"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: c-family/c-attribs.c:2015
+#: c-family/c-attribs.c:2026
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to functions"
 msgid "%qE attribute is only applicable on functions"
 msgstr "attribuut %qE is enkel van toepassing op functies"
 
-#: c-family/c-attribs.c:2046
+#: c-family/c-attribs.c:2057
 #, fuzzy, gcc-internal-format
 msgid "%q+D defined both normally and as %qE attribute"
 msgstr "%J%qD is zowel als alias en als normale naam gedefinieerd"
 
-#: c-family/c-attribs.c:2054
+#: c-family/c-attribs.c:2065
 #, fuzzy, gcc-internal-format
 msgid "weak %q+D cannot be defined %qE"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: c-family/c-attribs.c:2071 c-family/c-attribs.c:2582
+#: c-family/c-attribs.c:2082 c-family/c-attribs.c:2593
 #, gcc-internal-format
 msgid "attribute %qE argument not a string"
 msgstr ""
 
-#: c-family/c-attribs.c:2106
+#: c-family/c-attribs.c:2117
 #, fuzzy, gcc-internal-format
 msgid "%+qD declared alias after being used"
 msgstr "%J%qD als inline gedeclareerd na oproep"
 
-#: c-family/c-attribs.c:2108
+#: c-family/c-attribs.c:2119
 #, fuzzy, gcc-internal-format
 msgid "%+qD declared ifunc after being used"
 msgstr "%J%qD als inline gedeclareerd na oproep"
 
-#: c-family/c-attribs.c:2159
+#: c-family/c-attribs.c:2170
 #, fuzzy, gcc-internal-format
 msgid "indirect function %q+D cannot be declared weakref"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: c-family/c-attribs.c:2181
+#: c-family/c-attribs.c:2192
 #, gcc-internal-format
 msgid "weakref attribute must appear before alias attribute"
 msgstr ""
 
-#: c-family/c-attribs.c:2193
+#: c-family/c-attribs.c:2204
 #, fuzzy, gcc-internal-format
 msgid "%+qD declared weakref after being used"
 msgstr "%J%qD als inline gedeclareerd na oproep"
 
-#: c-family/c-attribs.c:2217
+#: c-family/c-attribs.c:2228
 #, gcc-internal-format
 msgid "%qE attribute ignored on non-class types"
 msgstr "attribuut %qE wordt genegeerd voor non-class-types"
 
-#: c-family/c-attribs.c:2223
+#: c-family/c-attribs.c:2234
 #, gcc-internal-format
 msgid "%qE attribute ignored because %qT is already defined"
 msgstr "attribuut %qE wordt genegeerd omdat %qT reeds gedefinieerd is"
 
 # Of moet dit vertaald worden als 'zichtbaarheidsargument is ...'?
-#: c-family/c-attribs.c:2236
+#: c-family/c-attribs.c:2247
 #, gcc-internal-format
 msgid "visibility argument not a string"
 msgstr "zichtbaarheidsargument is geen string"
 
-#: c-family/c-attribs.c:2248
+#: c-family/c-attribs.c:2259
 #, gcc-internal-format
 msgid "%qE attribute ignored on types"
 msgstr "attribuut %qE wordt genegeerd voor types"
 
-#: c-family/c-attribs.c:2264
+#: c-family/c-attribs.c:2275
 #, fuzzy, gcc-internal-format
 msgid "visibility argument must be one of \"default\", \"hidden\", \"protected\" or \"internal\""
 msgstr "het argument van %<visibility%> moet \"default\", \"hidden\", \"protected\" of \"internal\" zijn"
 
-#: c-family/c-attribs.c:2275
+#: c-family/c-attribs.c:2286
 #, fuzzy, gcc-internal-format
 msgid "%qD redeclared with different visibility"
 msgstr "%qs als ander soort symbool geherdeclareerd"
 
-#: c-family/c-attribs.c:2278 c-family/c-attribs.c:2282
+#: c-family/c-attribs.c:2289 c-family/c-attribs.c:2293
 #, gcc-internal-format
 msgid "%qD was declared %qs which implies default visibility"
 msgstr ""
 
-#: c-family/c-attribs.c:2320
+#: c-family/c-attribs.c:2331
 #, fuzzy, gcc-internal-format
 msgid "tls_model argument not a string"
 msgstr "het argument van %<tls_model%> is geen string"
 
-#: c-family/c-attribs.c:2333
+#: c-family/c-attribs.c:2344
 #, fuzzy, gcc-internal-format
 msgid "tls_model argument must be one of \"local-exec\", \"initial-exec\", \"local-dynamic\" or \"global-dynamic\""
 msgstr "het argument van %<tls_model%> moet \"local-exec\", \"initial-exec\", \"local-dynamic\" of \"global-dynamic\" zijn"
 
-#: c-family/c-attribs.c:2353 c-family/c-attribs.c:2656
-#: c-family/c-attribs.c:3497 config/m32c/m32c.c:2944
+#: c-family/c-attribs.c:2364 c-family/c-attribs.c:2667
+#: c-family/c-attribs.c:3508 config/m32c/m32c.c:2944
 #, gcc-internal-format
 msgid "%qE attribute applies only to functions"
 msgstr "attribuut %qE is enkel van toepassing op functies"
 
-#: c-family/c-attribs.c:2417
+#: c-family/c-attribs.c:2428
 #, gcc-internal-format
 msgid "alloc_size parameter outside range"
 msgstr ""
 
-#: c-family/c-attribs.c:2443
+#: c-family/c-attribs.c:2454
 #, gcc-internal-format
 msgid "alloc_align parameter outside range"
 msgstr ""
 
-#: c-family/c-attribs.c:2467
+#: c-family/c-attribs.c:2478
 #, fuzzy, gcc-internal-format
 msgid "assume_aligned parameter not integer constant"
 msgstr "gevraagd alignment is geen constante"
 
-#: c-family/c-attribs.c:2595
+#: c-family/c-attribs.c:2606
 #, gcc-internal-format
 msgid "only %<inbranch%> and %<notinbranch%> flags are allowed for %<__simd__%> attribute"
 msgstr ""
 
-#: c-family/c-attribs.c:2662 c-family/c-attribs.c:3503
+#: c-family/c-attribs.c:2673 c-family/c-attribs.c:3514
 #, gcc-internal-format
 msgid "can%'t set %qE attribute after definition"
 msgstr "kan attribuut %qE niet instellen na een definitie"
 
-#: c-family/c-attribs.c:2727
+#: c-family/c-attribs.c:2738
 #, gcc-internal-format
 msgid "%qE attribute duplicated"
 msgstr "attribuut %qE is gedupliceerd"
 
-#: c-family/c-attribs.c:2729
+#: c-family/c-attribs.c:2740
 #, gcc-internal-format
 msgid "%qE attribute follows %qE"
 msgstr "attribuut %qE volgt na %qE"
 
-#: c-family/c-attribs.c:2828
+#: c-family/c-attribs.c:2839
 #, fuzzy, gcc-internal-format
 msgid "type was previously declared %qE"
 msgstr "eerdere declaratie van %qs"
 
-#: c-family/c-attribs.c:2841 cp/class.c:4397
+#: c-family/c-attribs.c:2852 cp/class.c:4401
 #, fuzzy, gcc-internal-format
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: c-family/c-attribs.c:2899
+#: c-family/c-attribs.c:2910
 #, fuzzy, gcc-internal-format
 msgid "%qE argument not an identifier"
 msgstr "het argument van %<cleanup%> is geen naam"
 
-#: c-family/c-attribs.c:2910
+#: c-family/c-attribs.c:2921
 #, fuzzy, gcc-internal-format
 msgid "%qD is not compatible with %qD"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: c-family/c-attribs.c:2913
+#: c-family/c-attribs.c:2924
 #, fuzzy, gcc-internal-format
 msgid "%qE argument is not a function"
 msgstr "het argument van %<cleanup%> is geen functie"
 
-#: c-family/c-attribs.c:2961
+#: c-family/c-attribs.c:2972
 #, gcc-internal-format
 msgid "deprecated message is not a string"
 msgstr ""
 
-#: c-family/c-attribs.c:3002
+#: c-family/c-attribs.c:3013
 #, gcc-internal-format
 msgid "%qE attribute ignored for %qE"
 msgstr "attribuut %qE wordt genegeerd wegens %qE"
 
-#: c-family/c-attribs.c:3065
+#: c-family/c-attribs.c:3076
 #, gcc-internal-format
 msgid "invalid vector type for attribute %qE"
 msgstr "ongeldig vector-type voor attribuut %qE"
 
-#: c-family/c-attribs.c:3071 ada/gcc-interface/utils.c:3896
+#: c-family/c-attribs.c:3082 ada/gcc-interface/utils.c:3899
 #, gcc-internal-format
 msgid "vector size not an integral multiple of component size"
 msgstr ""
 
-#: c-family/c-attribs.c:3077 ada/gcc-interface/utils.c:3903
+#: c-family/c-attribs.c:3088 ada/gcc-interface/utils.c:3906
 #, gcc-internal-format
 msgid "zero vector size"
 msgstr ""
 
-#: c-family/c-attribs.c:3085
+#: c-family/c-attribs.c:3096
 #, gcc-internal-format
 msgid "number of components of the vector not a power of two"
 msgstr "het aantal componenten van de vector is geen macht van twee"
 
-#: c-family/c-attribs.c:3118 ada/gcc-interface/utils.c:6092
+#: c-family/c-attribs.c:3129 ada/gcc-interface/utils.c:6098
 #, gcc-internal-format
 msgid "nonnull attribute without arguments on a non-prototype"
 msgstr "attribuut 'nonnull' is gebruikt zonder argumenten voor een niet-prototype"
 
-#: c-family/c-attribs.c:3137 ada/gcc-interface/utils.c:6106
+#: c-family/c-attribs.c:3148 ada/gcc-interface/utils.c:6112
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument has invalid operand number (argument %lu)"
 msgstr "argument van %<nonnull%> heeft een ongeldig operandnummer (argument %lu)"
 
-#: c-family/c-attribs.c:3159 ada/gcc-interface/utils.c:6128
+#: c-family/c-attribs.c:3170 ada/gcc-interface/utils.c:6134
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument with out-of-range operand number (argument %lu, operand %lu)"
 msgstr "argument van %<nonnull%> heeft een operandnummer dat buiten bereik is (argument %lu, operand %lu)"
 
-#: c-family/c-attribs.c:3168 ada/gcc-interface/utils.c:6137
+#: c-family/c-attribs.c:3179 ada/gcc-interface/utils.c:6143
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument references non-pointer operand (argument %lu, operand %lu)"
 msgstr "argument van %<nonnull%> verwijst naar niet-pointer operand (argument %lu, operand %lu)"
 
-#: c-family/c-attribs.c:3208
+#: c-family/c-attribs.c:3219
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored for field of type %qT"
 msgid "%qE attribute ignored on objects of type %qT"
 msgstr "attribuut %qE wordt genegeerd voor veld van type %qT"
 
-#: c-family/c-attribs.c:3216
+#: c-family/c-attribs.c:3227
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute does not apply to types"
 msgid "%qE attribute does not apply to functions"
 msgstr "attribuut %qE heeft geen betekenis voor types"
 
-#: c-family/c-attribs.c:3273
+#: c-family/c-attribs.c:3284
 #, fuzzy, gcc-internal-format
 msgid "cleanup argument not an identifier"
 msgstr "het argument van %<cleanup%> is geen naam"
 
-#: c-family/c-attribs.c:3280
+#: c-family/c-attribs.c:3291
 #, fuzzy, gcc-internal-format
 msgid "cleanup argument not a function"
 msgstr "het argument van %<cleanup%> is geen functie"
 
-#: c-family/c-attribs.c:3317
+#: c-family/c-attribs.c:3328
 #, gcc-internal-format
 msgid "%qE attribute requires prototypes with named arguments"
 msgstr "attribuut %qE vereist prototypes met benoemde argumenten"
 
 # goede vertaling van variadic?
-#: c-family/c-attribs.c:3325
+#: c-family/c-attribs.c:3336
 #, gcc-internal-format
 msgid "%qE attribute only applies to variadic functions"
 msgstr "attribuut %qE is enkel van toepassing op variadische functies"
 
-#: c-family/c-attribs.c:3341 ada/gcc-interface/utils.c:6179
+#: c-family/c-attribs.c:3352 ada/gcc-interface/utils.c:6185
 #, gcc-internal-format
 msgid "requested position is not an integer constant"
 msgstr "gevraagde positie is geen integerconstante"
 
-#: c-family/c-attribs.c:3349 ada/gcc-interface/utils.c:6186
+#: c-family/c-attribs.c:3360 ada/gcc-interface/utils.c:6192
 #, gcc-internal-format
 msgid "requested position is less than zero"
 msgstr "gevraagde positie is kleiner dan nul"
 
-#: c-family/c-attribs.c:3404
+#: c-family/c-attribs.c:3415
 #, fuzzy, gcc-internal-format
 msgid "empty string in attribute %<target%>"
 msgstr "herhaalde label-declaratie %qs"
 
-#: c-family/c-attribs.c:3520
+#: c-family/c-attribs.c:3531
 #, fuzzy, gcc-internal-format
 msgid "returns_nonnull attribute on a function not returning a pointer"
 msgstr "%<return%> met waarde in een functie die void teruggeeft"
 
-#: c-family/c-attribs.c:3535
+#: c-family/c-attribs.c:3546
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to function types"
 msgid "%qE attribute is only valid on %<struct%> type"
@@ -25593,12 +25621,12 @@
 msgid "__builtin_shuffle argument vector(s) inner type must have the same size as inner type of the mask"
 msgstr ""
 
-#: c-family/c-common.c:1262 c-family/c-warn.c:1194
+#: c-family/c-common.c:1262 c-family/c-warn.c:1202
 #, fuzzy, gcc-internal-format
 msgid "unsigned conversion from %qT to %qT changes value from %qE to %qE"
 msgstr "cast laat qualifiers van doeltype van pointer vallen"
 
-#: c-family/c-common.c:1267 c-family/c-warn.c:1202
+#: c-family/c-common.c:1267 c-family/c-warn.c:1210
 #, fuzzy, gcc-internal-format
 msgid "unsigned conversion from %qT to %qT changes the value of %qE"
 msgstr "ongeldige registernaam voor %qs"
@@ -25730,7 +25758,7 @@
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "gebruik liefst haakjes rond toewijzingen die als waarheid gebruikt worden"
 
-#: c-family/c-common.c:3518 c/c-decl.c:4325 c/c-decl.c:6430 c/c-typeck.c:14177
+#: c-family/c-common.c:3518 c/c-decl.c:4325 c/c-decl.c:6450 c/c-typeck.c:14182
 #, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr "ongeldig gebruik van %<restrict%>"
@@ -25811,7 +25839,7 @@
 msgid "duplicate case value"
 msgstr "herhaalde case-waarde"
 
-#: c-family/c-common.c:4867 c-family/c-warn.c:2216
+#: c-family/c-common.c:4867 c-family/c-warn.c:2225
 #, fuzzy, gcc-internal-format
 msgid "previously used here"
 msgstr "%Jeerder hier gebruikt"
@@ -25857,195 +25885,195 @@
 msgid "missing sentinel in function call"
 msgstr "sentinel ontbreekt in functie-oproep"
 
-#: c-family/c-common.c:5411
+#: c-family/c-common.c:5409
 #, gcc-internal-format, gfc-internal-format
 msgid "null argument where non-null required (argument %lu)"
 msgstr "null argument waar een niet-null argument vereist is (argument %lu)"
 
-#: c-family/c-common.c:5506 c-family/c-common.c:5553
+#: c-family/c-common.c:5504 c-family/c-common.c:5551
 #, gcc-internal-format
 msgid "bad option %qs to attribute %<optimize%>"
 msgstr ""
 
-#: c-family/c-common.c:5509 c-family/c-common.c:5557
+#: c-family/c-common.c:5507 c-family/c-common.c:5555
 #, fuzzy, gcc-internal-format
 msgid "bad option %qs to pragma %<optimize%>"
 msgstr "ongeldige bewerking met %<__fpreg%>"
 
-#: c-family/c-common.c:5589
+#: c-family/c-common.c:5587
 #, gcc-internal-format
 msgid "%<fallthrough%> attribute specified multiple times"
 msgstr ""
 
-#: c-family/c-common.c:5593
+#: c-family/c-common.c:5591
 #, fuzzy, gcc-internal-format
 msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr "argumenten aan macro %qs gegeven"
 
-#: c-family/c-common.c:5733 c-family/c-common.c:6485 c-family/c-common.c:6558
+#: c-family/c-common.c:5731 c-family/c-common.c:6477 c-family/c-common.c:6550
 #: c/c-typeck.c:3555
 #, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr "te weinig argumenten voor functie %qE"
 
-#: c-family/c-common.c:5738 c-family/c-common.c:6584 c/c-typeck.c:3284
+#: c-family/c-common.c:5736 c-family/c-common.c:6576 c/c-typeck.c:3284
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to function %qE"
 msgstr "te veel argumenten voor functie %qE"
 
-#: c-family/c-common.c:5769
+#: c-family/c-common.c:5767
 #, fuzzy, gcc-internal-format
 #| msgid "third argument to %<__builtin_prefetch%> must be a constant"
 msgid "third argument to function %qE must be a constant integer"
 msgstr "derde argument voor %<__builtin_prefetch%> moet een constante zijn"
 
-#: c-family/c-common.c:5794
+#: c-family/c-common.c:5792
 #, gcc-internal-format
 msgid "second argument to function %qE must be a constant integer power of 2 between %qi and %qu bits"
 msgstr ""
 
-#: c-family/c-common.c:5815 c-family/c-common.c:5859
+#: c-family/c-common.c:5813 c-family/c-common.c:5857
 #, fuzzy, gcc-internal-format
 msgid "non-floating-point argument in call to function %qE"
 msgstr "niet-floating-point argument voor functie %qs"
 
-#: c-family/c-common.c:5838
+#: c-family/c-common.c:5836
 #, fuzzy, gcc-internal-format
 msgid "non-floating-point arguments in call to function %qE"
 msgstr "niet-floating-point argument voor functie %qs"
 
-#: c-family/c-common.c:5852
+#: c-family/c-common.c:5850
 #, fuzzy, gcc-internal-format
 msgid "non-const integer argument %u in call to function %qE"
 msgstr "niet-floating-point argument voor functie %qs"
 
-#: c-family/c-common.c:5872
+#: c-family/c-common.c:5870
 #, fuzzy, gcc-internal-format
 msgid "non-integer argument 3 in call to function %qE"
 msgstr "niet-floating-point argument voor functie %qs"
 
-#: c-family/c-common.c:5889 c-family/c-common.c:5925
+#: c-family/c-common.c:5887 c-family/c-common.c:5923
 #, fuzzy, gcc-internal-format
 msgid "argument %u in call to function %qE does not have integral type"
 msgstr "grootte van array %qs is van een niet-integer type"
 
-#: c-family/c-common.c:5896
+#: c-family/c-common.c:5894
 #, fuzzy, gcc-internal-format
 msgid "argument 3 in call to function %qE does not have pointer to integral type"
 msgstr "grootte van array %qs is van een niet-integer type"
 
-#: c-family/c-common.c:5902
+#: c-family/c-common.c:5900
 #, fuzzy, gcc-internal-format
 msgid "argument 3 in call to function %qE has pointer to enumerated type"
 msgstr "herhalings-aantal is geen integerconstante"
 
-#: c-family/c-common.c:5908
+#: c-family/c-common.c:5906
 #, fuzzy, gcc-internal-format
 msgid "argument 3 in call to function %qE has pointer to boolean type"
 msgstr "niet-floating-point argument voor functie %qs"
 
-#: c-family/c-common.c:5931
+#: c-family/c-common.c:5929
 #, fuzzy, gcc-internal-format
 msgid "argument 3 in call to function %qE has enumerated type"
 msgstr "niet-floating-point argument voor functie %qs"
 
-#: c-family/c-common.c:5937
+#: c-family/c-common.c:5935
 #, fuzzy, gcc-internal-format
 msgid "argument 3 in call to function %qE has boolean type"
 msgstr "niet-floating-point argument voor functie %qs"
 
-#: c-family/c-common.c:6184
+#: c-family/c-common.c:6183
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to static data member %qD"
 msgstr "ongeldig gebruik van onvolledige typedef %qs"
 
-#: c-family/c-common.c:6189
+#: c-family/c-common.c:6188
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> when %<operator[]%> is overloaded"
 msgstr ""
 
-#: c-family/c-common.c:6196
+#: c-family/c-common.c:6195
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to a non constant address"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: c-family/c-common.c:6209
+#: c-family/c-common.c:6208
 #, fuzzy, gcc-internal-format
 msgid "attempt to take address of bit-field structure member %qD"
 msgstr "poging om het adres te nemen van lid %qs van een bitveld-structure"
 
-#: c-family/c-common.c:6261
+#: c-family/c-common.c:6260
 #, gcc-internal-format
 msgid "index %E denotes an offset greater than size of %qT"
 msgstr ""
 
-#: c-family/c-common.c:6427 cp/init.c:3004 cp/init.c:3023
+#: c-family/c-common.c:6419 cp/init.c:3020 cp/init.c:3039
 #, fuzzy, gcc-internal-format
 msgid "size of array is too large"
 msgstr "omvang van array %qs is te groot"
 
-#: c-family/c-common.c:6517
+#: c-family/c-common.c:6509
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible type for argument %d of %qE"
 msgid "operand type %qT is incompatible with argument %d of %qE"
 msgstr "incompatibel type voor argument %d van %qE"
 
-#: c-family/c-common.c:6651
+#: c-family/c-common.c:6643
 #, fuzzy, gcc-internal-format
 msgid "incorrect number of arguments to function %qE"
 msgstr "te weinig argumenten voor functie %qE"
 
-#: c-family/c-common.c:6665
+#: c-family/c-common.c:6657
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a non-void pointer type"
 msgstr ""
 
-#: c-family/c-common.c:6674
+#: c-family/c-common.c:6666
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a constant size type"
 msgstr "herhalings-aantal is geen integerconstante"
 
-#: c-family/c-common.c:6685
+#: c-family/c-common.c:6677
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a nonzero size object"
 msgstr "herhalings-aantal is geen integerconstante"
 
-#: c-family/c-common.c:6706
+#: c-family/c-common.c:6698
 #, gcc-internal-format
 msgid "argument %d of %qE must be a pointer type"
 msgstr ""
 
-#: c-family/c-common.c:6714
+#: c-family/c-common.c:6706
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must be a pointer to a constant size type"
 msgstr "herhalings-aantal is geen integerconstante"
 
-#: c-family/c-common.c:6720
+#: c-family/c-common.c:6712
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a function"
 msgstr "herhalings-aantal is geen integerconstante"
 
-#: c-family/c-common.c:6728
+#: c-family/c-common.c:6720
 #, fuzzy, gcc-internal-format
 msgid "size mismatch in argument %d of %qE"
 msgstr "doorgeven van argument %d van %qs"
 
-#: c-family/c-common.c:6740
+#: c-family/c-common.c:6732
 #, gcc-internal-format
 msgid "non-integer memory model argument %d of %qE"
 msgstr ""
 
-#: c-family/c-common.c:6753
+#: c-family/c-common.c:6745
 #, fuzzy, gcc-internal-format
 msgid "invalid memory model argument %d of %qE"
 msgstr "ongeldig type-argument %qs"
 
-#: c-family/c-common.c:7672
+#: c-family/c-common.c:7664
 #, gcc-internal-format
 msgid "index value is out of bound"
 msgstr "indexwaarde valt buiten bereik"
 
-#: c-family/c-common.c:7714 c-family/c-common.c:7763 c-family/c-common.c:7779
+#: c-family/c-common.c:7706 c-family/c-common.c:7755 c-family/c-common.c:7771
 #, gcc-internal-format
 msgid "conversion of scalar %qT to vector %qT involves truncation"
 msgstr ""
@@ -26052,22 +26080,22 @@
 
 #. Reject arguments that are built-in functions with
 #. no library fallback.
-#: c-family/c-common.c:7867
+#: c-family/c-common.c:7859
 #, fuzzy, gcc-internal-format
 msgid "built-in function %qE must be directly called"
 msgstr "%Jingebouwde functie %qD gedeclareerd als niet-functie"
 
-#: c-family/c-common.c:7889 c/c-decl.c:6177
+#: c-family/c-common.c:7881 c/c-decl.c:6197
 #, fuzzy, gcc-internal-format
 msgid "size of array %qE is too large"
 msgstr "omvang van array %qs is te groot"
 
-#: c-family/c-common.c:7891 c/c-decl.c:6180
+#: c-family/c-common.c:7883 c/c-decl.c:6200
 #, fuzzy, gcc-internal-format
 msgid "size of unnamed array is too large"
 msgstr "omvang van array %qs is te groot"
 
-#: c-family/c-common.c:7921
+#: c-family/c-common.c:7913
 #, gcc-internal-format
 msgid "environment variable SOURCE_DATE_EPOCH must expand to a non-negative integer less than or equal to %wd"
 msgstr ""
@@ -26594,7 +26622,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr ""
 
-#: c-family/c-omp.c:557 cp/semantics.c:8186
+#: c-family/c-omp.c:557 cp/semantics.c:8189
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "ongeldig type voor iteratie-variabele %qE"
@@ -26610,22 +26638,22 @@
 msgid "%qE is not initialized"
 msgstr "parameter %qD krijgt beginwaarde"
 
-#: c-family/c-omp.c:599 cp/semantics.c:8076
+#: c-family/c-omp.c:599 cp/semantics.c:8079
 #, fuzzy, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "Ongeldig token in expressie"
 
-#: c-family/c-omp.c:704 cp/semantics.c:7732
+#: c-family/c-omp.c:704 cp/semantics.c:7735
 #, fuzzy, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "Ongeldig token in expressie"
 
-#: c-family/c-omp.c:711 cp/semantics.c:8082
+#: c-family/c-omp.c:711 cp/semantics.c:8085
 #, fuzzy, gcc-internal-format
 msgid "missing increment expression"
 msgstr "toewijzingsonderdrukking"
 
-#: c-family/c-omp.c:775 cp/semantics.c:7847
+#: c-family/c-omp.c:775 cp/semantics.c:7850
 #, fuzzy, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "Ongeldig token in expressie"
@@ -26682,112 +26710,127 @@
 msgid "%<-Wabi=1%> is not supported, using =2"
 msgstr "-pipe wordt niet ondersteund"
 
-#: c-family/c-opts.c:612 fortran/cpp.c:350
+#: c-family/c-opts.c:610 fortran/cpp.c:350
 #, fuzzy, gcc-internal-format
 msgid "output filename specified twice"
 msgstr "Bestandsnaam voor uitvoer twee keer opgegeven"
 
-#: c-family/c-opts.c:799
+#: c-family/c-opts.c:797
 #, gcc-internal-format
 msgid "-fexcess-precision=standard for C++"
 msgstr ""
 
-#: c-family/c-opts.c:834
+#: c-family/c-opts.c:832
 #, gcc-internal-format
 msgid "-fno-gnu89-inline is only supported in GNU99 or C99 mode"
 msgstr ""
 
-#: c-family/c-opts.c:880
+#: c-family/c-opts.c:878
 #, gcc-internal-format
 msgid "-Wformat-y2k ignored without -Wformat"
 msgstr "-Wformat-y2k genegeerd zonder -Wformat"
 
-#: c-family/c-opts.c:882
+#: c-family/c-opts.c:880
 #, gcc-internal-format
 msgid "-Wformat-extra-args ignored without -Wformat"
 msgstr "-Wformat-extra-args genegeerd zonder -Wformat"
 
-#: c-family/c-opts.c:884
+#: c-family/c-opts.c:882
 #, fuzzy, gcc-internal-format
 msgid "-Wformat-zero-length ignored without -Wformat"
 msgstr "-Wformat-extra-args genegeerd zonder -Wformat"
 
-#: c-family/c-opts.c:886
+#: c-family/c-opts.c:884
 #, gcc-internal-format
 msgid "-Wformat-nonliteral ignored without -Wformat"
 msgstr "-Wformat-nonliteral genegeerd zonder -Wformat"
 
-#: c-family/c-opts.c:888
+#: c-family/c-opts.c:886
 #, fuzzy, gcc-internal-format
 msgid "-Wformat-contains-nul ignored without -Wformat"
 msgstr "-Wformat-nonliteral genegeerd zonder -Wformat"
 
-#: c-family/c-opts.c:890
+#: c-family/c-opts.c:888
 #, gcc-internal-format
 msgid "-Wformat-security ignored without -Wformat"
 msgstr "-Wformat-security genegeerd zonder -Wformat"
 
-#: c-family/c-opts.c:928
+#: c-family/c-opts.c:918
 #, fuzzy, gcc-internal-format
 msgid "%<-fabi-compat-version=1%> is not supported, using =2"
 msgstr "-malign-loops=%d ligt niet tussen 0 en %d"
 
-#: c-family/c-opts.c:988
+#: c-family/c-opts.c:944
+#, gcc-internal-format
+msgid "-Wabi won't warn about anything"
+msgstr ""
+
+#: c-family/c-opts.c:946
+#, gcc-internal-format
+msgid "-Wabi warns about differences from the most up-to-date ABI, which is also used by default"
+msgstr ""
+
+#: c-family/c-opts.c:949
+#, gcc-internal-format
+msgid "use e.g. -Wabi=11 to warn about changes from GCC 7"
+msgstr ""
+
+#: c-family/c-opts.c:1003
 #, fuzzy, gcc-internal-format
 msgid "external TLS initialization functions not supported on this target"
 msgstr "sectie-attributen worden niet ondersteund op dit doelsysteem"
 
-#: c-family/c-opts.c:1001
+#: c-family/c-opts.c:1016
 #, gcc-internal-format, gfc-internal-format
 msgid "too many filenames given.  Type %s --help for usage"
 msgstr ""
 
-#: c-family/c-opts.c:1016
+#: c-family/c-opts.c:1031
 #, fuzzy, gcc-internal-format
 msgid "opening output file %s: %m"
 msgstr "kan bestand '%s' niet openen"
 
-#: c-family/c-opts.c:1036
+#: c-family/c-opts.c:1051
 #, gcc-internal-format, gfc-internal-format
 msgid "the \"%s\" debug format cannot be used with pre-compiled headers"
 msgstr ""
 
-#: c-family/c-opts.c:1190
+#: c-family/c-opts.c:1205
 #, fuzzy, gcc-internal-format
 msgid "opening dependency file %s: %m"
 msgstr "dynamische dependencies.\n"
 
-#: c-family/c-opts.c:1201
+#: c-family/c-opts.c:1216
 #, fuzzy, gcc-internal-format
 msgid "closing dependency file %s: %m"
 msgstr "dynamische dependencies.\n"
 
-#: c-family/c-opts.c:1204
+#: c-family/c-opts.c:1219
 #, fuzzy, gcc-internal-format
 msgid "when writing output to %s: %m"
 msgstr "kan bestand '%s' niet openen"
 
-#: c-family/c-opts.c:1284
+#: c-family/c-opts.c:1299
 #, fuzzy, gcc-internal-format
 msgid "to generate dependencies you must specify either -M or -MM"
 msgstr "-MG moet samen met ofwel -M, ofwel -MM gebruikt worden"
 
-#: c-family/c-opts.c:1307
+#: c-family/c-opts.c:1322
 #, fuzzy, gcc-internal-format
 msgid "-MG may only be used with -M or -MM"
 msgstr "macro %qs gebruikt zonder argumenten"
 
-#: c-family/c-opts.c:1340
+#: c-family/c-opts.c:1355
 #, gcc-internal-format
 msgid "-fdirectives-only is incompatible with -Wunused_macros"
 msgstr ""
 
-#: c-family/c-opts.c:1342
+#: c-family/c-opts.c:1357
 #, gcc-internal-format
 msgid "-fdirectives-only is incompatible with -traditional"
 msgstr ""
 
-#: c-family/c-opts.c:1534
+#: c-family/c-opts.c:1549
 #, gcc-internal-format
 msgid "too late for # directive to set debug directory"
 msgstr ""
@@ -27174,720 +27217,720 @@
 msgid "wrong type argument to %s"
 msgstr "argument van verkeerd type voor abs"
 
-#: c-family/c-warn.c:53 c-family/c-warn.c:66 cp/constexpr.c:1847
+#: c-family/c-warn.c:54 c-family/c-warn.c:67 cp/constexpr.c:1847
 #: cp/constexpr.c:4099
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "overflow in constante expressie"
 
-#: c-family/c-warn.c:93
+#: c-family/c-warn.c:94
 #, fuzzy, gcc-internal-format
 #| msgid "integer overflow in expression"
 msgid "integer overflow in expression %qE of type %qT results in %qE"
 msgstr "integer overflow in expressie"
 
-#: c-family/c-warn.c:95
+#: c-family/c-warn.c:96
 #, fuzzy, gcc-internal-format
 #| msgid "integer overflow in expression"
 msgid "integer overflow in expression of type %qT results in %qE"
 msgstr "integer overflow in expressie"
 
-#: c-family/c-warn.c:101
+#: c-family/c-warn.c:102
 #, fuzzy, gcc-internal-format
 #| msgid "floating point overflow in expression"
 msgid "floating point overflow in expression %qE of type %qT results in %qE"
 msgstr "floating-point overflow in expressie"
 
-#: c-family/c-warn.c:103
+#: c-family/c-warn.c:104
 #, fuzzy, gcc-internal-format
 #| msgid "floating point overflow in expression"
 msgid "floating point overflow in expression of type %qT results in %qE"
 msgstr "floating-point overflow in expressie"
 
-#: c-family/c-warn.c:109
+#: c-family/c-warn.c:110
 #, fuzzy, gcc-internal-format
 msgid "fixed-point overflow in expression %qE of type %qT results in %qE"
 msgstr "floating-point overflow in expressie"
 
-#: c-family/c-warn.c:111
+#: c-family/c-warn.c:112
 #, fuzzy, gcc-internal-format
 msgid "fixed-point overflow in expression of type %qT results in %qE"
 msgstr "floating-point overflow in expressie"
 
-#: c-family/c-warn.c:117
+#: c-family/c-warn.c:118
 #, fuzzy, gcc-internal-format
 #| msgid "vector overflow in expression"
 msgid "vector overflow in expression %qE of type %qT results in %qE"
 msgstr "vector overflow in expressie"
 
-#: c-family/c-warn.c:119
+#: c-family/c-warn.c:120
 #, fuzzy, gcc-internal-format
 #| msgid "vector overflow in expression"
 msgid "vector overflow in expression of type %qT results in %qE"
 msgstr "vector overflow in expressie"
 
-#: c-family/c-warn.c:126
+#: c-family/c-warn.c:127
 #, fuzzy, gcc-internal-format
 msgid "complex integer overflow in expression %qE of type %qT results in %qE"
 msgstr "integer overflow in expressie"
 
-#: c-family/c-warn.c:128
+#: c-family/c-warn.c:129
 #, fuzzy, gcc-internal-format
 msgid "complex integer overflow in expression of type %qT results in %qE"
 msgstr "integer overflow in expressie"
 
-#: c-family/c-warn.c:132
+#: c-family/c-warn.c:133
 #, fuzzy, gcc-internal-format
 msgid "complex floating point overflow in expression %qE of type %qT results in %qE"
 msgstr "floating-point overflow in expressie"
 
-#: c-family/c-warn.c:134
+#: c-family/c-warn.c:135
 #, fuzzy, gcc-internal-format
 msgid "complex floating point overflow in expression of type %qT results in %qE"
 msgstr "floating-point overflow in expressie"
 
-#: c-family/c-warn.c:216
+#: c-family/c-warn.c:217
 #, gcc-internal-format
 msgid "logical %<or%> applied to non-boolean constant"
 msgstr ""
 
-#: c-family/c-warn.c:219
+#: c-family/c-warn.c:220
 #, gcc-internal-format
 msgid "logical %<and%> applied to non-boolean constant"
 msgstr ""
 
-#: c-family/c-warn.c:289
+#: c-family/c-warn.c:290
 #, gcc-internal-format
 msgid "logical %<or%> of collectively exhaustive tests is always true"
 msgstr ""
 
-#: c-family/c-warn.c:293
+#: c-family/c-warn.c:294
 #, gcc-internal-format
 msgid "logical %<and%> of mutually exclusive tests is always false"
 msgstr ""
 
-#: c-family/c-warn.c:303
+#: c-family/c-warn.c:304
 #, fuzzy, gcc-internal-format
 msgid "logical %<or%> of equal expressions"
 msgstr "ongeldige operanden voor binaire %s-operator"
 
-#: c-family/c-warn.c:306
+#: c-family/c-warn.c:307
 #, fuzzy, gcc-internal-format
 msgid "logical %<and%> of equal expressions"
 msgstr "ongeldige operanden voor binaire %s-operator"
 
-#: c-family/c-warn.c:384
+#: c-family/c-warn.c:385
 #, gcc-internal-format
 msgid "bitwise comparison always evaluates to false"
 msgstr ""
 
 # is de "," deel van de special format spec of niet?  en moet "true" hier vertaald worden of niet?
-#: c-family/c-warn.c:387
+#: c-family/c-warn.c:388
 #, fuzzy, gcc-internal-format
 msgid "bitwise comparison always evaluates to true"
 msgstr "het adres van %qD, zal altijd %<true%> zijn"
 
-#: c-family/c-warn.c:441
+#: c-family/c-warn.c:442
 #, gcc-internal-format
 msgid "self-comparison always evaluates to true"
 msgstr ""
 
-#: c-family/c-warn.c:444
+#: c-family/c-warn.c:445
 #, gcc-internal-format
 msgid "self-comparison always evaluates to false"
 msgstr ""
 
-#: c-family/c-warn.c:494
+#: c-family/c-warn.c:495
 #, gcc-internal-format
 msgid "logical not is only applied to the left hand side of comparison"
 msgstr ""
 
-#: c-family/c-warn.c:502
+#: c-family/c-warn.c:503
 #, gcc-internal-format
 msgid "add parentheses around left hand side expression to silence this warning"
 msgstr ""
 
-#: c-family/c-warn.c:636
+#: c-family/c-warn.c:637
 #, gcc-internal-format
 msgid "type-punning to incomplete type might break strict-aliasing rules"
 msgstr ""
 
-#: c-family/c-warn.c:654
+#: c-family/c-warn.c:655
 #, gcc-internal-format
 msgid "dereferencing type-punned pointer will break strict-aliasing rules"
 msgstr ""
 
-#: c-family/c-warn.c:662 c-family/c-warn.c:680
+#: c-family/c-warn.c:663 c-family/c-warn.c:681
 #, gcc-internal-format
 msgid "dereferencing type-punned pointer might break strict-aliasing rules"
 msgstr ""
 
-#: c-family/c-warn.c:803
+#: c-family/c-warn.c:811
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to use the size of the destination?"
 msgstr ""
 
-#: c-family/c-warn.c:834
+#: c-family/c-warn.c:842
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the destination; did you mean to remove the addressof?"
 msgstr ""
 
-#: c-family/c-warn.c:841
+#: c-family/c-warn.c:849
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the destination; did you mean to provide an explicit length?"
 msgstr ""
 
-#: c-family/c-warn.c:846
+#: c-family/c-warn.c:854
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the destination; did you mean to dereference it?"
 msgstr ""
 
-#: c-family/c-warn.c:858
+#: c-family/c-warn.c:866
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the destination; expected %qT or an explicit length"
 msgstr ""
 
-#: c-family/c-warn.c:874
+#: c-family/c-warn.c:882
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to remove the addressof?"
 msgstr ""
 
-#: c-family/c-warn.c:881
+#: c-family/c-warn.c:889
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to provide an explicit length?"
 msgstr ""
 
-#: c-family/c-warn.c:886
+#: c-family/c-warn.c:894
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to dereference it?"
 msgstr ""
 
-#: c-family/c-warn.c:898
+#: c-family/c-warn.c:906
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the source; expected %qT or an explicit length"
 msgstr ""
 
-#: c-family/c-warn.c:914
+#: c-family/c-warn.c:922
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the first source; did you mean to remove the addressof?"
 msgstr ""
 
-#: c-family/c-warn.c:921
+#: c-family/c-warn.c:929
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the first source; did you mean to provide an explicit length?"
 msgstr ""
 
-#: c-family/c-warn.c:926
+#: c-family/c-warn.c:934
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the first source; did you mean to dereference it?"
 msgstr ""
 
-#: c-family/c-warn.c:938
+#: c-family/c-warn.c:946
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the first source; expected %qT or an explicit length"
 msgstr ""
 
-#: c-family/c-warn.c:954
+#: c-family/c-warn.c:962
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the second source; did you mean to remove the addressof?"
 msgstr ""
 
-#: c-family/c-warn.c:961
+#: c-family/c-warn.c:969
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the second source; did you mean to provide an explicit length?"
 msgstr ""
 
-#: c-family/c-warn.c:966
+#: c-family/c-warn.c:974
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the second source; did you mean to dereference it?"
 msgstr ""
 
-#: c-family/c-warn.c:978
+#: c-family/c-warn.c:986
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the second source; expected %qT or an explicit length"
 msgstr ""
 
-#: c-family/c-warn.c:1007 c-family/c-warn.c:1014
+#: c-family/c-warn.c:1015 c-family/c-warn.c:1022
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%>-qualified parameter type %qT of %q+D"
 msgstr "ISO C verbiedt gekwalificeerde functie-types"
 
-#: c-family/c-warn.c:1024
+#: c-family/c-warn.c:1032
 #, fuzzy, gcc-internal-format
 msgid "first argument of %q+D should be %<int%>"
 msgstr "%Jhet eerste argument van %qD zou een %<int%> moeten zijn"
 
-#: c-family/c-warn.c:1033
+#: c-family/c-warn.c:1041
 #, fuzzy, gcc-internal-format
 msgid "second argument of %q+D should be %<char **%>"
 msgstr "%Jhet tweede argument van %qD zou een %<char **%> moeten zijn"
 
-#: c-family/c-warn.c:1042
+#: c-family/c-warn.c:1050
 #, fuzzy, gcc-internal-format
 msgid "third argument of %q+D should probably be %<char **%>"
 msgstr "%Jhet derde argument van %qD zou waarschijnlijk een %<char **%> moeten zijn"
 
-#: c-family/c-warn.c:1053
+#: c-family/c-warn.c:1061
 #, fuzzy, gcc-internal-format
 msgid "%q+D takes only zero or two arguments"
 msgstr "%J%qD neemt ofwel geen, ofwel twee argumenten"
 
-#: c-family/c-warn.c:1057
+#: c-family/c-warn.c:1065
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared as variadic function"
 msgstr "veld %qs als een functie gedeclareerd"
 
-#: c-family/c-warn.c:1099
+#: c-family/c-warn.c:1107
 #, fuzzy, gcc-internal-format
 msgid "conversion to %qT from boolean expression"
 msgstr "ongeldige registernaam voor %qs"
 
-#: c-family/c-warn.c:1117 c-family/c-warn.c:1192
+#: c-family/c-warn.c:1125 c-family/c-warn.c:1200
 #, fuzzy, gcc-internal-format
 msgid "conversion from %qT to %qT changes value from %qE to %qE"
 msgstr "cast laat qualifiers van doeltype van pointer vallen"
 
-#: c-family/c-warn.c:1121 c-family/c-warn.c:1200
+#: c-family/c-warn.c:1129 c-family/c-warn.c:1208
 #, fuzzy, gcc-internal-format
 msgid "conversion from %qT to %qT changes the value of %qE"
 msgstr "ongeldige registernaam voor %qs"
 
-#: c-family/c-warn.c:1141
+#: c-family/c-warn.c:1149
 #, fuzzy, gcc-internal-format
 msgid "conversion from %qT to %qT discards imaginary component"
 msgstr "cast laat qualifiers van doeltype van pointer vallen"
 
-#: c-family/c-warn.c:1153
+#: c-family/c-warn.c:1161
 #, fuzzy, gcc-internal-format
 msgid "conversion from %qT to %qT may change value"
 msgstr "ongeldige registernaam voor %qs"
 
-#: c-family/c-warn.c:1213 c-family/c-warn.c:1230 c-family/c-warn.c:1247
+#: c-family/c-warn.c:1221 c-family/c-warn.c:1238 c-family/c-warn.c:1255
 #, fuzzy, gcc-internal-format
 msgid "overflow in conversion from %qT to %qT changes value from %qE to %qE"
 msgstr "ongeldige registernaam voor %qs"
 
-#: c-family/c-warn.c:1218 c-family/c-warn.c:1235 c-family/c-warn.c:1252
+#: c-family/c-warn.c:1226 c-family/c-warn.c:1243 c-family/c-warn.c:1260
 #, fuzzy, gcc-internal-format
 msgid "overflow in conversion from %qT to %qT changes the value of %qE"
 msgstr "ongeldige registernaam voor %qs"
 
-#: c-family/c-warn.c:1282
+#: c-family/c-warn.c:1290
 #, fuzzy, gcc-internal-format
 msgid "case value %qs not in enumerated type"
 msgstr "%Jcase-waarde %qs bestaat niet in het enumeratie-type"
 
-#: c-family/c-warn.c:1287
+#: c-family/c-warn.c:1295
 #, fuzzy, gcc-internal-format
 msgid "case value %qs not in enumerated type %qT"
 msgstr "%Jcase-waarde %qs bestaat niet in enumeratie-type %qT"
 
 # hopelijk kan ik hier %</%> gebruiken zelfs als ze niet in de originele boodschap staan...
-#: c-family/c-warn.c:1348
+#: c-family/c-warn.c:1356
 #, fuzzy, gcc-internal-format
 msgid "switch missing default case"
 msgstr "%H%<default%> geval ontbreekt in switch"
 
-#: c-family/c-warn.c:1393
+#: c-family/c-warn.c:1401
 #, gcc-internal-format
 msgid "switch condition has boolean value"
 msgstr ""
 
-#: c-family/c-warn.c:1466
+#: c-family/c-warn.c:1474
 #, fuzzy, gcc-internal-format
 msgid "enumeration value %qE not handled in switch"
 msgstr "%Henumeratiewaarde %qE wordt niet opgevangen in switch"
 
-#: c-family/c-warn.c:1494
+#: c-family/c-warn.c:1502
 #, gcc-internal-format
 msgid "the omitted middle operand in ?: will always be %<true%>, suggest explicit middle operand"
 msgstr ""
 
-#: c-family/c-warn.c:1515
+#: c-family/c-warn.c:1523
 #, fuzzy, gcc-internal-format
 msgid "assignment of member %qD in read-only object"
 msgstr "%s van alleen-lezen locatie"
 
-#: c-family/c-warn.c:1517
+#: c-family/c-warn.c:1525
 #, fuzzy, gcc-internal-format
 msgid "increment of member %qD in read-only object"
 msgstr "%s van alleen-lezen locatie"
 
-#: c-family/c-warn.c:1519
+#: c-family/c-warn.c:1527
 #, fuzzy, gcc-internal-format
 msgid "decrement of member %qD in read-only object"
 msgstr "%s van alleen-lezen locatie"
 
-#: c-family/c-warn.c:1521
+#: c-family/c-warn.c:1529
 #, gcc-internal-format
 msgid "member %qD in read-only object used as %<asm%> output"
 msgstr ""
 
-#: c-family/c-warn.c:1525
+#: c-family/c-warn.c:1533
 #, fuzzy, gcc-internal-format
 msgid "assignment of read-only member %qD"
 msgstr "%s van alleen-lezen lid %qs"
 
-#: c-family/c-warn.c:1526
+#: c-family/c-warn.c:1534
 #, fuzzy, gcc-internal-format
 msgid "increment of read-only member %qD"
 msgstr "%s van alleen-lezen lid %qs"
 
-#: c-family/c-warn.c:1527
+#: c-family/c-warn.c:1535
 #, fuzzy, gcc-internal-format
 msgid "decrement of read-only member %qD"
 msgstr "%s van alleen-lezen lid %qs"
 
-#: c-family/c-warn.c:1528
+#: c-family/c-warn.c:1536
 #, gcc-internal-format
 msgid "read-only member %qD used as %<asm%> output"
 msgstr ""
 
-#: c-family/c-warn.c:1532
+#: c-family/c-warn.c:1540
 #, fuzzy, gcc-internal-format
 msgid "assignment of read-only variable %qD"
 msgstr "%s van alleen-lezen variabele %qs"
 
-#: c-family/c-warn.c:1533
+#: c-family/c-warn.c:1541
 #, fuzzy, gcc-internal-format
 msgid "increment of read-only variable %qD"
 msgstr "%s van alleen-lezen variabele %qs"
 
-#: c-family/c-warn.c:1534
+#: c-family/c-warn.c:1542
 #, fuzzy, gcc-internal-format
 msgid "decrement of read-only variable %qD"
 msgstr "%s van alleen-lezen variabele %qs"
 
-#: c-family/c-warn.c:1535
+#: c-family/c-warn.c:1543
 #, gcc-internal-format
 msgid "read-only variable %qD used as %<asm%> output"
 msgstr ""
 
-#: c-family/c-warn.c:1538
+#: c-family/c-warn.c:1546
 #, fuzzy, gcc-internal-format
 msgid "assignment of read-only parameter %qD"
 msgstr "%s van alleen-lezen lid %qs"
 
-#: c-family/c-warn.c:1539
+#: c-family/c-warn.c:1547
 #, fuzzy, gcc-internal-format
 msgid "increment of read-only parameter %qD"
 msgstr "%s van alleen-lezen lid %qs"
 
-#: c-family/c-warn.c:1540
+#: c-family/c-warn.c:1548
 #, fuzzy, gcc-internal-format
 msgid "decrement of read-only parameter %qD"
 msgstr "%s van alleen-lezen lid %qs"
 
-#: c-family/c-warn.c:1541
+#: c-family/c-warn.c:1549
 #, fuzzy, gcc-internal-format
 msgid "read-only parameter %qD use as %<asm%> output"
 msgstr "%s van alleen-lezen lid %qs"
 
-#: c-family/c-warn.c:1546
+#: c-family/c-warn.c:1554
 #, fuzzy, gcc-internal-format
 msgid "assignment of read-only named return value %qD"
 msgstr "%s van alleen-lezen variabele %qs"
 
-#: c-family/c-warn.c:1548
+#: c-family/c-warn.c:1556
 #, fuzzy, gcc-internal-format
 msgid "increment of read-only named return value %qD"
 msgstr "%s van alleen-lezen variabele %qs"
 
-#: c-family/c-warn.c:1550
+#: c-family/c-warn.c:1558
 #, fuzzy, gcc-internal-format
 msgid "decrement of read-only named return value %qD"
 msgstr "%s van alleen-lezen variabele %qs"
 
-#: c-family/c-warn.c:1552
+#: c-family/c-warn.c:1560
 #, fuzzy, gcc-internal-format
 msgid "read-only named return value %qD used as %<asm%>output"
 msgstr "%s van alleen-lezen variabele %qs"
 
-#: c-family/c-warn.c:1557
+#: c-family/c-warn.c:1565
 #, fuzzy, gcc-internal-format
 msgid "assignment of function %qD"
 msgstr "kan functie %<main%> niet inline maken"
 
-#: c-family/c-warn.c:1558
+#: c-family/c-warn.c:1566
 #, fuzzy, gcc-internal-format
 msgid "increment of function %qD"
 msgstr "kan functie %<main%> niet inline maken"
 
-#: c-family/c-warn.c:1559
+#: c-family/c-warn.c:1567
 #, fuzzy, gcc-internal-format
 msgid "decrement of function %qD"
 msgstr "kan functie %<main%> niet inline maken"
 
-#: c-family/c-warn.c:1560
+#: c-family/c-warn.c:1568
 #, gcc-internal-format
 msgid "function %qD used as %<asm%> output"
 msgstr ""
 
-#: c-family/c-warn.c:1563 c/c-typeck.c:4762
+#: c-family/c-warn.c:1571 c/c-typeck.c:4767
 #, fuzzy, gcc-internal-format
 msgid "assignment of read-only location %qE"
 msgstr "%s van alleen-lezen locatie"
 
-#: c-family/c-warn.c:1564 c/c-typeck.c:4765
+#: c-family/c-warn.c:1572 c/c-typeck.c:4770
 #, fuzzy, gcc-internal-format
 msgid "increment of read-only location %qE"
 msgstr "%s van alleen-lezen locatie"
 
-#: c-family/c-warn.c:1565 c/c-typeck.c:4768
+#: c-family/c-warn.c:1573 c/c-typeck.c:4773
 #, fuzzy, gcc-internal-format
 msgid "decrement of read-only location %qE"
 msgstr "%s van alleen-lezen locatie"
 
-#: c-family/c-warn.c:1566
+#: c-family/c-warn.c:1574
 #, gcc-internal-format
 msgid "read-only location %qE used as %<asm%> output"
 msgstr ""
 
-#: c-family/c-warn.c:1580
+#: c-family/c-warn.c:1588
 #, fuzzy, gcc-internal-format
 msgid "lvalue required as left operand of assignment"
 msgstr "ongeldige lvalue in toewijzing"
 
-#: c-family/c-warn.c:1583
+#: c-family/c-warn.c:1591
 #, gcc-internal-format
 msgid "lvalue required as increment operand"
 msgstr ""
 
-#: c-family/c-warn.c:1586
+#: c-family/c-warn.c:1594
 #, gcc-internal-format
 msgid "lvalue required as decrement operand"
 msgstr ""
 
-#: c-family/c-warn.c:1589
+#: c-family/c-warn.c:1597
 #, gcc-internal-format
 msgid "lvalue required as unary %<&%> operand"
 msgstr ""
 
-#: c-family/c-warn.c:1592
+#: c-family/c-warn.c:1600
 #, fuzzy, gcc-internal-format
 msgid "lvalue required in asm statement"
 msgstr "ongeldige lvalue in asm-statement"
 
-#: c-family/c-warn.c:1609
+#: c-family/c-warn.c:1617
 #, fuzzy, gcc-internal-format
 msgid "invalid type argument (have %qT)"
 msgstr "ongeldig type-argument %qs"
 
-#: c-family/c-warn.c:1613
+#: c-family/c-warn.c:1621
 #, fuzzy, gcc-internal-format
 msgid "invalid type argument of array indexing (have %qT)"
 msgstr "ongeldig type-argument %qs"
 
-#: c-family/c-warn.c:1618
+#: c-family/c-warn.c:1626
 #, fuzzy, gcc-internal-format
 msgid "invalid type argument of unary %<*%> (have %qT)"
 msgstr "ongeldig type-argument %qs"
 
-#: c-family/c-warn.c:1623
+#: c-family/c-warn.c:1631
 #, fuzzy, gcc-internal-format
 msgid "invalid type argument of %<->%> (have %qT)"
 msgstr "ongeldig type-argument %qs"
 
-#: c-family/c-warn.c:1628
+#: c-family/c-warn.c:1636
 #, fuzzy, gcc-internal-format
 msgid "invalid type argument of %<->*%> (have %qT)"
 msgstr "ongeldig type-argument %qs"
 
-#: c-family/c-warn.c:1633
+#: c-family/c-warn.c:1641
 #, fuzzy, gcc-internal-format
 msgid "invalid type argument of implicit conversion (have %qT)"
 msgstr "ongeldig type-argument %qs"
 
-#: c-family/c-warn.c:1654
+#: c-family/c-warn.c:1662
 #, fuzzy, gcc-internal-format
 msgid "array subscript has type %<char%>"
 msgstr "array subscript is van het type %<char%>"
 
-#: c-family/c-warn.c:1689 c-family/c-warn.c:1692
+#: c-family/c-warn.c:1697 c-family/c-warn.c:1700
 #, fuzzy, gcc-internal-format
 msgid "suggest parentheses around %<+%> inside %<<<%>"
 msgstr "gebruik liefst haakjes rond + of - binnen een shift"
 
-#: c-family/c-warn.c:1695 c-family/c-warn.c:1698
+#: c-family/c-warn.c:1703 c-family/c-warn.c:1706
 #, fuzzy, gcc-internal-format
 msgid "suggest parentheses around %<-%> inside %<<<%>"
 msgstr "gebruik liefst haakjes rond + of - binnen een shift"
 
-#: c-family/c-warn.c:1704 c-family/c-warn.c:1707
+#: c-family/c-warn.c:1712 c-family/c-warn.c:1715
 #, fuzzy, gcc-internal-format
 msgid "suggest parentheses around %<+%> inside %<>>%>"
 msgstr "gebruik liefst haakjes rond + of - binnen een shift"
 
-#: c-family/c-warn.c:1710 c-family/c-warn.c:1713
+#: c-family/c-warn.c:1718 c-family/c-warn.c:1721
 #, fuzzy, gcc-internal-format
 msgid "suggest parentheses around %<-%> inside %<>>%>"
 msgstr "gebruik liefst haakjes rond + of - binnen een shift"
 
-#: c-family/c-warn.c:1719 c-family/c-warn.c:1722
+#: c-family/c-warn.c:1727 c-family/c-warn.c:1730
 #, fuzzy, gcc-internal-format
 msgid "suggest parentheses around %<&&%> within %<||%>"
 msgstr "gebruik liefst haakjes rond && binnen ||"
 
-#: c-family/c-warn.c:1729 c-family/c-warn.c:1733
+#: c-family/c-warn.c:1737 c-family/c-warn.c:1741
 #, fuzzy, gcc-internal-format
 msgid "suggest parentheses around arithmetic in operand of %<|%>"
 msgstr "gebruik liefst haakjes rond een rekensom in een operand van |"
 
-#: c-family/c-warn.c:1737 c-family/c-warn.c:1740
+#: c-family/c-warn.c:1745 c-family/c-warn.c:1748
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<|%>"
 msgstr "gebruik liefst haakjes rond een vergelijking in een operand van %<|%>"
 
-#: c-family/c-warn.c:1745
+#: c-family/c-warn.c:1753
 #, gcc-internal-format
 msgid "suggest parentheses around operand of %<!%> or change %<|%> to %<||%> or %<!%> to %<~%>"
 msgstr ""
 
-#: c-family/c-warn.c:1753 c-family/c-warn.c:1757
+#: c-family/c-warn.c:1761 c-family/c-warn.c:1765
 #, gcc-internal-format
 msgid "suggest parentheses around arithmetic in operand of %<^%>"
 msgstr "gebruik liefst haakjes rond een rekensom in een operand van %<^%>"
 
-#: c-family/c-warn.c:1761 c-family/c-warn.c:1764
+#: c-family/c-warn.c:1769 c-family/c-warn.c:1772
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<^%>"
 msgstr "gebruik liefst haakjes rond een vergelijking in een operand van %<^%>"
 
-#: c-family/c-warn.c:1770 c-family/c-warn.c:1773
+#: c-family/c-warn.c:1778 c-family/c-warn.c:1781
 #, gcc-internal-format
 msgid "suggest parentheses around %<+%> in operand of %<&%>"
 msgstr "gebruik liefst haakjes rond %<+%> in een operand van %<&%>"
 
-#: c-family/c-warn.c:1776 c-family/c-warn.c:1779
+#: c-family/c-warn.c:1784 c-family/c-warn.c:1787
 #, gcc-internal-format
 msgid "suggest parentheses around %<-%> in operand of %<&%>"
 msgstr "gebruik liefst haakjes rond %<-%> in een operand van %<&%>"
 
-#: c-family/c-warn.c:1783 c-family/c-warn.c:1786
+#: c-family/c-warn.c:1791 c-family/c-warn.c:1794
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<&%>"
 msgstr "gebruik liefst haakjes rond een vergelijking in een operand van %<&%>"
 
-#: c-family/c-warn.c:1791
+#: c-family/c-warn.c:1799
 #, gcc-internal-format
 msgid "suggest parentheses around operand of %<!%> or change %<&%> to %<&&%> or %<!%> to %<~%>"
 msgstr ""
 
-#: c-family/c-warn.c:1798 c-family/c-warn.c:1801
+#: c-family/c-warn.c:1806 c-family/c-warn.c:1809
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<==%>"
 msgstr "gebruik liefst haakjes rond een vergelijking in een operand van %<==%>"
 
-#: c-family/c-warn.c:1806 c-family/c-warn.c:1809
+#: c-family/c-warn.c:1814 c-family/c-warn.c:1817
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<!=%>"
 msgstr "gebruik liefst haakjes rond een vergelijking in een operand van %<!=%>"
 
-#: c-family/c-warn.c:1819 c-family/c-warn.c:1825
+#: c-family/c-warn.c:1827 c-family/c-warn.c:1833
 #, gcc-internal-format
 msgid "comparisons like %<X<=Y<=Z%> do not have their mathematical meaning"
 msgstr "vergelijkingen als %<X<=Y<=Z%> hebben niet hun wiskundige betekenis"
 
-#: c-family/c-warn.c:1841
+#: c-family/c-warn.c:1849
 #, gcc-internal-format
 msgid "label %q+D defined but not used"
 msgstr "label %q+D is gedefinieerd maar wordt niet gebruikt"
 
-#: c-family/c-warn.c:1843
+#: c-family/c-warn.c:1851
 #, gcc-internal-format
 msgid "label %q+D declared but not defined"
 msgstr "label %q+D is gedeclareerd maar wordt niet gebruikt"
 
-#: c-family/c-warn.c:1866
+#: c-family/c-warn.c:1874
 #, gcc-internal-format
 msgid "division by zero"
 msgstr "deling door nul"
 
-#: c-family/c-warn.c:1886
+#: c-family/c-warn.c:1894
 #, gcc-internal-format
 msgid "%<memset%> used with constant zero length parameter; this could be due to transposed parameters"
 msgstr ""
 
-#: c-family/c-warn.c:1909
+#: c-family/c-warn.c:1918
 #, gcc-internal-format
 msgid "%<memset%> used with length equal to number of elements without multiplication by element size"
 msgstr ""
 
-#: c-family/c-warn.c:1948 c/c-typeck.c:11499 c/c-typeck.c:11667
+#: c-family/c-warn.c:1957 c/c-typeck.c:11504 c/c-typeck.c:11672
 #: cp/typeck.c:5048
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr "vergelijking tussen types %qT en %qT"
 
-#: c-family/c-warn.c:1998
+#: c-family/c-warn.c:2007
 #, gcc-internal-format
 msgid "comparison of integer expressions of different signedness: %qT and %qT"
 msgstr ""
 
-#: c-family/c-warn.c:2051
+#: c-family/c-warn.c:2060
 #, gcc-internal-format
 msgid "promoted ~unsigned is always non-zero"
 msgstr ""
 
-#: c-family/c-warn.c:2054
+#: c-family/c-warn.c:2063
 #, gcc-internal-format
 msgid "comparison of promoted ~unsigned with constant"
 msgstr "vergelijking van gepromoveerde ~unsigned met constante"
 
-#: c-family/c-warn.c:2064
+#: c-family/c-warn.c:2073
 #, gcc-internal-format
 msgid "comparison of promoted ~unsigned with unsigned"
 msgstr "vergelijking van gepromoveerde ~unsigned met unsigned"
 
-#: c-family/c-warn.c:2118
+#: c-family/c-warn.c:2127
 #, fuzzy, gcc-internal-format
 msgid "unused parameter %qD"
 msgstr "ongeldige macronaam %<%.*s%>"
 
-#: c-family/c-warn.c:2180
+#: c-family/c-warn.c:2189
 #, fuzzy, gcc-internal-format
 msgid "typedef %qD locally defined but not used"
 msgstr "label %qs gedefinieerd maar niet gebruikt"
 
-#: c-family/c-warn.c:2215
+#: c-family/c-warn.c:2224
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<const%>"
 msgid "duplicated %<if%> condition"
 msgstr "herhaalde %<const%>"
 
-#: c-family/c-warn.c:2244
+#: c-family/c-warn.c:2253
 #, gcc-internal-format
 msgid "optimization attribute on %qD follows definition but the attribute doesn%'t match"
 msgstr ""
 
-#: c-family/c-warn.c:2254
+#: c-family/c-warn.c:2261
 #, fuzzy, gcc-internal-format
 msgid "inline declaration of %qD follows declaration with attribute %qs"
 msgstr "%Jdeclaratie van %qD als inline volgt declaratie met %<noinline%> attribuut"
 
-#: c-family/c-warn.c:2259
+#: c-family/c-warn.c:2266
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q+D with attribute %qs follows inline declaration"
 msgstr "%Jdeclaratie van %qD met %<noinline%> attribuut volgt declaratie als inline"
 
-#: c-family/c-warn.c:2306
+#: c-family/c-warn.c:2313
 #, gcc-internal-format
 msgid "result of %qE requires %u bits to represent, but %qT only has %u bits"
 msgstr ""
 
-#: c-family/c-warn.c:2344 c-family/c-warn.c:2368
+#: c-family/c-warn.c:2351 c-family/c-warn.c:2375
 #, fuzzy, gcc-internal-format
 #| msgid "comparison of unsigned expression < 0 is always false"
 msgid "comparison of constant %qE with boolean expression is always false"
 msgstr "vergelijking van 'unsigned'-expressie < 0 is altijd onwaar"
 
-#: c-family/c-warn.c:2347 c-family/c-warn.c:2365
+#: c-family/c-warn.c:2354 c-family/c-warn.c:2372
 #, fuzzy, gcc-internal-format
 #| msgid "comparison of unsigned expression >= 0 is always true"
 msgid "comparison of constant %qE with boolean expression is always true"
 msgstr "vergelijking van 'unsigned'-expressie >= 0 is altijd waar"
 
-#: c-family/c-warn.c:2415
+#: c-family/c-warn.c:2422
 #, fuzzy
 msgid "passing argument %i to restrict-qualified parameter aliases with argument %Z"
 msgid_plural "passing argument %i to restrict-qualified parameter aliases with arguments %Z"
@@ -27894,17 +27937,17 @@
 msgstr[0] "cast laat qualifiers van doeltype van pointer vallen"
 msgstr[1] "cast laat qualifiers van doeltype van pointer vallen"
 
-#: c-family/c-warn.c:2480 c/c-typeck.c:5288 cp/call.c:5365
+#: c-family/c-warn.c:2487 c/c-typeck.c:5293 cp/call.c:5365
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr ""
 
-#: c-family/c-warn.c:2586
+#: c-family/c-warn.c:2593
 #, gcc-internal-format
 msgid "macro expands to multiple statements"
 msgstr ""
 
-#: c-family/c-warn.c:2587
+#: c-family/c-warn.c:2594
 #, gcc-internal-format
 msgid "some parts of macro expansion are not guarded by this %qs clause"
 msgstr ""
@@ -27919,7 +27962,7 @@
 msgid "too many input files"
 msgstr "te veel invoerbestanden"
 
-#: common/config/aarch64/aarch64-common.c:319 config/aarch64/aarch64.c:10686
+#: common/config/aarch64/aarch64-common.c:319 config/aarch64/aarch64.c:10702
 #, fuzzy, gcc-internal-format
 msgid "unknown value %qs for -mcpu"
 msgstr "slechte waarde (%s) voor optie -mcpu"
@@ -27950,7 +27993,7 @@
 msgstr ""
 
 #: common/config/arm/arm-common.c:322 common/config/arm/arm-common.c:376
-#: common/config/arm/arm-common.c:423 config/aarch64/aarch64.c:10639
+#: common/config/arm/arm-common.c:423 config/aarch64/aarch64.c:10655
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments are: %s; did you mean %qs?"
@@ -27957,7 +28000,7 @@
 msgstr "geldige argumenten van %qs zijn: %s"
 
 #: common/config/arm/arm-common.c:325 common/config/arm/arm-common.c:379
-#: common/config/arm/arm-common.c:426 config/aarch64/aarch64.c:10642
+#: common/config/arm/arm-common.c:426 config/aarch64/aarch64.c:10658
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments are: %s"
@@ -28439,13 +28482,13 @@
 msgid "profiler support for VxWorks"
 msgstr ""
 
-#: config/aarch64/aarch64-builtins.c:1109 config/arm/arm-builtins.c:2262
+#: config/aarch64/aarch64-builtins.c:1109 config/arm/arm-builtins.c:2272
 #, fuzzy, gcc-internal-format
 #| msgid "argument must be a constant"
 msgid "%Kargument %d must be a constant immediate"
 msgstr "argument moet een constante zijn"
 
-#: config/aarch64/aarch64-builtins.c:1180 config/arm/arm-builtins.c:2492
+#: config/aarch64/aarch64-builtins.c:1180 config/arm/arm-builtins.c:2502
 #, fuzzy, gcc-internal-format
 msgid "%Klane index must be a constant immediate"
 msgstr "%<defined%> zonder een naam"
@@ -28455,175 +28498,175 @@
 msgid "%Ktotal size and element size must be a non-zero constant immediate"
 msgstr ""
 
-#: config/aarch64/aarch64.c:1053
+#: config/aarch64/aarch64.c:1069
 #, fuzzy, gcc-internal-format
 msgid "%qs is incompatible with %s %s"
 msgstr "case-selector niet compatibel met label"
 
-#: config/aarch64/aarch64.c:1055
+#: config/aarch64/aarch64.c:1071
 #, fuzzy, gcc-internal-format
 msgid "%qs feature modifier is incompatible with %s %s"
 msgstr "case-selector niet compatibel met label"
 
-#: config/aarch64/aarch64.c:3772
+#: config/aarch64/aarch64.c:3788
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10287
+#: config/aarch64/aarch64.c:10303
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown flag passed in -moverride=%s (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10331
+#: config/aarch64/aarch64.c:10347
 #, gcc-internal-format, gfc-internal-format
 msgid "%s string ill-formed\n"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10388
+#: config/aarch64/aarch64.c:10404
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr "Ongeldige optie voor floating-point emulatie: -mfpe-%s"
 
-#: config/aarch64/aarch64.c:10406
+#: config/aarch64/aarch64.c:10422
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown tuning option (%s)"
 msgstr "onbekende spec-functie '%s'"
 
-#: config/aarch64/aarch64.c:10683
+#: config/aarch64/aarch64.c:10699
 #, fuzzy, gcc-internal-format
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr "ontbrekende witruimte na getal %qs"
 
-#: config/aarch64/aarch64.c:10690
+#: config/aarch64/aarch64.c:10706
 #, fuzzy, gcc-internal-format
 msgid "invalid feature modifier in %<-mcpu=%s%>"
 msgstr "beginwaarde ontbreekt"
 
-#: config/aarch64/aarch64.c:10717
+#: config/aarch64/aarch64.c:10733
 #, fuzzy, gcc-internal-format
 msgid "missing arch name in %<-march=%s%>"
 msgstr "ontbrekende witruimte na getal %qs"
 
-#: config/aarch64/aarch64.c:10720
+#: config/aarch64/aarch64.c:10736
 #, fuzzy, gcc-internal-format
 msgid "unknown value %qs for -march"
 msgstr "slechte waarde (%s) voor de -march= optie"
 
-#: config/aarch64/aarch64.c:10724
+#: config/aarch64/aarch64.c:10740
 #, fuzzy, gcc-internal-format
 msgid "invalid feature modifier in %<-march=%s%>"
 msgstr "beginwaarde ontbreekt"
 
-#: config/aarch64/aarch64.c:10750
+#: config/aarch64/aarch64.c:10766
 #, fuzzy, gcc-internal-format
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr "ontbrekende witruimte na getal %qs"
 
-#: config/aarch64/aarch64.c:10753
+#: config/aarch64/aarch64.c:10769
 #, fuzzy, gcc-internal-format
 msgid "unknown value %qs for -mtune"
 msgstr "slechte waarde (%s) voor de -march= optie"
 
-#: config/aarch64/aarch64.c:10871 config/arm/arm.c:3173
+#: config/aarch64/aarch64.c:10887 config/arm/arm.c:3173
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "switch -mcpu=%s conflicts with -march=%s switch"
 msgstr "optie -mcpu=%s geeft conflicten met optie -mtune="
 
-#: config/aarch64/aarch64.c:10906
+#: config/aarch64/aarch64.c:10922
 #, fuzzy, gcc-internal-format
 msgid "assembler does not support -mabi=ilp32"
 msgstr "ondersteunt geen multilib"
 
-#: config/aarch64/aarch64.c:10913
+#: config/aarch64/aarch64.c:10929
 #, gcc-internal-format
 msgid "return address signing is only supported for -mabi=lp64"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10975
+#: config/aarch64/aarch64.c:10991
 #, gcc-internal-format
 msgid "code model %qs with -f%s"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11138
+#: config/aarch64/aarch64.c:11154
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11141
+#: config/aarch64/aarch64.c:11157
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11145 config/aarch64/aarch64.c:11184
-#: config/aarch64/aarch64.c:11257
+#: config/aarch64/aarch64.c:11161 config/aarch64/aarch64.c:11200
+#: config/aarch64/aarch64.c:11273
 #, fuzzy, gcc-internal-format
 msgid "invalid value (\"%s\") in %<target()%> pragma or attribute"
 msgstr "ongeldig type-argument %qs"
 
-#: config/aarch64/aarch64.c:11177
+#: config/aarch64/aarch64.c:11193
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11180
+#: config/aarch64/aarch64.c:11196
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11213
+#: config/aarch64/aarch64.c:11229
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"tune=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11253
+#: config/aarch64/aarch64.c:11269
 #, fuzzy, gcc-internal-format
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr "misvormde #pragma pack"
 
-#: config/aarch64/aarch64.c:11306 config/aarch64/aarch64.c:11483
+#: config/aarch64/aarch64.c:11322 config/aarch64/aarch64.c:11499
 #, fuzzy, gcc-internal-format
 msgid "malformed %<target()%> pragma or attribute"
 msgstr "misvormde #pragma weak"
 
-#: config/aarch64/aarch64.c:11354
+#: config/aarch64/aarch64.c:11370
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11362
+#: config/aarch64/aarch64.c:11378
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11416
+#: config/aarch64/aarch64.c:11432
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11473 config/arm/arm.c:30742
-#: config/i386/i386.c:5440 config/powerpcspe/powerpcspe.c:39760
-#: config/rs6000/rs6000.c:36904 config/s390/s390.c:15746
+#: config/aarch64/aarch64.c:11489 config/arm/arm.c:30742
+#: config/i386/i386.c:5443 config/powerpcspe/powerpcspe.c:39760
+#: config/rs6000/rs6000.c:36960 config/s390/s390.c:15746
 #, fuzzy, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "het argument van %<alias%> is geen string"
 
-#: config/aarch64/aarch64.c:11500
+#: config/aarch64/aarch64.c:11516
 #, fuzzy, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr "het argument van %<alias%> is geen string"
 
-#: config/aarch64/aarch64.c:11509
+#: config/aarch64/aarch64.c:11525
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13571
+#: config/aarch64/aarch64.c:13587
 #, fuzzy, gcc-internal-format
 msgid "%Klane %wd out of range %wd - %wd"
 msgstr "operandnummer buiten bereik"
 
-#: config/aarch64/aarch64.c:13573
+#: config/aarch64/aarch64.c:13589
 #, fuzzy, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr "operandnummer buiten bereik"
@@ -28684,8 +28727,8 @@
 msgid "bad value %qs for -mmemory-latency"
 msgstr "slechte waarde %qs voor -mmeroy-latency"
 
-#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6526
-#: config/arc/arc.c:6800 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
+#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6517
+#: config/arc/arc.c:6791 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
 #: config/tilepro/tilepro.c:3108
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -28794,11 +28837,11 @@
 #: config/arm/arm.c:7029 config/avr/avr.c:9718 config/avr/avr.c:9734
 #: config/bfin/bfin.c:4705 config/bfin/bfin.c:4766 config/bfin/bfin.c:4795
 #: config/epiphany/epiphany.c:491 config/h8300/h8300.c:5459
-#: config/i386/i386.c:6452 config/i386/i386.c:12479 config/i386/i386.c:41424
-#: config/i386/i386.c:41474 config/i386/i386.c:41544 config/m68k/m68k.c:780
+#: config/i386/i386.c:6455 config/i386/i386.c:12482 config/i386/i386.c:41418
+#: config/i386/i386.c:41468 config/i386/i386.c:41538 config/m68k/m68k.c:780
 #: config/mcore/mcore.c:3070 config/nvptx/nvptx.c:4611
 #: config/powerpcspe/powerpcspe.c:35785 config/riscv/riscv.c:2698
-#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:32982
+#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:33038
 #: config/rx/rx.c:2719 config/rx/rx.c:2745 config/s390/s390.c:1056
 #: config/s390/s390.c:1143 config/sh/sh.c:8428 config/sh/sh.c:8446
 #: config/sh/sh.c:8470 config/sh/sh.c:8541 config/sh/sh.c:8564
@@ -28808,139 +28851,139 @@
 msgid "%qE attribute only applies to functions"
 msgstr "attribuut %qE is enkel van toepassing op functies"
 
-#: config/arc/arc.c:6425
+#: config/arc/arc.c:6416
 #, fuzzy, gcc-internal-format
 msgid "__builtin_arc_aligned with non-constant alignment"
 msgstr "%<__builtin_next_arg%> opgeroepen zonder argument"
 
-#: config/arc/arc.c:6433
+#: config/arc/arc.c:6424
 #, fuzzy, gcc-internal-format
 msgid "invalid alignment value for __builtin_arc_aligned"
 msgstr "ongeldig argument voor %<__builtin_frame_address%>"
 
-#: config/arc/arc.c:6596
+#: config/arc/arc.c:6587
 #, gcc-internal-format
 msgid "operand 1 should be an unsigned 3-bit immediate"
 msgstr ""
 
-#: config/arc/arc.c:6637 config/arc/arc.c:6734
+#: config/arc/arc.c:6628 config/arc/arc.c:6725
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6670 config/arc/arc.c:6702
+#: config/arc/arc.c:6661 config/arc/arc.c:6693
 #, gcc-internal-format
 msgid "operand 1 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6674 config/arc/arc.c:6706
+#: config/arc/arc.c:6665 config/arc/arc.c:6697
 #, fuzzy, gcc-internal-format
 msgid "operand 2 should be an unsigned 8-bit value"
 msgstr "%<defined%> zonder een naam"
 
-#: config/arc/arc.c:6738
+#: config/arc/arc.c:6729
 #, fuzzy, gcc-internal-format
 msgid "operand 3 should be an unsigned 8-bit value"
 msgstr "%<defined%> zonder een naam"
 
-#: config/arc/arc.c:6771
+#: config/arc/arc.c:6762
 #, gcc-internal-format
 msgid "operand 4 should be an unsigned 8-bit value (0-255)"
 msgstr ""
 
-#: config/arc/arc.c:6775
+#: config/arc/arc.c:6766
 #, gcc-internal-format
 msgid "operand 3 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6782
+#: config/arc/arc.c:6773
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (subreg 0-7)"
 msgstr ""
 
-#: config/arc/arc.c:6785
+#: config/arc/arc.c:6776
 #, gcc-internal-format
 msgid "operand 2 should be an even 3-bit value (subreg 0,2,4,6)"
 msgstr ""
 
-#: config/arc/arc.c:6832
+#: config/arc/arc.c:6823
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "builtin requires an immediate for operand %d"
 msgstr "een long long constante is geen geldige onmiddellijke operand"
 
-#: config/arc/arc.c:6837
+#: config/arc/arc.c:6828
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "operand %d should be a 6 bit unsigned immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/arc/arc.c:6841
+#: config/arc/arc.c:6832
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "operand %d should be a 8 bit unsigned immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/arc/arc.c:6845
+#: config/arc/arc.c:6836
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "operand %d should be a 3 bit unsigned immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/arc/arc.c:6848
+#: config/arc/arc.c:6839
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown builtin immediate operand type for operand %d"
 msgstr ""
 
-#: config/arc/arc.c:6899
+#: config/arc/arc.c:6890
 #, gcc-internal-format
 msgid "register number must be a compile-time constant. Try giving higher optimization levels"
 msgstr ""
 
-#: config/arc/arc.c:7685
+#: config/arc/arc.c:7747
 #, gcc-internal-format
 msgid "Insn addresses not set after shorten_branches"
 msgstr ""
 
 # pre-increment vertalen? zoja, als wat?
-#: config/arc/arc.c:7894
+#: config/arc/arc.c:7956
 #, fuzzy, gcc-internal-format
 msgid "insn addresses not freed"
 msgstr "pre-increment adres is geen register"
 
-#: config/arc/arc.c:10682
+#: config/arc/arc.c:10670
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only available for 32-bit"
 msgid "%qE attribute only valid for ARCv2 architecture"
 msgstr "attribuut %qE is alleen beschikbaar voor 32-bits"
 
-#: config/arc/arc.c:10690 config/arc/arc.c:10729
+#: config/arc/arc.c:10678 config/arc/arc.c:10717
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qE attribute is not a string constant"
 msgid "argument of %qE attribute is missing"
 msgstr "argument van attribuut %qE is geen string-constante"
 
-#: config/arc/arc.c:10701 config/arc/arc.c:10740 config/arc/arc.c:10842
+#: config/arc/arc.c:10689 config/arc/arc.c:10728 config/arc/arc.c:10830
 #: config/avr/avr.c:9790
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute allows only an integer constant argument"
 msgstr "herhalings-aantal is geen integerconstante"
 
-#: config/arc/arc.c:10721
+#: config/arc/arc.c:10709
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only available for 32-bit"
 msgid "%qE attribute only valid for ARC EM architecture"
 msgstr "attribuut %qE is alleen beschikbaar voor 32-bits"
 
-#: config/arc/arc.c:10776
+#: config/arc/arc.c:10764
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to function types"
 msgid "%qE attribute only applies to types"
 msgstr "attribuut %qE is enkel van toepassing op functie-types"
 
-#: config/arc/arc.c:10782
+#: config/arc/arc.c:10770
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored"
 msgid "argument of %qE attribute ignored"
 msgstr "attribuut %qE wordt genegeerd"
 
-#: config/arc/arc.c:10832 config/avr/avr.c:9777 config/bfin/bfin.c:4827
+#: config/arc/arc.c:10820 config/avr/avr.c:9777 config/bfin/bfin.c:4827
 #: config/i386/winnt.c:63 config/msp430/msp430.c:2018
 #: config/nvptx/nvptx.c:4634
 #, gcc-internal-format
@@ -28947,174 +28990,174 @@
 msgid "%qE attribute only applies to variables"
 msgstr "attribuut %qE is enkel van toepassing op variabelen"
 
-#: config/arm/arm-builtins.c:2370
+#: config/arm/arm-builtins.c:2380
 #, fuzzy, gcc-internal-format
 msgid "this builtin is not supported for this target"
 msgstr "sectie-attributen worden niet ondersteund op dit doelsysteem"
 
-#: config/arm/arm-builtins.c:2475
+#: config/arm/arm-builtins.c:2485
 #, gcc-internal-format
 msgid "You must enable NEON instructions (e.g. -mfloat-abi=softfp -mfpu=neon) to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2513
+#: config/arm/arm-builtins.c:2523
 #, gcc-internal-format
 msgid "You must enable VFP instructions to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2573
+#: config/arm/arm-builtins.c:2583
 #, gcc-internal-format
 msgid "You must enable crypto instructions (e.g. include -mfloat-abi=softfp -mfpu=crypto-neon...) to use these intrinsics."
 msgstr ""
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:2633 config/arm/arm-builtins.c:2737
+#: config/arm/arm-builtins.c:2643 config/arm/arm-builtins.c:2747
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2641 config/arm/arm-builtins.c:2686
-#: config/arm/arm-builtins.c:2744 config/arm/arm-builtins.c:2753
+#: config/arm/arm-builtins.c:2651 config/arm/arm-builtins.c:2696
+#: config/arm/arm-builtins.c:2754 config/arm/arm-builtins.c:2763
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2646 config/arm/arm-builtins.c:2755
+#: config/arm/arm-builtins.c:2656 config/arm/arm-builtins.c:2765
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2651 config/arm/arm-builtins.c:2757
+#: config/arm/arm-builtins.c:2661 config/arm/arm-builtins.c:2767
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2823
+#: config/arm/arm-builtins.c:2833
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2828
+#: config/arm/arm-builtins.c:2838
 #, gcc-internal-format
 msgid "the range of mask should be in 0 to 255"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3016
+#: config/arm/arm-builtins.c:3026
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3018
+#: config/arm/arm-builtins.c:3028
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3020
+#: config/arm/arm-builtins.c:3030
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3022
+#: config/arm/arm-builtins.c:3032
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3028
+#: config/arm/arm-builtins.c:3038
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3030
+#: config/arm/arm-builtins.c:3040
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3035
+#: config/arm/arm-builtins.c:3045
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3037
+#: config/arm/arm-builtins.c:3047
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3039
+#: config/arm/arm-builtins.c:3049
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3041
+#: config/arm/arm-builtins.c:3051
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3043
+#: config/arm/arm-builtins.c:3053
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3045
+#: config/arm/arm-builtins.c:3055
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3047
+#: config/arm/arm-builtins.c:3057
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3049
+#: config/arm/arm-builtins.c:3059
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3051
+#: config/arm/arm-builtins.c:3061
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3053
+#: config/arm/arm-builtins.c:3063
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3055
+#: config/arm/arm-builtins.c:3065
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3057
+#: config/arm/arm-builtins.c:3067
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3059
+#: config/arm/arm-builtins.c:3069
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3061
+#: config/arm/arm-builtins.c:3071
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3063
+#: config/arm/arm-builtins.c:3073
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3065
+#: config/arm/arm-builtins.c:3075
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3067
+#: config/arm/arm-builtins.c:3077
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3069
+#: config/arm/arm-builtins.c:3079
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr ""
@@ -30035,564 +30078,564 @@
 msgid "can%'t set position in PCH file: %m"
 msgstr "kan bestand '%s' niet openen"
 
-#: config/i386/i386.c:3177
+#: config/i386/i386.c:3180
 #, fuzzy, gcc-internal-format
 msgid "wrong argument %qs to option %qs"
 msgstr "fout in argumenten voor spec-functie '%s'"
 
-#: config/i386/i386.c:3183
+#: config/i386/i386.c:3186
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr ""
 
-#: config/i386/i386.c:3193
+#: config/i386/i386.c:3196
 #, fuzzy, gcc-internal-format
 msgid "wrong strategy name %qs specified for option %qs"
 msgstr "%Jer kan geen alignment opgegeven worden voor %qD"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3219
+#: config/i386/i386.c:3222
 #, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386.c:3232
+#: config/i386/i386.c:3235
 #, fuzzy, gcc-internal-format
 msgid "unknown alignment %qs specified for option %qs"
 msgstr "%Jer kan geen alignment opgegeven worden voor %qD"
 
-#: config/i386/i386.c:3242
+#: config/i386/i386.c:3245
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr ""
 
-#: config/i386/i386.c:3249
+#: config/i386/i386.c:3252
 #, fuzzy, gcc-internal-format
 msgid "too many size ranges specified in option %qs"
 msgstr "Bestandsnaam voor uitvoer twee keer opgegeven"
 
-#: config/i386/i386.c:3302
+#: config/i386/i386.c:3305
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown parameter to option -mtune-ctrl: %s"
 msgstr "Bestandsnaam ontbreekt na %qs optie"
 
-#: config/i386/i386.c:3726
+#: config/i386/i386.c:3729
 #, fuzzy, gcc-internal-format
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "afrondingsmodus niet ondersteund voor VAX-floats"
 
-#: config/i386/i386.c:3775
+#: config/i386/i386.c:3778
 #, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr ""
 
-#: config/i386/i386.c:3777
+#: config/i386/i386.c:3780
 #, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr ""
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3804
+#: config/i386/i386.c:3807
 #, gcc-internal-format
 msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386.c:3821
+#: config/i386/i386.c:3824
 #, fuzzy, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "ISO C ondersteunt de %<%c%> lengte-optie niet"
 
-#: config/i386/i386.c:3833
+#: config/i386/i386.c:3836
 #, fuzzy, gcc-internal-format
 msgid "-mabi=ms not supported with X32 ABI"
 msgstr "-pipe wordt niet ondersteund"
 
-#: config/i386/i386.c:3851 config/i386/i386.c:3860 config/i386/i386.c:3872
-#: config/i386/i386.c:3883 config/i386/i386.c:3894
+#: config/i386/i386.c:3854 config/i386/i386.c:3863 config/i386/i386.c:3875
+#: config/i386/i386.c:3886 config/i386/i386.c:3897
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "ISO C ondersteunt de %<%c%> lengte-optie niet"
 
-#: config/i386/i386.c:3863 config/i386/i386.c:3875
+#: config/i386/i386.c:3866 config/i386/i386.c:3878
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "ISO C ondersteunt de %<%c%> lengte-optie niet"
 
-#: config/i386/i386.c:3881 config/i386/i386.c:3890 config/i386/i386.c:5213
+#: config/i386/i386.c:3884 config/i386/i386.c:3893 config/i386/i386.c:5216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "afrondingsmodus niet ondersteund voor VAX-floats"
 
-#: config/i386/i386.c:3918
+#: config/i386/i386.c:3921
 #, fuzzy, gcc-internal-format
 msgid "-masm=intel not supported in this configuration"
 msgstr "alias-definities worden niet ondersteund in deze configuratie; genegeerd"
 
-#: config/i386/i386.c:3923
+#: config/i386/i386.c:3926
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr ""
 
-#: config/i386/i386.c:3932
+#: config/i386/i386.c:3935
 #, fuzzy, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr "slechte waarde (%s) voor de -march= optie"
 
-#: config/i386/i386.c:3934
+#: config/i386/i386.c:3937
 #, fuzzy, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "slechte waarde (%s) voor de -march= optie"
 
-#: config/i386/i386.c:3941
+#: config/i386/i386.c:3944
 #, fuzzy, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr "slechte waarde (%s) voor de -march= optie"
 
-#: config/i386/i386.c:3943
+#: config/i386/i386.c:3946
 #, fuzzy, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "slechte waarde (%s) voor de -march= optie"
 
-#: config/i386/i386.c:3951 config/i386/i386.c:4265
+#: config/i386/i386.c:3954 config/i386/i386.c:4268
 #, fuzzy, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "doel-CPU ondersteunt geen interworking"
 
-#: config/i386/i386.c:4197 config/i386/i386.c:4200
+#: config/i386/i386.c:4200 config/i386/i386.c:4203
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "Intel MPX does not support x32"
 msgstr "%s ondersteunt %s niet"
 
-#: config/i386/i386.c:4205
+#: config/i386/i386.c:4208
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "bad value (%qs) for %<-march=%> switch"
 msgstr "slechte waarde (%s) voor de -march= optie"
 
-#: config/i386/i386.c:4206
+#: config/i386/i386.c:4209
 #, fuzzy, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"arch=\")%> attribute"
 msgstr "slechte waarde (%s) voor de -march= optie"
 
-#: config/i386/i386.c:4228
+#: config/i386/i386.c:4231
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "geldige argumenten van %qs zijn: %s"
 
-#: config/i386/i386.c:4230
+#: config/i386/i386.c:4233
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4235
+#: config/i386/i386.c:4238
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "geldige argumenten van %qs zijn: %s"
 
-#: config/i386/i386.c:4236
+#: config/i386/i386.c:4239
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "geldige argumenten van %qs zijn: %s"
 
-#: config/i386/i386.c:4284
+#: config/i386/i386.c:4287
 #, fuzzy, gcc-internal-format
 msgid "bad value (%qs) for %<-mtune=%> switch"
 msgstr "slechte waarde (%s) voor de -march= optie"
 
-#: config/i386/i386.c:4285
+#: config/i386/i386.c:4288
 #, fuzzy, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"tune=\")%> attribute"
 msgstr "slechte waarde (%s) voor de -march= optie"
 
-#: config/i386/i386.c:4305
+#: config/i386/i386.c:4308
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "geldige argumenten van %qs zijn: %s"
 
-#: config/i386/i386.c:4307
+#: config/i386/i386.c:4310
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4312
+#: config/i386/i386.c:4315
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "geldige argumenten van %qs zijn: %s"
 
-#: config/i386/i386.c:4313
+#: config/i386/i386.c:4316
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "geldige argumenten van %qs zijn: %s"
 
-#: config/i386/i386.c:4379
+#: config/i386/i386.c:4382
 #, gcc-internal-format
 msgid "-mregparm is ignored in 64-bit mode"
 msgstr ""
 
-#: config/i386/i386.c:4381
+#: config/i386/i386.c:4384
 #, gcc-internal-format
 msgid "-mregparm is ignored for Intel MCU psABI"
 msgstr ""
 
-#: config/i386/i386.c:4384
+#: config/i386/i386.c:4387
 #, gcc-internal-format, gfc-internal-format
 msgid "-mregparm=%d is not between 0 and %d"
 msgstr "-mregparm=%d ligt niet tussen 0 en %d"
 
-#: config/i386/i386.c:4417
+#: config/i386/i386.c:4420
 #, fuzzy, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "alias-definities worden niet ondersteund in deze configuratie; genegeerd"
 
-#: config/i386/i386.c:4418
+#: config/i386/i386.c:4421
 #, fuzzy, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "alias-definities worden niet ondersteund in deze configuratie; genegeerd"
 
-#: config/i386/i386.c:4497
+#: config/i386/i386.c:4500
 #, fuzzy, gcc-internal-format
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "sectie-attributen worden niet ondersteund voor dit doelsysteem"
 
-#: config/i386/i386.c:4500
+#: config/i386/i386.c:4503
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr "-mpreferred_stack_boundary=%d ligt niet tussen 2 en 31"
 
-#: config/i386/i386.c:4523
+#: config/i386/i386.c:4526
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr "-mpreferred_stack_boundary=%d ligt niet tussen 2 en 31"
 
-#: config/i386/i386.c:4536
+#: config/i386/i386.c:4539
 #, fuzzy, gcc-internal-format
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "case-selector niet compatibel met label"
 
-#: config/i386/i386.c:4539
+#: config/i386/i386.c:4542
 #, gcc-internal-format
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr ""
 
-#: config/i386/i386.c:4545
+#: config/i386/i386.c:4548
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386.c:4546
+#: config/i386/i386.c:4549
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386.c:4556
+#: config/i386/i386.c:4559
 #, fuzzy, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "pointer naar functie gebruikt in rekensom"
 
-#: config/i386/i386.c:4563
+#: config/i386/i386.c:4566
 #, fuzzy, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "pointer naar functie gebruikt in rekensom"
 
-#: config/i386/i386.c:4613
+#: config/i386/i386.c:4616
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr ""
 
-#: config/i386/i386.c:4615
+#: config/i386/i386.c:4618
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr ""
 
-#: config/i386/i386.c:4629
+#: config/i386/i386.c:4632
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr ""
 
-#: config/i386/i386.c:4631
+#: config/i386/i386.c:4634
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr ""
 
-#: config/i386/i386.c:4741
+#: config/i386/i386.c:4744
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr ""
 
-#: config/i386/i386.c:4744
+#: config/i386/i386.c:4747
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr ""
 
-#: config/i386/i386.c:4748
+#: config/i386/i386.c:4751
 #, gcc-internal-format
 msgid "-mcall-ms2sysv-xlogues isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386.c:4813 config/powerpcspe/powerpcspe.c:5663
+#: config/i386/i386.c:4816 config/powerpcspe/powerpcspe.c:5663
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown option for -mrecip=%s"
 msgstr "onbekende machine-modus %qs"
 
-#: config/i386/i386.c:4870 config/powerpcspe/powerpcspe.c:5339
+#: config/i386/i386.c:4873 config/powerpcspe/powerpcspe.c:5339
 #, gcc-internal-format
 msgid "%qs is not a valid number in -mstack-protector-guard-offset="
 msgstr ""
 
-#: config/i386/i386.c:4875 config/powerpcspe/powerpcspe.c:5344
+#: config/i386/i386.c:4878 config/powerpcspe/powerpcspe.c:5344
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid offset in -mstack-protector-guard-offset="
 msgstr "-fPIC is niet geldig met -mcoff"
 
-#: config/i386/i386.c:4907 config/powerpcspe/powerpcspe.c:5356
+#: config/i386/i386.c:4910 config/powerpcspe/powerpcspe.c:5356
 #, gcc-internal-format
 msgid "%qs is not a valid base register in -mstack-protector-guard-reg="
 msgstr ""
 
-#: config/i386/i386.c:5506 config/i386/i386.c:5553 config/s390/s390.c:15812
+#: config/i386/i386.c:5509 config/i386/i386.c:5556 config/s390/s390.c:15812
 #: config/s390/s390.c:15862 config/s390/s390.c:15879
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr ""
 
-#: config/i386/i386.c:5534
+#: config/i386/i386.c:5537
 #, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr ""
 
-#: config/i386/i386.c:5837
+#: config/i386/i386.c:5840
 #, fuzzy, gcc-internal-format
 msgid "interrupt and naked attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386.c:5852
+#: config/i386/i386.c:5855
 #, gcc-internal-format
 msgid "Only DWARF debug format is supported for interrupt service routine."
 msgstr ""
 
-#: config/i386/i386.c:5901
+#: config/i386/i386.c:5904
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s en -mcall-%s zijn incompatibel"
 
-#: config/i386/i386.c:5913
+#: config/i386/i386.c:5916
 #, gcc-internal-format
 msgid "%<-mindirect-branch=thunk-extern%>, %<-fcf-protection=branch%> and %<-fcheck-pointer-bounds%> are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5949
+#: config/i386/i386.c:5952
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s en -mcall-%s zijn incompatibel"
 
-#: config/i386/i386.c:6047
+#: config/i386/i386.c:6050
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in %s service routine"
 msgstr ""
 
-#: config/i386/i386.c:6051
+#: config/i386/i386.c:6054
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in function with no_caller_saved_registers attribute"
 msgstr ""
 
-#: config/i386/i386.c:6465 config/i386/i386.c:6516
+#: config/i386/i386.c:6468 config/i386/i386.c:6519
 #, fuzzy, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386.c:6470
+#: config/i386/i386.c:6473
 #, fuzzy, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386.c:6477 config/i386/i386.c:41444
+#: config/i386/i386.c:6480 config/i386/i386.c:41438
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "herhalings-aantal is geen integerconstante"
 
-#: config/i386/i386.c:6483
+#: config/i386/i386.c:6486
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "argument van attribuut %qE is groter dan %d"
 
-#: config/i386/i386.c:6508 config/i386/i386.c:6551
+#: config/i386/i386.c:6511 config/i386/i386.c:6554
 #, fuzzy, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386.c:6512
+#: config/i386/i386.c:6515
 #, fuzzy, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386.c:6520 config/i386/i386.c:6569
+#: config/i386/i386.c:6523 config/i386/i386.c:6572
 #, fuzzy, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386.c:6530 config/i386/i386.c:6547
+#: config/i386/i386.c:6533 config/i386/i386.c:6550
 #, fuzzy, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386.c:6534
+#: config/i386/i386.c:6537
 #, fuzzy, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386.c:6538 config/i386/i386.c:6565
+#: config/i386/i386.c:6541 config/i386/i386.c:6568
 #, fuzzy, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386.c:6555 config/i386/i386.c:6573
+#: config/i386/i386.c:6558 config/i386/i386.c:6576
 #, fuzzy, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
 # XXX FIXME, ERROR:  s/none /non-/
-#: config/i386/i386.c:6561
+#: config/i386/i386.c:6564
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute is used for none class-method"
 msgid "%qE attribute is used for non-class method"
 msgstr "attribuut %qE is gebruikt voor non-class-methode"
 
-#: config/i386/i386.c:6805
+#: config/i386/i386.c:6808
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:6808
+#: config/i386/i386.c:6811
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:7126
+#: config/i386/i386.c:7129
 #, fuzzy, gcc-internal-format
 #| msgid "does not support multilib"
 msgid "X32 does not support ms_abi attribute"
 msgstr "ondersteunt geen multilib"
 
-#: config/i386/i386.c:7160
+#: config/i386/i386.c:7163
 #, gcc-internal-format
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr ""
 
-#: config/i386/i386.c:7502
+#: config/i386/i386.c:7505
 #, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7508
+#: config/i386/i386.c:7511
 #, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7522
+#: config/i386/i386.c:7525
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7528
+#: config/i386/i386.c:7531
 #, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7544
+#: config/i386/i386.c:7547
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7550
+#: config/i386/i386.c:7553
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7566
+#: config/i386/i386.c:7569
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7572
+#: config/i386/i386.c:7575
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7754
+#: config/i386/i386.c:7757
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:7871
+#: config/i386/i386.c:7874
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:7989
+#: config/i386/i386.c:7992
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:8152
+#: config/i386/i386.c:8155
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.c:8158
+#: config/i386/i386.c:8161
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.c:8174
+#: config/i386/i386.c:8177
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr ""
 
-#: config/i386/i386.c:8471 config/i386/i386.c:8750 config/i386/i386.c:9276
+#: config/i386/i386.c:8474 config/i386/i386.c:8753 config/i386/i386.c:9279
 #, gcc-internal-format
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:8473 config/i386/i386.c:8752 config/i386/i386.c:9278
+#: config/i386/i386.c:8476 config/i386/i386.c:8755 config/i386/i386.c:9281
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr ""
 
-#: config/i386/i386.c:9178
+#: config/i386/i386.c:9181
 #, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr ""
 
-#: config/i386/i386.c:11601
+#: config/i386/i386.c:11604
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "-mcall-ms2sysv-xlogues is not compatible with %s"
 msgstr "case-selector niet compatibel met label"
 
-#: config/i386/i386.c:13593
+#: config/i386/i386.c:13596
 #, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr ""
 
-#: config/i386/i386.c:13683
+#: config/i386/i386.c:13686
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr ""
 
-#: config/i386/i386.c:14970
+#: config/i386/i386.c:14973
 #, fuzzy, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr "conflicterende types voor ingebouwde functie %qs"
 
-#: config/i386/i386.c:14990
+#: config/i386/i386.c:14993
 #, fuzzy, gcc-internal-format
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
 msgstr "conflicterende types voor ingebouwde functie %qs"
@@ -30599,312 +30642,312 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:15001
+#: config/i386/i386.c:15004
 #, fuzzy, gcc-internal-format
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr "ISO C90 ondersteunt geen flexibele array-leden"
 
-#: config/i386/i386.c:17939
+#: config/i386/i386.c:17942
 #, gcc-internal-format
 msgid "'V' modifier on non-integer register"
 msgstr ""
 
-#: config/i386/i386.c:17950 config/i386/i386.c:17964
+#: config/i386/i386.c:17953 config/i386/i386.c:17967
 #, gcc-internal-format
 msgid "unsupported size for integer register"
 msgstr ""
 
-#: config/i386/i386.c:17996
+#: config/i386/i386.c:17999
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr ""
 
-#: config/i386/i386.c:18011
+#: config/i386/i386.c:18014
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr ""
 
-#: config/i386/i386.c:18202
+#: config/i386/i386.c:18205
 #, fuzzy, gcc-internal-format
 msgid "non-integer operand used with operand code 'z'"
 msgstr "herdefinitie van %<union %s%>"
 
-#: config/i386/i386.c:28467
+#: config/i386/i386.c:28470
 #, gcc-internal-format
 msgid "interrupt service routine can't be called directly"
 msgstr ""
 
-#: config/i386/i386.c:29995
+#: config/i386/i386.c:29998
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in -fabi-version=12 (GCC 8)"
 msgstr ""
 
-#: config/i386/i386.c:32435
+#: config/i386/i386.c:32438
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr ""
 
-#: config/i386/i386.c:32485
+#: config/i386/i386.c:32488
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for %s"
 msgstr ""
 
-#: config/i386/i386.c:32495
+#: config/i386/i386.c:32498
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr ""
 
-#: config/i386/i386.c:32657
+#: config/i386/i386.c:32660
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386.c:32662 config/i386/i386.c:32938
-#: config/rs6000/rs6000.c:37850
+#: config/i386/i386.c:32665 config/i386/i386.c:32941
+#: config/rs6000/rs6000.c:37906
 #, fuzzy, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "-pipe wordt niet ondersteund"
 
-#: config/i386/i386.c:32795 config/rs6000/rs6000.c:37607
+#: config/i386/i386.c:32798 config/rs6000/rs6000.c:37663
 #, fuzzy, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "instructie-scheduling wordt niet ondersteund op deze doelmachine"
 
-#: config/i386/i386.c:33207
+#: config/i386/i386.c:33210
 #, fuzzy, gcc-internal-format
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr "derde argument voor %<__builtin_prefetch%> moet een constante zijn"
 
-#: config/i386/i386.c:33232 config/i386/i386.c:33282
+#: config/i386/i386.c:33235 config/i386/i386.c:33285
 #, gcc-internal-format, gfc-internal-format
 msgid "Parameter to builtin not valid: %s"
 msgstr ""
 
-#: config/i386/i386.c:33975 config/i386/i386.c:35415
+#: config/i386/i386.c:33978 config/i386/i386.c:35418
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:34370
+#: config/i386/i386.c:34373
 #, fuzzy, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:34465
+#: config/i386/i386.c:34468
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:35346
+#: config/i386/i386.c:35349
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:35361
+#: config/i386/i386.c:35364
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:35394
+#: config/i386/i386.c:35397
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:35434
+#: config/i386/i386.c:35437
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:35447
+#: config/i386/i386.c:35450
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:35457
+#: config/i386/i386.c:35460
 #, fuzzy, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:35462 config/i386/i386.c:36249
+#: config/i386/i386.c:35465 config/i386/i386.c:36252
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:35596
+#: config/i386/i386.c:35599
 #, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr ""
 
-#: config/i386/i386.c:35601
+#: config/i386/i386.c:35604
 #, fuzzy, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr "ongeldige const_double operand"
 
-#: config/i386/i386.c:35607 config/i386/i386.c:35814
+#: config/i386/i386.c:35610 config/i386/i386.c:35817
 #, fuzzy, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr "ongeldige const_double operand"
 
-#: config/i386/i386.c:35796
+#: config/i386/i386.c:35799
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:35802
+#: config/i386/i386.c:35805
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:35805
+#: config/i386/i386.c:35808
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:36247
+#: config/i386/i386.c:36250
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:36329 config/powerpcspe/powerpcspe.c:16219
-#: config/rs6000/rs6000.c:15304
+#: config/i386/i386.c:36332 config/powerpcspe/powerpcspe.c:16219
+#: config/rs6000/rs6000.c:15348
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr ""
 
-#: config/i386/i386.c:36539
+#: config/i386/i386.c:36542
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr ""
 
-#: config/i386/i386.c:36543
+#: config/i386/i386.c:36546
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr ""
 
-#: config/i386/i386.c:37381
+#: config/i386/i386.c:37375
 #, fuzzy, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:38108 config/i386/i386.c:38290
+#: config/i386/i386.c:38102 config/i386/i386.c:38284
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:38343
+#: config/i386/i386.c:38337
 #, fuzzy, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:38349
+#: config/i386/i386.c:38343
 #, fuzzy, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr "ongeldige const_double operand"
 
-#: config/i386/i386.c:38368
+#: config/i386/i386.c:38362
 #, fuzzy, gcc-internal-format
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:41431
+#: config/i386/i386.c:41425
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "attribuut %qE is alleen beschikbaar voor 32-bits"
 
-#: config/i386/i386.c:41452
+#: config/i386/i386.c:41446
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr ""
 
-#: config/i386/i386.c:41485 config/i386/i386.c:41494
+#: config/i386/i386.c:41479 config/i386/i386.c:41488
 #, fuzzy, gcc-internal-format
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386.c:41530 config/powerpcspe/powerpcspe.c:35868
-#: config/rs6000/rs6000.c:33065
+#: config/i386/i386.c:41524 config/powerpcspe/powerpcspe.c:35868
+#: config/rs6000/rs6000.c:33121
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "incompatibel attribuut %qE wordt genegeerd"
 
-#: config/i386/i386.c:41555 config/i386/i386.c:41577 config/ia64/ia64.c:815
+#: config/i386/i386.c:41549 config/i386/i386.c:41571 config/ia64/ia64.c:815
 #: config/s390/s390.c:1153
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "attribuut %qE vereist een string-constante als argument"
 
-#: config/i386/i386.c:41565 config/i386/i386.c:41587 config/s390/s390.c:1182
+#: config/i386/i386.c:41559 config/i386/i386.c:41581 config/s390/s390.c:1182
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qE attribute is not a string constant"
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "argument van attribuut %qE is geen string-constante"
 
-#: config/i386/i386.c:41619
+#: config/i386/i386.c:41613
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386.c:41626
+#: config/i386/i386.c:41620
 #, gcc-internal-format, gfc-internal-format
 msgid "interrupt service routine should have unsigned %sint as the second argument"
 msgstr ""
 
-#: config/i386/i386.c:41636
+#: config/i386/i386.c:41630
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386.c:41639
+#: config/i386/i386.c:41633
 #, gcc-internal-format
 msgid "interrupt service routine can't have non-void return value"
 msgstr ""
 
-#: config/i386/i386.c:44676
+#: config/i386/i386.c:44670
 #, fuzzy, gcc-internal-format
 msgid "alternatives not allowed in asm flag output"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: config/i386/i386.c:44740
+#: config/i386/i386.c:44734
 #, fuzzy, gcc-internal-format
 msgid "unknown asm flag output %qs"
 msgstr "onbekende machine-modus %qs"
 
-#: config/i386/i386.c:44769
+#: config/i386/i386.c:44763
 #, fuzzy, gcc-internal-format
 msgid "invalid type for asm flag output"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: config/i386/i386.c:50634
+#: config/i386/i386.c:50628
 #, fuzzy, gcc-internal-format
 msgid "unknown architecture specific memory model"
 msgstr "onbekende machine-modus %qs"
 
-#: config/i386/i386.c:50641
+#: config/i386/i386.c:50635
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50647
+#: config/i386/i386.c:50641
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50671 config/i386/i386.c:50787
+#: config/i386/i386.c:50665 config/i386/i386.c:50781
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unsupported simdlen %d"
 msgstr "niet-ondersteunde versie"
 
-#: config/i386/i386.c:50690
+#: config/i386/i386.c:50684
 #, fuzzy, gcc-internal-format
 msgid "unsupported return type %qT for simd"
 msgstr "ongebruikte argumenten in $-stijl formaat"
 
-#: config/i386/i386.c:50712
+#: config/i386/i386.c:50706
 #, fuzzy, gcc-internal-format
 msgid "unsupported argument type %qT for simd"
 msgstr "ongebruikte argumenten in $-stijl formaat"
 
-#: config/i386/i386.c:51033
+#: config/i386/i386.c:51027
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr ""
@@ -31126,7 +31169,7 @@
 msgstr ""
 
 #: config/m68k/m68k.c:1128 config/powerpcspe/powerpcspe.c:28512
-#: config/rs6000/rs6000.c:25791
+#: config/rs6000/rs6000.c:25868
 #, fuzzy, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "-pipe wordt niet ondersteund"
@@ -31705,58 +31748,58 @@
 
 #. Trampoline is not supported on reduced-set registers yet.
 #: config/nds32/nds32.c:2327 config/nds32/nds32.c:2381
-#: config/nds32/nds32.c:3127 config/nds32/nds32.c:3201
-#: config/nds32/nds32.c:3216 config/nds32/nds32.c:3222
-#: config/nds32/nds32.c:3284 config/nds32/nds32.c:3290
-#: config/nds32/nds32.c:3322
+#: config/nds32/nds32.c:3128 config/nds32/nds32.c:3202
+#: config/nds32/nds32.c:3217 config/nds32/nds32.c:3223
+#: config/nds32/nds32.c:3285 config/nds32/nds32.c:3291
+#: config/nds32/nds32.c:3323
 #, fuzzy, gcc-internal-format
 msgid "a nested function is not supported for reduced registers"
 msgstr "sectie-attributen worden niet ondersteund voor dit doelsysteem"
 
 #. The enum index value for array size is out of range.
-#: config/nds32/nds32.c:3025
+#: config/nds32/nds32.c:3026
 #, fuzzy, gcc-internal-format
 msgid "intrinsic register index is out of range"
 msgstr "ongeldig register in de instructie"
 
-#: config/nds32/nds32.c:3041 config/nds32/nds32.c:3048
-#: config/nds32/nds32.c:3055 config/nds32/nds32.c:3062
-#: config/nds32/nds32.c:3069
+#: config/nds32/nds32.c:3042 config/nds32/nds32.c:3049
+#: config/nds32/nds32.c:3056 config/nds32/nds32.c:3063
+#: config/nds32/nds32.c:3070
 #, fuzzy, gcc-internal-format
 msgid "CCTL intrinsic function subtype out of range!"
 msgstr "ongeldig register in de instructie"
 
-#: config/nds32/nds32.c:3508
+#: config/nds32/nds32.c:3509
 #, gcc-internal-format
 msgid "invalid id value for interrupt/exception attribute"
 msgstr ""
 
-#: config/nds32/nds32.c:3536
+#: config/nds32/nds32.c:3537
 #, fuzzy, gcc-internal-format
 msgid "invalid id value for reset attribute"
 msgstr "ongeldig type-argument %qs"
 
-#: config/nds32/nds32.c:3552
+#: config/nds32/nds32.c:3553
 #, fuzzy, gcc-internal-format
 msgid "invalid nmi function for reset attribute"
 msgstr "ongeldig type-argument %qs"
 
-#: config/nds32/nds32.c:3565
+#: config/nds32/nds32.c:3566
 #, fuzzy, gcc-internal-format
 msgid "invalid warm function for reset attribute"
 msgstr "ongeldig type-argument %qs"
 
-#: config/nds32/nds32.c:3638
+#: config/nds32/nds32.c:3639
 #, gcc-internal-format
 msgid "Disable FPU ISA, the ABI option must be enable '-mfloat-abi=soft'"
 msgstr ""
 
-#: config/nds32/nds32.c:3641
+#: config/nds32/nds32.c:3642
 #, gcc-internal-format
 msgid "'-mabi=2fp+' option only support when FPU available, must be enable '-mext-fpu-sp' or '-mext-fpu-dp'"
 msgstr ""
 
-#: config/nds32/nds32.c:3647
+#: config/nds32/nds32.c:3648
 #, fuzzy, gcc-internal-format
 msgid "position-independent code not supported"
 msgstr "Positie-onafhankelijke code wordt niet ondersteund.  Genegeerd"
@@ -32096,12 +32139,12 @@
 msgid "junk at end of #pragma longcall"
 msgstr "rommel aan einde van #pragma longcall"
 
-#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6154
+#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6152
 #, gcc-internal-format
 msgid "vec_lvsl is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6158
+#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6156
 #, gcc-internal-format
 msgid "vec_lvsr is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
@@ -32152,7 +32195,7 @@
 msgid "vec_insert only accepts 3 arguments"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6868
+#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6866
 #, fuzzy, gcc-internal-format
 msgid "passing arg %d of %qE discards qualifiers from pointer target type"
 msgstr "cast laat qualifiers van doeltype van pointer vallen"
@@ -32237,7 +32280,7 @@
 msgid "target attribute or pragma changes SPE ABI"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4351 config/rs6000/rs6000.c:4223
+#: config/powerpcspe/powerpcspe.c:4351 config/rs6000/rs6000.c:4243
 #, fuzzy, gcc-internal-format
 msgid "AltiVec not supported in this target"
 msgstr "sectie-attributen worden niet ondersteund op dit doelsysteem"
@@ -32383,7 +32426,7 @@
 msgid "-mvsx-small-integer requires -mpower8-vector, -mupper-regs-di, and -mdirect-move"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4959 config/rs6000/rs6000.c:4601
+#: config/powerpcspe/powerpcspe.c:4959 config/rs6000/rs6000.c:4628
 #, gcc-internal-format
 msgid "target attribute or pragma changes long double size"
 msgstr ""
@@ -32424,22 +32467,22 @@
 msgstr ""
 
 #: config/powerpcspe/powerpcspe.c:5140 config/powerpcspe/powerpcspe.c:5155
-#: config/rs6000/rs6000.c:4766 config/rs6000/rs6000.c:4781
+#: config/rs6000/rs6000.c:4791 config/rs6000/rs6000.c:4806
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:5168 config/rs6000/rs6000.c:4794
+#: config/powerpcspe/powerpcspe.c:5168 config/rs6000/rs6000.c:4819
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:5234 config/rs6000/rs6000.c:4828
+#: config/powerpcspe/powerpcspe.c:5234 config/rs6000/rs6000.c:4853
 #, gcc-internal-format
 msgid "target attribute or pragma changes single precision floating point"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:5237 config/rs6000/rs6000.c:4831
+#: config/powerpcspe/powerpcspe.c:5237 config/rs6000/rs6000.c:4856
 #, gcc-internal-format
 msgid "target attribute or pragma changes double precision floating point"
 msgstr ""
@@ -32449,12 +32492,12 @@
 msgid "-mstack-protector-guard=tls needs a valid base register"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:8415 config/rs6000/rs6000.c:7925
+#: config/powerpcspe/powerpcspe.c:8415 config/rs6000/rs6000.c:7950
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11237
+#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11269
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
@@ -32464,7 +32507,7 @@
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11595
+#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11633
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr ""
@@ -32474,12 +32517,12 @@
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12604
+#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12648
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12779
+#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12823
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
@@ -32489,28 +32532,28 @@
 msgid "internal error: builtin function %s already processed"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:13971
+#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:14015
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be an 8-bit field value"
 msgstr "%<defined%> zonder een naam"
 
-#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14015
+#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14059
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr ""
 
 #: config/powerpcspe/powerpcspe.c:14934 config/powerpcspe/powerpcspe.c:16803
-#: config/rs6000/rs6000.c:14101
+#: config/rs6000/rs6000.c:14145
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14119
+#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14163
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "%<defined%> zonder een naam"
 
-#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14135
+#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14179
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 7-bit unsigned literal"
 msgstr "%<defined%> zonder een naam"
@@ -32530,12 +32573,12 @@
 msgid "builtin %s is only valid in 64-bit mode"
 msgstr "alias-definities worden niet ondersteund in deze configuratie; genegeerd"
 
-#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14791
+#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14835
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %d must be an unsigned literal"
 msgstr "%<defined%> zonder een naam"
 
-#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14793
+#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14837
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "argument voor %<__builtin_args_info%> buiten bereik"
@@ -32557,54 +32600,54 @@
 msgid "hwcap %s is an invalid argument to builtin %s"
 msgstr "ongeldig argument voor %<__builtin_return_address%>"
 
-#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15065
+#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15109
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15090
+#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15134
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "%<defined%> zonder een naam"
 
-#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15110
+#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15154
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "%<defined%> zonder een naam"
 
-#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15122
+#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15166
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be 0 or 1"
 msgid "argument 1 must be 0 or 2"
 msgstr "het tweede argument moet 0 of 1 zijn"
 
-#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15134
+#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15178
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "%<defined%> zonder een naam"
 
-#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15148
+#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15192
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "%<defined%> zonder een naam"
 
-#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15160
+#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15204
 #, gcc-internal-format
 msgid "argument 2 must be 0 or 1"
 msgstr "het tweede argument moet 0 of 1 zijn"
 
-#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15168
+#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15212
 #, gcc-internal-format
 msgid "argument 3 must be in the range 0..15"
 msgstr "het derde argument moet in het bereik 0..15 liggen"
 
-#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15237
-#: config/rs6000/rs6000.c:15569
+#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15281
+#: config/rs6000/rs6000.c:15613
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15394
+#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15438
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr ""
@@ -32730,7 +32773,7 @@
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25758
+#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25835
 #, fuzzy, gcc-internal-format
 msgid "stack frame too large"
 msgstr "bestand %qs is te groot"
@@ -32740,12 +32783,12 @@
 msgid "-fsplit-stack uses register r29"
 msgstr "ISO C90 ondersteunt geen flexibele array-leden"
 
-#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29459
+#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29536
 #, fuzzy, gcc-internal-format
 msgid "Stack frame larger than 2G is not supported for -fsplit-stack"
 msgstr "sectie-attributen worden niet ondersteund op dit doelsysteem"
 
-#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30447
+#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30524
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr ""
@@ -32755,22 +32798,22 @@
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32830
+#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32907
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32832
+#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32909
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32834
+#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32911
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32836
+#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32913
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr ""
@@ -32780,7 +32823,7 @@
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32845
+#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32922
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr ""
@@ -33324,72 +33367,72 @@
 "Please use an explicit cpu name.  Valid cpu names are: %s"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6168 config/rs6000/rs6000-c.c:6219
-#: config/rs6000/rs6000-c.c:6489 config/rs6000/rs6000-c.c:6555
-#: config/rs6000/rs6000-c.c:6916 config/rs6000/rs6000-c.c:6963
+#: config/rs6000/rs6000-c.c:6166 config/rs6000/rs6000-c.c:6217
+#: config/rs6000/rs6000-c.c:6487 config/rs6000/rs6000-c.c:6553
+#: config/rs6000/rs6000-c.c:6914 config/rs6000/rs6000-c.c:6961
 #, fuzzy, gcc-internal-format
 msgid "builtin %qs only accepts 2 arguments"
 msgstr "%J%qD neemt ofwel geen, ofwel twee argumenten"
 
-#: config/rs6000/rs6000-c.c:6292 config/rs6000/rs6000-c.c:6375
-#: config/rs6000/rs6000-c.c:6736
+#: config/rs6000/rs6000-c.c:6290 config/rs6000/rs6000-c.c:6373
+#: config/rs6000/rs6000-c.c:6734
 #, fuzzy, gcc-internal-format
 msgid "builtin %qs only accepts 3 arguments"
 msgstr "%J%qD neemt ofwel geen, ofwel twee argumenten"
 
-#: config/rs6000/rs6000-c.c:6484
+#: config/rs6000/rs6000-c.c:6482
 #, fuzzy, gcc-internal-format
 msgid "builtin %qs only accepts 1 argument"
 msgstr "%J%qD neemt ofwel geen, ofwel twee argumenten"
 
-#: config/rs6000/rs6000-c.c:7054
+#: config/rs6000/rs6000-c.c:7052
 #, gcc-internal-format
 msgid "builtin %qs requires builtin %qs"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:7058
+#: config/rs6000/rs6000-c.c:7056
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs not supported in this compiler configuration"
 msgstr "alias-definities worden niet ondersteund in deze configuratie; genegeerd"
 
-#: config/rs6000/rs6000-c.c:7068
+#: config/rs6000/rs6000-c.c:7066
 #, fuzzy, gcc-internal-format
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr "ongeldig argument voor %<__builtin_return_address%>"
 
-#: config/rs6000/rs6000.c:3754 config/rs6000/rs6000.c:3757
-#: config/rs6000/rs6000.c:3760
+#: config/rs6000/rs6000.c:3772 config/rs6000/rs6000.c:3775
+#: config/rs6000/rs6000.c:3778
 #, fuzzy, gcc-internal-format
 msgid "%qs requires %qs or %qs"
 msgstr "Ongeldige modus voor gen_tst_reg"
 
-#: config/rs6000/rs6000.c:3861
+#: config/rs6000/rs6000.c:3879
 #, gcc-internal-format
 msgid "%qs requires PowerPC64 architecture, enabling"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4037
+#: config/rs6000/rs6000.c:4057
 #, gcc-internal-format
 msgid "%qs command-line option is deprecated"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4048
+#: config/rs6000/rs6000.c:4068
 #, gcc-internal-format
 msgid "%qs is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4147
+#: config/rs6000/rs6000.c:4167
 #, gcc-internal-format
 msgid "will not generate %qs instructions because assembler lacks %qs support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4240
+#: config/rs6000/rs6000.c:4260
 #, fuzzy, gcc-internal-format
 #| msgid "SH2a does not support little-endian"
 msgid "%qs is not supported on little endian systems"
 msgstr "SH2a ondersteunt little-endian niet"
 
-#: config/rs6000/rs6000.c:4333
+#: config/rs6000/rs6000.c:4353
 #, gcc-internal-format
 msgid "power9 target option is incompatible with %<%s=<xxx>%> for <xxx> less than power9"
 msgstr ""
@@ -33396,7 +33439,7 @@
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:4341
+#: config/rs6000/rs6000.c:4361
 #, gcc-internal-format
 msgid "%qs incompatible with explicitly disabled options"
 msgstr ""
@@ -33405,245 +33448,246 @@
 #. error messages.  However, if users have managed to select
 #. power9-fusion without selecting power8-fusion, they
 #. already know about undocumented flags.
-#: config/rs6000/rs6000.c:4366 config/rs6000/rs6000.c:4373
-#: config/rs6000/rs6000.c:4380 config/rs6000/rs6000.c:4388
-#: config/rs6000/rs6000.c:4407 config/rs6000/rs6000.c:4464
-#: config/rs6000/rs6000.c:4468 config/rs6000/rs6000.c:4485
-#: config/rs6000/rs6000.c:4538 config/rs6000/rs6000.c:4565
-#: config/rs6000/rs6000.c:4580 config/rs6000/rs6000.c:4588
-#: config/rs6000/rs6000.c:4684
+#: config/rs6000/rs6000.c:4386 config/rs6000/rs6000.c:4393
+#: config/rs6000/rs6000.c:4400 config/rs6000/rs6000.c:4408
+#: config/rs6000/rs6000.c:4427 config/rs6000/rs6000.c:4484
+#: config/rs6000/rs6000.c:4488 config/rs6000/rs6000.c:4505
+#: config/rs6000/rs6000.c:4558 config/rs6000/rs6000.c:4585
+#: config/rs6000/rs6000.c:4600 config/rs6000/rs6000.c:4608
+#: config/rs6000/rs6000.c:4709
 #, gcc-internal-format
 msgid "%qs requires %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4625
+#: config/rs6000/rs6000.c:4650
 #, gcc-internal-format
 msgid "Using IEEE extended precision long double"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4627
+#: config/rs6000/rs6000.c:4652
 #, gcc-internal-format
 msgid "Using IBM extended precision long double"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4644
+#: config/rs6000/rs6000.c:4669
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "%qs requires VSX support"
 msgstr "%s ondersteunt %s niet"
 
-#: config/rs6000/rs6000.c:4653
+#: config/rs6000/rs6000.c:4678
 #, gcc-internal-format
 msgid "The -mfloat128 option may not be fully supported"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4676
+#: config/rs6000/rs6000.c:4701
 #, gcc-internal-format
 msgid "%qs requires full ISA 3.0 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4743
+#: config/rs6000/rs6000.c:4768
 #, gcc-internal-format
 msgid "unknown vectorization library ABI type (%qs) for %qs switch"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4930
+#: config/rs6000/rs6000.c:4955
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr "-fPIC is niet geldig met -mcoff"
 
-#: config/rs6000/rs6000.c:4935
+#: config/rs6000/rs6000.c:4960
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr "-fPIC is niet geldig met -mcoff"
 
-#: config/rs6000/rs6000.c:4947
+#: config/rs6000/rs6000.c:4972
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid base register in %qs"
 msgstr "-fPIC is niet geldig met -mcoff"
 
-#: config/rs6000/rs6000.c:4955
+#: config/rs6000/rs6000.c:4980
 #, fuzzy, gcc-internal-format
 msgid "%qs needs a valid base register"
 msgstr "-fPIC is niet geldig met -mcoff"
 
-#: config/rs6000/rs6000.c:5253
+#: config/rs6000/rs6000.c:5278
 #, fuzzy, gcc-internal-format
 msgid "unknown option for %<%s=%s%>"
 msgstr "onbekende machine-modus %qs"
 
-#: config/rs6000/rs6000.c:5290
+#: config/rs6000/rs6000.c:5315
 #, fuzzy, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: config/rs6000/rs6000.c:11401
+#: config/rs6000/rs6000.c:11439
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11862
+#: config/rs6000/rs6000.c:11906
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13572
+#: config/rs6000/rs6000.c:13616
 #, fuzzy, gcc-internal-format
 msgid "internal error: builtin function %qs already processed"
 msgstr "ingebouwde functie %qs kan niet uitgeschakeld worden"
 
-#: config/rs6000/rs6000.c:14150
+#: config/rs6000/rs6000.c:14194
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 1-bit unsigned literal"
 msgstr "%<defined%> zonder een naam"
 
-#: config/rs6000/rs6000.c:14189
+#: config/rs6000/rs6000.c:14233
 #, fuzzy, gcc-internal-format
 #| msgid "argument must be a constant"
 msgid "argument 1 of %qs must be a constant"
 msgstr "argument moet een constante zijn"
 
-#: config/rs6000/rs6000.c:14247 config/rs6000/rs6000.c:15898
+#: config/rs6000/rs6000.c:14291 config/rs6000/rs6000.c:15942
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qs is out of range"
 msgstr "argument voor %<__builtin_args_info%> buiten bereik"
 
-#: config/rs6000/rs6000.c:14742
+#: config/rs6000/rs6000.c:14786
 #, fuzzy, gcc-internal-format
 msgid "builtin %qs is only valid in 64-bit mode"
 msgstr "alias-definities worden niet ondersteund in deze configuratie; genegeerd"
 
-#: config/rs6000/rs6000.c:14939
+#: config/rs6000/rs6000.c:14983
 #, fuzzy, gcc-internal-format
 msgid "builtin %qs only accepts a string argument"
 msgstr "%J%qD neemt ofwel geen, ofwel twee argumenten"
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000.c:14958
+#: config/rs6000/rs6000.c:15002
 #, fuzzy, gcc-internal-format
 msgid "cpu %qs is an invalid argument to builtin %qs"
 msgstr "ongeldig argument voor %<__builtin_return_address%>"
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000.c:14986
+#: config/rs6000/rs6000.c:15030
 #, fuzzy, gcc-internal-format
 msgid "%s %qs is an invalid argument to builtin %qs"
 msgstr "ongeldig argument voor %<__builtin_return_address%>"
 
-#: config/rs6000/rs6000.c:15012
+#: config/rs6000/rs6000.c:15056
 #, gcc-internal-format
 msgid "builtin %qs needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15616
+#: config/rs6000/rs6000.c:15660
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be 0 or 1"
 msgid "second argument to %qs must be 0..12"
 msgstr "het tweede argument moet 0 of 1 zijn"
 
-#: config/rs6000/rs6000.c:15631
+#: config/rs6000/rs6000.c:15675
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be 0 or 1"
 msgid "third argument to %qs must be 0..12"
 msgstr "het tweede argument moet 0 of 1 zijn"
 
-#: config/rs6000/rs6000.c:15850
+#: config/rs6000/rs6000.c:15894
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument must be a constant"
 msgid "argument 1 of %s must be a constant"
 msgstr "argument moet een constante zijn"
 
-#: config/rs6000/rs6000.c:15932
+#: config/rs6000/rs6000.c:15976
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs is only valid for the cell processor"
 msgstr "-pipe wordt niet ondersteund"
 
-#: config/rs6000/rs6000.c:15934 config/rs6000/rs6000.c:15936
-#: config/rs6000/rs6000.c:15938 config/rs6000/rs6000.c:15940
-#: config/rs6000/rs6000.c:15946 config/rs6000/rs6000.c:15948
-#: config/rs6000/rs6000.c:15955 config/rs6000/rs6000.c:15962
-#: config/rs6000/rs6000.c:15969 config/rs6000/rs6000.c:15975
+#: config/rs6000/rs6000.c:15978 config/rs6000/rs6000.c:15980
+#: config/rs6000/rs6000.c:15982 config/rs6000/rs6000.c:15984
+#: config/rs6000/rs6000.c:15990 config/rs6000/rs6000.c:15992
+#: config/rs6000/rs6000.c:15999 config/rs6000/rs6000.c:16006
+#: config/rs6000/rs6000.c:16011 config/rs6000/rs6000.c:16014
+#: config/rs6000/rs6000.c:16018 config/rs6000/rs6000.c:16024
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs requires the %qs option"
 msgstr "%Jingebouwde functie %qD gedeclareerd als niet-functie"
 
-#: config/rs6000/rs6000.c:15943 config/rs6000/rs6000.c:15952
-#: config/rs6000/rs6000.c:15959 config/rs6000/rs6000.c:15966
+#: config/rs6000/rs6000.c:15987 config/rs6000/rs6000.c:15996
+#: config/rs6000/rs6000.c:16003
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs requires the %qs and %qs options"
 msgstr "%Jingebouwde functie %qD gedeclareerd als niet-functie"
 
-#: config/rs6000/rs6000.c:15972
+#: config/rs6000/rs6000.c:16021
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs requires ISA 3.0 IEEE 128-bit floating point"
 msgstr "%Jingebouwde functie %qD gedeclareerd als niet-functie"
 
-#: config/rs6000/rs6000.c:15978
+#: config/rs6000/rs6000.c:16027
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs requires the %qs (or newer), and %qs or %qs options"
 msgstr "%Jingebouwde functie %qD gedeclareerd als niet-functie"
 
-#: config/rs6000/rs6000.c:15982
+#: config/rs6000/rs6000.c:16031
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs is not supported with the current options"
 msgstr "-pipe wordt niet ondersteund"
 
-#: config/rs6000/rs6000.c:18218
+#: config/rs6000/rs6000.c:18290
 #, fuzzy, gcc-internal-format
 msgid "internal error: builtin function %qs had an unexpected return type %qs"
 msgstr "ingebouwde functie %qs kan niet uitgeschakeld worden"
 
-#: config/rs6000/rs6000.c:18235
+#: config/rs6000/rs6000.c:18307
 #, fuzzy, gcc-internal-format
 msgid "internal error: builtin function %qs, argument %d had unexpected argument type %qs"
 msgstr "ingebouwde functie %qs kan niet uitgeschakeld worden"
 
-#: config/rs6000/rs6000.c:29451
+#: config/rs6000/rs6000.c:29528
 #, fuzzy, gcc-internal-format
 msgid "%qs uses register r29"
 msgstr "%<__thread%> samen met %<register%> gebruikt"
 
-#: config/rs6000/rs6000.c:32748
+#: config/rs6000/rs6000.c:32825
 #, fuzzy, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "kan adres van bitveld %qs niet nemen"
 
-#: config/rs6000/rs6000.c:32842
+#: config/rs6000/rs6000.c:32919
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32850
+#: config/rs6000/rs6000.c:32927
 #, fuzzy, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "'complex' ongeldig voor %qs"
 
-#: config/rs6000/rs6000.c:32853
+#: config/rs6000/rs6000.c:32930
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:36876
+#: config/rs6000/rs6000.c:36932
 #, fuzzy, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "ongeldig gebruik van '%%%c'"
 
-#: config/rs6000/rs6000.c:36879
+#: config/rs6000/rs6000.c:36935
 #, fuzzy, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr "spec '%s' is ongeldig"
 
-#: config/rs6000/rs6000.c:36881
+#: config/rs6000/rs6000.c:36937
 #, fuzzy, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr "spec '%s' is ongeldig"
 
-#: config/rs6000/rs6000.c:37416
+#: config/rs6000/rs6000.c:37472
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:37575
+#: config/rs6000/rs6000.c:37631
 #, gcc-internal-format
 msgid "target_clones attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
@@ -34388,51 +34432,51 @@
 msgid "subprogram %q+F not marked Inline"
 msgstr ""
 
-#: ada/gcc-interface/trans.c:6404
+#: ada/gcc-interface/trans.c:6401
 #, gcc-internal-format
 msgid "out-of-bounds access may be optimized away"
 msgstr ""
 
-#: ada/gcc-interface/trans.c:6406
+#: ada/gcc-interface/trans.c:6403
 #, gcc-internal-format
 msgid "containing loop"
 msgstr ""
 
-#: ada/gcc-interface/utils.c:3887
+#: ada/gcc-interface/utils.c:3890
 #, gcc-internal-format
 msgid "invalid element type for attribute %qs"
 msgstr "ongeldig element-type voor attribuut %qs"
 
-#: ada/gcc-interface/utils.c:3911
+#: ada/gcc-interface/utils.c:3914
 #, fuzzy, gcc-internal-format
 #| msgid "number of components of the vector not a power of two"
 msgid "number of components of vector not a power of two"
 msgstr "het aantal componenten van de vector is geen macht van twee"
 
-#: ada/gcc-interface/utils.c:6037 ada/gcc-interface/utils.c:6215
-#: ada/gcc-interface/utils.c:6322
+#: ada/gcc-interface/utils.c:6043 ada/gcc-interface/utils.c:6220
+#: ada/gcc-interface/utils.c:6327
 #, gcc-internal-format
 msgid "%qs attribute ignored"
 msgstr "attribuut %qs wordt genegeerd"
 
 # XXX FIXME:  near-duplicate
-#: ada/gcc-interface/utils.c:6158
+#: ada/gcc-interface/utils.c:6164
 #, gcc-internal-format
 msgid "%qs attribute requires prototypes with named arguments"
 msgstr "attribuut %qs vereist prototypes met benoemde argumenten"
 
 # goede vertaling van variadic?
-#: ada/gcc-interface/utils.c:6167
+#: ada/gcc-interface/utils.c:6173
 #, gcc-internal-format
 msgid "%qs attribute only applies to variadic functions"
 msgstr "attribuut %qs is enkel van toepassing op variadische functies"
 
-#: ada/gcc-interface/utils.c:6282
+#: ada/gcc-interface/utils.c:6287
 #, gcc-internal-format
 msgid "%qE attribute has no effect"
 msgstr "attribuut %qE heeft geen effect"
 
-#: ada/gcc-interface/utils.c:6406
+#: ada/gcc-interface/utils.c:6411
 #, gcc-internal-format
 msgid "attribute %qs applies to array types only"
 msgstr "attribuut %qs is enkel van toepassing op array-types"
@@ -34448,7 +34492,7 @@
 #. an unprototyped function, it is compile-time undefined;
 #. making it a constraint in that case was rejected in
 #. DR#252.
-#: c/c-convert.c:101 c/c-typeck.c:2175 c/c-typeck.c:6507 c/c-typeck.c:12138
+#: c/c-convert.c:101 c/c-typeck.c:2175 c/c-typeck.c:6512 c/c-typeck.c:12143
 #: cp/typeck.c:2027 cp/typeck.c:7977 cp/typeck.c:8742
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
@@ -34510,7 +34554,7 @@
 msgid "type of array %q+D completed incompatibly with implicit initialization"
 msgstr ""
 
-#: c/c-decl.c:1567 c/c-decl.c:6701 c/c-decl.c:7574 c/c-decl.c:8381
+#: c/c-decl.c:1567 c/c-decl.c:6721 c/c-decl.c:7594 c/c-decl.c:8401
 #, fuzzy, gcc-internal-format
 msgid "originally defined here"
 msgstr "functie-definitie als %<typdef%> gedeclareerd"
@@ -34921,16 +34965,11 @@
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.c:4548 c/c-decl.c:7147
+#: c/c-decl.c:4548 c/c-decl.c:7167
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr ""
 
-#: c/c-decl.c:4635 cp/decl2.c:1520
-#, gcc-internal-format
-msgid "%q+D in declare target directive does not have mappable type"
-msgstr ""
-
 #: c/c-decl.c:4693
 #, fuzzy, gcc-internal-format
 msgid "%q+D is usually a function"
@@ -34956,7 +34995,7 @@
 #. of VLAs themselves count as VLAs, it does not make
 #. sense to permit them to be initialized given that
 #. ordinary VLAs may not be initialized.
-#: c/c-decl.c:4732 c/c-decl.c:4747 c/c-typeck.c:7630
+#: c/c-decl.c:4732 c/c-decl.c:4747 c/c-typeck.c:7635
 #, gcc-internal-format
 msgid "variable-sized object may not be initialized"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
@@ -35016,203 +35055,208 @@
 msgid "uninitialized const %qD is invalid in C++"
 msgstr "ongeïnitialiseerde const %qD is ongeldig in C++"
 
+#: c/c-decl.c:5224 cp/decl.c:7318
+#, gcc-internal-format
+msgid "%q+D in declare target directive does not have mappable type"
+msgstr ""
+
 # Of is 'verbiedt parameterdeclaraties op voorhand' beter?
-#: c/c-decl.c:5268
+#: c/c-decl.c:5288
 #, gcc-internal-format
 msgid "ISO C forbids forward parameter declarations"
 msgstr "ISO C verbiedt voorwaartse declaraties van parameters"
 
-#: c/c-decl.c:5371
+#: c/c-decl.c:5391
 #, gcc-internal-format
 msgid "defining a type in a compound literal is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:5425 c/c-decl.c:5440
+#: c/c-decl.c:5445 c/c-decl.c:5460
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant"
 msgstr "breedte van bitveld %qs is geen integerconstante"
 
-#: c/c-decl.c:5435
+#: c/c-decl.c:5455
 #, fuzzy, gcc-internal-format
 msgid "bit-field %qs width not an integer constant expression"
 msgstr "breedte van bitveld %qs is geen integerconstante"
 
-#: c/c-decl.c:5446
+#: c/c-decl.c:5466
 #, gcc-internal-format
 msgid "negative width in bit-field %qs"
 msgstr "bitveld %qs heeft een negatieve breedte"
 
-#: c/c-decl.c:5451
+#: c/c-decl.c:5471
 #, gcc-internal-format
 msgid "zero width for bit-field %qs"
 msgstr "bitveld %qs heeft breedte 0"
 
-#: c/c-decl.c:5461
+#: c/c-decl.c:5481
 #, gcc-internal-format
 msgid "bit-field %qs has invalid type"
 msgstr "bitveld %qs heeft een ongeldig type"
 
-#: c/c-decl.c:5467
+#: c/c-decl.c:5487
 #, fuzzy, gcc-internal-format
 msgid "cannot declare bit-field %qs with %<warn_if_not_aligned%> type"
 msgstr "cast geeft functie-type op"
 
-#: c/c-decl.c:5478
+#: c/c-decl.c:5498
 #, gcc-internal-format
 msgid "type of bit-field %qs is a GCC extension"
 msgstr "het type van bitveld %qs is een uitbreiding van GCC"
 
-#: c/c-decl.c:5484
+#: c/c-decl.c:5504
 #, gcc-internal-format
 msgid "width of %qs exceeds its type"
 msgstr "breedte van %qs overschrijdt zijn type"
 
-#: c/c-decl.c:5497
+#: c/c-decl.c:5517
 #, gcc-internal-format
 msgid "%qs is narrower than values of its type"
 msgstr "%qs is smaller dan waarden van zijn type"
 
-#: c/c-decl.c:5512
+#: c/c-decl.c:5532
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 forbids array %qE whose size can%'t be evaluated"
 msgstr "ISO C90 verbiedt array %qs, wiens grootte niet geëvalueerd kan worden"
 
-#: c/c-decl.c:5515
+#: c/c-decl.c:5535
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 forbids array whose size can%'t be evaluated"
 msgstr "ISO C90 verbiedt array %qs, wiens grootte niet geëvalueerd kan worden"
 
-#: c/c-decl.c:5522
+#: c/c-decl.c:5542
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 forbids variable length array %qE"
 msgstr "ISO C90 verbiedt array %qs van variabele grootte"
 
-#: c/c-decl.c:5524
+#: c/c-decl.c:5544
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 forbids variable length array"
 msgstr "ISO C90 verbiedt array %qs van variabele grootte"
 
-#: c/c-decl.c:5733 c/c-decl.c:6107 c/c-decl.c:6117
+#: c/c-decl.c:5753 c/c-decl.c:6127 c/c-decl.c:6137
 #, fuzzy, gcc-internal-format
 msgid "variably modified %qE at file scope"
 msgstr "argument %d is alleen-lezen"
 
-#: c/c-decl.c:5735
+#: c/c-decl.c:5755
 #, fuzzy, gcc-internal-format
 msgid "variably modified field at file scope"
 msgstr "argument %d is alleen-lezen"
 
-#: c/c-decl.c:5755
+#: c/c-decl.c:5775
 #, fuzzy, gcc-internal-format
 msgid "type defaults to %<int%> in declaration of %qE"
 msgstr "type krijgt standaardwaarde %<int%> in de declaratie van %qs"
 
-#: c/c-decl.c:5759
+#: c/c-decl.c:5779
 #, fuzzy, gcc-internal-format
 msgid "type defaults to %<int%> in type name"
 msgstr "type krijgt standaardwaarde %<int%> in de declaratie van %qs"
 
-#: c/c-decl.c:5791
+#: c/c-decl.c:5811
 #, gcc-internal-format
 msgid "duplicate %<const%>"
 msgstr "herhaalde %<const%>"
 
-#: c/c-decl.c:5793
+#: c/c-decl.c:5813
 #, gcc-internal-format
 msgid "duplicate %<restrict%>"
 msgstr "herhaalde %<restrict%>"
 
-#: c/c-decl.c:5795
+#: c/c-decl.c:5815
 #, gcc-internal-format
 msgid "duplicate %<volatile%>"
 msgstr "herhaalde %<volatile%>"
 
-#: c/c-decl.c:5797
+#: c/c-decl.c:5817
 #, fuzzy, gcc-internal-format
 msgid "duplicate %<_Atomic%>"
 msgstr "herhaalde %<restrict%>"
 
-#: c/c-decl.c:5800
+#: c/c-decl.c:5820
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "conflicting named address spaces (%s vs %s)"
 msgstr "conflicterende declaraties van %qs"
 
-#: c/c-decl.c:5823 c/c-parser.c:2821
+#: c/c-decl.c:5843 c/c-parser.c:2821
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified array type"
 msgstr ""
 
-#: c/c-decl.c:5837
+#: c/c-decl.c:5857
 #, gcc-internal-format
 msgid "function definition declared %<auto%>"
 msgstr "functie-definitie als %<auto%> gedeclareerd"
 
-#: c/c-decl.c:5839
+#: c/c-decl.c:5859
 #, gcc-internal-format
 msgid "function definition declared %<register%>"
 msgstr "functie-definitie als %<register%> gedeclareerd"
 
-#: c/c-decl.c:5841
+#: c/c-decl.c:5861
 #, gcc-internal-format
 msgid "function definition declared %<typedef%>"
 msgstr "functie-definitie als %<typdef%> gedeclareerd"
 
-#: c/c-decl.c:5843
+#: c/c-decl.c:5863
 #, fuzzy, gcc-internal-format
 msgid "function definition declared %qs"
 msgstr "functie-definitie als %<auto%> gedeclareerd"
 
-#: c/c-decl.c:5861
+#: c/c-decl.c:5881
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for structure field %qE"
 msgstr "opslagklasse opgegeven voor structure-veld %qs"
 
-#: c/c-decl.c:5864
+#: c/c-decl.c:5884
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for structure field"
 msgstr "opslagklasse opgegeven voor structure-veld %qs"
 
-#: c/c-decl.c:5868
+#: c/c-decl.c:5888
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for parameter %qE"
 msgstr "opslagklasse opgegeven voor parameter %qs"
 
-#: c/c-decl.c:5871
+#: c/c-decl.c:5891
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for unnamed parameter"
 msgstr "opslagklasse opgegeven voor parameter %qs"
 
-#: c/c-decl.c:5874 cp/decl.c:10935
+#: c/c-decl.c:5894 cp/decl.c:10959
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "opslagklasse opgegeven voor typenaam"
 
-#: c/c-decl.c:5891
+#: c/c-decl.c:5911
 #, fuzzy, gcc-internal-format
 msgid "%qE initialized and declared %<extern%>"
 msgstr "%qs krijgt beginwaarde en is als %<extern%> gedeclareerd"
 
-#: c/c-decl.c:5895
+#: c/c-decl.c:5915
 #, fuzzy, gcc-internal-format
 msgid "%qE has both %<extern%> and initializer"
 msgstr "%qs heeft zowel %<extern%> als een beginwaarde"
 
-#: c/c-decl.c:5900
+#: c/c-decl.c:5920
 #, fuzzy, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<auto%>"
 msgstr "declaratie van %qs op bestandsniveau specifieert %<auto%>"
 
-#: c/c-decl.c:5904
+#: c/c-decl.c:5924
 #, fuzzy, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<register%>"
 msgstr "declaratie van %qs op bestandsniveau specifieert %<auto%>"
 
-#: c/c-decl.c:5909
+#: c/c-decl.c:5929
 #, fuzzy, gcc-internal-format
 msgid "nested function %qE declared %<extern%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: c/c-decl.c:5912
+#: c/c-decl.c:5932
 #, fuzzy, gcc-internal-format
 msgid "function-scope %qE implicitly auto and declared %qs"
 msgstr "functie-definitie als %<auto%> gedeclareerd"
@@ -35220,703 +35264,703 @@
 #. Only the innermost declarator (making a parameter be of
 #. array type which is converted to pointer type)
 #. may have static or type qualifiers.
-#: c/c-decl.c:5959 c/c-decl.c:6328
+#: c/c-decl.c:5979 c/c-decl.c:6348
 #, gcc-internal-format
 msgid "static or type qualifiers in non-parameter array declarator"
 msgstr ""
 
-#: c/c-decl.c:6007
+#: c/c-decl.c:6027
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qE as array of voids"
 msgstr "%qs wordt gedeclareerd als een array van voids"
 
-#: c/c-decl.c:6009
+#: c/c-decl.c:6029
 #, fuzzy, gcc-internal-format
 msgid "declaration of type name as array of voids"
 msgstr "%qs wordt gedeclareerd als een array van voids"
 
-#: c/c-decl.c:6016
+#: c/c-decl.c:6036
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qE as array of functions"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: c/c-decl.c:6019
+#: c/c-decl.c:6039
 #, fuzzy, gcc-internal-format
 msgid "declaration of type name as array of functions"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: c/c-decl.c:6027 c/c-decl.c:8085
+#: c/c-decl.c:6047 c/c-decl.c:8105
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr "ongeldig gebruik van strcture met flexibel array-lid"
 
-#: c/c-decl.c:6053
+#: c/c-decl.c:6073
 #, fuzzy, gcc-internal-format
 msgid "size of array %qE has non-integer type"
 msgstr "grootte van array %qs is van een niet-integer type"
 
-#: c/c-decl.c:6057
+#: c/c-decl.c:6077
 #, fuzzy, gcc-internal-format
 msgid "size of unnamed array has non-integer type"
 msgstr "grootte van array %qs is van een niet-integer type"
 
-#: c/c-decl.c:6064
+#: c/c-decl.c:6084
 #, fuzzy, gcc-internal-format
 msgid "size of array %qE has incomplete type"
 msgstr "grootte van array %qs is van een niet-integer type"
 
-#: c/c-decl.c:6067
+#: c/c-decl.c:6087
 #, fuzzy, gcc-internal-format
 msgid "size of unnamed array has incomplete type"
 msgstr "grootte van array %qs is van een niet-integer type"
 
-#: c/c-decl.c:6078
+#: c/c-decl.c:6098
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids zero-size array %qE"
 msgstr "ISO C verbiedt array %qs met grootte 0"
 
-#: c/c-decl.c:6081
+#: c/c-decl.c:6101
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids zero-size array"
 msgstr "ISO C++ verbiedt array %qs met lengte 0"
 
-#: c/c-decl.c:6090
+#: c/c-decl.c:6110
 #, fuzzy, gcc-internal-format
 msgid "size of array %qE is negative"
 msgstr "grootte van array %qs is negatief"
 
-#: c/c-decl.c:6092
+#: c/c-decl.c:6112
 #, fuzzy, gcc-internal-format
 msgid "size of unnamed array is negative"
 msgstr "grootte van array %qs is negatief"
 
-#: c/c-decl.c:6216 c/c-decl.c:6871
+#: c/c-decl.c:6236 c/c-decl.c:6891
 #, gcc-internal-format
 msgid "ISO C90 does not support flexible array members"
 msgstr "ISO C90 ondersteunt geen flexibele array-leden"
 
 #. C99 6.7.5.2p4
-#: c/c-decl.c:6238
+#: c/c-decl.c:6258
 #, fuzzy, gcc-internal-format
 msgid "%<[*]%> not in a declaration"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: c/c-decl.c:6251
+#: c/c-decl.c:6271
 #, fuzzy, gcc-internal-format
 #| msgid "array type has incomplete element type"
 msgid "array type has incomplete element type %qT"
 msgstr "arraytype heeft onvolledig elementtype"
 
-#: c/c-decl.c:6257
+#: c/c-decl.c:6277
 #, gcc-internal-format
 msgid "declaration of %qE as multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: c/c-decl.c:6261
+#: c/c-decl.c:6281
 #, gcc-internal-format
 msgid "declaration of multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: c/c-decl.c:6364
+#: c/c-decl.c:6384
 #, fuzzy, gcc-internal-format
 msgid "%qE declared as function returning a function"
 msgstr "%qs gedeclareerd als een functie die een functie teruggeeft"
 
-#: c/c-decl.c:6367
+#: c/c-decl.c:6387
 #, fuzzy, gcc-internal-format
 msgid "type name declared as function returning a function"
 msgstr "%qs gedeclareerd als een functie die een functie teruggeeft"
 
-#: c/c-decl.c:6374
+#: c/c-decl.c:6394
 #, fuzzy, gcc-internal-format
 msgid "%qE declared as function returning an array"
 msgstr "%qs gedeclareerd als een functie die een array teruggeeft"
 
-#: c/c-decl.c:6377
+#: c/c-decl.c:6397
 #, fuzzy, gcc-internal-format
 msgid "type name declared as function returning an array"
 msgstr "%qs gedeclareerd als een functie die een array teruggeeft"
 
-#: c/c-decl.c:6418
+#: c/c-decl.c:6438
 #, fuzzy, gcc-internal-format
 msgid "function definition has qualified void return type"
 msgstr "functiedefinitie heeft een gekwalificeerde %<void%> als teruggeeftype"
 
-#: c/c-decl.c:6421 cp/decl.c:11201
+#: c/c-decl.c:6441 cp/decl.c:11225
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "typekwalificaties op teruggeeftypes van functies worden genegeerd"
 
-#: c/c-decl.c:6459 c/c-decl.c:6668 c/c-decl.c:6721 c/c-decl.c:6805
-#: c/c-decl.c:6926 c/c-parser.c:2823
+#: c/c-decl.c:6479 c/c-decl.c:6688 c/c-decl.c:6741 c/c-decl.c:6825
+#: c/c-decl.c:6946 c/c-parser.c:2823
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%>-qualified function type"
 msgstr "ISO C verbiedt gekwalificeerde functie-types"
 
-#: c/c-decl.c:6465 c/c-decl.c:6674 c/c-decl.c:6810 c/c-decl.c:6931
+#: c/c-decl.c:6485 c/c-decl.c:6694 c/c-decl.c:6830 c/c-decl.c:6951
 #, gcc-internal-format
 msgid "ISO C forbids qualified function types"
 msgstr "ISO C verbiedt gekwalificeerde functie-types"
 
 # misschien toch houden op type-qualifiers?
-#: c/c-decl.c:6559
+#: c/c-decl.c:6579
 #, fuzzy, gcc-internal-format
 msgid "%qs combined with %<auto%> qualifier for %qE"
 msgstr "%J onverenigbare typekwalificaties voor %qD"
 
-#: c/c-decl.c:6563
+#: c/c-decl.c:6583
 #, gcc-internal-format
 msgid "%qs combined with %<register%> qualifier for %qE"
 msgstr ""
 
-#: c/c-decl.c:6569
+#: c/c-decl.c:6589
 #, gcc-internal-format
 msgid "%qs specified for auto variable %qE"
 msgstr ""
 
-#: c/c-decl.c:6585
+#: c/c-decl.c:6605
 #, fuzzy, gcc-internal-format
 msgid "%qs specified for parameter %qE"
 msgstr "opslagklasse opgegeven voor parameter %qs"
 
-#: c/c-decl.c:6588
+#: c/c-decl.c:6608
 #, fuzzy, gcc-internal-format
 msgid "%qs specified for unnamed parameter"
 msgstr "opslagklasse opgegeven voor parameter %qs"
 
-#: c/c-decl.c:6594
+#: c/c-decl.c:6614
 #, fuzzy, gcc-internal-format
 msgid "%qs specified for structure field %qE"
 msgstr "opslagklasse opgegeven voor structure-veld %qs"
 
-#: c/c-decl.c:6597
+#: c/c-decl.c:6617
 #, fuzzy, gcc-internal-format
 msgid "%qs specified for structure field"
 msgstr "opslagklasse opgegeven voor structure-veld %qs"
 
-#: c/c-decl.c:6612
+#: c/c-decl.c:6632
 #, fuzzy, gcc-internal-format
 msgid "bit-field %qE has atomic type"
 msgstr "bitveld %qs heeft een ongeldig type"
 
-#: c/c-decl.c:6614
+#: c/c-decl.c:6634
 #, fuzzy, gcc-internal-format
 msgid "bit-field has atomic type"
 msgstr "bitveld %qs heeft een ongeldig type"
 
-#: c/c-decl.c:6623
+#: c/c-decl.c:6643
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for typedef %qE"
 msgstr "%Jer kan geen alignment opgegeven worden voor %qD"
 
-#: c/c-decl.c:6625
+#: c/c-decl.c:6645
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for %<register%> object %qE"
 msgstr "%Jer kan geen alignment opgegeven worden voor %qD"
 
-#: c/c-decl.c:6630
+#: c/c-decl.c:6650
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for parameter %qE"
 msgstr "opslagklasse opgegeven voor parameter %qs"
 
-#: c/c-decl.c:6632
+#: c/c-decl.c:6652
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for unnamed parameter"
 msgstr "opslagklasse opgegeven voor parameter %qs"
 
-#: c/c-decl.c:6637
+#: c/c-decl.c:6657
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for bit-field %qE"
 msgstr "%Jer kan geen alignment opgegeven worden voor %qD"
 
-#: c/c-decl.c:6639
+#: c/c-decl.c:6659
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for unnamed bit-field"
 msgstr "%<__alignof%> toegepast op bitveld"
 
-#: c/c-decl.c:6642
+#: c/c-decl.c:6662
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for function %qE"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: c/c-decl.c:6649
+#: c/c-decl.c:6669
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of %qE"
 msgstr ""
 
-#: c/c-decl.c:6652
+#: c/c-decl.c:6672
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of unnamed field"
 msgstr ""
 
-#: c/c-decl.c:6683
+#: c/c-decl.c:6703
 #, fuzzy, gcc-internal-format
 msgid "typedef %q+D declared %<inline%>"
 msgstr "%Jtypedef %qD als %<inline%> gedeclareerd"
 
-#: c/c-decl.c:6685
+#: c/c-decl.c:6705
 #, fuzzy, gcc-internal-format
 msgid "typedef %q+D declared %<_Noreturn%>"
 msgstr "%Jtypedef %qD als %<inline%> gedeclareerd"
 
-#: c/c-decl.c:6727
+#: c/c-decl.c:6747
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids const or volatile function types"
 msgstr "ISO C verbiedt %<const%> of %<volatile%> functie-types"
 
 #. C99 6.7.2.1p8
-#: c/c-decl.c:6738
+#: c/c-decl.c:6758
 #, fuzzy, gcc-internal-format
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "argument %d is alleen-lezen"
 
-#: c/c-decl.c:6755 cp/decl.c:9989
+#: c/c-decl.c:6775 cp/decl.c:10010
 #, fuzzy, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "variabele of veld %qs als void gedeclareerd"
 
-#: c/c-decl.c:6795
+#: c/c-decl.c:6815
 #, gcc-internal-format
 msgid "attributes in parameter array declarator ignored"
 msgstr "attributen genegeerd in declarator van parameter-array"
 
-#: c/c-decl.c:6837
+#: c/c-decl.c:6857
 #, fuzzy, gcc-internal-format
 msgid "parameter %q+D declared %<inline%>"
 msgstr "%Jparameter %qD als %<inline%> gedeclareerd"
 
-#: c/c-decl.c:6839
+#: c/c-decl.c:6859
 #, fuzzy, gcc-internal-format
 msgid "parameter %q+D declared %<_Noreturn%>"
 msgstr "%Jparameter %qD als %<inline%> gedeclareerd"
 
-#: c/c-decl.c:6852
+#: c/c-decl.c:6872
 #, fuzzy, gcc-internal-format
 msgid "field %qE declared as a function"
 msgstr "veld %qs als een functie gedeclareerd"
 
-#: c/c-decl.c:6859
+#: c/c-decl.c:6879
 #, fuzzy, gcc-internal-format
 msgid "field %qE has incomplete type"
 msgstr "veld %qs heeft een onvolledig type"
 
-#: c/c-decl.c:6861
+#: c/c-decl.c:6881
 #, fuzzy, gcc-internal-format
 msgid "unnamed field has incomplete type"
 msgstr "parameter %qs heeft een onvolledig type"
 
-#: c/c-decl.c:6897 c/c-decl.c:6908 c/c-decl.c:6911
+#: c/c-decl.c:6917 c/c-decl.c:6928 c/c-decl.c:6931
 #, fuzzy, gcc-internal-format
 msgid "invalid storage class for function %qE"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: c/c-decl.c:6968
+#: c/c-decl.c:6988
 #, gcc-internal-format
 msgid "cannot inline function %<main%>"
 msgstr "kan functie %<main%> niet %<inline%> maken"
 
-#: c/c-decl.c:6970
+#: c/c-decl.c:6990
 #, fuzzy, gcc-internal-format
 msgid "%<main%> declared %<_Noreturn%>"
 msgstr "%qs krijgt beginwaarde en is als %<extern%> gedeclareerd"
 
-#: c/c-decl.c:6981
+#: c/c-decl.c:7001
 #, fuzzy, gcc-internal-format
 msgid "ISO C99 does not support %<_Noreturn%>"
 msgstr "ISO C90 ondersteunt %<long long%> niet"
 
-#: c/c-decl.c:6984
+#: c/c-decl.c:7004
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support %<_Noreturn%>"
 msgstr "ISO C90 ondersteunt %<long long%> niet"
 
-#: c/c-decl.c:7013
+#: c/c-decl.c:7033
 #, gcc-internal-format
 msgid "variable previously declared %<static%> redeclared %<extern%>"
 msgstr "eerder als %<static%> gedeclareerde variabele als %<extern%> geherdeclareerd"
 
-#: c/c-decl.c:7023
+#: c/c-decl.c:7043
 #, fuzzy, gcc-internal-format
 msgid "variable %q+D declared %<inline%>"
 msgstr "%Jvariabele %qD als %<inline%> gedeclareerd"
 
-#: c/c-decl.c:7025
+#: c/c-decl.c:7045
 #, fuzzy, gcc-internal-format
 msgid "variable %q+D declared %<_Noreturn%>"
 msgstr "%Jvariabele %qD als %<inline%> gedeclareerd"
 
-#: c/c-decl.c:7060
+#: c/c-decl.c:7080
 #, fuzzy, gcc-internal-format
 msgid "non-nested function with variably modified type"
 msgstr "argument %d is alleen-lezen"
 
-#: c/c-decl.c:7062
+#: c/c-decl.c:7082
 #, gcc-internal-format
 msgid "object with variably modified type must have no linkage"
 msgstr ""
 
-#: c/c-decl.c:7153 c/c-decl.c:8821
+#: c/c-decl.c:7173 c/c-decl.c:8841
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr "functie-declaratie is geen prototype"
 
-#: c/c-decl.c:7163
+#: c/c-decl.c:7183
 #, gcc-internal-format
 msgid "parameter names (without types) in function declaration"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: c/c-decl.c:7201
+#: c/c-decl.c:7221
 #, fuzzy, gcc-internal-format
 msgid "parameter %u (%q+D) has incomplete type"
 msgstr "%Jparameter %u (%qD) heeft een onvolledig type"
 
-#: c/c-decl.c:7205
+#: c/c-decl.c:7225
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has incomplete type"
 msgstr "%Jparameter %u heeft een onvolledig type"
 
-#: c/c-decl.c:7216
+#: c/c-decl.c:7236
 #, fuzzy, gcc-internal-format
 msgid "parameter %u (%q+D) has void type"
 msgstr "%Jparameter %u (%qD) heeft %<void%> als type"
 
-#: c/c-decl.c:7220
+#: c/c-decl.c:7240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has void type"
 msgstr "%Jparameter %u heeft %<void%> als type"
 
-#: c/c-decl.c:7294
+#: c/c-decl.c:7314
 #, gcc-internal-format
 msgid "%<void%> as only parameter may not be qualified"
 msgstr "%<void%> als enige parameter mag niet gekwalificeerd worden"
 
-#: c/c-decl.c:7298 c/c-decl.c:7334
+#: c/c-decl.c:7318 c/c-decl.c:7354
 #, gcc-internal-format
 msgid "%<void%> must be the only parameter"
 msgstr "%<void%> moet de enige parameter zijn"
 
-#: c/c-decl.c:7328
+#: c/c-decl.c:7348
 #, fuzzy, gcc-internal-format
 msgid "parameter %q+D has just a forward declaration"
 msgstr "%Jparameter %qD heeft enkel een voorwaartse declaratie"
 
-#: c/c-decl.c:7374
+#: c/c-decl.c:7394
 #, gcc-internal-format
 msgid "%<%s %E%> declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr ""
 
-#: c/c-decl.c:7380
+#: c/c-decl.c:7400
 #, gcc-internal-format, gfc-internal-format
 msgid "anonymous %s declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr ""
 
-#: c/c-decl.c:7482
+#: c/c-decl.c:7502
 #, fuzzy, gcc-internal-format
 msgid "enum type defined here"
 msgstr "%qs tevoren hier gedefinieerd"
 
-#: c/c-decl.c:7488
+#: c/c-decl.c:7508
 #, fuzzy, gcc-internal-format
 msgid "struct defined here"
 msgstr "%qs tevoren hier gedefinieerd"
 
-#: c/c-decl.c:7494
+#: c/c-decl.c:7514
 #, fuzzy, gcc-internal-format
 msgid "union defined here"
 msgstr "%qs tevoren hier gedefinieerd"
 
-#: c/c-decl.c:7570
+#: c/c-decl.c:7590
 #, fuzzy, gcc-internal-format
 msgid "redefinition of %<union %E%>"
 msgstr "herdefinitie van %<union %s%>"
 
-#: c/c-decl.c:7572
+#: c/c-decl.c:7592
 #, fuzzy, gcc-internal-format
 msgid "redefinition of %<struct %E%>"
 msgstr "herdefinitie van %<struct %s%>"
 
-#: c/c-decl.c:7581
+#: c/c-decl.c:7601
 #, fuzzy, gcc-internal-format
 msgid "nested redefinition of %<union %E%>"
 msgstr "geneste herdefinitie van %<union %s%>"
 
-#: c/c-decl.c:7583
+#: c/c-decl.c:7603
 #, fuzzy, gcc-internal-format
 msgid "nested redefinition of %<struct %E%>"
 msgstr "geneste herdefinitie van %<struct %s%>"
 
-#: c/c-decl.c:7613 c/c-decl.c:8400
+#: c/c-decl.c:7633 c/c-decl.c:8420
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:7680 cp/decl.c:4802
+#: c/c-decl.c:7700 cp/decl.c:4802
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "declaratie declareert niets"
 
-#: c/c-decl.c:7685
+#: c/c-decl.c:7705
 #, fuzzy, gcc-internal-format
 msgid "ISO C99 doesn%'t support unnamed structs/unions"
 msgstr "ISO C ondersteunt geen naamloze structs/unions"
 
-#: c/c-decl.c:7688
+#: c/c-decl.c:7708
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 doesn%'t support unnamed structs/unions"
 msgstr "ISO C ondersteunt geen naamloze structs/unions"
 
-#: c/c-decl.c:7781 c/c-decl.c:7799 c/c-decl.c:7860
+#: c/c-decl.c:7801 c/c-decl.c:7819 c/c-decl.c:7880
 #, fuzzy, gcc-internal-format
 msgid "duplicate member %q+D"
 msgstr "%Jherhaald lid %qD"
 
-#: c/c-decl.c:7886
+#: c/c-decl.c:7906
 #, gcc-internal-format
 msgid "empty struct has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.c:7889
+#: c/c-decl.c:7909
 #, gcc-internal-format
 msgid "empty union has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.c:7994
+#: c/c-decl.c:8014
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr "union heeft geen benoemde leden"
 
-#: c/c-decl.c:7996
+#: c/c-decl.c:8016
 #, gcc-internal-format
 msgid "union has no members"
 msgstr "union heeft geen leden"
 
-#: c/c-decl.c:8001
+#: c/c-decl.c:8021
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr "struct heeft geen benoemde leden"
 
-#: c/c-decl.c:8003
+#: c/c-decl.c:8023
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr "struct heeft geen leden"
 
-#: c/c-decl.c:8064 cp/decl.c:12069
+#: c/c-decl.c:8084 cp/decl.c:12093
 #, fuzzy, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "%Jflexibel array-lid in union"
 
-#: c/c-decl.c:8070
+#: c/c-decl.c:8090
 #, fuzzy, gcc-internal-format
 msgid "flexible array member not at end of struct"
 msgstr "%Jflexibel array-lid niet aan het eind van de struct"
 
-#: c/c-decl.c:8076
+#: c/c-decl.c:8096
 #, fuzzy, gcc-internal-format
 msgid "flexible array member in a struct with no named members"
 msgstr "%Jflexibel array-lid in union"
 
-#: c/c-decl.c:8107
+#: c/c-decl.c:8127
 #, fuzzy, gcc-internal-format
 msgid "type %qT is too large"
 msgstr "omvang van array %qs is te groot"
 
-#: c/c-decl.c:8230
+#: c/c-decl.c:8250
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr "union kan niet transparant gemaakt worden"
 
-#: c/c-decl.c:8372
+#: c/c-decl.c:8392
 #, fuzzy, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr "geneste herdefinitie van %<enum %qs%>"
 
 #. This enum is a named one that has been declared already.
-#: c/c-decl.c:8379
+#: c/c-decl.c:8399
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr "herdeclaratie van %<enum %qs%>"
 
-#: c/c-decl.c:8458 cp/decl.c:14423
+#: c/c-decl.c:8478 cp/decl.c:14447
 #, gcc-internal-format
 msgid "specified mode too small for enumeral values"
 msgstr "opgegeven modus is te klein voor enumeratiewaarden"
 
-#: c/c-decl.c:8473
+#: c/c-decl.c:8493
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr "enumeratiewaarden overschrijden het bereik van de grootste integer"
 
-#: c/c-decl.c:8587 c/c-decl.c:8603
+#: c/c-decl.c:8607 c/c-decl.c:8623
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr "enumeratiewaarde voor %qE is geen integerconstante"
 
-#: c/c-decl.c:8598
+#: c/c-decl.c:8618
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr "enumeratiewaarde voor %qE is geen integerconstante"
 
-#: c/c-decl.c:8622
+#: c/c-decl.c:8642
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr "overflow in enumeratiewaarden"
 
-#: c/c-decl.c:8630
+#: c/c-decl.c:8650
 #, gcc-internal-format
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "ISO C beperkt enumeratiewaarden tot het bereik van het %<int%> type"
 
-#: c/c-decl.c:8715 cp/decl.c:5104 cp/decl.c:14955
+#: c/c-decl.c:8735 cp/decl.c:5104 cp/decl.c:14979
 #, fuzzy, gcc-internal-format
 msgid "inline function %qD given attribute noinline"
 msgstr "%J%<noinline%> attribuut gegeven aan ingebouwde functie %qD"
 
-#: c/c-decl.c:8733
+#: c/c-decl.c:8753
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr "teruggeeftype is onvolledig"
 
-#: c/c-decl.c:8744
+#: c/c-decl.c:8764
 #, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr "teruggeeftype krijgt standaardwaarde %<int%>"
 
-#: c/c-decl.c:8771
+#: c/c-decl.c:8791
 #, fuzzy, gcc-internal-format
 msgid "%q+D defined as variadic function without prototype"
 msgstr "sectie van %qs geeft een conflict met een eerdere declaratie"
 
-#: c/c-decl.c:8830
+#: c/c-decl.c:8850
 #, fuzzy, gcc-internal-format
 msgid "no previous prototype for %qD"
 msgstr "%Jgeen eerder prototype voor %qD"
 
-#: c/c-decl.c:8839
+#: c/c-decl.c:8859
 #, fuzzy, gcc-internal-format
 msgid "%qD was used with no prototype before its definition"
 msgstr "%J%qD werd voor haar definitie gebruikt zonder protoype"
 
-#: c/c-decl.c:8847 cp/decl.c:15090
+#: c/c-decl.c:8867 cp/decl.c:15114
 #, fuzzy, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "%Jgeen eerdere declaratie voor %qD"
 
-#: c/c-decl.c:8857
+#: c/c-decl.c:8877
 #, fuzzy, gcc-internal-format
 msgid "%qD was used with no declaration before its definition"
 msgstr "%J%qD werd voor haar definitie gebruikt zonder declaratie"
 
-#: c/c-decl.c:8876
+#: c/c-decl.c:8896
 #, fuzzy, gcc-internal-format
 msgid "return type of %qD is not %<int%>"
 msgstr "%Jteruggeeftype van %qD is niet %<int%>"
 
-#: c/c-decl.c:8878
+#: c/c-decl.c:8898
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr "ISO C verbiedt gekwalificeerde functie-types"
 
-#: c/c-decl.c:8885
+#: c/c-decl.c:8905
 #, fuzzy, gcc-internal-format
 msgid "%qD is normally a non-static function"
 msgstr "%J%qD is gewoonlijk een niet-static funtie"
 
-#: c/c-decl.c:8922
+#: c/c-decl.c:8942
 #, fuzzy, gcc-internal-format
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr "%Jparameterdeclaraties in oude stijl gebruikt in de definitie van een functie die een prototype heeft"
 
-#: c/c-decl.c:8937
+#: c/c-decl.c:8957
 #, fuzzy, gcc-internal-format
 msgid "traditional C rejects ISO C style function definitions"
 msgstr "%Jtraditionele C verwerpt functiedefinities in de stijl van ISO C"
 
-#: c/c-decl.c:8953
+#: c/c-decl.c:8973
 #, fuzzy, gcc-internal-format
 msgid "parameter name omitted"
 msgstr "%Jparameternaam weggelaten"
 
-#: c/c-decl.c:8990
+#: c/c-decl.c:9010
 #, fuzzy, gcc-internal-format
 msgid "old-style function definition"
 msgstr "%Jfunctiedefinitie in oude stijl"
 
-#: c/c-decl.c:8999
+#: c/c-decl.c:9019
 #, fuzzy, gcc-internal-format
 msgid "parameter name missing from parameter list"
 msgstr "%Jparameternaam ontbreekt in parameterlijst"
 
-#: c/c-decl.c:9015
+#: c/c-decl.c:9035
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a non-parameter"
 msgstr "%J%qD als niet-parameter gedeclareerd"
 
-#: c/c-decl.c:9023
+#: c/c-decl.c:9043
 #, fuzzy, gcc-internal-format
 msgid "multiple parameters named %qD"
 msgstr "%Jmeerdere parameters hebben de naam %qD"
 
-#: c/c-decl.c:9032
+#: c/c-decl.c:9052
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD declared with void type"
 msgstr "%Jparameter %qD als void gedeclareerd"
 
-#: c/c-decl.c:9061 c/c-decl.c:9066
+#: c/c-decl.c:9081 c/c-decl.c:9086
 #, fuzzy, gcc-internal-format
 msgid "type of %qD defaults to %<int%>"
 msgstr "%Jtype van %qD krijgt standaardtype %<int%>"
 
-#: c/c-decl.c:9086
+#: c/c-decl.c:9106
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD has incomplete type"
 msgstr "%Jparameter %qD heeft een onvolledig type"
 
-#: c/c-decl.c:9093
+#: c/c-decl.c:9113
 #, fuzzy, gcc-internal-format
 msgid "declaration for parameter %qD but no such parameter"
 msgstr "%Jdeclaratie voor parameter %qD maar er is zo geen parameter"
 
-#: c/c-decl.c:9146
+#: c/c-decl.c:9166
 #, fuzzy, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr "aantal argumenten kom niet overeen met prototype"
 
-#: c/c-decl.c:9157
+#: c/c-decl.c:9177
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr "aantal argumenten kom niet overeen met prototype"
 
-#: c/c-decl.c:9160 c/c-decl.c:9207 c/c-decl.c:9221
+#: c/c-decl.c:9180 c/c-decl.c:9227 c/c-decl.c:9241
 #, fuzzy, gcc-internal-format
 msgid "prototype declaration"
 msgstr "%Hdeclaratie van prototype"
 
-#: c/c-decl.c:9199
+#: c/c-decl.c:9219
 #, fuzzy, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr "gepromoveerd argument %qD komt niet overeen met prototype"
 
-#: c/c-decl.c:9204
+#: c/c-decl.c:9224
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr "gepromoveerd argument %qD komt niet overeen met prototype"
 
-#: c/c-decl.c:9214
+#: c/c-decl.c:9234
 #, fuzzy, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr "argument %qs komt niet overeen met prototype"
 
-#: c/c-decl.c:9219
+#: c/c-decl.c:9239
 #, fuzzy, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr "argument %qs komt niet overeen met prototype"
 
-#: c/c-decl.c:9470 cp/decl.c:15873
+#: c/c-decl.c:9490 cp/decl.c:15897
 #, fuzzy, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "%<return%> zonder waarde in een functie die een niet-void waarde teruggeeft"
 
-#: c/c-decl.c:9490 cp/decl.c:15905
+#: c/c-decl.c:9510 cp/decl.c:15929
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "parameter %qD krijgt beginwaarde"
@@ -35924,251 +35968,251 @@
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:9586
+#: c/c-decl.c:9606
 #, fuzzy, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "initiële declaratie voor %<for%> lus gebruikt buiten C99 modus"
 
-#: c/c-decl.c:9591
+#: c/c-decl.c:9611
 #, gcc-internal-format
 msgid "use option -std=c99, -std=gnu99, -std=c11 or -std=gnu11 to compile your code"
 msgstr ""
 
-#: c/c-decl.c:9626
+#: c/c-decl.c:9646
 #, fuzzy, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "de declaratie van %qs verbergt een globale declaratie"
 
-#: c/c-decl.c:9630
+#: c/c-decl.c:9650
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "de declaratie van %qs verbergt een globale declaratie"
 
-#: c/c-decl.c:9637
+#: c/c-decl.c:9657
 #, fuzzy, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "%qs als 'inline' gedeclareerd na de definitie"
 
-#: c/c-decl.c:9642
+#: c/c-decl.c:9662
 #, fuzzy, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "%qs als 'inline' gedeclareerd na de definitie"
 
-#: c/c-decl.c:9646
+#: c/c-decl.c:9666
 #, fuzzy, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "%qs als 'inline' gedeclareerd na de definitie"
 
-#: c/c-decl.c:9650
+#: c/c-decl.c:9670
 #, fuzzy, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "de declaratie van %qs verbergt een globale declaratie"
 
-#: c/c-decl.c:9900
+#: c/c-decl.c:9920
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr ""
 
-#: c/c-decl.c:9958 c/c-decl.c:9965
+#: c/c-decl.c:9978 c/c-decl.c:9985
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qE declaration specifier"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: c/c-decl.c:9992 c/c-decl.c:10376 c/c-decl.c:10766
+#: c/c-decl.c:10012 c/c-decl.c:10396 c/c-decl.c:10786
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr "twee of meer data types opgegeven bij declaratie"
 
-#: c/c-decl.c:10004 cp/parser.c:28261
+#: c/c-decl.c:10024 cp/parser.c:28258
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> is te lang voor GCC"
 
-#: c/c-decl.c:10017
+#: c/c-decl.c:10037
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C90 ondersteunt %<long long%> niet"
 
-#: c/c-decl.c:10246 c/c-parser.c:8848
+#: c/c-decl.c:10266 c/c-parser.c:8848
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C90 ondersteunt geen complexe types"
 
-#: c/c-decl.c:10292
+#: c/c-decl.c:10312
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr "ISO C ondersteunt %<long long%> niet"
 
-#: c/c-decl.c:10363 c/c-decl.c:10923
+#: c/c-decl.c:10383 c/c-decl.c:10943
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "herhaalde %qs"
 
-#: c/c-decl.c:10419
+#: c/c-decl.c:10439
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C ondersteunt %<long long%> niet"
 
-#: c/c-decl.c:10441
+#: c/c-decl.c:10461
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr "sectie-attributen worden niet ondersteund voor dit doelsysteem"
 
-#: c/c-decl.c:10484
+#: c/c-decl.c:10504
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support complex types"
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C90 ondersteunt geen complexe types"
 
-#: c/c-decl.c:10603
+#: c/c-decl.c:10623
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support the %<_Float%d%s%> type"
 msgstr "ISO C ondersteunt %<long long%> niet"
 
-#: c/c-decl.c:10653
+#: c/c-decl.c:10673
 #, fuzzy, gcc-internal-format
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "sectie-attributen worden niet ondersteund voor dit doelsysteem"
 
-#: c/c-decl.c:10724
+#: c/c-decl.c:10744
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support decimal floating point"
 msgstr "ISO C90 ondersteunt %<long long%> niet"
 
-#: c/c-decl.c:10747 c/c-decl.c:11013 c/c-parser.c:7842
+#: c/c-decl.c:10767 c/c-decl.c:11033 c/c-parser.c:7842
 #, fuzzy, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "sectie-attributen worden niet ondersteund voor dit doelsysteem"
 
-#: c/c-decl.c:10749
+#: c/c-decl.c:10769
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C ondersteunt %<long long%> niet"
 
-#: c/c-decl.c:10784
+#: c/c-decl.c:10804
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr ""
 
 # is letterlijke vertaling maar klinkt zo vreemd...
-#: c/c-decl.c:10797
+#: c/c-decl.c:10817
 #, fuzzy, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr "%qs slaagt er niet in een typedef of ingebouwd type te zijn"
 
-#: c/c-decl.c:10845
+#: c/c-decl.c:10865
 #, fuzzy, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: c/c-decl.c:10866
+#: c/c-decl.c:10886
 #, fuzzy, gcc-internal-format
 msgid "%qE used with %<auto%>"
 msgstr "%<__thread%> samen met %<auto%> gebruikt"
 
-#: c/c-decl.c:10868
+#: c/c-decl.c:10888
 #, fuzzy, gcc-internal-format
 msgid "%qE used with %<register%>"
 msgstr "%<__thread%> samen met %<register%> gebruikt"
 
-#: c/c-decl.c:10870
+#: c/c-decl.c:10890
 #, fuzzy, gcc-internal-format
 msgid "%qE used with %<typedef%>"
 msgstr "%<__thread%> samen met %<typedef%> gebruikt"
 
-#: c/c-decl.c:10884 c/c-parser.c:7360
+#: c/c-decl.c:10904 c/c-parser.c:7360
 #, fuzzy, gcc-internal-format
 msgid "ISO C99 does not support %qE"
 msgstr "%s ondersteunt %s niet"
 
-#: c/c-decl.c:10887 c/c-parser.c:7363
+#: c/c-decl.c:10907 c/c-parser.c:7363
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support %qE"
 msgstr "ISO C90 ondersteunt %<long long%> niet"
 
-#: c/c-decl.c:10899
+#: c/c-decl.c:10919
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<__thread%> vóór %<extern%> gebruikt"
 
-#: c/c-decl.c:10908
+#: c/c-decl.c:10928
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<__thread%> vóór %<static%> gebruikt"
 
-#: c/c-decl.c:10921
+#: c/c-decl.c:10941
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr ""
 
-#: c/c-decl.c:10929
+#: c/c-decl.c:10949
 #, fuzzy, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: c/c-decl.c:10937
+#: c/c-decl.c:10957
 #, fuzzy, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr "%<__thread%> samen met %s gebruikt"
 
-#: c/c-decl.c:11010
+#: c/c-decl.c:11030
 #, fuzzy, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "%<__thread%> samen met %<auto%> gebruikt"
 
-#: c/c-decl.c:11025
+#: c/c-decl.c:11045
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C ondersteunt gewone %<complex%> niet in de betekenis van %<double complex%>"
 
-#: c/c-decl.c:11076 c/c-decl.c:11092 c/c-decl.c:11118
+#: c/c-decl.c:11096 c/c-decl.c:11112 c/c-decl.c:11138
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C ondersteunt %<long long%> niet"
 
-#: c/c-decl.c:11514 cp/semantics.c:5348
+#: c/c-decl.c:11534 cp/semantics.c:5351
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:11518 cp/semantics.c:5352
+#: c/c-decl.c:11538 cp/semantics.c:5355
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.c:385 c/c-typeck.c:11426 cp/typeck.c:4680
+#: c/c-fold.c:385 c/c-typeck.c:11431 cp/typeck.c:4680
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count is negative"
 msgid "left shift of negative value"
 msgstr "teller van links shift is negatief"
 
-#: c/c-fold.c:395 c/c-typeck.c:11435 cp/typeck.c:4688
+#: c/c-fold.c:395 c/c-typeck.c:11440 cp/typeck.c:4688
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "teller van links shift is negatief"
 
-#: c/c-fold.c:396 c/c-typeck.c:11365 cp/typeck.c:4633
+#: c/c-fold.c:396 c/c-typeck.c:11370 cp/typeck.c:4633
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "teller van rechtse shift is negatief"
 
-#: c/c-fold.c:404 c/c-typeck.c:11454 cp/typeck.c:4696
+#: c/c-fold.c:404 c/c-typeck.c:11459 cp/typeck.c:4696
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "teller van links shift is >= breedte van het type"
 
-#: c/c-fold.c:405 c/c-typeck.c:11389 cp/typeck.c:4641
+#: c/c-fold.c:405 c/c-typeck.c:11394 cp/typeck.c:4641
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "teller van rechtse shift is >= breedte van het type"
 
-#: c/c-fold.c:412 c/c-typeck.c:11446
+#: c/c-fold.c:412 c/c-typeck.c:11451
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count >= width of type"
 msgid "left shift count >= width of vector element"
 msgstr "teller van links shift is >= breedte van het type"
 
-#: c/c-fold.c:413 c/c-typeck.c:11376
+#: c/c-fold.c:413 c/c-typeck.c:11381
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count >= width of type"
 msgid "right shift count >= width of vector element"
@@ -36189,7 +36233,7 @@
 msgid "to match this %qs"
 msgstr ""
 
-#: c/c-parser.c:1216 cp/parser.c:28484
+#: c/c-parser.c:1216 cp/parser.c:28481
 #, fuzzy, gcc-internal-format
 msgid "expected end of line"
 msgstr "ongeldige operand van %s"
@@ -36230,7 +36274,7 @@
 msgstr "onbekende machine-modus %qs"
 
 #: c/c-parser.c:1848 c/c-parser.c:11129 c/c-parser.c:16147 c/c-parser.c:16585
-#: c/c-parser.c:17061 cp/parser.c:36007 cp/parser.c:38993
+#: c/c-parser.c:17061 cp/parser.c:36004 cp/parser.c:38990
 #, fuzzy, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "meerdere opslagklassen in declaratie van %qs"
@@ -36245,7 +36289,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:1906 cp/parser.c:30161 cp/parser.c:30235
+#: c/c-parser.c:1906 cp/parser.c:30158 cp/parser.c:30232
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr ""
@@ -36301,7 +36345,7 @@
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr ""
 
-#: c/c-parser.c:2220 cp/parser.c:13002 cp/parser.c:13159
+#: c/c-parser.c:2220 cp/parser.c:12999 cp/parser.c:13156
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr ""
@@ -36329,7 +36373,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C90 ondersteunt %<long long%> niet"
 
-#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38634
+#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38631
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr ""
@@ -36393,13 +36437,13 @@
 #: c/c-parser.c:10745 c/c-parser.c:10798 c/c-parser.c:10814 c/c-parser.c:10860
 #: c/c-parser.c:11496 c/c-parser.c:11537 c/c-parser.c:13445 c/c-parser.c:13681
 #: c/c-parser.c:15544 c/c-parser.c:18218 c/gimple-parser.c:1058
-#: c/gimple-parser.c:1096 cp/parser.c:28487 cp/parser.c:31013
-#: cp/parser.c:31043 cp/parser.c:31113 cp/parser.c:33230 cp/parser.c:38350
+#: c/gimple-parser.c:1096 cp/parser.c:28484 cp/parser.c:31010
+#: cp/parser.c:31040 cp/parser.c:31110 cp/parser.c:33227 cp/parser.c:38347
 #, fuzzy, gcc-internal-format
 msgid "expected identifier"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:2995 cp/parser.c:18384
+#: c/c-parser.c:2995 cp/parser.c:18381
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "komma aan het einde van enumerator-lijst"
@@ -36568,12 +36612,12 @@
 msgid "expected statement"
 msgstr "ongeldige beginwaarde"
 
-#: c/c-parser.c:5639 cp/parser.c:12516
+#: c/c-parser.c:5639 cp/parser.c:12513
 #, fuzzy, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "leeg body in een else-statement"
 
-#: c/c-parser.c:5681 cp/parser.c:12519
+#: c/c-parser.c:5681 cp/parser.c:12516
 #, fuzzy, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "leeg body in een else-statement"
@@ -36922,7 +36966,7 @@
 msgid "%<__builtin_complex%> operands of different types"
 msgstr "tweede argument van %<__builtin_longjmp%> moet 1 zijn"
 
-#: c/c-parser.c:8891 cp/parser.c:6918
+#: c/c-parser.c:8891 cp/parser.c:6921
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_shuffle%>"
 msgstr "te weinig argumenten voor functie %<va_start%>"
@@ -36982,76 +37026,76 @@
 msgid "no type or storage class may be specified here,"
 msgstr "opslagklasse opgegeven voor parameter %qs"
 
-#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31073
+#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31070
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr ""
 
-#: c/c-parser.c:10682 cp/parser.c:31033
+#: c/c-parser.c:10682 cp/parser.c:31030
 #, fuzzy, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "misvormde #pragma pack"
 
-#: c/c-parser.c:10685 cp/parser.c:31036
+#: c/c-parser.c:10685 cp/parser.c:31033
 #, fuzzy, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "misvormde #pragma pack"
 
-#: c/c-parser.c:10699 cp/parser.c:31051
+#: c/c-parser.c:10699 cp/parser.c:31048
 #, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr ""
 
-#: c/c-parser.c:10704 cp/parser.c:31057
+#: c/c-parser.c:10704 cp/parser.c:31054
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.c:10711 cp/parser.c:31065
+#: c/c-parser.c:10711 cp/parser.c:31062
 #, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "attribuut %<getter%> mag slechts één keer opgegeven worden"
 
-#: c/c-parser.c:10905 cp/parser.c:38674
+#: c/c-parser.c:10905 cp/parser.c:38671
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
 #: c/c-parser.c:10949 c/c-parser.c:16582 c/c-parser.c:16840 c/c-parser.c:16899
-#: c/c-parser.c:16983 cp/parser.c:36004 cp/parser.c:36298 cp/parser.c:36386
-#: cp/parser.c:36457 cp/parser.c:38721 cp/parser.c:38736 cp/parser.c:38752
-#: cp/parser.c:38768 cp/parser.c:38784 cp/parser.c:38811 cp/parser.c:38824
-#: cp/parser.c:38847 cp/parser.c:38860
+#: c/c-parser.c:16983 cp/parser.c:36001 cp/parser.c:36295 cp/parser.c:36383
+#: cp/parser.c:36454 cp/parser.c:38718 cp/parser.c:38733 cp/parser.c:38749
+#: cp/parser.c:38765 cp/parser.c:38781 cp/parser.c:38808 cp/parser.c:38821
+#: cp/parser.c:38844 cp/parser.c:38857
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: c/c-parser.c:10972 cp/parser.c:38837
+#: c/c-parser.c:10972 cp/parser.c:38834
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "misvormde #pragma pack(pop[,id])"
 
-#: c/c-parser.c:11050 cp/parser.c:38918
+#: c/c-parser.c:11050 cp/parser.c:38915
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr ""
 
-#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38947 cp/parser.c:38980
+#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38944 cp/parser.c:38977
 #, fuzzy, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "overflow in constante expressie"
 
-#: c/c-parser.c:11111 cp/parser.c:38711
+#: c/c-parser.c:11111 cp/parser.c:38708
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "misvormde #pragma pack(pop[,id])"
 
-#: c/c-parser.c:11421 cp/parser.c:31457
+#: c/c-parser.c:11421 cp/parser.c:31454
 #, fuzzy, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "te veel invoerbestanden"
 
-#: c/c-parser.c:11443 cp/parser.c:31994
+#: c/c-parser.c:11443 cp/parser.c:31991
 #, fuzzy, gcc-internal-format
 msgid "expected integer expression before ')'"
 msgstr "ongeldige waarheidsexpressie"
@@ -37066,53 +37110,53 @@
 msgid "%qD is not a variable"
 msgstr "functie-oproep heeft geaggregeerde waarde"
 
-#: c/c-parser.c:11746 cp/semantics.c:6808
+#: c/c-parser.c:11746 cp/semantics.c:6811
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "functie-oproep heeft geaggregeerde waarde"
 
-#: c/c-parser.c:11788 cp/parser.c:32073
+#: c/c-parser.c:11788 cp/parser.c:32070
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:11865 cp/parser.c:32137
+#: c/c-parser.c:11865 cp/parser.c:32134
 #, fuzzy, gcc-internal-format
 msgid "expected %<none%> or %<present%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:11867 cp/parser.c:32139
+#: c/c-parser.c:11867 cp/parser.c:32136
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr ""
 
-#: c/c-parser.c:11968 cp/parser.c:32242
+#: c/c-parser.c:11968 cp/parser.c:32239
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32260
-#: cp/parser.c:36290 cp/parser.c:36378
+#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32257
+#: cp/parser.c:36287 cp/parser.c:36375
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:12035 cp/parser.c:32313
+#: c/c-parser.c:12035 cp/parser.c:32310
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:12042 cp/parser.c:32320
+#: c/c-parser.c:12042 cp/parser.c:32317
 #, fuzzy, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr "te veel invoerbestanden"
 
-#: c/c-parser.c:12044 cp/parser.c:32322
+#: c/c-parser.c:12044 cp/parser.c:32319
 #, fuzzy, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr "te veel invoerbestanden"
 
-#: c/c-parser.c:12050 cp/parser.c:32328
+#: c/c-parser.c:12050 cp/parser.c:32325
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -37134,83 +37178,83 @@
 msgid "%<num_tasks%> value must be positive"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-parser.c:12229 cp/semantics.c:6992
+#: c/c-parser.c:12229 cp/semantics.c:6995
 #, fuzzy, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-parser.c:12276 cp/semantics.c:7021
+#: c/c-parser.c:12276 cp/semantics.c:7024
 #, fuzzy, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32545 cp/parser.c:32552
+#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32542 cp/parser.c:32549
 #, fuzzy, gcc-internal-format
 msgid "expected %<tofrom%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32561 cp/parser.c:32568
+#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32558 cp/parser.c:32565
 #, fuzzy, gcc-internal-format
 msgid "expected %<scalar%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:12425 cp/semantics.c:6299
+#: c/c-parser.c:12425 cp/semantics.c:6302
 #, fuzzy, gcc-internal-format
 msgid "%qs expression must be integral"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6331
+#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6334
 #, fuzzy, gcc-internal-format
 msgid "%qs value must be positive"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-parser.c:12499 cp/parser.c:31853
+#: c/c-parser.c:12499 cp/parser.c:31850
 #, fuzzy, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "te veel argumenten voor formaat"
 
-#: c/c-parser.c:12533 cp/parser.c:31886
+#: c/c-parser.c:12533 cp/parser.c:31883
 #, fuzzy, gcc-internal-format
 msgid "unexpected argument"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:12699 cp/semantics.c:7120
+#: c/c-parser.c:12699 cp/semantics.c:7123
 #, fuzzy, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "herhalings-aantal is geen integerconstante"
 
-#: c/c-parser.c:12765 cp/parser.c:32626
+#: c/c-parser.c:12765 cp/parser.c:32623
 #, fuzzy, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37643
+#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37640
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr ""
 
-#: c/c-parser.c:12967 cp/parser.c:32840
+#: c/c-parser.c:12967 cp/parser.c:32837
 #, fuzzy, gcc-internal-format
 #| msgid "both %<long%> and %<void%> in declaration specifiers"
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "zowel %<long%> als %<void%> opgegeven bij declaratie"
 
-#: c/c-parser.c:13021 cp/parser.c:32856
+#: c/c-parser.c:13021 cp/parser.c:32853
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:13025 cp/parser.c:32859
+#: c/c-parser.c:13025 cp/parser.c:32856
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:13037 cp/semantics.c:6389
+#: c/c-parser.c:13037 cp/semantics.c:6392
 #, fuzzy, gcc-internal-format
 msgid "chunk size value must be positive"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-parser.c:13060 cp/parser.c:32879
+#: c/c-parser.c:13060 cp/parser.c:32876
 #, fuzzy, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "ongeldige const_double operand"
@@ -37220,12 +37264,12 @@
 msgid "%<num_teams%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:13226 cp/semantics.c:6479
+#: c/c-parser.c:13226 cp/semantics.c:6482
 #, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:13271 cp/semantics.c:6589
+#: c/c-parser.c:13271 cp/semantics.c:6592
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr ""
@@ -37245,17 +37289,17 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:13584 cp/parser.c:33374 cp/parser.c:33599
+#: c/c-parser.c:13584 cp/parser.c:33371 cp/parser.c:33596
 #, fuzzy, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "ongeldige const_double operand"
 
-#: c/c-parser.c:13669 cp/parser.c:33447
+#: c/c-parser.c:13669 cp/parser.c:33444
 #, gcc-internal-format
 msgid "invalid map kind"
 msgstr ""
 
-#: c/c-parser.c:13767 cp/parser.c:33546
+#: c/c-parser.c:13767 cp/parser.c:33543
 #, fuzzy, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "ongeldige const_double operand"
@@ -37265,67 +37309,67 @@
 msgid "invalid proc_bind kind"
 msgstr "ongeldige const_double operand"
 
-#: c/c-parser.c:14059 cp/parser.c:33825
+#: c/c-parser.c:14059 cp/parser.c:33822
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33836 cp/parser.c:34143
+#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33833 cp/parser.c:34140
 #, fuzzy, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "-fPIC is niet geldig met -mcoff"
 
-#: c/c-parser.c:14214 cp/parser.c:34010
+#: c/c-parser.c:14214 cp/parser.c:34007
 #, fuzzy, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "%<__thread%> samen met %s gebruikt"
 
-#: c/c-parser.c:14334 cp/parser.c:34132
+#: c/c-parser.c:14334 cp/parser.c:34129
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr ""
 
-#: c/c-parser.c:14472 cp/parser.c:36803
+#: c/c-parser.c:14472 cp/parser.c:36800
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14482 cp/parser.c:36813
+#: c/c-parser.c:14482 cp/parser.c:36810
 #, fuzzy, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr "de declaratie van %qs verbergt een parameter"
 
-#: c/c-parser.c:14502 cp/parser.c:36833
+#: c/c-parser.c:14502 cp/parser.c:36830
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr ""
 
-#: c/c-parser.c:14513 cp/parser.c:36844
+#: c/c-parser.c:14513 cp/parser.c:36841
 #, fuzzy, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr "lege declaratie"
 
-#: c/c-parser.c:14520 cp/parser.c:36851
+#: c/c-parser.c:14520 cp/parser.c:36848
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "de declaratie van %qs verbergt een globale declaratie"
 
-#: c/c-parser.c:14528 cp/parser.c:36859
+#: c/c-parser.c:14528 cp/parser.c:36856
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "ongeldige linker operand van %s"
 
-#: c/c-parser.c:14540 cp/parser.c:36871
+#: c/c-parser.c:14540 cp/parser.c:36868
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14632 cp/parser.c:36957
+#: c/c-parser.c:14632 cp/parser.c:36954
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:14648 cp/parser.c:36974
+#: c/c-parser.c:14648 cp/parser.c:36971
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr ""
@@ -37340,7 +37384,7 @@
 msgid "expected function name"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:14893 cp/parser.c:38064
+#: c/c-parser.c:14893 cp/parser.c:38061
 #, fuzzy, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr "%qs is meestal een functie"
@@ -37350,42 +37394,42 @@
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: c/c-parser.c:14953 cp/parser.c:38118 cp/parser.c:38160
+#: c/c-parser.c:14953 cp/parser.c:38115 cp/parser.c:38157
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: c/c-parser.c:14970 cp/parser.c:38174
+#: c/c-parser.c:14970 cp/parser.c:38171
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> already applied to %qD"
 msgstr ""
 
-#: c/c-parser.c:14979 cp/parser.c:38183
+#: c/c-parser.c:14979 cp/parser.c:38180
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr ""
 
-#: c/c-parser.c:14980 cp/parser.c:38184
+#: c/c-parser.c:14980 cp/parser.c:38181
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr ""
 
-#: c/c-parser.c:15023 cp/parser.c:37152
+#: c/c-parser.c:15023 cp/parser.c:37149
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
 
-#: c/c-parser.c:15435 cp/parser.c:34511 cp/parser.c:34537
+#: c/c-parser.c:15435 cp/parser.c:34508 cp/parser.c:34534
 #, fuzzy, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "ongeldige bewerking met %<__fpreg%>"
 
-#: c/c-parser.c:15439 cp/parser.c:34568 cp/parser.c:34584
+#: c/c-parser.c:15439 cp/parser.c:34565 cp/parser.c:34581
 #, fuzzy, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "ongeldige bewerking met %<__fpreg%>"
 
-#: c/c-parser.c:15488 cp/semantics.c:8401 cp/semantics.c:8411
+#: c/c-parser.c:15488 cp/semantics.c:8404 cp/semantics.c:8414
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
@@ -37395,22 +37439,22 @@
 msgid "expected %<(%> or end of line"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:15619 cp/parser.c:35103
+#: c/c-parser.c:15619 cp/parser.c:35100
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:15630 cp/parser.c:35114
+#: c/c-parser.c:15630 cp/parser.c:35111
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:15648 cp/parser.c:35141
+#: c/c-parser.c:15648 cp/parser.c:35138
 #, fuzzy, gcc-internal-format
 msgid "for statement expected"
 msgstr "overflow in constante expressie"
 
-#: c/c-parser.c:15718 cp/semantics.c:8066 cp/semantics.c:8153
+#: c/c-parser.c:15718 cp/semantics.c:8069 cp/semantics.c:8156
 #, fuzzy, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "herdeclaratie van %qs"
@@ -37420,73 +37464,73 @@
 msgid "not enough perfectly nested loops"
 msgstr ""
 
-#: c/c-parser.c:15862 cp/parser.c:35364
+#: c/c-parser.c:15862 cp/parser.c:35361
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.c:15909 cp/parser.c:35184 cp/parser.c:35226 cp/pt.c:16385
+#: c/c-parser.c:15909 cp/parser.c:35181 cp/parser.c:35223 cp/pt.c:16407
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: c/c-parser.c:16000 cp/parser.c:35437
+#: c/c-parser.c:16000 cp/parser.c:35434
 #, fuzzy, gcc-internal-format
 #| msgid "%<void%> as only parameter may not be qualified"
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "%<void%> als enige parameter mag niet gekwalificeerd worden"
 
-#: c/c-parser.c:16166 cp/parser.c:35600
+#: c/c-parser.c:16166 cp/parser.c:35597
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:16374 cp/parser.c:35799
+#: c/c-parser.c:16374 cp/parser.c:35796
 #, fuzzy, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:16573 cp/parser.c:35995
+#: c/c-parser.c:16573 cp/parser.c:35992
 #, fuzzy, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:16793 cp/parser.c:36232
+#: c/c-parser.c:16793 cp/parser.c:36229
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16806 cp/parser.c:36245
+#: c/c-parser.c:16806 cp/parser.c:36242
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16853 cp/parser.c:36470
+#: c/c-parser.c:16853 cp/parser.c:36467
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:16925 cp/parser.c:36325
+#: c/c-parser.c:16925 cp/parser.c:36322
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16937 cp/parser.c:36337
+#: c/c-parser.c:16937 cp/parser.c:36334
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17011 cp/parser.c:36414
+#: c/c-parser.c:17011 cp/parser.c:36411
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17024 cp/parser.c:36427
+#: c/c-parser.c:17024 cp/parser.c:36424
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17238 cp/parser.c:36680
+#: c/c-parser.c:17238 cp/parser.c:36677
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -37506,32 +37550,32 @@
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17395 cp/parser.c:37273
+#: c/c-parser.c:17395 cp/parser.c:37270
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17474 cp/parser.c:37343
+#: c/c-parser.c:17474 cp/parser.c:37340
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> with clauses in between %<#pragma omp declare target%> without clauses and %<#pragma omp end declare target%>"
 msgstr ""
 
-#: c/c-parser.c:17493 cp/parser.c:37362
+#: c/c-parser.c:17493 cp/parser.c:37359
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17534 cp/parser.c:37409
+#: c/c-parser.c:17534 cp/parser.c:37406
 #, fuzzy, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:17541 cp/parser.c:37416
+#: c/c-parser.c:17541 cp/parser.c:37413
 #, fuzzy, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:17547 cp/parser.c:37423
+#: c/c-parser.c:17547 cp/parser.c:37420
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr ""
@@ -37586,47 +37630,47 @@
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:17947 cp/parser.c:37868
+#: c/c-parser.c:17947 cp/parser.c:37865
 #, gcc-internal-format
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr ""
 
-#: c/c-parser.c:18162 cp/semantics.c:7531
+#: c/c-parser.c:18162 cp/semantics.c:7534
 #, fuzzy, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "label %qs gebruikt maar niet gedefinieerd"
 
-#: c/c-parser.c:18164 cp/semantics.c:7533
+#: c/c-parser.c:18164 cp/semantics.c:7536
 #, fuzzy, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: c/c-parser.c:18168 cp/semantics.c:7535
+#: c/c-parser.c:18168 cp/semantics.c:7538
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%Jparameter %u heeft een onvolledig type"
 
-#: c/c-parser.c:18368 cp/parser.c:38565
+#: c/c-parser.c:18368 cp/parser.c:38562
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:18374 cp/parser.c:38571
+#: c/c-parser.c:18374 cp/parser.c:38568
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
 
-#: c/c-parser.c:18383 cp/parser.c:38580
+#: c/c-parser.c:18383 cp/parser.c:38577
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.c:18385 cp/parser.c:38583
+#: c/c-parser.c:18385 cp/parser.c:38580
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.c:18391 cp/parser.c:38589
+#: c/c-parser.c:18391 cp/parser.c:38586
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
@@ -37641,7 +37685,7 @@
 msgid "%qD has an incomplete type %qT"
 msgstr "%qs heeft een onvolledig type"
 
-#: c/c-typeck.c:237 c/c-typeck.c:9994 c/c-typeck.c:10036 cp/call.c:4147
+#: c/c-typeck.c:237 c/c-typeck.c:9999 c/c-typeck.c:10041 cp/call.c:4147
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "ongeldig gebruik van een void-expressie"
@@ -37717,12 +37761,12 @@
 msgid "converting an array compound literal to a pointer is ill-formed in C++"
 msgstr ""
 
-#: c/c-typeck.c:2417 c/c-typeck.c:8641
+#: c/c-typeck.c:2417 c/c-typeck.c:8646
 #, fuzzy, gcc-internal-format
 msgid "%qT has no member named %qE; did you mean %qE?"
 msgstr "union heeft geen lid dat %qs heet"
 
-#: c/c-typeck.c:2421 c/c-typeck.c:8645
+#: c/c-typeck.c:2421 c/c-typeck.c:8650
 #, fuzzy, gcc-internal-format
 msgid "%qT has no member named %qE"
 msgstr "union heeft geen lid dat %qs heet"
@@ -37923,477 +37967,477 @@
 msgstr "pointer naar functie gebruikt in aftrekking"
 
 # 'Arithmetic'?? 'rekensom' is wel correct, maar het klinkt zo stom.
-#: c/c-typeck.c:3847
+#: c/c-typeck.c:3852
 #, gcc-internal-format
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "rekensom met pointer naar onvolledig type"
 
 # 'Arithmetic'?? 'rekensom' is wel correct, maar het klinkt zo stom.
-#: c/c-typeck.c:3852 cp/typeck.c:5562
+#: c/c-typeck.c:3857 cp/typeck.c:5562
 #, fuzzy, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr "rekensom met pointer naar onvolledig type"
 
-#: c/c-typeck.c:4283
+#: c/c-typeck.c:4288
 #, fuzzy, gcc-internal-format
 msgid "%<~%> on a boolean expression"
 msgstr "ongeldige waarheidsexpressie"
 
-#: c/c-typeck.c:4287
+#: c/c-typeck.c:4292
 #, gcc-internal-format
 msgid "did you mean to use logical not?"
 msgstr ""
 
-#: c/c-typeck.c:4296
+#: c/c-typeck.c:4301
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support %<~%> for complex conjugation"
 msgstr "ISO C ondersteunt het %<%c%> formaat niet"
 
-#: c/c-typeck.c:4335
+#: c/c-typeck.c:4340
 #, gcc-internal-format
 msgid "wrong type argument to unary exclamation mark"
 msgstr "argument van verkeerd type voor unair uitroepingsteken"
 
-#: c/c-typeck.c:4393
+#: c/c-typeck.c:4398
 #, gcc-internal-format
 msgid "increment of enumeration value is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:4396
+#: c/c-typeck.c:4401
 #, gcc-internal-format
 msgid "decrement of enumeration value is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:4403
+#: c/c-typeck.c:4408
 #, fuzzy, gcc-internal-format
 msgid "increment of a boolean expression"
 msgstr "ongeldige waarheidsexpressie"
 
-#: c/c-typeck.c:4406
+#: c/c-typeck.c:4411
 #, fuzzy, gcc-internal-format
 msgid "decrement of a boolean expression"
 msgstr "ongeldige waarheidsexpressie"
 
-#: c/c-typeck.c:4422
+#: c/c-typeck.c:4427
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support %<++%> and %<--%> on complex types"
 msgstr "ISO C ondersteunt het %<%c%> formaat niet"
 
 # Wat is beter: 'incrementeren', 'incrementering', of 'increment'?
-#: c/c-typeck.c:4447 c/c-typeck.c:4481
+#: c/c-typeck.c:4452 c/c-typeck.c:4486
 #, gcc-internal-format
 msgid "wrong type argument to increment"
 msgstr "argument van verkeerd type voor incrementeren"
 
-#: c/c-typeck.c:4449 c/c-typeck.c:4484
+#: c/c-typeck.c:4454 c/c-typeck.c:4489
 #, gcc-internal-format
 msgid "wrong type argument to decrement"
 msgstr "argument van verkeerd type voor decrementeren"
 
-#: c/c-typeck.c:4469
+#: c/c-typeck.c:4474
 #, fuzzy, gcc-internal-format
 msgid "increment of pointer to an incomplete type %qT"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: c/c-typeck.c:4473
+#: c/c-typeck.c:4478
 #, fuzzy, gcc-internal-format
 msgid "decrement of pointer to an incomplete type %qT"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: c/c-typeck.c:4577
+#: c/c-typeck.c:4582
 #, gcc-internal-format
 msgid "taking address of expression of type %<void%>"
 msgstr ""
 
-#: c/c-typeck.c:4636
+#: c/c-typeck.c:4641
 #, fuzzy, gcc-internal-format
 msgid "cannot take address of bit-field %qD"
 msgstr "kan adres van bitveld %qs niet nemen"
 
-#: c/c-typeck.c:4649
+#: c/c-typeck.c:4654
 #, fuzzy, gcc-internal-format
 msgid "cannot take address of scalar with reverse storage order"
 msgstr "kan adres van bitveld %qs niet nemen"
 
-#: c/c-typeck.c:4657
+#: c/c-typeck.c:4662
 #, fuzzy, gcc-internal-format
 msgid "address of array with reverse scalar storage order requested"
 msgstr "adres van registervariabele %qs gevraagd"
 
-#: c/c-typeck.c:4838
+#: c/c-typeck.c:4843
 #, fuzzy, gcc-internal-format
 msgid "global register variable %qD used in nested function"
 msgstr "globale registervariabele %qs gebruikt in geneste functie"
 
-#: c/c-typeck.c:4841
+#: c/c-typeck.c:4846
 #, fuzzy, gcc-internal-format
 msgid "register variable %qD used in nested function"
 msgstr "registervariabele %qs gebruikt in geneste functie"
 
-#: c/c-typeck.c:4846
+#: c/c-typeck.c:4851
 #, fuzzy, gcc-internal-format
 msgid "address of global register variable %qD requested"
 msgstr "adres van globale registervariabele %qs gevraagd"
 
-#: c/c-typeck.c:4848
+#: c/c-typeck.c:4853
 #, fuzzy, gcc-internal-format
 msgid "address of register variable %qD requested"
 msgstr "adres van registervariabele %qs gevraagd"
 
-#: c/c-typeck.c:4951
+#: c/c-typeck.c:4956
 #, fuzzy, gcc-internal-format
 msgid "non-lvalue array in conditional expression"
 msgstr "types in voorwaardelijke expressie komen niet overeen"
 
-#: c/c-typeck.c:5033
+#: c/c-typeck.c:5038
 #, fuzzy, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other result of conditional"
 msgstr "ongeldige registernaam voor %qs"
 
-#: c/c-typeck.c:5092 c/c-typeck.c:5098
+#: c/c-typeck.c:5097 c/c-typeck.c:5103
 #, gcc-internal-format
 msgid "operand of ?: changes signedness from %qT to %qT due to unsignedness of other operand"
 msgstr ""
 
-#: c/c-typeck.c:5115
+#: c/c-typeck.c:5120
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids conditional expr with only one void side"
 msgstr "ISO C verbiedt voorwaardelijke expressies met maar één void-zijde"
 
-#: c/c-typeck.c:5132
+#: c/c-typeck.c:5137
 #, fuzzy, gcc-internal-format
 msgid "pointers to disjoint address spaces used in conditional expression"
 msgstr "pointertypes in voorwaardelijke expressie komen niet overeen"
 
-#: c/c-typeck.c:5143 c/c-typeck.c:5160
+#: c/c-typeck.c:5148 c/c-typeck.c:5165
 #, fuzzy, gcc-internal-format
 #| msgid "pointer type mismatch in conditional expression"
 msgid "pointer to array loses qualifier in conditional expression"
 msgstr "pointertypes in voorwaardelijke expressie komen niet overeen"
 
-#: c/c-typeck.c:5148 c/c-typeck.c:5165
+#: c/c-typeck.c:5153 c/c-typeck.c:5170
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids conditional expr between %<void *%> and function pointer"
 msgstr "ISO C verbiedt voorwaardelijke expressies tussen %<void *%> en een functiepointer"
 
-#: c/c-typeck.c:5178
+#: c/c-typeck.c:5183
 #, gcc-internal-format
 msgid "pointer type mismatch in conditional expression"
 msgstr "pointertypes in voorwaardelijke expressie komen niet overeen"
 
-#: c/c-typeck.c:5187 c/c-typeck.c:5198
+#: c/c-typeck.c:5192 c/c-typeck.c:5203
 #, gcc-internal-format
 msgid "pointer/integer type mismatch in conditional expression"
 msgstr "types in voorwaardelijke expressie komen niet overeen (pointer/integer)"
 
-#: c/c-typeck.c:5336
+#: c/c-typeck.c:5341
 #, gcc-internal-format
 msgid "left-hand operand of comma expression has no effect"
 msgstr "linker operand van comma-expressie heeft geen effect"
 
-#: c/c-typeck.c:5354 c/c-typeck.c:10636
+#: c/c-typeck.c:5359 c/c-typeck.c:10641
 #, fuzzy, gcc-internal-format
 msgid "right-hand operand of comma expression has no effect"
 msgstr "linker operand van comma-expressie heeft geen effect"
 
-#: c/c-typeck.c:5423
+#: c/c-typeck.c:5428
 #, fuzzy
 msgid "cast adds %q#v qualifier to function type"
 msgstr "cast geeft functie-type op"
 
-#: c/c-typeck.c:5429
+#: c/c-typeck.c:5434
 #, fuzzy
 msgid "cast discards %qv qualifier from pointer target type"
 msgstr "cast laat qualifiers van doeltype van pointer vallen"
 
-#: c/c-typeck.c:5464
+#: c/c-typeck.c:5469
 #, gcc-internal-format
 msgid "to be safe all intermediate pointers in cast from %qT to %qT must be %<const%> qualified"
 msgstr ""
 
-#: c/c-typeck.c:5554
+#: c/c-typeck.c:5559
 #, gcc-internal-format
 msgid "cast specifies array type"
 msgstr "cast geeft array-type op"
 
-#: c/c-typeck.c:5560
+#: c/c-typeck.c:5565
 #, gcc-internal-format
 msgid "cast specifies function type"
 msgstr "cast geeft functie-type op"
 
-#: c/c-typeck.c:5575
+#: c/c-typeck.c:5580
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids casting nonscalar to the same type"
 msgstr "ISO C verbiedt het casten van een niet-scalair naar hetzelfde type"
 
-#: c/c-typeck.c:5595
+#: c/c-typeck.c:5600
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids casts to union type"
 msgstr "ISO C verbiedt casts naar een union-type"
 
-#: c/c-typeck.c:5605
+#: c/c-typeck.c:5610
 #, gcc-internal-format
 msgid "cast to union type from type not present in union"
 msgstr "cast naar union-type van een type dat geen deel uitmaakt van de union"
 
-#: c/c-typeck.c:5640
+#: c/c-typeck.c:5645
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint generic address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5645
+#: c/c-typeck.c:5650
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to generic address space pointer from disjoint %s address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5650
+#: c/c-typeck.c:5655
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint %s address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5670
+#: c/c-typeck.c:5675
 #, gcc-internal-format
 msgid "cast increases required alignment of target type"
 msgstr "cast verhoogt het benodigde alignment van het doeltype"
 
-#: c/c-typeck.c:5681
+#: c/c-typeck.c:5686
 #, gcc-internal-format
 msgid "cast from pointer to integer of different size"
 msgstr "cast van pointer naar integer met andere grootte"
 
-#: c/c-typeck.c:5686
+#: c/c-typeck.c:5691
 #, gcc-internal-format
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr ""
 
-#: c/c-typeck.c:5695 cp/typeck.c:7811
+#: c/c-typeck.c:5700 cp/typeck.c:7811
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "cast naar pointer van integer met andere grootte"
 
-#: c/c-typeck.c:5709
+#: c/c-typeck.c:5714
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids conversion of function pointer to object pointer type"
 msgstr "ISO C verbiedt een vergelijking van %<void *%> met een functie-pointer"
 
-#: c/c-typeck.c:5718
+#: c/c-typeck.c:5723
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids conversion of object pointer to function pointer type"
 msgstr "ISO C verbiedt een vergelijking van %<void *%> met een functie-pointer"
 
-#: c/c-typeck.c:5728
+#: c/c-typeck.c:5733
 #, fuzzy, gcc-internal-format
 msgid "cast between incompatible function types from %qT to %qT"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: c/c-typeck.c:5815
+#: c/c-typeck.c:5820
 #, gcc-internal-format
 msgid "defining a type in a cast is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:5856
+#: c/c-typeck.c:5861
 #, fuzzy, gcc-internal-format
 msgid "assignment to expression with array type"
 msgstr "toewijzingsonderdrukking"
 
-#: c/c-typeck.c:5982
+#: c/c-typeck.c:5987
 #, gcc-internal-format
 msgid "enum conversion in assignment is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:6180 c/c-typeck.c:6202 c/c-typeck.c:6226
+#: c/c-typeck.c:6185 c/c-typeck.c:6207 c/c-typeck.c:6231
 #, fuzzy, gcc-internal-format
 msgid "(near initialization for %qs)"
 msgstr "(dicht bij initialisatie van %qs)"
 
 # moet beter kunnen - "... waar haakjes rond staan" klinkt ook al niet geweldig
-#: c/c-typeck.c:6241
+#: c/c-typeck.c:6246
 #, gcc-internal-format
 msgid "array initialized from parenthesized string constant"
 msgstr "array heeft stringconstante tussen haakjes als beginwaarde"
 
-#: c/c-typeck.c:6284 c/c-typeck.c:6476 c/c-typeck.c:6908
+#: c/c-typeck.c:6289 c/c-typeck.c:6481 c/c-typeck.c:6913
 #, fuzzy, gcc-internal-format
 msgid "expected %qT but argument is of type %qT"
 msgstr "eerste argument van %qs zou een %<int%> moeten zijn"
 
-#: c/c-typeck.c:6471
+#: c/c-typeck.c:6476
 #, fuzzy, gcc-internal-format
 msgid "enum conversion when passing argument %d of %qE is invalid in C++"
 msgstr "doelen van pointer in %s verschillen in signedness"
 
-#: c/c-typeck.c:6480
+#: c/c-typeck.c:6485
 #, fuzzy, gcc-internal-format
 msgid "enum conversion from %qT to %qT in assignment is invalid in C++"
 msgstr "doelen van pointer in %s verschillen in signedness"
 
-#: c/c-typeck.c:6484
+#: c/c-typeck.c:6489
 #, fuzzy, gcc-internal-format
 msgid "enum conversion from %qT to %qT in initialization is invalid in C++"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: c/c-typeck.c:6489
+#: c/c-typeck.c:6494
 #, fuzzy, gcc-internal-format
 msgid "enum conversion from %qT to %qT in return is invalid in C++"
 msgstr "doelen van pointer in %s verschillen in signedness"
 
-#: c/c-typeck.c:6523
+#: c/c-typeck.c:6528
 #, gcc-internal-format
 msgid "cannot pass rvalue to reference parameter"
 msgstr ""
 
-#: c/c-typeck.c:6656 c/c-typeck.c:6942
+#: c/c-typeck.c:6661 c/c-typeck.c:6947
 #, fuzzy
 msgid "passing argument %d of %qE makes %q#v qualified function pointer from unqualified"
 msgstr "%s maakt gekwalificeerde functiepointer van een niet gekwalificeerde"
 
-#: c/c-typeck.c:6659 c/c-typeck.c:6945
+#: c/c-typeck.c:6664 c/c-typeck.c:6950
 #, fuzzy
 msgid "assignment makes %q#v qualified function pointer from unqualified"
 msgstr "%s maakt gekwalificeerde functiepointer van een niet gekwalificeerde"
 
-#: c/c-typeck.c:6662 c/c-typeck.c:6947
+#: c/c-typeck.c:6667 c/c-typeck.c:6952
 #, fuzzy
 msgid "initialization makes %q#v qualified function pointer from unqualified"
 msgstr "%s maakt gekwalificeerde functiepointer van een niet gekwalificeerde"
 
-#: c/c-typeck.c:6665 c/c-typeck.c:6949
+#: c/c-typeck.c:6670 c/c-typeck.c:6954
 #, fuzzy
 msgid "return makes %q#v qualified function pointer from unqualified"
 msgstr "%s maakt gekwalificeerde functiepointer van een niet gekwalificeerde"
 
-#: c/c-typeck.c:6673 c/c-typeck.c:6840 c/c-typeck.c:6883
+#: c/c-typeck.c:6678 c/c-typeck.c:6845 c/c-typeck.c:6888
 #, fuzzy
 msgid "passing argument %d of %qE discards %qv qualifier from pointer target type"
 msgstr "cast laat qualifiers van doeltype van pointer vallen"
 
-#: c/c-typeck.c:6675 c/c-typeck.c:6842 c/c-typeck.c:6885
+#: c/c-typeck.c:6680 c/c-typeck.c:6847 c/c-typeck.c:6890
 #, fuzzy
 msgid "assignment discards %qv qualifier from pointer target type"
 msgstr "cast laat qualifiers van doeltype van pointer vallen"
 
-#: c/c-typeck.c:6677 c/c-typeck.c:6844 c/c-typeck.c:6887
+#: c/c-typeck.c:6682 c/c-typeck.c:6849 c/c-typeck.c:6892
 #, fuzzy
 msgid "initialization discards %qv qualifier from pointer target type"
 msgstr "cast laat qualifiers van doeltype van pointer vallen"
 
-#: c/c-typeck.c:6679 c/c-typeck.c:6846 c/c-typeck.c:6889
+#: c/c-typeck.c:6684 c/c-typeck.c:6851 c/c-typeck.c:6894
 #, fuzzy
 msgid "return discards %qv qualifier from pointer target type"
 msgstr "cast laat qualifiers van doeltype van pointer vallen"
 
-#: c/c-typeck.c:6688
+#: c/c-typeck.c:6693
 #, fuzzy, gcc-internal-format
 msgid "ISO C prohibits argument conversion to union type"
 msgstr "ISO C verbiedt conversie van argumenten naar union type"
 
-#: c/c-typeck.c:6750
+#: c/c-typeck.c:6755
 #, fuzzy, gcc-internal-format
 msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgstr "ongeldige registernaam voor %qs"
 
-#: c/c-typeck.c:6762
+#: c/c-typeck.c:6767
 #, gcc-internal-format
 msgid "passing argument %d of %qE from pointer to non-enclosed address space"
 msgstr ""
 
-#: c/c-typeck.c:6766
+#: c/c-typeck.c:6771
 #, fuzzy, gcc-internal-format
 msgid "assignment from pointer to non-enclosed address space"
 msgstr "cast van pointer naar integer met andere grootte"
 
-#: c/c-typeck.c:6770
+#: c/c-typeck.c:6775
 #, gcc-internal-format
 msgid "initialization from pointer to non-enclosed address space"
 msgstr ""
 
-#: c/c-typeck.c:6774
+#: c/c-typeck.c:6779
 #, gcc-internal-format
 msgid "return from pointer to non-enclosed address space"
 msgstr ""
 
-#: c/c-typeck.c:6792
+#: c/c-typeck.c:6797
 #, gcc-internal-format
 msgid "argument %d of %qE might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:6798
+#: c/c-typeck.c:6803
 #, gcc-internal-format
 msgid "assignment left-hand side might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:6803
+#: c/c-typeck.c:6808
 #, gcc-internal-format
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:6808 cp/typeck.c:8891
+#: c/c-typeck.c:6813 cp/typeck.c:8891
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:6857
+#: c/c-typeck.c:6862
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids passing argument %d of %qE between function pointer and %<void *%>"
 msgstr "ISO C verbiedt %s tussen functiepointer en %<void *%>"
 
-#: c/c-typeck.c:6860
+#: c/c-typeck.c:6865
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids assignment between function pointer and %<void *%>"
 msgstr "ISO C verbiedt %s tussen functiepointer en %<void *%>"
 
-#: c/c-typeck.c:6862
+#: c/c-typeck.c:6867
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids initialization between function pointer and %<void *%>"
 msgstr "ISO C verbiedt %s tussen functiepointer en %<void *%>"
 
-#: c/c-typeck.c:6864
+#: c/c-typeck.c:6869
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids return between function pointer and %<void *%>"
 msgstr "ISO C verbiedt %s tussen functiepointer en %<void *%>"
 
 # 'signedness' = 'signed-heid'?
-#: c/c-typeck.c:6904
+#: c/c-typeck.c:6909
 #, fuzzy, gcc-internal-format
 msgid "pointer targets in passing argument %d of %qE differ in signedness"
 msgstr "doelen van pointer in %s verschillen in signedness"
 
 # 'signedness' = 'signed-heid'?
-#: c/c-typeck.c:6913
+#: c/c-typeck.c:6918
 #, fuzzy, gcc-internal-format
 msgid "pointer targets in assignment from %qT to %qT differ in signedness"
 msgstr "doelen van pointer in %s verschillen in signedness"
 
 # 'signedness' = 'signed-heid'?
-#: c/c-typeck.c:6918
+#: c/c-typeck.c:6923
 #, fuzzy, gcc-internal-format
 msgid "pointer targets in initialization of %qT from %qT differ in signedness"
 msgstr "doelen van pointer in %s verschillen in signedness"
 
 # 'signedness' = 'signed-heid'?
-#: c/c-typeck.c:6923
+#: c/c-typeck.c:6928
 #, fuzzy, gcc-internal-format
 msgid "pointer targets in returning %qT from a function with return type %qT differ in signedness"
 msgstr "doelen van pointer in %s verschillen in signedness"
 
-#: c/c-typeck.c:6961
+#: c/c-typeck.c:6966
 #, gcc-internal-format
 msgid "passing argument %d of %qE from incompatible pointer type"
 msgstr ""
 
-#: c/c-typeck.c:6967
+#: c/c-typeck.c:6972
 #, fuzzy, gcc-internal-format
 #| msgid "assignment from incompatible pointer type"
 msgid "assignment to %qT from incompatible pointer type %qT"
 msgstr "toewijzing vanuit incompatibel pointertype"
 
-#: c/c-typeck.c:6972
+#: c/c-typeck.c:6977
 #, fuzzy, gcc-internal-format
 #| msgid "initialization from incompatible pointer type"
 msgid "initialization of %qT from incompatible pointer type %qT"
 msgstr "initialisatie vanuit incompatibel pointertype"
 
-#: c/c-typeck.c:6977
+#: c/c-typeck.c:6982
 #, fuzzy, gcc-internal-format
 msgid "returning %qT from a function with incompatible return type %qT"
 msgstr "%<return%> met waarde in een functie die void teruggeeft"
@@ -38400,788 +38444,788 @@
 
 #. ??? This should not be an error when inlining calls to
 #. unprototyped functions.
-#: c/c-typeck.c:6991 c/c-typeck.c:7514 cp/typeck.c:2063
+#: c/c-typeck.c:6996 c/c-typeck.c:7519 cp/typeck.c:2063
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "ongeldig gebruik van array die geen lvalue is"
 
-#: c/c-typeck.c:7004
+#: c/c-typeck.c:7009
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE makes pointer from integer without a cast"
 msgstr "%s maakt pointer van integer zonder een cast"
 
-#: c/c-typeck.c:7010
+#: c/c-typeck.c:7015
 #, fuzzy, gcc-internal-format
 msgid "assignment to %qT from %qT makes pointer from integer without a cast"
 msgstr "%s maakt pointer van integer zonder een cast"
 
-#: c/c-typeck.c:7015
+#: c/c-typeck.c:7020
 #, fuzzy, gcc-internal-format
 msgid "initialization of %qT from %qT makes pointer from integer without a cast"
 msgstr "%s maakt pointer van integer zonder een cast"
 
-#: c/c-typeck.c:7019
+#: c/c-typeck.c:7024
 #, fuzzy, gcc-internal-format
 msgid "returning %qT from a function with return type %qT makes pointer from integer without a cast"
 msgstr "%s maakt pointer van integer zonder een cast"
 
-#: c/c-typeck.c:7035
+#: c/c-typeck.c:7040
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE makes integer from pointer without a cast"
 msgstr "%s maakt integer van pointer zonder een cast"
 
-#: c/c-typeck.c:7041
+#: c/c-typeck.c:7046
 #, fuzzy, gcc-internal-format
 msgid "assignment to %qT from %qT makes integer from pointer without a cast"
 msgstr "%s maakt integer van pointer zonder een cast"
 
-#: c/c-typeck.c:7046
+#: c/c-typeck.c:7051
 #, fuzzy, gcc-internal-format
 msgid "initialization of %qT from %qT makes integer from pointer without a cast"
 msgstr "%s maakt integer van pointer zonder een cast"
 
-#: c/c-typeck.c:7050
+#: c/c-typeck.c:7055
 #, fuzzy, gcc-internal-format
 msgid "returning %qT from a function with return type %qT makes integer from pointer without a cast"
 msgstr "%s maakt integer van pointer zonder een cast"
 
-#: c/c-typeck.c:7073
+#: c/c-typeck.c:7078
 #, gcc-internal-format
 msgid "incompatible type for argument %d of %qE"
 msgstr "incompatibel type voor argument %d van %qE"
 
-#: c/c-typeck.c:7078
+#: c/c-typeck.c:7083
 #, gcc-internal-format
 msgid "incompatible types when assigning to type %qT from type %qT"
 msgstr ""
 
-#: c/c-typeck.c:7083
+#: c/c-typeck.c:7088
 #, gcc-internal-format
 msgid "incompatible types when initializing type %qT using type %qT"
 msgstr ""
 
-#: c/c-typeck.c:7088
+#: c/c-typeck.c:7093
 #, gcc-internal-format
 msgid "incompatible types when returning type %qT but %qT was expected"
 msgstr ""
 
-#: c/c-typeck.c:7152
+#: c/c-typeck.c:7157
 #, gcc-internal-format
 msgid "traditional C rejects automatic aggregate initialization"
 msgstr ""
 
-#: c/c-typeck.c:7388 c/c-typeck.c:8284 cp/typeck2.c:1045
+#: c/c-typeck.c:7393 c/c-typeck.c:8289 cp/typeck2.c:1045
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "initialisatie van flexibel array-lid"
 
-#: c/c-typeck.c:7398 cp/typeck2.c:1059
+#: c/c-typeck.c:7403 cp/typeck2.c:1059
 #, gcc-internal-format
 msgid "char-array initialized from wide string"
 msgstr "char-array heeft wide string als beginwaarde"
 
-#: c/c-typeck.c:7407
+#: c/c-typeck.c:7412
 #, fuzzy, gcc-internal-format
 msgid "wide character array initialized from non-wide string"
 msgstr "wchar_t-array heeft geen wide string als beginwaarde"
 
-#: c/c-typeck.c:7413
+#: c/c-typeck.c:7418
 #, fuzzy, gcc-internal-format
 msgid "wide character array initialized from incompatible wide string"
 msgstr "wchar_t-array heeft geen wide string als beginwaarde"
 
-#: c/c-typeck.c:7446
+#: c/c-typeck.c:7451
 #, gcc-internal-format
 msgid "array of inappropriate type initialized from string constant"
 msgstr "array van ongeschikt type heeft stringconstante als beginwaarde"
 
-#: c/c-typeck.c:7533 c/c-typeck.c:7557 c/c-typeck.c:7560 c/c-typeck.c:7568
-#: c/c-typeck.c:7608 c/c-typeck.c:9131 c/c-typeck.c:9181
+#: c/c-typeck.c:7538 c/c-typeck.c:7562 c/c-typeck.c:7565 c/c-typeck.c:7573
+#: c/c-typeck.c:7613 c/c-typeck.c:9136 c/c-typeck.c:9186
 #, gcc-internal-format
 msgid "initializer element is not constant"
 msgstr "beginwaarde-element is niet constant"
 
-#: c/c-typeck.c:7542
+#: c/c-typeck.c:7547
 #, gcc-internal-format
 msgid "array initialized from non-constant array expression"
 msgstr "array krijgt niet-constante array-expressie als beginwaarde"
 
-#: c/c-typeck.c:7573 c/c-typeck.c:7621 c/c-typeck.c:9191
+#: c/c-typeck.c:7578 c/c-typeck.c:7626 c/c-typeck.c:9196
 #, fuzzy, gcc-internal-format
 msgid "initializer element is not a constant expression"
 msgstr "beginwaarde-element is niet constant"
 
-#: c/c-typeck.c:7615 c/c-typeck.c:9186
+#: c/c-typeck.c:7620 c/c-typeck.c:9191
 #, gcc-internal-format
 msgid "initializer element is not computable at load time"
 msgstr "beginwaarde-element kan niet berekend worden tijdens het laden"
 
-#: c/c-typeck.c:7634
+#: c/c-typeck.c:7639
 #, gcc-internal-format
 msgid "invalid initializer"
 msgstr "ongeldige beginwaarde"
 
-#: c/c-typeck.c:7912 cp/decl.c:6396
+#: c/c-typeck.c:7917 cp/decl.c:6396
 #, fuzzy, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: c/c-typeck.c:8132
+#: c/c-typeck.c:8137
 #, gcc-internal-format
 msgid "extra brace group at end of initializer"
 msgstr "extra accolade-groep aan einde van beginwaarde"
 
-#: c/c-typeck.c:8215
+#: c/c-typeck.c:8220
 #, gcc-internal-format
 msgid "braces around scalar initializer"
 msgstr "accolades rond scalaire beginwaarde"
 
-#: c/c-typeck.c:8281 c/c-typeck.c:9615 cp/typeck2.c:1084 cp/typeck2.c:1297
+#: c/c-typeck.c:8286 c/c-typeck.c:9620 cp/typeck2.c:1084 cp/typeck2.c:1297
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "initialisatie van flexibel array-lid in een geneste context"
 
-#: c/c-typeck.c:8318
+#: c/c-typeck.c:8323
 #, gcc-internal-format
 msgid "missing braces around initializer"
 msgstr "accolades ontbreken rond beginwaarde"
 
-#: c/c-typeck.c:8341
+#: c/c-typeck.c:8346
 #, fuzzy, gcc-internal-format
 msgid "missing initializer for field %qD of %qT"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: c/c-typeck.c:8365
+#: c/c-typeck.c:8370
 #, gcc-internal-format
 msgid "empty scalar initializer"
 msgstr "lege scalaire beginwaarde"
 
-#: c/c-typeck.c:8370
+#: c/c-typeck.c:8375
 #, gcc-internal-format
 msgid "extra elements in scalar initializer"
 msgstr "extra elementen in scalaire beginwaarde"
 
-#: c/c-typeck.c:8483 c/c-typeck.c:8565
+#: c/c-typeck.c:8488 c/c-typeck.c:8570
 #, gcc-internal-format
 msgid "array index in non-array initializer"
 msgstr "array-index in beginwaarde van niet-array"
 
 # of gewoon "veldnaam niet in beginwaarde van record of union"?
-#: c/c-typeck.c:8488 c/c-typeck.c:8627
+#: c/c-typeck.c:8493 c/c-typeck.c:8632
 #, gcc-internal-format
 msgid "field name not in record or union initializer"
 msgstr "veldnaam in beginwaarde van iets anders dan record of union"
 
-#: c/c-typeck.c:8538
+#: c/c-typeck.c:8543
 #, gcc-internal-format
 msgid "array index in initializer not of integer type"
 msgstr "array-index in beginwaarde is niet van een integer type"
 
-#: c/c-typeck.c:8547 c/c-typeck.c:8556
+#: c/c-typeck.c:8552 c/c-typeck.c:8561
 #, fuzzy, gcc-internal-format
 msgid "array index in initializer is not an integer constant expression"
 msgstr "array-index in beginwaarde is niet van een integer type"
 
-#: c/c-typeck.c:8561 c/c-typeck.c:8563
+#: c/c-typeck.c:8566 c/c-typeck.c:8568
 #, gcc-internal-format
 msgid "nonconstant array index in initializer"
 msgstr "niet-constante array-index in beginwaarde"
 
-#: c/c-typeck.c:8567 c/c-typeck.c:8570
+#: c/c-typeck.c:8572 c/c-typeck.c:8575
 #, gcc-internal-format
 msgid "array index in initializer exceeds array bounds"
 msgstr "array-index in beginwaarde overschrijdt de grenzen van de array"
 
-#: c/c-typeck.c:8589
+#: c/c-typeck.c:8594
 #, gcc-internal-format
 msgid "empty index range in initializer"
 msgstr "leeg indexbereik in beginwaarde"
 
-#: c/c-typeck.c:8598
+#: c/c-typeck.c:8603
 #, gcc-internal-format
 msgid "array index range in initializer exceeds array bounds"
 msgstr "array-indexbereik in beginwaarde overschrijdt de grenzen van de array"
 
-#: c/c-typeck.c:8700 c/c-typeck.c:8730 c/c-typeck.c:9274
+#: c/c-typeck.c:8705 c/c-typeck.c:8735 c/c-typeck.c:9279
 #, gcc-internal-format
 msgid "initialized field with side-effects overwritten"
 msgstr "geïnitialiseerd veld met neveneffecten wordt overschreven"
 
-#: c/c-typeck.c:8704 c/c-typeck.c:8734 c/c-typeck.c:9277
+#: c/c-typeck.c:8709 c/c-typeck.c:8739 c/c-typeck.c:9282
 #, gcc-internal-format
 msgid "initialized field overwritten"
 msgstr "geïnitialiseerd veld wordt overschreven"
 
-#: c/c-typeck.c:9208
+#: c/c-typeck.c:9213
 #, gcc-internal-format
 msgid "enum conversion in initialization is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:9496
+#: c/c-typeck.c:9501
 #, gcc-internal-format
 msgid "excess elements in char array initializer"
 msgstr "overtollige elementen in beginwaarde van char array"
 
-#: c/c-typeck.c:9503 c/c-typeck.c:9574
+#: c/c-typeck.c:9508 c/c-typeck.c:9579
 #, gcc-internal-format
 msgid "excess elements in struct initializer"
 msgstr "overtollige elementen in beginwaarde van struct"
 
-#: c/c-typeck.c:9518
+#: c/c-typeck.c:9523
 #, gcc-internal-format
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr ""
 
-#: c/c-typeck.c:9589
+#: c/c-typeck.c:9594
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr "niet-statische initialisatie van flexibel array-lid"
 
-#: c/c-typeck.c:9687
+#: c/c-typeck.c:9692
 #, gcc-internal-format
 msgid "excess elements in union initializer"
 msgstr "overtollige elementen in beginwaarde van union"
 
-#: c/c-typeck.c:9709
+#: c/c-typeck.c:9714
 #, gcc-internal-format
 msgid "traditional C rejects initialization of unions"
 msgstr ""
 
-#: c/c-typeck.c:9777
+#: c/c-typeck.c:9782
 #, gcc-internal-format
 msgid "excess elements in array initializer"
 msgstr "overtollige elementen in beginwaarde van array"
 
-#: c/c-typeck.c:9811
+#: c/c-typeck.c:9816
 #, gcc-internal-format
 msgid "excess elements in vector initializer"
 msgstr "overtollige elementen in beginwaarde van vector"
 
-#: c/c-typeck.c:9843
+#: c/c-typeck.c:9848
 #, gcc-internal-format
 msgid "excess elements in scalar initializer"
 msgstr "overtollige elementen in beginwaarde van scalair"
 
-#: c/c-typeck.c:10086
+#: c/c-typeck.c:10091
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C verbiedt %<goto *expr;%>"
 
-#: c/c-typeck.c:10113 c/gimple-parser.c:1604 cp/typeck.c:9113
+#: c/c-typeck.c:10118 c/gimple-parser.c:1604 cp/typeck.c:9113
 #, fuzzy, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "als %<noreturn%> gedeclareerde functie bevat een %<return%> statement"
 
-#: c/c-typeck.c:10139 c/c-typeck.c:10143
+#: c/c-typeck.c:10144 c/c-typeck.c:10148
 #, fuzzy, gcc-internal-format
 msgid "%<return%> with no value, in function returning non-void"
 msgstr "%<return%> zonder waarde in een functie die een niet-void waarde teruggeeft"
 
-#: c/c-typeck.c:10157 c/gimple-parser.c:1614
+#: c/c-typeck.c:10162 c/gimple-parser.c:1614
 #, fuzzy, gcc-internal-format
 msgid "%<return%> with a value, in function returning void"
 msgstr "%<return%> met waarde in een functie die void teruggeeft"
 
-#: c/c-typeck.c:10160
+#: c/c-typeck.c:10165
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids %<return%> with expression, in function returning void"
 msgstr "%<return%> met waarde in een functie die void teruggeeft"
 
-#: c/c-typeck.c:10236
+#: c/c-typeck.c:10241
 #, fuzzy, gcc-internal-format
 #| msgid "function returns address of local variable"
 msgid "function returns address of label"
 msgstr "functie geeft adres van lokale variabele terug"
 
-#: c/c-typeck.c:10327 cp/semantics.c:1171
+#: c/c-typeck.c:10332 cp/semantics.c:1171
 #, gcc-internal-format
 msgid "switch quantity not an integer"
 msgstr "switch-waarde is geen integer"
 
-#: c/c-typeck.c:10352
+#: c/c-typeck.c:10357
 #, fuzzy, gcc-internal-format
 msgid "%<long%> switch expression not converted to %<int%> in ISO C"
 msgstr "%<long%> switch-expressie wordt in ISO C niet naar %<int%> geconverteerd"
 
-#: c/c-typeck.c:10390 c/c-typeck.c:10398
+#: c/c-typeck.c:10395 c/c-typeck.c:10403
 #, fuzzy, gcc-internal-format
 msgid "case label is not an integer constant expression"
 msgstr "ongeldig gebruik van een void-expressie"
 
-#: c/c-typeck.c:10404 cp/parser.c:11067
+#: c/c-typeck.c:10409 cp/parser.c:11067
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "case-label niet in een switch-statement"
 
-#: c/c-typeck.c:10406
+#: c/c-typeck.c:10411
 #, fuzzy, gcc-internal-format
 msgid "%<default%> label not within a switch statement"
 msgstr "default-label niet in een switch-statement"
 
-#: c/c-typeck.c:10578 cp/parser.c:12356
+#: c/c-typeck.c:10583 cp/parser.c:12353
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "break-statement niet in een lus of switch"
 
-#: c/c-typeck.c:10580 cp/parser.c:12379
+#: c/c-typeck.c:10585 cp/parser.c:12376
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "continue-statement niet in een lus"
 
-#: c/c-typeck.c:10585 cp/parser.c:12369
+#: c/c-typeck.c:10590 cp/parser.c:12366
 #, fuzzy, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr "break-statement niet in een lus of switch"
 
-#: c/c-typeck.c:10590
+#: c/c-typeck.c:10595
 #, fuzzy, gcc-internal-format
 msgid "break statement within %<#pragma simd%> loop body"
 msgstr "break-statement niet in een lus of switch"
 
-#: c/c-typeck.c:10592
+#: c/c-typeck.c:10597
 #, fuzzy, gcc-internal-format
 msgid "continue statement within %<#pragma simd%> loop body"
 msgstr "continue-statement niet in een lus"
 
-#: c/c-typeck.c:10618 cp/cp-gimplify.c:432
+#: c/c-typeck.c:10623 cp/cp-gimplify.c:432
 #, gcc-internal-format
 msgid "statement with no effect"
 msgstr "statement zonder effect"
 
 # vertaling voor 'statement'?
-#: c/c-typeck.c:10662
+#: c/c-typeck.c:10667
 #, gcc-internal-format
 msgid "expression statement has incomplete type"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: c/c-typeck.c:11476 c/c-typeck.c:11644 cp/typeck.c:5017
+#: c/c-typeck.c:11481 c/c-typeck.c:11649 cp/typeck.c:5017
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr ""
 
-#: c/c-typeck.c:11484 c/c-typeck.c:11652 cp/typeck.c:5030
+#: c/c-typeck.c:11489 c/c-typeck.c:11657 cp/typeck.c:5030
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr ""
 
-#: c/c-typeck.c:11509 c/c-typeck.c:11677 cp/typeck.c:5058
+#: c/c-typeck.c:11514 c/c-typeck.c:11682 cp/typeck.c:5058
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr ""
 
-#: c/c-typeck.c:11523 cp/typeck.c:4743
+#: c/c-typeck.c:11528 cp/typeck.c:4743
 #, gcc-internal-format
 msgid "comparing floating point with == or != is unsafe"
 msgstr ""
 
-#: c/c-typeck.c:11541 c/c-typeck.c:11562
+#: c/c-typeck.c:11546 c/c-typeck.c:11567
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<false%> for the address of %qD will never be NULL"
 msgstr ""
 
-#: c/c-typeck.c:11547 c/c-typeck.c:11568
+#: c/c-typeck.c:11552 c/c-typeck.c:11573
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<true%> for the address of %qD will never be NULL"
 msgstr ""
 
-#: c/c-typeck.c:11589 c/c-typeck.c:11718
+#: c/c-typeck.c:11594 c/c-typeck.c:11723
 #, fuzzy, gcc-internal-format
 msgid "comparison of pointers to disjoint address spaces"
 msgstr "een cast ontbreekt bij vergelijking van ongelijke pointer-types"
 
-#: c/c-typeck.c:11596 c/c-typeck.c:11602
+#: c/c-typeck.c:11601 c/c-typeck.c:11607
 #, gcc-internal-format
 msgid "ISO C forbids comparison of %<void *%> with function pointer"
 msgstr "ISO C verbiedt een vergelijking van %<void *%> met een functie-pointer"
 
-#: c/c-typeck.c:11609 c/c-typeck.c:11728
+#: c/c-typeck.c:11614 c/c-typeck.c:11733
 #, gcc-internal-format
 msgid "comparison of distinct pointer types lacks a cast"
 msgstr "een cast ontbreekt bij vergelijking van ongelijke pointer-types"
 
-#: c/c-typeck.c:11621 c/c-typeck.c:11626 c/c-typeck.c:11754 c/c-typeck.c:11759
+#: c/c-typeck.c:11626 c/c-typeck.c:11631 c/c-typeck.c:11759 c/c-typeck.c:11764
 #, gcc-internal-format
 msgid "comparison between pointer and integer"
 msgstr "vergelijking tussen pointer en integer"
 
-#: c/c-typeck.c:11706
+#: c/c-typeck.c:11711
 #, gcc-internal-format
 msgid "comparison of complete and incomplete pointers"
 msgstr "vergelijking van volledige en onvolledige pointers"
 
 # 'ordered' -> 'bevolen' of 'geordend'? Waarschijnlijk het laatste.
-#: c/c-typeck.c:11708
+#: c/c-typeck.c:11713
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids ordered comparisons of pointers to functions"
 msgstr "ISO C verbiedt geordende vergelijkingen tussen pointers naar functies"
 
-#: c/c-typeck.c:11713
+#: c/c-typeck.c:11718
 #, gcc-internal-format
 msgid "ordered comparison of pointer with null pointer"
 msgstr "geordende vergelijking van pointer met null-pointer"
 
-#: c/c-typeck.c:11736 c/c-typeck.c:11739 c/c-typeck.c:11746 c/c-typeck.c:11749
+#: c/c-typeck.c:11741 c/c-typeck.c:11744 c/c-typeck.c:11751 c/c-typeck.c:11754
 #: cp/typeck.c:5081 cp/typeck.c:5088
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "geordende vergelijking van pointer met integer nul"
 
-#: c/c-typeck.c:11811
+#: c/c-typeck.c:11816
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
 msgstr ""
 
-#: c/c-typeck.c:12126
+#: c/c-typeck.c:12131
 #, fuzzy, gcc-internal-format
 msgid "used array that cannot be converted to pointer where scalar is required"
 msgstr "waarde van array-type gebruikt waar een scalair nodig is"
 
-#: c/c-typeck.c:12130
+#: c/c-typeck.c:12135
 #, fuzzy, gcc-internal-format
 msgid "used struct type value where scalar is required"
 msgstr "waarde van struct-type gebruikt waar een scalair nodig is"
 
-#: c/c-typeck.c:12134
+#: c/c-typeck.c:12139
 #, fuzzy, gcc-internal-format
 msgid "used union type value where scalar is required"
 msgstr "waarde van union-type gebruikt waar een scalair nodig is"
 
-#: c/c-typeck.c:12150
+#: c/c-typeck.c:12155
 #, fuzzy, gcc-internal-format
 msgid "used vector type where scalar is required"
 msgstr "waarde van struct-type gebruikt waar een scalair nodig is"
 
-#: c/c-typeck.c:12340 cp/semantics.c:8508
+#: c/c-typeck.c:12345 cp/semantics.c:8511
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12379 cp/semantics.c:8545
+#: c/c-typeck.c:12384 cp/semantics.c:8548
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12423 c/c-typeck.c:13581 c/c-typeck.c:13642 c/c-typeck.c:13704
+#: c/c-typeck.c:12428 c/c-typeck.c:13586 c/c-typeck.c:13647 c/c-typeck.c:13709
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "te veel invoerbestanden"
 
-#: c/c-typeck.c:12436 c/c-typeck.c:13628 cp/semantics.c:4546
-#: cp/semantics.c:6717
+#: c/c-typeck.c:12441 c/c-typeck.c:13633 cp/semantics.c:4549
+#: cp/semantics.c:6720
 #, fuzzy, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr "bitveld %qs heeft een ongeldig type"
 
-#: c/c-typeck.c:12445 c/c-typeck.c:13652 cp/semantics.c:4556
-#: cp/semantics.c:6735
+#: c/c-typeck.c:12450 c/c-typeck.c:13657 cp/semantics.c:4559
+#: cp/semantics.c:6738
 #, fuzzy, gcc-internal-format
 msgid "%qE is a member of a union"
 msgstr "%qs is meestal een functie"
 
-#: c/c-typeck.c:12455 cp/semantics.c:4570 cp/semantics.c:6760
+#: c/c-typeck.c:12460 cp/semantics.c:4573 cp/semantics.c:6763
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.c:12459 c/c-typeck.c:13669 cp/semantics.c:4574
-#: cp/semantics.c:6763
+#: c/c-typeck.c:12464 c/c-typeck.c:13674 cp/semantics.c:4577
+#: cp/semantics.c:6766
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.c:12466
+#: c/c-typeck.c:12471
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%> %qD in %qs clause"
 msgstr "te veel invoerbestanden"
 
-#: c/c-typeck.c:12475 c/c-typeck.c:13676 c/c-typeck.c:13778
-#: cp/semantics.c:4591 cp/semantics.c:6769 cp/semantics.c:6931
+#: c/c-typeck.c:12480 c/c-typeck.c:13681 c/c-typeck.c:13783
+#: cp/semantics.c:4594 cp/semantics.c:6772 cp/semantics.c:6934
 #, fuzzy, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.c:12511 cp/semantics.c:4623
+#: c/c-typeck.c:12516 cp/semantics.c:4626
 #, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr ""
 
-#: c/c-typeck.c:12518 cp/semantics.c:4630
+#: c/c-typeck.c:12523 cp/semantics.c:4633
 #, fuzzy, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr "grootte van array %qs is van een niet-integer type"
 
-#: c/c-typeck.c:12545 c/c-typeck.c:12609 c/c-typeck.c:12867
-#: cp/semantics.c:4666 cp/semantics.c:4730
+#: c/c-typeck.c:12550 c/c-typeck.c:12614 c/c-typeck.c:12872
+#: cp/semantics.c:4669 cp/semantics.c:4733
 #, fuzzy, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr "ISO C90 verbiedt array %qs van variabele grootte"
 
-#: c/c-typeck.c:12564 cp/semantics.c:4685
+#: c/c-typeck.c:12569 cp/semantics.c:4688
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12572 cp/semantics.c:4693
+#: c/c-typeck.c:12577 cp/semantics.c:4696
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12581 c/c-typeck.c:12691 cp/semantics.c:4702
-#: cp/semantics.c:4812
+#: c/c-typeck.c:12586 c/c-typeck.c:12696 cp/semantics.c:4705
+#: cp/semantics.c:4815
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12598 cp/semantics.c:4719
+#: c/c-typeck.c:12603 cp/semantics.c:4722
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12635 cp/semantics.c:4756
+#: c/c-typeck.c:12640 cp/semantics.c:4759
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12650 cp/semantics.c:4771
+#: c/c-typeck.c:12655 cp/semantics.c:4774
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12683 cp/semantics.c:4804
+#: c/c-typeck.c:12688 cp/semantics.c:4807
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12701 c/c-typeck.c:12810 cp/semantics.c:4822
-#: cp/semantics.c:4934
+#: c/c-typeck.c:12706 c/c-typeck.c:12815 cp/semantics.c:4825
+#: cp/semantics.c:4937
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12709 cp/semantics.c:4830
+#: c/c-typeck.c:12714 cp/semantics.c:4833
 #, fuzzy, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr "%qs is smaller dan waarden van zijn type"
 
-#: c/c-typeck.c:13103 c/c-typeck.c:13113
+#: c/c-typeck.c:13108 c/c-typeck.c:13118
 #, gcc-internal-format
 msgid "%qD in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: c/c-typeck.c:13130
+#: c/c-typeck.c:13135
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%> %qE in %<reduction%> clause"
 msgstr "ISO C verbiedt gekwalificeerde functie-types"
 
-#: c/c-typeck.c:13178
+#: c/c-typeck.c:13183
 #, gcc-internal-format
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr ""
 
-#: c/c-typeck.c:13187 cp/semantics.c:5755
+#: c/c-typeck.c:13192 cp/semantics.c:5758
 #, fuzzy, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr "grootte van %qs is %u bytes"
 
-#: c/c-typeck.c:13275
+#: c/c-typeck.c:13280
 #, fuzzy, gcc-internal-format
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "ISO C90 verbiedt array %qs van variabele grootte"
 
-#: c/c-typeck.c:13293 c/c-typeck.c:13836 cp/semantics.c:7249
+#: c/c-typeck.c:13298 c/c-typeck.c:13841 cp/semantics.c:7252
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13305 cp/semantics.c:7289
+#: c/c-typeck.c:13310 cp/semantics.c:7292
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr ""
 
-#: c/c-typeck.c:13319 cp/semantics.c:5929
+#: c/c-typeck.c:13324 cp/semantics.c:5932
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr ""
 
-#: c/c-typeck.c:13327
+#: c/c-typeck.c:13332
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with type %qT"
 msgstr ""
 
-#: c/c-typeck.c:13335
+#: c/c-typeck.c:13340
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13354 cp/semantics.c:5999
+#: c/c-typeck.c:13359 cp/semantics.c:6002
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
-#: c/c-typeck.c:13384 c/c-typeck.c:13771 cp/semantics.c:6083
-#: cp/semantics.c:6924
+#: c/c-typeck.c:13389 c/c-typeck.c:13776 cp/semantics.c:6086
+#: cp/semantics.c:6927
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.c:13393 cp/semantics.c:6092
+#: c/c-typeck.c:13398 cp/semantics.c:6095
 #, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr ""
 
-#: c/c-typeck.c:13404 c/c-typeck.c:13434 c/c-typeck.c:13463
+#: c/c-typeck.c:13409 c/c-typeck.c:13439 c/c-typeck.c:13468
 #, gcc-internal-format
 msgid "%qE appears more than once in data clauses"
 msgstr ""
 
-#: c/c-typeck.c:13411 c/c-typeck.c:13440 c/c-typeck.c:13600 c/c-typeck.c:13714
-#: c/c-typeck.c:13720 c/c-typeck.c:13733 c/c-typeck.c:13742
-#: cp/semantics.c:6102 cp/semantics.c:6109 cp/semantics.c:6160
-#: cp/semantics.c:6166 cp/semantics.c:6203 cp/semantics.c:6680
-#: cp/semantics.c:6817 cp/semantics.c:6823 cp/semantics.c:6836
-#: cp/semantics.c:6845
+#: c/c-typeck.c:13416 c/c-typeck.c:13445 c/c-typeck.c:13605 c/c-typeck.c:13719
+#: c/c-typeck.c:13725 c/c-typeck.c:13738 c/c-typeck.c:13747
+#: cp/semantics.c:6105 cp/semantics.c:6112 cp/semantics.c:6163
+#: cp/semantics.c:6169 cp/semantics.c:6206 cp/semantics.c:6683
+#: cp/semantics.c:6820 cp/semantics.c:6826 cp/semantics.c:6839
+#: cp/semantics.c:6848
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
-#: c/c-typeck.c:13413 c/c-typeck.c:13442 c/c-typeck.c:13722 c/c-typeck.c:13744
-#: cp/semantics.c:6111 cp/semantics.c:6168 cp/semantics.c:6825
-#: cp/semantics.c:6847
+#: c/c-typeck.c:13418 c/c-typeck.c:13447 c/c-typeck.c:13727 c/c-typeck.c:13749
+#: cp/semantics.c:6114 cp/semantics.c:6171 cp/semantics.c:6828
+#: cp/semantics.c:6850
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr ""
 
-#: c/c-typeck.c:13427 cp/semantics.c:6154
+#: c/c-typeck.c:13432 cp/semantics.c:6157
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: c/c-typeck.c:13456 cp/semantics.c:6197
+#: c/c-typeck.c:13461 cp/semantics.c:6200
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: c/c-typeck.c:13475 cp/semantics.c:6545
+#: c/c-typeck.c:13480 cp/semantics.c:6548
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.c:13482
+#: c/c-typeck.c:13487
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array"
 msgstr ""
 
-#: c/c-typeck.c:13489
+#: c/c-typeck.c:13494
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<aligned%> clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.c:13496
+#: c/c-typeck.c:13501
 #, gcc-internal-format
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:13551 cp/semantics.c:6627
+#: c/c-typeck.c:13556 cp/semantics.c:6630
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.c:13573 cp/semantics.c:6658
+#: c/c-typeck.c:13578 cp/semantics.c:6661
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13597 c/c-typeck.c:13731 cp/semantics.c:6677
-#: cp/semantics.c:6834
+#: c/c-typeck.c:13602 c/c-typeck.c:13736 cp/semantics.c:6680
+#: cp/semantics.c:6837
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr ""
 
-#: c/c-typeck.c:13603 c/c-typeck.c:13735 cp/semantics.c:6683
-#: cp/semantics.c:6838
+#: c/c-typeck.c:13608 c/c-typeck.c:13740 cp/semantics.c:6686
+#: cp/semantics.c:6841
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr ""
 
-#: c/c-typeck.c:13635 cp/semantics.c:6724
+#: c/c-typeck.c:13640 cp/semantics.c:6727
 #, fuzzy, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.c:13695 c/c-typeck.c:13785 cp/semantics.c:6799
-#: cp/semantics.c:6938
+#: c/c-typeck.c:13700 c/c-typeck.c:13790 cp/semantics.c:6802
+#: cp/semantics.c:6941
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.c:13766 cp/semantics.c:6918
+#: c/c-typeck.c:13771 cp/semantics.c:6921
 #, fuzzy, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.c:13794 cp/semantics.c:6947
+#: c/c-typeck.c:13799 cp/semantics.c:6950
 #, fuzzy, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qs is geen static veld"
 
-#: c/c-typeck.c:13808 cp/semantics.c:6962
+#: c/c-typeck.c:13813 cp/semantics.c:6965
 #, fuzzy, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.c:13811 cp/semantics.c:6964
+#: c/c-typeck.c:13816 cp/semantics.c:6967
 #, fuzzy, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.c:13826
+#: c/c-typeck.c:13831
 #, fuzzy, gcc-internal-format
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "waarde met subscript is noch een array, noch een pointer"
 
-#: c/c-typeck.c:13900 cp/semantics.c:6359
+#: c/c-typeck.c:13905 cp/semantics.c:6362
 #, gcc-internal-format
 msgid "%<nonmonotonic%> modifier specified for %qs schedule kind"
 msgstr ""
 
-#: c/c-typeck.c:13931 cp/semantics.c:7141
+#: c/c-typeck.c:13936 cp/semantics.c:7144
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:13981 cp/semantics.c:7332
+#: c/c-typeck.c:13986 cp/semantics.c:7335
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr ""
 
-#: c/c-typeck.c:14001 cp/semantics.c:7223
+#: c/c-typeck.c:14006 cp/semantics.c:7226
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:14013 cp/semantics.c:7236
+#: c/c-typeck.c:14018 cp/semantics.c:7239
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14031 cp/semantics.c:7203
+#: c/c-typeck.c:14036 cp/semantics.c:7206
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14204
+#: c/c-typeck.c:14209
 #, gcc-internal-format
 msgid "cannot use %<va_arg%> with reverse storage order"
 msgstr ""
 
 # Of misschien beter "... niet van het %<va_list%> type"?
-#: c/c-typeck.c:14209
+#: c/c-typeck.c:14214
 #, fuzzy, gcc-internal-format
 #| msgid "first argument to %<va_arg%> not of type %<va_list%>"
 msgid "second argument to %<va_arg%> is of incomplete type %qT"
 msgstr "het eerste argument van %<va_arg%> is geen %<va_list%>"
 
-#: c/c-typeck.c:14215
+#: c/c-typeck.c:14220
 #, gcc-internal-format
 msgid "C++ requires promoted type, not enum type, in %<va_arg%>"
 msgstr ""
@@ -39301,7 +39345,7 @@
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/call.c:3441 cp/pt.c:6495
+#: cp/call.c:3441 cp/pt.c:6509
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -39594,7 +39638,7 @@
 msgid "%q#D is private within this context"
 msgstr "registervariabele %qs gebruikt in geneste functie"
 
-#: cp/call.c:6478 cp/decl.c:7343
+#: cp/call.c:6478 cp/decl.c:7364
 #, fuzzy, gcc-internal-format
 msgid "declared private here"
 msgstr "%qs tevoren hier gedeclareerd"
@@ -39604,7 +39648,7 @@
 msgid "%q#D is protected within this context"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/call.c:6486 cp/decl.c:7344
+#: cp/call.c:6486 cp/decl.c:7365
 #, fuzzy, gcc-internal-format
 msgid "declared protected here"
 msgstr "%qs tevoren hier gedeclareerd"
@@ -39911,7 +39955,7 @@
 msgid "call to non-function %qD"
 msgstr "kan functie %<main%> niet inline maken"
 
-#: cp/call.c:9119 cp/pt.c:15053 cp/typeck.c:2901
+#: cp/call.c:9119 cp/pt.c:15075 cp/typeck.c:2901
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
@@ -40123,262 +40167,262 @@
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr ""
 
-#: cp/class.c:2098
+#: cp/class.c:2103
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr ""
 
-#: cp/class.c:2110
+#: cp/class.c:2115
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr ""
 
-#: cp/class.c:2152
+#: cp/class.c:2156
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr ""
 
-#: cp/class.c:2156
+#: cp/class.c:2160
 #, gcc-internal-format
 msgid "%q#D is public, but requires an existing %q#T object"
 msgstr ""
 
-#: cp/class.c:2430
+#: cp/class.c:2434
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr ""
 
-#: cp/class.c:2785
+#: cp/class.c:2789
 #, fuzzy, gcc-internal-format
 msgid "%qD can be marked override"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/class.c:2797
+#: cp/class.c:2801
 #, fuzzy, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr "label %qs gedefinieerd maar niet gebruikt"
 
-#: cp/class.c:2799
+#: cp/class.c:2803
 #, fuzzy, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr "label %qs gedefinieerd maar niet gebruikt"
 
-#: cp/class.c:2861
+#: cp/class.c:2865
 #, fuzzy, gcc-internal-format
 msgid "%qD was hidden"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: cp/class.c:2863
+#: cp/class.c:2867
 #, fuzzy, gcc-internal-format
 msgid "  by %qD"
 msgstr "%s voor %qs"
 
-#: cp/class.c:2896
+#: cp/class.c:2900
 #, fuzzy, gcc-internal-format
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "ongeldig gebruik van onvolledige typedef %qs"
 
-#: cp/class.c:2906 cp/name-lookup.c:3293 cp/parser.c:19720
+#: cp/class.c:2910 cp/name-lookup.c:3293 cp/parser.c:19717
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
 
-#: cp/class.c:3097
+#: cp/class.c:3101
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr ""
 
-#: cp/class.c:3213
+#: cp/class.c:3217
 #, fuzzy, gcc-internal-format
 msgid "bit-field %q+#D with non-integral type"
 msgstr "breedte van bitveld %qs is geen integerconstante"
 
-#: cp/class.c:3229
+#: cp/class.c:3233
 #, fuzzy, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr "breedte van bitveld %qs is geen integerconstante"
 
-#: cp/class.c:3234
+#: cp/class.c:3238
 #, fuzzy, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr "bitveld %qs heeft een negatieve breedte"
 
-#: cp/class.c:3239
+#: cp/class.c:3243
 #, fuzzy, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr "bitveld %qs heeft breedte 0"
 
-#: cp/class.c:3249
+#: cp/class.c:3253
 #, fuzzy, gcc-internal-format
 msgid "width of %qD exceeds its type"
 msgstr "breedte van %qs overschrijdt zijn type"
 
-#: cp/class.c:3255
+#: cp/class.c:3259
 #, fuzzy, gcc-internal-format
 msgid "%qD is too small to hold all values of %q#T"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/class.c:3316
+#: cp/class.c:3320
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr ""
 
-#: cp/class.c:3319
+#: cp/class.c:3323
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr ""
 
-#: cp/class.c:3321
+#: cp/class.c:3325
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr ""
 
-#: cp/class.c:3325
+#: cp/class.c:3329
 #, gcc-internal-format
 msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/class.c:3453
+#: cp/class.c:3457
 #, fuzzy, gcc-internal-format
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/class.c:3460
+#: cp/class.c:3464
 #, fuzzy, gcc-internal-format
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr "%qs is geen static veld"
 
-#: cp/class.c:3470
+#: cp/class.c:3474
 #, fuzzy, gcc-internal-format
 msgid "field %q+D invalidly declared function type"
 msgstr "veld %qs als een functie gedeclareerd"
 
-#: cp/class.c:3476
+#: cp/class.c:3480
 #, fuzzy, gcc-internal-format
 msgid "field %q+D invalidly declared method type"
 msgstr "bitveld %qs heeft een ongeldig type"
 
-#: cp/class.c:3536
+#: cp/class.c:3540
 #, gcc-internal-format
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr ""
 
-#: cp/class.c:3585
+#: cp/class.c:3589
 #, fuzzy, gcc-internal-format
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/class.c:3591
+#: cp/class.c:3595
 #, fuzzy, gcc-internal-format
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/class.c:3617
+#: cp/class.c:3621
 #, fuzzy, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr "overtollige elementen in beginwaarde van union"
 
-#: cp/class.c:3658
+#: cp/class.c:3662
 #, fuzzy, gcc-internal-format
 msgid "field %q#D with same name as class"
 msgstr "%qs is geen iterator"
 
-#: cp/class.c:3681
+#: cp/class.c:3685
 #, fuzzy, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr "%s heeft geen benoemde leden"
 
-#: cp/class.c:3686
+#: cp/class.c:3690
 #, gcc-internal-format
 msgid "  but does not override %<%T(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:3688
+#: cp/class.c:3692
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:3692
+#: cp/class.c:3696
 #, gcc-internal-format
 msgid "  but does not override %<operator=(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:4097
+#: cp/class.c:4101
 #, gcc-internal-format
 msgid "alignment of %qD increased in -fabi-version=9 (GCC 5.2)"
 msgstr ""
 
-#: cp/class.c:4100
+#: cp/class.c:4104
 #, fuzzy, gcc-internal-format
 msgid "alignment of %qD will increase in -fabi-version=9"
 msgstr "de declaratie van %qs verbergt een parameter"
 
-#: cp/class.c:4378
+#: cp/class.c:4382
 #, fuzzy, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "geen beginwaarde voor variant-veld %qs"
 
-#: cp/class.c:4813
+#: cp/class.c:4817
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr ""
 
-#: cp/class.c:4834
+#: cp/class.c:4838
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr ""
 
-#: cp/class.c:5350 cp/constexpr.c:237
+#: cp/class.c:5367 cp/constexpr.c:237
 #, fuzzy, gcc-internal-format
 msgid "enclosing class of %<constexpr%> non-static member function %q+#D is not a literal type"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/class.c:5374
+#: cp/class.c:5391
 #, fuzzy, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr "%qs is geen iterator"
 
-#: cp/class.c:5377
+#: cp/class.c:5394
 #, gcc-internal-format
 msgid "  %qT is a closure type, which is only literal in C++17 and later"
 msgstr ""
 
-#: cp/class.c:5380
+#: cp/class.c:5397
 #, fuzzy, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr "veld %qs heeft een onvolledig type"
 
-#: cp/class.c:5387
+#: cp/class.c:5404
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no %<constexpr%> constructor that is not a copy or move constructor"
 msgstr ""
 
-#: cp/class.c:5420
+#: cp/class.c:5437
 #, fuzzy, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "veld %qs heeft een onvolledig type"
 
-#: cp/class.c:5435
+#: cp/class.c:5452
 #, fuzzy, gcc-internal-format
 msgid "  non-static data member %qD has non-literal type"
 msgstr "%qs is geen static veld"
 
-#: cp/class.c:5442
+#: cp/class.c:5459
 #, fuzzy, gcc-internal-format
 msgid "  non-static data member %qD has volatile type"
 msgstr "%qs is geen static veld"
 
-#: cp/class.c:5561
+#: cp/class.c:5578
 #, fuzzy, gcc-internal-format
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "veld %qs heeft een onvolledig type"
 
-#: cp/class.c:5590
+#: cp/class.c:5607
 #, gcc-internal-format
 msgid "non-static reference %q#D in class without a constructor"
 msgstr ""
 
-#: cp/class.c:5596
+#: cp/class.c:5613
 #, fuzzy, gcc-internal-format
 msgid "non-static const member %q#D in class without a constructor"
 msgstr "%qs is geen static veld"
@@ -40385,153 +40429,153 @@
 
 #. If the function is defaulted outside the class, we just
 #. give the synthesis error.
-#: cp/class.c:5624
+#: cp/class.c:5641
 #, gcc-internal-format
 msgid "%q+D declared to take const reference, but implicit declaration would take non-const"
 msgstr ""
 
-#: cp/class.c:5898
+#: cp/class.c:5915
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:5910
+#: cp/class.c:5927
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:6133
+#: cp/class.c:6150
 #, gcc-internal-format
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr ""
 
-#: cp/class.c:6291
+#: cp/class.c:6308
 #, fuzzy, gcc-internal-format
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr "omvang van array %qs is te groot"
 
-#: cp/class.c:6576
+#: cp/class.c:6593
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr "ongeldig gebruik van %<this%> op hoogste niveau"
 
-#: cp/class.c:6578
+#: cp/class.c:6595
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of structure with flexible array member"
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr "ongeldig gebruik van strcture met flexibel array-lid"
 
-#: cp/class.c:6583
+#: cp/class.c:6600
 #, fuzzy, gcc-internal-format
 msgid "array member %q#D declared here"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: cp/class.c:6610
+#: cp/class.c:6627
 #, fuzzy, gcc-internal-format
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr "%Jflexibel array-lid niet aan het eind van de struct"
 
-#: cp/class.c:6612
+#: cp/class.c:6629
 #, fuzzy, gcc-internal-format
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr "%Jflexibel array-lid in overigens lege struct"
 
-#: cp/class.c:6620 cp/class.c:6650
+#: cp/class.c:6637 cp/class.c:6667
 #, fuzzy, gcc-internal-format
 msgid "in the definition of %q#T"
 msgstr "herdefinitie van %qs"
 
-#: cp/class.c:6628
+#: cp/class.c:6645
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD not at end of %q#T"
 msgstr "%Jflexibel array-lid niet aan het eind van de struct"
 
-#: cp/class.c:6630
+#: cp/class.c:6647
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr "%Jflexibel array-lid in overigens lege struct"
 
-#: cp/class.c:6648
+#: cp/class.c:6665
 #, fuzzy, gcc-internal-format
 msgid "next member %q#D declared here"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: cp/class.c:6760 cp/parser.c:23239
+#: cp/class.c:6777 cp/parser.c:23236
 #, fuzzy, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "herdefinitie van %qs"
 
-#: cp/class.c:6897
+#: cp/class.c:6914
 #, fuzzy, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "veld %qs heeft een onvolledig type"
 
-#: cp/class.c:6925
+#: cp/class.c:6942
 #, fuzzy, gcc-internal-format
 msgid "type transparent %q#T does not have any fields"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/class.c:6931
+#: cp/class.c:6948
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr ""
 
-#: cp/class.c:6935
+#: cp/class.c:6952
 #, fuzzy, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/class.c:6941
+#: cp/class.c:6958
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:7071
+#: cp/class.c:7088
 #, fuzzy, gcc-internal-format
 msgid "definition of %qD does not match %<#include <initializer_list>%>"
 msgstr "functie-definitie als %<auto%> gedeclareerd"
 
-#: cp/class.c:7082
+#: cp/class.c:7099
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr ""
 
-#: cp/class.c:7582
+#: cp/class.c:7599
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "taal-string %<\"%E\"%> wordt niet herkend"
 
-#: cp/class.c:7672
+#: cp/class.c:7689
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr ""
 
-#: cp/class.c:7817
+#: cp/class.c:7834
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr ""
 
-#: cp/class.c:7844
+#: cp/class.c:7861
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr ""
 
-#: cp/class.c:7870
+#: cp/class.c:7887
 #, fuzzy, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "herhaald lid %qs"
 
-#: cp/class.c:7873
+#: cp/class.c:7890
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr ""
 
-#: cp/class.c:7948 cp/class.c:7990
+#: cp/class.c:7965 cp/class.c:8007
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr ""
 
-#: cp/class.c:7968
+#: cp/class.c:7985
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr ""
@@ -40541,12 +40585,12 @@
 #. A name N used in a class S shall refer to the same declaration
 #. in its context and when re-evaluated in the completed scope of
 #. S.
-#: cp/class.c:8235
+#: cp/class.c:8252
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D"
 msgstr "herdeclaratie van %qs"
 
-#: cp/class.c:8237
+#: cp/class.c:8254
 #, gcc-internal-format
 msgid "changes meaning of %qD from %q#D"
 msgstr ""
@@ -40938,17 +40982,17 @@
 msgid "unexpected AST of kind %s"
 msgstr "onverwachte operand"
 
-#: cp/cp-gimplify.c:1415
+#: cp/cp-gimplify.c:1416
 #, gcc-internal-format
 msgid "throw will always call terminate()"
 msgstr ""
 
-#: cp/cp-gimplify.c:1418
+#: cp/cp-gimplify.c:1419
 #, gcc-internal-format
 msgid "in C++11 destructors default to noexcept"
 msgstr ""
 
-#: cp/cp-gimplify.c:1429
+#: cp/cp-gimplify.c:1430
 #, gcc-internal-format
 msgid "in C++11 this throw will terminate because destructors default to noexcept"
 msgstr ""
@@ -41358,7 +41402,7 @@
 msgid "redeclaration %qD differs in %<constexpr%> from previous declaration"
 msgstr "ingebouwde functie %qs als niet-functie gedeclareerd"
 
-#: cp/decl.c:1304 cp/decl.c:13843
+#: cp/decl.c:1304 cp/decl.c:13867
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr "eerdere declaratie van %qs"
@@ -41683,7 +41727,7 @@
 msgid "  enters OpenMP structured block"
 msgstr ""
 
-#: cp/decl.c:3434 cp/parser.c:12366 cp/parser.c:12387
+#: cp/decl.c:3434 cp/parser.c:12363 cp/parser.c:12384
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr ""
@@ -41693,7 +41737,7 @@
 msgid "%qD is not a type"
 msgstr "%qs is geen iterator"
 
-#: cp/decl.c:3838 cp/parser.c:6366
+#: cp/decl.c:3838 cp/parser.c:6369
 #, fuzzy, gcc-internal-format
 msgid "%qD used without template parameters"
 msgstr "macro %qs gebruikt zonder argumenten"
@@ -42069,8 +42113,8 @@
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.c:6011 cp/decl.c:6234 cp/typeck2.c:1310 cp/typeck2.c:1590
-#: cp/typeck2.c:1638 cp/typeck2.c:1685
+#: cp/decl.c:6011 cp/decl.c:6234 cp/typeck2.c:1310 cp/typeck2.c:1593
+#: cp/typeck2.c:1641 cp/typeck2.c:1688
 #, fuzzy, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "ongeldige beginwaarde voor veld %qs"
@@ -42145,12 +42189,12 @@
 msgid "assignment (not initialization) in declaration"
 msgstr ""
 
-#: cp/decl.c:6873 cp/decl.c:12605
+#: cp/decl.c:6873 cp/decl.c:12629
 #, fuzzy, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C++ staat het gebruik van %<varargs.h%> niet toe"
 
-#: cp/decl.c:6877 cp/decl.c:12609
+#: cp/decl.c:6877 cp/decl.c:12633
 #, fuzzy, gcc-internal-format
 msgid "%<register%> storage class specifier used"
 msgstr "opslagklasse opgegeven voor parameter %qs"
@@ -42176,42 +42220,42 @@
 msgid "function %q#D is initialized like a variable"
 msgstr "typedef %qs krijgt beginwaarde alsof het een variabele is"
 
-#: cp/decl.c:7329
+#: cp/decl.c:7350
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr ""
 
-#: cp/decl.c:7332
+#: cp/decl.c:7353
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.c:7339
+#: cp/decl.c:7360
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/decl.c:7365
+#: cp/decl.c:7386
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:7374
+#: cp/decl.c:7395
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:7592
+#: cp/decl.c:7613
 #, fuzzy, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr "dereferentie van pointer naar onvolledig type"
 
-#: cp/decl.c:7608
+#: cp/decl.c:7629
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr "ISO C90 verbiedt array %qs van variabele grootte"
 
-#: cp/decl.c:7617 cp/decl.c:7702
+#: cp/decl.c:7638 cp/decl.c:7723
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
@@ -42218,7 +42262,7 @@
 msgstr[0] "opslagklasse opgegeven voor structure-veld %qs"
 msgstr[1] "opslagklasse opgegeven voor structure-veld %qs"
 
-#: cp/decl.c:7621
+#: cp/decl.c:7642
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
@@ -42225,7 +42269,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:7624
+#: cp/decl.c:7645
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
@@ -42232,882 +42276,882 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:7669
+#: cp/decl.c:7690
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/decl.c:7695
+#: cp/decl.c:7716
 #, fuzzy, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "ongeldig gebruik van een void-expressie"
 
-#: cp/decl.c:7704
+#: cp/decl.c:7725
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.c:7725
+#: cp/decl.c:7746
 #, fuzzy, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr "dubbele beginwaarde"
 
-#: cp/decl.c:7751
+#: cp/decl.c:7772
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/decl.c:7756
+#: cp/decl.c:7777
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "herhaald lid %qs"
 
 # Betere vertaling voor 'decompose'?
-#: cp/decl.c:7761
+#: cp/decl.c:7782
 #, fuzzy, gcc-internal-format
 #| msgid "cannot decompose address"
 msgid "cannot decompose lambda closure type %qT"
 msgstr "kan adres niet ontleden"
 
-#: cp/decl.c:7765
+#: cp/decl.c:7786
 #, fuzzy, gcc-internal-format
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "teruggeeftype is onvolledig"
 
-#: cp/decl.c:7774
+#: cp/decl.c:7795
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "ongeldig gebruik van onvolledige typedef %qs"
 
-#: cp/decl.c:8213
+#: cp/decl.c:8234
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:8216
+#: cp/decl.c:8237
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:8222
+#: cp/decl.c:8243
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:8450
+#: cp/decl.c:8471
 #, fuzzy, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "beginwaarde legt grootte van %qs niet vast"
 
-#: cp/decl.c:8454
+#: cp/decl.c:8475
 #, fuzzy, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "array-grootte ontbreekt in %qs"
 
-#: cp/decl.c:8457
+#: cp/decl.c:8478
 #, fuzzy, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "array %qs heeft grootte die negatief of 0 is"
 
-#: cp/decl.c:8473
+#: cp/decl.c:8494
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.c:8475
+#: cp/decl.c:8496
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.c:8499
+#: cp/decl.c:8520
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.c:8501
+#: cp/decl.c:8522
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr ""
 
-#: cp/decl.c:8506
+#: cp/decl.c:8527
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.c:8508
+#: cp/decl.c:8529
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.c:8510
+#: cp/decl.c:8531
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:8515
+#: cp/decl.c:8536
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.c:8517
+#: cp/decl.c:8538
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.c:8519
+#: cp/decl.c:8540
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr ""
 
-#: cp/decl.c:8524
+#: cp/decl.c:8545
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.c:8526
+#: cp/decl.c:8547
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.c:8528
+#: cp/decl.c:8549
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr ""
 
-#: cp/decl.c:8535
+#: cp/decl.c:8556
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "veld %qs als een functie gedeclareerd"
 
-#: cp/decl.c:8542
+#: cp/decl.c:8563
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%qs gedeclareerd als een functie die een functie teruggeeft"
 
-#: cp/decl.c:8574
+#: cp/decl.c:8595
 #, fuzzy, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/decl.c:8614
+#: cp/decl.c:8635
 #, fuzzy, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:8624
+#: cp/decl.c:8645
 #, fuzzy, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr "%J%qD als niet-parameter gedeclareerd"
 
-#: cp/decl.c:8630
+#: cp/decl.c:8651
 #, fuzzy, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr "%Jparameter %qD als void gedeclareerd"
 
-#: cp/decl.c:8632
+#: cp/decl.c:8653
 #, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr ""
 
-#: cp/decl.c:8703
+#: cp/decl.c:8724
 #, fuzzy, gcc-internal-format
 msgid "concept %qD has no definition"
 msgstr "%Jfunctiedefinitie in oude stijl"
 
-#: cp/decl.c:8772
+#: cp/decl.c:8793
 #, fuzzy, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "POS mag niet opgegeven worden voor een lijst van veld-declaraties"
 
 #. Something like `template <class T> friend void f<T>()'.
-#: cp/decl.c:8782
+#: cp/decl.c:8803
 #, fuzzy, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "ongeldig gebruik van een void-expressie"
 
-#: cp/decl.c:8800
+#: cp/decl.c:8821
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:8808
+#: cp/decl.c:8829
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:8857
+#: cp/decl.c:8878
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr ""
 
-#: cp/decl.c:8859
+#: cp/decl.c:8880
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/decl.c:8861
+#: cp/decl.c:8882
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be %<constexpr%>"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/decl.c:8863
+#: cp/decl.c:8884
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/decl.c:8920
+#: cp/decl.c:8941
 #, fuzzy, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:8921
+#: cp/decl.c:8942
 #, fuzzy, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:8929
+#: cp/decl.c:8950
 #, fuzzy, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:8930
+#: cp/decl.c:8951
 #, fuzzy, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:8940
+#: cp/decl.c:8961
 #, fuzzy, gcc-internal-format
 msgid "deduction guide %qD must be declared at namespace scope"
 msgstr "de declaratie van %qs is %<extern%> en heeft een beginwaarde"
 
-#: cp/decl.c:8946
+#: cp/decl.c:8967
 #, fuzzy, gcc-internal-format
 msgid "deduction guide %qD must not have a function body"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/decl.c:8959
+#: cp/decl.c:8980
 #, fuzzy, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr "conflicterende declaraties van %qs"
 
-#: cp/decl.c:8969
+#: cp/decl.c:8990
 #, fuzzy, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "Ongeldige optie %qs"
 
-#: cp/decl.c:8977
+#: cp/decl.c:8998
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:8983
+#: cp/decl.c:9004
 #, gcc-internal-format
 msgid "floating point suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:8991
+#: cp/decl.c:9012
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/decl.c:8996
+#: cp/decl.c:9017
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/decl.c:9076
+#: cp/decl.c:9097
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr ""
 
-#: cp/decl.c:9116
+#: cp/decl.c:9137
 #, fuzzy, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "functie-definitie als %<auto%> gedeclareerd"
 
-#: cp/decl.c:9121
+#: cp/decl.c:9142
 #, fuzzy, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "functie-definitie als %<auto%> gedeclareerd"
 
-#: cp/decl.c:9123
+#: cp/decl.c:9144
 #, fuzzy, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr "%qs tevoren hier gedefinieerd"
 
-#: cp/decl.c:9140
+#: cp/decl.c:9161
 #, fuzzy, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:9329
+#: cp/decl.c:9350
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/decl.c:9337
+#: cp/decl.c:9358
 #, fuzzy, gcc-internal-format
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: cp/decl.c:9344
+#: cp/decl.c:9365
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.c:9464
+#: cp/decl.c:9485
 #, fuzzy, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: cp/decl.c:9468
+#: cp/decl.c:9489
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: cp/decl.c:9472
+#: cp/decl.c:9493
 #, fuzzy, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: cp/decl.c:9486
+#: cp/decl.c:9507
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:9493
+#: cp/decl.c:9514
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: cp/decl.c:9498
+#: cp/decl.c:9519
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: cp/decl.c:9598
+#: cp/decl.c:9619
 #, fuzzy, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "grootte van array %qs is van een niet-integraal type"
 
-#: cp/decl.c:9600
+#: cp/decl.c:9621
 #, fuzzy, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "grootte van array %qs is van een niet-integraal type"
 
-#: cp/decl.c:9630 cp/decl.c:9680
+#: cp/decl.c:9651 cp/decl.c:9701
 #, fuzzy, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "ongeldig gebruik van een void-expressie"
 
-#: cp/decl.c:9646
+#: cp/decl.c:9667
 #, fuzzy, gcc-internal-format
 msgid "size of array %qD is negative"
 msgstr "grootte van array %qs is negatief"
 
-#: cp/decl.c:9648 cp/init.c:3651
+#: cp/decl.c:9669 cp/init.c:3667
 #, fuzzy, gcc-internal-format
 msgid "size of array is negative"
 msgstr "grootte van array %qs is negatief"
 
-#: cp/decl.c:9662
+#: cp/decl.c:9683
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C++ verbiedt array %qs met lengte 0"
 
-#: cp/decl.c:9664
+#: cp/decl.c:9685
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++ verbiedt array %qs met lengte 0"
 
-#: cp/decl.c:9677
+#: cp/decl.c:9698
 #, fuzzy, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "grootte van array %qs is van een niet-integraal type"
 
-#: cp/decl.c:9686
+#: cp/decl.c:9707
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++ verbiedt array %qs van variabele lengte"
 
-#: cp/decl.c:9688
+#: cp/decl.c:9709
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++ verbiedt array %qs van variabele lengte"
 
-#: cp/decl.c:9694
+#: cp/decl.c:9715
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr ""
 
-#: cp/decl.c:9697
+#: cp/decl.c:9718
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr ""
 
-#: cp/decl.c:9746
+#: cp/decl.c:9767
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr ""
 
-#: cp/decl.c:9799
+#: cp/decl.c:9820
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as array of %qT"
 msgstr "veld %qs als een functie gedeclareerd"
 
-#: cp/decl.c:9809
+#: cp/decl.c:9830
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "%qs wordt gedeclareerd als een array van voids"
 
-#: cp/decl.c:9811
+#: cp/decl.c:9832
 #, fuzzy, gcc-internal-format
 msgid "creating array of void"
 msgstr "doorgeven van argument %d van %qs"
 
-#: cp/decl.c:9816
+#: cp/decl.c:9837
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/decl.c:9818
+#: cp/decl.c:9839
 #, fuzzy, gcc-internal-format
 msgid "creating array of functions"
 msgstr "doorgeven van argument %d van %qs"
 
-#: cp/decl.c:9823
+#: cp/decl.c:9844
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/decl.c:9825
+#: cp/decl.c:9846
 #, fuzzy, gcc-internal-format
 msgid "creating array of references"
 msgstr "doorgeven van argument %d van %qs"
 
-#: cp/decl.c:9830
+#: cp/decl.c:9851
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/decl.c:9832
+#: cp/decl.c:9853
 #, fuzzy, gcc-internal-format
 msgid "creating array of function members"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/decl.c:9846
+#: cp/decl.c:9867
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.c:9850
+#: cp/decl.c:9871
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.c:9909
+#: cp/decl.c:9930
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr ""
 
-#: cp/decl.c:9912
+#: cp/decl.c:9933
 #, fuzzy, gcc-internal-format
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: cp/decl.c:9922
+#: cp/decl.c:9943
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr ""
 
-#: cp/decl.c:9925
+#: cp/decl.c:9946
 #, fuzzy, gcc-internal-format
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: cp/decl.c:9937
+#: cp/decl.c:9958
 #, fuzzy, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "registernaam niet opgegeven voor %qs"
 
-#: cp/decl.c:9940
+#: cp/decl.c:9961
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr ""
 
-#: cp/decl.c:9948
+#: cp/decl.c:9969
 #, fuzzy, gcc-internal-format
 msgid "return type specified for deduction guide"
 msgstr "registernaam niet opgegeven voor %qs"
 
-#: cp/decl.c:9951
+#: cp/decl.c:9972
 #, fuzzy, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: cp/decl.c:9955
+#: cp/decl.c:9976
 #, fuzzy, gcc-internal-format
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/decl.c:9964
+#: cp/decl.c:9985
 #, fuzzy, gcc-internal-format
 msgid "decl-specifier in declaration of deduction guide"
 msgstr "conflicterende declaraties van %qs"
 
-#: cp/decl.c:9985
+#: cp/decl.c:10006
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr ""
 
-#: cp/decl.c:9992
+#: cp/decl.c:10013
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr ""
 
-#: cp/decl.c:10007
+#: cp/decl.c:10028
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "POS mag niet opgegeven worden voor een lijst van veld-declaraties"
 
-#: cp/decl.c:10013
+#: cp/decl.c:10034
 #, gcc-internal-format
 msgid "inline variables are only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/decl.c:10268
+#: cp/decl.c:10292
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: cp/decl.c:10271 cp/decl.c:10291
+#: cp/decl.c:10295 cp/decl.c:10315
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "ongeldig gebruik van het niet gedefinieerde type %<%s %s%>"
 
-#: cp/decl.c:10274
+#: cp/decl.c:10298
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "ongeldig gebruik van het niet gedefinieerde type %<%s %s%>"
 
-#: cp/decl.c:10283
+#: cp/decl.c:10307
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a class or a namespace"
 msgstr "%qs is geen iterator"
 
-#: cp/decl.c:10305 cp/decl.c:10398 cp/decl.c:10407 cp/decl.c:11970
+#: cp/decl.c:10329 cp/decl.c:10422 cp/decl.c:10431 cp/decl.c:11994
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/decl.c:10311
+#: cp/decl.c:10335
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as non-member"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/decl.c:10339
+#: cp/decl.c:10363
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr ""
 
-#: cp/decl.c:10390
+#: cp/decl.c:10414
 #, fuzzy, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "functie-definitie als %<register%> gedeclareerd"
 
-#: cp/decl.c:10415
+#: cp/decl.c:10439
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "herdeclaratie van %qs"
 
-#: cp/decl.c:10420
+#: cp/decl.c:10444
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "de declaratie van %qs verbergt een parameter"
 
-#: cp/decl.c:10454
+#: cp/decl.c:10478
 #, fuzzy, gcc-internal-format
 msgid "%<concept%> cannot appear in a typedef declaration"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/decl.c:10460
+#: cp/decl.c:10484
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/decl.c:10468
+#: cp/decl.c:10492
 #, fuzzy, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "twee of meer data types in de declaratie van %qs"
 
-#: cp/decl.c:10474
+#: cp/decl.c:10498
 #, fuzzy, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr "conflicterende declaraties van %qs"
 
-#: cp/decl.c:10515
+#: cp/decl.c:10539
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C ondersteunt gewone %<complex%> niet in de betekenis van %<double complex%>"
 
-#: cp/decl.c:10564 cp/decl.c:10567 cp/decl.c:10570
+#: cp/decl.c:10588 cp/decl.c:10591 cp/decl.c:10594
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ verbiedt lid-declaraties zonder leden"
 
-#: cp/decl.c:10586
+#: cp/decl.c:10610
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr "__builtin_saveregs wordt niet ondersteund door dit doelsysteem"
 
-#: cp/decl.c:10592
+#: cp/decl.c:10616
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ ondersteunt %<long long%> niet"
 
-#: cp/decl.c:10614 cp/decl.c:10634
+#: cp/decl.c:10638 cp/decl.c:10658
 #, fuzzy, gcc-internal-format
 msgid "%<signed%> or %<unsigned%> invalid for %qs"
 msgstr "'long', 'short', 'signed' of 'unsigned' ongeldig voor %qs"
 
-#: cp/decl.c:10616
+#: cp/decl.c:10640
 #, fuzzy, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgstr "zowel 'signed' als 'unsigned' opgegeven voor %qs"
 
-#: cp/decl.c:10618
+#: cp/decl.c:10642
 #, fuzzy, gcc-internal-format
 msgid "%<long long%> invalid for %qs"
 msgstr "'complex' ongeldig voor %qs"
 
-#: cp/decl.c:10620
+#: cp/decl.c:10644
 #, fuzzy, gcc-internal-format
 msgid "%<long%> invalid for %qs"
 msgstr "'complex' ongeldig voor %qs"
 
-#: cp/decl.c:10622
+#: cp/decl.c:10646
 #, fuzzy, gcc-internal-format
 msgid "%<short%> invalid for %qs"
 msgstr "'complex' ongeldig voor %qs"
 
-#: cp/decl.c:10624
+#: cp/decl.c:10648
 #, fuzzy, gcc-internal-format
 msgid "%<long%> or %<short%> invalid for %qs"
 msgstr "'long', 'short', 'signed' of 'unsigned' ongeldig voor %qs"
 
-#: cp/decl.c:10626
+#: cp/decl.c:10650
 #, fuzzy, gcc-internal-format
 msgid "%<long%>, %<int%>, %<short%>, or %<char%> invalid for %qs"
 msgstr "'long', 'short', 'signed' of 'unsigned' ongeldig voor %qs"
 
-#: cp/decl.c:10628
+#: cp/decl.c:10652
 #, fuzzy, gcc-internal-format
 msgid "%<long%> or %<short%> specified with char for %qs"
 msgstr "'long' of 'short' opgegeven bij 'char' voor %qs"
 
-#: cp/decl.c:10630
+#: cp/decl.c:10654
 #, fuzzy, gcc-internal-format
 msgid "%<long%> and %<short%> specified together for %qs"
 msgstr "zowel 'long' als 'short' opgegeven voor %qs"
 
-#: cp/decl.c:10636
+#: cp/decl.c:10660
 #, fuzzy, gcc-internal-format
 msgid "%<short%> or %<long%> invalid for %qs"
 msgstr "'long', 'short', 'signed' of 'unsigned' ongeldig voor %qs"
 
-#: cp/decl.c:10644
+#: cp/decl.c:10668
 #, fuzzy, gcc-internal-format
 msgid "long, short, signed or unsigned used invalidly for %qs"
 msgstr "ongeldig gebruik van 'long', 'short', 'signed' of 'unsigned' voor %qs"
 
-#: cp/decl.c:10712
+#: cp/decl.c:10736
 #, fuzzy, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "'complex' ongeldig voor %qs"
 
-#: cp/decl.c:10751
+#: cp/decl.c:10775
 #, gcc-internal-format
 msgid "template placeholder type %qT must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.c:10769
+#: cp/decl.c:10793
 #, fuzzy, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:10775
+#: cp/decl.c:10799
 #, fuzzy, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<constexpr%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:10785
+#: cp/decl.c:10809
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:10790
+#: cp/decl.c:10814
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "opslagklasse opgegeven voor parameter %qs"
 
-#: cp/decl.c:10796
+#: cp/decl.c:10820
 #, gcc-internal-format
 msgid "storage class specifiers invalid in parameter declarations"
 msgstr ""
 
-#: cp/decl.c:10800
+#: cp/decl.c:10824
 #, fuzzy, gcc-internal-format
 msgid "a parameter cannot be declared %<concept%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:10805
+#: cp/decl.c:10829
 #, fuzzy, gcc-internal-format
 msgid "a parameter cannot be declared %<constexpr%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:10815
+#: cp/decl.c:10839
 #, fuzzy, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "POS mag niet opgegeven worden voor een lijst van veld-declaraties"
 
-#: cp/decl.c:10825
+#: cp/decl.c:10849
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %<inline%>"
 msgstr "kan functie %<main%> niet inline maken"
 
-#: cp/decl.c:10828
+#: cp/decl.c:10852
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %<typedef%>"
 msgstr "herdeclaratie van %qs"
 
-#: cp/decl.c:10830
+#: cp/decl.c:10854
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %<constexpr%>"
 msgstr "ingebouwde functie %qs als niet-functie gedeclareerd"
 
-#: cp/decl.c:10834
+#: cp/decl.c:10858
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr "eerdere declaratie van %qs"
 
-#: cp/decl.c:10839
+#: cp/decl.c:10863
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<concept%>"
 msgstr ""
 
-#: cp/decl.c:10845
+#: cp/decl.c:10869
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %<register%>"
 msgstr "subscript ontbreekt in array-referentie"
 
-#: cp/decl.c:10849
+#: cp/decl.c:10873
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<static%>"
 msgstr ""
 
-#: cp/decl.c:10853
+#: cp/decl.c:10877
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %<extern%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:10857
+#: cp/decl.c:10881
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %<mutable%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:10861
+#: cp/decl.c:10885
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10872
+#: cp/decl.c:10896
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr "eerdere declaratie van %qs"
 
-#: cp/decl.c:10875
+#: cp/decl.c:10899
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10906
+#: cp/decl.c:10930
 #, fuzzy, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/decl.c:10929
+#: cp/decl.c:10953
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "opslagklasse opgegeven voor parameter %qs"
 
-#: cp/decl.c:10933
+#: cp/decl.c:10957
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "opslagklasse opgegeven voor parameter %qs"
 
-#: cp/decl.c:10946
+#: cp/decl.c:10970
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:10950
+#: cp/decl.c:10974
 #, fuzzy, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "top-level declaratie van %qs specifieert %<auto%>"
 
-#: cp/decl.c:10957
+#: cp/decl.c:10981
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr ""
 
-#: cp/decl.c:10969
+#: cp/decl.c:10993
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr ""
 
-#: cp/decl.c:11050
+#: cp/decl.c:11074
 #, fuzzy, gcc-internal-format
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/decl.c:11098
+#: cp/decl.c:11122
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.c:11118
+#: cp/decl.c:11142
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.c:11121
+#: cp/decl.c:11145
 #, gcc-internal-format
 msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/decl.c:11127
+#: cp/decl.c:11151
 #, fuzzy, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr "functiedefinitie heeft een gekwalificeerde %<void%> als teruggeeftype"
 
-#: cp/decl.c:11134
+#: cp/decl.c:11158
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:11147
+#: cp/decl.c:11171
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "deduced class type %qD in function return type"
 msgstr "typekwalificaties op teruggeeftypes van functies worden genegeerd"
 
-#: cp/decl.c:11156
+#: cp/decl.c:11180
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr ""
 
-#: cp/decl.c:11169
+#: cp/decl.c:11193
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
@@ -43114,304 +43158,304 @@
 
 #. Not using maybe_warn_cpp0x because this should
 #. always be an error.
-#: cp/decl.c:11180
+#: cp/decl.c:11204
 #, gcc-internal-format
 msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/decl.c:11183
+#: cp/decl.c:11207
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.c:11212
+#: cp/decl.c:11236
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs gedeclareerd als een functie die een functie teruggeeft"
 
-#: cp/decl.c:11218
+#: cp/decl.c:11242
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs gedeclareerd als een functie die een array teruggeeft"
 
-#: cp/decl.c:11247
+#: cp/decl.c:11271
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.c:11248
+#: cp/decl.c:11272
 #, fuzzy, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/decl.c:11252
+#: cp/decl.c:11276
 #, fuzzy, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "structure heeft geen lid dat %qs heet"
 
-#: cp/decl.c:11253
+#: cp/decl.c:11277
 #, fuzzy, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "structure heeft geen lid dat %qs heet"
 
-#: cp/decl.c:11261
+#: cp/decl.c:11285
 #, fuzzy, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr "structure heeft geen lid dat %qs heet"
 
-#: cp/decl.c:11262
+#: cp/decl.c:11286
 #, fuzzy, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr "structure heeft geen lid dat %qs heet"
 
-#: cp/decl.c:11280
+#: cp/decl.c:11304
 #, fuzzy, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
 #. Cannot be both friend and virtual.
-#: cp/decl.c:11295
+#: cp/decl.c:11319
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr ""
 
-#: cp/decl.c:11299
+#: cp/decl.c:11323
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr ""
 
-#: cp/decl.c:11301
+#: cp/decl.c:11325
 #, gcc-internal-format
 msgid "can%'t define friend function %qs in a local class definition"
 msgstr ""
 
-#: cp/decl.c:11313
+#: cp/decl.c:11337
 #, fuzzy, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr "functiedefinitie heeft een gekwalificeerde %<void%> als teruggeeftype"
 
-#: cp/decl.c:11339
+#: cp/decl.c:11363
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr ""
 
-#: cp/decl.c:11379
+#: cp/decl.c:11403
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/decl.c:11392 cp/decl.c:11399
+#: cp/decl.c:11416 cp/decl.c:11423
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: cp/decl.c:11401
+#: cp/decl.c:11425
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/decl.c:11430
+#: cp/decl.c:11454
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: cp/decl.c:11431
+#: cp/decl.c:11455
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/decl.c:11504
+#: cp/decl.c:11528
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.c:11574
+#: cp/decl.c:11598
 #, fuzzy, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "parameter %qs heeft enkel een voorwaartse declaratie"
 
-#: cp/decl.c:11599
+#: cp/decl.c:11623
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr ""
 
-#: cp/decl.c:11605
+#: cp/decl.c:11629
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr ""
 
-#: cp/decl.c:11635
+#: cp/decl.c:11659
 #, fuzzy, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: cp/decl.c:11637
+#: cp/decl.c:11661
 #, fuzzy, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: cp/decl.c:11645
+#: cp/decl.c:11669
 #, fuzzy, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: cp/decl.c:11685
+#: cp/decl.c:11709
 #, fuzzy, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:11693
+#: cp/decl.c:11717
 #, fuzzy, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "argument %d is alleen-lezen"
 
-#: cp/decl.c:11695
+#: cp/decl.c:11719
 #, fuzzy, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "argument %d is alleen-lezen"
 
-#: cp/decl.c:11706
+#: cp/decl.c:11730
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "POS mag niet opgegeven worden voor een lijst van veld-declaraties"
 
-#: cp/decl.c:11709
+#: cp/decl.c:11733
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<explicit%> in friend declaration"
 msgstr "%<inline%> bij lege declaratie"
 
-#: cp/decl.c:11712
+#: cp/decl.c:11736
 #, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr ""
 
-#: cp/decl.c:11721
+#: cp/decl.c:11745
 #, fuzzy, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:11726
+#: cp/decl.c:11750
 #, fuzzy, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:11732
+#: cp/decl.c:11756
 #, fuzzy, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:11737
+#: cp/decl.c:11761
 #, fuzzy, gcc-internal-format
 msgid "static %qs cannot be declared %<mutable%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:11742
+#: cp/decl.c:11766
 #, fuzzy, gcc-internal-format
 msgid "const %qs cannot be declared %<mutable%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:11747
+#: cp/decl.c:11771
 #, fuzzy, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:11778
+#: cp/decl.c:11802
 #, fuzzy, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "%Jtypedef %qD als %<inline%> gedeclareerd"
 
-#: cp/decl.c:11783
+#: cp/decl.c:11807
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.c:11787
+#: cp/decl.c:11811
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr ""
 
-#: cp/decl.c:11813
+#: cp/decl.c:11837
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr ""
 
-#: cp/decl.c:11900
+#: cp/decl.c:11924
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "POS mag niet opgegeven worden voor een lijst van veld-declaraties"
 
-#: cp/decl.c:11908
+#: cp/decl.c:11932
 #, fuzzy, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: cp/decl.c:11910
+#: cp/decl.c:11934
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr ""
 
-#: cp/decl.c:11914
+#: cp/decl.c:11938
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr ""
 
-#: cp/decl.c:11927
+#: cp/decl.c:11951
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr ""
 
-#: cp/decl.c:11947
+#: cp/decl.c:11971
 #, fuzzy, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "%s laat qualifiers van doeltype van pointer vallen"
 
-#: cp/decl.c:11951
+#: cp/decl.c:11975
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.c:11961
+#: cp/decl.c:11985
 #, fuzzy, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "de declaratie van %qs verbergt een globale declaratie"
 
-#: cp/decl.c:11976
+#: cp/decl.c:12000
 #, fuzzy, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "dubbele beginwaarde"
 
-#: cp/decl.c:11995
+#: cp/decl.c:12019
 #, fuzzy, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "attributen genegeerd in declarator van parameter-array"
 
-#: cp/decl.c:12001
+#: cp/decl.c:12025
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/decl.c:12003
+#: cp/decl.c:12027
 #, fuzzy, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "%Jparameter %qD als %<inline%> gedeclareerd"
 
-#: cp/decl.c:12052 cp/parser.c:3270
+#: cp/decl.c:12076 cp/parser.c:3270
 #, fuzzy, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "ongeldig gebruik van een void-expressie"
 
-#: cp/decl.c:12056
+#: cp/decl.c:12080
 #, fuzzy, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.c:12080
+#: cp/decl.c:12104
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C++ verbiedt array %qs met lengte 0"
 
-#: cp/decl.c:12083
+#: cp/decl.c:12107
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array members"
@@ -43418,157 +43462,157 @@
 msgstr "ISO C90 ondersteunt geen flexibele array-leden"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:12099
+#: cp/decl.c:12123
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: cp/decl.c:12121
+#: cp/decl.c:12145
 #, fuzzy, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/decl.c:12130
+#: cp/decl.c:12154
 #, fuzzy, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "veld %qs als een functie gedeclareerd"
 
-#: cp/decl.c:12139
+#: cp/decl.c:12163
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/decl.c:12153
+#: cp/decl.c:12177
 #, fuzzy, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "eerdere impliciete declaratie van `%s'"
 
-#: cp/decl.c:12160
+#: cp/decl.c:12184
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "de declaratie van %qs verbergt een parameter"
 
-#: cp/decl.c:12166
+#: cp/decl.c:12190
 #, fuzzy, gcc-internal-format
 msgid "a destructor cannot be %<concept%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:12171
+#: cp/decl.c:12195
 #, gcc-internal-format
 msgid "a destructor cannot be %<constexpr%>"
 msgstr ""
 
-#: cp/decl.c:12177
+#: cp/decl.c:12201
 #, fuzzy, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "eerdere impliciete declaratie van `%s'"
 
-#: cp/decl.c:12185
+#: cp/decl.c:12209
 #, fuzzy, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/decl.c:12190
+#: cp/decl.c:12214
 #, fuzzy, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/decl.c:12199
+#: cp/decl.c:12223
 #, fuzzy, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr "herdeclaratie van %<enum %s%>"
 
-#: cp/decl.c:12202
+#: cp/decl.c:12226
 #, fuzzy, gcc-internal-format
 msgid "variable template declared here"
 msgstr "variabele of veld %qs als void gedeclareerd"
 
-#: cp/decl.c:12257
+#: cp/decl.c:12281
 #, fuzzy, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr "veld %qs heeft een onvolledig type"
 
-#: cp/decl.c:12262
+#: cp/decl.c:12286
 #, fuzzy, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "parameter %qs heeft een onvolledig type"
 
-#: cp/decl.c:12272
+#: cp/decl.c:12296
 #, fuzzy, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qs mag niet als alleen-lezen gedeclareerd worden"
 
-#: cp/decl.c:12318
+#: cp/decl.c:12342
 #, fuzzy, gcc-internal-format
 msgid "static data member %qE declared %<concept%>"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.c:12322
+#: cp/decl.c:12346
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "%qs is geen static veld"
 
-#: cp/decl.c:12350
+#: cp/decl.c:12374
 #, fuzzy, gcc-internal-format
 msgid "non-static data member %qE declared %<concept%>"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.c:12354
+#: cp/decl.c:12378
 #, fuzzy, gcc-internal-format
 msgid "non-static data member %qE declared %<constexpr%>"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.c:12409
+#: cp/decl.c:12433
 #, fuzzy, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/decl.c:12411
+#: cp/decl.c:12435
 #, fuzzy, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/decl.c:12415
+#: cp/decl.c:12439
 #, fuzzy, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/decl.c:12418
+#: cp/decl.c:12442
 #, fuzzy, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/decl.c:12423
+#: cp/decl.c:12447
 #, fuzzy, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: cp/decl.c:12434
+#: cp/decl.c:12458
 #, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.c:12438
+#: cp/decl.c:12462
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.c:12446
+#: cp/decl.c:12470
 #, fuzzy, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/decl.c:12453
+#: cp/decl.c:12477
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr ""
 
-#: cp/decl.c:12454
+#: cp/decl.c:12478
 #, fuzzy, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/decl.c:12489
+#: cp/decl.c:12513
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr ""
@@ -43575,78 +43619,78 @@
 
 #. 7.1.1: There can be no static function declarations within a
 #. block.
-#: cp/decl.c:12497
+#: cp/decl.c:12521
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr ""
 
-#: cp/decl.c:12533
+#: cp/decl.c:12557
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr ""
 
-#: cp/decl.c:12540
+#: cp/decl.c:12564
 #, fuzzy, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/decl.c:12546
+#: cp/decl.c:12570
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr ""
 
-#: cp/decl.c:12553
+#: cp/decl.c:12577
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "de zwakke declaratie van %qs moet aan de definitie voorafgaan"
 
-#: cp/decl.c:12574
+#: cp/decl.c:12598
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "de declaratie van %qs is %<extern%> en heeft een beginwaarde"
 
-#: cp/decl.c:12585
+#: cp/decl.c:12609
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs krijgt beginwaarde en is als %<extern%> gedeclareerd"
 
-#: cp/decl.c:12589
+#: cp/decl.c:12613
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs heeft zowel %<extern%> als een beginwaarde"
 
-#: cp/decl.c:12754
+#: cp/decl.c:12778
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "ongeldig type-argument %qs"
 
-#: cp/decl.c:12757
+#: cp/decl.c:12781
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "ongeldig type-argument %qs"
 
 # Of is 'verbiedt parameterdeclaraties op voorhand' beter?
-#: cp/decl.c:12841
+#: cp/decl.c:12865
 #, fuzzy, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "ISO C verbiedt voorwaartse declaraties van parameters"
 
-#: cp/decl.c:12845
+#: cp/decl.c:12869
 #, fuzzy, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "attributen genegeerd in declarator van parameter-array"
 
-#: cp/decl.c:12868
+#: cp/decl.c:12892
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "parameter %qs als void gedeclareerd"
 
-#: cp/decl.c:12895
+#: cp/decl.c:12919
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.c:12897
+#: cp/decl.c:12921
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr ""
@@ -43666,169 +43710,169 @@
 #. or implicitly defined), there's no need to worry about their
 #. existence.  Theoretically, they should never even be
 #. instantiated, but that's hard to forestall.
-#: cp/decl.c:13150
+#: cp/decl.c:13174
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr ""
 
-#: cp/decl.c:13228
+#: cp/decl.c:13252
 #, fuzzy, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/decl.c:13234
+#: cp/decl.c:13258
 #, fuzzy, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/decl.c:13261
+#: cp/decl.c:13285
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/decl.c:13267
+#: cp/decl.c:13291
 #, fuzzy, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/decl.c:13277
+#: cp/decl.c:13301
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr ""
 
 #. 13.4.0.3
-#: cp/decl.c:13303
+#: cp/decl.c:13327
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading operator ?:"
 msgstr ""
 
 #. Variadic.
-#: cp/decl.c:13314
+#: cp/decl.c:13338
 #, fuzzy, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.c:13338
+#: cp/decl.c:13362
 #, fuzzy, gcc-internal-format
 msgid "%qD must have either zero or one argument"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.c:13339
+#: cp/decl.c:13363
 #, fuzzy, gcc-internal-format
 msgid "%qD must have either one or two arguments"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.c:13350
+#: cp/decl.c:13374
 #, fuzzy, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.c:13351
+#: cp/decl.c:13375
 #, fuzzy, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.c:13361
+#: cp/decl.c:13385
 #, fuzzy, gcc-internal-format
 msgid "%qD must have no arguments"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.c:13362 cp/decl.c:13371
+#: cp/decl.c:13386 cp/decl.c:13395
 #, fuzzy, gcc-internal-format
 msgid "%qD must have exactly one argument"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.c:13372
+#: cp/decl.c:13396
 #, fuzzy, gcc-internal-format
 msgid "%qD must have exactly two arguments"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.c:13389 cp/decl.c:13392
+#: cp/decl.c:13413 cp/decl.c:13416
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/decl.c:13419
+#: cp/decl.c:13443
 #, gcc-internal-format
 msgid "conversion to a reference to void will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13421
+#: cp/decl.c:13445
 #, gcc-internal-format
 msgid "conversion to void will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13428
+#: cp/decl.c:13452
 #, gcc-internal-format
 msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13430
+#: cp/decl.c:13454
 #, gcc-internal-format
 msgid "conversion to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13438
+#: cp/decl.c:13462
 #, gcc-internal-format
 msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13440
+#: cp/decl.c:13464
 #, gcc-internal-format
 msgid "conversion to a base class will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13455
+#: cp/decl.c:13479
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr ""
 
-#: cp/decl.c:13474
+#: cp/decl.c:13498
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.c:13480
+#: cp/decl.c:13504
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.c:13492
+#: cp/decl.c:13516
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr ""
 
-#: cp/decl.c:13547
+#: cp/decl.c:13571
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr ""
 
-#: cp/decl.c:13570
+#: cp/decl.c:13594
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr ""
 
-#: cp/decl.c:13573
+#: cp/decl.c:13597
 #, fuzzy, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "beginwaarde ontbreekt"
 
-#: cp/decl.c:13575
+#: cp/decl.c:13599
 #, fuzzy, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "dit is een eerdere declaratie"
 
-#: cp/decl.c:13583
+#: cp/decl.c:13607
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr ""
 
-#: cp/decl.c:13584 cp/decl.c:13591
+#: cp/decl.c:13608 cp/decl.c:13615
 #, fuzzy, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr "dit is een eerdere declaratie"
 
-#: cp/decl.c:13590
+#: cp/decl.c:13614
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr ""
@@ -43840,94 +43884,94 @@
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:13605
+#: cp/decl.c:13629
 #, fuzzy, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/decl.c:13659 cp/name-lookup.c:4652
+#: cp/decl.c:13683 cp/name-lookup.c:4652
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr ""
 
-#: cp/decl.c:13689 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6425
-#: cp/pt.c:9209
+#: cp/decl.c:13713 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6428
+#: cp/pt.c:9223
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qs is geen iterator"
 
-#: cp/decl.c:13694
+#: cp/decl.c:13718
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:13703 cp/name-lookup.c:4079 cp/name-lookup.c:4086
-#: cp/name-lookup.c:4939 cp/parser.c:6376 cp/parser.c:26300
+#: cp/decl.c:13727 cp/name-lookup.c:4079 cp/name-lookup.c:4086
+#: cp/name-lookup.c:4939 cp/parser.c:6379 cp/parser.c:26297
 #, fuzzy, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "grootte van %qs is %u bytes"
 
-#: cp/decl.c:13806
+#: cp/decl.c:13830
 #, fuzzy, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "sectie van %qs geeft een conflict met een eerdere declaratie"
 
-#: cp/decl.c:13842
+#: cp/decl.c:13866
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "ingebouwde functie %qs als niet-functie gedeclareerd"
 
-#: cp/decl.c:13982
+#: cp/decl.c:14006
 #, fuzzy, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "overtollige elementen in beginwaarde van union"
 
-#: cp/decl.c:13989
+#: cp/decl.c:14013
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr ""
 
-#: cp/decl.c:14000
+#: cp/decl.c:14024
 #, fuzzy, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/decl.c:14025
+#: cp/decl.c:14049
 #, fuzzy, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "%qs is geen typedef of ingebouwd type"
 
-#: cp/decl.c:14055
+#: cp/decl.c:14079
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr ""
 
-#: cp/decl.c:14057
+#: cp/decl.c:14081
 #, fuzzy, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "herhaalde case-waarde"
 
-#: cp/decl.c:14202
+#: cp/decl.c:14226
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14205 cp/decl.c:14213 cp/decl.c:14225 cp/parser.c:18284
+#: cp/decl.c:14229 cp/decl.c:14237 cp/decl.c:14249 cp/parser.c:18281
 #, fuzzy, gcc-internal-format
 msgid "previous definition here"
 msgstr "eerdere definitie van %qs"
 
-#: cp/decl.c:14210
+#: cp/decl.c:14234
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14222
+#: cp/decl.c:14246
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14300
+#: cp/decl.c:14324
 #, fuzzy, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr "grootte van array %qs is van een niet-integer type"
@@ -43936,78 +43980,78 @@
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:14447
+#: cp/decl.c:14471
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr ""
 
-#: cp/decl.c:14619
+#: cp/decl.c:14643
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "enumeratiewaarde voor %qE is geen integerconstante"
 
-#: cp/decl.c:14629
+#: cp/decl.c:14653
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "enumeratiewaarde voor %qE is geen integerconstante"
 
-#: cp/decl.c:14678
+#: cp/decl.c:14702
 #, fuzzy, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "ISO C beperkt enumeratiewaarden tot het bereik van het %<int%> type"
 
-#: cp/decl.c:14679
+#: cp/decl.c:14703
 #, fuzzy, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "ISO C beperkt enumeratiewaarden tot het bereik van het %<int%> type"
 
-#: cp/decl.c:14690
+#: cp/decl.c:14714
 #, fuzzy, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "overflow in enumeratiewaarden"
 
-#: cp/decl.c:14710
+#: cp/decl.c:14734
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qE is not an integer constant"
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "enumeratiewaarde voor %qE is geen integerconstante"
 
-#: cp/decl.c:14821
+#: cp/decl.c:14845
 #, fuzzy, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "type van teruggeefwaarde is onvolledig"
 
-#: cp/decl.c:14999 cp/typeck.c:9286
+#: cp/decl.c:15023 cp/typeck.c:9286
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr ""
 
-#: cp/decl.c:15344
+#: cp/decl.c:15368
 #, fuzzy, gcc-internal-format
 msgid "invalid function declaration"
 msgstr "herhaalde label-declaratie %qs"
 
-#: cp/decl.c:15786
+#: cp/decl.c:15810
 #, fuzzy, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr "%<return%> zonder waarde in een functie die een niet-void waarde teruggeeft"
 
-#: cp/decl.c:15788 cp/typeck.c:9166
+#: cp/decl.c:15812 cp/typeck.c:9166
 #, fuzzy, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "de terugkeerwaarde van een functie kan geen funtie zijn"
 
-#: cp/decl.c:15996
+#: cp/decl.c:16020
 #, fuzzy, gcc-internal-format
 msgid "invalid member function declaration"
 msgstr "herhaalde label-declaratie %qs"
 
-#: cp/decl.c:16010
+#: cp/decl.c:16034
 #, fuzzy, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "kan klasse '%s' niet vinden"
 
-#: cp/decl.c:16386
+#: cp/decl.c:16410
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -44047,7 +44091,7 @@
 msgid "deleting %qT is undefined"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/decl2.c:585 cp/pt.c:5552
+#: cp/decl2.c:585 cp/pt.c:5566
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "herdeclaratie van %qs"
@@ -44060,7 +44104,7 @@
 #. [temp.mem]
 #.
 #. A destructor shall not be a member template.
-#: cp/decl2.c:640 cp/pt.c:5511
+#: cp/decl2.c:640 cp/pt.c:5525
 #, fuzzy, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "%<%s %s%> binnen parameterlijst gedeclareerd"
@@ -44235,47 +44279,47 @@
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr ""
 
-#: cp/decl2.c:2660
+#: cp/decl2.c:2650
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2664
+#: cp/decl2.c:2654
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2669
+#: cp/decl2.c:2659
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2677
+#: cp/decl2.c:2667
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr ""
 
-#: cp/decl2.c:2695
+#: cp/decl2.c:2685
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2699
+#: cp/decl2.c:2689
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2704
+#: cp/decl2.c:2694
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2711
+#: cp/decl2.c:2701
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr ""
 
-#: cp/decl2.c:4309
+#: cp/decl2.c:4299
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using unnamed type, is used but never defined"
 msgstr "label %qs gebruikt maar niet gedefinieerd"
@@ -44284,62 +44328,62 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4318
+#: cp/decl2.c:4308
 #, fuzzy, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr "eerdere declaratie van %qs"
 
-#: cp/decl2.c:4322
+#: cp/decl2.c:4312
 #, fuzzy, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr "eerdere declaratie van %qs"
 
-#: cp/decl2.c:4326
+#: cp/decl2.c:4316
 #, gcc-internal-format
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr ""
 
-#: cp/decl2.c:4334
+#: cp/decl2.c:4324
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "label %qs gebruikt maar niet gedefinieerd"
 
-#: cp/decl2.c:4338
+#: cp/decl2.c:4328
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4341
+#: cp/decl2.c:4331
 #, fuzzy, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "eerdere declaratie van %qs"
 
-#: cp/decl2.c:4529
+#: cp/decl2.c:4519
 #, fuzzy, gcc-internal-format
 msgid "mangling of %q#D as %qE conflicts with a previous mangle"
 msgstr "sectie van %qs geeft een conflict met een eerdere declaratie"
 
-#: cp/decl2.c:4532
+#: cp/decl2.c:4522
 #, fuzzy, gcc-internal-format
 msgid "previous mangling %q#D"
 msgstr "eerdere declaratie van %qs"
 
-#: cp/decl2.c:4534
+#: cp/decl2.c:4524
 #, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr ""
 
-#: cp/decl2.c:4606 cp/decl2.c:4609
+#: cp/decl2.c:4596 cp/decl2.c:4599
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.c:4956
+#: cp/decl2.c:4946
 #, fuzzy, gcc-internal-format
 msgid "inline function %qD used but never defined"
 msgstr "label %qs gebruikt maar niet gedefinieerd"
 
-#: cp/decl2.c:5143
+#: cp/decl2.c:5133
 #, fuzzy, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr "parameternaam ontbreekt uit parameterlijst"
@@ -44346,17 +44390,17 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5251
+#: cp/decl2.c:5241
 #, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.c:5254
+#: cp/decl2.c:5244
 #, fuzzy, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "kan functie %<main%> niet inline maken"
 
-#: cp/decl2.c:5307
+#: cp/decl2.c:5297
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr ""
@@ -44643,333 +44687,333 @@
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr "herdefinitie van %<struct %s%>"
 
-#: cp/init.c:613
+#: cp/init.c:629
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr ""
 
-#: cp/init.c:615
+#: cp/init.c:631
 #, fuzzy, gcc-internal-format
 msgid "defined here"
 msgstr "%qs tevoren hier gedefinieerd"
 
-#: cp/init.c:673
+#: cp/init.c:689
 #, fuzzy, gcc-internal-format
 msgid "initializer for flexible array member %q#D"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/init.c:699
+#: cp/init.c:715
 #, fuzzy, gcc-internal-format
 msgid "%qD should be initialized in the member initialization list"
 msgstr "ongeldige beginwaarde"
 
-#: cp/init.c:720
+#: cp/init.c:736
 #, fuzzy, gcc-internal-format
 msgid "%qD is initialized with itself"
 msgstr "%qs is hier niet gedeclareerd (eerste gebruik in deze functie)"
 
-#: cp/init.c:831
+#: cp/init.c:847
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for array member %q#D"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/init.c:845 cp/init.c:869 cp/init.c:2410 cp/method.c:1368
+#: cp/init.c:861 cp/init.c:885 cp/init.c:2427 cp/method.c:1368
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/init.c:847 cp/init.c:864 cp/init.c:871 cp/init.c:2395 cp/init.c:2423
+#: cp/init.c:863 cp/init.c:880 cp/init.c:887 cp/init.c:2412 cp/init.c:2440
 #: cp/method.c:1371 cp/method.c:1382
 #, fuzzy, gcc-internal-format
 msgid "%q#D should be initialized"
 msgstr "parameter %qs krijgt beginwaarde"
 
-#: cp/init.c:862 cp/init.c:2382 cp/method.c:1379
+#: cp/init.c:878 cp/init.c:2399 cp/method.c:1379
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/init.c:1041
+#: cp/init.c:1057
 #, fuzzy, gcc-internal-format
 msgid "%qD will be initialized after"
 msgstr "parameter %qs krijgt beginwaarde"
 
-#: cp/init.c:1044
+#: cp/init.c:1060
 #, fuzzy, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr "veld %qs heeft al een beginwaarde gekregen"
 
-#: cp/init.c:1048
+#: cp/init.c:1064
 #, fuzzy, gcc-internal-format
 msgid "  %q#D"
 msgstr "%s voor %qs"
 
-#: cp/init.c:1050
+#: cp/init.c:1066
 #, fuzzy, gcc-internal-format
 msgid "  base %qT"
 msgstr "%s voor %qs"
 
-#: cp/init.c:1052
+#: cp/init.c:1068
 #, fuzzy, gcc-internal-format
 msgid "  when initialized here"
 msgstr "parameter %qs krijgt beginwaarde"
 
-#: cp/init.c:1069
+#: cp/init.c:1085
 #, fuzzy, gcc-internal-format
 msgid "multiple initializations given for %qD"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: cp/init.c:1073
+#: cp/init.c:1089
 #, fuzzy, gcc-internal-format
 msgid "multiple initializations given for base %qT"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: cp/init.c:1158
+#: cp/init.c:1174
 #, fuzzy, gcc-internal-format
 msgid "initializations for multiple members of %qT"
 msgstr "beginwaarde legt grootte van %qs niet vast"
 
-#: cp/init.c:1255
+#: cp/init.c:1271
 #, gcc-internal-format
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr ""
 
-#: cp/init.c:1482 cp/init.c:1501
+#: cp/init.c:1498 cp/init.c:1517
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr ""
 
-#: cp/init.c:1488
+#: cp/init.c:1504
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr ""
 
-#: cp/init.c:1495
+#: cp/init.c:1511
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr "%qs is geen static veld"
 
-#: cp/init.c:1534
+#: cp/init.c:1550
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr ""
 
-#: cp/init.c:1542
+#: cp/init.c:1558
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr ""
 
-#: cp/init.c:1589
+#: cp/init.c:1605
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr ""
 
-#: cp/init.c:1597
+#: cp/init.c:1613
 #, fuzzy, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/init.c:1600
+#: cp/init.c:1616
 #, fuzzy, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/init.c:1710 cp/init.c:4386 cp/typeck2.c:1175
+#: cp/init.c:1727 cp/init.c:4402 cp/typeck2.c:1175
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
 
-#: cp/init.c:2019 cp/semantics.c:3268
+#: cp/init.c:2036 cp/semantics.c:3271
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qs is geen iterator"
 
-#: cp/init.c:2075
+#: cp/init.c:2092
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr ""
 
-#: cp/init.c:2089
+#: cp/init.c:2106
 #, fuzzy, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr "bitveld %qs heeft een negatieve breedte"
 
-#: cp/init.c:2175 cp/typeck.c:1893
+#: cp/init.c:2192 cp/typeck.c:1893
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/init.c:2182 cp/semantics.c:1835
+#: cp/init.c:2199 cp/semantics.c:1835
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "ongeldig gebruik van onvolledige typedef %qs"
 
-#: cp/init.c:2379
+#: cp/init.c:2396
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2387
+#: cp/init.c:2404
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2391
+#: cp/init.c:2408
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/init.c:2407
+#: cp/init.c:2424
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr "beginwaarde legt grootte van %qs niet vast"
 
-#: cp/init.c:2415
+#: cp/init.c:2432
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2419
+#: cp/init.c:2436
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr "beginwaarde legt grootte van %qs niet vast"
 
-#: cp/init.c:2710
+#: cp/init.c:2727
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2721
+#: cp/init.c:2738
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2732
+#: cp/init.c:2749
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2880
+#: cp/init.c:2896
 #, fuzzy, gcc-internal-format
 msgid "integer overflow in array size"
 msgstr "integer overflow in expressie"
 
-#: cp/init.c:2890
+#: cp/init.c:2906
 #, gcc-internal-format
 msgid "array size in new-expression must be constant"
 msgstr ""
 
-#: cp/init.c:2904
+#: cp/init.c:2920
 #, fuzzy, gcc-internal-format
 msgid "variably modified type not allowed in new-expression"
 msgstr "argument %d is alleen-lezen"
 
-#: cp/init.c:2920
+#: cp/init.c:2936
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by typedef"
 msgstr ""
 
-#: cp/init.c:2922
+#: cp/init.c:2938
 #, gcc-internal-format
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr ""
 
-#: cp/init.c:2932
+#: cp/init.c:2948
 #, gcc-internal-format
 msgid "invalid type %<void%> for new"
 msgstr ""
 
-#: cp/init.c:2975
+#: cp/init.c:2991
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr "beginwaarde legt grootte van %qs niet vast"
 
-#: cp/init.c:3101
+#: cp/init.c:3117
 #, fuzzy, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr "kan klasse '%s' niet vinden"
 
-#: cp/init.c:3108 cp/search.c:1023
+#: cp/init.c:3124 cp/search.c:1026
 #, fuzzy, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "grootte van %qs is %u bytes"
 
-#: cp/init.c:3181
+#: cp/init.c:3197
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr ""
 
-#: cp/init.c:3184
+#: cp/init.c:3200
 #, gcc-internal-format
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr ""
 
-#: cp/init.c:3187
+#: cp/init.c:3203
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr ""
 
-#: cp/init.c:3370
+#: cp/init.c:3386
 #, fuzzy, gcc-internal-format
 msgid "parenthesized initializer in array new"
 msgstr "attributen genegeerd in declarator van parameter-array"
 
-#: cp/init.c:3633
+#: cp/init.c:3649
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr ""
 
-#: cp/init.c:3665
+#: cp/init.c:3681
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr ""
 
-#: cp/init.c:3674
+#: cp/init.c:3690
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr ""
 
-#: cp/init.c:3743
+#: cp/init.c:3759
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete [] operator:"
 msgstr ""
 
-#: cp/init.c:3747
+#: cp/init.c:3763
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete [] will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4295
+#: cp/init.c:4311
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr ""
 
-#: cp/init.c:4599
+#: cp/init.c:4615
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr ""
 
-#: cp/init.c:4623
+#: cp/init.c:4639
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete operator:"
 msgstr ""
 
-#: cp/init.c:4628
+#: cp/init.c:4644
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4642
+#: cp/init.c:4658
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4647
+#: cp/init.c:4663
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4954
+#: cp/init.c:4970
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr ""
@@ -45441,7 +45485,7 @@
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/name-lookup.c:5111 cp/name-lookup.c:7065
+#: cp/name-lookup.c:5111 cp/name-lookup.c:7073
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "attribuut-commando %qD wordt genegeerd"
@@ -45488,53 +45532,53 @@
 msgid "it was later defined here"
 msgstr "%qs tevoren hier gedefinieerd"
 
-#: cp/name-lookup.c:6687
+#: cp/name-lookup.c:6695
 #, gcc-internal-format
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn't a template"
 msgstr ""
 
-#: cp/name-lookup.c:7059
+#: cp/name-lookup.c:7067
 #, fuzzy, gcc-internal-format
 msgid "strong using directive no longer supported"
 msgstr "-pipe wordt niet ondersteund"
 
-#: cp/name-lookup.c:7062
+#: cp/name-lookup.c:7070
 #, gcc-internal-format
 msgid "you may use an inline namespace instead"
 msgstr ""
 
-#: cp/name-lookup.c:7079
+#: cp/name-lookup.c:7087
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on local using directive"
 msgstr "herhaalde definitie %qs"
 
-#: cp/name-lookup.c:7163
+#: cp/name-lookup.c:7171
 #, fuzzy, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:7183
+#: cp/name-lookup.c:7191
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot nest more than %d namespaces"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/name-lookup.c:7218
+#: cp/name-lookup.c:7226
 #, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr ""
 
-#: cp/name-lookup.c:7219
+#: cp/name-lookup.c:7227
 #, fuzzy, gcc-internal-format
 msgid "%qD defined here"
 msgstr "label %qs gedefinieerd maar niet gebruikt"
 
-#: cp/name-lookup.c:7292
+#: cp/name-lookup.c:7300
 #, gcc-internal-format
 msgid "XXX entering pop_everything ()\n"
 msgstr ""
 
-#: cp/name-lookup.c:7301
+#: cp/name-lookup.c:7309
 #, gcc-internal-format
 msgid "XXX leaving pop_everything ()\n"
 msgstr ""
@@ -45554,7 +45598,7 @@
 msgid "LEXER_DEBUGGING_ENABLED_P is not set to true"
 msgstr ""
 
-#: cp/parser.c:1352 cp/parser.c:37254
+#: cp/parser.c:1352 cp/parser.c:37251
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -45579,7 +45623,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr "grootte van %qs is %u bytes"
 
-#: cp/parser.c:2949 cp/parser.c:18221
+#: cp/parser.c:2949 cp/parser.c:18218
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "%<%.*s%> is niet gedefinieerd"
@@ -45659,7 +45703,7 @@
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "overflow in constante expressie"
 
-#: cp/parser.c:3143 cp/pt.c:17853
+#: cp/parser.c:3143 cp/pt.c:17890
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr ""
@@ -45881,7 +45925,7 @@
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr ""
 
-#: cp/parser.c:4587 cp/parser.c:12940
+#: cp/parser.c:4587 cp/parser.c:12937
 #, fuzzy, gcc-internal-format
 msgid "expected declaration"
 msgstr "lege declaratie"
@@ -45933,7 +45977,7 @@
 msgid "fold-expressions only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:5275 cp/parser.c:5452 cp/parser.c:5630 cp/semantics.c:3612
+#: cp/parser.c:5275 cp/parser.c:5452 cp/parser.c:5633 cp/semantics.c:3615
 #, fuzzy, gcc-internal-format
 msgid "expected primary-expression"
 msgstr "ongeldige waarheidsexpressie"
@@ -45953,92 +45997,92 @@
 msgid "local variable %qD may not appear in this context"
 msgstr ""
 
-#: cp/parser.c:5787
+#: cp/parser.c:5790
 #, fuzzy, gcc-internal-format
 msgid "expected id-expression"
 msgstr "ongeldige waarheidsexpressie"
 
-#: cp/parser.c:5919
+#: cp/parser.c:5922
 #, fuzzy, gcc-internal-format
 msgid "scope %qT before %<~%> is not a class-name"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.c:5948 cp/parser.c:7860
+#: cp/parser.c:5951 cp/parser.c:7860
 #, gcc-internal-format
 msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:6059
+#: cp/parser.c:6062
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<~%T%> as member of %qT"
 msgstr "de declaratie van %qs verbergt een parameter"
 
-#: cp/parser.c:6074
+#: cp/parser.c:6077
 #, fuzzy, gcc-internal-format
 msgid "typedef-name %qD used as destructor declarator"
 msgstr "parameter %qs heeft enkel een voorwaartse declaratie"
 
-#: cp/parser.c:6111 cp/parser.c:20249
+#: cp/parser.c:6114 cp/parser.c:20246
 #, fuzzy, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:6220
+#: cp/parser.c:6223
 #, gcc-internal-format
 msgid "found %<:%> in nested-name-specifier, expected %<::%>"
 msgstr ""
 
-#: cp/parser.c:6288
+#: cp/parser.c:6291
 #, fuzzy, gcc-internal-format
 msgid "decltype evaluates to %qT, which is not a class or enumeration type"
 msgstr "%qs is smaller dan waarden van zijn type"
 
-#: cp/parser.c:6314
+#: cp/parser.c:6317
 #, fuzzy, gcc-internal-format
 msgid "function template-id %qD in nested-name-specifier"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/parser.c:6322
+#: cp/parser.c:6325
 #, fuzzy, gcc-internal-format
 msgid "variable template-id %qD in nested-name-specifier"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/parser.c:6426 cp/typeck.c:2684 cp/typeck.c:2687 cp/typeck.c:2704
+#: cp/parser.c:6429 cp/typeck.c:2684 cp/typeck.c:2687 cp/typeck.c:2704
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.c:6504
+#: cp/parser.c:6507
 #, fuzzy, gcc-internal-format
 msgid "expected nested-name-specifier"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/parser.c:6711 cp/parser.c:8950
+#: cp/parser.c:6714 cp/parser.c:8950
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/parser.c:6797
+#: cp/parser.c:6800
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a %<typeid%> expression"
 msgstr "types in voorwaardelijke expressie komen niet overeen"
 
-#: cp/parser.c:6889
+#: cp/parser.c:6892
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "te weinig argumenten voor functie %<va_start%>"
 
-#: cp/parser.c:6901 cp/pt.c:18416
+#: cp/parser.c:6904 cp/pt.c:18453
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "te weinig argumenten voor functie %<va_start%>"
 
-#: cp/parser.c:6995
+#: cp/parser.c:6998
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids compound-literals"
 msgstr "ISO C++ verbiedt het gebruik van samengestelde expressies als lvalues"
 
-#: cp/parser.c:7054
+#: cp/parser.c:7057
 #, gcc-internal-format
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
@@ -46168,7 +46212,7 @@
 msgid "capture of non-variable %qE"
 msgstr "%s van alleen-lezen variabele %qs"
 
-#: cp/parser.c:10391 cp/parser.c:10401 cp/semantics.c:3453 cp/semantics.c:3465
+#: cp/parser.c:10391 cp/parser.c:10401 cp/semantics.c:3456 cp/semantics.c:3468
 #, fuzzy, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "%qs tevoren hier gedeclareerd"
@@ -46254,7 +46298,7 @@
 msgid "init-statement in selection statements only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:11546 cp/parser.c:28490
+#: cp/parser.c:11546 cp/parser.c:28487
 #, fuzzy, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "herdeclaratie van %qs"
@@ -46275,558 +46319,558 @@
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:12250 cp/parser.c:28493
+#: cp/parser.c:12250 cp/parser.c:28490
 #, fuzzy, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "herdeclaratie van %qs"
 
-#: cp/parser.c:12298
+#: cp/parser.c:12297
 #, gcc-internal-format
 msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/parser.c:12426
+#: cp/parser.c:12423
 #, fuzzy, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr "kan functie %<main%> niet inline maken"
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:12434
+#: cp/parser.c:12431
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ verbiedt geneste functies"
 
-#: cp/parser.c:12447 cp/parser.c:28496
+#: cp/parser.c:12444 cp/parser.c:28493
 #, fuzzy, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "ongeldige beginwaarde"
 
-#: cp/parser.c:12620 cp/parser.c:23584
+#: cp/parser.c:12617 cp/parser.c:23581
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr ""
 
-#: cp/parser.c:12863
+#: cp/parser.c:12860
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr ""
 
-#: cp/parser.c:13083
+#: cp/parser.c:13080
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:13103
+#: cp/parser.c:13100
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr ""
 
-#: cp/parser.c:13124
+#: cp/parser.c:13121
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr ""
 
-#: cp/parser.c:13148
+#: cp/parser.c:13145
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/parser.c:13203
+#: cp/parser.c:13200
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13206
+#: cp/parser.c:13203
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13257
+#: cp/parser.c:13254
 #, gcc-internal-format
 msgid "structured bindings only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:13306
+#: cp/parser.c:13303
 #, fuzzy, gcc-internal-format
 msgid "empty structured binding declaration"
 msgstr "lege declaratie"
 
-#: cp/parser.c:13324
+#: cp/parser.c:13321
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for structured binding declaration"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/parser.c:13491
+#: cp/parser.c:13488
 #, fuzzy, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/parser.c:13558
+#: cp/parser.c:13555
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr ""
 
-#: cp/parser.c:13594
+#: cp/parser.c:13591
 #, fuzzy, gcc-internal-format
 msgid "decl-specifier invalid in condition"
 msgstr "herdefinitie van %<union %s%>"
 
-#: cp/parser.c:13600
+#: cp/parser.c:13597
 #, fuzzy, gcc-internal-format
 msgid "%qD invalid in lambda"
 msgstr "Ongeldige optie %qs"
 
-#: cp/parser.c:13693
+#: cp/parser.c:13690
 #, fuzzy, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "%qs mag niet als alleen-lezen gedeclareerd worden"
 
-#: cp/parser.c:13763 cp/parser.c:24064
+#: cp/parser.c:13760 cp/parser.c:24061
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:13805
+#: cp/parser.c:13802
 #, fuzzy, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr "ongeldige linker operand van %s"
 
-#: cp/parser.c:13909
+#: cp/parser.c:13906
 #, gcc-internal-format
 msgid "static_assert without a message only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:14111
+#: cp/parser.c:14108
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr "types in voorwaardelijke expressie komen niet overeen"
 
-#: cp/parser.c:14264
+#: cp/parser.c:14261
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.c:14291
+#: cp/parser.c:14288
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "%s laat qualifiers van doeltype van pointer vallen"
 
-#: cp/parser.c:14295
+#: cp/parser.c:14292
 #, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr ""
 
-#: cp/parser.c:14379
+#: cp/parser.c:14376
 #, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr ""
 
-#: cp/parser.c:14406
+#: cp/parser.c:14403
 #, fuzzy, gcc-internal-format
 msgid "cannot expand initializer for member %qD"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/parser.c:14418 cp/pt.c:24255
+#: cp/parser.c:14415 cp/pt.c:24333
 #, fuzzy, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "%Jdeclaratie van %qD als static volgt declaratie als niet-static"
 
-#: cp/parser.c:14430 cp/pt.c:24267
+#: cp/parser.c:14427 cp/pt.c:24345
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
 
-#: cp/parser.c:14482
+#: cp/parser.c:14479
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr ""
 
-#: cp/parser.c:14552
+#: cp/parser.c:14549
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:14927
+#: cp/parser.c:14924
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr ""
 
-#: cp/parser.c:14933
+#: cp/parser.c:14930
 #, fuzzy, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:14942
+#: cp/parser.c:14939
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr ""
 
-#: cp/parser.c:14948
+#: cp/parser.c:14945
 #, fuzzy, gcc-internal-format
 msgid "invalid encoding prefix in literal operator"
 msgstr "ongeldige const_double operand"
 
-#: cp/parser.c:14975
+#: cp/parser.c:14972
 #, fuzzy, gcc-internal-format
 msgid "expected operator"
 msgstr "onverwachte operand"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:15020
+#: cp/parser.c:15017
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr ""
 
-#: cp/parser.c:15190
+#: cp/parser.c:15187
 #, fuzzy, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr "ongeldig gebruik van onvolledige typedef %qs"
 
-#: cp/parser.c:15198
+#: cp/parser.c:15195
 #, fuzzy, gcc-internal-format
 msgid "cv-qualified type parameter"
 msgstr "ongeldige macronaam %<%.*s%>"
 
-#: cp/parser.c:15283
+#: cp/parser.c:15280
 #, gcc-internal-format
 msgid "variadic constraint introduced without %<...%>"
 msgstr ""
 
-#: cp/parser.c:15347
+#: cp/parser.c:15344
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/parser.c:15582 cp/parser.c:15668 cp/parser.c:21694
+#: cp/parser.c:15579 cp/parser.c:15665 cp/parser.c:21691
 #, fuzzy, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/parser.c:15586 cp/parser.c:15672
+#: cp/parser.c:15583 cp/parser.c:15669
 #, fuzzy, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: cp/parser.c:15738
+#: cp/parser.c:15735
 #, fuzzy, gcc-internal-format
 msgid "expected template-id"
 msgstr "ongeldige beginwaarde"
 
-#: cp/parser.c:15798
+#: cp/parser.c:15795
 #, fuzzy, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.c:15802
+#: cp/parser.c:15799
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr ""
 
-#: cp/parser.c:15806
+#: cp/parser.c:15803
 #, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr ""
 
-#: cp/parser.c:15924
+#: cp/parser.c:15921
 #, fuzzy, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "%qs is geen iterator"
 
 #. The name does not name a template.
-#: cp/parser.c:15992 cp/parser.c:16122 cp/parser.c:16337
+#: cp/parser.c:15989 cp/parser.c:16119 cp/parser.c:16334
 #, fuzzy, gcc-internal-format
 msgid "expected template-name"
 msgstr "ongeldige beginwaarde"
 
 #. Explain what went wrong.
-#: cp/parser.c:16038
+#: cp/parser.c:16035
 #, fuzzy, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr "parameter %qs heeft enkel een voorwaartse declaratie"
 
-#: cp/parser.c:16040
+#: cp/parser.c:16037
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr ""
 
-#: cp/parser.c:16189
+#: cp/parser.c:16186
 #, fuzzy, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr "top-level declaratie van %qs specifieert %<auto%>"
 
-#: cp/parser.c:16298 cp/parser.c:16316 cp/parser.c:16483
+#: cp/parser.c:16295 cp/parser.c:16313 cp/parser.c:16480
 #, fuzzy, gcc-internal-format
 msgid "expected template-argument"
 msgstr "ongeldige beginwaarde"
 
-#: cp/parser.c:16458
+#: cp/parser.c:16455
 #, fuzzy, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr "ongeldig type-argument %qs"
 
-#: cp/parser.c:16585
+#: cp/parser.c:16582
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/parser.c:16589
+#: cp/parser.c:16586
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/parser.c:16648
+#: cp/parser.c:16645
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr ""
 
-#: cp/parser.c:16869
+#: cp/parser.c:16866
 #, fuzzy, gcc-internal-format
 msgid "expected type specifier"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/parser.c:17053
+#: cp/parser.c:17050
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:17059
+#: cp/parser.c:17056
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
 # Of is 'verbiedt parameterdeclaraties op voorhand' beter?
-#: cp/parser.c:17064
+#: cp/parser.c:17061
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -fconcepts"
 msgstr "ISO C verbiedt voorwaartse declaraties van parameters"
 
-#: cp/parser.c:17209
+#: cp/parser.c:17206
 #, fuzzy, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "herdeclaratie van %qs"
 
-#: cp/parser.c:17278
+#: cp/parser.c:17275
 #, fuzzy, gcc-internal-format
 msgid "expected type-name"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:17631
+#: cp/parser.c:17628
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr ""
 
-#: cp/parser.c:17854
+#: cp/parser.c:17851
 #, fuzzy, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "declaratie declareert niets"
 
-#: cp/parser.c:17942
+#: cp/parser.c:17939
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr ""
 
-#: cp/parser.c:17946
+#: cp/parser.c:17943
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "herhaalde definitie %qs"
 
-#: cp/parser.c:17951
+#: cp/parser.c:17948
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr ""
 
-#: cp/parser.c:18085
+#: cp/parser.c:18082
 #, fuzzy, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.c:18096
+#: cp/parser.c:18093
 #, fuzzy, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr "%qs is smaller dan waarden van zijn type"
 
-#: cp/parser.c:18111
+#: cp/parser.c:18108
 #, fuzzy, gcc-internal-format
 msgid "unnamed scoped enum is not allowed"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/parser.c:18166
+#: cp/parser.c:18163
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:18215
+#: cp/parser.c:18212
 #, fuzzy, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "herhaalde definitie %qs"
 
-#: cp/parser.c:18229
+#: cp/parser.c:18226
 #, fuzzy, gcc-internal-format
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "ingebouwde functie %qs als niet-functie gedeclareerd"
 
-#: cp/parser.c:18241 cp/parser.c:23070
+#: cp/parser.c:18238 cp/parser.c:23067
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/parser.c:18246 cp/parser.c:23075
+#: cp/parser.c:18243 cp/parser.c:23072
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/parser.c:18258 cp/parser.c:23089
+#: cp/parser.c:18255 cp/parser.c:23086
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr ""
 
-#: cp/parser.c:18282
+#: cp/parser.c:18279
 #, fuzzy, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "herdefinitie van %qs"
 
-#: cp/parser.c:18295
+#: cp/parser.c:18292
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO C++ verbiedt het %sen van een enum"
 
-#: cp/parser.c:18315
+#: cp/parser.c:18312
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:18318
+#: cp/parser.c:18315
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:18497
+#: cp/parser.c:18494
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.c:18503
+#: cp/parser.c:18500
 #, fuzzy, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:18570
+#: cp/parser.c:18567
 #, gcc-internal-format
 msgid "nested namespace definitions only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:18578
+#: cp/parser.c:18575
 #, fuzzy, gcc-internal-format
 msgid "nested namespace name required"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:18583
+#: cp/parser.c:18580
 #, gcc-internal-format
 msgid "namespace name required"
 msgstr ""
 
-#: cp/parser.c:18587
+#: cp/parser.c:18584
 #, fuzzy, gcc-internal-format
 msgid "a nested namespace definition cannot have attributes"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/parser.c:18590
+#: cp/parser.c:18587
 #, fuzzy, gcc-internal-format
 msgid "a nested namespace definition cannot be inline"
 msgstr "kan functie %<main%> niet inline maken"
 
-#: cp/parser.c:18597
+#: cp/parser.c:18594
 #, fuzzy, gcc-internal-format
 msgid "namespace %qD entered"
 msgstr "modi in %s expressie komen niet overeen"
 
-#: cp/parser.c:18652
+#: cp/parser.c:18649
 #, fuzzy, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/parser.c:18803
+#: cp/parser.c:18800
 #, gcc-internal-format
 msgid "pack expansion in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:18818
+#: cp/parser.c:18815
 #, fuzzy, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/parser.c:18865
+#: cp/parser.c:18862
 #, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:18875
+#: cp/parser.c:18872
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:18940
+#: cp/parser.c:18937
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "geen eerdere declaratie voor %qs"
 
-#: cp/parser.c:19106
+#: cp/parser.c:19103
 #, fuzzy, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr "kan functie %<main%> niet inline maken"
 
-#: cp/parser.c:19493
+#: cp/parser.c:19490
 #, fuzzy, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/parser.c:19504
+#: cp/parser.c:19501
 #, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr ""
 
-#: cp/parser.c:19508
+#: cp/parser.c:19505
 #, fuzzy, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: cp/parser.c:19559
+#: cp/parser.c:19556
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
 #. Anything else is an error.
-#: cp/parser.c:19598 cp/parser.c:21906
+#: cp/parser.c:19595 cp/parser.c:21903
 #, fuzzy, gcc-internal-format
 msgid "expected initializer"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:19679
+#: cp/parser.c:19676
 #, fuzzy, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "ingebouwde functie %qs kan niet uitgeschakeld worden"
 
-#: cp/parser.c:19713
+#: cp/parser.c:19710
 #, fuzzy, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "attributen genegeerd in declarator van parameter-array"
 
-#: cp/parser.c:19727
+#: cp/parser.c:19724
 #, fuzzy, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr "functie %qs geherdeclareerd als inline"
 
-#: cp/parser.c:20169
+#: cp/parser.c:20166
 #, fuzzy, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "array subscript is geen integer"
 
-#: cp/parser.c:20295
+#: cp/parser.c:20292
 #, fuzzy, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr "herhaald lid %qs"
 
-#: cp/parser.c:20299
+#: cp/parser.c:20296
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "%qs is geen iterator"
@@ -46835,17 +46879,17 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:20328
+#: cp/parser.c:20325
 #, fuzzy, gcc-internal-format
 msgid "invalid declarator"
 msgstr "herdeclaratie van %qs"
 
-#: cp/parser.c:20336
+#: cp/parser.c:20333
 #, fuzzy, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/parser.c:20338
+#: cp/parser.c:20335
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr ""
@@ -46852,382 +46896,382 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:20410
+#: cp/parser.c:20407
 #, fuzzy, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr "nutteloze type-kwalificatie in lege declaratie"
 
-#: cp/parser.c:20435
+#: cp/parser.c:20432
 #, fuzzy, gcc-internal-format
 msgid "expected declarator"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/parser.c:20554
+#: cp/parser.c:20551
 #, fuzzy, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.c:20556
+#: cp/parser.c:20553
 #, fuzzy, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "herhaald lid %qs"
 
-#: cp/parser.c:20577
+#: cp/parser.c:20574
 #, fuzzy, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "onverwachte operand"
 
-#: cp/parser.c:20638
+#: cp/parser.c:20635
 #, fuzzy, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "herhaalde case-waarde"
 
-#: cp/parser.c:20692
+#: cp/parser.c:20689
 #, fuzzy, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr "herhaalde case-waarde"
 
-#: cp/parser.c:20729
+#: cp/parser.c:20726
 #, gcc-internal-format
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr ""
 
-#: cp/parser.c:20787
+#: cp/parser.c:20784
 #, fuzzy, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "herhaalde case-waarde"
 
-#: cp/parser.c:21025
+#: cp/parser.c:21022
 #, fuzzy, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr "eerste argument van %qs zou een %<int%> moeten zijn"
 
-#: cp/parser.c:21031 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2090
+#: cp/parser.c:21028 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2093
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: cp/parser.c:21052
+#: cp/parser.c:21049
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.c:21057
+#: cp/parser.c:21054
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "ongeldig type-argument %qs"
 
-#: cp/parser.c:21145
+#: cp/parser.c:21142
 #, fuzzy, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:21429
+#: cp/parser.c:21426
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:21504
+#: cp/parser.c:21501
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.c:21678
+#: cp/parser.c:21675
 #, fuzzy, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "argumenten aan macro %qs gegeven"
 
-#: cp/parser.c:21696
+#: cp/parser.c:21693
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/parser.c:21702
+#: cp/parser.c:21699
 #, fuzzy, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/parser.c:21704
+#: cp/parser.c:21701
 #, fuzzy, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/parser.c:22131
+#: cp/parser.c:22128
 #, gcc-internal-format
 msgid "C++ designated initializers only available with -std=c++2a or -std=gnu++2a"
 msgstr ""
 
-#: cp/parser.c:22151
+#: cp/parser.c:22148
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr "ISO C++ staat het gebruik van %<varargs.h%> niet toe"
 
-#: cp/parser.c:22189
+#: cp/parser.c:22186
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C++ staat het gebruik van %<varargs.h%> niet toe"
 
-#: cp/parser.c:22203
+#: cp/parser.c:22200
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr ""
 
-#: cp/parser.c:22228
+#: cp/parser.c:22225
 #, fuzzy, gcc-internal-format
 msgid "%<...%> not allowed in designated initializer list"
 msgstr "ISO C++ staat het gebruik van %<varargs.h%> niet toe"
 
-#: cp/parser.c:22266
+#: cp/parser.c:22263
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr ""
 
-#: cp/parser.c:22322 cp/parser.c:22448
+#: cp/parser.c:22319 cp/parser.c:22445
 #, fuzzy, gcc-internal-format
 msgid "expected class-name"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:22650
+#: cp/parser.c:22647
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "%J%qD als inline gedeclareerd na zijn definitie"
 
-#: cp/parser.c:22653
+#: cp/parser.c:22650
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "%J%qD als inline gedeclareerd na zijn definitie"
 
-#: cp/parser.c:22656
+#: cp/parser.c:22653
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "conflicterende declaraties van %qs"
 
-#: cp/parser.c:23012
+#: cp/parser.c:23009
 #, fuzzy, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:23023
+#: cp/parser.c:23020
 #, fuzzy, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "[kan %s niet vinden]"
 
-#: cp/parser.c:23031
+#: cp/parser.c:23028
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:23038
+#: cp/parser.c:23035
 #, fuzzy, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "ingebouwde functie %qs als niet-functie gedeclareerd"
 
-#: cp/parser.c:23050
+#: cp/parser.c:23047
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr ""
 
-#: cp/parser.c:23056
+#: cp/parser.c:23053
 #, fuzzy, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "herdeclaratie van %qs"
 
-#: cp/parser.c:23114
+#: cp/parser.c:23111
 #, fuzzy, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/parser.c:23146
+#: cp/parser.c:23143
 #, fuzzy, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "parameter %qs heeft enkel een voorwaartse declaratie"
 
-#: cp/parser.c:23182
+#: cp/parser.c:23179
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr ""
 
-#: cp/parser.c:23241
+#: cp/parser.c:23238
 #, fuzzy, gcc-internal-format
 msgid "previous definition of %q#T"
 msgstr "eerdere definitie van %qs"
 
-#: cp/parser.c:23331 cp/parser.c:28499
+#: cp/parser.c:23328 cp/parser.c:28496
 #, fuzzy, gcc-internal-format
 msgid "expected class-key"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:23355
+#: cp/parser.c:23352
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:23359
+#: cp/parser.c:23356
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:23605
+#: cp/parser.c:23602
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr ""
 
-#: cp/parser.c:23623
+#: cp/parser.c:23620
 #, fuzzy, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "ingebouwde functie %qs als niet-functie gedeclareerd"
 
-#: cp/parser.c:23641
+#: cp/parser.c:23638
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:23738
+#: cp/parser.c:23735
 #, gcc-internal-format
 msgid "default member initializers for bit-fields only available with -std=c++2a or -std=gnu++2a"
 msgstr ""
 
-#: cp/parser.c:23745
+#: cp/parser.c:23742
 #, fuzzy, gcc-internal-format
 msgid "default member initializer for unnamed bit-field"
 msgstr "%<__alignof%> toegepast op bitveld"
 
-#: cp/parser.c:23758
+#: cp/parser.c:23755
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr ""
 
-#: cp/parser.c:23903
+#: cp/parser.c:23900
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr ""
 
-#: cp/parser.c:23923
+#: cp/parser.c:23920
 #, fuzzy, gcc-internal-format
 msgid "extra %<;%> after in-class function definition"
 msgstr "%J%qD als inline gedeclareerd na zijn definitie"
 
-#: cp/parser.c:23970
+#: cp/parser.c:23967
 #, fuzzy, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr "attributen genegeerd in declarator van parameter-array"
 
-#: cp/parser.c:23984
+#: cp/parser.c:23981
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:24058
+#: cp/parser.c:24055
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr ""
 
-#: cp/parser.c:24093
+#: cp/parser.c:24090
 #, fuzzy, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/parser.c:24223
+#: cp/parser.c:24220
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr ""
 
-#: cp/parser.c:24243
+#: cp/parser.c:24240
 #, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr ""
 
-#: cp/parser.c:24267
+#: cp/parser.c:24264
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr ""
 
-#: cp/parser.c:24270
+#: cp/parser.c:24267
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:24364 cp/parser.c:24442
+#: cp/parser.c:24361 cp/parser.c:24439
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "%qs gedeclareerd als een functie die een functie teruggeeft"
 
-#: cp/parser.c:24450
+#: cp/parser.c:24447
 #, fuzzy, gcc-internal-format
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "%qs gedeclareerd als een functie die een functie teruggeeft"
 
-#: cp/parser.c:24456
+#: cp/parser.c:24453
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr ""
 
-#: cp/parser.c:24500
+#: cp/parser.c:24497
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "%s laat qualifiers van doeltype van pointer vallen"
 
-#: cp/parser.c:24539
+#: cp/parser.c:24536
 #, fuzzy, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr "kan functie %<main%> niet inline maken"
 
-#: cp/parser.c:24650
+#: cp/parser.c:24647
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/parser.c:25203
+#: cp/parser.c:25200
 #, gcc-internal-format
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr ""
 
-#: cp/parser.c:25217
+#: cp/parser.c:25214
 #, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr ""
 
-#: cp/parser.c:25301
+#: cp/parser.c:25298
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:25305
+#: cp/parser.c:25302
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:25342
+#: cp/parser.c:25339
 #, fuzzy, gcc-internal-format
 msgid "expected attribute before %<...%>"
 msgstr "top-level declaratie van %qs specifieert %<auto%>"
 
-#: cp/parser.c:25403
+#: cp/parser.c:25400
 #, gcc-internal-format
 msgid "attribute using prefix only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:25721
+#: cp/parser.c:25718
 #, gcc-internal-format
 msgid "%<requires%> only available with -fconcepts"
 msgstr ""
 
-#: cp/parser.c:25753
+#: cp/parser.c:25750
 #, fuzzy, gcc-internal-format
 msgid "a requires expression cannot appear outside a template"
 msgstr "overflow in constante expressie"
 
-#: cp/parser.c:26467
+#: cp/parser.c:26464
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:26472
+#: cp/parser.c:26469
 #, fuzzy, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "herdeclaratie van %qs"
 
-#: cp/parser.c:26476
+#: cp/parser.c:26473
 #, fuzzy, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "twee of meer data types in de declaratie van %qs"
@@ -47236,456 +47280,456 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:26483
+#: cp/parser.c:26480
 #, fuzzy, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/parser.c:26832
+#: cp/parser.c:26829
 #, fuzzy, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "-pipe wordt niet ondersteund"
 
-#: cp/parser.c:26991
+#: cp/parser.c:26988
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr ""
 
-#: cp/parser.c:26996
+#: cp/parser.c:26993
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr ""
 
-#: cp/parser.c:27066
+#: cp/parser.c:27063
 #, fuzzy, gcc-internal-format
 msgid "empty introduction-list"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: cp/parser.c:27090
+#: cp/parser.c:27087
 #, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr ""
 
-#: cp/parser.c:27112
+#: cp/parser.c:27109
 #, fuzzy, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "herdeclaratie van %<enum %s%>"
 
-#: cp/parser.c:27121
+#: cp/parser.c:27118
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr ""
 
-#: cp/parser.c:27141
+#: cp/parser.c:27138
 #, fuzzy, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "ongeldige linker operand van %s"
 
-#: cp/parser.c:27245
+#: cp/parser.c:27242
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "herdeclaratie van %qs"
 
-#: cp/parser.c:27296
+#: cp/parser.c:27293
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "a class template declaration must not declare anything else"
 msgstr "declaratie declareert niets"
 
-#: cp/parser.c:27342
+#: cp/parser.c:27339
 #, fuzzy, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/parser.c:27650
+#: cp/parser.c:27647
 #, fuzzy, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.c:27663
+#: cp/parser.c:27660
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr ""
 
-#: cp/parser.c:27958
+#: cp/parser.c:27955
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:28118
+#: cp/parser.c:28115
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "ongeldige linker operand van %s"
 
-#: cp/parser.c:28133
+#: cp/parser.c:28130
 #, fuzzy, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> vóór %<extern%> gebruikt"
 
-#: cp/parser.c:28267
+#: cp/parser.c:28264
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ ondersteunt %<long long%> niet"
 
-#: cp/parser.c:28275
+#: cp/parser.c:28272
 #, fuzzy, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "zowel %<short%> als %<char%> opgegeven bij declaratie"
 
-#: cp/parser.c:28280
+#: cp/parser.c:28277
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "herhaalde %qs"
 
-#: cp/parser.c:28304
+#: cp/parser.c:28301
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "herhaalde %qs"
 
-#: cp/parser.c:28356
+#: cp/parser.c:28353
 #, fuzzy, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:28359
+#: cp/parser.c:28356
 #, fuzzy, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:28362
+#: cp/parser.c:28359
 #, fuzzy, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:28368
+#: cp/parser.c:28365
 #, fuzzy, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:28371
+#: cp/parser.c:28368
 #, fuzzy, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "ongeldige beginwaarde"
 
-#: cp/parser.c:28374
+#: cp/parser.c:28371
 #, fuzzy, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:28377
+#: cp/parser.c:28374
 #, fuzzy, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:28380
+#: cp/parser.c:28377
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:28383
+#: cp/parser.c:28380
 #, fuzzy, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:28386
+#: cp/parser.c:28383
 #, fuzzy, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:28389
+#: cp/parser.c:28386
 #, fuzzy, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:28392
+#: cp/parser.c:28389
 #, fuzzy, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:28395
+#: cp/parser.c:28392
 #, fuzzy, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:28398
+#: cp/parser.c:28395
 #, fuzzy, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:28401
+#: cp/parser.c:28398
 #, fuzzy, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:28404
+#: cp/parser.c:28401
 #, fuzzy, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:28407
+#: cp/parser.c:28404
 #, fuzzy, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:28410
+#: cp/parser.c:28407
 #, fuzzy, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:28413
+#: cp/parser.c:28410
 #, fuzzy, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:28416
+#: cp/parser.c:28413
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.c:28419
+#: cp/parser.c:28416
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr ""
 
-#: cp/parser.c:28451
+#: cp/parser.c:28448
 #, fuzzy, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:28463
+#: cp/parser.c:28460
 #, fuzzy, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:28466
+#: cp/parser.c:28463
 #, fuzzy, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:28469
+#: cp/parser.c:28466
 #, fuzzy, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:28475
+#: cp/parser.c:28472
 #, fuzzy, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:28502
+#: cp/parser.c:28499
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:28772
+#: cp/parser.c:28769
 #, fuzzy, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "Ongeldige optie %qs"
 
-#: cp/parser.c:28777
+#: cp/parser.c:28774
 #, fuzzy, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "dit is een eerdere declaratie"
 
-#: cp/parser.c:28798
+#: cp/parser.c:28795
 #, fuzzy, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qs als ander soort symbool geherdeclareerd"
 
-#: cp/parser.c:28819
+#: cp/parser.c:28816
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr ""
 
-#: cp/parser.c:29062
+#: cp/parser.c:29059
 #, fuzzy, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "ongeldig type-argument %qs"
 
-#: cp/parser.c:29303 cp/parser.c:30620 cp/parser.c:30808
+#: cp/parser.c:29300 cp/parser.c:30617 cp/parser.c:30805
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr ""
 
-#: cp/parser.c:29372
+#: cp/parser.c:29369
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/parser.c:29442
+#: cp/parser.c:29439
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:29473
+#: cp/parser.c:29470
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr ""
 
-#: cp/parser.c:29883
+#: cp/parser.c:29880
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr ""
 
-#: cp/parser.c:29958 cp/parser.c:29976
+#: cp/parser.c:29955 cp/parser.c:29973
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/parser.c:29970 cp/parser.c:30035
+#: cp/parser.c:29967 cp/parser.c:30032
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr ""
 
-#: cp/parser.c:30078
+#: cp/parser.c:30075
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:30284 cp/parser.c:30291 cp/parser.c:30298
+#: cp/parser.c:30281 cp/parser.c:30288 cp/parser.c:30295
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr ""
 
-#: cp/parser.c:30413
+#: cp/parser.c:30410
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr ""
 
-#: cp/parser.c:30585
+#: cp/parser.c:30582
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:30592
+#: cp/parser.c:30589
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "prefix-attributen worden genegeerd vóór %<@%D%>"
 
-#: cp/parser.c:30867 cp/parser.c:30874 cp/parser.c:30881
+#: cp/parser.c:30864 cp/parser.c:30871 cp/parser.c:30878
 #, fuzzy, gcc-internal-format
 msgid "invalid type for property"
 msgstr "ongeldige operand voor 'p' modifier"
 
-#: cp/parser.c:32011
+#: cp/parser.c:32008
 #, fuzzy, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/parser.c:32724
+#: cp/parser.c:32721
 #, fuzzy, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr "ongeldige beginwaarde"
 
-#: cp/parser.c:34911
+#: cp/parser.c:34908
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:35231 cp/pt.c:16392
+#: cp/parser.c:35228 cp/pt.c:16414
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "registervariabele %qs gebruikt in geneste functie"
 
-#: cp/parser.c:35316
+#: cp/parser.c:35313
 #, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr ""
 
-#: cp/parser.c:37521
+#: cp/parser.c:37518
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr "ongeldige beginwaarde"
 
-#: cp/parser.c:37549
+#: cp/parser.c:37546
 #, fuzzy, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "ongeldige waarheidsexpressie"
 
-#: cp/parser.c:37561
+#: cp/parser.c:37558
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:37662
+#: cp/parser.c:37659
 #, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr ""
 
-#: cp/parser.c:37682 cp/semantics.c:5405
+#: cp/parser.c:37679 cp/semantics.c:5408
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37687 cp/semantics.c:5414
+#: cp/parser.c:37684 cp/semantics.c:5417
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37690 cp/pt.c:12944 cp/semantics.c:5420
+#: cp/parser.c:37687 cp/pt.c:12966 cp/semantics.c:5423
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37693 cp/semantics.c:5426
+#: cp/parser.c:37690 cp/semantics.c:5429
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:38047
+#: cp/parser.c:38044
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:38057
+#: cp/parser.c:38054
 #, fuzzy, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr "%qs is meestal een functie"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:38392
+#: cp/parser.c:38389
 #, gcc-internal-format
 msgid "atomic_cancel"
 msgstr ""
 
-#: cp/parser.c:38435 cp/semantics.c:8575
+#: cp/parser.c:38432 cp/semantics.c:8578
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:38437 cp/semantics.c:8577
+#: cp/parser.c:38434 cp/semantics.c:8580
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:38631
+#: cp/parser.c:38628
 #, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "rommel aan einde van %<#pragma GCC pch_preprocess%>"
 
 # 'braced-group'? Wie schrijft verdorie die foutmeldingen?
-#: cp/parser.c:38927
+#: cp/parser.c:38924
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "accolade-groep in expressie enkel toegestaan binnen een functie"
 
 # 'braced-group'? Wie schrijft verdorie die foutmeldingen?
-#: cp/parser.c:38959
+#: cp/parser.c:38956
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr "accolade-groep in expressie enkel toegestaan binnen een functie"
 
-#: cp/parser.c:39039
+#: cp/parser.c:39036
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr ""
 
-#: cp/parser.c:39295
+#: cp/parser.c:39292
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:39351
+#: cp/parser.c:39348
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
@@ -47773,7 +47817,7 @@
 msgstr "de declaratie van %qs is %<extern%> en heeft een beginwaarde"
 
 # XXX FIXME:  useless gettextization
-#: cp/pt.c:1954 cp/semantics.c:5274
+#: cp/pt.c:1954 cp/semantics.c:5277
 #, fuzzy, gcc-internal-format
 #| msgid "%s %qs"
 msgid "%s %#qD"
@@ -47940,107 +47984,107 @@
 msgid "argument to __integer_pack must be between 0 and %d"
 msgstr "herhalings-aantal is geen integerconstante"
 
-#: cp/pt.c:3942
+#: cp/pt.c:3955
 #, gcc-internal-format
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr ""
 
-#: cp/pt.c:4010
+#: cp/pt.c:4023
 #, fuzzy, gcc-internal-format
 msgid "expansion pattern %qT contains no argument packs"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/pt.c:4012
+#: cp/pt.c:4025
 #, fuzzy, gcc-internal-format
 msgid "expansion pattern %qE contains no argument packs"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/pt.c:4063
+#: cp/pt.c:4077
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr ""
 
-#: cp/pt.c:4080 cp/pt.c:4835
+#: cp/pt.c:4094 cp/pt.c:4849
 #, gcc-internal-format
 msgid "        %qD"
 msgstr ""
 
-#: cp/pt.c:4082
+#: cp/pt.c:4096
 #, fuzzy, gcc-internal-format
 msgid "        <anonymous>"
 msgstr "<anoniem>"
 
-#: cp/pt.c:4208
+#: cp/pt.c:4222
 #, fuzzy, gcc-internal-format
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr "de declaratie van %qs verbergt een parameter"
 
-#: cp/pt.c:4211
+#: cp/pt.c:4225
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q+#D shadows template parameter"
 msgstr "de declaratie van %qs verbergt een parameter"
 
-#: cp/pt.c:4213
+#: cp/pt.c:4227
 #, fuzzy, gcc-internal-format
 msgid "template parameter %qD declared here"
 msgstr "parameter %qs als void gedeclareerd"
 
-#: cp/pt.c:4771
+#: cp/pt.c:4785
 #, fuzzy, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr "herdeclaratie van %<enum %s%>"
 
-#: cp/pt.c:4830
+#: cp/pt.c:4844
 #, fuzzy, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: cp/pt.c:4854
+#: cp/pt.c:4868
 #, fuzzy, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/pt.c:4858
+#: cp/pt.c:4872
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:4862 cp/pt.c:4873
+#: cp/pt.c:4876 cp/pt.c:4887
 #, gcc-internal-format
 msgid "primary template here"
 msgstr ""
 
-#: cp/pt.c:4870
+#: cp/pt.c:4884
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:4885
+#: cp/pt.c:4899
 #, fuzzy, gcc-internal-format
 msgid "partial specialization %qD is not more specialized than"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/pt.c:4887
+#: cp/pt.c:4901
 #, fuzzy, gcc-internal-format
 msgid "primary template %qD"
 msgstr "herhaald label %qs"
 
-#: cp/pt.c:4934
+#: cp/pt.c:4948
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:4937
+#: cp/pt.c:4951
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:4958
+#: cp/pt.c:4972
 #, fuzzy, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr "argument %d is alleen-lezen"
 
-#: cp/pt.c:5004
+#: cp/pt.c:5018
 #, fuzzy, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
@@ -48047,17 +48091,17 @@
 msgstr[0] "argument %d is alleen-lezen"
 msgstr[1] "argument %d is alleen-lezen"
 
-#: cp/pt.c:5066
+#: cp/pt.c:5080
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "herhaalde definitie %qs"
 
-#: cp/pt.c:5070
+#: cp/pt.c:5084
 #, fuzzy, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "de declaratie van %qs is %<extern%> en heeft een beginwaarde"
 
-#: cp/pt.c:5247
+#: cp/pt.c:5261
 #, fuzzy, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "ongeldig type-argument %qs"
@@ -48065,47 +48109,47 @@
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5269
+#: cp/pt.c:5283
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "macro %qs gebruikt zonder argumenten"
 
-#: cp/pt.c:5305
+#: cp/pt.c:5319
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr ""
 
-#: cp/pt.c:5308
+#: cp/pt.c:5322
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "argumenten aan macro %qs gegeven"
 
-#: cp/pt.c:5311
+#: cp/pt.c:5325
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/pt.c:5314
+#: cp/pt.c:5328
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr ""
 
-#: cp/pt.c:5317 cp/pt.c:5375
+#: cp/pt.c:5331 cp/pt.c:5389
 #, fuzzy, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "eerste argument van %qs zou een %<int%> moeten zijn"
 
-#: cp/pt.c:5489
+#: cp/pt.c:5503
 #, fuzzy, gcc-internal-format
 msgid "template %qD declared"
 msgstr "parameter %qs als void gedeclareerd"
 
-#: cp/pt.c:5496
+#: cp/pt.c:5510
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr ""
 
-#: cp/pt.c:5504
+#: cp/pt.c:5518
 #, fuzzy, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
@@ -48115,57 +48159,57 @@
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5526
+#: cp/pt.c:5540
 #, fuzzy, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "herhaalde label-declaratie %qs"
 
-#: cp/pt.c:5669
+#: cp/pt.c:5683
 #, fuzzy, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "herdefinitie van %<union %s%>"
 
-#: cp/pt.c:5712
+#: cp/pt.c:5726
 #, fuzzy, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/pt.c:5726
+#: cp/pt.c:5740
 #, fuzzy, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/pt.c:5729
+#: cp/pt.c:5743
 #, fuzzy, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/pt.c:5731
+#: cp/pt.c:5745
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr ""
 
-#: cp/pt.c:5752
+#: cp/pt.c:5766
 #, fuzzy, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: cp/pt.c:5755
+#: cp/pt.c:5769
 #, fuzzy, gcc-internal-format
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "ongeldige linker operand van %s"
 
-#: cp/pt.c:5882
+#: cp/pt.c:5896
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:5895
+#: cp/pt.c:5909
 #, fuzzy, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "twee of meer data types in de declaratie van %qs"
 
-#: cp/pt.c:5906
+#: cp/pt.c:5920
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
@@ -48172,7 +48216,7 @@
 msgstr[0] "macro %qs gebruikt zonder argumenten"
 msgstr[1] "macro %qs gebruikt zonder argumenten"
 
-#: cp/pt.c:5910
+#: cp/pt.c:5924
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
@@ -48179,12 +48223,12 @@
 msgstr[0] "eerdere declaratie van %qs"
 msgstr[1] "eerdere declaratie van %qs"
 
-#: cp/pt.c:5947
+#: cp/pt.c:5961
 #, fuzzy, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/pt.c:5948
+#: cp/pt.c:5962
 #, fuzzy, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "ongeldige naam %qs"
@@ -48193,117 +48237,117 @@
 #.
 #. A template-parameter may not be given default arguments
 #. by two different declarations in the same scope.
-#: cp/pt.c:5958
+#: cp/pt.c:5972
 #, fuzzy, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "herdefinitie van %<struct %s%>"
 
-#: cp/pt.c:5960
+#: cp/pt.c:5974
 #, fuzzy, gcc-internal-format
 msgid "original definition appeared here"
 msgstr "functie-definitie als %<typdef%> gedeclareerd"
 
-#: cp/pt.c:5988
+#: cp/pt.c:6002
 #, fuzzy, gcc-internal-format
 msgid "redeclaration %q#D with different constraints"
 msgstr "ingebouwde functie %qs als niet-functie gedeclareerd"
 
-#: cp/pt.c:5991
+#: cp/pt.c:6005
 #, fuzzy, gcc-internal-format
 msgid "original declaration appeared here"
 msgstr "functie-definitie als %<typdef%> gedeclareerd"
 
-#: cp/pt.c:6250 cp/pt.c:6318
+#: cp/pt.c:6264 cp/pt.c:6332
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:6253
+#: cp/pt.c:6267
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6256
+#: cp/pt.c:6270
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6268
+#: cp/pt.c:6282
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:6272
+#: cp/pt.c:6286
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:6321
+#: cp/pt.c:6335
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr ""
 
-#: cp/pt.c:6323
+#: cp/pt.c:6337
 #, fuzzy, gcc-internal-format
 msgid "because it is a member of %qT"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/pt.c:6383
+#: cp/pt.c:6397
 #, fuzzy, gcc-internal-format
 msgid "  couldn't deduce template parameter %qD"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/pt.c:6392
+#: cp/pt.c:6406
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.c:6401
+#: cp/pt.c:6415
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:6410
+#: cp/pt.c:6424
 #, fuzzy, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/pt.c:6421
+#: cp/pt.c:6435
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: cp/pt.c:6431
+#: cp/pt.c:6445
 #, fuzzy, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr "-fPIC is niet geldig met -mcoff"
 
-#: cp/pt.c:6440
+#: cp/pt.c:6454
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:6452
+#: cp/pt.c:6466
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.c:6456
+#: cp/pt.c:6470
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.c:6467
+#: cp/pt.c:6481
 #, fuzzy, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/pt.c:6478
+#: cp/pt.c:6492
 #, fuzzy, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/pt.c:6490
+#: cp/pt.c:6504
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
@@ -48310,294 +48354,294 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/pt.c:6521
+#: cp/pt.c:6535
 #, fuzzy, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/pt.c:6534
+#: cp/pt.c:6548
 #, fuzzy, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/pt.c:6538
+#: cp/pt.c:6552
 #, fuzzy, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "iterator %qs is van een afgeleid type"
 
-#: cp/pt.c:6549
+#: cp/pt.c:6563
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.c:6559
+#: cp/pt.c:6573
 #, fuzzy, gcc-internal-format
 msgid "  can't deduce a template for %qT from non-template type %qT"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/pt.c:6569
+#: cp/pt.c:6583
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: cp/pt.c:6609
+#: cp/pt.c:6623
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr ""
 
-#: cp/pt.c:6758
+#: cp/pt.c:6772
 #, fuzzy, gcc-internal-format
 msgid "in template argument for type %qT"
 msgstr "eerste argument van %qs zou een %<int%> moeten zijn"
 
-#: cp/pt.c:6772
+#: cp/pt.c:6786
 #, fuzzy, gcc-internal-format
 msgid "template argument %qE for type %qT not a constant integer"
 msgstr "eerste argument van %qs zou een %<int%> moeten zijn"
 
-#: cp/pt.c:6833
+#: cp/pt.c:6847
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:6841
+#: cp/pt.c:6855
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:6857
+#: cp/pt.c:6871
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:6864
+#: cp/pt.c:6878
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:6873
+#: cp/pt.c:6887
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:6888
+#: cp/pt.c:6902
 #, fuzzy, gcc-internal-format
 msgid "the address of %qD is not a valid template argument"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/pt.c:6897
+#: cp/pt.c:6911
 #, fuzzy, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/pt.c:6904
+#: cp/pt.c:6918
 #, fuzzy, gcc-internal-format
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:6933
+#: cp/pt.c:6947
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr ""
 
-#: cp/pt.c:6941
+#: cp/pt.c:6955
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:6959
+#: cp/pt.c:6973
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:6975
+#: cp/pt.c:6989
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an object with linkage"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:6986
+#: cp/pt.c:7000
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because object %qD does not have linkage"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:7036
+#: cp/pt.c:7050
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:7038
+#: cp/pt.c:7052
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr ""
 
-#: cp/pt.c:7092
+#: cp/pt.c:7106
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:7654
+#: cp/pt.c:7668
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/pt.c:7670
+#: cp/pt.c:7684
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/pt.c:7805
+#: cp/pt.c:7819
 #, fuzzy, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/pt.c:7834
+#: cp/pt.c:7848
 #, fuzzy, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/pt.c:7839
+#: cp/pt.c:7853
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr ""
 
-#: cp/pt.c:7855 cp/pt.c:7877 cp/pt.c:7931
+#: cp/pt.c:7869 cp/pt.c:7891 cp/pt.c:7945
 #, fuzzy, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/pt.c:7860
+#: cp/pt.c:7874
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr ""
 
-#: cp/pt.c:7865
+#: cp/pt.c:7879
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr ""
 
-#: cp/pt.c:7868
+#: cp/pt.c:7882
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr ""
 
-#: cp/pt.c:7882
+#: cp/pt.c:7896
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr ""
 
-#: cp/pt.c:7885
+#: cp/pt.c:7899
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr ""
 
-#: cp/pt.c:7935
+#: cp/pt.c:7949
 #, fuzzy, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/pt.c:7949
+#: cp/pt.c:7963
 #, fuzzy, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/pt.c:7952
+#: cp/pt.c:7966
 #, fuzzy, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr "eerste argument van %qs zou een %<int%> moeten zijn"
 
-#: cp/pt.c:8012
+#: cp/pt.c:8026
 #, fuzzy, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/pt.c:8149 cp/pt.c:8465
+#: cp/pt.c:8163 cp/pt.c:8479
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "argument %d is alleen-lezen"
 
-#: cp/pt.c:8164 cp/pt.c:8298
+#: cp/pt.c:8178 cp/pt.c:8312
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr ""
 
-#: cp/pt.c:8294
+#: cp/pt.c:8308
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d or more)"
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "verkeerd aantal sjabloonargumenten (%d, moet %d of meer zijn)"
 
-#: cp/pt.c:8303
+#: cp/pt.c:8317
 #, fuzzy, gcc-internal-format
 #| msgid "provided for %q+D"
 msgid "provided for %qD"
 msgstr "gegeven voor %q+D"
 
-#: cp/pt.c:8328
+#: cp/pt.c:8342
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:8332
+#: cp/pt.c:8346
 #, fuzzy, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "argumenten aan macro %qs gegeven"
 
-#: cp/pt.c:8431
+#: cp/pt.c:8445
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:9054
+#: cp/pt.c:9068
 #, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%q#D is geen functiesjabloon"
 
-#: cp/pt.c:9221
+#: cp/pt.c:9235
 #, fuzzy, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "parameter %qs heeft enkel een voorwaartse declaratie"
 
-#: cp/pt.c:9223
+#: cp/pt.c:9237
 #, fuzzy, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "lege declaratie"
 
-#: cp/pt.c:9346
+#: cp/pt.c:9360
 #, fuzzy, gcc-internal-format
 msgid "template constraint failure"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: cp/pt.c:9697
+#: cp/pt.c:9718
 #, fuzzy, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:10125
+#: cp/pt.c:10148
 #, gcc-internal-format, gfc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:11202
+#: cp/pt.c:11225
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD in union"
 msgstr "%Jflexibel array-lid in union"
 
-#: cp/pt.c:11691
+#: cp/pt.c:11713
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:12160
+#: cp/pt.c:12182
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr ""
 
-#: cp/pt.c:12163
+#: cp/pt.c:12185
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr ""
 
-#: cp/pt.c:12747
+#: cp/pt.c:12769
 #, fuzzy, gcc-internal-format
 msgid "  when instantiating default argument for call to %qD"
 msgstr "herdefinitie van %<struct %s%>"
@@ -48615,279 +48659,279 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:13708
+#: cp/pt.c:13730
 #, fuzzy, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/pt.c:13881
+#: cp/pt.c:13903
 #, fuzzy, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "ongeldige operand voor %p-code"
 
-#: cp/pt.c:13883
+#: cp/pt.c:13905
 #, fuzzy, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "herdeclaratie van %qs"
 
-#: cp/pt.c:14001
+#: cp/pt.c:14023
 #, fuzzy, gcc-internal-format
 msgid "function returning an array"
 msgstr "%qs gedeclareerd als een functie die een array teruggeeft"
 
-#: cp/pt.c:14003
+#: cp/pt.c:14025
 #, fuzzy, gcc-internal-format
 msgid "function returning a function"
 msgstr "%qs gedeclareerd als een functie die een functie teruggeeft"
 
-#: cp/pt.c:14043
+#: cp/pt.c:14065
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "pointer naar lid-functie gebruikt in rekensom"
 
-#: cp/pt.c:14637
+#: cp/pt.c:14659
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr ""
 
-#: cp/pt.c:14639
+#: cp/pt.c:14661
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "herhaald lid %qs"
 
-#: cp/pt.c:14641
+#: cp/pt.c:14663
 #, fuzzy, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "herhaald lid %qs"
 
-#: cp/pt.c:14654
+#: cp/pt.c:14676
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "%s laat qualifiers van doeltype van pointer vallen"
 
-#: cp/pt.c:14657
+#: cp/pt.c:14679
 #, fuzzy, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "%s laat qualifiers van doeltype van pointer vallen"
 
-#: cp/pt.c:14705
+#: cp/pt.c:14727
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "herhaald lid %qs"
 
-#: cp/pt.c:14711
+#: cp/pt.c:14733
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "herhaald lid %qs"
 
-#: cp/pt.c:14717
+#: cp/pt.c:14739
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "herhaald lid %qs"
 
-#: cp/pt.c:14783
+#: cp/pt.c:14805
 #, fuzzy, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "doorgeven van argument %d van %qs"
 
-#: cp/pt.c:14816
+#: cp/pt.c:14838
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/pt.c:14853
+#: cp/pt.c:14875
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr ""
 
-#: cp/pt.c:14861
+#: cp/pt.c:14883
 #, fuzzy, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr "%qs is smaller dan waarden van zijn type"
 
-#: cp/pt.c:14925
+#: cp/pt.c:14947
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.c:15000
+#: cp/pt.c:15022
 #, fuzzy, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:15178
+#: cp/pt.c:15200
 #, fuzzy, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "argument %qs komt niet overeen met prototype"
 
-#: cp/pt.c:15193
+#: cp/pt.c:15215
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr ""
 
-#: cp/pt.c:15195
+#: cp/pt.c:15217
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr ""
 
-#: cp/pt.c:15394
+#: cp/pt.c:15416
 #, fuzzy, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "ontbrekende witruimte na getal %qs"
 
-#: cp/pt.c:15883 cp/pt.c:17386
+#: cp/pt.c:15905 cp/pt.c:17408
 #, fuzzy, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "ongeldig gebruik van een void-expressie"
 
-#: cp/pt.c:15887 cp/pt.c:17390
+#: cp/pt.c:15909 cp/pt.c:17412
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr ""
 
-#: cp/pt.c:18334
+#: cp/pt.c:18371
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:18362
+#: cp/pt.c:18399
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:18367
+#: cp/pt.c:18404
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.c:18370
+#: cp/pt.c:18407
 #, fuzzy, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:18375
+#: cp/pt.c:18412
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "%J%qD als inline gedeclareerd na zijn definitie"
 
-#: cp/pt.c:18712
+#: cp/pt.c:18752
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:18715
+#: cp/pt.c:18755
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:19026
+#: cp/pt.c:19066
 #, fuzzy, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr "%qs is smaller dan waarden van zijn type"
 
-#: cp/pt.c:19028
+#: cp/pt.c:19068
 #, fuzzy, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "eerste argument van %qs zou een %<int%> moeten zijn"
 
-#: cp/pt.c:19038
+#: cp/pt.c:19078
 #, fuzzy, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "argument %d is alleen-lezen"
 
-#: cp/pt.c:19053
+#: cp/pt.c:19093
 #, fuzzy, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "beginwaarde-element is niet constant"
 
-#: cp/pt.c:19071
+#: cp/pt.c:19111
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr ""
 
-#: cp/pt.c:22972
+#: cp/pt.c:23050
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "herhaalde definitie %qs"
 
-#: cp/pt.c:22974
+#: cp/pt.c:23052
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "herhaalde definitie %qs"
 
 # XXX FIXME:  useless gettextization
-#: cp/pt.c:22980
+#: cp/pt.c:23058
 #, fuzzy
 #| msgid "%s %qs"
 msgid "%s %#qS"
 msgstr "%s %qs"
 
-#: cp/pt.c:23004 cp/pt.c:23091
+#: cp/pt.c:23082 cp/pt.c:23169
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.c:23023
+#: cp/pt.c:23101
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qs is geen static veld"
 
-#: cp/pt.c:23029 cp/pt.c:23086
+#: cp/pt.c:23107 cp/pt.c:23164
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr ""
 
-#: cp/pt.c:23034
+#: cp/pt.c:23112
 #, fuzzy, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.c:23042
+#: cp/pt.c:23120
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "eerdere impliciete declaratie van %qs"
 
-#: cp/pt.c:23078
+#: cp/pt.c:23156
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "herhaalde definitie %qs"
 
-#: cp/pt.c:23101 cp/pt.c:23187
+#: cp/pt.c:23179 cp/pt.c:23265
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "pointer naar functie gebruikt in aftrekking"
 
-#: cp/pt.c:23106 cp/pt.c:23204
+#: cp/pt.c:23184 cp/pt.c:23282
 #, fuzzy, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "herhaalde definitie %qs"
 
-#: cp/pt.c:23163
+#: cp/pt.c:23241
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.c:23165
+#: cp/pt.c:23243
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.c:23174
+#: cp/pt.c:23252
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.c:23192
+#: cp/pt.c:23270
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "pointer naar functie gebruikt in aftrekking"
 
-#: cp/pt.c:23238
+#: cp/pt.c:23316
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "herhaalde definitie %qs"
 
-#: cp/pt.c:23536
+#: cp/pt.c:23614
 #, fuzzy, gcc-internal-format
 msgid "exception specification of %qD depends on itself"
 msgstr "impliciete declaratie van functie %qs"
@@ -48899,109 +48943,109 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:23842
+#: cp/pt.c:23920
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "eerdere impliciete declaratie van %qs"
 
-#: cp/pt.c:24043
+#: cp/pt.c:24121
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:24418
+#: cp/pt.c:24496
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr ""
 
-#: cp/pt.c:24420
+#: cp/pt.c:24498
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:25723
+#: cp/pt.c:25802
 #, fuzzy, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/pt.c:25961
+#: cp/pt.c:26040
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/pt.c:26440
+#: cp/pt.c:26519
 #, fuzzy, gcc-internal-format
 msgid "non-class template %qT used without template arguments"
 msgstr "parameter %qs heeft enkel een voorwaartse declaratie"
 
-#: cp/pt.c:26586
+#: cp/pt.c:26665
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:26593
+#: cp/pt.c:26672
 #, fuzzy, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:26607
+#: cp/pt.c:26686
 #, fuzzy, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "argument %d is alleen-lezen"
 
-#: cp/pt.c:26614
+#: cp/pt.c:26693
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "functie wordt niet als kandidaat voor inlining beschouwd"
 
-#: cp/pt.c:26676
+#: cp/pt.c:26755
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:26679
+#: cp/pt.c:26758
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:26711
+#: cp/pt.c:26790
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/pt.c:26746
+#: cp/pt.c:26825
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/pt.c:26748
+#: cp/pt.c:26827
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "kan %qs niet nabootsen"
 
-#: cp/pt.c:26781
+#: cp/pt.c:26860
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:26785
+#: cp/pt.c:26864
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not constant"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "beginwaarde-element is niet constant"
 
-#: cp/pt.c:26789
+#: cp/pt.c:26868
 #, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.c:26793
+#: cp/pt.c:26872
 #, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.c:26912
+#: cp/pt.c:26991
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr "ongeldig type-argument %qs"
@@ -49056,77 +49100,77 @@
 msgid "cannot dynamic_cast %qE (of type %q#T) to type %q#T (%s)"
 msgstr ""
 
-#: cp/search.c:240
+#: cp/search.c:243
 #, fuzzy, gcc-internal-format
 msgid "%qT is an ambiguous base of %qT"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/search.c:256
+#: cp/search.c:259
 #, fuzzy, gcc-internal-format
 msgid "%qT is an inaccessible base of %qT"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/search.c:1905
+#: cp/search.c:1908
 #, fuzzy, gcc-internal-format
 msgid "invalid covariant return type for %q#D"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/search.c:1907 cp/search.c:1922 cp/search.c:1928 cp/search.c:1957
+#: cp/search.c:1910 cp/search.c:1925 cp/search.c:1931 cp/search.c:1960
 #, fuzzy, gcc-internal-format
 msgid "overridden function is %q#D"
 msgstr "bibliotheekfunctie %qs wordt verborgen"
 
-#: cp/search.c:1920
+#: cp/search.c:1923
 #, fuzzy, gcc-internal-format
 msgid "invalid covariant return type for %q+#D"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/search.c:1926
+#: cp/search.c:1929
 #, fuzzy, gcc-internal-format
 msgid "conflicting return type specified for %q+#D"
 msgstr "conflicterende types voor %qs"
 
-#: cp/search.c:1942
+#: cp/search.c:1945
 #, fuzzy, gcc-internal-format
 msgid "looser throw specifier for %q+#F"
 msgstr "'long' of 'short' opgegeven bij 'char' voor %qs"
 
-#: cp/search.c:1944
+#: cp/search.c:1947
 #, fuzzy, gcc-internal-format
 msgid "overridden function is %q#F"
 msgstr "bibliotheekfunctie %qs wordt verborgen"
 
-#: cp/search.c:1955
+#: cp/search.c:1958
 #, fuzzy, gcc-internal-format
 msgid "conflicting type attributes specified for %q+#D"
 msgstr "conflicterende types voor %qs"
 
-#: cp/search.c:1972
+#: cp/search.c:1975
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<transaction_safe_dynamic%>"
 msgstr "%qs was als %<extern%> gedeclareerd en daarna als %<static%>"
 
-#: cp/search.c:1974
+#: cp/search.c:1977
 #, fuzzy, gcc-internal-format
 msgid "overriding %qD declared %<transaction_safe%>"
 msgstr "%Jvariabele %qD als %<inline%> gedeclareerd"
 
-#: cp/search.c:1981
+#: cp/search.c:1984
 #, fuzzy, gcc-internal-format
 msgid "deleted function %q+D overriding non-deleted function"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/search.c:1984 cp/search.c:1992 cp/search.c:2000
+#: cp/search.c:1987 cp/search.c:1995 cp/search.c:2003
 #, fuzzy, gcc-internal-format
 msgid "overridden function is %qD"
 msgstr "bibliotheekfunctie %qs wordt verborgen"
 
-#: cp/search.c:1989
+#: cp/search.c:1992
 #, fuzzy, gcc-internal-format
 msgid "non-deleted function %q+D overriding deleted function"
 msgstr "kan functie %<main%> niet inline maken"
 
-#: cp/search.c:1998
+#: cp/search.c:2001
 #, fuzzy, gcc-internal-format
 msgid "virtual function %q+D overriding final function"
 msgstr "%Jingebouwde functie %qD gedeclareerd als niet-functie"
@@ -49133,12 +49177,12 @@
 
 #. A static member function cannot match an inherited
 #. virtual member function.
-#: cp/search.c:2082
+#: cp/search.c:2085
 #, fuzzy, gcc-internal-format
 msgid "%q+#D cannot be declared"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/search.c:2083
+#: cp/search.c:2086
 #, fuzzy, gcc-internal-format
 msgid "  since %q+#D declared in base class"
 msgstr "%qs tevoren hier gedeclareerd"
@@ -49178,587 +49222,602 @@
 msgid "invalid use of member %qD in static member function"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/semantics.c:2153
+#: cp/semantics.c:2156
 #, gcc-internal-format
 msgid "a statement expression is an insufficient context for overload resolution"
 msgstr ""
 
-#: cp/semantics.c:2540
+#: cp/semantics.c:2543
 #, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr ""
 
-#: cp/semantics.c:2622
+#: cp/semantics.c:2625
 #, fuzzy, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/semantics.c:2624
+#: cp/semantics.c:2627
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr "%s laat qualifiers van doeltype van pointer vallen"
 
-#: cp/semantics.c:2626
+#: cp/semantics.c:2629
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr "ongeldig gebruik van %<this%> op hoogste niveau"
 
-#: cp/semantics.c:2648
+#: cp/semantics.c:2651
 #, fuzzy, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "%s laat qualifiers van doeltype van pointer vallen"
 
-#: cp/semantics.c:2656 cp/typeck.c:2604
+#: cp/semantics.c:2659 cp/typeck.c:2604
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/semantics.c:2678
+#: cp/semantics.c:2681
 #, fuzzy, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr "%<%c%> optie gebruikt bij type %<%c%>"
 
-#: cp/semantics.c:2751
+#: cp/semantics.c:2754
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr ""
 
-#: cp/semantics.c:2892
+#: cp/semantics.c:2895
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr ""
 
-#: cp/semantics.c:2942
+#: cp/semantics.c:2945
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr ""
 
-#: cp/semantics.c:2945
+#: cp/semantics.c:2948
 #, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr ""
 
-#: cp/semantics.c:2962
+#: cp/semantics.c:2965
 #, fuzzy, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr "de declaratie van %qs verbergt een symbool uit de parameterlijst"
 
-#: cp/semantics.c:2993
+#: cp/semantics.c:2996
 #, fuzzy, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr "ongeldig gebruik van het niet gedefinieerde type %<%s %s%>"
 
-#: cp/semantics.c:3263
+#: cp/semantics.c:3266
 #, fuzzy, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "ongeldige linker operand van %s"
 
-#: cp/semantics.c:3423
+#: cp/semantics.c:3426
 #, fuzzy, gcc-internal-format
 msgid "cannot capture member %qD of anonymous union"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/semantics.c:3443 cp/semantics.c:9269
+#: cp/semantics.c:3446 cp/semantics.c:9272
 #, fuzzy, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qs is geen iterator"
 
-#: cp/semantics.c:3448
+#: cp/semantics.c:3451
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.c:3450
+#: cp/semantics.c:3453
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.c:3462
+#: cp/semantics.c:3465
 #, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr ""
 
-#: cp/semantics.c:3464
+#: cp/semantics.c:3467
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr ""
 
-#: cp/semantics.c:3596
+#: cp/semantics.c:3599
 #, fuzzy, gcc-internal-format
 msgid "use of parameter outside function body"
 msgstr "kan functie %<main%> niet inline maken"
 
 # Betere term voor "mismatched"?
-#: cp/semantics.c:3606
+#: cp/semantics.c:3609
 #, fuzzy, gcc-internal-format
 #| msgid "mismatched arguments"
 msgid "missing template arguments"
 msgstr "slechte combinatie van argumenten"
 
-#: cp/semantics.c:3633
+#: cp/semantics.c:3636
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr ""
 
-#: cp/semantics.c:3664
+#: cp/semantics.c:3667
 #, fuzzy, gcc-internal-format
 msgid "use of namespace %qD as expression"
 msgstr "modi in %s expressie komen niet overeen"
 
-#: cp/semantics.c:3669
+#: cp/semantics.c:3672
 #, fuzzy, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr "modi in %s expressie komen niet overeen"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:3675
+#: cp/semantics.c:3678
 #, fuzzy, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "grootte van %qs is %u bytes"
 
-#: cp/semantics.c:3702
+#: cp/semantics.c:3705
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "overflow in constante expressie"
 
-#: cp/semantics.c:3841
+#: cp/semantics.c:3844
 #, fuzzy, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "opslaggrootte van %qs is onbekend"
 
-#: cp/semantics.c:3870
+#: cp/semantics.c:3873
 #, fuzzy, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr "%qs is geen iterator"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4009
+#: cp/semantics.c:4012
 #, fuzzy, gcc-internal-format
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr "nutteloze type-kwalificatie in lege declaratie"
 
-#: cp/semantics.c:4038
+#: cp/semantics.c:4041
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr ""
 
-#: cp/semantics.c:4052
+#: cp/semantics.c:4055
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/semantics.c:4056
+#: cp/semantics.c:4059
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/semantics.c:4061
+#: cp/semantics.c:4064
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/semantics.c:4072
+#: cp/semantics.c:4075
 #, gcc-internal-format
 msgid "offsetof within non-standard-layout type %qT is conditionally-supported"
 msgstr ""
 
-#: cp/semantics.c:4583 cp/semantics.c:6069 cp/semantics.c:6140
-#: cp/semantics.c:6183 cp/semantics.c:6533 cp/semantics.c:6632
-#: cp/semantics.c:6775
+#: cp/semantics.c:4586 cp/semantics.c:6072 cp/semantics.c:6143
+#: cp/semantics.c:6186 cp/semantics.c:6536 cp/semantics.c:6635
+#: cp/semantics.c:6778
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5271
+#: cp/semantics.c:5274
 #, fuzzy, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr "grootte van %qs is %u bytes"
 
-#: cp/semantics.c:5544
+#: cp/semantics.c:5547
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: cp/semantics.c:5592
+#: cp/semantics.c:5595
 #, fuzzy, gcc-internal-format
 msgid "%qE has const type for %<reduction%>"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: cp/semantics.c:5707
+#: cp/semantics.c:5710
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:5941
+#: cp/semantics.c:5944
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5955
+#: cp/semantics.c:5958
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5977
+#: cp/semantics.c:5980
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6080
+#: cp/semantics.c:6083
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/semantics.c:6152
+#: cp/semantics.c:6155
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: cp/semantics.c:6195
+#: cp/semantics.c:6198
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: cp/semantics.c:6240
+#: cp/semantics.c:6243
 #, gcc-internal-format
 msgid "%<gang%> static expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6254
+#: cp/semantics.c:6257
 #, fuzzy, gcc-internal-format
 msgid "%<gang%> static value must be positive"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/semantics.c:6288
+#: cp/semantics.c:6291
 #, gcc-internal-format
 msgid "%<gang%> num expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6291
+#: cp/semantics.c:6294
 #, fuzzy, gcc-internal-format
 #| msgid "vectorlength must be an integer constant"
 msgid "%<vector%> length expression must be integral"
 msgstr "vectorlengte moet een integerconstante zijn"
 
-#: cp/semantics.c:6295
+#: cp/semantics.c:6298
 #, gcc-internal-format
 msgid "%<worker%> num expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6317
+#: cp/semantics.c:6320
 #, fuzzy, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/semantics.c:6321
+#: cp/semantics.c:6324
 #, fuzzy, gcc-internal-format
 msgid "%<vector%> length value must be positive"
 msgstr "gevraagd alignment is geen macht van 2"
 
-#: cp/semantics.c:6326
+#: cp/semantics.c:6329
 #, gcc-internal-format
 msgid "%<worker%> num value must be positive"
 msgstr ""
 
-#: cp/semantics.c:6376
+#: cp/semantics.c:6379
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6406
+#: cp/semantics.c:6409
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6419
+#: cp/semantics.c:6422
 #, fuzzy, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: cp/semantics.c:6438
+#: cp/semantics.c:6441
 #, fuzzy, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr "%<defined%> zonder een naam"
 
-#: cp/semantics.c:6466
+#: cp/semantics.c:6469
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6495
+#: cp/semantics.c:6498
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr ""
 
-#: cp/semantics.c:6516
+#: cp/semantics.c:6519
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6543
+#: cp/semantics.c:6546
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/semantics.c:6557
+#: cp/semantics.c:6560
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:6563
+#: cp/semantics.c:6566
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: cp/semantics.c:6576
+#: cp/semantics.c:6579
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6625
+#: cp/semantics.c:6628
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/semantics.c:6910
+#: cp/semantics.c:6913
 #, fuzzy, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr "te veel invoerbestanden"
 
-#: cp/semantics.c:6914
+#: cp/semantics.c:6917
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6979
+#: cp/semantics.c:6982
 #, fuzzy, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr "%<defined%> zonder een naam"
 
-#: cp/semantics.c:7008
+#: cp/semantics.c:7011
 #, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7037
+#: cp/semantics.c:7040
 #, gcc-internal-format
 msgid "%<num_tasks%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7066
+#: cp/semantics.c:7069
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:7105
+#: cp/semantics.c:7108
 #, fuzzy, gcc-internal-format
 msgid "%<tile%> argument needs integral type"
 msgstr "%qs is geen iterator"
 
-#: cp/semantics.c:7524
+#: cp/semantics.c:7527
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.c:7538
+#: cp/semantics.c:7541
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "%Jparameter %u heeft een onvolledig type"
 
-#: cp/semantics.c:7743
+#: cp/semantics.c:7746
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.c:8171
+#: cp/semantics.c:8174
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.c:8398 cp/semantics.c:8408
+#: cp/semantics.c:8401 cp/semantics.c:8411
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.c:8702
+#: cp/semantics.c:8705
 #, fuzzy, gcc-internal-format
 msgid "static assertion failed"
 msgstr "pex_init mislukt"
 
-#: cp/semantics.c:8704
+#: cp/semantics.c:8707
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr ""
 
-#: cp/semantics.c:8709
+#: cp/semantics.c:8712
 #, fuzzy, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "%Jdeclaratie van %qD als niet-static volgt declaratie als static"
 
-#: cp/semantics.c:8739
+#: cp/semantics.c:8742
 #, fuzzy, gcc-internal-format
 msgid "argument to decltype must be an expression"
 msgstr "modi in %s expressie komen niet overeen"
 
-#: cp/semantics.c:8767
+#: cp/semantics.c:8770
 #, fuzzy, gcc-internal-format
 msgid "decltype cannot resolve address of overloaded function"
 msgstr "einde van niet-void functie werd bereikt zonder teruggeefwaarde"
 
-#: cp/semantics.c:9308
+#: cp/semantics.c:9311
 #, fuzzy, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "linker operand van comma-expressie heeft geen effect"
 
-#: cp/semantics.c:9361
+#: cp/semantics.c:9364
 #, fuzzy, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "argument %d is alleen-lezen"
 
-#: cp/semantics.c:9363
+#: cp/semantics.c:9366
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:9381
+#: cp/semantics.c:9384
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %<__builtin_return_address%>"
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "niet-ondersteund argument voor %<__builtin_return_address%>"
 
-#: cp/tree.c:1276
+#: cp/tree.c:1295
 #, gcc-internal-format
 msgid "%qV qualifiers cannot be applied to %qT"
 msgstr ""
 
-#: cp/tree.c:1788
+#: cp/tree.c:1807
 #, fuzzy, gcc-internal-format
 msgid "lambda-expression in a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/tree.c:1792
+#: cp/tree.c:1811
 #, fuzzy, gcc-internal-format
 msgid "statement-expression in a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/tree.c:4050
+#: cp/tree.c:4083
 #, gcc-internal-format
-msgid "the calling convention for %qT changes in -fabi-version=12 (GCC 8)"
+msgid "-fabi-version=13 (GCC 8.2) fixes the calling convention for %qT, which was accidentally changed in 8.1"
 msgstr ""
 
-#: cp/tree.c:4055
+#: cp/tree.c:4087
 #, gcc-internal-format
+msgid "-fabi-version=12 (GCC 8.1) accidentally changes the calling convention for %qT"
+msgstr ""
+
+#: cp/tree.c:4090
+#, fuzzy, gcc-internal-format
+msgid " declared here"
+msgstr "%qs tevoren hier gedeclareerd"
+
+#: cp/tree.c:4094
+#, gcc-internal-format
+msgid "the calling convention for %qT changes in -fabi-version=13 (GCC 8.2)"
+msgstr ""
+
+#: cp/tree.c:4096
+#, gcc-internal-format
 msgid " because all of its copy and move constructors are deleted"
 msgstr ""
 
-#: cp/tree.c:4416
+#: cp/tree.c:4464
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to function types"
 msgid "%qE attribute applied to %qD with void return type"
 msgstr "attribuut %qE is enkel van toepassing op functie-types"
 
-#: cp/tree.c:4423
+#: cp/tree.c:4471
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr "attribuut %qE is enkel van toepassing op class-definities"
 
-#: cp/tree.c:4475
+#: cp/tree.c:4523
 #, gcc-internal-format
 msgid "requested init_priority is not an integer constant"
 msgstr ""
 
-#: cp/tree.c:4497
+#: cp/tree.c:4545
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr ""
 
-#: cp/tree.c:4505
+#: cp/tree.c:4553
 #, gcc-internal-format
 msgid "requested init_priority is out of range"
 msgstr ""
 
-#: cp/tree.c:4515
+#: cp/tree.c:4563
 #, gcc-internal-format
 msgid "requested init_priority is reserved for internal use"
 msgstr ""
 
-#: cp/tree.c:4526
+#: cp/tree.c:4574
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr "sectie-attributen worden niet ondersteund op dit doelsysteem"
 
-#: cp/tree.c:4553
+#: cp/tree.c:4601
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %qE"
 msgstr "herdeclaratie van %qs"
 
-#: cp/tree.c:4573
+#: cp/tree.c:4621
 #, fuzzy, gcc-internal-format
 msgid "the %qE attribute requires arguments"
 msgstr "herhalings-aantal is geen integerconstante"
 
-#: cp/tree.c:4584
+#: cp/tree.c:4632
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qE attribute is not a string constant"
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "argument van attribuut %qE is geen string-constante"
 
-#: cp/tree.c:4597 cp/tree.c:4610
+#: cp/tree.c:4645 cp/tree.c:4658
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qE attribute is not a string constant"
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "argument van attribuut %qE is geen string-constante"
 
-#: cp/tree.c:4599
+#: cp/tree.c:4647
 #, gcc-internal-format
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr ""
 
-#: cp/tree.c:4612
+#: cp/tree.c:4660
 #, fuzzy, gcc-internal-format
 #| msgid "'%%%c' is not a valid operand prefix"
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "'%%%c' is geen geldige operand-prefix"
 
-#: cp/tree.c:4636
+#: cp/tree.c:4684
 #, gcc-internal-format
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr ""
 
-#: cp/tree.c:4642
+#: cp/tree.c:4690
 #, gcc-internal-format
 msgid "%qE attribute applied to %qT after its definition"
 msgstr ""
 
-#: cp/tree.c:4649
+#: cp/tree.c:4697
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "herhaalde definitie %qs"
 
-#: cp/tree.c:4656
+#: cp/tree.c:4704
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/tree.c:4678
+#: cp/tree.c:4726
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to functions, not %s"
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "attribuut %qE is enkel van toepassing op functies, niet %s"
 
-#: cp/tree.c:4684
+#: cp/tree.c:4732
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute applies only to functions"
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "attribuut %qE is enkel van toepassing op functies"
 
-#: cp/tree.c:5440
+#: cp/tree.c:5488
 #, fuzzy, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "array subscript is geen integer"
 
-#: cp/tree.c:5453
+#: cp/tree.c:5501
 #, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr ""
@@ -50860,107 +50919,107 @@
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr ""
 
-#: cp/typeck2.c:1496 cp/typeck2.c:1523
+#: cp/typeck2.c:1499 cp/typeck2.c:1526
 #, fuzzy, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/typeck2.c:1504
+#: cp/typeck2.c:1507
 #, fuzzy, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "parameter %qs krijgt beginwaarde"
 
-#: cp/typeck2.c:1511
+#: cp/typeck2.c:1514
 #, fuzzy, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr "parameter %qs krijgt beginwaarde"
 
-#: cp/typeck2.c:1587
+#: cp/typeck2.c:1590
 #, fuzzy, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: cp/typeck2.c:1660
+#: cp/typeck2.c:1663
 #, fuzzy, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "onbekend veld %qs opgegeven in beginwaarde"
 
-#: cp/typeck2.c:1671
+#: cp/typeck2.c:1674
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr ""
 
-#: cp/typeck2.c:1858
+#: cp/typeck2.c:1861
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr ""
 
-#: cp/typeck2.c:1872
+#: cp/typeck2.c:1875
 #, fuzzy, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "grootte van array %qs is van een niet-integraal type"
 
-#: cp/typeck2.c:1898
+#: cp/typeck2.c:1901
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr ""
 
-#: cp/typeck2.c:1900
+#: cp/typeck2.c:1903
 #, fuzzy, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "grootte van array %qs is van een niet-integraal type"
 
-#: cp/typeck2.c:1927
+#: cp/typeck2.c:1930
 #, fuzzy, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/typeck2.c:1936
+#: cp/typeck2.c:1939
 #, fuzzy, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/typeck2.c:1958
+#: cp/typeck2.c:1961
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2018
+#: cp/typeck2.c:2021
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "pointer naar lid-functie gebruikt in rekensom"
 
-#: cp/typeck2.c:2029
+#: cp/typeck2.c:2032
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "pointer naar lid-functie gebruikt in rekensom"
 
-#: cp/typeck2.c:2037
+#: cp/typeck2.c:2040
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++2a"
 msgstr "pointer naar lid-functie gebruikt in rekensom"
 
-#: cp/typeck2.c:2080
+#: cp/typeck2.c:2083
 #, fuzzy, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/typeck2.c:2096
+#: cp/typeck2.c:2099
 #, fuzzy, gcc-internal-format
 msgid "cannot deduce template arguments for %qT from ()"
 msgstr "eerste argument van %qs zou een %<int%> moeten zijn"
 
-#: cp/typeck2.c:2114
+#: cp/typeck2.c:2117
 #, fuzzy, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "dubbele beginwaarde"
 
-#: cp/typeck2.c:2341
+#: cp/typeck2.c:2344
 #, fuzzy, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "parameter %qs wijst naar een onvolledig type"
 
-#: cp/typeck2.c:2344
+#: cp/typeck2.c:2347
 #, fuzzy, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "parameter %qs wijst naar een onvolledig type"
@@ -51177,11 +51236,11 @@
 msgstr ""
 
 #: fortran/array.c:221 fortran/array.c:661 fortran/check.c:2849
-#: fortran/check.c:5222 fortran/check.c:5260 fortran/check.c:5302
-#: fortran/check.c:5329 fortran/check.c:5529 fortran/match.c:1821
+#: fortran/check.c:5225 fortran/check.c:5263 fortran/check.c:5305
+#: fortran/check.c:5332 fortran/check.c:5532 fortran/match.c:1821
 #: fortran/match.c:3174 fortran/match.c:3516 fortran/match.c:3712
-#: fortran/simplify.c:2909 fortran/simplify.c:2939 fortran/simplify.c:5764
-#: fortran/simplify.c:7658
+#: fortran/simplify.c:2909 fortran/simplify.c:2939 fortran/simplify.c:5769
+#: fortran/simplify.c:7663
 #, gcc-internal-format
 msgid "Coarrays disabled at %C, use %<-fcoarray=%> to enable"
 msgstr ""
@@ -51317,119 +51376,124 @@
 msgid "DO-iterator %qs at %L is inside iterator of the same name"
 msgstr ""
 
-#: fortran/array.c:1073 fortran/array.c:1255
+#: fortran/array.c:1073 fortran/array.c:1264
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in array constructor at %C"
 msgstr ""
 
-#: fortran/array.c:1129
+#: fortran/array.c:1105
 #, fuzzy, gcc-internal-format, gfc-internal-format
+msgid "NULL() at %C cannot appear in an array constructor"
+msgstr "overflow in constante expressie"
+
+#: fortran/array.c:1138
+#, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "[...] style array constructors at %C"
 msgstr "Lege array-constructor op %C is niet toegestaan"
 
-#: fortran/array.c:1149
+#: fortran/array.c:1158
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array constructor including type specification at %C"
 msgstr "eerdere definitie van %qs"
 
-#: fortran/array.c:1155 fortran/match.c:4148
+#: fortran/array.c:1164 fortran/match.c:4148
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-spec at %L cannot contain a deferred type parameter"
 msgstr ""
 
-#: fortran/array.c:1163
+#: fortran/array.c:1172
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-spec at %L cannot contain an asterisk for a type parameter"
 msgstr ""
 
-#: fortran/array.c:1181
+#: fortran/array.c:1190
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty array constructor at %C is not allowed"
 msgstr "Lege array-constructor op %C is niet toegestaan"
 
-#: fortran/array.c:1218 fortran/array.c:1228
+#: fortran/array.c:1227 fortran/array.c:1237
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "incompatible type for argument %d of %qE"
 msgid "Incompatible typespec for array element at %L"
 msgstr "incompatibel type voor argument %d van %qE"
 
-#: fortran/array.c:1302
+#: fortran/array.c:1311
 #, gcc-internal-format, gfc-internal-format
 msgid "Element in %s array constructor at %L is %s"
 msgstr ""
 
-#: fortran/array.c:1633
+#: fortran/array.c:1642
 #, gcc-internal-format, gfc-internal-format
 msgid "Iterator step at %L cannot be zero"
 msgstr ""
 
-#: fortran/array.c:1770
+#: fortran/array.c:1779
 #, gcc-internal-format
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit.   See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/array.c:1940
+#: fortran/array.c:1949
 #, gcc-internal-format, gfc-internal-format
 msgid "AC-IMPLIED-DO initial expression references control variable at %L"
 msgstr ""
 
-#: fortran/array.c:1947
+#: fortran/array.c:1956
 #, gcc-internal-format, gfc-internal-format
 msgid "AC-IMPLIED-DO final expression references control variable at %L"
 msgstr ""
 
-#: fortran/array.c:1954
+#: fortran/array.c:1963
 #, gcc-internal-format, gfc-internal-format
 msgid "AC-IMPLIED-DO step expression references control variable at %L"
 msgstr ""
 
-#: fortran/array.c:1966
+#: fortran/array.c:1975
 #, gcc-internal-format, gfc-internal-format
 msgid "Array constructor value at %L shall not be unlimited polymorphic [F2008: C4106]"
 msgstr ""
 
-#: fortran/array.c:2055
+#: fortran/array.c:2067
 #, gcc-internal-format, gfc-internal-format
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor at %L"
 msgstr ""
 
-#: fortran/array.c:2174
+#: fortran/array.c:2186
 #, gcc-internal-format
 msgid "spec_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2233
+#: fortran/array.c:2245
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2237
+#: fortran/array.c:2249
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad array dimension at %L"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: fortran/array.c:2264 fortran/data.c:552 fortran/data.c:571
-#: fortran/data.c:585 fortran/data.c:714
+#: fortran/array.c:2276 fortran/data.c:563 fortran/data.c:582
+#: fortran/data.c:596 fortran/data.c:725
 #, fuzzy, gcc-internal-format
 msgid "Simplification error"
 msgstr "herdeclaratie van %qs"
 
-#: fortran/array.c:2376
+#: fortran/array.c:2388
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimen_type"
 msgstr ""
 
-#: fortran/array.c:2427
+#: fortran/array.c:2439
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2472
+#: fortran/array.c:2484
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad EXPR_ARRAY expr"
 msgstr ""
 
-#: fortran/array.c:2620
+#: fortran/array.c:2632
 #, gcc-internal-format
 msgid "gfc_find_array_ref(): No ref found"
 msgstr ""
@@ -51488,7 +51552,7 @@
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or PROCEDURE"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet %s zijn"
 
-#: fortran/check.c:205 fortran/check.c:6658
+#: fortran/check.c:205 fortran/check.c:6661
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a constant"
 msgid "%qs argument of %qs intrinsic at %L must be a constant"
@@ -51629,7 +51693,7 @@
 msgstr ""
 
 # rank -> rang: correct in Fortran-context?
-#: fortran/check.c:946 fortran/check.c:6602
+#: fortran/check.c:946 fortran/check.c:6605
 #, fuzzy, gcc-internal-format
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have the same type"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet kleiner dan rang %d zijn"
@@ -51871,9 +51935,9 @@
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
 #: fortran/check.c:1939 fortran/check.c:2525 fortran/check.c:2628
-#: fortran/check.c:2835 fortran/check.c:2880 fortran/check.c:4256
-#: fortran/check.c:4390 fortran/check.c:4445 fortran/check.c:5515
-#: fortran/check.c:5644
+#: fortran/check.c:2835 fortran/check.c:2880 fortran/check.c:4259
+#: fortran/check.c:4393 fortran/check.c:4448 fortran/check.c:5518
+#: fortran/check.c:5647
 #, gcc-internal-format
 msgid "%qs intrinsic with KIND argument at %L"
 msgstr ""
@@ -52086,7 +52150,7 @@
 msgstr ""
 
 # rank -> rang: correct in Fortran-context?
-#: fortran/check.c:3768 fortran/check.c:5591
+#: fortran/check.c:3768 fortran/check.c:5594
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must provide at least as many elements as there are .TRUE. values in %qs (%ld/%d)"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet kleiner dan rang %d zijn"
@@ -52109,12 +52173,12 @@
 msgid "%qs argument of %qs intrinsic at %L must not be a subobject of %qs"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet %s zijn"
 
-#: fortran/check.c:3901
+#: fortran/check.c:3904
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The argument of the RANK intrinsic at %L must be a data object"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een constante zijn"
 
-#: fortran/check.c:4005
+#: fortran/check.c:4008
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a constant"
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L must be an array of constant size"
@@ -52121,375 +52185,375 @@
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een constante zijn"
 
 # vertaling voor 'intrinsic'? 'intrinsiek(e) xxx', maar wat als xxx te gebruiken?
-#: fortran/check.c:4015
+#: fortran/check.c:4018
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L is empty"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet %s zijn"
 
 # vertaling voor 'intrinsic'? 'intrinsiek(e) xxx', maar wat als xxx te gebruiken?
-#: fortran/check.c:4022
+#: fortran/check.c:4025
 #, fuzzy, gcc-internal-format
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L has more than %d elements"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet %s zijn"
 
 # vertaling voor 'intrinsic'? 'intrinsiek(e) xxx', maar wat als xxx te gebruiken?
-#: fortran/check.c:4039
+#: fortran/check.c:4042
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has negative element (%d)"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet %s zijn"
 
-#: fortran/check.c:4071
+#: fortran/check.c:4074
 #, gcc-internal-format, gfc-internal-format
 msgid "Element %d of actual argument of RESHAPE at %L cannot be negative"
 msgstr ""
 
 # vertaling voor 'intrinsic'? 'intrinsiek(e) xxx', maar wat als xxx te gebruiken?
-#: fortran/check.c:4109
+#: fortran/check.c:4112
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has wrong number of elements (%d/%d)"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet %s zijn"
 
 # vertaling voor 'intrinsic'? 'intrinsiek(e) xxx', maar wat als xxx te gebruiken?
-#: fortran/check.c:4127
+#: fortran/check.c:4130
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has out-of-range dimension (%d)"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet %s zijn"
 
-#: fortran/check.c:4136
+#: fortran/check.c:4139
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has invalid permutation of dimensions (dimension %qd duplicated)"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een constante zijn"
 
-#: fortran/check.c:4172
+#: fortran/check.c:4175
 #, gcc-internal-format, gfc-internal-format
 msgid "Without padding, there are not enough elements in the intrinsic RESHAPE source at %L to match the shape"
 msgstr ""
 
 # vertaling voor 'intrinsic'? 'intrinsiek(e) xxx', maar wat als xxx te gebruiken?
-#: fortran/check.c:4189 fortran/check.c:4208
+#: fortran/check.c:4192 fortran/check.c:4211
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L cannot be of type %s"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet %s zijn"
 
-#: fortran/check.c:4199 fortran/check.c:4218
+#: fortran/check.c:4202 fortran/check.c:4221
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of an extensible type"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een constante zijn"
 
-#: fortran/check.c:4317
+#: fortran/check.c:4320
 #, gcc-internal-format
 msgid "SELECTED_REAL_KIND with neither %<P%> nor %<R%> argument at %L"
 msgstr ""
 
-#: fortran/check.c:4348
+#: fortran/check.c:4351
 #, gcc-internal-format
 msgid "%qs intrinsic with RADIX argument at %L"
 msgstr ""
 
-#: fortran/check.c:4383
+#: fortran/check.c:4386
 #, fuzzy, gcc-internal-format
 msgid "%<source%> argument of %<shape%> intrinsic at %L must not be an assumed size array"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/check.c:4460 fortran/check.c:6641
+#: fortran/check.c:4463 fortran/check.c:6644
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be a procedure"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
 # vertaling voor 'intrinsic'? 'intrinsiek(e) xxx', maar wat als xxx te gebruiken?
-#: fortran/check.c:4473 fortran/check.c:4612 fortran/check.c:6633
+#: fortran/check.c:4476 fortran/check.c:4615 fortran/check.c:6636
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be TYPE(*)"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet %s zijn"
 
-#: fortran/check.c:4484 fortran/check.c:4624
+#: fortran/check.c:4487 fortran/check.c:4627
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be an assumed-size array"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/check.c:4554
+#: fortran/check.c:4557
 #, gcc-internal-format
 msgid "is_c_interoperable(): gfc_simplify_expr failed"
 msgstr ""
 
-#: fortran/check.c:4603
+#: fortran/check.c:4606
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be an interoperable data entity: %s"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/check.c:4642
+#: fortran/check.c:4645
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_1 at %L to C_ASSOCIATED shall have the type TYPE(C_PTR) or TYPE(C_FUNPTR)"
 msgstr ""
 
-#: fortran/check.c:4656
+#: fortran/check.c:4659
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_2 at %L to C_ASSOCIATED shall have the same type as C_PTR_1: %s instead of %s"
 msgstr ""
 
-#: fortran/check.c:4680
+#: fortran/check.c:4683
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_POINTER shall have the type TYPE(C_PTR)"
 msgstr ""
 
-#: fortran/check.c:4692
+#: fortran/check.c:4695
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER must be a pointer"
 msgstr ""
 
-#: fortran/check.c:4699
+#: fortran/check.c:4702
 #, gcc-internal-format, gfc-internal-format
 msgid "FPTR argument at %L to C_F_POINTER shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:4706
+#: fortran/check.c:4709
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:4713
+#: fortran/check.c:4716
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected SHAPE argument at %L to C_F_POINTER with scalar FPTR"
 msgstr ""
 
-#: fortran/check.c:4719
+#: fortran/check.c:4722
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected SHAPE argument to C_F_POINTER with array FPTR at %L"
 msgstr ""
 
-#: fortran/check.c:4738
+#: fortran/check.c:4741
 #, gcc-internal-format, gfc-internal-format
 msgid "SHAPE argument at %L to C_F_POINTER must have the same size as the RANK of FPTR"
 msgstr ""
 
-#: fortran/check.c:4748
+#: fortran/check.c:4751
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic FPTR at %L to C_F_POINTER"
 msgstr ""
 
-#: fortran/check.c:4753
+#: fortran/check.c:4756
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array FPTR at %L to C_F_POINTER: %s"
 msgstr ""
 
-#: fortran/check.c:4769
+#: fortran/check.c:4772
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_PROCPOINTER shall have the type TYPE(C_FUNPTR)"
 msgstr ""
 
-#: fortran/check.c:4781
+#: fortran/check.c:4784
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall be a procedure pointer"
 msgstr ""
 
-#: fortran/check.c:4788
+#: fortran/check.c:4791
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:4794
+#: fortran/check.c:4797
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure pointer at %L to C_F_PROCPOINTER"
 msgstr ""
 
-#: fortran/check.c:4808
+#: fortran/check.c:4811
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:4823
+#: fortran/check.c:4826
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L is invalid as X argument to C_FUNLOC"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/check.c:4831
+#: fortran/check.c:4834
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall be a procedure or a procedure pointer"
 msgstr ""
 
-#: fortran/check.c:4837
+#: fortran/check.c:4840
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure at %L to C_FUNLOC"
 msgstr ""
 
-#: fortran/check.c:4851
+#: fortran/check.c:4854
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:4857
+#: fortran/check.c:4860
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "X argument at %L to C_LOC shall not be polymorphic"
 msgstr "ongeldig type-argument %qs"
 
-#: fortran/check.c:4868
+#: fortran/check.c:4871
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall have either the POINTER or the TARGET attribute"
 msgstr ""
 
-#: fortran/check.c:4876
+#: fortran/check.c:4879
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall be not be a zero-sized string"
 msgstr ""
 
-#: fortran/check.c:4885
+#: fortran/check.c:4888
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument at %L to C_LOC shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:4892
+#: fortran/check.c:4895
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array at %L as argument to C_LOC: %s"
 msgstr ""
 
-#: fortran/check.c:4903
+#: fortran/check.c:4906
 #, gcc-internal-format, gfc-internal-format
 msgid "Array of interoperable type at %L to C_LOC which is nonallocatable and neither assumed size nor explicit size"
 msgstr ""
 
-#: fortran/check.c:4908
+#: fortran/check.c:4911
 #, gcc-internal-format, gfc-internal-format
 msgid "Array section at %L to C_LOC"
 msgstr ""
 
-#: fortran/check.c:4936
+#: fortran/check.c:4939
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "non double precision REAL argument to %s intrinsic at %L"
 msgstr "Ontbrekende argumenten voor intrinsic %s op %L"
 
 # rank -> rang: correct in Fortran-context?
-#: fortran/check.c:4949
+#: fortran/check.c:4952
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be less than rank %d"
 msgid "%qs argument of %qs intrinsic at %L must be less than rank %d"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet kleiner dan rang %d zijn"
 
-#: fortran/check.c:4968
+#: fortran/check.c:4971
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L is not a valid dimension index"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een constante zijn"
 
-#: fortran/check.c:5231
+#: fortran/check.c:5234
 #, gcc-internal-format, gfc-internal-format
 msgid "%s argument to IMAGE_INDEX must be a rank one array at %L"
 msgstr ""
 
-#: fortran/check.c:5242
+#: fortran/check.c:5245
 #, gcc-internal-format, gfc-internal-format
 msgid "The number of array elements of the SUB argument to IMAGE_INDEX at %L shall be %d (corank) not %d"
 msgstr ""
 
-#: fortran/check.c:5275
+#: fortran/check.c:5278
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to NUM_IMAGES at %L"
 msgstr ""
 
-#: fortran/check.c:5288
+#: fortran/check.c:5291
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FAILED= argument to NUM_IMAGES at %L"
 msgstr "Ontbrekende argumenten voor intrinsic %s op %L"
 
-#: fortran/check.c:5312
+#: fortran/check.c:5315
 #, gcc-internal-format, gfc-internal-format
 msgid "TEAM argument at %L to the intrinsic TEAM_NUMBER shall be of type TEAM_TYPE"
 msgstr ""
 
-#: fortran/check.c:5338
+#: fortran/check.c:5341
 #, gcc-internal-format, gfc-internal-format
 msgid "DIM argument without COARRAY argument not allowed for THIS_IMAGE intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:5345
+#: fortran/check.c:5348
 #, gcc-internal-format, gfc-internal-format
 msgid "The DISTANCE argument may not be specified together with the COARRAY or DIM argument in intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:5356
+#: fortran/check.c:5359
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected DIM argument with noncoarray argument at %L"
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/check.c:5374
+#: fortran/check.c:5377
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to THIS_IMAGE at %L"
 msgstr ""
 
 # vertaling voor 'intrinsic'? 'intrinsiek(e) xxx', maar wat als xxx te gebruiken?
-#: fortran/check.c:5454
+#: fortran/check.c:5457
 #, fuzzy, gcc-internal-format
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L must not be %s"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet %s zijn"
 
-#: fortran/check.c:5483
+#: fortran/check.c:5486
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic TRANSFER at %L has partly undefined result: source size %ld < result size %ld"
 msgstr ""
 
-#: fortran/check.c:5605
+#: fortran/check.c:5608
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must have the same rank as %qs or be a scalar"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
 # rank -> rang: correct in Fortran-context?
-#: fortran/check.c:5618
+#: fortran/check.c:5621
 #, fuzzy, gcc-internal-format
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have identical shape."
 msgstr "'%s' argument voor intrinsic '%s' op %L moet kleiner dan rang %d zijn"
 
 # vertaling voor 'intrinsic'? 'intrinsiek(e) xxx', maar wat als xxx te gebruiken?
-#: fortran/check.c:5861 fortran/check.c:5893
+#: fortran/check.c:5864 fortran/check.c:5896
 #, fuzzy, gcc-internal-format
 msgid "Size of %qs argument of %qs intrinsic at %L too small (%i/%i)"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet %s zijn"
 
-#: fortran/check.c:5901
+#: fortran/check.c:5904
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many arguments to %s at %L"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/check.c:5919
+#: fortran/check.c:5922
 #, gcc-internal-format
 msgid "fe_runtime_error string must be null terminated"
 msgstr ""
 
-#: fortran/check.c:5931
+#: fortran/check.c:5934
 #, gcc-internal-format, gfc-internal-format
 msgid "fe_runtime_error: Wrong number of arguments (%d instead of %d)"
 msgstr ""
 
-#: fortran/check.c:5971
+#: fortran/check.c:5974
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr "ongeldig type-argument %qs"
 
-#: fortran/check.c:5990
+#: fortran/check.c:5993
 #, gcc-internal-format, gfc-internal-format
 msgid "Real COUNT_RATE argument to SYSTEM_CLOCK at %L"
 msgstr ""
 
-#: fortran/check.c:6000
+#: fortran/check.c:6003
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "COUNT_RATE argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr "ongeldig type-argument %qs"
 
-#: fortran/check.c:6017
+#: fortran/check.c:6020
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "COUNT_MAX argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr "ongeldig type-argument %qs"
 
 # rank -> rang: correct in Fortran-context?
-#: fortran/check.c:6234
+#: fortran/check.c:6237
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of a kind not wider than the default kind (%d)"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet kleiner dan rang %d zijn"
 
 # vertaling voor 'intrinsic'? 'intrinsiek(e) xxx', maar wat als xxx te gebruiken?
-#: fortran/check.c:6586 fortran/check.c:6594
+#: fortran/check.c:6589 fortran/check.c:6597
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or LOGICAL"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet %s zijn"
 
-#: fortran/check.c:6625
+#: fortran/check.c:6628
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic function NULL at %L cannot be an actual argument to STORAGE_SIZE, because it returns a disassociated pointer"
 msgstr ""
@@ -52501,7 +52565,7 @@
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:727 fortran/decl.c:3636 fortran/decl.c:10066
+#: fortran/class.c:727 fortran/decl.c:3655 fortran/decl.c:10091
 #, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr ""
@@ -52527,44 +52591,49 @@
 msgid "non-constant array in DATA statement %L"
 msgstr "niet-constante array in DATA statement %L."
 
-#: fortran/data.c:137
+#: fortran/data.c:140
 #, gcc-internal-format, gfc-internal-format
 msgid "failure to simplify substring reference in DATA statement at %L"
 msgstr ""
 
-#: fortran/data.c:170
+#: fortran/data.c:173
 #, gcc-internal-format, gfc-internal-format
 msgid "Unused initialization string at %L because variable has zero length"
 msgstr ""
 
-#: fortran/data.c:176
+#: fortran/data.c:179
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Initialization at %C isn't for a pointer variable"
 msgid "Initialization string at %L was truncated to fit the variable (%ld/%ld)"
 msgstr "Initialisatie op %C is niet voor een pointervariable"
 
-#: fortran/data.c:265
+#: fortran/data.c:268
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L already is initialized at %L"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/data.c:289
+#: fortran/data.c:292
 #, gcc-internal-format, gfc-internal-format
 msgid "Data element below array lower bound at %L"
 msgstr ""
 
-#: fortran/data.c:306 fortran/data.c:395
+#: fortran/data.c:309 fortran/data.c:398
 #, gcc-internal-format, gfc-internal-format
 msgid "Data element above array upper bound at %L"
 msgstr ""
 
-#: fortran/data.c:336 fortran/data.c:505
+#: fortran/data.c:339 fortran/data.c:496
 #, fuzzy, gcc-internal-format
 msgid "re-initialization of %qs at %L"
 msgstr "Extensie: herinitialisatie van '%s' op %L"
 
-#: fortran/data.c:727
+#: fortran/data.c:515
 #, gcc-internal-format
+msgid "Nonpointer object %qs with default initialization shall not appear in a DATA statement at %L"
+msgstr ""
+
+#: fortran/data.c:738
+#, gcc-internal-format
 msgid "TODO: Vector sections in data statements"
 msgstr ""
 
@@ -52588,794 +52657,793 @@
 msgid "Invalid initializer %s in Data statement at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:536
+#: fortran/decl.c:537
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:573
+#: fortran/decl.c:574
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %C cannot appear within an INTERFACE"
 msgstr "overflow in constante expressie"
 
-#: fortran/decl.c:597
+#: fortran/decl.c:598
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid substring in data-implied-do at %L in DATA statement"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:619
+#: fortran/decl.c:620
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:664
+#: fortran/decl.c:662
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Empty old style initializer list at %C"
 msgstr "dubbele beginwaarde"
 
-#: fortran/decl.c:684
+#: fortran/decl.c:671
 #, fuzzy, gcc-internal-format, gfc-internal-format
+msgid "Array in initializer list at %L must have an explicit shape"
+msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
+
+#: fortran/decl.c:694
+#, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "extra elements in scalar initializer"
 msgid "Repeat spec invalid in scalar initializer at %C"
 msgstr "extra elementen in scalaire beginwaarde"
 
-#: fortran/decl.c:689
+#: fortran/decl.c:699
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "vectorlength must be an integer constant"
 msgid "Repeat spec must be an integer at %C"
 msgstr "vectorlengte moet een integerconstante zijn"
 
-#: fortran/decl.c:698
+#: fortran/decl.c:710
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected data constant after repeat spec at %C"
 msgstr "vector overflow in expressie"
 
-#: fortran/decl.c:729
+#: fortran/decl.c:742
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "End of scalar initializer expected at %C"
 msgstr "ongeldige waarheidsexpressie"
 
-#: fortran/decl.c:758
+#: fortran/decl.c:773
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "nonconstant array index in initializer"
-msgid "Expected constant array-spec in initializer list at %L"
-msgstr "niet-constante array-index in beginwaarde"
-
-#: fortran/decl.c:767
-#, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "excess elements in array initializer"
 msgid "Not enough elements in array initializer at %C"
 msgstr "overtollige elementen in beginwaarde van array"
 
-#: fortran/decl.c:769
+#: fortran/decl.c:775
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "excess elements in array initializer"
 msgid "Too many elements in array initializer at %C"
 msgstr "overtollige elementen in beginwaarde van array"
 
-#: fortran/decl.c:790
+#: fortran/decl.c:795
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in old style initializer list at %C"
 msgstr "%qs is geen iterator"
 
-#: fortran/decl.c:812
+#: fortran/decl.c:821
 #, gcc-internal-format, gfc-internal-format
 msgid "The assumed-rank array at %C shall not have a codimension"
 msgstr ""
 
-#: fortran/decl.c:876
+#: fortran/decl.c:885
 #, gcc-internal-format, gfc-internal-format
 msgid "Sum of array rank %d and corank %d at %C exceeds maximum allowed dimensions of %d"
 msgstr ""
 
-#: fortran/decl.c:900
+#: fortran/decl.c:909
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad INTENT specification at %C"
 msgstr ""
 
-#: fortran/decl.c:921
+#: fortran/decl.c:930
 #, gcc-internal-format, gfc-internal-format
 msgid "deferred type parameter at %C"
 msgstr ""
 
-#: fortran/decl.c:1004 fortran/resolve.c:11705
+#: fortran/decl.c:1013 fortran/resolve.c:11725
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
 
-#: fortran/decl.c:1030
+#: fortran/decl.c:1039
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Old-style character length at %C"
 msgstr "opvulkarakter in strfmon-formaat"
 
-#: fortran/decl.c:1061
+#: fortran/decl.c:1070
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in character length specification at %C"
 msgstr ""
 
-#: fortran/decl.c:1212 fortran/decl.c:1217 fortran/decl.c:1266
+#: fortran/decl.c:1221 fortran/decl.c:1226 fortran/decl.c:1275
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %C is already defined at %L"
 msgstr "veld %qs heeft al een beginwaarde gekregen"
 
-#: fortran/decl.c:1222
+#: fortran/decl.c:1231
 #, fuzzy, gcc-internal-format
 msgid "Contained procedure %qs at %C clashes with procedure defined at %L"
 msgstr "veld %qs heeft al een beginwaarde gekregen"
 
-#: fortran/decl.c:1231
+#: fortran/decl.c:1240
 #, fuzzy, gcc-internal-format
 msgid "Name %qs at %C is already defined as a generic interface at %L"
 msgstr "veld %qs heeft al een beginwaarde gekregen"
 
-#: fortran/decl.c:1244
+#: fortran/decl.c:1253
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %C has an explicit interface from a previous declaration"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/decl.c:1257
+#: fortran/decl.c:1266
 #, gcc-internal-format
 msgid "Procedure %qs defined in interface body at %L clashes with internal procedure defined at %C"
 msgstr ""
 
-#: fortran/decl.c:1335
+#: fortran/decl.c:1344
 #, gcc-internal-format
 msgid "Procedure %qs at %L must have the BIND(C) attribute to be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:1362
+#: fortran/decl.c:1371
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because derived type %qs is not C interoperable"
 msgstr ""
 
-#: fortran/decl.c:1369
+#: fortran/decl.c:1378
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because it is polymorphic"
 msgstr ""
 
-#: fortran/decl.c:1376
+#: fortran/decl.c:1385
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument of the BIND(C) procedure %qs but may not be C interoperable"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/decl.c:1391
+#: fortran/decl.c:1400
 #, fuzzy, gcc-internal-format
 msgid "Character argument %qs at %L must be length 1 because procedure %qs is BIND(C)"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/decl.c:1404
+#: fortran/decl.c:1413
 #, gcc-internal-format
 msgid "Variable %qs at %L with ALLOCATABLE attribute in procedure %qs with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1412
+#: fortran/decl.c:1421
 #, gcc-internal-format
 msgid "Variable %qs at %L with POINTER attribute in procedure %qs with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1421
+#: fortran/decl.c:1430
 #, gcc-internal-format
 msgid "Scalar variable %qs at %L with POINTER or ALLOCATABLE in procedure %qs with BIND(C) is not yet supported"
 msgstr ""
 
-#: fortran/decl.c:1430
+#: fortran/decl.c:1439
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the OPTIONAL and the VALUE attribute because procedure %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1437
+#: fortran/decl.c:1446
 #, gcc-internal-format
 msgid "Variable %qs at %L with OPTIONAL attribute in procedure %qs which is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1448
+#: fortran/decl.c:1457
 #, fuzzy, gcc-internal-format
 msgid "Assumed-shape array %qs at %L as dummy argument to the BIND(C) procedure %qs at %L"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/decl.c:1516
+#: fortran/decl.c:1525
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C also declared as a type at %L"
 msgstr "gevraagd alignment is geen macht van 2"
 
-#: fortran/decl.c:1575
+#: fortran/decl.c:1584
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %C must be declared with a C interoperable kind since common block %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1615
+#: fortran/decl.c:1624
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument must be a constant"
 msgid "CHARACTER length must be a constant at %L"
 msgstr "argument moet een constante zijn"
 
-#: fortran/decl.c:1630
+#: fortran/decl.c:1639
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression at %L is being truncated (%ld/%ld)"
 msgstr ""
 
 # rank -> rang: correct in Fortran-context?
-#: fortran/decl.c:1638
+#: fortran/decl.c:1647
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The CHARACTER elements of the array constructor at %L must have the same length (%ld/%ld)"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet kleiner dan rang %d zijn"
 
-#: fortran/decl.c:1729
+#: fortran/decl.c:1738
 #, gcc-internal-format
 msgid "Initializer not allowed for PARAMETER %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:1739
+#: fortran/decl.c:1748
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER at %L is missing an initializer"
 msgstr "beginwaarde ontbreekt in PARAMETER op %L"
 
-#: fortran/decl.c:1749
+#: fortran/decl.c:1758
 #, gcc-internal-format
 msgid "Variable %qs at %C with an initializer already appears in a DATA statement"
 msgstr ""
 
-#: fortran/decl.c:1792
+#: fortran/decl.c:1801
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot initialize parameter array at %L with variable length elements"
 msgstr ""
 
-#: fortran/decl.c:1861
+#: fortran/decl.c:1870
 #, gcc-internal-format, gfc-internal-format
 msgid "Can't initialize implied-shape array at %L with scalar"
 msgstr ""
 
-#: fortran/decl.c:1896
+#: fortran/decl.c:1905
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-constant lower bound in implied-shape declaration at %L"
 msgstr "twee of meer data types in de declaratie van %qs"
 
-#: fortran/decl.c:1982 fortran/decl.c:1989
+#: fortran/decl.c:1991 fortran/decl.c:1998
 #, gcc-internal-format, gfc-internal-format
 msgid "Component at %C must have the POINTER attribute"
 msgstr ""
 
-#: fortran/decl.c:1998
+#: fortran/decl.c:2007
 #, fuzzy, gcc-internal-format
 msgid "Component %qs with CLASS at %C must be allocatable or pointer"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/decl.c:2007
+#: fortran/decl.c:2016
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr ""
 
-#: fortran/decl.c:2031 fortran/symbol.c:2230
+#: fortran/decl.c:2040 fortran/symbol.c:2244
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %C already declared at %L"
 msgstr "gevraagd alignment is geen macht van 2"
 
-#: fortran/decl.c:2079
+#: fortran/decl.c:2088
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer array component of structure at %C must have a deferred shape"
 msgstr ""
 
-#: fortran/decl.c:2088
+#: fortran/decl.c:2097
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component of structure at %C must have a deferred shape"
 msgstr ""
 
-#: fortran/decl.c:2097
+#: fortran/decl.c:2106
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have an explicit shape"
 msgstr ""
 
-#: fortran/decl.c:2114
+#: fortran/decl.c:2123
 #, fuzzy, gcc-internal-format
 #| msgid "a parameter list with an ellipsis can%'t match an empty parameter name list declaration"
 msgid "Type parameter %qs at %C has no corresponding entry in the type parameter name list at %L"
 msgstr "een parameterlijst met een beletselteken kan niet overeenkomen met een declaratie met lege parameterlijst"
 
-#: fortran/decl.c:2171
+#: fortran/decl.c:2180
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C is ambiguous"
 msgstr ""
 
-#: fortran/decl.c:2188
+#: fortran/decl.c:2197
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C may not have MOLD"
 msgstr ""
 
-#: fortran/decl.c:2205
+#: fortran/decl.c:2214
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of pointer at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:2226
+#: fortran/decl.c:2235
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Error in pointer initialization at %C"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: fortran/decl.c:2233
+#: fortran/decl.c:2242
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "non-NULL pointer initialization at %C"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: fortran/decl.c:2256
+#: fortran/decl.c:2265
 #, gcc-internal-format
 msgid "RESULT variable %qs at %L prohibits FUNCTION name %qs at %C from appearing in a specification statement"
 msgstr ""
 
-#: fortran/decl.c:2318
+#: fortran/decl.c:2327
 #, gcc-internal-format
 msgid "%qs not allowed outside STRUCTURE at %C"
 msgstr ""
 
-#: fortran/decl.c:2320
+#: fortran/decl.c:2329
 #, gcc-internal-format
 msgid "%qs at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr ""
 
-#: fortran/decl.c:2327
+#: fortran/decl.c:2336
 #, fuzzy, gcc-internal-format
 msgid "%qs entity cannot have attributes at %C"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: fortran/decl.c:2367
+#: fortran/decl.c:2376
 #, fuzzy, gcc-internal-format
 msgid "Non-PARAMETER symbol %qs at %L can't be implied-shape"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/decl.c:2377
+#: fortran/decl.c:2386
 #, gcc-internal-format, gfc-internal-format
 msgid "Implied-shape array at %L"
 msgstr ""
 
-#: fortran/decl.c:2422
+#: fortran/decl.c:2431
 #, gcc-internal-format, gfc-internal-format
 msgid "Explicit shaped array with nonconstant bounds at %C"
 msgstr ""
 
-#: fortran/decl.c:2501
+#: fortran/decl.c:2510
 #, gcc-internal-format
 msgid "%qs at %C is a redefinition of the declaration in the corresponding interface for MODULE PROCEDURE %qs"
 msgstr ""
 
-#: fortran/decl.c:2512
+#: fortran/decl.c:2521
 #, fuzzy, gcc-internal-format
 msgid "%qs entity cannot have an initializer at %C"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/decl.c:2538 fortran/decl.c:8369
+#: fortran/decl.c:2547 fortran/decl.c:8388
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr "herhaalde label-declaratie %qs"
 
-#: fortran/decl.c:2546
+#: fortran/decl.c:2555
 #, gcc-internal-format
 msgid "Couldn't set pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:2609
+#: fortran/decl.c:2618
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Old-style initialization at %C"
 msgstr "dubbele beginwaarde"
 
-#: fortran/decl.c:2617
+#: fortran/decl.c:2626
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr "dubbele beginwaarde"
 
-#: fortran/decl.c:2630
+#: fortran/decl.c:2639
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in old style initialization of %s at %C"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: fortran/decl.c:2650 fortran/decl.c:6661
+#: fortran/decl.c:2659 fortran/decl.c:6680
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr "Initialisatie op %C is niet voor een pointervariable"
 
-#: fortran/decl.c:2663
+#: fortran/decl.c:2672
 #, fuzzy, gcc-internal-format
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: fortran/decl.c:2672 fortran/decl.c:10240
+#: fortran/decl.c:2681 fortran/decl.c:10265
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr "ongeldige waarheidsexpressie"
 
-#: fortran/decl.c:2679
+#: fortran/decl.c:2688
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:2696
+#: fortran/decl.c:2705
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr ""
 
-#: fortran/decl.c:2710
+#: fortran/decl.c:2719
 #, gcc-internal-format, gfc-internal-format
 msgid "The component with KIND or LEN attribute at %C does not not appear in the type parameter list at %L"
 msgstr ""
 
-#: fortran/decl.c:2718
+#: fortran/decl.c:2727
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C that appears in the type parameter list at %L has neither the KIND nor LEN attribute"
 msgstr ""
 
-#: fortran/decl.c:2726
+#: fortran/decl.c:2735
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C which is a type parameter must be a scalar"
 msgstr ""
 
-#: fortran/decl.c:2789 fortran/decl.c:2825
+#: fortran/decl.c:2798 fortran/decl.c:2834
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr "sectie-attributen worden niet ondersteund voor dit doelsysteem"
 
-#: fortran/decl.c:2831
+#: fortran/decl.c:2840
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr "twee of meer data types in de declaratie van %qs"
 
-#: fortran/decl.c:2890 fortran/decl.c:2967
+#: fortran/decl.c:2899 fortran/decl.c:2976
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis at %C"
 msgstr "Bestandsnaam ontbreekt na %qs optie"
 
-#: fortran/decl.c:2903 fortran/decl.c:3038
+#: fortran/decl.c:2912 fortran/decl.c:3047
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr "ongeldige waarheidsexpressie"
 
-#: fortran/decl.c:2911 fortran/decl.c:3044
+#: fortran/decl.c:2920 fortran/decl.c:3053
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr ""
 
-#: fortran/decl.c:2941 fortran/decl.c:3657
+#: fortran/decl.c:2950 fortran/decl.c:3676
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr "afrondingsmodus niet ondersteund voor VAX-floats"
 
-#: fortran/decl.c:2954
+#: fortran/decl.c:2963
 #, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr ""
 
-#: fortran/decl.c:2965
+#: fortran/decl.c:2974
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr "Bestandsnaam ontbreekt na %qs optie"
 
-#: fortran/decl.c:3070
+#: fortran/decl.c:3079
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr "afrondingsmodus niet ondersteund voor VAX-floats"
 
-#: fortran/decl.c:3202
+#: fortran/decl.c:3211
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:3291
+#: fortran/decl.c:3310
 #, gcc-internal-format, gfc-internal-format
 msgid "RECORD at %C is an extension, enable it with -fdec-structure"
 msgstr ""
 
-#: fortran/decl.c:3304
+#: fortran/decl.c:3323
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected after RECORD at %C"
 msgstr ""
 
-#: fortran/decl.c:3417
+#: fortran/decl.c:3436
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C cannot contain both ASSUMED and DEFERRED parameters"
 msgstr ""
 
-#: fortran/decl.c:3441
+#: fortran/decl.c:3460
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C does not contain enough parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3465
+#: fortran/decl.c:3484
 #, fuzzy, gcc-internal-format
 msgid "The derived parameter %qs at %C does not have a default value"
 msgstr "de tweede parameter van %<va_start%> is niet het laatste benoemde argument"
 
 # vertaling voor 'statement'?
-#: fortran/decl.c:3497
+#: fortran/decl.c:3516
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The parameter expression at %C must be of INTEGER type and not %s type"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/decl.c:3525
+#: fortran/decl.c:3544
 #, gcc-internal-format
 msgid "The KIND parameter %qs at %C cannot either be ASSUMED or DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:3532
+#: fortran/decl.c:3551
 #, fuzzy, gcc-internal-format
 msgid "The value for the KIND parameter %qs at %C does not reduce to a constant expression"
 msgstr "grootte van array %qs is van een niet-integraal type"
 
-#: fortran/decl.c:3547
+#: fortran/decl.c:3566
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C contains too many parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3556
+#: fortran/decl.c:3575
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Parameterized derived type at %C is ambiguous"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/decl.c:3819
+#: fortran/decl.c:3838
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type at %C"
 msgstr ""
 
-#: fortran/decl.c:3824
+#: fortran/decl.c:3843
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr ""
 
-#: fortran/decl.c:3846
+#: fortran/decl.c:3865
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C is not allowed for components"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: fortran/decl.c:3849
+#: fortran/decl.c:3868
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr ""
 
-#: fortran/decl.c:3872 fortran/decl.c:3903 fortran/decl.c:3932
-#: fortran/decl.c:4216
+#: fortran/decl.c:3891 fortran/decl.c:3922 fortran/decl.c:3951
+#: fortran/decl.c:4235
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr ""
 
-#: fortran/decl.c:3928
+#: fortran/decl.c:3947
 #, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr ""
 
-#: fortran/decl.c:3971 fortran/decl.c:4107 fortran/decl.c:4119
-#: fortran/decl.c:4133 fortran/decl.c:4611 fortran/decl.c:4619
+#: fortran/decl.c:3990 fortran/decl.c:4126 fortran/decl.c:4138
+#: fortran/decl.c:4152 fortran/decl.c:4630 fortran/decl.c:4638
 #, fuzzy, gcc-internal-format
 msgid "Type name %qs at %C is ambiguous"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/decl.c:4066
+#: fortran/decl.c:4085
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CLASS statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/decl.c:4148
+#: fortran/decl.c:4167
 #, gcc-internal-format
 msgid "Type name %qs at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr ""
 
-#: fortran/decl.c:4287
+#: fortran/decl.c:4306
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4296
+#: fortran/decl.c:4315
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr ""
 
-#: fortran/decl.c:4355
+#: fortran/decl.c:4374
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr ""
 
-#: fortran/decl.c:4401
+#: fortran/decl.c:4420
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4454
+#: fortran/decl.c:4473
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr ""
 
-#: fortran/decl.c:4464
+#: fortran/decl.c:4483
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4570
+#: fortran/decl.c:4589
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr ""
 
-#: fortran/decl.c:4577
+#: fortran/decl.c:4596
 #, gcc-internal-format, gfc-internal-format
 msgid "F2008: C1210 IMPORT statement at %C is not permitted in a module procedure interface body"
 msgstr ""
 
-#: fortran/decl.c:4582
+#: fortran/decl.c:4601
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:4596
+#: fortran/decl.c:4615
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr ""
 
-#: fortran/decl.c:4625
+#: fortran/decl.c:4644
 #, gcc-internal-format
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr ""
 
-#: fortran/decl.c:4632
+#: fortran/decl.c:4651
 #, gcc-internal-format
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr ""
 
-#: fortran/decl.c:4673
+#: fortran/decl.c:4692
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IMPORT statement at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:5010
+#: fortran/decl.c:5029
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing codimension specification at %C"
 msgstr "beginwaarde ontbreekt"
 
-#: fortran/decl.c:5012
+#: fortran/decl.c:5031
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr "beginwaarde ontbreekt"
 
-#: fortran/decl.c:5107
+#: fortran/decl.c:5126
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr "herhaalde label-declaratie %qs"
 
-#: fortran/decl.c:5124
+#: fortran/decl.c:5143
 #, gcc-internal-format
 msgid "%s at %L is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:5141
+#: fortran/decl.c:5160
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: fortran/decl.c:5150
+#: fortran/decl.c:5169
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "KIND attribute at %C in a TYPE definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: fortran/decl.c:5158
+#: fortran/decl.c:5177
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be INTEGER"
 msgstr ""
 
-#: fortran/decl.c:5165
+#: fortran/decl.c:5184
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5174
+#: fortran/decl.c:5193
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LEN attribute at %C in a TYPE definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
 # vertaling voor 'intrinsic'? 'intrinsiek(e) xxx', maar wat als xxx te gebruiken?
-#: fortran/decl.c:5182
+#: fortran/decl.c:5201
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be INTEGER"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet %s zijn"
 
-#: fortran/decl.c:5189
+#: fortran/decl.c:5208
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be default integer kind (%d)"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/decl.c:5198
+#: fortran/decl.c:5217
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: fortran/decl.c:5216
+#: fortran/decl.c:5235
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: fortran/decl.c:5226
+#: fortran/decl.c:5245
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:5236
+#: fortran/decl.c:5255
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed outside a TYPE definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: fortran/decl.c:5249
+#: fortran/decl.c:5268
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5260
+#: fortran/decl.c:5279
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5315 fortran/decl.c:8673
+#: fortran/decl.c:5334 fortran/decl.c:8692
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:5321
+#: fortran/decl.c:5340
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5355
+#: fortran/decl.c:5374
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5362
+#: fortran/decl.c:5381
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5369
+#: fortran/decl.c:5388
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr ""
 
-#: fortran/decl.c:5410
+#: fortran/decl.c:5429
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:5508
+#: fortran/decl.c:5527
 #, gcc-internal-format
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:5530
+#: fortran/decl.c:5549
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr "overflow in constante expressie"
 
-#: fortran/decl.c:5539
+#: fortran/decl.c:5558
 #, fuzzy, gcc-internal-format
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr "overflow in constante expressie"
 
-#: fortran/decl.c:5543
+#: fortran/decl.c:5562
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr "overflow in constante expressie"
 
-#: fortran/decl.c:5555
+#: fortran/decl.c:5574
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr ""
 
-#: fortran/decl.c:5569
+#: fortran/decl.c:5588
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/decl.c:5577
+#: fortran/decl.c:5596
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/decl.c:5589
+#: fortran/decl.c:5608
 #, fuzzy, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr "%s: definitie van functie '%s' niet omgezet\n"
 
-#: fortran/decl.c:5597
+#: fortran/decl.c:5616
 #, fuzzy, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be a character string"
 msgstr "%s: definitie van functie '%s' niet omgezet\n"
@@ -53382,951 +53450,956 @@
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:5608
+#: fortran/decl.c:5627
 #, gcc-internal-format
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr ""
 
-#: fortran/decl.c:5682
+#: fortran/decl.c:5701
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5727
+#: fortran/decl.c:5746
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5734
+#: fortran/decl.c:5753
 #, fuzzy, gcc-internal-format
 msgid "Missing symbol"
 msgstr "beginwaarde ontbreekt"
 
-#: fortran/decl.c:5763
+#: fortran/decl.c:5782
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/decl.c:5850
+#: fortran/decl.c:5869
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr ""
 
-#: fortran/decl.c:5892
+#: fortran/decl.c:5911
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in anonymous structure declaration at %C"
 msgstr "twee of meer data types in de declaratie van %qs"
 
-#: fortran/decl.c:5901
+#: fortran/decl.c:5920
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr "twee of meer data types in de declaratie van %qs"
 
-#: fortran/decl.c:5951
+#: fortran/decl.c:5970
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C"
 msgstr ""
 
-#: fortran/decl.c:5996
+#: fortran/decl.c:6015
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPURE procedure at %C"
 msgstr ""
 
-#: fortran/decl.c:6008
+#: fortran/decl.c:6027
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr ""
 
-#: fortran/decl.c:6054
+#: fortran/decl.c:6073
 #, gcc-internal-format, gfc-internal-format
 msgid "ELEMENTAL prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6061
+#: fortran/decl.c:6080
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PURE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:6068
+#: fortran/decl.c:6087
 #, gcc-internal-format, gfc-internal-format
 msgid "RECURSIVE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6134 fortran/primary.c:1820
+#: fortran/decl.c:6153 fortran/primary.c:1820
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Alternate-return argument at %C"
 msgstr "%qs is geen iterator"
 
-#: fortran/decl.c:6140 fortran/decl.c:6148
+#: fortran/decl.c:6159 fortran/decl.c:6167
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "A parameter name is required at %C"
 msgstr "%Jparameternaam weggelaten"
 
-#: fortran/decl.c:6188
+#: fortran/decl.c:6207
 #, fuzzy, gcc-internal-format
 msgid "Name %qs at %C is the name of the procedure"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: fortran/decl.c:6201
+#: fortran/decl.c:6220
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected parameter list in type declaration at %C"
 msgstr "conflicterende declaraties van %qs"
 
-#: fortran/decl.c:6204
+#: fortran/decl.c:6223
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr ""
 
-#: fortran/decl.c:6222
+#: fortran/decl.c:6241
 #, fuzzy, gcc-internal-format
 msgid "Duplicate name %qs in parameter list at %C"
 msgstr "herhaalde label-declaratie %qs"
 
-#: fortran/decl.c:6225
+#: fortran/decl.c:6244
 #, fuzzy, gcc-internal-format
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr "de terugkeerwaarde van een functie kan geen funtie zijn"
 
-#: fortran/decl.c:6264
+#: fortran/decl.c:6283
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in MODULE PROCEDURE formal argument names (%s/%s) at %C"
 msgstr ""
 
-#: fortran/decl.c:6270
+#: fortran/decl.c:6289
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in number of MODULE PROCEDURE formal arguments at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:6309
+#: fortran/decl.c:6328
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr ""
 
-#: fortran/decl.c:6386
+#: fortran/decl.c:6405
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr "conflicterende declaraties van %qs"
 
-#: fortran/decl.c:6396 fortran/decl.c:7494
+#: fortran/decl.c:6415 fortran/decl.c:7513
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr ""
 
-#: fortran/decl.c:6600
+#: fortran/decl.c:6619
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:6607
+#: fortran/decl.c:6626
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:6613
+#: fortran/decl.c:6632
 #, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr ""
 
-#: fortran/decl.c:6636
+#: fortran/decl.c:6655
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr "gevraagd alignment is geen macht van 2"
 
-#: fortran/decl.c:6682 fortran/decl.c:6870 fortran/decl.c:10723
+#: fortran/decl.c:6701 fortran/decl.c:6889 fortran/decl.c:10748
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:6731 fortran/decl.c:10623
+#: fortran/decl.c:6750 fortran/decl.c:10648
 #, fuzzy, gcc-internal-format
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr "Array subscript-stap verwacht op %C"
 
-#: fortran/decl.c:6738
+#: fortran/decl.c:6757
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr ""
 
-#: fortran/decl.c:6742
+#: fortran/decl.c:6761
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:6814
+#: fortran/decl.c:6833
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in procedure pointer component at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:6832
+#: fortran/decl.c:6851
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr ""
 
-#: fortran/decl.c:6841 fortran/decl.c:9392
+#: fortran/decl.c:6860 fortran/decl.c:9411
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:6911
+#: fortran/decl.c:6930
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE statement at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:6983
+#: fortran/decl.c:7002
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr ""
 
-#: fortran/decl.c:7007 fortran/decl.c:7011 fortran/decl.c:7266
-#: fortran/decl.c:7270 fortran/decl.c:7462 fortran/decl.c:7466
-#: fortran/symbol.c:1875
+#: fortran/decl.c:7026 fortran/decl.c:7030 fortran/decl.c:7285
+#: fortran/decl.c:7289 fortran/decl.c:7481 fortran/decl.c:7485
+#: fortran/symbol.c:1889
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr ""
 
-#: fortran/decl.c:7164
+#: fortran/decl.c:7183
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/decl.c:7173
+#: fortran/decl.c:7192
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr ""
 
-#: fortran/decl.c:7176
+#: fortran/decl.c:7195
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr ""
 
-#: fortran/decl.c:7179
+#: fortran/decl.c:7198
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SUBMODULE"
 msgstr "overflow in constante expressie"
 
-#: fortran/decl.c:7182
+#: fortran/decl.c:7201
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr ""
 
-#: fortran/decl.c:7186 fortran/decl.c:7231
+#: fortran/decl.c:7205 fortran/decl.c:7250
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr ""
 
-#: fortran/decl.c:7190
+#: fortran/decl.c:7209
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a STRUCTURE block"
 msgstr "overflow in constante expressie"
 
-#: fortran/decl.c:7194
+#: fortran/decl.c:7213
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr ""
 
-#: fortran/decl.c:7198
+#: fortran/decl.c:7217
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr ""
 
-#: fortran/decl.c:7203
+#: fortran/decl.c:7222
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr ""
 
-#: fortran/decl.c:7207
+#: fortran/decl.c:7226
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr ""
 
-#: fortran/decl.c:7211
+#: fortran/decl.c:7230
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr ""
 
-#: fortran/decl.c:7215
+#: fortran/decl.c:7234
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr ""
 
-#: fortran/decl.c:7219
+#: fortran/decl.c:7238
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr ""
 
-#: fortran/decl.c:7223
+#: fortran/decl.c:7242
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected ENTRY statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/decl.c:7244
+#: fortran/decl.c:7263
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr "overflow in constante expressie"
 
-#: fortran/decl.c:7295 fortran/decl.c:7501
+#: fortran/decl.c:7314 fortran/decl.c:7520
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7563 fortran/decl.c:7570
+#: fortran/decl.c:7582 fortran/decl.c:7589
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:7610
+#: fortran/decl.c:7629
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr "constant object wordt beschreven (argument %d)"
 
-#: fortran/decl.c:7626
+#: fortran/decl.c:7645
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr "overflow in constante expressie"
 
-#: fortran/decl.c:7634
+#: fortran/decl.c:7653
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr ""
 
-#: fortran/decl.c:7653
+#: fortran/decl.c:7672
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing closing paren for binding label at %C"
 msgstr "parameternaam ontbreekt uit parameterlijst"
 
-#: fortran/decl.c:7659
+#: fortran/decl.c:7678
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr "Functienaam '%s' niet toegestaan op %C"
 
-#: fortran/decl.c:7665
+#: fortran/decl.c:7684
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7694
+#: fortran/decl.c:7713
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr ""
 
-#: fortran/decl.c:7939
+#: fortran/decl.c:7958
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7948
+#: fortran/decl.c:7967
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "END statement instead of %s statement at %L"
 msgstr "ongeldige beginwaarde"
 
 #. We would have required END [something].
-#: fortran/decl.c:7957
+#: fortran/decl.c:7976
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr ""
 
-#: fortran/decl.c:7968
+#: fortran/decl.c:7987
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s statement at %L"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/decl.c:7988
+#: fortran/decl.c:8007
 #, fuzzy, gcc-internal-format
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr "ongeldige expressie als operand"
 
-#: fortran/decl.c:8005
+#: fortran/decl.c:8024
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr ""
 
-#: fortran/decl.c:8019 fortran/decl.c:8027
+#: fortran/decl.c:8038 fortran/decl.c:8046
 #, fuzzy, gcc-internal-format
 msgid "Expected label %qs for %s statement at %C"
 msgstr "ongeldige expressie als operand"
 
-#: fortran/decl.c:8126
+#: fortran/decl.c:8145
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr ""
 
-#: fortran/decl.c:8134
+#: fortran/decl.c:8153
 #, gcc-internal-format, gfc-internal-format
 msgid "Dimensions specified for %s at %L after its initialization"
 msgstr ""
 
-#: fortran/decl.c:8142
+#: fortran/decl.c:8161
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr ""
 
-#: fortran/decl.c:8151
+#: fortran/decl.c:8170
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr ""
 
-#: fortran/decl.c:8249
+#: fortran/decl.c:8268
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr ""
 
-#: fortran/decl.c:8286
+#: fortran/decl.c:8305
 #, fuzzy, gcc-internal-format
 msgid "Expected %<(%> at %C"
 msgstr "ongeldige operand van %s"
 
-#: fortran/decl.c:8300 fortran/decl.c:8340
+#: fortran/decl.c:8319 fortran/decl.c:8359
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr ""
 
-#: fortran/decl.c:8316
+#: fortran/decl.c:8335
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C must be an integer"
 msgstr ""
 
-#: fortran/decl.c:8320
+#: fortran/decl.c:8339
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr ""
 
-#: fortran/decl.c:8326
+#: fortran/decl.c:8345
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr ""
 
-#: fortran/decl.c:8365
+#: fortran/decl.c:8384
 #, gcc-internal-format
 msgid "Couldn't set Cray pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:8389
+#: fortran/decl.c:8408
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr ""
 
-#: fortran/decl.c:8401
+#: fortran/decl.c:8420
 #, fuzzy, gcc-internal-format
 msgid "Expected %<,%> or end of statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/decl.c:8427
+#: fortran/decl.c:8446
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:8459
+#: fortran/decl.c:8478
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:8478
+#: fortran/decl.c:8497
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer declaration at %C requires -fcray-pointer flag"
 msgstr ""
 
-#: fortran/decl.c:8517
+#: fortran/decl.c:8536
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/decl.c:8623
+#: fortran/decl.c:8642
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:8640
+#: fortran/decl.c:8659
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:8679
+#: fortran/decl.c:8698
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED statement at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:8717
+#: fortran/decl.c:8736
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:8741
+#: fortran/decl.c:8760
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:8778
+#: fortran/decl.c:8797
 #, gcc-internal-format, gfc-internal-format
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:8806
+#: fortran/decl.c:8825
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr ""
 
-#: fortran/decl.c:8813
+#: fortran/decl.c:8832
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8819
+#: fortran/decl.c:8838
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr ""
 
-#: fortran/decl.c:8839
+#: fortran/decl.c:8858
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Initializing already initialized variable at %C"
 msgstr "Initialisatie op %C is niet voor een pointervariable"
 
 #. With legacy PARAMETER statements, don't expect a terminating ')'.
-#: fortran/decl.c:8864
+#: fortran/decl.c:8883
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER without '()' at %C"
 msgstr ""
 
-#: fortran/decl.c:8880
+#: fortran/decl.c:8899
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8899 fortran/decl.c:8955
+#: fortran/decl.c:8918 fortran/decl.c:8974
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:8934
+#: fortran/decl.c:8953
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in AUTOMATIC statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/decl.c:8941
+#: fortran/decl.c:8960
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in AUTOMATIC statement at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:8990
+#: fortran/decl.c:9009
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in STATIC statement at %C"
 msgstr "ongeldige expressie als operand"
 
-#: fortran/decl.c:8997
+#: fortran/decl.c:9016
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in STATIC statement at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:9016
+#: fortran/decl.c:9035
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:9027
+#: fortran/decl.c:9046
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:9073
+#: fortran/decl.c:9092
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9087
+#: fortran/decl.c:9106
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:9091
+#: fortran/decl.c:9110
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VALUE statement at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:9129
+#: fortran/decl.c:9148
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VALUE statement at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:9141
+#: fortran/decl.c:9160
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE statement at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:9168
+#: fortran/decl.c:9187
 #, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr ""
 
-#: fortran/decl.c:9193
+#: fortran/decl.c:9212
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:9205
+#: fortran/decl.c:9224
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9249
+#: fortran/decl.c:9268
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:9274
+#: fortran/decl.c:9293
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE declaration at %C"
 msgstr "twee of meer data types in de declaratie van %qs"
 
-#: fortran/decl.c:9367
+#: fortran/decl.c:9386
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr ""
 
-#: fortran/decl.c:9425
+#: fortran/decl.c:9444
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr ""
 
-#: fortran/decl.c:9474
+#: fortran/decl.c:9493
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr ""
 
-#: fortran/decl.c:9483
+#: fortran/decl.c:9502
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/decl.c:9489
+#: fortran/decl.c:9508
 #, gcc-internal-format
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr ""
 
-#: fortran/decl.c:9496
+#: fortran/decl.c:9515
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:9503
+#: fortran/decl.c:9522
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr ""
 
-#: fortran/decl.c:9526
+#: fortran/decl.c:9545
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:9538
+#: fortran/decl.c:9557
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:9559
+#: fortran/decl.c:9578
 #, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
 msgstr ""
 
-#: fortran/decl.c:9605
+#: fortran/decl.c:9624
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Failed to create structure type '%s' at %C"
 msgstr "herhaalde case-waarde"
 
-#: fortran/decl.c:9611
+#: fortran/decl.c:9630
 #, fuzzy, gcc-internal-format
 msgid "Type definition of %qs at %C was already defined at %L"
 msgstr "veld %qs heeft al een beginwaarde gekregen"
 
-#: fortran/decl.c:9658
+#: fortran/decl.c:9677
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Junk after MAP statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/decl.c:9691
+#: fortran/decl.c:9710
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Junk after UNION statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/decl.c:9726
+#: fortran/decl.c:9745
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr ""
 
-#: fortran/decl.c:9740
+#: fortran/decl.c:9759
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected in non-nested structure declaration at %C"
 msgstr "conflicterende declaraties van %qs"
 
-#: fortran/decl.c:9758
+#: fortran/decl.c:9777
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Junk after non-nested STRUCTURE statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/decl.c:9765
+#: fortran/decl.c:9784
 #, fuzzy, gcc-internal-format
 msgid "Structure name %qs at %C cannot be the same as an intrinsic type"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/decl.c:9926
+#: fortran/decl.c:9947
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr ""
 
-#: fortran/decl.c:9954
+#: fortran/decl.c:9975
 #, fuzzy, gcc-internal-format
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/decl.c:9964
+#: fortran/decl.c:9986
 #, fuzzy, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr "gevraagd alignment is geen macht van 2"
 
-#: fortran/decl.c:9981
+#: fortran/decl.c:9989
 #, fuzzy, gcc-internal-format
+msgid "Derived type name %qs at %C already has a basic type"
+msgstr "gevraagd alignment is geen macht van 2"
+
+#: fortran/decl.c:10006
+#, fuzzy, gcc-internal-format
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr "kan klasse '%s' niet vinden"
 
-#: fortran/decl.c:10042
+#: fortran/decl.c:10067
 #, gcc-internal-format, gfc-internal-format
 msgid "Garbage after PARAMETERIZED TYPE declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:10126
+#: fortran/decl.c:10151
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr ""
 
-#: fortran/decl.c:10146
+#: fortran/decl.c:10171
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM and ENUMERATOR at %C"
 msgstr ""
 
-#: fortran/decl.c:10178
+#: fortran/decl.c:10203
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr ""
 
-#: fortran/decl.c:10257
+#: fortran/decl.c:10282
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr ""
 
-#: fortran/decl.c:10305
+#: fortran/decl.c:10330
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr ""
 
-#: fortran/decl.c:10341
+#: fortran/decl.c:10366
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr ""
 
-#: fortran/decl.c:10388 fortran/decl.c:10403
+#: fortran/decl.c:10413 fortran/decl.c:10428
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate access-specifier at %C"
 msgstr "herhaalde label-declaratie %qs"
 
-#: fortran/decl.c:10423
+#: fortran/decl.c:10448
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10443
+#: fortran/decl.c:10468
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10470
+#: fortran/decl.c:10495
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate POINTER attribute at %C"
 msgstr "herhaalde label-declaratie %qs"
 
-#: fortran/decl.c:10488
+#: fortran/decl.c:10513
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr ""
 
-#: fortran/decl.c:10504
+#: fortran/decl.c:10529
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DEFERRED at %C"
 msgstr ""
 
-#: fortran/decl.c:10517
+#: fortran/decl.c:10542
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected access-specifier at %C"
 msgstr "Array subscript verwacht op %C"
 
-#: fortran/decl.c:10519
+#: fortran/decl.c:10544
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr "herhaalde label-declaratie %qs"
 
-#: fortran/decl.c:10527
+#: fortran/decl.c:10552
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED can't both appear at %C"
 msgstr ""
 
-#: fortran/decl.c:10539
+#: fortran/decl.c:10564
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:10581
+#: fortran/decl.c:10606
 #, gcc-internal-format
 msgid "Interface-name expected after %<(%> at %C"
 msgstr ""
 
-#: fortran/decl.c:10587
+#: fortran/decl.c:10612
 #, fuzzy, gcc-internal-format
 msgid "%<)%> expected at %C"
 msgstr "ongeldige operand van %s"
 
-#: fortran/decl.c:10607
+#: fortran/decl.c:10632
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr "constant object wordt beschreven (argument %d)"
 
-#: fortran/decl.c:10612
+#: fortran/decl.c:10637
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:10635
+#: fortran/decl.c:10660
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr "ongeldige expressie als operand"
 
-#: fortran/decl.c:10639
+#: fortran/decl.c:10664
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
 msgstr ""
 
-#: fortran/decl.c:10651
+#: fortran/decl.c:10676
 #, fuzzy, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr "constant object wordt beschreven (argument %d)"
 
-#: fortran/decl.c:10657
+#: fortran/decl.c:10682
 #, gcc-internal-format
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr ""
 
-#: fortran/decl.c:10667
+#: fortran/decl.c:10692
 #, fuzzy, gcc-internal-format
 msgid "Expected binding target after %<=>%> at %C"
 msgstr "ongeldige waarheidsexpressie"
 
-#: fortran/decl.c:10684
+#: fortran/decl.c:10709
 #, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr ""
 
-#: fortran/decl.c:10695
+#: fortran/decl.c:10720
 #, gcc-internal-format
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:10746
+#: fortran/decl.c:10771
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr ""
 
-#: fortran/decl.c:10766
+#: fortran/decl.c:10791
 #, fuzzy, gcc-internal-format
 msgid "Expected %<::%> at %C"
 msgstr "ongeldige operand van %s"
 
-#: fortran/decl.c:10778
+#: fortran/decl.c:10803
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected generic name or operator descriptor at %C"
 msgstr "Array subscript verwacht op %C"
 
-#: fortran/decl.c:10799
+#: fortran/decl.c:10824
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Malformed GENERIC statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/decl.c:10810
+#: fortran/decl.c:10835
 #, fuzzy, gcc-internal-format
 msgid "Expected %<=>%> at %C"
 msgstr "ongeldige operand van %s"
 
-#: fortran/decl.c:10846
+#: fortran/decl.c:10871
 #, gcc-internal-format
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:10854
+#: fortran/decl.c:10879
 #, gcc-internal-format
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr ""
 
-#: fortran/decl.c:10902
+#: fortran/decl.c:10927
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr "ongeldige expressie als operand"
 
-#: fortran/decl.c:10912
+#: fortran/decl.c:10937
 #, fuzzy, gcc-internal-format
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr "fout in argumenten voor spec-functie '%s'"
 
-#: fortran/decl.c:10930
+#: fortran/decl.c:10955
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr ""
 
-#: fortran/decl.c:10965
+#: fortran/decl.c:10990
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr ""
 
-#: fortran/decl.c:10976
+#: fortran/decl.c:11001
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr ""
 
-#: fortran/decl.c:10998
+#: fortran/decl.c:11023
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr ""
 
-#: fortran/decl.c:11005
+#: fortran/decl.c:11030
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/decl.c:11015
+#: fortran/decl.c:11040
 #, fuzzy, gcc-internal-format
 msgid "Expected %<,%> at %C"
 msgstr "ongeldige operand van %s"
 
-#: fortran/decl.c:11021
+#: fortran/decl.c:11046
 #, fuzzy, gcc-internal-format
 msgid "Unknown procedure name %qs at %C"
 msgstr "onbekende operator '%s' in %%:version-compare"
 
-#: fortran/decl.c:11034
+#: fortran/decl.c:11059
 #, fuzzy, gcc-internal-format
 msgid "%qs at %C is already defined as FINAL procedure"
 msgstr "veld %qs heeft al een beginwaarde gekregen"
 
-#: fortran/decl.c:11104
+#: fortran/decl.c:11129
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr ""
 
-#: fortran/decl.c:11150
+#: fortran/decl.c:11175
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr "%s voor %qs"
 
-#: fortran/decl.c:11170
+#: fortran/decl.c:11195
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive requires a non-negative integral constant less than or equal to %u at %C"
 msgstr ""
 
-#: fortran/decl.c:11184
+#: fortran/decl.c:11209
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ UNROLL directive at %C"
 msgstr "%s voor %qs"
@@ -54662,27 +54735,27 @@
 msgid "BOZ literal at %L used to initialize non-integer variable %qs"
 msgstr ""
 
-#: fortran/expr.c:3369 fortran/resolve.c:10197
+#: fortran/expr.c:3369 fortran/resolve.c:10210
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal at %L outside a DATA statement and outside INT/REAL/DBLE/CMPLX"
 msgstr ""
 
-#: fortran/expr.c:3380 fortran/resolve.c:10208
+#: fortran/expr.c:3380 fortran/resolve.c:10221
 #, gcc-internal-format
 msgid "BOZ literal at %L is bitwise transferred non-integer symbol %qs"
 msgstr ""
 
-#: fortran/expr.c:3388 fortran/resolve.c:10217
+#: fortran/expr.c:3388 fortran/resolve.c:10230
 #, fuzzy, gcc-internal-format
 msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "Arithmetische underflow bij conversie van %s naar %s op %L"
 
-#: fortran/expr.c:3392 fortran/resolve.c:10221
+#: fortran/expr.c:3392 fortran/resolve.c:10234
 #, fuzzy, gcc-internal-format
 msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "Arithmetische underflow bij conversie van %s naar %s op %L"
 
-#: fortran/expr.c:3396 fortran/resolve.c:10225
+#: fortran/expr.c:3396 fortran/resolve.c:10238
 #, fuzzy, gcc-internal-format
 msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "Arithmetische underflow bij conversie van %s naar %s op %L"
@@ -54692,147 +54765,147 @@
 msgid "The assignment to a KIND or LEN component of a parameterized type at %L is not allowed"
 msgstr ""
 
-#: fortran/expr.c:3426
+#: fortran/expr.c:3429
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible types in DATA statement at %L; attempted conversion of %s to %s"
 msgstr ""
 
-#: fortran/expr.c:3465
+#: fortran/expr.c:3468
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is not a POINTER at %L"
 msgstr ""
 
-#: fortran/expr.c:3473
+#: fortran/expr.c:3476
 #, gcc-internal-format
 msgid "%qs in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgstr ""
 
-#: fortran/expr.c:3496
+#: fortran/expr.c:3499
 #, fuzzy, gcc-internal-format
 msgid "Expected bounds specification for %qs at %L"
 msgstr "herhaalde label-declaratie %qs"
 
-#: fortran/expr.c:3501
+#: fortran/expr.c:3504
 #, fuzzy, gcc-internal-format
 msgid "Bounds specification for %qs in pointer assignment at %L"
 msgstr "herhaalde label-declaratie %qs"
 
-#: fortran/expr.c:3514
+#: fortran/expr.c:3517
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower bound has to be present at %L"
 msgstr ""
 
-#: fortran/expr.c:3520
+#: fortran/expr.c:3523
 #, gcc-internal-format, gfc-internal-format
 msgid "Stride must not be present at %L"
 msgstr ""
 
-#: fortran/expr.c:3532
+#: fortran/expr.c:3535
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the upper bounds must be specified at %L"
 msgstr ""
 
-#: fortran/expr.c:3558
+#: fortran/expr.c:3561
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %L shall not have a coindex"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/expr.c:3579
+#: fortran/expr.c:3582
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3603
+#: fortran/expr.c:3606
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs is invalid as proc-target in procedure pointer assignment at %L"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/expr.c:3612
+#: fortran/expr.c:3615
 #, fuzzy, gcc-internal-format
 msgid "Abstract interface %qs is invalid in procedure pointer assignment at %L"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/expr.c:3622
+#: fortran/expr.c:3625
 #, fuzzy, gcc-internal-format
 msgid "Statement function %qs is invalid in procedure pointer assignment at %L"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/expr.c:3628
+#: fortran/expr.c:3631
 #, fuzzy, gcc-internal-format
 msgid "Internal procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/expr.c:3635
+#: fortran/expr.c:3638
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic %qs at %L is invalid in procedure pointer assignment"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/expr.c:3643
+#: fortran/expr.c:3646
 #, fuzzy, gcc-internal-format
 msgid "Nonintrinsic elemental procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/expr.c:3666
+#: fortran/expr.c:3669
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in the procedure pointer assignment at %L: mismatch in the calling convention"
 msgstr ""
 
-#: fortran/expr.c:3719
+#: fortran/expr.c:3722
 #, fuzzy, gcc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %qs is not a subroutine"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/expr.c:3729 fortran/expr.c:3744
+#: fortran/expr.c:3732 fortran/expr.c:3747
 #, fuzzy, gcc-internal-format
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/expr.c:3735 fortran/expr.c:3750 fortran/resolve.c:2566
+#: fortran/expr.c:3738 fortran/expr.c:3753 fortran/resolve.c:2566
 #, fuzzy, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/expr.c:3762
+#: fortran/expr.c:3765
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %s"
 msgstr ""
 
-#: fortran/expr.c:3771
+#: fortran/expr.c:3774
 #, gcc-internal-format
 msgid "Procedure pointer target %qs at %L must be either an intrinsic, host or use associated, referenced or have the EXTERNAL attribute"
 msgstr ""
 
-#: fortran/expr.c:3788
+#: fortran/expr.c:3791
 #, gcc-internal-format, gfc-internal-format
 msgid "Data-pointer-object at %L must be unlimited polymorphic, or of a type with the BIND or SEQUENCE attribute, to be compatible with an unlimited polymorphic target"
 msgstr ""
 
-#: fortran/expr.c:3793
+#: fortran/expr.c:3796
 #, gcc-internal-format, gfc-internal-format
 msgid "Different types in pointer assignment at %L; attempted assignment of %s to %s"
 msgstr ""
 
-#: fortran/expr.c:3802
+#: fortran/expr.c:3805
 #, gcc-internal-format, gfc-internal-format
 msgid "Different kind type parameters in pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3809
+#: fortran/expr.c:3812
 #, gcc-internal-format, gfc-internal-format
 msgid "Different ranks in pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3828
+#: fortran/expr.c:3831
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is smaller than size of the pointer (%ld < %ld) at %L"
 msgstr ""
 
-#: fortran/expr.c:3841
+#: fortran/expr.c:3844
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target must be rank 1 or simply contiguous at %L"
 msgstr ""
 
-#: fortran/expr.c:3845
+#: fortran/expr.c:3848
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is not rank 1 at %L"
 msgstr ""
@@ -54840,149 +54913,154 @@
 #. The test above might need to be extend when F08, Note 5.4 has to be
 #. interpreted in the way that target and pointer with the same coindex
 #. are allowed.
-#: fortran/expr.c:3877 fortran/expr.c:3925
+#: fortran/expr.c:3880 fortran/expr.c:3928
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data target at %L shall not have a coindex"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: fortran/expr.c:3880
+#: fortran/expr.c:3883
 #, gcc-internal-format, gfc-internal-format
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr ""
 
-#: fortran/expr.c:3888
+#: fortran/expr.c:3891
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr ""
 
-#: fortran/expr.c:3895
+#: fortran/expr.c:3898
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr ""
 
-#: fortran/expr.c:3904
+#: fortran/expr.c:3907
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr ""
 
-#: fortran/expr.c:3912
+#: fortran/expr.c:3915
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr "%s van alleen-lezen variabele %qs"
 
-#: fortran/expr.c:3936
+#: fortran/expr.c:3939
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to contiguous pointer from non-contiguous target at %L"
 msgstr ""
 
-#: fortran/expr.c:3975
+#: fortran/expr.c:3978
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr ""
 
-#: fortran/expr.c:4051 fortran/resolve.c:1452
+#: fortran/expr.c:4054 fortran/resolve.c:1452
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: fortran/expr.c:4057
+#: fortran/expr.c:4060
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr ""
 
-#: fortran/expr.c:4072 fortran/resolve.c:1458
+#: fortran/expr.c:4075 fortran/resolve.c:1458
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: fortran/expr.c:4084
+#: fortran/expr.c:4087
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr ""
 
-#: fortran/expr.c:5512
+#: fortran/expr.c:4557
+#, gcc-internal-format
+msgid "generate_isocbinding_initializer(): bad iso_c_binding type, expected %<c_ptr%> or %<c_funptr%>"
+msgstr ""
+
+#: fortran/expr.c:5568
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr "ongeldige waarheidsexpressie"
 
-#: fortran/expr.c:5520
+#: fortran/expr.c:5576
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5528
+#: fortran/expr.c:5584
 #, fuzzy, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr "ongeldige waarheidsexpressie"
 
 # dit klinkt niet al te best
-#: fortran/expr.c:5537
+#: fortran/expr.c:5593
 #, fuzzy, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr "functie-oproep heeft geaggregeerde waarde"
 
-#: fortran/expr.c:5548
+#: fortran/expr.c:5604
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5557
+#: fortran/expr.c:5613
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr "ongeldige waarheidsexpressie"
 
-#: fortran/expr.c:5570
+#: fortran/expr.c:5626
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr ""
 
 # dit klinkt niet al te best
-#: fortran/expr.c:5583
+#: fortran/expr.c:5639
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr "functie-oproep heeft geaggregeerde waarde"
 
-#: fortran/expr.c:5613
+#: fortran/expr.c:5669
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr "overflow in constante expressie"
 
-#: fortran/expr.c:5621
+#: fortran/expr.c:5677
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr "overflow in constante expressie"
 
-#: fortran/expr.c:5634
+#: fortran/expr.c:5690
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a pointer association context (%s) at %L"
 msgstr "overflow in constante expressie"
 
-#: fortran/expr.c:5642
+#: fortran/expr.c:5698
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a variable definition context (%s) at %L"
 msgstr "overflow in constante expressie"
 
-#: fortran/expr.c:5654
+#: fortran/expr.c:5710
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs can not appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr "overflow in constante expressie"
 
-#: fortran/expr.c:5713
+#: fortran/expr.c:5769
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
 msgstr "overflow in constante expressie"
 
-#: fortran/expr.c:5717
+#: fortran/expr.c:5773
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L associated to expression can not be used in a variable definition context (%s)"
 msgstr "overflow in constante expressie"
 
-#: fortran/expr.c:5728
+#: fortran/expr.c:5784
 #, fuzzy, gcc-internal-format
 msgid "Associate-name %qs can not appear in a variable definition context (%s) at %L because its target at %L can not, either"
 msgstr "overflow in constante expressie"
 
-#: fortran/expr.c:5770
+#: fortran/expr.c:5826
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr ""
@@ -54992,22 +55070,22 @@
 msgid "can't open input file: %s"
 msgstr "kan bestand '%s' niet openen"
 
-#: fortran/frontend-passes.c:190
+#: fortran/frontend-passes.c:192
 #, fuzzy, gcc-internal-format
 msgid "No location in statement"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/frontend-passes.c:205
+#: fortran/frontend-passes.c:207
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "No location in expression near %L"
 msgstr "vector overflow in expressie"
 
-#: fortran/frontend-passes.c:409
+#: fortran/frontend-passes.c:414
 #, gcc-internal-format
 msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
-#: fortran/frontend-passes.c:817 fortran/trans-array.c:1182
+#: fortran/frontend-passes.c:822 fortran/trans-array.c:1182
 #: fortran/trans-array.c:6440 fortran/trans-array.c:7864
 #: fortran/trans-intrinsic.c:7307
 #, fuzzy, gcc-internal-format, gfc-internal-format
@@ -55014,67 +55092,67 @@
 msgid "Creating array temporary at %L"
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/frontend-passes.c:842 fortran/frontend-passes.c:846
+#: fortran/frontend-passes.c:847 fortran/frontend-passes.c:851
 #, fuzzy, gcc-internal-format
 msgid "Removing call to function %qs at %L"
 msgstr "Bestandsnaam ontbreekt na %qs optie"
 
-#: fortran/frontend-passes.c:1273 fortran/frontend-passes.c:1312
+#: fortran/frontend-passes.c:1278 fortran/frontend-passes.c:1317
 #, fuzzy, gcc-internal-format
 msgid "bad expression"
 msgstr "ongeldige waarheidsexpressie"
 
-#: fortran/frontend-passes.c:1308
+#: fortran/frontend-passes.c:1313
 #, fuzzy, gcc-internal-format
 msgid "bad op"
 msgstr "slechte test"
 
-#: fortran/frontend-passes.c:2161
+#: fortran/frontend-passes.c:2166
 #, fuzzy, gcc-internal-format
 msgid "illegal OP in optimize_comparison"
 msgstr "ongeldige operand in de instructie"
 
-#: fortran/frontend-passes.c:2407
+#: fortran/frontend-passes.c:2412
 #, gcc-internal-format
 msgid "Variable %qs at %L set to undefined value inside loop  beginning at %L as INTENT(OUT) argument to subroutine %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:2414
+#: fortran/frontend-passes.c:2419
 #, gcc-internal-format
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to subroutine %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:2637 fortran/frontend-passes.c:2661
+#: fortran/frontend-passes.c:2642 fortran/frontend-passes.c:2666
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L out of bounds (%ld < %ld) in loop beginning at %L"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/frontend-passes.c:2646 fortran/frontend-passes.c:2670
+#: fortran/frontend-passes.c:2651 fortran/frontend-passes.c:2675
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L out of bounds (%ld > %ld) in loop beginning at %L"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/frontend-passes.c:2730
+#: fortran/frontend-passes.c:2735
 #, gcc-internal-format
 msgid "Variable %qs at %L set to undefined value inside loop beginning at %L as INTENT(OUT) argument to function %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:2736
+#: fortran/frontend-passes.c:2741
 #, gcc-internal-format
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:3128 fortran/trans-expr.c:1581
+#: fortran/frontend-passes.c:3133 fortran/trans-expr.c:1581
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr ""
 
-#: fortran/frontend-passes.c:3637
+#: fortran/frontend-passes.c:3642
 #, gcc-internal-format
 msgid "Scalarization using DIMEN_RANGE unimplemented"
 msgstr ""
 
-#: fortran/frontend-passes.c:4429
+#: fortran/frontend-passes.c:4434
 #, gcc-internal-format, gfc-internal-format
 msgid "Interchanging loops at %L"
 msgstr ""
@@ -55194,12 +55272,12 @@
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:970 fortran/resolve.c:16351
+#: fortran/interface.c:970 fortran/resolve.c:16378
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:977 fortran/resolve.c:16369
+#: fortran/interface.c:977 fortran/resolve.c:16396
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
@@ -56392,7 +56470,7 @@
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.c:3369 fortran/resolve.c:14263
+#: fortran/io.c:3369 fortran/resolve.c:14283
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -56559,7 +56637,7 @@
 msgid "Integer too large at %C"
 msgstr ""
 
-#: fortran/match.c:580 fortran/parse.c:1132
+#: fortran/match.c:580 fortran/parse.c:1136
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Too many digits in statement label at %C"
 msgstr "ongeldige beginwaarde"
@@ -57321,57 +57399,57 @@
 msgid "Expected block name %qs of SELECT construct at %C"
 msgstr "ongeldige expressie als operand"
 
-#: fortran/match.c:6186
+#: fortran/match.c:6201
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "parse error in SELECT TYPE statement at %C"
 msgstr "%s voor %qs"
 
-#: fortran/match.c:6211
+#: fortran/match.c:6226
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr ""
 
-#: fortran/match.c:6249
+#: fortran/match.c:6264
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr ""
 
-#: fortran/match.c:6301
+#: fortran/match.c:6316
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CASE specification at %C"
 msgstr "twee of meer data types in de declaratie van %qs"
 
-#: fortran/match.c:6319
+#: fortran/match.c:6334
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected TYPE IS statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/match.c:6351
+#: fortran/match.c:6366
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr ""
 
-#: fortran/match.c:6362
+#: fortran/match.c:6377
 #, gcc-internal-format, gfc-internal-format
 msgid "All the LEN type parameters in the TYPE IS statement at %C must be ASSUMED"
 msgstr ""
 
-#: fortran/match.c:6373
+#: fortran/match.c:6388
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr "twee of meer data types in de declaratie van %qs"
 
-#: fortran/match.c:6449
+#: fortran/match.c:6464
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr "twee of meer data types in de declaratie van %qs"
 
-#: fortran/match.c:6572
+#: fortran/match.c:6587
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr ""
 
-#: fortran/match.c:6610
+#: fortran/match.c:6625
 #, gcc-internal-format
 msgid "Label %qs at %C doesn't match WHERE label %qs"
 msgstr ""
@@ -57522,188 +57600,188 @@
 msgid "mio_array_ref(): Unknown array ref"
 msgstr ""
 
-#: fortran/module.c:3716
+#: fortran/module.c:3718
 #, gcc-internal-format, gfc-internal-format
 msgid "Namelist %s cannot be renamed by USE association to %s"
 msgstr ""
 
-#: fortran/module.c:4832
+#: fortran/module.c:4834
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4835
+#: fortran/module.c:4837
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:5029
+#: fortran/module.c:5031
 #, gcc-internal-format
 msgid "%qs of module %qs, imported at %C, is also the name of the current program unit"
 msgstr ""
 
-#: fortran/module.c:5381
+#: fortran/module.c:5383
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in module %qs"
 msgstr "naar label %s gerefereerd buiten enige functie"
 
-#: fortran/module.c:5388
+#: fortran/module.c:5390
 #, fuzzy, gcc-internal-format
 msgid "User operator %qs referenced at %L not found in module %qs"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/module.c:5393
+#: fortran/module.c:5395
 #, gcc-internal-format
 msgid "Intrinsic operator %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5628
+#: fortran/module.c:5630
 #, gcc-internal-format
 msgid "write_symbol(): bad module symbol %qs"
 msgstr ""
 
-#: fortran/module.c:5961
+#: fortran/module.c:5963
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr ""
 
-#: fortran/module.c:6148
+#: fortran/module.c:6150
 #, fuzzy, gcc-internal-format
 msgid "Can't open module file %qs for writing at %C: %s"
 msgstr "%s: kan bestand '%s' niet openen om te lezen: %s\n"
 
-#: fortran/module.c:6169
+#: fortran/module.c:6171
 #, fuzzy, gcc-internal-format
 msgid "Error writing module file %qs for writing: %s"
 msgstr "%s: fout bij schrijven van bestand '%s': %s\n"
 
-#: fortran/module.c:6180
+#: fortran/module.c:6182
 #, fuzzy, gcc-internal-format
 msgid "Can't delete module file %qs: %s"
 msgstr "%s: kan aux-infobestand '%s' niet verwijderen: %s\n"
 
-#: fortran/module.c:6183
+#: fortran/module.c:6185
 #, fuzzy, gcc-internal-format
 msgid "Can't rename module file %qs to %qs: %s"
 msgstr "%s: waarschuwing: kan naam van bestand '%s' niet wijzigen in '%s': %s\n"
 
-#: fortran/module.c:6189
+#: fortran/module.c:6191
 #, fuzzy, gcc-internal-format
 msgid "Can't delete temporary module file %qs: %s"
 msgstr "%s: kan aux-infobestand '%s' niet verwijderen: %s\n"
 
-#: fortran/module.c:6246
+#: fortran/module.c:6248
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C already declared"
 msgstr "gevraagd alignment is geen macht van 2"
 
-#: fortran/module.c:6317
+#: fortran/module.c:6319
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr ""
 
-#: fortran/module.c:6425 fortran/module.c:6769
+#: fortran/module.c:6427 fortran/module.c:6771
 #, gcc-internal-format
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr ""
 
-#: fortran/module.c:6553
+#: fortran/module.c:6555
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr ""
 
-#: fortran/module.c:6574 fortran/module.c:6607 fortran/module.c:6649
+#: fortran/module.c:6576 fortran/module.c:6609 fortran/module.c:6651
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs already declared"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: fortran/module.c:6754
+#: fortran/module.c:6756
 #, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:6776
+#: fortran/module.c:6778
 #, gcc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr ""
 
-#: fortran/module.c:6844
+#: fortran/module.c:6846
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr ""
 
-#: fortran/module.c:6898
+#: fortran/module.c:6900
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr ""
 
-#: fortran/module.c:6924
+#: fortran/module.c:6926
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/module.c:6953
+#: fortran/module.c:6955
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr ""
 
-#: fortran/module.c:6965
+#: fortran/module.c:6967
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
 msgstr ""
 
-#: fortran/module.c:6978
+#: fortran/module.c:6980
 #, gcc-internal-format
 msgid "Can't find an intrinsic module named %qs at %C"
 msgstr ""
 
-#: fortran/module.c:6984
+#: fortran/module.c:6986
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr ""
 
-#: fortran/module.c:6990
+#: fortran/module.c:6992
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr ""
 
-#: fortran/module.c:6996
+#: fortran/module.c:6998
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr ""
 
-#: fortran/module.c:7006
+#: fortran/module.c:7008
 #, fuzzy, gcc-internal-format
 msgid "Can't open module file %qs for reading at %C: %s"
 msgstr "%s: kan bestand '%s' niet openen om te lezen: %s\n"
 
-#: fortran/module.c:7009
+#: fortran/module.c:7011
 #, gcc-internal-format
 msgid "Module file %qs has not been generated, either because the module does not contain a MODULE PROCEDURE or there is an error in the module."
 msgstr ""
 
-#: fortran/module.c:7020
+#: fortran/module.c:7022
 #, gcc-internal-format
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:7043
+#: fortran/module.c:7045
 #, gcc-internal-format
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr ""
 
-#: fortran/module.c:7051
+#: fortran/module.c:7053
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr ""
 
-#: fortran/module.c:7066
+#: fortran/module.c:7068
 #, gcc-internal-format, gfc-internal-format
 msgid "Can't USE the same %smodule we're building"
 msgstr ""
 
 #: fortran/openmp.c:296 fortran/openmp.c:397 fortran/openmp.c:692
-#: fortran/openmp.c:3167
+#: fortran/openmp.c:3166
 #, gcc-internal-format, gfc-internal-format
 msgid "COMMON block /%s/ not found at %C"
 msgstr ""
@@ -57781,862 +57859,862 @@
 #: fortran/openmp.c:2180
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "valid arguments to %qs are: %s"
-msgid "Invalid argument to !$ACC WAIT at %L"
+msgid "Invalid argument to !$ACC WAIT at %C"
 msgstr "geldige argumenten van %qs zijn: %s"
 
-#: fortran/openmp.c:2188
+#: fortran/openmp.c:2187
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "WAIT clause at %L requires a scalar INTEGER expression"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/openmp.c:2221
+#: fortran/openmp.c:2220
 #, gcc-internal-format, gfc-internal-format
 msgid "ACC CACHE directive must be inside of loop %C"
 msgstr ""
 
-#: fortran/openmp.c:2252
+#: fortran/openmp.c:2251
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for typename"
 msgid "Multiple loop axes specified for routine"
 msgstr "opslagklasse opgegeven voor typenaam"
 
-#: fortran/openmp.c:2278
+#: fortran/openmp.c:2277
 #, gcc-internal-format, gfc-internal-format
 msgid "Only the !$ACC ROUTINE form without list is allowed in interface block at %C"
 msgstr ""
 
-#: fortran/openmp.c:2306
+#: fortran/openmp.c:2305
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$ACC ROUTINE ( NAME ) at %C, invalid function name %s"
 msgstr ""
 
-#: fortran/openmp.c:2315
+#: fortran/openmp.c:2314
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$ACC ROUTINE ( NAME ) at %C"
 msgstr "%s voor %qs"
 
-#: fortran/openmp.c:2322
+#: fortran/openmp.c:2321
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$ACC ROUTINE ( NAME ) at %C, expecting ')' after NAME"
 msgstr ""
 
-#: fortran/openmp.c:2457 fortran/openmp.c:2481
+#: fortran/openmp.c:2456 fortran/openmp.c:2480
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP CRITICAL statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/openmp.c:2548
+#: fortran/openmp.c:2547
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP FLUSH statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/openmp.c:2942 fortran/openmp.c:6225
+#: fortran/openmp.c:2941 fortran/openmp.c:6230
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined %s !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2946 fortran/openmp.c:6229
+#: fortran/openmp.c:2945 fortran/openmp.c:6234
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2951
+#: fortran/openmp.c:2950
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2953
+#: fortran/openmp.c:2952
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2973
+#: fortran/openmp.c:2972
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after !$OMP DECLARE REDUCTION at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/openmp.c:3010
+#: fortran/openmp.c:3009
 #, gcc-internal-format, gfc-internal-format
 msgid "Only the !$OMP DECLARE TARGET form without clauses is allowed in interface block at %C"
 msgstr ""
 
-#: fortran/openmp.c:3025
+#: fortran/openmp.c:3024
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after !$OMP DECLARE TARGET at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/openmp.c:3048
+#: fortran/openmp.c:3047
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET variable at %L is an element of a COMMON block"
 msgstr ""
 
-#: fortran/openmp.c:3053
+#: fortran/openmp.c:3052
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET variable at %L previously mentioned in LINK clause and later in TO clause"
 msgstr ""
 
-#: fortran/openmp.c:3059
+#: fortran/openmp.c:3058
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET variable at %L previously mentioned in TO clause and later in LINK clause"
 msgstr ""
 
-#: fortran/openmp.c:3063
+#: fortran/openmp.c:3062
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable at %L mentioned multiple times in clauses of the same OMP DECLARE TARGET directive"
 msgstr ""
 
-#: fortran/openmp.c:3078
+#: fortran/openmp.c:3077
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET COMMON at %L previously mentioned in LINK clause and later in TO clause"
 msgstr ""
 
-#: fortran/openmp.c:3084
+#: fortran/openmp.c:3083
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET COMMON at %L previously mentioned in TO clause and later in LINK clause"
 msgstr ""
 
-#: fortran/openmp.c:3088
+#: fortran/openmp.c:3087
 #, gcc-internal-format, gfc-internal-format
 msgid "COMMON at %L mentioned multiple times in clauses of the same OMP DECLARE TARGET directive"
 msgstr ""
 
-#: fortran/openmp.c:3115
+#: fortran/openmp.c:3114
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$OMP DECLARE TARGET list at %C"
 msgstr "constant object wordt beschreven (argument %d)"
 
-#: fortran/openmp.c:3147
+#: fortran/openmp.c:3146
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate variable at %C is an element of a COMMON block"
 msgstr ""
 
-#: fortran/openmp.c:3184
+#: fortran/openmp.c:3183
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after OMP THREADPRIVATE at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/openmp.c:3191
+#: fortran/openmp.c:3190
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$OMP THREADPRIVATE list at %C"
 msgstr "constant object wordt beschreven (argument %d)"
 
-#: fortran/openmp.c:3405
+#: fortran/openmp.c:3404
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after TASKWAIT clause at %C"
 msgstr "conflicterende declaraties van %qs"
 
-#: fortran/openmp.c:3419
+#: fortran/openmp.c:3418
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after TASKYIELD clause at %C"
 msgstr "conflicterende declaraties van %qs"
 
-#: fortran/openmp.c:3478
+#: fortran/openmp.c:3477
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP WORKSHARE statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/openmp.c:3492
+#: fortran/openmp.c:3491
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP MASTER statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/openmp.c:3551
+#: fortran/openmp.c:3550
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP ATOMIC statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/openmp.c:3578
+#: fortran/openmp.c:3577
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP BARRIER statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/openmp.c:3592
+#: fortran/openmp.c:3591
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP TASKGROUP statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/openmp.c:3642
+#: fortran/openmp.c:3641
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP CANCELLATION POINT statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/openmp.c:3662
+#: fortran/openmp.c:3661
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after NOWAIT clause at %C"
 msgstr "conflicterende declaraties van %qs"
 
-#: fortran/openmp.c:3704
+#: fortran/openmp.c:3703
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s clause at %L requires a scalar INTEGER expression"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/openmp.c:3715
+#: fortran/openmp.c:3714
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "INTEGER expression of %s clause at %L must be positive"
 msgstr "%qs is geen bestand, pipe of tty"
 
 # vertaling voor 'statement'?
-#: fortran/openmp.c:3726
+#: fortran/openmp.c:3725
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "INTEGER expression of %s clause at %L must be non-negative"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/openmp.c:3737
+#: fortran/openmp.c:3736
 #, gcc-internal-format
 msgid "POINTER object %qs of derived type in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3740
+#: fortran/openmp.c:3739
 #, fuzzy, gcc-internal-format
 msgid "Cray pointer object %qs of derived type in %s clause at %L"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: fortran/openmp.c:3743
+#: fortran/openmp.c:3742
 #, fuzzy, gcc-internal-format
 msgid "Cray pointee object %qs of derived type in %s clause at %L"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: fortran/openmp.c:3749 fortran/openmp.c:4687
+#: fortran/openmp.c:3748 fortran/openmp.c:4686
 #, gcc-internal-format
 msgid "POINTER object %qs of polymorphic type in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3754
+#: fortran/openmp.c:3753
 #, fuzzy, gcc-internal-format
 msgid "Cray pointer object %qs of polymorphic type in %s clause at %L"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: fortran/openmp.c:3759
+#: fortran/openmp.c:3758
 #, fuzzy, gcc-internal-format
 msgid "Cray pointee object %qs of polymorphic type in %s clause at %L"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: fortran/openmp.c:3769 fortran/openmp.c:4385 fortran/openmp.c:4490
+#: fortran/openmp.c:3768 fortran/openmp.c:4384 fortran/openmp.c:4489
 #, fuzzy, gcc-internal-format
 msgid "Assumed size array %qs in %s clause at %L"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: fortran/openmp.c:3772
+#: fortran/openmp.c:3771
 #, fuzzy, gcc-internal-format
 msgid "Assumed rank array %qs in %s clause at %L"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: fortran/openmp.c:3776
+#: fortran/openmp.c:3775
 #, gcc-internal-format
 msgid "Noncontiguous deferred shape array %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3784
+#: fortran/openmp.c:3783
 #, gcc-internal-format
 msgid "ALLOCATABLE object %qs of derived type in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3789
+#: fortran/openmp.c:3788
 #, gcc-internal-format
 msgid "ALLOCATABLE object %qs of polymorphic type in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3801 fortran/openmp.c:4480
+#: fortran/openmp.c:3800 fortran/openmp.c:4479
 #, fuzzy, gcc-internal-format
 msgid "POINTER object %qs in %s clause at %L"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: fortran/openmp.c:3806 fortran/openmp.c:4691
+#: fortran/openmp.c:3805 fortran/openmp.c:4690
 #, fuzzy, gcc-internal-format
 msgid "Cray pointer object %qs in %s clause at %L"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: fortran/openmp.c:3811 fortran/openmp.c:4694
+#: fortran/openmp.c:3810 fortran/openmp.c:4693
 #, fuzzy, gcc-internal-format
 msgid "Cray pointee object %qs in %s clause at %L"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: fortran/openmp.c:3816 fortran/openmp.c:4682
+#: fortran/openmp.c:3815 fortran/openmp.c:4681
 #, fuzzy, gcc-internal-format
 msgid "ALLOCATABLE object %qs in %s clause at %L"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: fortran/openmp.c:3819
+#: fortran/openmp.c:3818
 #, fuzzy, gcc-internal-format
 msgid "VALUE object %qs in %s clause at %L"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: fortran/openmp.c:3862
+#: fortran/openmp.c:3861
 #, gcc-internal-format, gfc-internal-format
 msgid "Implicitly declared function %s used in !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:3911
+#: fortran/openmp.c:3910
 #, gcc-internal-format, gfc-internal-format
 msgid "Implicitly declared subroutine %s used in !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:3944
+#: fortran/openmp.c:3943
 #, gcc-internal-format, gfc-internal-format
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:3952 fortran/openmp.c:3963 fortran/resolve.c:10028
-#: fortran/resolve.c:11295
+#: fortran/openmp.c:3951 fortran/openmp.c:3962 fortran/resolve.c:10041
+#: fortran/resolve.c:11315
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/openmp.c:3967
+#: fortran/openmp.c:3966
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause without modifier at %L used together with IF clauses with modifiers"
 msgstr ""
 
-#: fortran/openmp.c:4044
+#: fortran/openmp.c:4043
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause modifier %s at %L not appropriate for the current OpenMP construct"
 msgstr ""
 
-#: fortran/openmp.c:4054
+#: fortran/openmp.c:4053
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/openmp.c:4064
+#: fortran/openmp.c:4063
 #, gcc-internal-format, gfc-internal-format
 msgid "SCHEDULE clause's chunk_size at %L requires a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/openmp.c:4069
+#: fortran/openmp.c:4068
 #, gcc-internal-format, gfc-internal-format
 msgid "INTEGER expression of SCHEDULE clause's chunk_size at %L must be positive"
 msgstr ""
 
-#: fortran/openmp.c:4084
+#: fortran/openmp.c:4083
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs is not a dummy argument at %L"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/openmp.c:4116
+#: fortran/openmp.c:4115 fortran/openmp.c:5998
 #, fuzzy, gcc-internal-format
 msgid "Object %qs is not a variable at %L"
 msgstr "functie-oproep heeft geaggregeerde waarde"
 
-#: fortran/openmp.c:4132 fortran/openmp.c:4143 fortran/openmp.c:4151
-#: fortran/openmp.c:4162 fortran/openmp.c:4174 fortran/openmp.c:4189
-#: fortran/openmp.c:6023
+#: fortran/openmp.c:4131 fortran/openmp.c:4142 fortran/openmp.c:4150
+#: fortran/openmp.c:4161 fortran/openmp.c:4173 fortran/openmp.c:4188
+#: fortran/openmp.c:6028
 #, gcc-internal-format
 msgid "Symbol %qs present on multiple clauses at %L"
 msgstr ""
 
-#: fortran/openmp.c:4196
+#: fortran/openmp.c:4195
 #, gcc-internal-format
 msgid "Array %qs is not permitted in reduction at %L"
 msgstr ""
 
-#: fortran/openmp.c:4209
+#: fortran/openmp.c:4208
 #, gcc-internal-format
 msgid "Symbol %qs present on both FROM and TO clauses at %L"
 msgstr ""
 
-#: fortran/openmp.c:4231
+#: fortran/openmp.c:4230
 #, gcc-internal-format
 msgid "Non-THREADPRIVATE object %qs in COPYIN clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4239
+#: fortran/openmp.c:4238
 #, gcc-internal-format
 msgid "Assumed size array %qs in COPYPRIVATE clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4242
+#: fortran/openmp.c:4241
 #, gcc-internal-format
 msgid "INTENT(IN) POINTER %qs in COPYPRIVATE clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4250
+#: fortran/openmp.c:4249
 #, gcc-internal-format
 msgid "THREADPRIVATE object %qs in SHARED clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4253
+#: fortran/openmp.c:4252
 #, fuzzy, gcc-internal-format
 msgid "Cray pointee %qs in SHARED clause at %L"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: fortran/openmp.c:4256
+#: fortran/openmp.c:4255
 #, fuzzy, gcc-internal-format
 msgid "ASSOCIATE name %qs in SHARED clause at %L"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: fortran/openmp.c:4271
+#: fortran/openmp.c:4270
 #, gcc-internal-format
 msgid "%qs in ALIGNED clause must be POINTER, ALLOCATABLE, Cray pointer or C_PTR at %L"
 msgstr ""
 
-#: fortran/openmp.c:4283
+#: fortran/openmp.c:4282
 #, fuzzy, gcc-internal-format
 msgid "%qs in ALIGNED clause at %L requires a scalar positive constant integer alignment expression"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/openmp.c:4302
+#: fortran/openmp.c:4301
 #, gcc-internal-format, gfc-internal-format
 msgid "SINK dependence type only allowed on ORDERED directive at %L"
 msgstr ""
 
-#: fortran/openmp.c:4306
+#: fortran/openmp.c:4305
 #, gcc-internal-format, gfc-internal-format
 msgid "DEPEND SINK used together with DEPEND SOURCE on the same construct at %L"
 msgstr ""
 
-#: fortran/openmp.c:4316
+#: fortran/openmp.c:4315
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "accumulator is not a constant integer"
 msgid "SINK addend not a constant integer at %L"
 msgstr "accumulator is geen integer-constante"
 
-#: fortran/openmp.c:4322
+#: fortran/openmp.c:4321
 #, gcc-internal-format, gfc-internal-format
 msgid "Only SOURCE or SINK dependence types are allowed on ORDERED directive at %L"
 msgstr ""
 
-#: fortran/openmp.c:4333 fortran/openmp.c:4354
+#: fortran/openmp.c:4332 fortran/openmp.c:4353
 #, gcc-internal-format
 msgid "%qs in %s clause at %L is not a proper array section"
 msgstr ""
 
-#: fortran/openmp.c:4337
+#: fortran/openmp.c:4336
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coarrays not supported in %s clause at %L"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: fortran/openmp.c:4346
+#: fortran/openmp.c:4345
 #, gcc-internal-format, gfc-internal-format
 msgid "Stride should not be specified for array section in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4367
+#: fortran/openmp.c:4366
 #, gcc-internal-format
 msgid "%qs in DEPEND clause at %L is a zero size array section"
 msgstr ""
 
-#: fortran/openmp.c:4403
+#: fortran/openmp.c:4402
 #, gcc-internal-format, gfc-internal-format
 msgid "TARGET%s with map-type other than TO, FROM, TOFROM, or ALLOC on MAP clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4419
+#: fortran/openmp.c:4418
 #, gcc-internal-format, gfc-internal-format
 msgid "TARGET ENTER DATA with map-type other than TO, or ALLOC on MAP clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4434
+#: fortran/openmp.c:4433
 #, gcc-internal-format, gfc-internal-format
 msgid "TARGET EXIT DATA with map-type other than FROM, RELEASE, or DELETE on MAP clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4450 fortran/openmp.c:4466
+#: fortran/openmp.c:4449 fortran/openmp.c:4465
 #, fuzzy, gcc-internal-format
 msgid "THREADPRIVATE object %qs in %s clause at %L"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: fortran/openmp.c:4453 fortran/openmp.c:4469
+#: fortran/openmp.c:4452 fortran/openmp.c:4468
 #, fuzzy, gcc-internal-format
 msgid "Cray pointee %qs in %s clause at %L"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: fortran/openmp.c:4472
+#: fortran/openmp.c:4471
 #, fuzzy, gcc-internal-format
 msgid "ASSOCIATE name %qs in %s clause at %L"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: fortran/openmp.c:4477
+#: fortran/openmp.c:4476
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer %qs in %s clause at %L"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: fortran/openmp.c:4483
+#: fortran/openmp.c:4482
 #, fuzzy, gcc-internal-format
 msgid "Cray pointer %qs in %s clause at %L"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: fortran/openmp.c:4493
+#: fortran/openmp.c:4492
 #, gcc-internal-format
 msgid "Variable %qs in %s clause is used in NAMELIST statement at %L"
 msgstr ""
 
 #. case OMP_LIST_REDUCTION:
-#: fortran/openmp.c:4503
+#: fortran/openmp.c:4502
 #, gcc-internal-format
 msgid "INTENT(IN) POINTER %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4596
+#: fortran/openmp.c:4595
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP DECLARE REDUCTION %s not found for type %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:4622
+#: fortran/openmp.c:4621
 #, gcc-internal-format, gfc-internal-format
 msgid "LINEAR clause modifier used on DO or SIMD construct at %L"
 msgstr ""
 
-#: fortran/openmp.c:4627
+#: fortran/openmp.c:4626
 #, gcc-internal-format, gfc-internal-format
 msgid "LINEAR clause specified together with ORDERED clause with argument at %L"
 msgstr ""
 
-#: fortran/openmp.c:4632
+#: fortran/openmp.c:4631
 #, gcc-internal-format
 msgid "LINEAR variable %qs must be INTEGER at %L"
 msgstr ""
 
-#: fortran/openmp.c:4637
+#: fortran/openmp.c:4636
 #, gcc-internal-format
 msgid "LINEAR dummy argument %qs with VALUE attribute with %s modifier at %L"
 msgstr ""
 
-#: fortran/openmp.c:4648
+#: fortran/openmp.c:4647
 #, gcc-internal-format
 msgid "%qs in LINEAR clause at %L requires a scalar integer linear-step expression"
 msgstr ""
 
-#: fortran/openmp.c:4665
+#: fortran/openmp.c:4664
 #, gcc-internal-format
 msgid "%qs in LINEAR clause at %L requires a constant integer linear-step expression or dummy argument specified in UNIFORM clause"
 msgstr ""
 
-#: fortran/openmp.c:4699
+#: fortran/openmp.c:4698
 #, gcc-internal-format
 msgid "%s clause variable %qs at %L is neither a POINTER nor an array"
 msgstr ""
 
-#: fortran/openmp.c:4731
+#: fortran/openmp.c:4730
 #, gcc-internal-format, gfc-internal-format
 msgid "DIST_SCHEDULE clause's chunk_size at %L requires a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/openmp.c:4763
+#: fortran/openmp.c:4762
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible use of TILE and COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:4765
+#: fortran/openmp.c:4764
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE dependence type only allowed on ORDERED directive at %L"
 msgstr ""
 
-#: fortran/openmp.c:4778
+#: fortran/openmp.c:4777
 #, gcc-internal-format, gfc-internal-format
 msgid "%s must contain at least one MAP clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4875
+#: fortran/openmp.c:4874
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unexpected !$OMP ATOMIC expression at %L"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/openmp.c:4904
+#: fortran/openmp.c:4903
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC statement must set a scalar variable of intrinsic type at %L"
 msgstr ""
 
-#: fortran/openmp.c:4929
+#: fortran/openmp.c:4928
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC READ statement must read from a scalar variable of intrinsic type at %L"
 msgstr ""
 
-#: fortran/openmp.c:4934
+#: fortran/openmp.c:4933
 #, gcc-internal-format, gfc-internal-format
 msgid "expr in !$OMP ATOMIC WRITE assignment var = expr must be scalar and cannot reference var at %L"
 msgstr ""
 
-#: fortran/openmp.c:4956 fortran/openmp.c:5247
+#: fortran/openmp.c:4955 fortran/openmp.c:5246
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE capture statement must read from a scalar variable of intrinsic type at %L"
 msgstr ""
 
-#: fortran/openmp.c:4971
+#: fortran/openmp.c:4970
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE update statement must set a scalar variable of intrinsic type at %L"
 msgstr ""
 
-#: fortran/openmp.c:4978 fortran/openmp.c:5254
+#: fortran/openmp.c:4977 fortran/openmp.c:5253
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE capture statement reads from different variable than update statement writes into at %L"
 msgstr ""
 
-#: fortran/openmp.c:4994
+#: fortran/openmp.c:4993
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC with ALLOCATABLE variable at %L"
 msgstr ""
 
-#: fortran/openmp.c:5036
+#: fortran/openmp.c:5035
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment operator must be binary +, *, -, /, .AND., .OR., .EQV. or .NEQV. at %L"
 msgstr ""
 
-#: fortran/openmp.c:5084
+#: fortran/openmp.c:5083
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment must be var = var op expr or var = expr op var at %L"
 msgstr ""
 
-#: fortran/openmp.c:5098
+#: fortran/openmp.c:5097
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC var = var op expr not mathematically equivalent to var = var op (expr) at %L"
 msgstr ""
 
-#: fortran/openmp.c:5130
+#: fortran/openmp.c:5129
 #, gcc-internal-format, gfc-internal-format
 msgid "expr in !$OMP ATOMIC assignment var = var op expr must be scalar and cannot reference var at %L"
 msgstr ""
 
-#: fortran/openmp.c:5154
+#: fortran/openmp.c:5153
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment intrinsic IAND, IOR or IEOR must have two arguments at %L"
 msgstr ""
 
-#: fortran/openmp.c:5161
+#: fortran/openmp.c:5160
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment intrinsic must be MIN, MAX, IAND, IOR or IEOR at %L"
 msgstr ""
 
-#: fortran/openmp.c:5178
+#: fortran/openmp.c:5177
 #, gcc-internal-format
 msgid "!$OMP ATOMIC intrinsic arguments except one must not reference %qs at %L"
 msgstr ""
 
-#: fortran/openmp.c:5185
+#: fortran/openmp.c:5184
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC intrinsic arguments must be scalar at %L"
 msgstr ""
 
-#: fortran/openmp.c:5193
+#: fortran/openmp.c:5192
 #, gcc-internal-format
 msgid "First or last !$OMP ATOMIC intrinsic argument must be %qs at %L"
 msgstr ""
 
-#: fortran/openmp.c:5211
+#: fortran/openmp.c:5210
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment must have an operator or intrinsic on right hand side at %L"
 msgstr ""
 
-#: fortran/openmp.c:5225
+#: fortran/openmp.c:5224
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE capture statement must set a scalar variable of intrinsic type at %L"
 msgstr ""
 
-#: fortran/openmp.c:5544
+#: fortran/openmp.c:5543
 #, gcc-internal-format, gfc-internal-format
 msgid "%s cannot be a DO WHILE or DO without loop control at %L"
 msgstr ""
 
-#: fortran/openmp.c:5550
+#: fortran/openmp.c:5549
 #, gcc-internal-format, gfc-internal-format
 msgid "%s cannot be a DO CONCURRENT loop at %L"
 msgstr ""
 
-#: fortran/openmp.c:5556
+#: fortran/openmp.c:5555
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable must be of type integer at %L"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: fortran/openmp.c:5560
+#: fortran/openmp.c:5559
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable must not be THREADPRIVATE at %L"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: fortran/openmp.c:5573
+#: fortran/openmp.c:5572
 #, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable present on clause other than PRIVATE or LASTPRIVATE at %L"
 msgstr ""
 
-#: fortran/openmp.c:5577
+#: fortran/openmp.c:5576
 #, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable present on clause other than LASTPRIVATE at %L"
 msgstr ""
 
-#: fortran/openmp.c:5581
+#: fortran/openmp.c:5580
 #, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable present on clause other than LINEAR at %L"
 msgstr ""
 
-#: fortran/openmp.c:5599
+#: fortran/openmp.c:5598
 #, gcc-internal-format, gfc-internal-format
 msgid "%s collapsed loops don't form rectangular iteration space at %L"
 msgstr ""
 
-#: fortran/openmp.c:5611
+#: fortran/openmp.c:5610
 #, gcc-internal-format, gfc-internal-format
 msgid "collapsed %s loops not perfectly nested at %L"
 msgstr ""
 
-#: fortran/openmp.c:5620 fortran/openmp.c:5628
+#: fortran/openmp.c:5619 fortran/openmp.c:5627
 #, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for collapsed %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:5712 fortran/openmp.c:5725
+#: fortran/openmp.c:5711 fortran/openmp.c:5724
 #, gcc-internal-format, gfc-internal-format
 msgid "The %s directive cannot be specified within a %s region at %L"
 msgstr ""
 
-#: fortran/openmp.c:5744
+#: fortran/openmp.c:5743
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP cannot be a DO WHILE or DO without loop control at %L"
 msgstr ""
 
-#: fortran/openmp.c:5750
+#: fortran/openmp.c:5749
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP iteration variable must be of type integer at %L"
 msgstr ""
 
-#: fortran/openmp.c:5766
+#: fortran/openmp.c:5765
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s loops don't form rectangular iteration space at %L"
 msgstr ""
 
-#: fortran/openmp.c:5778
+#: fortran/openmp.c:5777
 #, gcc-internal-format, gfc-internal-format
 msgid "%s !$ACC LOOP loops not perfectly nested at %L"
 msgstr ""
 
-#: fortran/openmp.c:5788 fortran/openmp.c:5797
+#: fortran/openmp.c:5787 fortran/openmp.c:5796
 #, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for %s !$ACC LOOP at %L"
 msgstr ""
 
-#: fortran/openmp.c:5812 fortran/openmp.c:5819
+#: fortran/openmp.c:5811 fortran/openmp.c:5818
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s in PARALLEL region doesn't allow %s arguments at %L"
 msgstr ""
 
-#: fortran/openmp.c:5841
+#: fortran/openmp.c:5840
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside another loop parallelized across gangs at %L"
 msgstr ""
 
-#: fortran/openmp.c:5845 fortran/openmp.c:5849
+#: fortran/openmp.c:5844 fortran/openmp.c:5848
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside loop parallelized across workers at %L"
 msgstr ""
 
-#: fortran/openmp.c:5856
+#: fortran/openmp.c:5855
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across workers at %L"
 msgstr ""
 
-#: fortran/openmp.c:5860
+#: fortran/openmp.c:5859
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across vectors at %L"
 msgstr ""
 
-#: fortran/openmp.c:5866
+#: fortran/openmp.c:5865
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across vectors is not allowed inside another loop parallelized across vectors at %L"
 msgstr ""
 
-#: fortran/openmp.c:5878
+#: fortran/openmp.c:5877
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with INDEPENDENT at %L"
 msgstr ""
 
-#: fortran/openmp.c:5880
+#: fortran/openmp.c:5879
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with GANG at %L"
 msgstr ""
 
-#: fortran/openmp.c:5882
+#: fortran/openmp.c:5881
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with WORKER at %L"
 msgstr ""
 
-#: fortran/openmp.c:5884
+#: fortran/openmp.c:5883
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with VECTOR at %L"
 msgstr ""
 
-#: fortran/openmp.c:5886
+#: fortran/openmp.c:5885
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with AUTO at %L"
 msgstr ""
 
-#: fortran/openmp.c:5891
+#: fortran/openmp.c:5890
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with GANG at %L"
 msgstr ""
 
-#: fortran/openmp.c:5893
+#: fortran/openmp.c:5892
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with WORKER at %L"
 msgstr ""
 
-#: fortran/openmp.c:5895
+#: fortran/openmp.c:5894
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with VECTOR at %L"
 msgstr ""
 
-#: fortran/openmp.c:5899
+#: fortran/openmp.c:5898
 #, gcc-internal-format, gfc-internal-format
 msgid "Tiled loop cannot be parallelized across gangs, workers and vectors at the same time at %L"
 msgstr ""
 
-#: fortran/openmp.c:5934
+#: fortran/openmp.c:5933
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "TILE requires constant expression at %L"
 msgstr "overflow in constante expressie"
 
-#: fortran/openmp.c:5999
+#: fortran/openmp.c:6004
 #, fuzzy, gcc-internal-format
 msgid "PARAMETER object %qs is not allowed at %L"
 msgstr "functie-oproep heeft geaggregeerde waarde"
 
-#: fortran/openmp.c:6006
+#: fortran/openmp.c:6011
 #, gcc-internal-format
 msgid "Array sections: %qs not allowed in !$ACC DECLARE at %L"
 msgstr ""
 
-#: fortran/openmp.c:6133
+#: fortran/openmp.c:6138
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP TARGET UPDATE at %L requires at least one TO or FROM clause"
 msgstr ""
 
-#: fortran/openmp.c:6155
+#: fortran/openmp.c:6160
 #, gcc-internal-format
 msgid "!$OMP DECLARE SIMD should refer to containing procedure %qs at %L"
 msgstr ""
 
-#: fortran/openmp.c:6179
+#: fortran/openmp.c:6184
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_PRIV or OMP_ORIG used in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6187
+#: fortran/openmp.c:6192
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_OUT or OMP_IN used in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6216
+#: fortran/openmp.c:6221
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid operator for !$OMP DECLARE REDUCTION %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:6238
+#: fortran/openmp.c:6243
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER length in !$OMP DECLARE REDUCTION %s not constant at %L"
 msgstr ""
 
-#: fortran/openmp.c:6254
+#: fortran/openmp.c:6259
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6269
+#: fortran/openmp.c:6274
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6279
+#: fortran/openmp.c:6284
 #, gcc-internal-format, gfc-internal-format
 msgid "One of actual subroutine arguments in INITIALIZER clause of !$OMP DECLARE REDUCTION must be OMP_PRIV at %L"
 msgstr ""
 
-#: fortran/openmp.c:6287
+#: fortran/openmp.c:6292
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing INITIALIZER clause for !$OMP DECLARE REDUCTION of derived type without default initializer at %L"
 msgstr ""
@@ -58747,494 +58825,494 @@
 msgid "Unclassifiable statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/parse.c:629
+#: fortran/parse.c:631
 #, gcc-internal-format, gfc-internal-format
 msgid "OpenACC directives at %C may not appear in PURE procedures"
 msgstr ""
 
-#: fortran/parse.c:705
+#: fortran/parse.c:707
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable OpenACC directive at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/parse.c:831 fortran/parse.c:1040
+#: fortran/parse.c:835 fortran/parse.c:1044
 #, gcc-internal-format, gfc-internal-format
 msgid "OpenMP directives other than SIMD or DECLARE TARGET at %C may not appear in PURE or ELEMENTAL procedures"
 msgstr ""
 
-#: fortran/parse.c:1024
+#: fortran/parse.c:1028
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable OpenMP directive at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/parse.c:1076
+#: fortran/parse.c:1080
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable GCC directive at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/parse.c:1135 fortran/parse.c:1362
+#: fortran/parse.c:1139 fortran/parse.c:1366
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Zero is not a valid statement label at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/parse.c:1142 fortran/parse.c:1354
+#: fortran/parse.c:1146 fortran/parse.c:1358
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-numeric character in statement label at %C"
 msgstr ""
 
-#: fortran/parse.c:1154 fortran/parse.c:1403
+#: fortran/parse.c:1158 fortran/parse.c:1407
 #, gcc-internal-format, gfc-internal-format
 msgid "Semicolon at %C needs to be preceded by statement"
 msgstr ""
 
-#: fortran/parse.c:1161 fortran/parse.c:1418
+#: fortran/parse.c:1165 fortran/parse.c:1422
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Statement label without statement at %L"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/parse.c:1224 fortran/parse.c:1405
+#: fortran/parse.c:1228 fortran/parse.c:1409
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Semicolon at %C without preceding statement"
 msgstr "case-selector niet compatibel met label"
 
-#: fortran/parse.c:1247 fortran/parse.c:1381
+#: fortran/parse.c:1251 fortran/parse.c:1385
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad continuation line at %C"
 msgstr ""
 
-#: fortran/parse.c:1679
+#: fortran/parse.c:1683
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT statement at %L does not have a statement label"
 msgstr ""
 
-#: fortran/parse.c:2435
+#: fortran/parse.c:2439
 #, gcc-internal-format
 msgid "gfc_ascii_statement(): Bad statement code"
 msgstr ""
 
-#: fortran/parse.c:2577
+#: fortran/parse.c:2581
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/parse.c:2732
+#: fortran/parse.c:2736
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot follow %s statement at %L"
 msgstr ""
 
-#: fortran/parse.c:2749
+#: fortran/parse.c:2753
 #, fuzzy, gcc-internal-format
 msgid "Unexpected end of file in %qs"
 msgstr "ongeldige operand van %s"
 
-#: fortran/parse.c:2784
+#: fortran/parse.c:2788
 #, gcc-internal-format
 msgid "Derived-type %qs with SEQUENCE must not have a CONTAINS section at %C"
 msgstr ""
 
-#: fortran/parse.c:2787
+#: fortran/parse.c:2791
 #, gcc-internal-format
 msgid "Derived-type %qs with BIND(C) must not have a CONTAINS section at %C"
 msgstr ""
 
-#: fortran/parse.c:2807
+#: fortran/parse.c:2811
 #, gcc-internal-format, gfc-internal-format
 msgid "Components in TYPE at %C must precede CONTAINS"
 msgstr ""
 
-#: fortran/parse.c:2811
+#: fortran/parse.c:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound procedure at %C"
 msgstr ""
 
-#: fortran/parse.c:2819
+#: fortran/parse.c:2823
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC binding at %C"
 msgstr ""
 
-#: fortran/parse.c:2827
+#: fortran/parse.c:2831
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure declaration at %C"
 msgstr "eerdere declaratie van %qs"
 
-#: fortran/parse.c:2839
+#: fortran/parse.c:2843
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type definition at %C with empty CONTAINS section"
 msgstr ""
 
-#: fortran/parse.c:2849 fortran/parse.c:3304
+#: fortran/parse.c:2853 fortran/parse.c:3308
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement in TYPE at %C must be inside a MODULE"
 msgstr ""
 
-#: fortran/parse.c:2856
+#: fortran/parse.c:2860
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede procedure bindings"
 msgstr "overflow in constante expressie"
 
-#: fortran/parse.c:2863 fortran/parse.c:3317
+#: fortran/parse.c:2867 fortran/parse.c:3321
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PRIVATE statement at %C"
 msgstr ""
 
-#: fortran/parse.c:2873
+#: fortran/parse.c:2877
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede CONTAINS"
 msgstr ""
 
-#: fortran/parse.c:2877
+#: fortran/parse.c:2881
 #, gcc-internal-format, gfc-internal-format
 msgid "Already inside a CONTAINS block at %C"
 msgstr ""
 
-#: fortran/parse.c:2996
+#: fortran/parse.c:3000
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s at %L of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray, which is not possible as the component has the pointer attribute"
 msgstr ""
 
-#: fortran/parse.c:3002
+#: fortran/parse.c:3006
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer component %s at %L has a noncoarray subcomponent of type LOCK_TYPE, which must have a codimension or be a subcomponent of a coarray"
 msgstr ""
 
-#: fortran/parse.c:3007
+#: fortran/parse.c:3011
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L of type LOCK_TYPE must have a codimension"
 msgstr ""
 
-#: fortran/parse.c:3011
+#: fortran/parse.c:3015
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L must have a codimension as it has a noncoarray subcomponent of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/parse.c:3016
+#: fortran/parse.c:3020
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as already a coarray subcomponent exists)"
 msgstr ""
 
-#: fortran/parse.c:3023
+#: fortran/parse.c:3027
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as %s at %L has a codimension or a coarray subcomponent)"
 msgstr ""
 
-#: fortran/parse.c:3033
+#: fortran/parse.c:3037
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s at %L of type EVENT_TYPE must have a codimension or be a subcomponent of a coarray, which is not possible as the component has the pointer attribute"
 msgstr ""
 
-#: fortran/parse.c:3039
+#: fortran/parse.c:3043
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer component %s at %L has a noncoarray subcomponent of type EVENT_TYPE, which must have a codimension or be a subcomponent of a coarray"
 msgstr ""
 
-#: fortran/parse.c:3044
+#: fortran/parse.c:3048
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L of type EVENT_TYPE must have a codimension"
 msgstr ""
 
-#: fortran/parse.c:3048
+#: fortran/parse.c:3052
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L must have a codimension as it has a noncoarray subcomponent of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/parse.c:3053
+#: fortran/parse.c:3057
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as already a coarray subcomponent exists)"
 msgstr ""
 
-#: fortran/parse.c:3060
+#: fortran/parse.c:3064
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as %s at %L has a codimension or a coarray subcomponent)"
 msgstr ""
 
-#: fortran/parse.c:3112
+#: fortran/parse.c:3116
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "failed to open %s"
 msgid "failed to create map component '%s'"
 msgstr "kan %s niet openen"
 
-#: fortran/parse.c:3145
+#: fortran/parse.c:3149
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "failed to open %s"
 msgid "failed to create union component '%s'"
 msgstr "kan %s niet openen"
 
-#: fortran/parse.c:3200
+#: fortran/parse.c:3204
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in nested structure declaration at %C"
 msgstr "twee of meer data types in de declaratie van %qs"
 
-#: fortran/parse.c:3287
+#: fortran/parse.c:3291
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside CONTAINS"
 msgstr ""
 
-#: fortran/parse.c:3295
+#: fortran/parse.c:3299
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type definition at %C without components"
 msgstr ""
 
-#: fortran/parse.c:3311
+#: fortran/parse.c:3315
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede structure components"
 msgstr ""
 
-#: fortran/parse.c:3328
+#: fortran/parse.c:3332
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede structure components"
 msgstr ""
 
-#: fortran/parse.c:3334
+#: fortran/parse.c:3338
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE attribute at %C already specified in TYPE statement"
 msgstr ""
 
-#: fortran/parse.c:3339
+#: fortran/parse.c:3343
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SEQUENCE statement at %C"
 msgstr ""
 
-#: fortran/parse.c:3349
+#: fortran/parse.c:3353
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS block in derived type definition at %C"
 msgstr ""
 
-#: fortran/parse.c:3407
+#: fortran/parse.c:3411
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM declaration at %C has no ENUMERATORS"
 msgstr ""
 
-#: fortran/parse.c:3494
+#: fortran/parse.c:3498
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in INTERFACE block at %C"
 msgstr ""
 
-#: fortran/parse.c:3518
+#: fortran/parse.c:3522
 #, gcc-internal-format
 msgid "Name %qs of ABSTRACT INTERFACE at %C cannot be the same as an intrinsic type"
 msgstr ""
 
-#: fortran/parse.c:3552
+#: fortran/parse.c:3556
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement at %C in INTERFACE body"
 msgstr ""
 
-#: fortran/parse.c:3570
+#: fortran/parse.c:3574
 #, fuzzy, gcc-internal-format
 msgid "INTERFACE procedure %qs at %L has the same name as the enclosing procedure"
 msgstr "veld %qs heeft al een beginwaarde gekregen"
 
-#: fortran/parse.c:3700
+#: fortran/parse.c:3704
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/parse.c:3732
+#: fortran/parse.c:3736
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement is not allowed inside of BLOCK DATA at %C"
 msgstr ""
 
-#: fortran/parse.c:3822
+#: fortran/parse.c:3826
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement must appear in a MODULE"
 msgstr ""
 
-#: fortran/parse.c:3830
+#: fortran/parse.c:3834
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C follows another accessibility specification"
 msgstr ""
 
-#: fortran/parse.c:3882
+#: fortran/parse.c:3886
 #, fuzzy, gcc-internal-format
 msgid "Bad kind expression for function %qs at %L"
 msgstr "fout in argumenten voor spec-functie '%s'"
 
-#: fortran/parse.c:3886
+#: fortran/parse.c:3890
 #, fuzzy, gcc-internal-format
 msgid "The type for function %qs at %L is not accessible"
 msgstr "%s: definitie van functie '%s' niet omgezet\n"
 
-#: fortran/parse.c:3946
+#: fortran/parse.c:3950
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C follows previous unmasked ELSEWHERE"
 msgstr ""
 
-#: fortran/parse.c:3968
+#: fortran/parse.c:3972
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in WHERE block at %C"
 msgstr ""
 
-#: fortran/parse.c:4027
+#: fortran/parse.c:4031
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in FORALL block at %C"
 msgstr ""
 
-#: fortran/parse.c:4078
+#: fortran/parse.c:4082
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSE IF statement at %C cannot follow ELSE statement at %L"
 msgstr ""
 
-#: fortran/parse.c:4096
+#: fortran/parse.c:4100
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ELSE statements at %L and %C"
 msgstr ""
 
-#: fortran/parse.c:4157
+#: fortran/parse.c:4161
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected a CASE or END SELECT statement following SELECT CASE at %C"
 msgstr ""
 
-#: fortran/parse.c:4241
+#: fortran/parse.c:4245
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected TYPE IS, CLASS IS or END SELECT statement following SELECT TYPE at %C"
 msgstr ""
 
-#: fortran/parse.c:4303
+#: fortran/parse.c:4307
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %C cannot be redefined inside loop beginning at %L"
 msgstr "overflow in constante expressie"
 
-#: fortran/parse.c:4336
+#: fortran/parse.c:4340
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is within another block"
 msgstr ""
 
-#: fortran/parse.c:4346
+#: fortran/parse.c:4350
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is interwoven with another DO loop"
 msgstr ""
 
-#: fortran/parse.c:4372
+#: fortran/parse.c:4376
 #, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL block inside of OpenACC region at %C"
 msgstr ""
 
-#: fortran/parse.c:4373
+#: fortran/parse.c:4377
 #, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL block inside of OpenMP region at %C"
 msgstr ""
 
-#: fortran/parse.c:4399
+#: fortran/parse.c:4403
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label in END CRITICAL at %C does not match CRITICAL label"
 msgstr ""
 
-#: fortran/parse.c:4468
+#: fortran/parse.c:4472
 #, gcc-internal-format, gfc-internal-format
 msgid "BLOCK construct at %C"
 msgstr ""
 
-#: fortran/parse.c:4502
+#: fortran/parse.c:4506
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSOCIATE construct at %C"
 msgstr ""
 
-#: fortran/parse.c:4690
+#: fortran/parse.c:4694
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label in ENDDO at %C doesn't match DO label"
 msgstr ""
 
-#: fortran/parse.c:4706
+#: fortran/parse.c:4710
 #, gcc-internal-format, gfc-internal-format
 msgid "Named block DO at %L requires matching ENDDO name"
 msgstr ""
 
-#: fortran/parse.c:4897
+#: fortran/parse.c:4901
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing !$OMP END ATOMIC after !$OMP ATOMIC CAPTURE at %C"
 msgstr ""
 
-#: fortran/parse.c:4913 fortran/parse.c:4972
+#: fortran/parse.c:4917 fortran/parse.c:4976
 #, gcc-internal-format, gfc-internal-format
 msgid "OpenACC directive inside of CRITICAL block at %C"
 msgstr ""
 
-#: fortran/parse.c:4947
+#: fortran/parse.c:4951
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/parse.c:4991
+#: fortran/parse.c:4995
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected DO loop at %C"
 msgstr "ongeldige operand van %s"
 
-#: fortran/parse.c:5011
+#: fortran/parse.c:5015
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant !$ACC END LOOP at %C"
 msgstr ""
 
-#: fortran/parse.c:5225
+#: fortran/parse.c:5229
 #, gcc-internal-format, gfc-internal-format
 msgid "Name after !$omp critical and !$omp end critical does not match at %C"
 msgstr ""
 
-#: fortran/parse.c:5283
+#: fortran/parse.c:5287
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot terminate a non-block DO loop"
 msgstr ""
 
-#: fortran/parse.c:5297
+#: fortran/parse.c:5301
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %C after the first executable statement"
 msgstr ""
 
-#: fortran/parse.c:5423
+#: fortran/parse.c:5427
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive does not commence a loop at %C"
 msgstr ""
 
-#: fortran/parse.c:5538
+#: fortran/parse.c:5542
 #, fuzzy, gcc-internal-format
 msgid "Contained procedure %qs at %C is already ambiguous"
 msgstr "veld %qs heeft al een beginwaarde gekregen"
 
-#: fortran/parse.c:5595
+#: fortran/parse.c:5599
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in CONTAINS section at %C"
 msgstr ""
 
-#: fortran/parse.c:5620
+#: fortran/parse.c:5624
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS statement without FUNCTION or SUBROUTINE statement at %L"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/parse.c:5732
+#: fortran/parse.c:5736
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS statement at %C is already in a contained program unit"
 msgstr ""
 
-#: fortran/parse.c:5784
+#: fortran/parse.c:5788
 #, fuzzy, gcc-internal-format
 msgid "Global binding name %qs at %L is already being used as a %s at %L"
 msgstr "veld %qs heeft al een beginwaarde gekregen"
 
-#: fortran/parse.c:5788
+#: fortran/parse.c:5792
 #, fuzzy, gcc-internal-format
 msgid "Global name %qs at %L is already being used as a %s at %L"
 msgstr "veld %qs heeft al een beginwaarde gekregen"
 
-#: fortran/parse.c:5794
+#: fortran/parse.c:5798
 #, fuzzy, gcc-internal-format
 msgid "Global binding name %qs at %L is already being used at %L"
 msgstr "veld %qs heeft al een beginwaarde gekregen"
 
-#: fortran/parse.c:5797
+#: fortran/parse.c:5801
 #, fuzzy, gcc-internal-format
 msgid "Global name %qs at %L is already being used at %L"
 msgstr "veld %qs heeft al een beginwaarde gekregen"
 
-#: fortran/parse.c:5819
+#: fortran/parse.c:5823
 #, gcc-internal-format, gfc-internal-format
 msgid "Blank BLOCK DATA at %C conflicts with prior BLOCK DATA at %L"
 msgstr ""
 
-#: fortran/parse.c:5845
+#: fortran/parse.c:5849
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in BLOCK DATA at %C"
 msgstr ""
 
-#: fortran/parse.c:5949
+#: fortran/parse.c:5953
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in MODULE at %C"
 msgstr ""
@@ -59242,7 +59320,7 @@
 #. If we see a duplicate main program, shut down.  If the second
 #. instance is an implied main program, i.e. data decls or executable
 #. statements, we're in for lots of errors.
-#: fortran/parse.c:6333
+#: fortran/parse.c:6337
 #, gcc-internal-format, gfc-internal-format
 msgid "Two main PROGRAMs at %L and %C"
 msgstr ""
@@ -59989,7 +60067,7 @@
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.c:1893 fortran/resolve.c:9560 fortran/resolve.c:11225
+#: fortran/resolve.c:1893 fortran/resolve.c:9573 fortran/resolve.c:11245
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "naar label %s gerefereerd buiten enige functie"
@@ -60099,7 +60177,7 @@
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:2905 fortran/resolve.c:16283
+#: fortran/resolve.c:2905 fortran/resolve.c:16310
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
@@ -60220,198 +60298,198 @@
 msgid "logical_to_bitwise(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:4059
+#: fortran/resolve.c:4065
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:4229 fortran/resolve.c:4252
+#: fortran/resolve.c:4235 fortran/resolve.c:4258
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:4347
+#: fortran/resolve.c:4353
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/resolve.c:4352
+#: fortran/resolve.c:4358
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/resolve.c:4362
+#: fortran/resolve.c:4368
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/resolve.c:4367
+#: fortran/resolve.c:4373
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/resolve.c:4387
+#: fortran/resolve.c:4393
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr ""
 
-#: fortran/resolve.c:4404
+#: fortran/resolve.c:4410
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/resolve.c:4412
+#: fortran/resolve.c:4418
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/resolve.c:4428
+#: fortran/resolve.c:4434
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/resolve.c:4437
+#: fortran/resolve.c:4443
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/resolve.c:4453
+#: fortran/resolve.c:4459
 #, fuzzy, gcc-internal-format
 #| msgid "subscript missing in array reference"
 msgid "check_dimension(): Bad array reference"
 msgstr "subscript ontbreekt in array-referentie"
 
-#: fortran/resolve.c:4476
+#: fortran/resolve.c:4482
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:4486
+#: fortran/resolve.c:4492
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.c:4494
+#: fortran/resolve.c:4500
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr "subscript ontbreekt in array-referentie"
 
-#: fortran/resolve.c:4510
+#: fortran/resolve.c:4516
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr ""
 
-#: fortran/resolve.c:4538
+#: fortran/resolve.c:4544
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4544
+#: fortran/resolve.c:4550
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: fortran/resolve.c:4550
+#: fortran/resolve.c:4556
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: fortran/resolve.c:4589
+#: fortran/resolve.c:4595
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4596
+#: fortran/resolve.c:4602
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr ""
 
-#: fortran/resolve.c:4641
+#: fortran/resolve.c:4647
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr ""
 
-#: fortran/resolve.c:4652
+#: fortran/resolve.c:4658
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.c:4663
+#: fortran/resolve.c:4669
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.c:4706
+#: fortran/resolve.c:4712
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr ""
 
-#: fortran/resolve.c:4804
+#: fortran/resolve.c:4810
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:4811
+#: fortran/resolve.c:4817
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4820
+#: fortran/resolve.c:4826
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr ""
 
-#: fortran/resolve.c:4833
+#: fortran/resolve.c:4839
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:4840
+#: fortran/resolve.c:4846
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4850
+#: fortran/resolve.c:4856
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr ""
 
-#: fortran/resolve.c:4860
+#: fortran/resolve.c:4866
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr ""
 
-#: fortran/resolve.c:5013
+#: fortran/resolve.c:5019
 #, fuzzy, gcc-internal-format
 msgid "resolve_ref(): Bad array reference"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: fortran/resolve.c:5027
+#: fortran/resolve.c:5033
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:5037
+#: fortran/resolve.c:5043
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:5056
+#: fortran/resolve.c:5062
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:5154
+#: fortran/resolve.c:5160
 #, gcc-internal-format
 msgid "expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.c:5236
+#: fortran/resolve.c:5242
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr ""
 
-#: fortran/resolve.c:5246
+#: fortran/resolve.c:5252
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
@@ -60420,12 +60498,12 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5256
+#: fortran/resolve.c:5262
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5271
+#: fortran/resolve.c:5277
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
@@ -60434,268 +60512,268 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5281
+#: fortran/resolve.c:5287
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5292
+#: fortran/resolve.c:5298
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5301
+#: fortran/resolve.c:5307
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:5316
+#: fortran/resolve.c:5322
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:5478
+#: fortran/resolve.c:5484
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5483
+#: fortran/resolve.c:5489
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5553
+#: fortran/resolve.c:5559
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.c:5566
+#: fortran/resolve.c:5572
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.c:5919
+#: fortran/resolve.c:5925
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/resolve.c:5926
+#: fortran/resolve.c:5932
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5961
+#: fortran/resolve.c:5967
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5970
+#: fortran/resolve.c:5976
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr ""
 
 #. Nothing matching found!
-#: fortran/resolve.c:6158
+#: fortran/resolve.c:6164
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:6185
+#: fortran/resolve.c:6191
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:6236
+#: fortran/resolve.c:6242
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:6786
+#: fortran/resolve.c:6792
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr ""
 
-#: fortran/resolve.c:6812
+#: fortran/resolve.c:6818
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr ""
 
-#: fortran/resolve.c:6822
+#: fortran/resolve.c:6828
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: fortran/resolve.c:6826 fortran/resolve.c:6833
+#: fortran/resolve.c:6832 fortran/resolve.c:6839
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6875
+#: fortran/resolve.c:6881
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:6911
+#: fortran/resolve.c:6917
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.c:6928
+#: fortran/resolve.c:6934
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.c:6934
+#: fortran/resolve.c:6940
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.c:6995
+#: fortran/resolve.c:7001
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7000
+#: fortran/resolve.c:7006
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7007
+#: fortran/resolve.c:7013
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7015
+#: fortran/resolve.c:7021
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr ""
 
-#: fortran/resolve.c:7020
+#: fortran/resolve.c:7026
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:7033
+#: fortran/resolve.c:7039
 #, fuzzy, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "overflow in constante expressie"
 
-#: fortran/resolve.c:7136 fortran/resolve.c:7428
+#: fortran/resolve.c:7142 fortran/resolve.c:7434
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:7144 fortran/resolve.c:7393
+#: fortran/resolve.c:7150 fortran/resolve.c:7399
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7250
+#: fortran/resolve.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7281
+#: fortran/resolve.c:7287
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.c:7439
+#: fortran/resolve.c:7445
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.c:7451
+#: fortran/resolve.c:7457
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.c:7465
+#: fortran/resolve.c:7471
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7480
+#: fortran/resolve.c:7486
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7493
+#: fortran/resolve.c:7499
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.c:7511
+#: fortran/resolve.c:7517
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.c:7592 fortran/resolve.c:7607
+#: fortran/resolve.c:7598 fortran/resolve.c:7613
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7599
+#: fortran/resolve.c:7605
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "%s voor %qs"
 
-#: fortran/resolve.c:7622
+#: fortran/resolve.c:7628
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7649
+#: fortran/resolve.c:7655
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7668
+#: fortran/resolve.c:7674
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.c:7683
+#: fortran/resolve.c:7689
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr "ongeldige expressie als operand"
 
-#: fortran/resolve.c:7694
+#: fortran/resolve.c:7700
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "%s voor %qs"
 
-#: fortran/resolve.c:7726
+#: fortran/resolve.c:7732
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.c:7749
+#: fortran/resolve.c:7755
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:7760
+#: fortran/resolve.c:7766
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.c:7771
-#, gcc-internal-format, gfc-internal-format
-msgid "Errmsg-variable at %L must be a scalar CHARACTER variable"
-msgstr ""
+#: fortran/resolve.c:7782
+#, fuzzy, gcc-internal-format, gfc-internal-format
+msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
+msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.c:7794
+#: fortran/resolve.c:7805
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:7824
+#: fortran/resolve.c:7835
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.c:7830 fortran/resolve.c:7836
+#: fortran/resolve.c:7841 fortran/resolve.c:7847
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -60704,235 +60782,235 @@
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8064
+#: fortran/resolve.c:8075
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr ""
 
 # vertaling voor 'statement'?
-#: fortran/resolve.c:8115
+#: fortran/resolve.c:8126
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "expressie-statement heeft onvolledig type"
 
 # vertaling voor 'statement'?
-#: fortran/resolve.c:8126
+#: fortran/resolve.c:8137
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.c:8139
+#: fortran/resolve.c:8150
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:8185
+#: fortran/resolve.c:8196
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr ""
 
-#: fortran/resolve.c:8204
+#: fortran/resolve.c:8215
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr ""
 
-#: fortran/resolve.c:8214
+#: fortran/resolve.c:8225
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr ""
 
 # vertaling voor 'statement'?
-#: fortran/resolve.c:8232 fortran/resolve.c:8240
+#: fortran/resolve.c:8243 fortran/resolve.c:8251
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.c:8302 fortran/resolve.c:8873
+#: fortran/resolve.c:8313 fortran/resolve.c:8884
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr ""
 
-#: fortran/resolve.c:8328
+#: fortran/resolve.c:8339
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:8340
+#: fortran/resolve.c:8351
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:8355
+#: fortran/resolve.c:8366
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr ""
 
-#: fortran/resolve.c:8458
+#: fortran/resolve.c:8469
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr ""
 
-#: fortran/resolve.c:8518
+#: fortran/resolve.c:8529
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr ""
 
-#: fortran/resolve.c:8523
+#: fortran/resolve.c:8534
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr "%Jparameter %u heeft %<void%> als type"
 
-#: fortran/resolve.c:8545
+#: fortran/resolve.c:8556
 #, fuzzy, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/resolve.c:8556
+#: fortran/resolve.c:8567
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:8763
+#: fortran/resolve.c:8774
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8783 fortran/resolve.c:8795
+#: fortran/resolve.c:8794 fortran/resolve.c:8806
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.c:8824
+#: fortran/resolve.c:8835
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr ""
 
-#: fortran/resolve.c:8836
+#: fortran/resolve.c:8847
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:8848
+#: fortran/resolve.c:8859
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:8851
+#: fortran/resolve.c:8862
 #, fuzzy, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/resolve.c:8861
+#: fortran/resolve.c:8872
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.c:9108
+#: fortran/resolve.c:9119
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9204
+#: fortran/resolve.c:9215
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "Ongeldige soort voor %s op %L"
 
-#: fortran/resolve.c:9257
+#: fortran/resolve.c:9268
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/resolve.c:9267
+#: fortran/resolve.c:9278
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9280
+#: fortran/resolve.c:9291
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9289
+#: fortran/resolve.c:9300
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr ""
 
-#: fortran/resolve.c:9296
+#: fortran/resolve.c:9307
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9307
+#: fortran/resolve.c:9318
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr ""
 
-#: fortran/resolve.c:9313
+#: fortran/resolve.c:9324
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9328
+#: fortran/resolve.c:9339
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:9388
+#: fortran/resolve.c:9399
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:9398
+#: fortran/resolve.c:9409
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.c:9402
+#: fortran/resolve.c:9413
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/resolve.c:9405
+#: fortran/resolve.c:9416
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/resolve.c:9412 fortran/resolve.c:9533
+#: fortran/resolve.c:9423 fortran/resolve.c:9545
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.c:9424 fortran/resolve.c:9540
+#: fortran/resolve.c:9435 fortran/resolve.c:9553
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.c:9436
+#: fortran/resolve.c:9447
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr ""
 
-#: fortran/resolve.c:9449
+#: fortran/resolve.c:9460
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.c:9510
+#: fortran/resolve.c:9521
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:9514 fortran/resolve.c:9524
+#: fortran/resolve.c:9525 fortran/resolve.c:9535
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "%<defined%> zonder een naam"
 
-#: fortran/resolve.c:9567
+#: fortran/resolve.c:9580
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9577
+#: fortran/resolve.c:9590
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr ""
@@ -60939,12 +61017,12 @@
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:9594 fortran/resolve.c:9617
+#: fortran/resolve.c:9607 fortran/resolve.c:9630
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.c:9598 fortran/resolve.c:9623
+#: fortran/resolve.c:9611 fortran/resolve.c:9636
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -60952,107 +61030,107 @@
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:9638
+#: fortran/resolve.c:9651
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9710
+#: fortran/resolve.c:9723
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:9726
+#: fortran/resolve.c:9739
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:9734 fortran/resolve.c:9821
+#: fortran/resolve.c:9747 fortran/resolve.c:9834
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:9744 fortran/resolve.c:9831
+#: fortran/resolve.c:9757 fortran/resolve.c:9844
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:9775
+#: fortran/resolve.c:9788
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "%s van alleen-lezen variabele %qs"
 
-#: fortran/resolve.c:9784
+#: fortran/resolve.c:9797
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr ""
 
-#: fortran/resolve.c:9949
+#: fortran/resolve.c:9962
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.c:9959
+#: fortran/resolve.c:9972
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr ""
 
-#: fortran/resolve.c:10036
+#: fortran/resolve.c:10049
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr ""
 
-#: fortran/resolve.c:10138
+#: fortran/resolve.c:10151
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:10251
+#: fortran/resolve.c:10264
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr ""
 
-#: fortran/resolve.c:10283
+#: fortran/resolve.c:10296
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:10288
+#: fortran/resolve.c:10301
 #, gcc-internal-format, gfc-internal-format
 msgid "The impure variable at %L is assigned to a derived type variable with a POINTER component in a PURE procedure (12.6)"
 msgstr ""
 
-#: fortran/resolve.c:10298
+#: fortran/resolve.c:10311
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "%s van alleen-lezen variabele %qs"
 
-#: fortran/resolve.c:10330
+#: fortran/resolve.c:10343
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:10334
+#: fortran/resolve.c:10347
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "%s van alleen-lezen variabele %qs"
 
-#: fortran/resolve.c:10339
+#: fortran/resolve.c:10352
 #, fuzzy, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr "%s van alleen-lezen variabele %qs"
 
-#: fortran/resolve.c:10346
+#: fortran/resolve.c:10359
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr ""
 
-#: fortran/resolve.c:10357
+#: fortran/resolve.c:10370
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:10663
+#: fortran/resolve.c:10683
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
@@ -61059,69 +61137,69 @@
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:10905
+#: fortran/resolve.c:10925
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr "ongeldig type-argument %qs"
 
-#: fortran/resolve.c:10917
+#: fortran/resolve.c:10937
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: fortran/resolve.c:11157
+#: fortran/resolve.c:11177
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:11160
+#: fortran/resolve.c:11180
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "overflow in constante expressie"
 
-#: fortran/resolve.c:11171
+#: fortran/resolve.c:11191
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr ""
 
-#: fortran/resolve.c:11233
+#: fortran/resolve.c:11253
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr ""
 
 # Ongeldig soort wat?
-#: fortran/resolve.c:11278
+#: fortran/resolve.c:11298
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Invalid NULL at %L"
 msgstr "Ongeldige soort voor %s op %L"
 
-#: fortran/resolve.c:11282
+#: fortran/resolve.c:11302
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:11339
+#: fortran/resolve.c:11359
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:11344
+#: fortran/resolve.c:11364
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:11428
+#: fortran/resolve.c:11448
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:11507
+#: fortran/resolve.c:11527
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr ""
 
-#: fortran/resolve.c:11617
+#: fortran/resolve.c:11637
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
@@ -61128,7 +61206,7 @@
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:11630
+#: fortran/resolve.c:11650
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr ""
@@ -61136,57 +61214,57 @@
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:11647
+#: fortran/resolve.c:11667
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.c:11732
+#: fortran/resolve.c:11752
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "String-lengte bij %L is te groot"
 
-#: fortran/resolve.c:11961
+#: fortran/resolve.c:11981
 #, fuzzy, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:11965
+#: fortran/resolve.c:11985
 #, fuzzy, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: fortran/resolve.c:11973
+#: fortran/resolve.c:11993
 #, fuzzy, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:11983
+#: fortran/resolve.c:12003
 #, fuzzy, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:11998
+#: fortran/resolve.c:12018
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.c:12010
+#: fortran/resolve.c:12030
 #, fuzzy, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:12041
+#: fortran/resolve.c:12061
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.c:12063
+#: fortran/resolve.c:12083
 #, fuzzy, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:12090
+#: fortran/resolve.c:12110
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
@@ -61193,892 +61271,897 @@
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12131
+#: fortran/resolve.c:12151
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr ""
 
-#: fortran/resolve.c:12150
+#: fortran/resolve.c:12170
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr ""
 
-#: fortran/resolve.c:12171
+#: fortran/resolve.c:12191
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:12178
+#: fortran/resolve.c:12198
 #, fuzzy, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:12225
+#: fortran/resolve.c:12245
 #, fuzzy, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:12228
+#: fortran/resolve.c:12248
 #, fuzzy, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:12232
+#: fortran/resolve.c:12252
 #, fuzzy, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:12235
+#: fortran/resolve.c:12255
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:12238
+#: fortran/resolve.c:12258
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:12241
+#: fortran/resolve.c:12261
 #, fuzzy, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:12283
+#: fortran/resolve.c:12303
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s at %L"
 msgstr "%s voor %qs"
 
-#: fortran/resolve.c:12310
+#: fortran/resolve.c:12330
 #, fuzzy, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een array zijn"
 
-#: fortran/resolve.c:12332
+#: fortran/resolve.c:12352
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:12354
+#: fortran/resolve.c:12374
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.c:12372
+#: fortran/resolve.c:12392
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:12381
+#: fortran/resolve.c:12401
 #, fuzzy, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:12389
+#: fortran/resolve.c:12409
 #, fuzzy, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:12399
+#: fortran/resolve.c:12419
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr ""
 
-#: fortran/resolve.c:12418
+#: fortran/resolve.c:12438
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:12422
+#: fortran/resolve.c:12442
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:12426
+#: fortran/resolve.c:12446
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:12430
+#: fortran/resolve.c:12450
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:12443
+#: fortran/resolve.c:12463
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:12452
+#: fortran/resolve.c:12472
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/resolve.c:12458
+#: fortran/resolve.c:12478
 #, fuzzy, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:12470
+#: fortran/resolve.c:12490
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:12527
+#: fortran/resolve.c:12547
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "attribuut %qE botst met attribuut %s"
 
-#: fortran/resolve.c:12533
+#: fortran/resolve.c:12553
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "attribuut %qE botst met attribuut %s"
 
-#: fortran/resolve.c:12539
+#: fortran/resolve.c:12559
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "attribuut %qE botst met attribuut %s"
 
-#: fortran/resolve.c:12547
+#: fortran/resolve.c:12567
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "attribuut %qE botst met attribuut %s"
 
-#: fortran/resolve.c:12553
+#: fortran/resolve.c:12573
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/resolve.c:12596
+#: fortran/resolve.c:12616
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12604
+#: fortran/resolve.c:12624
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12612
+#: fortran/resolve.c:12632
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12621
+#: fortran/resolve.c:12641
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.c:12705
+#: fortran/resolve.c:12725
 #, fuzzy, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/resolve.c:12714
+#: fortran/resolve.c:12734
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:12723
+#: fortran/resolve.c:12743
 #, fuzzy, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/resolve.c:12731
+#: fortran/resolve.c:12751
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/resolve.c:12737
+#: fortran/resolve.c:12757
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:12743
+#: fortran/resolve.c:12763
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr ""
 
-#: fortran/resolve.c:12751
+#: fortran/resolve.c:12771
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:12760
+#: fortran/resolve.c:12780
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:12782
+#: fortran/resolve.c:12802
 #, fuzzy, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "veld %qs heeft al een beginwaarde gekregen"
 
-#: fortran/resolve.c:12819
+#: fortran/resolve.c:12839
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr ""
 
-#: fortran/resolve.c:12859
+#: fortran/resolve.c:12879
 #, gcc-internal-format
 msgid "%qs and %qs can't be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12895
+#: fortran/resolve.c:12915
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.c:12954
+#: fortran/resolve.c:12974
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12966
+#: fortran/resolve.c:12986
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.c:12994
+#: fortran/resolve.c:13014
 #, gcc-internal-format
 msgid "GENERIC %qs at %L can't overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.c:13050
+#: fortran/resolve.c:13070
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L can't be NOPASS"
 msgstr ""
 
-#: fortran/resolve.c:13242
+#: fortran/resolve.c:13262
 #, fuzzy, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/resolve.c:13284
+#: fortran/resolve.c:13304
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/resolve.c:13298
+#: fortran/resolve.c:13318
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:13312 fortran/resolve.c:13778
+#: fortran/resolve.c:13332 fortran/resolve.c:13798
 #, fuzzy, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/resolve.c:13320
+#: fortran/resolve.c:13340
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet kleiner dan rang %d zijn"
 
-#: fortran/resolve.c:13329
+#: fortran/resolve.c:13349
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/resolve.c:13335
+#: fortran/resolve.c:13355
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/resolve.c:13341
+#: fortran/resolve.c:13361
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "Te veel argumenten voor %s op %L"
 
-#: fortran/resolve.c:13370
+#: fortran/resolve.c:13390
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "veld %qs heeft al een beginwaarde gekregen"
 
-#: fortran/resolve.c:13380
+#: fortran/resolve.c:13400
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "veld %qs heeft al een beginwaarde gekregen"
 
-#: fortran/resolve.c:13472
+#: fortran/resolve.c:13492
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.c:13574
+#: fortran/resolve.c:13594
 #, fuzzy, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:13583
+#: fortran/resolve.c:13603
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13593
+#: fortran/resolve.c:13613
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.c:13602
+#: fortran/resolve.c:13622
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.c:13613
+#: fortran/resolve.c:13633
 #, gcc-internal-format
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.c:13711
+#: fortran/resolve.c:13731
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: fortran/resolve.c:13725
+#: fortran/resolve.c:13745
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:13741
+#: fortran/resolve.c:13761
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet kleiner dan rang %d zijn"
 
-#: fortran/resolve.c:13751
+#: fortran/resolve.c:13771
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/resolve.c:13760
+#: fortran/resolve.c:13780
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/resolve.c:13769
+#: fortran/resolve.c:13789
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een scalair zijn"
 
-#: fortran/resolve.c:13811
+#: fortran/resolve.c:13831
 #, fuzzy, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:13824
+#: fortran/resolve.c:13844
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr ""
 
-#: fortran/resolve.c:13835
+#: fortran/resolve.c:13855
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13868
+#: fortran/resolve.c:13888
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:13876
+#: fortran/resolve.c:13896
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.c:13885
+#: fortran/resolve.c:13905
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr ""
 
-#: fortran/resolve.c:13903 fortran/resolve.c:13915
+#: fortran/resolve.c:13923 fortran/resolve.c:13935
 #, fuzzy, gcc-internal-format
 msgid "The pointer component %qs of %qs at %L is a type that has not been declared"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:13989
+#: fortran/resolve.c:14009
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "ongeldige waarheidsexpressie"
 
-#: fortran/resolve.c:14034
+#: fortran/resolve.c:14054
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.c:14047
+#: fortran/resolve.c:14067
 #, fuzzy, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:14111
+#: fortran/resolve.c:14131
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14144
+#: fortran/resolve.c:14164
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.c:14216
+#: fortran/resolve.c:14236
 #, fuzzy, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "Lege array-constructor op %C is niet toegestaan"
 
-#: fortran/resolve.c:14222
+#: fortran/resolve.c:14242
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14228
+#: fortran/resolve.c:14248
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14236
+#: fortran/resolve.c:14256
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14253
+#: fortran/resolve.c:14273
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14275
+#: fortran/resolve.c:14295
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14286
+#: fortran/resolve.c:14306
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14313
+#: fortran/resolve.c:14333
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "attribuut %qE botst met attribuut %s"
 
-#: fortran/resolve.c:14337
+#: fortran/resolve.c:14357
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:14353
+#: fortran/resolve.c:14373
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:14364
+#: fortran/resolve.c:14384
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr ""
 
-#: fortran/resolve.c:14372
+#: fortran/resolve.c:14392
 #, fuzzy, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:14423
+#: fortran/resolve.c:14443
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr ""
 
-#: fortran/resolve.c:14434
+#: fortran/resolve.c:14454
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.c:14441
+#: fortran/resolve.c:14461
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.c:14480
+#: fortran/resolve.c:14500
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:14544
+#: fortran/resolve.c:14564
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:14547
+#: fortran/resolve.c:14567
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:14643
+#: fortran/resolve.c:14663
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:14664
+#: fortran/resolve.c:14684
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr "herhaalde label-declaratie %qs"
 
-#: fortran/resolve.c:14677
+#: fortran/resolve.c:14697
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14680
+#: fortran/resolve.c:14700
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14688
+#: fortran/resolve.c:14708
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:14695
+#: fortran/resolve.c:14715
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:14708
+#: fortran/resolve.c:14728
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr ""
 
-#: fortran/resolve.c:14714
+#: fortran/resolve.c:14734
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14724
+#: fortran/resolve.c:14744
 #, fuzzy, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:14733
+#: fortran/resolve.c:14753
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.c:14746 fortran/resolve.c:14923
+#: fortran/resolve.c:14766 fortran/resolve.c:14943
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.c:14760
+#: fortran/resolve.c:14780
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14769
+#: fortran/resolve.c:14789
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:14778
+#: fortran/resolve.c:14798
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14786
+#: fortran/resolve.c:14806
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:14793
+#: fortran/resolve.c:14813
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:14813
+#: fortran/resolve.c:14833
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "overflow in constante expressie"
 
-#: fortran/resolve.c:14820
+#: fortran/resolve.c:14840
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14827
+#: fortran/resolve.c:14847
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:14834
+#: fortran/resolve.c:14854
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:14860
+#: fortran/resolve.c:14880
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:14870
+#: fortran/resolve.c:14890
 #, fuzzy, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:14949
+#: fortran/resolve.c:14969
 #, fuzzy, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:14964
+#: fortran/resolve.c:14984
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14977
+#: fortran/resolve.c:14997
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14995
+#: fortran/resolve.c:15015
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.c:15007
+#: fortran/resolve.c:15027
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "ongeldig type-argument %qs"
 
-#: fortran/resolve.c:15016
+#: fortran/resolve.c:15036
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:15028
+#: fortran/resolve.c:15048
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:15037
+#: fortran/resolve.c:15057
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15049
+#: fortran/resolve.c:15069
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15065
+#: fortran/resolve.c:15085
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15073
+#: fortran/resolve.c:15093
 #, fuzzy, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:15080
+#: fortran/resolve.c:15100
 #, fuzzy, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:15092
+#: fortran/resolve.c:15112
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:15101
+#: fortran/resolve.c:15121
 #, fuzzy, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "overflow in constante expressie"
 
-#: fortran/resolve.c:15117
+#: fortran/resolve.c:15137
 #, fuzzy, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "overflow in constante expressie"
 
-#: fortran/resolve.c:15123
+#: fortran/resolve.c:15143
 #, fuzzy, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "overflow in constante expressie"
 
-#: fortran/resolve.c:15148
+#: fortran/resolve.c:15168
 #, fuzzy, gcc-internal-format
 msgid "Namelist %qs can not be an argument to subroutine or function at %L"
 msgstr "Bestandsnaam ontbreekt na %qs optie"
 
-#: fortran/resolve.c:15218
+#: fortran/resolve.c:15238
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:15229
+#: fortran/resolve.c:15249
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:15333
+#: fortran/resolve.c:15353
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:15339
+#: fortran/resolve.c:15359
 #, fuzzy, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:15345
+#: fortran/resolve.c:15365
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.c:15354
+#: fortran/resolve.c:15374
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:15368
+#: fortran/resolve.c:15388
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:15414
+#: fortran/resolve.c:15434
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.c:15427
+#: fortran/resolve.c:15447
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.c:15526
+#: fortran/resolve.c:15546
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15534
+#: fortran/resolve.c:15554
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15542
+#: fortran/resolve.c:15562
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15667
+#: fortran/resolve.c:15687
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.c:15832
+#: fortran/resolve.c:15852
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "label %qs gedefinieerd maar niet gebruikt"
 
-#: fortran/resolve.c:15838
+#: fortran/resolve.c:15858
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "label %qs gedefinieerd maar niet gebruikt"
 
-#: fortran/resolve.c:15922
+#: fortran/resolve.c:15942
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15931
+#: fortran/resolve.c:15951
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15939
+#: fortran/resolve.c:15959
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:15955
+#: fortran/resolve.c:15975
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16058
+#: fortran/resolve.c:16078
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:16073
+#: fortran/resolve.c:16093
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:16098
+#: fortran/resolve.c:16118
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:16107
+#: fortran/resolve.c:16127
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16180
+#: fortran/resolve.c:16200
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16191
+#: fortran/resolve.c:16211
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16202
+#: fortran/resolve.c:16222
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "Substring bij %L heeft lengte nul"
 
-#: fortran/resolve.c:16293
+#: fortran/resolve.c:16253
 #, fuzzy, gcc-internal-format
+msgid "Self reference in character length expression for %qs at %L"
+msgstr "overflow in constante expressie"
+
+#: fortran/resolve.c:16320
+#, fuzzy, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:16306
+#: fortran/resolve.c:16333
 #, fuzzy, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:16326
+#: fortran/resolve.c:16353
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:16336
+#: fortran/resolve.c:16363
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:16344
+#: fortran/resolve.c:16371
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:16358
+#: fortran/resolve.c:16385
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:16376
+#: fortran/resolve.c:16403
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:16383
+#: fortran/resolve.c:16410
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:16461
+#: fortran/resolve.c:16488
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -62406,19 +62489,12 @@
 msgid "simplify_min_max(): Bad type in arglist"
 msgstr ""
 
-#. Result is processor-dependent.
-#: fortran/simplify.c:5472
-#, gcc-internal-format, gfc-internal-format
-msgid "Second argument MOD at %L is zero"
-msgstr ""
+#: fortran/simplify.c:5470 fortran/simplify.c:5478
+#, fuzzy, gcc-internal-format
+msgid "Argument %qs of MOD at %L shall not be zero"
+msgstr "ongeldig type-argument %qs"
 
-#. Result is processor-dependent.
-#: fortran/simplify.c:5483
-#, gcc-internal-format, gfc-internal-format
-msgid "Second argument of MOD at %L is zero"
-msgstr ""
-
-#: fortran/simplify.c:5494
+#: fortran/simplify.c:5484
 #, gcc-internal-format
 msgid "gfc_simplify_mod(): Bad arguments"
 msgstr ""
@@ -62426,97 +62502,97 @@
 #. Result is processor-dependent. This processor just opts
 #. to not handle it at all.
 #. Result is processor-dependent.
-#: fortran/simplify.c:5520 fortran/simplify.c:5532
+#: fortran/simplify.c:5525 fortran/simplify.c:5537
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of MODULO at %L is zero"
 msgstr ""
 
-#: fortran/simplify.c:5552
+#: fortran/simplify.c:5557
 #, gcc-internal-format
 msgid "gfc_simplify_modulo(): Bad arguments"
 msgstr ""
 
-#: fortran/simplify.c:5600
+#: fortran/simplify.c:5605
 #, gcc-internal-format, gfc-internal-format
 msgid "Result of NEAREST is NaN at %L"
 msgstr ""
 
-#: fortran/simplify.c:6081
+#: fortran/simplify.c:6086
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative at %L"
 msgstr ""
 
-#: fortran/simplify.c:6137
+#: fortran/simplify.c:6142
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument NCOPIES of REPEAT intrinsic is too large at %L"
 msgstr ""
 
-#: fortran/simplify.c:6174
+#: fortran/simplify.c:6179
 #, gcc-internal-format, gfc-internal-format
 msgid "Evaluation of string longer than 2**28 at %L deferred to runtime, expect bugs"
 msgstr ""
 
-#: fortran/simplify.c:6302
+#: fortran/simplify.c:6307
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Reshaped array too large at %C"
 msgstr "omvang van array %qs is te groot"
 
-#: fortran/simplify.c:6416
+#: fortran/simplify.c:6421
 #, gcc-internal-format, gfc-internal-format
 msgid "Result of SCALE overflows its kind at %L"
 msgstr ""
 
-#: fortran/simplify.c:6995
+#: fortran/simplify.c:7000
 #, fuzzy, gcc-internal-format
 msgid "Bad type in gfc_simplify_sign"
 msgstr "overflow in constante expressie"
 
-#: fortran/simplify.c:7024
+#: fortran/simplify.c:7029
 #, gcc-internal-format
 msgid "in gfc_simplify_sin(): Bad type"
 msgstr ""
 
-#: fortran/simplify.c:7151 fortran/simplify.c:7431
+#: fortran/simplify.c:7156 fortran/simplify.c:7436
 #, gcc-internal-format
 msgid "Failure getting length of a constant array."
 msgstr ""
 
-#: fortran/simplify.c:7161
+#: fortran/simplify.c:7166
 #, gcc-internal-format
 msgid "The number of elements (%d) in the array constructor at %L requires an increase of the allowed %d upper limit.  See %<-fmax-array-constructor%> option."
 msgstr ""
 
-#: fortran/simplify.c:7227
+#: fortran/simplify.c:7232
 #, gcc-internal-format, gfc-internal-format
 msgid "Simplification of SPREAD at %C not yet implemented"
 msgstr ""
 
-#: fortran/simplify.c:7251
+#: fortran/simplify.c:7256
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of SQRT at %L has a negative value"
 msgstr "functie-oproep heeft geaggregeerde waarde"
 
-#: fortran/simplify.c:7267
+#: fortran/simplify.c:7272
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid argument of SQRT at %L"
 msgstr "ongeldig type-argument %qs"
 
-#: fortran/simplify.c:7598
+#: fortran/simplify.c:7603
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY lower bound is %ld)"
 msgstr ""
 
-#: fortran/simplify.c:7621
+#: fortran/simplify.c:7626
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY upper bound is %ld)"
 msgstr ""
 
-#: fortran/simplify.c:7993
+#: fortran/simplify.c:7998
 #, gcc-internal-format
 msgid "gfc_convert_constant(): Unexpected type"
 msgstr ""
 
-#: fortran/simplify.c:8078
+#: fortran/simplify.c:8083
 #, gcc-internal-format
 msgid "Character %qs in string at %L cannot be converted into character kind %d"
 msgstr ""
@@ -62619,7 +62695,7 @@
 msgid "BIND(C) applied to %s %s at %L"
 msgstr ""
 
-#: fortran/symbol.c:901 fortran/symbol.c:912 fortran/symbol.c:1762
+#: fortran/symbol.c:901 fortran/symbol.c:912 fortran/symbol.c:1776
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute conflicts with %s attribute at %L"
 msgstr ""
@@ -62695,18 +62771,24 @@
 msgid "Duplicate VOLATILE attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1367
+#: fortran/symbol.c:1360
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "%qE attribute cannot be specified for local variables"
+msgid "VOLATILE attribute at %L cannot be specified in a PURE procedure"
+msgstr "attribuut %qE kan niet opgegeven worden voor lokale variabelen"
+
+#: fortran/symbol.c:1381
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ASYNCHRONOUS attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1758
+#: fortran/symbol.c:1772
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "%s attribute of %qs conflicts with %s attribute at %L"
 msgstr "attribuut %qE botst met attribuut %s"
 
-#: fortran/symbol.c:1794
+#: fortran/symbol.c:1808
 #, gcc-internal-format, gfc-internal-format
 msgid ""
 "%s procedure at %L is already declared as %s procedure. \n"
@@ -62713,208 +62795,208 @@
 "F2008: A pointer function assignment is ambiguous if it is the first executable statement after the specification block. Please add any other kind of executable statement before it. FIXME"
 msgstr ""
 
-#: fortran/symbol.c:1802
+#: fortran/symbol.c:1816
 #, gcc-internal-format, gfc-internal-format
 msgid "%s procedure at %L is already declared as %s procedure"
 msgstr ""
 
-#: fortran/symbol.c:1837
+#: fortran/symbol.c:1851
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgstr ""
 
-#: fortran/symbol.c:1861
+#: fortran/symbol.c:1875
 #, gcc-internal-format, gfc-internal-format
 msgid "ACCESS specification at %L was already specified"
 msgstr ""
 
-#: fortran/symbol.c:1878
+#: fortran/symbol.c:1892
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate BIND attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1885
+#: fortran/symbol.c:1899
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) at %L"
 msgstr ""
 
-#: fortran/symbol.c:1901
+#: fortran/symbol.c:1915
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate EXTENDS attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1905
+#: fortran/symbol.c:1919
 #, gcc-internal-format, gfc-internal-format
 msgid "EXTENDS at %L"
 msgstr ""
 
-#: fortran/symbol.c:1931
+#: fortran/symbol.c:1945
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L already has an explicit interface"
 msgstr "gevraagd alignment is geen macht van 2"
 
-#: fortran/symbol.c:1938
+#: fortran/symbol.c:1952
 #, gcc-internal-format
 msgid "%qs at %L has attributes specified outside its INTERFACE body"
 msgstr ""
 
-#: fortran/symbol.c:1976
+#: fortran/symbol.c:1990
 #, gcc-internal-format
 msgid "Symbol %qs at %L conflicts with symbol from module %qs, use-associated at %L"
 msgstr ""
 
-#: fortran/symbol.c:1980
+#: fortran/symbol.c:1994
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr "gevraagd alignment is geen macht van 2"
 
-#: fortran/symbol.c:1987
+#: fortran/symbol.c:2001
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/symbol.c:1999
+#: fortran/symbol.c:2013
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L cannot have a type"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/symbol.c:2242
+#: fortran/symbol.c:2256
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %C already in the parent type at %L"
 msgstr "gevraagd alignment is geen macht van 2"
 
-#: fortran/symbol.c:2327
+#: fortran/symbol.c:2341
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C is ambiguous"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/symbol.c:2359
+#: fortran/symbol.c:2373
 #, gcc-internal-format
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr ""
 
-#: fortran/symbol.c:2508
+#: fortran/symbol.c:2522
 #, gcc-internal-format
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr ""
 
-#: fortran/symbol.c:2529
+#: fortran/symbol.c:2543
 #, fuzzy, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure; did you mean %qs?"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: fortran/symbol.c:2533
+#: fortran/symbol.c:2547
 #, fuzzy, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: fortran/symbol.c:2697
+#: fortran/symbol.c:2711
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr "herhaalde case-waarde"
 
-#: fortran/symbol.c:2708
+#: fortran/symbol.c:2722
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr ""
 
-#: fortran/symbol.c:2718
+#: fortran/symbol.c:2732
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr ""
 
-#: fortran/symbol.c:2724
+#: fortran/symbol.c:2738
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:2766
+#: fortran/symbol.c:2780
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr ""
 
-#: fortran/symbol.c:2775
+#: fortran/symbol.c:2789
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr ""
 
-#: fortran/symbol.c:2781
+#: fortran/symbol.c:2795
 #, gcc-internal-format, gfc-internal-format
 msgid "Shared DO termination label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:3110
+#: fortran/symbol.c:3124
 #, gcc-internal-format
 msgid "new_symbol(): Symbol name too long"
 msgstr ""
 
-#: fortran/symbol.c:3135
+#: fortran/symbol.c:3149
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr ""
 
-#: fortran/symbol.c:3138
+#: fortran/symbol.c:3152
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
 msgstr ""
 
 #. Symbol is from another namespace.
-#: fortran/symbol.c:3381
+#: fortran/symbol.c:3395
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C has already been host associated"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/symbol.c:4397
+#: fortran/symbol.c:4411
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr ""
 
-#: fortran/symbol.c:4410
+#: fortran/symbol.c:4424
 #, gcc-internal-format
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr ""
 
-#: fortran/symbol.c:4428
+#: fortran/symbol.c:4442
 #, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr ""
 
-#: fortran/symbol.c:4449
+#: fortran/symbol.c:4463
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:4459
+#: fortran/symbol.c:4473
 #, gcc-internal-format
 msgid "Procedure pointer component %qs at %L cannot be a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:4470
+#: fortran/symbol.c:4484
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:4509
+#: fortran/symbol.c:4523
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.c:4519
+#: fortran/symbol.c:4533
 #, fuzzy, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/symbol.c:4533
+#: fortran/symbol.c:4547
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot be declared with both PRIVATE and BIND(C) attributes"
 msgstr ""
 
-#: fortran/symbol.c:4541
+#: fortran/symbol.c:4555
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.c:5018 fortran/symbol.c:5023
+#: fortran/symbol.c:5032 fortran/symbol.c:5037
 #, gcc-internal-format
 msgid "Symbol %qs is used before it is typed at %L"
 msgstr ""
@@ -62961,7 +63043,7 @@
 msgid "Creating array temporary at %L for argument %qs"
 msgstr "doorgeven van argument %d van %qs"
 
-#: fortran/trans-array.c:10693
+#: fortran/trans-array.c:10724
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr ""
@@ -63165,12 +63247,12 @@
 msgid "%<dim%> argument of %s intrinsic at %L is not a valid dimension index"
 msgstr "'%s' argument voor intrinsic '%s' op %L moet een constante zijn"
 
-#: fortran/trans-intrinsic.c:10572 fortran/trans-stmt.c:1050
+#: fortran/trans-intrinsic.c:10574 fortran/trans-stmt.c:1050
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, the event component of derived type at %L is not yet supported"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:10579
+#: fortran/trans-intrinsic.c:10581
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The event variable at %L shall not be coindexed"
 msgstr "ongeldig type-argument %qs"
@@ -63210,7 +63292,7 @@
 msgid "Sorry, only support for integer kind %d implemented for image-set at %L"
 msgstr ""
 
-#: fortran/trans-stmt.c:3346
+#: fortran/trans-stmt.c:3343
 #, gcc-internal-format
 msgid "gfc_trans_select(): Bad type for case expr."
 msgstr ""
@@ -63339,7 +63421,7 @@
 msgid "two or more sections for %s"
 msgstr "twee of meer data types in de declaratie van %qs"
 
-#: lto/lto-partition.c:516
+#: lto/lto-partition.c:570
 #, gcc-internal-format
 msgid "min partition size cannot be greater than max partition size"
 msgstr ""
@@ -63474,57 +63556,57 @@
 msgid "Cannot read %s"
 msgstr "open %s"
 
-#: lto/lto.c:2369
+#: lto/lto.c:2337
 #, gcc-internal-format
 msgid "lto_obj_file_open() failed"
 msgstr ""
 
-#: lto/lto.c:2394
+#: lto/lto.c:2362
 #, fuzzy, gcc-internal-format
 msgid "waitpid failed"
 msgstr "pex_init mislukt"
 
-#: lto/lto.c:2397
+#: lto/lto.c:2365
 #, fuzzy, gcc-internal-format
 msgid "streaming subprocess failed"
 msgstr "kan bestand '%s' niet openen"
 
-#: lto/lto.c:2400
+#: lto/lto.c:2368
 #, gcc-internal-format
 msgid "streaming subprocess was killed by signal"
 msgstr ""
 
-#: lto/lto.c:2476
+#: lto/lto.c:2445
 #, gcc-internal-format
 msgid "no LTRANS output list filename provided"
 msgstr ""
 
-#: lto/lto.c:2564
+#: lto/lto.c:2525
 #, fuzzy, gcc-internal-format
 msgid "opening LTRANS output list %s: %m"
 msgstr "kan bestand '%s' niet openen"
 
-#: lto/lto.c:2570
+#: lto/lto.c:2532
 #, fuzzy, gcc-internal-format
 msgid "writing to LTRANS output list %s: %m"
 msgstr "kan bestand '%s' niet openen"
 
-#: lto/lto.c:2581
+#: lto/lto.c:2542
 #, fuzzy, gcc-internal-format
 msgid "closing LTRANS output list %s: %m"
 msgstr "kan bestand '%s' niet openen"
 
-#: lto/lto.c:2833
+#: lto/lto.c:2794
 #, fuzzy, gcc-internal-format
 msgid "could not open symbol resolution file: %m"
 msgstr "kan antwoordbestand %s niet openen"
 
-#: lto/lto.c:2954
+#: lto/lto.c:2915
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing resolution data for %s"
 msgstr "accolades ontbreken rond beginwaarde"
 
-#: lto/lto.c:2986
+#: lto/lto.c:2947
 #, gcc-internal-format
 msgid "errors during merging of translation units"
 msgstr ""
Index: gcc/po/ChangeLog
===================================================================
--- gcc/po/ChangeLog	(.../tags/gcc_8_2_0_release)
+++ gcc/po/ChangeLog	(.../branches/gcc-8-branch)
@@ -1,3 +1,17 @@
+2018-10-01  Joseph Myers  <joseph@codesourcery.com>
+
+	* ru.po: Update.
+
+2018-07-30  Joseph Myers  <joseph@codesourcery.com>
+
+	* de.po, sv.po: Update.
+
+2018-07-27  Joseph Myers  <joseph@codesourcery.com>
+
+	* be.po, da.po, de.po, el.po, es.po, fi.po, fr.po, hr.po, id.po,
+	ja.po, nl.po, ru.po, sr.po, sv.po, tr.po, uk.po, vi.po, zh_CN.po,
+	zh_TW.po: Update.
+
 2018-07-26  Release Manager
 
 	* GCC 8.2.0 released.
Index: gcc/po/vi.po
===================================================================
--- gcc/po/vi.po	(.../tags/gcc_8_2_0_release)
+++ gcc/po/vi.po	(.../branches/gcc-8-branch)
@@ -9,7 +9,7 @@
 msgstr ""
 "Project-Id-Version: gcc 7.1-b20170101\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2018-05-01 20:30+0000\n"
+"POT-Creation-Date: 2018-07-25 14:25+0000\n"
 "PO-Revision-Date: 2017-01-08 08:33+0700\n"
 "Last-Translator: Trần Ngọc Quân <vnwildman@gmail.com>\n"
 "Language-Team: Vietnamese <translation-team-vi@lists.sourceforge.net>\n"
@@ -43,35 +43,35 @@
 msgid "[cannot find %s]"
 msgstr "[không tìm thấy %s]"
 
-#: collect2.c:1557
+#: collect2.c:1585
 #, c-format
 msgid "collect2 version %s\n"
 msgstr "collect2 phiên bản %s\n"
 
-#: collect2.c:1664
+#: collect2.c:1692
 #, c-format
 msgid "%d constructor found\n"
 msgid_plural "%d constructors found\n"
 msgstr[0] "Tìm thấy %d bộ cấu trúc\n"
 
-#: collect2.c:1668
+#: collect2.c:1696
 #, c-format
 msgid "%d destructor found\n"
 msgid_plural "%d destructors found\n"
 msgstr[0] "Tìm thấy %d bộ hủy cấu trúc\n"
 
-#: collect2.c:1672
+#: collect2.c:1700
 #, c-format
 msgid "%d frame table found\n"
 msgid_plural "%d frame tables found\n"
 msgstr[0] "Tìm thấy %d bảng khung\n"
 
-#: collect2.c:1836
+#: collect2.c:1864
 #, c-format
 msgid "[Leaving %s]\n"
 msgstr "[Đang rời khỏi %s]\n"
 
-#: collect2.c:2068
+#: collect2.c:2094
 #, c-format
 msgid ""
 "\n"
@@ -80,7 +80,7 @@
 "\n"
 "write_c_file - tên kết xuất là %s, tiền tố là %s\n"
 
-#: collect2.c:2584
+#: collect2.c:2610
 #, c-format
 msgid ""
 "\n"
@@ -103,7 +103,7 @@
 msgid "%s: some warnings being treated as errors"
 msgstr "%s: xử lý một số các cảnh báo như là các lỗi"
 
-#: diagnostic.c:324 input.c:222 input.c:1834 c-family/c-opts.c:1377
+#: diagnostic.c:324 input.c:222 input.c:1834 c-family/c-opts.c:1392
 #: fortran/cpp.c:576 fortran/error.c:1008 fortran/error.c:1028
 msgid "<built-in>"
 msgstr "<có-sẵn>"
@@ -195,13 +195,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:4164 config/arc/arc.c:5784 config/i386/i386.c:17302
+#: final.c:4164 config/arc/arc.c:5775 config/i386/i386.c:17305
 #: config/pdp11/pdp11.c:1715
 #, c-format
 msgid "floating constant misused"
 msgstr "sai sử dụng hằng số dấu chấm động"
 
-#: final.c:4222 config/arc/arc.c:5881 config/i386/i386.c:17393
+#: final.c:4222 config/arc/arc.c:5872 config/i386/i386.c:17396
 #: config/pdp11/pdp11.c:1756
 #, c-format
 msgid "invalid expression as operand"
@@ -1143,7 +1143,7 @@
 msgid "GCSE disabled"
 msgstr "GCSE bị tắt"
 
-#: gimple-ssa-isolate-paths.c:542 c/c-typeck.c:10240
+#: gimple-ssa-isolate-paths.c:542 c/c-typeck.c:10245
 #, gcc-internal-format
 msgid "function returns address of local variable"
 msgstr "hàm trả về địa chỉ của biến cục bộ"
@@ -1445,7 +1445,7 @@
 msgid "options enabled: "
 msgstr "tùy chọn đã bật: "
 
-#: tree-diagnostic.c:299 c/c-decl.c:5419 c/c-typeck.c:7259 cp/error.c:1042
+#: tree-diagnostic.c:299 c/c-decl.c:5439 c/c-typeck.c:7264 cp/error.c:1042
 #: c-family/c-pretty-print.c:413
 #, gcc-internal-format
 msgid "<anonymous>"
@@ -2909,67 +2909,67 @@
 msgstr "đồ sửa đổi chiều dài theo định dạng strfmon"
 
 #. Handle deferred options from command-line.
-#: c-family/c-opts.c:1402 fortran/cpp.c:590
+#: c-family/c-opts.c:1417 fortran/cpp.c:590
 msgid "<command-line>"
 msgstr "<dòng lệnh>"
 
-#: config/aarch64/aarch64.c:6613
+#: config/aarch64/aarch64.c:6629
 #, fuzzy, c-format
 #| msgid "Unsupported operand for code '%c'"
 msgid "unsupported operand for code '%c'"
 msgstr "Không hỗ trợ toán hạng cho mã “%c”"
 
-#: config/aarch64/aarch64.c:6624 config/aarch64/aarch64.c:6640
-#: config/aarch64/aarch64.c:6652 config/aarch64/aarch64.c:6663
-#: config/aarch64/aarch64.c:6673 config/aarch64/aarch64.c:6694
-#: config/aarch64/aarch64.c:6764 config/aarch64/aarch64.c:6775
-#: config/aarch64/aarch64.c:6789 config/aarch64/aarch64.c:7011
-#: config/aarch64/aarch64.c:7029
+#: config/aarch64/aarch64.c:6640 config/aarch64/aarch64.c:6656
+#: config/aarch64/aarch64.c:6668 config/aarch64/aarch64.c:6679
+#: config/aarch64/aarch64.c:6689 config/aarch64/aarch64.c:6710
+#: config/aarch64/aarch64.c:6780 config/aarch64/aarch64.c:6791
+#: config/aarch64/aarch64.c:6805 config/aarch64/aarch64.c:7027
+#: config/aarch64/aarch64.c:7045
 #, c-format
 msgid "invalid operand for '%%%c'"
 msgstr "toán hạng không hợp lệ đối với “%%%c”"
 
-#: config/aarch64/aarch64.c:6709 config/aarch64/aarch64.c:6720
-#: config/aarch64/aarch64.c:6871 config/aarch64/aarch64.c:6882
+#: config/aarch64/aarch64.c:6725 config/aarch64/aarch64.c:6736
+#: config/aarch64/aarch64.c:6887 config/aarch64/aarch64.c:6898
 #, fuzzy, c-format
 #| msgid "invalid constant"
 msgid "invalid vector constant"
 msgstr "hằng không hợp lệ"
 
-#: config/aarch64/aarch64.c:6732 config/aarch64/aarch64.c:6744
-#: config/aarch64/aarch64.c:6755
+#: config/aarch64/aarch64.c:6748 config/aarch64/aarch64.c:6760
+#: config/aarch64/aarch64.c:6771
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr "toán hạn dấu chấm động / thanh ghi véctơ không tương thích cho “%%%c”"
 
-#: config/aarch64/aarch64.c:6823 config/arm/arm.c:22704
+#: config/aarch64/aarch64.c:6839 config/arm/arm.c:22704
 #, c-format
 msgid "missing operand"
 msgstr "toán hạng còn thiếu"
 
-#: config/aarch64/aarch64.c:6908
+#: config/aarch64/aarch64.c:6924
 #, c-format
 msgid "invalid constant"
 msgstr "hằng không hợp lệ"
 
-#: config/aarch64/aarch64.c:6911
+#: config/aarch64/aarch64.c:6927
 #, c-format
 msgid "invalid operand"
 msgstr "toán hạng không hợp lệ"
 
-#: config/aarch64/aarch64.c:7040 config/aarch64/aarch64.c:7045
+#: config/aarch64/aarch64.c:7056 config/aarch64/aarch64.c:7061
 #, c-format
 msgid "invalid operand prefix '%%%c'"
 msgstr "tiền tố toán hạng không hợp lệ “%%%c”"
 
-#: config/aarch64/aarch64.c:7062
+#: config/aarch64/aarch64.c:7078
 #, fuzzy, c-format
 #| msgid "invalid addressing mode"
 msgid "invalid address mode"
 msgstr "sai đặt chế độ đặt địa chỉ"
 
-#: config/alpha/alpha.c:5125 config/i386/i386.c:18558
-#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21798
+#: config/alpha/alpha.c:5125 config/i386/i386.c:18561
+#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21875
 #: config/sparc/sparc.c:9290
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
@@ -2986,7 +2986,7 @@
 msgstr "giá trị %%r sai"
 
 #: config/alpha/alpha.c:5223 config/ia64/ia64.c:5534
-#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21506
+#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21583
 #: config/xtensa/xtensa.c:2429
 #, c-format
 msgid "invalid %%R value"
@@ -2993,13 +2993,13 @@
 msgstr "giá trị %%R sai"
 
 #: config/alpha/alpha.c:5229 config/powerpcspe/powerpcspe.c:23933
-#: config/rs6000/rs6000.c:21426 config/xtensa/xtensa.c:2396
+#: config/rs6000/rs6000.c:21503 config/xtensa/xtensa.c:2396
 #, c-format
 msgid "invalid %%N value"
 msgstr "giá trị %%N sai"
 
 #: config/alpha/alpha.c:5237 config/powerpcspe/powerpcspe.c:23961
-#: config/rs6000/rs6000.c:21454
+#: config/rs6000/rs6000.c:21531
 #, c-format
 msgid "invalid %%P value"
 msgstr "giá trị %%P sai"
@@ -3030,7 +3030,7 @@
 msgstr "giá trị %%U sai"
 
 #: config/alpha/alpha.c:5323 config/powerpcspe/powerpcspe.c:24021
-#: config/rs6000/rs6000.c:21514
+#: config/rs6000/rs6000.c:21591
 #, c-format
 msgid "invalid %%s value"
 msgstr "giá trị %%s sai"
@@ -3041,7 +3041,7 @@
 msgstr "giá trị %%C sai"
 
 #: config/alpha/alpha.c:5371 config/powerpcspe/powerpcspe.c:23797
-#: config/rs6000/rs6000.c:21290
+#: config/rs6000/rs6000.c:21367
 #, c-format
 msgid "invalid %%E value"
 msgstr "giá trị %%E sai"
@@ -3052,7 +3052,7 @@
 msgstr "không rõ bỏ ghi rõ bố trí lại"
 
 #: config/alpha/alpha.c:5405 config/cr16/cr16.c:1569
-#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21803
+#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21880
 #: config/spu/spu.c:1458
 #, c-format
 msgid "invalid %%xn code"
@@ -3063,58 +3063,58 @@
 msgid "invalid operand address"
 msgstr "địa chỉ toán hạng không hợp lệ"
 
-#: config/arc/arc.c:3810
+#: config/arc/arc.c:3808
 #, c-format
 msgid "invalid operand to %%Z code"
 msgstr "toán hạng không hợp lệ cho mã %%Z"
 
-#: config/arc/arc.c:3818
+#: config/arc/arc.c:3816
 #, c-format
 msgid "invalid operand to %%z code"
 msgstr "toán hạng không hợp lệ cho mã %%z"
 
-#: config/arc/arc.c:3826
+#: config/arc/arc.c:3824
 #, fuzzy, c-format
 #| msgid "invalid operand to %%Z code"
 msgid "invalid operands to %%c code"
 msgstr "toán hạng không hợp lệ cho mã %%Z"
 
-#: config/arc/arc.c:3834
+#: config/arc/arc.c:3832
 #, c-format
 msgid "invalid operand to %%M code"
 msgstr "toán hạng không hợp lệ cho mã %%M"
 
-#: config/arc/arc.c:3842 config/m32r/m32r.c:2100
+#: config/arc/arc.c:3840 config/m32r/m32r.c:2100
 #, c-format
 msgid "invalid operand to %%p code"
 msgstr "sai đặt toán hạng tới mã %%p"
 
-#: config/arc/arc.c:3853 config/m32r/m32r.c:2093
+#: config/arc/arc.c:3851 config/m32r/m32r.c:2093
 #, c-format
 msgid "invalid operand to %%s code"
 msgstr "sai đặt toán hạng tới mã %%s"
 
-#: config/arc/arc.c:4001 config/m32r/m32r.c:2126
+#: config/arc/arc.c:3999 config/m32r/m32r.c:2126
 #, c-format
 msgid "invalid operand to %%R code"
 msgstr "sai đặt toán hạng tới mã %%R"
 
-#: config/arc/arc.c:4077 config/m32r/m32r.c:2149
+#: config/arc/arc.c:4075 config/m32r/m32r.c:2149
 #, c-format
 msgid "invalid operand to %%H/%%L code"
 msgstr "sai đặt toán hạng tới mã %%H/%%L"
 
-#: config/arc/arc.c:4145 config/m32r/m32r.c:2220
+#: config/arc/arc.c:4143 config/m32r/m32r.c:2220
 #, c-format
 msgid "invalid operand to %%U code"
 msgstr "sai đặt toán hạng tới mã %%U"
 
-#: config/arc/arc.c:4157
+#: config/arc/arc.c:4155
 #, c-format
 msgid "invalid operand to %%V code"
 msgstr "toán hạng không hợp lệ cho mã %%V"
 
-#: config/arc/arc.c:4214
+#: config/arc/arc.c:4212
 #, c-format
 msgid "invalid operand to %%O code"
 msgstr "toán hạng không hợp lệ cho mã %%O"
@@ -3121,18 +3121,18 @@
 
 #. Unknown flag.
 #. Undocumented flag.
-#: config/arc/arc.c:4240 config/epiphany/epiphany.c:1305
-#: config/m32r/m32r.c:2247 config/nds32/nds32.c:3079 config/sparc/sparc.c:9569
+#: config/arc/arc.c:4238 config/epiphany/epiphany.c:1305
+#: config/m32r/m32r.c:2247 config/nds32/nds32.c:3080 config/sparc/sparc.c:9569
 #, c-format
 msgid "invalid operand output code"
 msgstr "sai đặt mã kết xuất toán hạng"
 
-#: config/arc/arc.c:5869
+#: config/arc/arc.c:5860
 #, c-format
 msgid "invalid UNSPEC as operand: %d"
 msgstr "UNSPEC không hợp lệ như là toán hạng: %d"
 
-#: config/arc/arc.c:6158 config/cris/cris.c:2568
+#: config/arc/arc.c:6149 config/cris/cris.c:2568
 msgid "unrecognized supposed constant"
 msgstr "không nhận ra điều nên là hằng số"
 
@@ -3167,7 +3167,7 @@
 #: config/arm/arm.c:22685 config/arm/arm.c:22692 config/bfin/bfin.c:1441
 #: config/bfin/bfin.c:1448 config/bfin/bfin.c:1455 config/bfin/bfin.c:1462
 #: config/bfin/bfin.c:1471 config/bfin/bfin.c:1478 config/bfin/bfin.c:1485
-#: config/bfin/bfin.c:1492 config/nds32/nds32.c:3098
+#: config/bfin/bfin.c:1492 config/nds32/nds32.c:3099
 #, c-format
 msgid "invalid operand for code '%c'"
 msgstr "sai đặt toán hạng cho mã “%c”"
@@ -3516,103 +3516,103 @@
 msgid "bad output_condmove_single operand"
 msgstr "đặt sai toán hạng output_condmove_single"
 
-#: config/i386/i386.c:17387
+#: config/i386/i386.c:17390
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "đặt sai UNSPEC như là toán hạng"
 
-#: config/i386/i386.c:17925
+#: config/i386/i386.c:17928
 #, fuzzy, c-format
 #| msgid "invalid use of %<restrict%>"
 msgid "invalid use of register '%s'"
 msgstr "dùng %<restrict%> không hợp lệ"
 
-#: config/i386/i386.c:17930
+#: config/i386/i386.c:17933
 #, c-format
 msgid "invalid use of asm flag output"
 msgstr "sử dụng kết xuất cờ asm sai"
 
-#: config/i386/i386.c:18160
+#: config/i386/i386.c:18163
 #, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr "sai kích cỡ toán hạng cho mã toán hạng “O”"
 
-#: config/i386/i386.c:18195
+#: config/i386/i386.c:18198
 #, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr "sai kích cỡ toán hạng cho mã toán hạng “z”"
 
-#: config/i386/i386.c:18264
+#: config/i386/i386.c:18267
 #, c-format
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "sử dụng loại toán hạng không hợp lệ với mã toán hạng “Z”"
 
-#: config/i386/i386.c:18269
+#: config/i386/i386.c:18272
 #, c-format
 msgid "invalid operand size for operand code 'Z'"
 msgstr "sai kích cỡ toán hạng cho mã toán hạng “Z”"
 
-#: config/i386/i386.c:18346
+#: config/i386/i386.c:18349
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "toán hạng không phải là một mã điều kiện, mã toán hạng sai “Y”"
 
-#: config/i386/i386.c:18425
+#: config/i386/i386.c:18428
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "toán hạng không phải là một mã điều kiện, mã toán hạng sai “D”"
 
-#: config/i386/i386.c:18443
+#: config/i386/i386.c:18446
 #, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "toán hạng không phải là một mã điều kiện, mã toán hạng không hợp lệ “%c”"
 
-#: config/i386/i386.c:18456
+#: config/i386/i386.c:18459
 #, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr ""
 
-#: config/i386/i386.c:18471
+#: config/i386/i386.c:18474
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'Y'"
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr "toán hạng không phải là một mã điều kiện, mã toán hạng sai “Y”"
 
-#: config/i386/i386.c:18499
+#: config/i386/i386.c:18502
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'Y'"
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr "toán hạng không phải là một mã điều kiện, mã toán hạng sai “Y”"
 
-#: config/i386/i386.c:18517
+#: config/i386/i386.c:18520
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'Y'"
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr "toán hạng không phải là một mã điều kiện, mã toán hạng sai “Y”"
 
-#: config/i386/i386.c:18540
+#: config/i386/i386.c:18543
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'Y'"
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "toán hạng không phải là một mã điều kiện, mã toán hạng sai “Y”"
 
-#: config/i386/i386.c:18626
+#: config/i386/i386.c:18629
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "mã toán hạng sai “%c”"
 
-#: config/i386/i386.c:18688
+#: config/i386/i386.c:18691
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "sai đặt ràng buộc cho toán hạng"
 
-#: config/i386/i386.c:18738
+#: config/i386/i386.c:18741
 #, fuzzy, c-format
 #| msgid "invalid zero extract"
 msgid "invalid vector immediate"
 msgstr "trích số không không hợp lệ"
 
-#: config/i386/i386.c:29572
+#: config/i386/i386.c:29575
 msgid "unknown insn mode"
 msgstr "không rõ chế độ lệnh"
 
@@ -3650,7 +3650,7 @@
 msgstr "gặp toán hạng %%P sai"
 
 #: config/iq2000/iq2000.c:3185 config/powerpcspe/powerpcspe.c:23951
-#: config/rs6000/rs6000.c:21444
+#: config/rs6000/rs6000.c:21521
 #, c-format
 msgid "invalid %%p value"
 msgstr "gặp giá trị %%p sai"
@@ -3704,7 +3704,7 @@
 msgstr "địa chỉ hậu gia không phải là một thanh ghi"
 
 #: config/m32r/m32r.c:2350 config/m32r/m32r.c:2365
-#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33292
+#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33348
 msgid "bad address"
 msgstr "địa chỉ sai"
 
@@ -3823,185 +3823,185 @@
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr "Hãy thử chạy “%s” trong trình bao để tăng giới hạn.\n"
 
-#: config/powerpcspe/powerpcspe.c:4411 config/rs6000/rs6000.c:4258
+#: config/powerpcspe/powerpcspe.c:4411 config/rs6000/rs6000.c:4278
 msgid "-maltivec=le not allowed for big-endian targets"
 msgstr "-maltivec=le không cho phép trên đích big-endian"
 
-#: config/powerpcspe/powerpcspe.c:4423 config/rs6000/rs6000.c:4273
+#: config/powerpcspe/powerpcspe.c:4423 config/rs6000/rs6000.c:4293
 msgid "-mvsx requires hardware floating point"
 msgstr "-mvsx yêu cầu dấu chấm động loại phần cứng"
 
-#: config/powerpcspe/powerpcspe.c:4431 config/rs6000/rs6000.c:4281
+#: config/powerpcspe/powerpcspe.c:4431 config/rs6000/rs6000.c:4301
 msgid "-mvsx and -mpaired are incompatible"
 msgstr "-mvsx và -mpaired không tương thích với nhau"
 
-#: config/powerpcspe/powerpcspe.c:4433 config/rs6000/rs6000.c:4283
+#: config/powerpcspe/powerpcspe.c:4433 config/rs6000/rs6000.c:4303
 msgid "-mvsx needs indexed addressing"
 msgstr "-mvsx yêu cầu đặt địa chỉ một cách phụ lục"
 
-#: config/powerpcspe/powerpcspe.c:4438 config/rs6000/rs6000.c:4288
+#: config/powerpcspe/powerpcspe.c:4438 config/rs6000/rs6000.c:4308
 msgid "-mvsx and -mno-altivec are incompatible"
 msgstr "-mvsx và -mno-altivec không tương thích với nhau"
 
-#: config/powerpcspe/powerpcspe.c:4440 config/rs6000/rs6000.c:4290
+#: config/powerpcspe/powerpcspe.c:4440 config/rs6000/rs6000.c:4310
 msgid "-mno-altivec disables vsx"
 msgstr "-mno-altivec thì tắt vsx"
 
-#: config/powerpcspe/powerpcspe.c:4648 config/rs6000/rs6000.c:4416
+#: config/powerpcspe/powerpcspe.c:4648 config/rs6000/rs6000.c:4436
 msgid "-mquad-memory requires 64-bit mode"
 msgstr "-mquad-memory yêu cầu chế độ 64-bit"
 
-#: config/powerpcspe/powerpcspe.c:4651 config/rs6000/rs6000.c:4419
+#: config/powerpcspe/powerpcspe.c:4651 config/rs6000/rs6000.c:4439
 msgid "-mquad-memory-atomic requires 64-bit mode"
 msgstr "-mquad-memory-atomic cần chế độ 64-bit"
 
-#: config/powerpcspe/powerpcspe.c:4663 config/rs6000/rs6000.c:4431
+#: config/powerpcspe/powerpcspe.c:4663 config/rs6000/rs6000.c:4451
 msgid "-mquad-memory is not available in little endian mode"
 msgstr "-mquad-memory không sẵn sàng trên chế độ little endian"
 
-#: config/powerpcspe/powerpcspe.c:4735 config/rs6000/rs6000.c:4512
+#: config/powerpcspe/powerpcspe.c:4735 config/rs6000/rs6000.c:4532
 msgid "-mtoc-fusion requires 64-bit"
 msgstr "-mtoc-fusion yêu cầu chế độ 64-bit"
 
-#: config/powerpcspe/powerpcspe.c:4742 config/rs6000/rs6000.c:4519
+#: config/powerpcspe/powerpcspe.c:4742 config/rs6000/rs6000.c:4539
 msgid "-mtoc-fusion requires medium/large code model"
 msgstr "-mtoc-fusion yêu cầu mô hình mã medium/large"
 
-#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10915
+#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10947
 msgid "bad move"
 msgstr "sai di chuyển"
 
-#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21087
+#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21164
 msgid "Bad 128-bit move"
 msgstr "Di chuyển 128-bit sai"
 
-#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21278
+#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21355
 #, c-format
 msgid "invalid %%e value"
 msgstr "giá trị %%e sai"
 
-#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21299
+#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21376
 #, c-format
 msgid "invalid %%f value"
 msgstr "giá trị %%f sai"
 
-#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21308
+#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21385
 #, c-format
 msgid "invalid %%F value"
 msgstr "giá trị %%F sai"
 
-#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21317
+#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21394
 #, c-format
 msgid "invalid %%G value"
 msgstr "giá trị %%G sai"
 
-#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21352
+#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21429
 #, c-format
 msgid "invalid %%j code"
 msgstr "mã %%j sai"
 
-#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21362
+#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21439
 #, c-format
 msgid "invalid %%J code"
 msgstr "mã %%J sai"
 
-#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21372
+#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21449
 #, c-format
 msgid "invalid %%k value"
 msgstr "giá trị %%k sai"
 
-#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21387
+#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21464
 #: config/xtensa/xtensa.c:2415
 #, c-format
 msgid "invalid %%K value"
 msgstr "giá trị %%K sai"
 
-#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21434
+#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21511
 #, c-format
 msgid "invalid %%O value"
 msgstr "giá trị %%O sai"
 
-#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21481
+#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21558
 #, c-format
 msgid "invalid %%q value"
 msgstr "giá trị %%q sai"
 
-#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21534
+#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21611
 #, c-format
 msgid "invalid %%T value"
 msgstr "giá trị %%T sai"
 
-#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21546
+#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21623
 #, c-format
 msgid "invalid %%u value"
 msgstr "giá trị %%u sai"
 
-#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21560
+#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21637
 #: config/xtensa/xtensa.c:2384
 #, c-format
 msgid "invalid %%v value"
 msgstr "giá trị %%v sai"
 
-#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21627
+#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21704
 #: config/xtensa/xtensa.c:2436
 #, c-format
 msgid "invalid %%x value"
 msgstr "giá trị %%x sai"
 
-#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21747
+#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21824
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "giá trị %%y sai, hãy thử sử dụng ràng buộc “Z”"
 
-#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22282
+#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22359
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr "__float128 và __ibm128 không thể được dùng trong cùng một biểu thức"
 
-#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22288
+#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22365
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr "__ibm128 và long double không thể được dùng trong cùng một biểu thức"
 
-#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22294
+#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22371
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr "__float128 và long double không thể được dùng trong cùng một biểu thức"
 
-#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36572
+#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36628
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "đối số AltiVec bị gửi cho hàm không nguyên mẫu"
 
-#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38739
+#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38795
 msgid "Could not generate addis value for fusion"
 msgstr "Không thể tạo addis cho sát nhập"
 
-#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38809
+#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38865
 msgid "Unable to generate load/store offset for fusion"
 msgstr "Không thể tạo ra việc tải/lưu offset cho hợp nhất"
 
-#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38908
+#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38964
 msgid "Bad GPR fusion"
 msgstr "Hợp nhất GPR sai"
 
-#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39126
+#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39182
 msgid "emit_fusion_p9_load, bad reg #1"
 msgstr "emit_fusion_p9_load, reg #1 sai"
 
-#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39172
+#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39228
 msgid "emit_fusion_p9_load, bad reg #2"
 msgstr "emit_fusion_p9_load, reg #2 sai"
 
-#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39175
+#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39231
 msgid "emit_fusion_p9_load not MEM"
 msgstr "emit_fusion_p9_load không MEM"
 
-#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39213
+#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39269
 msgid "emit_fusion_p9_store, bad reg #1"
 msgstr "emit_fusion_p9_store, reg #1 sai"
 
-#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39259
+#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39315
 msgid "emit_fusion_p9_store, bad reg #2"
 msgstr "emit_fusion_p9_store, reg #2 sai"
 
-#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39262
+#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39318
 msgid "emit_fusion_p9_store not MEM"
 msgstr "emit_fusion_p9_store không MEM"
 
@@ -4380,14 +4380,14 @@
 #: c/gimple-parser.c:188 c/gimple-parser.c:197 c/gimple-parser.c:226
 #: c/gimple-parser.c:1375 c/gimple-parser.c:1404 c/gimple-parser.c:1484
 #: c/gimple-parser.c:1511 c/c-parser.c:3204 c/c-parser.c:9967
-#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27841
-#: cp/parser.c:28430
+#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27838
+#: cp/parser.c:28427
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "cần %<;%>"
 
 #: c/c-parser.c:2431 c/c-parser.c:7573 c/c-parser.c:8015 c/c-parser.c:8058
-#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27839 cp/parser.c:28448
+#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27836 cp/parser.c:28445
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "cần %<,%>"
@@ -4402,7 +4402,7 @@
 #: c/gimple-parser.c:821 c/gimple-parser.c:837 c/gimple-parser.c:853
 #: c/gimple-parser.c:880 c/gimple-parser.c:915 c/gimple-parser.c:1038
 #: c/gimple-parser.c:1209 c/gimple-parser.c:1220 c/gimple-parser.c:1342
-#: c/gimple-parser.c:1441 cp/parser.c:28478
+#: c/gimple-parser.c:1441 cp/parser.c:28475
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "cần %<)%>"
@@ -4410,7 +4410,7 @@
 #: c/c-parser.c:3824 c/c-parser.c:4733 c/c-parser.c:4769 c/c-parser.c:6441
 #: c/c-parser.c:8125 c/c-parser.c:8983 c/c-parser.c:9127 c/c-parser.c:11588
 #: c/c-parser.c:18220 c/c-parser.c:18222 c/gimple-parser.c:1015
-#: cp/parser.c:28442
+#: cp/parser.c:28439
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "cần %<]%>"
@@ -4424,7 +4424,7 @@
 #: c/c-parser.c:17792 c/gimple-parser.c:363 c/gimple-parser.c:811
 #: c/gimple-parser.c:873 c/gimple-parser.c:911 c/gimple-parser.c:1198
 #: c/gimple-parser.c:1339 c/gimple-parser.c:1438 c/c-parser.c:11911
-#: cp/parser.c:28433
+#: cp/parser.c:28430
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "cần %<(%>"
@@ -4431,7 +4431,7 @@
 
 #: c/c-parser.c:4903 c/c-parser.c:10310 c/c-parser.c:16212 c/c-parser.c:18449
 #: c/gimple-parser.c:141 c/gimple-parser.c:1444 c/c-parser.c:3018
-#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18155 cp/parser.c:28439
+#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18152 cp/parser.c:28436
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "cần %<{%>"
@@ -4441,13 +4441,13 @@
 #: c/c-parser.c:12351 c/c-parser.c:12493 c/c-parser.c:12864 c/c-parser.c:12957
 #: c/c-parser.c:13566 c/c-parser.c:17636 c/c-parser.c:17695
 #: c/gimple-parser.c:431 c/gimple-parser.c:1492 c/gimple-parser.c:1519
-#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28472 cp/parser.c:29597
-#: cp/parser.c:32279
+#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28469 cp/parser.c:29594
+#: cp/parser.c:32276
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "cần %<:%>"
 
-#: c/c-parser.c:5974 cp/parser.c:28365
+#: c/c-parser.c:5974 cp/parser.c:28362
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "cần %<while%>"
@@ -4456,18 +4456,18 @@
 msgid "expected %<.%>"
 msgstr "cần %<.%>"
 
-#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30172
-#: cp/parser.c:30246
+#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30169
+#: cp/parser.c:30243
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "cần %<@end%>"
 
-#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28457
+#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28454
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "cần %<>%>"
 
-#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28481
+#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28478
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "cần %<,%> hoặc %<)%>"
@@ -4475,32 +4475,32 @@
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15190 c/c-parser.c:15234 c/c-parser.c:15466 c/c-parser.c:15701
 #: c/c-parser.c:17833 c/gimple-parser.c:286 c/c-parser.c:4792
-#: cp/parser.c:28460
+#: cp/parser.c:28457
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "cần %<=%>"
 
-#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28436
-#: cp/parser.c:30389
+#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28433
+#: cp/parser.c:30386
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "cần %<}%>"
 
-#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35674
+#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35671
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "cần %<#pragma omp section%> hoặc %<}%>"
 
-#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28445 cp/parser.c:31535
+#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28442 cp/parser.c:31532
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "cần %<[%>"
 
-#: c/c-typeck.c:7847
+#: c/c-typeck.c:7852
 msgid "(anonymous)"
 msgstr "(nặc danh)"
 
-#: c/gimple-parser.c:795 cp/parser.c:15791 cp/parser.c:28454
+#: c/gimple-parser.c:795 cp/parser.c:15788 cp/parser.c:28451
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "cần %<<%>"
@@ -4768,11 +4768,11 @@
 msgid "%r%s:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr "%r%s:%d:%R   trong khai triển constexpr của %qs"
 
-#: cp/pt.c:1949 cp/semantics.c:5268
+#: cp/pt.c:1949 cp/semantics.c:5271
 msgid "candidates are:"
 msgstr "các ứng cử là:"
 
-#: cp/pt.c:1951 cp/pt.c:22975
+#: cp/pt.c:1951 cp/pt.c:23053
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "ứng cử là:"
@@ -4817,27 +4817,27 @@
 msgid "source type is not polymorphic"
 msgstr "nguồn không có loại nhiều dạng"
 
-#: cp/typeck.c:6083 c/c-typeck.c:4261
+#: cp/typeck.c:6083 c/c-typeck.c:4266
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "đối số có loại sai đối với dấu trừ nguyên phân"
 
-#: cp/typeck.c:6084 c/c-typeck.c:4248
+#: cp/typeck.c:6084 c/c-typeck.c:4253
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "đối số có loại sai đối với dấu cộng nguyên phân"
 
-#: cp/typeck.c:6111 c/c-typeck.c:4302
+#: cp/typeck.c:6111 c/c-typeck.c:4307
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "đối số có loại sai đối với phần bù bit"
 
-#: cp/typeck.c:6128 c/c-typeck.c:4310
+#: cp/typeck.c:6128 c/c-typeck.c:4315
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "đối số có loại sai đối với bộ tuyệt đối"
 
-#: cp/typeck.c:6140 c/c-typeck.c:4322
+#: cp/typeck.c:6140 c/c-typeck.c:4327
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "đối số có loại sai đối với phần chia"
@@ -5081,67 +5081,67 @@
 msgid "Expected attribute bit name"
 msgstr "Mong đợi một tên bit thuộc tính"
 
-#: fortran/module.c:3223
+#: fortran/module.c:3225
 msgid "Expected integer string"
 msgstr "Mong đợi một chuỗi số nguyên"
 
-#: fortran/module.c:3227
+#: fortran/module.c:3229
 msgid "Error converting integer"
 msgstr "Gặp lỗi khi chuyển đổi số nguyên"
 
-#: fortran/module.c:3249
+#: fortran/module.c:3251
 msgid "Expected real string"
 msgstr "Mong đợi một chuỗi thật"
 
-#: fortran/module.c:3474
+#: fortran/module.c:3476
 msgid "Expected expression type"
 msgstr "Mong đợi một loại biểu thức"
 
-#: fortran/module.c:3554
+#: fortran/module.c:3556
 msgid "Bad operator"
 msgstr "Toán tử sai"
 
-#: fortran/module.c:3671
+#: fortran/module.c:3673
 msgid "Bad type in constant expression"
 msgstr "Gặp loại saio trong biểu thức bất biến"
 
-#: fortran/module.c:7038
+#: fortran/module.c:7040
 msgid "Unexpected end of module"
 msgstr "Gặp kết thức mô-đun bất thường"
 
-#: fortran/parse.c:1757
+#: fortran/parse.c:1761
 msgid "arithmetic IF"
 msgstr "IF (nếu) số học"
 
-#: fortran/parse.c:1766
+#: fortran/parse.c:1770
 msgid "attribute declaration"
 msgstr "lời khai báo thuộc tính"
 
-#: fortran/parse.c:1802
+#: fortran/parse.c:1806
 msgid "data declaration"
 msgstr "lời khai báo dữ liệu"
 
-#: fortran/parse.c:1820
+#: fortran/parse.c:1824
 msgid "derived type declaration"
 msgstr "lời khai báo loại có hướng"
 
-#: fortran/parse.c:1947
+#: fortran/parse.c:1951
 msgid "block IF"
 msgstr "IF (nếu) loại khối"
 
-#: fortran/parse.c:1956
+#: fortran/parse.c:1960
 msgid "implied END DO"
 msgstr "ngụ ý END DO (kết thúc làm)"
 
-#: fortran/parse.c:2050 fortran/resolve.c:11199
+#: fortran/parse.c:2054 fortran/resolve.c:11219
 msgid "assignment"
 msgstr "sự gán"
 
-#: fortran/parse.c:2053 fortran/resolve.c:11250 fortran/resolve.c:11253
+#: fortran/parse.c:2057 fortran/resolve.c:11270 fortran/resolve.c:11273
 msgid "pointer assignment"
 msgstr "sự gán hàm trỏ"
 
-#: fortran/parse.c:2071
+#: fortran/parse.c:2075
 msgid "simple IF"
 msgstr "IF (nếu) đơn giản"
 
@@ -5233,107 +5233,113 @@
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr "Tại %%L có một toán tử thuộc số nguyên phân “%s” với toán hạng %s"
 
-#: fortran/resolve.c:3878
+#: fortran/resolve.c:3879
+#, fuzzy, c-format
+#| msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
+msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
+msgstr "Tại %%L có một toán tử thuộc số nhị phân “%s” với các toán hạng %s/%s"
+
+#: fortran/resolve.c:3884
 #, c-format
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr "Tại %%L có một toán tử thuộc số nhị phân “%s” với các toán hạng %s/%s"
 
-#: fortran/resolve.c:3893
+#: fortran/resolve.c:3899
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr "Tại %%L có một toán tử ghép nối chuỗi với các toán hạng %s/%s"
 
-#: fortran/resolve.c:3926
+#: fortran/resolve.c:3932
 #, c-format
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr "Tại %%L có một toán tử hợp lý “%s” với các toán hạng %s/%s"
 
-#: fortran/resolve.c:3949
+#: fortran/resolve.c:3955
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr "Tại %%L có một toán tử .not. với toán hạng %s"
 
-#: fortran/resolve.c:3963
+#: fortran/resolve.c:3969
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "Không thể so sánh các số lượng PHỨC TẠP tại %L"
 
-#: fortran/resolve.c:4015
+#: fortran/resolve.c:4021
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr "Tại %%L thì các bộ hợp lý phải được so sánh với %s thay cho %s"
 
-#: fortran/resolve.c:4021
+#: fortran/resolve.c:4027
 #, c-format
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr "Tại %%L có một toán tử so sánh “%s” với các toán hạng %s/%s"
 
-#: fortran/resolve.c:4034
+#: fortran/resolve.c:4040
 #, fuzzy, c-format
 #| msgid "Unknown operator %%<%s%%> at %%L"
 msgid "Unknown operator %%<%s%%> at %%L; did you mean '%s'?"
 msgstr "Không rõ toán tử %%<%s%%> tại %%L"
 
-#: fortran/resolve.c:4037
+#: fortran/resolve.c:4043
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr "Không rõ toán tử %%<%s%%> tại %%L"
 
-#: fortran/resolve.c:4040
+#: fortran/resolve.c:4046
 #, c-format
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr "Toán hạng của toán tử người dùng %%<%s%%> tại %%L là %s"
 
-#: fortran/resolve.c:4044
+#: fortran/resolve.c:4050
 #, c-format
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr "Các toán hạng của toán tử người dùng %%<%s%%> tại %%L là %s/%s"
 
-#: fortran/resolve.c:4132
+#: fortran/resolve.c:4138
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "Tại %%L và %%L có một toán tử với các phân hàng mâu thuẫn nhau"
 
-#: fortran/resolve.c:6849
+#: fortran/resolve.c:6855
 msgid "Loop variable"
 msgstr "Biến vòng lặp"
 
-#: fortran/resolve.c:6853
+#: fortran/resolve.c:6859
 msgid "iterator variable"
 msgstr "biến iterator"
 
-#: fortran/resolve.c:6857
+#: fortran/resolve.c:6863
 msgid "Start expression in DO loop"
 msgstr "Biểu thức bắt đầu trong vòng lặp DO (làm)"
 
-#: fortran/resolve.c:6861
+#: fortran/resolve.c:6867
 msgid "End expression in DO loop"
 msgstr "Biểu thức kết thúc trong vòng lặp DO (làm)"
 
-#: fortran/resolve.c:6865
+#: fortran/resolve.c:6871
 msgid "Step expression in DO loop"
 msgstr "Biểu thức bước trong vòng lặp DO (làm)"
 
-#: fortran/resolve.c:7150 fortran/resolve.c:7153
+#: fortran/resolve.c:7156 fortran/resolve.c:7159
 msgid "DEALLOCATE object"
 msgstr "đối tượng DEALLOCATE"
 
-#: fortran/resolve.c:7525 fortran/resolve.c:7528
+#: fortran/resolve.c:7531 fortran/resolve.c:7534
 msgid "ALLOCATE object"
 msgstr "đối tượng ALLOCATE"
 
-#: fortran/resolve.c:7720 fortran/resolve.c:9417
+#: fortran/resolve.c:7726 fortran/resolve.c:9428
 msgid "STAT variable"
 msgstr "biến STAT"
 
-#: fortran/resolve.c:7764 fortran/resolve.c:9429
+#: fortran/resolve.c:7770 fortran/resolve.c:9440
 msgid "ERRMSG variable"
 msgstr "Biến ERRMSG"
 
-#: fortran/resolve.c:9219
+#: fortran/resolve.c:9230
 msgid "item in READ"
 msgstr "mục tin trong READ"
 
-#: fortran/resolve.c:9441
+#: fortran/resolve.c:9452
 msgid "ACQUIRED_LOCK variable"
 msgstr "biến ACQUIRED_LOCK"
 
@@ -5366,7 +5372,7 @@
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:10154
+#: fortran/trans-expr.c:10157
 msgid "Assignment of scalar to unallocated array"
 msgstr "Gán vô hướng cho mảng chưa cấp phát"
 
@@ -5375,12 +5381,12 @@
 msgid "Unequal character lengths (%ld/%ld) in %s"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:8088
+#: fortran/trans-intrinsic.c:8090
 #, c-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative (its value is %ld)"
 msgstr "Tham số NCOPIES của REPEAT (lặp lại) hạn chế là âm (giá trị của nó là %ld)"
 
-#: fortran/trans-intrinsic.c:8120
+#: fortran/trans-intrinsic.c:8122
 msgid "Argument NCOPIES of REPEAT intrinsic is too large"
 msgstr "Điều thực chất REPEAT (lặp lại) có đối số NCOPIES (số các bản sao) quá lớn"
 
@@ -5401,15 +5407,15 @@
 msgid "Invalid image number %d in SYNC IMAGES"
 msgstr "Số ảnh không hợp lệ %d trong SYNC IMAGES"
 
-#: fortran/trans-stmt.c:2180
+#: fortran/trans-stmt.c:2177
 msgid "Loop iterates infinitely"
 msgstr ""
 
-#: fortran/trans-stmt.c:2200 fortran/trans-stmt.c:2456
+#: fortran/trans-stmt.c:2197 fortran/trans-stmt.c:2453
 msgid "Loop variable has been modified"
 msgstr "Biến vòng lặp bị sửa đổi"
 
-#: fortran/trans-stmt.c:2309
+#: fortran/trans-stmt.c:2306
 msgid "DO step value is zero"
 msgstr "Giá trị bước DO (làm) là số không"
 
@@ -5993,10 +5999,10 @@
 msgid "Allow dollar signs in entity names."
 msgstr "Cho phép tên thực thể chứa dấu đồng đô la \"$\"."
 
-#: fortran/lang.opt:485 config/alpha/alpha.opt:31 common.opt:783
-#: common.opt:985 common.opt:989 common.opt:993 common.opt:997 common.opt:1532
-#: common.opt:1588 common.opt:1712 common.opt:1716 common.opt:1946
-#: common.opt:2116 common.opt:2792
+#: fortran/lang.opt:485 config/alpha/alpha.opt:31 common.opt:649
+#: common.opt:783 common.opt:989 common.opt:993 common.opt:997 common.opt:1001
+#: common.opt:1536 common.opt:1592 common.opt:1716 common.opt:1720
+#: common.opt:1950 common.opt:2120 common.opt:2796
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr "Không làm gì. Giữ lại vì mục đích tương thích ngược."
 
@@ -6215,12 +6221,12 @@
 msgstr "Có tên hiển thị bên ngoài thì phụ thêm dấu gạch dưới."
 
 #: fortran/lang.opt:751 c-family/c.opt:1356 c-family/c.opt:1384
-#: c-family/c.opt:1634 config/pa/pa.opt:42 config/pa/pa.opt:70 common.opt:1154
-#: common.opt:1333 common.opt:1408 common.opt:1676 common.opt:1799
-#: common.opt:2169 common.opt:2205 common.opt:2298 common.opt:2302
-#: common.opt:2407 common.opt:2498 common.opt:2506 common.opt:2514
-#: common.opt:2522 common.opt:2623 common.opt:2675 common.opt:2755
-#: common.opt:2893 common.opt:2897 common.opt:2901 common.opt:2905
+#: c-family/c.opt:1634 config/pa/pa.opt:42 config/pa/pa.opt:70 common.opt:1158
+#: common.opt:1337 common.opt:1412 common.opt:1680 common.opt:1803
+#: common.opt:2173 common.opt:2209 common.opt:2302 common.opt:2306
+#: common.opt:2411 common.opt:2502 common.opt:2510 common.opt:2518
+#: common.opt:2526 common.opt:2627 common.opt:2679 common.opt:2759
+#: common.opt:2897 common.opt:2901 common.opt:2905 common.opt:2909
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr "Không làm gì. Dành cho mục đích tương thích ngược."
 
@@ -6272,7 +6278,7 @@
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:220 c-family/c.opt:224
 #: c-family/c.opt:236 c-family/c.opt:1855 c-family/c.opt:1863 brig/lang.opt:39
-#: config/darwin.opt:56 common.opt:338 common.opt:341 common.opt:3046
+#: config/darwin.opt:56 common.opt:338 common.opt:341 common.opt:3050
 #, c-format
 msgid "missing filename after %qs"
 msgstr "thiếu tên tập tin sau %qs"
@@ -6870,7 +6876,7 @@
 #: c-family/c.opt:1525 c-family/c.opt:1528 c-family/c.opt:1569
 #: c-family/c.opt:1704 c-family/c.opt:1731 c-family/c.opt:1771
 #: c-family/c.opt:1802 c-family/c.opt:1806 c-family/c.opt:1822
-#: config/ia64/ia64.opt:167 config/ia64/ia64.opt:170 c-family/c-opts.c:434
+#: config/ia64/ia64.opt:167 config/ia64/ia64.opt:170 c-family/c-opts.c:432
 #, gcc-internal-format
 msgid "switch %qs is no longer supported"
 msgstr "switch %qs không còn tiếp tục được hỗ trợ nữa"
@@ -14090,10 +14096,6 @@
 msgid "Warn if dereferencing a NULL pointer may lead to erroneous or undefined behavior."
 msgstr ""
 
-#: common.opt:649
-msgid "Warn if the loop cannot be optimized due to nontrivial assumptions."
-msgstr ""
-
 #: common.opt:656
 msgid "Warn about some C++ One Definition Rule violations during link time optimization."
 msgstr ""
@@ -14270,1698 +14272,1698 @@
 msgid "-dumpdir <dir>\tSet the directory name to be used for dumps."
 msgstr ""
 
-#: common.opt:946
+#: common.opt:950
 msgid "The version of the C++ ABI in use."
 msgstr ""
 
-#: common.opt:950
+#: common.opt:954
 msgid "Aggressively optimize loops using language constraints."
 msgstr ""
 
-#: common.opt:954
+#: common.opt:958
 msgid "Align the start of functions."
 msgstr "Chỉnh đầu của hàm."
 
-#: common.opt:964
+#: common.opt:968
 msgid "Align labels which are only reached by jumping."
 msgstr ""
 
-#: common.opt:971
+#: common.opt:975
 msgid "Align all labels."
 msgstr "Cân chỉnh tất cả các nhãn."
 
-#: common.opt:978
+#: common.opt:982
 msgid "Align the start of loops."
 msgstr "Chỉnh đầu của vòng lặp."
 
-#: common.opt:1001
+#: common.opt:1005
 msgid "Select what to sanitize."
 msgstr "Chọn cái gì để cải thiện."
 
-#: common.opt:1005
+#: common.opt:1009
 #, fuzzy
 #| msgid "Select what to sanitize."
 msgid "Select type of coverage sanitization."
 msgstr "Chọn cái gì để cải thiện."
 
-#: common.opt:1009
+#: common.opt:1013
 msgid "-fasan-shadow-offset=<number>\tUse custom shadow memory offset."
 msgstr ""
 
-#: common.opt:1013
+#: common.opt:1017
 msgid "-fsanitize-sections=<sec1,sec2,...>\tSanitize global variables in user-defined sections."
 msgstr ""
 
-#: common.opt:1018
+#: common.opt:1022
 msgid "After diagnosing undefined behavior attempt to continue execution."
 msgstr ""
 
-#: common.opt:1022
+#: common.opt:1026
 msgid "This switch is deprecated; use -fsanitize-recover= instead."
 msgstr "Cái chuyển này đã lạc hậu: hãy thay thế bằng -fsanitize-recover=."
 
-#: common.opt:1029
+#: common.opt:1033
 msgid "Use trap instead of a library function for undefined behavior sanitization."
 msgstr ""
 
-#: common.opt:1033
+#: common.opt:1037
 msgid "Generate unwind tables that are exact at each instruction boundary."
 msgstr ""
 
-#: common.opt:1037
+#: common.opt:1041
 msgid "Generate auto-inc/dec instructions."
 msgstr "Tạo ra câu lệnh auto-inc/dec."
 
-#: common.opt:1041
+#: common.opt:1045
 msgid "Use sample profile information for call graph node weights. The default profile file is fbdata.afdo in 'pwd'."
 msgstr ""
 
-#: common.opt:1046
+#: common.opt:1050
 msgid "Use sample profile information for call graph node weights. The profile file is specified in the argument."
 msgstr ""
 
-#: common.opt:1055
+#: common.opt:1059
 msgid "Generate code to check bounds before indexing arrays."
 msgstr ""
 
-#: common.opt:1059
+#: common.opt:1063
 msgid "Replace add, compare, branch with branch on count register."
 msgstr ""
 
-#: common.opt:1063
+#: common.opt:1067
 msgid "Use profiling information for branch probabilities."
 msgstr ""
 
-#: common.opt:1067
+#: common.opt:1071
 msgid "Perform branch target load optimization before prologue / epilogue threading."
 msgstr ""
 
-#: common.opt:1071
+#: common.opt:1075
 msgid "Perform branch target load optimization after prologue / epilogue threading."
 msgstr ""
 
-#: common.opt:1075
+#: common.opt:1079
 msgid "Restrict target load migration not to re-use registers in any basic block."
 msgstr ""
 
-#: common.opt:1079
+#: common.opt:1083
 msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions."
 msgstr ""
 
-#: common.opt:1083
+#: common.opt:1087
 msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls."
 msgstr ""
 
-#: common.opt:1090
+#: common.opt:1094
 msgid "Save registers around function calls."
 msgstr ""
 
-#: common.opt:1094
+#: common.opt:1098
 msgid "This switch is deprecated; do not use."
 msgstr "Cái chuyển này đã lạc hậu: đừng dùng."
 
-#: common.opt:1098
+#: common.opt:1102
 msgid "Check the return value of new in C++."
 msgstr "Kiểm tra giá trị trả về của new trong C++."
 
-#: common.opt:1102 common.opt:1106
+#: common.opt:1106 common.opt:1110
 msgid "Perform internal consistency checkings."
 msgstr ""
 
-#: common.opt:1110
+#: common.opt:1114
 #, fuzzy
 msgid "Enable code hoisting."
 msgstr "Bật khả năng tiền xử lý."
 
-#: common.opt:1114
+#: common.opt:1118
 msgid "Looks for opportunities to reduce stack adjustments and stack references."
 msgstr ""
 
-#: common.opt:1118
+#: common.opt:1122
 msgid "Do not put uninitialized globals in the common section."
 msgstr ""
 
-#: common.opt:1126
+#: common.opt:1130
 msgid "-fcompare-debug[=<opts>]\tCompile with and without e.g. -gtoggle, and compare the final-insns dump."
 msgstr ""
 
-#: common.opt:1130
+#: common.opt:1134
 msgid "Run only the second compilation of -fcompare-debug."
 msgstr "Chỉ chạy biên dịch lần hai của tùy chọn -fcompare-debug."
 
-#: common.opt:1134
+#: common.opt:1138
 msgid "Perform comparison elimination after register allocation has finished."
 msgstr ""
 
-#: common.opt:1138
+#: common.opt:1142
 msgid "Do not perform optimizations increasing noticeably stack usage."
 msgstr ""
 
-#: common.opt:1142
+#: common.opt:1146
 msgid "Perform a register copy-propagation optimization pass."
 msgstr ""
 
-#: common.opt:1146
+#: common.opt:1150
 msgid "Perform cross-jumping optimization."
 msgstr ""
 
-#: common.opt:1150
+#: common.opt:1154
 msgid "When running CSE, follow jumps to their targets."
 msgstr ""
 
-#: common.opt:1158
+#: common.opt:1162
 msgid "Omit range reduction step when performing complex division."
 msgstr ""
 
-#: common.opt:1162
+#: common.opt:1166
 msgid "Complex multiplication and division follow Fortran rules."
 msgstr ""
 
-#: common.opt:1166
+#: common.opt:1170
 msgid "Place data items into their own section."
 msgstr ""
 
-#: common.opt:1170
+#: common.opt:1174
 msgid "List all available debugging counters with their limits and counts."
 msgstr ""
 
-#: common.opt:1174
+#: common.opt:1178
 msgid "-fdbg-cnt=<counter>:<limit>[,<counter>:<limit>,...]\tSet the debug counter limit."
 msgstr ""
 
-#: common.opt:1178
+#: common.opt:1182
 msgid "-fdebug-prefix-map=<old>=<new> Map one directory name to another in debug information."
 msgstr ""
 
-#: common.opt:1182
+#: common.opt:1186
 msgid "-ffile-prefix-map=<old>=<new> Map one directory name to another in compilation result."
 msgstr ""
 
-#: common.opt:1186
+#: common.opt:1190
 msgid "Output .debug_types section when using DWARF v4 debuginfo."
 msgstr ""
 
-#: common.opt:1192
+#: common.opt:1196
 msgid "Defer popping functions args from stack until later."
 msgstr ""
 
-#: common.opt:1196
+#: common.opt:1200
 msgid "Attempt to fill delay slots of branch instructions."
 msgstr ""
 
-#: common.opt:1200
+#: common.opt:1204
 msgid "Delete dead instructions that may throw exceptions."
 msgstr ""
 
-#: common.opt:1204
+#: common.opt:1208
 msgid "Delete useless null pointer checks."
 msgstr ""
 
-#: common.opt:1208
+#: common.opt:1212
 msgid "Stream extra data to support more aggressive devirtualization in LTO local transformation mode."
 msgstr ""
 
-#: common.opt:1212
+#: common.opt:1216
 msgid "Perform speculative devirtualization."
 msgstr ""
 
-#: common.opt:1216
+#: common.opt:1220
 msgid "Try to convert virtual calls to direct ones."
 msgstr ""
 
-#: common.opt:1220
+#: common.opt:1224
 msgid "-fdiagnostics-show-location=[once|every-line]\tHow often to emit source location at the beginning of line-wrapped diagnostics."
 msgstr ""
 
-#: common.opt:1237
+#: common.opt:1241
 msgid "Show the source line with a caret indicating the column."
 msgstr ""
 
-#: common.opt:1245
+#: common.opt:1249
 msgid "-fdiagnostics-color=[never|always|auto]\tColorize diagnostics."
 msgstr ""
 
-#: common.opt:1265
+#: common.opt:1269
 msgid "Print fix-it hints in machine-readable form."
 msgstr ""
 
-#: common.opt:1269
+#: common.opt:1273
 msgid "Print fix-it hints to stderr in unified diff format."
 msgstr ""
 
-#: common.opt:1273
+#: common.opt:1277
 msgid "Amend appropriate diagnostic messages with the command line option that controls them."
 msgstr ""
 
-#: common.opt:1277
+#: common.opt:1281
 msgid "-fdisable-[tree|rtl|ipa]-<pass>=range1+range2 disables an optimization pass."
 msgstr "-fdisable-[tree|rtl|ipa]-<pass>=vùng1+vùng2 tắt chuyển qua tối ưu hóa."
 
-#: common.opt:1281
+#: common.opt:1285
 msgid "-fenable-[tree|rtl|ipa]-<pass>=range1+range2 enables an optimization pass."
 msgstr "-fenable-[tree|rtl|ipa]-<pass>=vùng1+vùng2 bật chuyển qua tối ưu hóa."
 
-#: common.opt:1285
+#: common.opt:1289
 msgid "-fdump-<type>\tDump various compiler internals to a file."
 msgstr ""
 
-#: common.opt:1292
+#: common.opt:1296
 msgid "-fdump-final-insns=filename\tDump to filename the insns at the end of translation."
 msgstr ""
 
-#: common.opt:1296
+#: common.opt:1300
 msgid "-fdump-go-spec=filename\tWrite all declarations to file as Go code."
 msgstr ""
 
-#: common.opt:1300
+#: common.opt:1304
 msgid "Suppress output of addresses in debugging dumps."
 msgstr ""
 
-#: common.opt:1304
+#: common.opt:1308
 msgid "Collect and dump debug information into temporary file if ICE in C/C++ compiler occurred."
 msgstr ""
 
-#: common.opt:1309
+#: common.opt:1313
 msgid "Dump detailed information on GCC's internal representation of source code locations."
 msgstr ""
 
-#: common.opt:1313
+#: common.opt:1317
 msgid "Dump optimization passes."
 msgstr ""
 
-#: common.opt:1317
+#: common.opt:1321
 msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps."
 msgstr ""
 
-#: common.opt:1321
+#: common.opt:1325
 msgid "Suppress output of previous and next insn numbers in debugging dumps."
 msgstr ""
 
-#: common.opt:1325
+#: common.opt:1329
 msgid "Enable CFI tables via GAS assembler directives."
 msgstr ""
 
-#: common.opt:1329
+#: common.opt:1333
 msgid "Perform early inlining."
 msgstr ""
 
-#: common.opt:1337
+#: common.opt:1341
 msgid "Perform interprocedural reduction of aggregates."
 msgstr ""
 
-#: common.opt:1341
+#: common.opt:1345
 msgid "Perform unused symbol elimination in debug info."
 msgstr ""
 
-#: common.opt:1345
+#: common.opt:1349
 msgid "Perform unused type elimination in debug info."
 msgstr ""
 
-#: common.opt:1349
+#: common.opt:1353
 msgid "Do not suppress C++ class debug information."
 msgstr ""
 
-#: common.opt:1353
+#: common.opt:1357
 msgid "Enable exception handling."
 msgstr "Bật tiếp nhận ngoại lệ."
 
-#: common.opt:1357
+#: common.opt:1361
 msgid "Perform a number of minor, expensive optimizations."
 msgstr ""
 
-#: common.opt:1361
+#: common.opt:1365
 msgid "-fexcess-precision=[fast|standard]\tSpecify handling of excess floating-point precision."
 msgstr "-fexcess-precision=[fast|standard]\tChỉ định cách xử lý khi độ chính xác của dấu chấm động bị vượt quá."
 
-#: common.opt:1364
+#: common.opt:1368
 #, c-format
 msgid "unknown excess precision style %qs"
 msgstr "không hiểu kiểu chính xác bị vượt quá %qs"
 
-#: common.opt:1376
+#: common.opt:1380
 msgid "-fpermitted-flt-eval-methods=[c11|ts-18661]\tSpecify which values of FLT_EVAL_METHOD are permitted."
 msgstr "-fpermitted-flt-eval-methods=[c11|ts-18661]\tChỉ định xem giá trị của FLT_EVAL_METHOD sẽ cho phép."
 
-#: common.opt:1379
+#: common.opt:1383
 #, c-format
 msgid "unknown specification for the set of FLT_EVAL_METHOD values to permit %qs"
 msgstr ""
 
-#: common.opt:1392
+#: common.opt:1396
 msgid "Output lto objects containing both the intermediate language and binary output."
 msgstr ""
 
-#: common.opt:1396
+#: common.opt:1400
 msgid "Assume no NaNs or infinities are generated."
 msgstr ""
 
-#: common.opt:1400
+#: common.opt:1404
 msgid "-ffixed-<register>\tMark <register> as being unavailable to the compiler."
 msgstr ""
 
-#: common.opt:1404
+#: common.opt:1408
 msgid "Don't allocate floats and doubles in extended-precision registers."
 msgstr ""
 
-#: common.opt:1412
+#: common.opt:1416
 msgid "Perform a forward propagation pass on RTL."
 msgstr ""
 
-#: common.opt:1416
+#: common.opt:1420
 msgid "-ffp-contract=[off|on|fast]\tPerform floating-point expression contraction."
 msgstr ""
 
-#: common.opt:1419
+#: common.opt:1423
 #, c-format
 msgid "unknown floating point contraction style %qs"
 msgstr ""
 
-#: common.opt:1433
+#: common.opt:1437
 msgid "Allow built-in functions ceil, floor, round, trunc to raise \"inexact\" exceptions."
 msgstr ""
 
-#: common.opt:1440
+#: common.opt:1444
 msgid "Allow function addresses to be held in registers."
 msgstr "Sử dụng địa chỉ hàm mà được giữ trong các thanh ghi."
 
-#: common.opt:1444
+#: common.opt:1448
 msgid "Place each function into its own section."
 msgstr ""
 
-#: common.opt:1448
+#: common.opt:1452
 msgid "Perform global common subexpression elimination."
 msgstr ""
 
-#: common.opt:1452
+#: common.opt:1456
 msgid "Perform enhanced load motion during global common subexpression elimination."
 msgstr ""
 
-#: common.opt:1456
+#: common.opt:1460
 msgid "Perform store motion after global common subexpression elimination."
 msgstr ""
 
-#: common.opt:1460
+#: common.opt:1464
 msgid "Perform redundant load after store elimination in global common subexpression elimination."
 msgstr ""
 
-#: common.opt:1465
+#: common.opt:1469
 msgid "Perform global common subexpression elimination after register allocation has finished."
 msgstr ""
 
-#: common.opt:1482
+#: common.opt:1486
 msgid "-fgnat-encodings=[all|gdb|minimal]\tSelect the balance between GNAT encodings and standard DWARF emitted in the debug information"
 msgstr ""
 
-#: common.opt:1487
+#: common.opt:1491
 msgid "Enable in and out of Graphite representation."
 msgstr ""
 
-#: common.opt:1491
+#: common.opt:1495
 msgid "Enable Graphite Identity transformation."
 msgstr ""
 
-#: common.opt:1495
+#: common.opt:1499
 msgid "Enable hoisting adjacent loads to encourage generating conditional move instructions."
 msgstr ""
 
-#: common.opt:1504
+#: common.opt:1508
 msgid "Mark all loops as parallel."
 msgstr "Đánh dấu tất cả các vòng lặp là xử lý song song."
 
-#: common.opt:1508 common.opt:1516 common.opt:2587
+#: common.opt:1512 common.opt:1520 common.opt:2591
 msgid "Enable loop nest transforms.  Same as -floop-nest-optimize."
 msgstr ""
 
-#: common.opt:1512
+#: common.opt:1516
 #, fuzzy
 #| msgid "Enable clip instructions."
 msgid "Enable loop interchange on trees."
 msgstr "Bật các câu lệnh trích đoạn."
 
-#: common.opt:1520
+#: common.opt:1524
 msgid "Perform unroll-and-jam on loops."
 msgstr ""
 
-#: common.opt:1524
+#: common.opt:1528
 msgid "Enable support for GNU transactional memory."
 msgstr ""
 
-#: common.opt:1528
+#: common.opt:1532
 msgid "Use STB_GNU_UNIQUE if supported by the assembler."
 msgstr ""
 
-#: common.opt:1536
+#: common.opt:1540
 msgid "Enable the loop nest optimizer."
 msgstr "Bật sự tối ưu hóa vòng lặp lồng nhau."
 
-#: common.opt:1540
+#: common.opt:1544
 msgid "Force bitfield accesses to match their type width."
 msgstr ""
 
-#: common.opt:1544
+#: common.opt:1548
 msgid "Merge adjacent stores."
 msgstr ""
 
-#: common.opt:1548
+#: common.opt:1552
 msgid "Enable guessing of branch probabilities."
 msgstr ""
 
-#: common.opt:1556
+#: common.opt:1560
 msgid "Process #ident directives."
 msgstr ""
 
-#: common.opt:1560
+#: common.opt:1564
 msgid "Perform conversion of conditional jumps to branchless equivalents."
 msgstr ""
 
-#: common.opt:1564
+#: common.opt:1568
 msgid "Perform conversion of conditional jumps to conditional execution."
 msgstr ""
 
-#: common.opt:1568
+#: common.opt:1572
 msgid "-fstack-reuse=[all|named_vars|none]\tSet stack reuse level for local variables."
 msgstr ""
 
-#: common.opt:1571
+#: common.opt:1575
 #, c-format
 msgid "unknown Stack Reuse Level %qs"
 msgstr ""
 
-#: common.opt:1584
+#: common.opt:1588
 msgid "Convert conditional jumps in innermost loops to branchless equivalents."
 msgstr ""
 
-#: common.opt:1596
+#: common.opt:1600
 msgid "Do not generate .size directives."
 msgstr "Đừng tạo ra chỉ thị .size."
 
-#: common.opt:1600
+#: common.opt:1604
 msgid "Perform indirect inlining."
 msgstr ""
 
-#: common.opt:1606
+#: common.opt:1610
 msgid "Enable inlining of function declared \"inline\", disabling disables all inlining."
 msgstr ""
 
-#: common.opt:1610
+#: common.opt:1614
 msgid "Integrate functions into their callers when code size is known not to grow."
 msgstr ""
 
-#: common.opt:1614
+#: common.opt:1618
 msgid "Integrate functions not declared \"inline\" into their callers when profitable."
 msgstr ""
 
-#: common.opt:1618
+#: common.opt:1622
 msgid "Integrate functions only required by their single caller."
 msgstr ""
 
-#: common.opt:1625
+#: common.opt:1629
 msgid "-finline-limit=<number>\tLimit the size of inlined functions to <number>."
 msgstr ""
 
-#: common.opt:1629
+#: common.opt:1633
 msgid "Inline __atomic operations when a lock free instruction sequence is available."
 msgstr ""
 
-#: common.opt:1636
+#: common.opt:1640
 msgid "-fcf-protection=[full|branch|return|none]\tInstrument functions with checks to verify jump/call/return control-flow transfer instructions have valid targets."
 msgstr ""
 
-#: common.opt:1640
+#: common.opt:1644
 #, c-format
 msgid "unknown Control-Flow Protection Level %qs"
 msgstr ""
 
-#: common.opt:1656
+#: common.opt:1660
 msgid "Instrument function entry and exit with profiling calls."
 msgstr ""
 
-#: common.opt:1660
+#: common.opt:1664
 msgid "-finstrument-functions-exclude-function-list=name,...  Do not instrument listed functions."
 msgstr ""
 
-#: common.opt:1664
+#: common.opt:1668
 msgid "-finstrument-functions-exclude-file-list=filename,...  Do not instrument functions listed in files."
 msgstr ""
 
-#: common.opt:1668
+#: common.opt:1672
 msgid "Perform interprocedural constant propagation."
 msgstr ""
 
-#: common.opt:1672
+#: common.opt:1676
 msgid "Perform cloning to make Interprocedural constant propagation stronger."
 msgstr ""
 
-#: common.opt:1680
+#: common.opt:1684
 msgid "Perform interprocedural bitwise constant propagation."
 msgstr ""
 
-#: common.opt:1684
+#: common.opt:1688
 msgid "Perform interprocedural profile propagation."
 msgstr ""
 
-#: common.opt:1688
+#: common.opt:1692
 msgid "Perform interprocedural points-to analysis."
 msgstr ""
 
-#: common.opt:1692
+#: common.opt:1696
 msgid "Discover pure and const functions."
 msgstr ""
 
-#: common.opt:1696
+#: common.opt:1700
 msgid "Perform Identical Code Folding for functions and read-only variables."
 msgstr ""
 
-#: common.opt:1700
+#: common.opt:1704
 msgid "Perform Identical Code Folding for functions."
 msgstr ""
 
-#: common.opt:1704
+#: common.opt:1708
 msgid "Perform Identical Code Folding for variables."
 msgstr ""
 
-#: common.opt:1708
+#: common.opt:1712
 msgid "Discover readonly and non addressable static variables."
 msgstr ""
 
-#: common.opt:1720
+#: common.opt:1724
 msgid "Perform IPA Value Range Propagation."
 msgstr ""
 
-#: common.opt:1724
+#: common.opt:1728
 #, fuzzy
 #| msgid "-fira-algorithm=[CB|priority] Set the used IRA algorithm."
 msgid "-fira-algorithm=[CB|priority]\tSet the used IRA algorithm."
 msgstr "-fira-algorithm=[CB|priority] Đặt dùng thuật toán IRA."
 
-#: common.opt:1727
+#: common.opt:1731
 #, c-format
 msgid "unknown IRA algorithm %qs"
 msgstr "không hiểu thuật toán IRA %qs"
 
-#: common.opt:1737
+#: common.opt:1741
 #, fuzzy
 #| msgid "-fira-region=[one|all|mixed] Set regions for IRA."
 msgid "-fira-region=[one|all|mixed]\tSet regions for IRA."
 msgstr "-fira-region=[one|all|mixed] Đặt vùng cho IRA."
 
-#: common.opt:1740
+#: common.opt:1744
 #, c-format
 msgid "unknown IRA region %qs"
 msgstr "không hiểu vùng IRA %qs"
 
-#: common.opt:1753
+#: common.opt:1757
 msgid "Use IRA based register pressure calculation in RTL hoist optimizations."
 msgstr ""
 
-#: common.opt:1758
+#: common.opt:1762
 msgid "Use IRA based register pressure calculation in RTL loop optimizations."
 msgstr ""
 
-#: common.opt:1763
+#: common.opt:1767
 msgid "Share slots for saving different hard registers."
 msgstr ""
 
-#: common.opt:1767
+#: common.opt:1771
 msgid "Share stack slots for spilled pseudo-registers."
 msgstr ""
 
-#: common.opt:1771
+#: common.opt:1775
 msgid "-fira-verbose=<number>\tControl IRA's level of diagnostic messages."
 msgstr ""
 
-#: common.opt:1775
+#: common.opt:1779
 msgid "Optimize induction variables on trees."
 msgstr ""
 
-#: common.opt:1779
+#: common.opt:1783
 msgid "Use jump tables for sufficiently large switch statements."
 msgstr ""
 
-#: common.opt:1783
+#: common.opt:1787
 msgid "Generate code for functions even if they are fully inlined."
 msgstr "Xuất hàm ngay cả khi chúng có thể chung dòng."
 
-#: common.opt:1787
+#: common.opt:1791
 msgid "Generate code for static functions even if they are never called."
 msgstr "Xuất mã cho hàm tĩnh ngay cả khi chúng không bao giờ được gọi."
 
-#: common.opt:1791
+#: common.opt:1795
 msgid "Emit static const variables even if they are not used."
 msgstr ""
 
-#: common.opt:1795
+#: common.opt:1799
 msgid "Give external symbols a leading underscore."
 msgstr ""
 
-#: common.opt:1803
+#: common.opt:1807
 msgid "Do CFG-sensitive rematerialization in LRA."
 msgstr ""
 
-#: common.opt:1807
+#: common.opt:1811
 msgid "Enable link-time optimization."
 msgstr ""
 
-#: common.opt:1811
+#: common.opt:1815
 msgid "Link-time optimization with number of parallel jobs or jobserver."
 msgstr ""
 
-#: common.opt:1814
+#: common.opt:1818
 #, c-format
 msgid "unknown LTO partitioning model %qs"
 msgstr "không hiểu mô hình phân vùng TLS %qs"
 
-#: common.opt:1833
+#: common.opt:1837
 msgid "Specify the algorithm to partition symbols and vars at linktime."
 msgstr ""
 
-#: common.opt:1838
+#: common.opt:1842
 msgid "-flto-compression-level=<number>\tUse zlib compression level <number> for IL."
 msgstr "-flto-compression-level=<số>\tDùng mức nén zlib <số> cho IL."
 
-#: common.opt:1842
+#: common.opt:1846
 msgid "Merge C++ types using One Definition Rule."
 msgstr ""
 
-#: common.opt:1846
+#: common.opt:1850
 msgid "Report various link-time optimization statistics."
 msgstr ""
 
-#: common.opt:1850
+#: common.opt:1854
 msgid "Report various link-time optimization statistics for WPA only."
 msgstr ""
 
-#: common.opt:1854
+#: common.opt:1858
 msgid "Set errno after built-in math functions."
 msgstr ""
 
-#: common.opt:1858
+#: common.opt:1862
 msgid "-fmax-errors=<number>\tMaximum number of errors to report."
 msgstr "-fmax-errors=<số>\tSố lượng tối đa các lỗi cần thông báo."
 
-#: common.opt:1862
+#: common.opt:1866
 msgid "Report on permanent memory allocation."
 msgstr ""
 
-#: common.opt:1866
+#: common.opt:1870
 msgid "Report on permanent memory allocation in WPA only."
 msgstr ""
 
-#: common.opt:1873
+#: common.opt:1877
 msgid "Attempt to merge identical constants and constant variables."
 msgstr ""
 
-#: common.opt:1877
+#: common.opt:1881
 msgid "Attempt to merge identical constants across compilation units."
 msgstr ""
 
-#: common.opt:1881
+#: common.opt:1885
 msgid "Attempt to merge identical debug strings across compilation units."
 msgstr ""
 
-#: common.opt:1885
+#: common.opt:1889
 msgid "-fmessage-length=<number>\tLimit diagnostics to <number> characters per line.  0 suppresses line-wrapping."
 msgstr ""
 
-#: common.opt:1889
+#: common.opt:1893
 msgid "Perform SMS based modulo scheduling before the first scheduling pass."
 msgstr ""
 
-#: common.opt:1893
+#: common.opt:1897
 msgid "Perform SMS based modulo scheduling with register moves allowed."
 msgstr ""
 
-#: common.opt:1897
+#: common.opt:1901
 msgid "Move loop invariant computations out of loops."
 msgstr ""
 
-#: common.opt:1901
+#: common.opt:1905
 msgid "Use the RTL dead code elimination pass."
 msgstr ""
 
-#: common.opt:1905
+#: common.opt:1909
 msgid "Use the RTL dead store elimination pass."
 msgstr ""
 
-#: common.opt:1909
+#: common.opt:1913
 msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling."
 msgstr ""
 
-#: common.opt:1913
+#: common.opt:1917
 msgid "Support synchronous non-call exceptions."
 msgstr ""
 
-#: common.opt:1916
+#: common.opt:1920
 #, c-format
 msgid "options or targets missing after %qs"
 msgstr "thiếu tùy chọn hay đích sau %qs"
 
-#: common.opt:1917
+#: common.opt:1921
 msgid "-foffload=<targets>=<options>  Specify offloading targets and options for them."
 msgstr ""
 
-#: common.opt:1921
+#: common.opt:1925
 msgid "-foffload-abi=[lp64|ilp32]     Set the ABI to use in an offload compiler."
 msgstr ""
 
-#: common.opt:1924
+#: common.opt:1928
 #, c-format
 msgid "unknown offload ABI %qs"
 msgstr "không hiểu ABI offload %qs"
 
-#: common.opt:1934
+#: common.opt:1938
 msgid "When possible do not generate stack frames."
 msgstr ""
 
-#: common.opt:1938
+#: common.opt:1942
 msgid "Enable all optimization info dumps on stderr."
 msgstr ""
 
-#: common.opt:1942
+#: common.opt:1946
 msgid "-fopt-info[-<type>=filename]\tDump compiler optimization details."
 msgstr "-fopt-info[-<type>=tập-tin]\tĐổ chi tiết việc tối ưu hóa bộ dịch."
 
-#: common.opt:1950
+#: common.opt:1954
 msgid "Optimize sibling and tail recursive calls."
 msgstr ""
 
-#: common.opt:1954
+#: common.opt:1958
 msgid "Perform partial inlining."
 msgstr ""
 
-#: common.opt:1958 common.opt:1962
+#: common.opt:1962 common.opt:1966
 msgid "Report on memory allocation before interprocedural optimization."
 msgstr ""
 
-#: common.opt:1966
+#: common.opt:1970
 msgid "Pack structure members together without holes."
 msgstr ""
 
-#: common.opt:1970
+#: common.opt:1974
 msgid "-fpack-struct=<number>\tSet initial maximum structure member alignment."
 msgstr ""
 
-#: common.opt:1974
+#: common.opt:1978
 msgid "Return small aggregates in memory, not registers."
 msgstr ""
 
-#: common.opt:1978
+#: common.opt:1982
 msgid "Perform loop peeling."
 msgstr ""
 
-#: common.opt:1982
+#: common.opt:1986
 msgid "Enable machine specific peephole optimizations."
 msgstr ""
 
-#: common.opt:1986
+#: common.opt:1990
 msgid "Enable an RTL peephole pass before sched2."
 msgstr ""
 
-#: common.opt:1990
+#: common.opt:1994
 msgid "Generate position-independent code if possible (large mode)."
 msgstr ""
 
-#: common.opt:1994
+#: common.opt:1998
 msgid "Generate position-independent code for executables if possible (large mode)."
 msgstr ""
 
-#: common.opt:1998
+#: common.opt:2002
 msgid "Generate position-independent code if possible (small mode)."
 msgstr ""
 
-#: common.opt:2002
+#: common.opt:2006
 msgid "Generate position-independent code for executables if possible (small mode)."
 msgstr ""
 
-#: common.opt:2006
+#: common.opt:2010
 msgid "Use PLT for PIC calls (-fno-plt: load the address from GOT at call site)."
 msgstr ""
 
-#: common.opt:2010
+#: common.opt:2014
 msgid "Specify a plugin to load."
 msgstr "Chỉ định phần bổ sung cần nạp."
 
-#: common.opt:2014
+#: common.opt:2018
 msgid "-fplugin-arg-<name>-<key>[=<value>]\tSpecify argument <key>=<value> for plugin <name>."
 msgstr "-fplugin-arg-<tên>-<khóa>[=<giá trị>]\tChỉ định đối số <khóa>=<giá trị> cho plugin <tên>."
 
-#: common.opt:2018
+#: common.opt:2022
 msgid "Run predictive commoning optimization."
 msgstr ""
 
-#: common.opt:2022
+#: common.opt:2026
 msgid "Generate prefetch instructions, if available, for arrays in loops."
 msgstr ""
 
-#: common.opt:2026
+#: common.opt:2030
 msgid "Enable basic program profiling code."
 msgstr ""
 
-#: common.opt:2030
+#: common.opt:2034
 #, fuzzy
 #| msgid "Generate string instructions for block moves."
 msgid "Generate absolute source path names for gcov."
 msgstr "Tạo ra câu lệnh chuỗi để di chuyển khối."
 
-#: common.opt:2034
+#: common.opt:2038
 msgid "Insert arc-based program profiling code."
 msgstr ""
 
-#: common.opt:2038
+#: common.opt:2042
 msgid "Set the top-level directory for storing the profile data. The default is 'pwd'."
 msgstr ""
 
-#: common.opt:2043
+#: common.opt:2047
 msgid "Enable correction of flow inconsistent profile data input."
 msgstr ""
 
-#: common.opt:2047
+#: common.opt:2051
 msgid "-fprofile-update=[single|atomic|prefer-atomic]\tSet the profile update method."
 msgstr ""
 
-#: common.opt:2050
+#: common.opt:2054
 #, fuzzy, c-format
 msgid "unknown profile update method %qs"
 msgstr "không hiểu mô hình kích thước con trỏ %qs"
 
-#: common.opt:2063
+#: common.opt:2067
 msgid "Enable common options for generating profile info for profile feedback directed optimizations."
 msgstr ""
 
-#: common.opt:2067
+#: common.opt:2071
 msgid "Enable common options for generating profile info for profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr ""
 
-#: common.opt:2071
+#: common.opt:2075
 msgid "Enable common options for performing profile feedback directed optimizations."
 msgstr ""
 
-#: common.opt:2075
+#: common.opt:2079
 msgid "Enable common options for performing profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr ""
 
-#: common.opt:2079
+#: common.opt:2083
 msgid "Insert code to profile values of expressions."
 msgstr ""
 
-#: common.opt:2083
+#: common.opt:2087
 msgid "Report on consistency of profile."
 msgstr ""
 
-#: common.opt:2087
+#: common.opt:2091
 msgid "Enable function reordering that improves code placement."
 msgstr ""
 
-#: common.opt:2091
+#: common.opt:2095
 #, fuzzy
 #| msgid "Generate cld instruction in the function prologue."
 msgid "Insert NOP instructions at each function entry."
 msgstr "Tạo ra câu lệnh cld trong đoạn mở đầu hàm."
 
-#: common.opt:2098
+#: common.opt:2102
 msgid "-frandom-seed=<string>\tMake compile reproducible using <string>."
 msgstr ""
 
-#: common.opt:2108
+#: common.opt:2112
 msgid "Record gcc command line switches in the object file."
 msgstr ""
 
-#: common.opt:2112
+#: common.opt:2116
 msgid "Return small aggregates in registers."
 msgstr ""
 
-#: common.opt:2120
+#: common.opt:2124
 msgid "Tell DSE that the storage for a C++ object is dead when the constructor starts and when the destructor finishes."
 msgstr ""
 
-#: common.opt:2128
+#: common.opt:2132
 msgid "Relief of register pressure through live range shrinkage."
 msgstr ""
 
-#: common.opt:2132
+#: common.opt:2136
 msgid "Perform a register renaming optimization pass."
 msgstr ""
 
-#: common.opt:2136
+#: common.opt:2140
 msgid "Perform a target dependent instruction fusion optimization pass."
 msgstr ""
 
-#: common.opt:2140
+#: common.opt:2144
 msgid "Reorder basic blocks to improve code placement."
 msgstr ""
 
-#: common.opt:2144
+#: common.opt:2148
 msgid "-freorder-blocks-algorithm=[simple|stc]\tSet the used basic block reordering algorithm."
 msgstr ""
 
-#: common.opt:2147
+#: common.opt:2151
 #, c-format
 msgid "unknown basic block reordering algorithm %qs"
 msgstr "không hiểu thuật toán xếp lại khối cơ bản %qs"
 
-#: common.opt:2157
+#: common.opt:2161
 msgid "Reorder basic blocks and partition into hot and cold sections."
 msgstr ""
 
-#: common.opt:2161
+#: common.opt:2165
 msgid "Reorder functions to improve code placement."
 msgstr ""
 
-#: common.opt:2165
+#: common.opt:2169
 msgid "Add a common subexpression elimination pass after loop optimizations."
 msgstr ""
 
-#: common.opt:2173
+#: common.opt:2177
 msgid "Disable optimizations that assume default FP rounding behavior."
 msgstr ""
 
-#: common.opt:2177
+#: common.opt:2181
 msgid "Enable scheduling across basic blocks."
 msgstr ""
 
-#: common.opt:2181
+#: common.opt:2185
 msgid "Enable register pressure sensitive insn scheduling."
 msgstr ""
 
-#: common.opt:2185
+#: common.opt:2189
 msgid "Allow speculative motion of non-loads."
 msgstr ""
 
-#: common.opt:2189
+#: common.opt:2193
 msgid "Allow speculative motion of some loads."
 msgstr ""
 
-#: common.opt:2193
+#: common.opt:2197
 msgid "Allow speculative motion of more loads."
 msgstr ""
 
-#: common.opt:2197
+#: common.opt:2201
 msgid "-fsched-verbose=<number>\tSet the verbosity level of the scheduler."
 msgstr ""
 
-#: common.opt:2201
+#: common.opt:2205
 msgid "If scheduling post reload, do superblock scheduling."
 msgstr ""
 
-#: common.opt:2209
+#: common.opt:2213
 msgid "Reschedule instructions before register allocation."
 msgstr ""
 
-#: common.opt:2213
+#: common.opt:2217
 msgid "Reschedule instructions after register allocation."
 msgstr ""
 
-#: common.opt:2220
+#: common.opt:2224
 msgid "Schedule instructions using selective scheduling algorithm."
 msgstr ""
 
-#: common.opt:2224
+#: common.opt:2228
 msgid "Run selective scheduling after reload."
 msgstr ""
 
-#: common.opt:2228
+#: common.opt:2232
 msgid "Run self-tests, using the given path to locate test files."
 msgstr ""
 
-#: common.opt:2232
+#: common.opt:2236
 msgid "Perform software pipelining of inner loops during selective scheduling."
 msgstr ""
 
-#: common.opt:2236
+#: common.opt:2240
 msgid "Perform software pipelining of outer loops during selective scheduling."
 msgstr ""
 
-#: common.opt:2240
+#: common.opt:2244
 msgid "Reschedule pipelined regions without pipelining."
 msgstr ""
 
-#: common.opt:2244
+#: common.opt:2248
 msgid "Allow interposing function (or variables) by ones with different semantics (or initializer) respectively by dynamic linker."
 msgstr ""
 
-#: common.opt:2250
+#: common.opt:2254
 msgid "Allow premature scheduling of queued insns."
 msgstr ""
 
-#: common.opt:2254
+#: common.opt:2258
 msgid "-fsched-stalled-insns=<number>\tSet number of queued insns that can be prematurely scheduled."
 msgstr ""
 
-#: common.opt:2262
+#: common.opt:2266
 msgid "Set dependence distance checking in premature scheduling of queued insns."
 msgstr ""
 
-#: common.opt:2266
+#: common.opt:2270
 msgid "-fsched-stalled-insns-dep=<number>\tSet dependence distance checking in premature scheduling of queued insns."
 msgstr ""
 
-#: common.opt:2270
+#: common.opt:2274
 msgid "Enable the group heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2274
+#: common.opt:2278
 msgid "Enable the critical path heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2278
+#: common.opt:2282
 msgid "Enable the speculative instruction heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2282
+#: common.opt:2286
 msgid "Enable the rank heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2286
+#: common.opt:2290
 msgid "Enable the last instruction heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2290
+#: common.opt:2294
 msgid "Enable the dependent count heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2294
+#: common.opt:2298
 msgid "Access data in the same section from shared anchor points."
 msgstr ""
 
-#: common.opt:2306
+#: common.opt:2310
 msgid "Turn on Redundant Extensions Elimination pass."
 msgstr ""
 
-#: common.opt:2310
+#: common.opt:2314
 msgid "Show column numbers in diagnostics, when available.  Default on."
 msgstr ""
 
-#: common.opt:2314
+#: common.opt:2318
 msgid "Emit function prologues only before parts of the function that need it, rather than at the top of the function."
 msgstr ""
 
-#: common.opt:2319
+#: common.opt:2323
 msgid "Shrink-wrap parts of the prologue and epilogue separately."
 msgstr ""
 
-#: common.opt:2323
+#: common.opt:2327
 msgid "Disable optimizations observable by IEEE signaling NaNs."
 msgstr ""
 
-#: common.opt:2327
+#: common.opt:2331
 msgid "Disable floating point optimizations that ignore the IEEE signedness of zero."
 msgstr ""
 
-#: common.opt:2331
+#: common.opt:2335
 msgid "Convert floating point constants to single precision constants."
 msgstr ""
 
-#: common.opt:2335
+#: common.opt:2339
 msgid "Split lifetimes of induction variables when loops are unrolled."
 msgstr ""
 
-#: common.opt:2339
+#: common.opt:2343
 msgid "Generate discontiguous stack frames."
 msgstr "Tạo ra các khung ngăn xếp không liên tiếp."
 
-#: common.opt:2343
+#: common.opt:2347
 msgid "Split wide types into independent registers."
 msgstr ""
 
-#: common.opt:2347
+#: common.opt:2351
 msgid "Enable backward propagation of use properties at the SSA level."
 msgstr ""
 
-#: common.opt:2351
+#: common.opt:2355
 msgid "Optimize conditional patterns using SSA PHI nodes."
 msgstr ""
 
-#: common.opt:2355
+#: common.opt:2359
 msgid "Optimize amount of stdarg registers saved to stack at start of function."
 msgstr ""
 
-#: common.opt:2359
+#: common.opt:2363
 msgid "Apply variable expansion when loops are unrolled."
 msgstr ""
 
-#: common.opt:2363
+#: common.opt:2367
 msgid "-fstack-check=[no|generic|specific]\tInsert stack checking code into the program."
 msgstr "-fstack-check=[no|generic|specific]\t Chèn mã kiểm tra ngăn xếp vào chương trình."
 
-#: common.opt:2367
+#: common.opt:2371
 msgid "Insert stack checking code into the program.  Same as -fstack-check=specific."
 msgstr "Chèn mã kiểm tra ngăn xếp vào chương trình. Giống với -fstack-check=specific."
 
-#: common.opt:2371
+#: common.opt:2375
 msgid "Insert code to probe each page of stack space as it is allocated to protect from stack-clash style attacks."
 msgstr ""
 
-#: common.opt:2379
+#: common.opt:2383
 msgid "-fstack-limit-register=<register>\tTrap if the stack goes past <register>."
 msgstr "-fstack-limit-register=<register>\tBẫy nếu ngăn xếp đi qua <register>."
 
-#: common.opt:2383
+#: common.opt:2387
 msgid "-fstack-limit-symbol=<name>\tTrap if the stack goes past symbol <name>."
 msgstr "-fstack-limit-symbol=<tên>\tBẫy nếu ngăn xếp đi qua ký hiệu <tên>."
 
-#: common.opt:2387
+#: common.opt:2391
 msgid "Use propolice as a stack protection method."
 msgstr "Bật chức năng bảo vệ ngăn xếp asan."
 
-#: common.opt:2391
+#: common.opt:2395
 msgid "Use a stack protection method for every function."
 msgstr ""
 
-#: common.opt:2395
+#: common.opt:2399
 msgid "Use a smart stack protection method for certain functions."
 msgstr ""
 
-#: common.opt:2399
+#: common.opt:2403
 msgid "Use stack protection method only for functions with the stack_protect attribute."
 msgstr ""
 
-#: common.opt:2403
+#: common.opt:2407
 msgid "Output stack usage information on a per-function basis."
 msgstr ""
 
-#: common.opt:2415
+#: common.opt:2419
 msgid "Assume strict aliasing rules apply."
 msgstr ""
 
-#: common.opt:2419
+#: common.opt:2423
 msgid "Treat signed overflow as undefined.  Negated as -fwrapv -fwrapv-pointer."
 msgstr ""
 
-#: common.opt:2423
+#: common.opt:2427
 msgid "Implement __atomic operations via libcalls to legacy __sync functions."
 msgstr ""
 
-#: common.opt:2427
+#: common.opt:2431
 msgid "Check for syntax errors, then stop."
 msgstr "Kiểm tra lỗi cú pháp, sau đó dừng lại."
 
-#: common.opt:2431
+#: common.opt:2435
 msgid "Create data files needed by \"gcov\"."
 msgstr "Tạo tập tin dữ liệu cần bởi \"gcov\"."
 
-#: common.opt:2435
+#: common.opt:2439
 msgid "Perform jump threading optimizations."
 msgstr ""
 
-#: common.opt:2439
+#: common.opt:2443
 msgid "Report the time taken by each compiler pass."
 msgstr ""
 
-#: common.opt:2443
+#: common.opt:2447
 msgid "Record times taken by sub-phases separately."
 msgstr ""
 
-#: common.opt:2447
+#: common.opt:2451
 msgid "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tSet the default thread-local storage code generation model."
 msgstr ""
 
-#: common.opt:2450
+#: common.opt:2454
 #, c-format
 msgid "unknown TLS model %qs"
 msgstr "không hiểu mô hình TLS %qs"
 
-#: common.opt:2466
+#: common.opt:2470
 msgid "Reorder top level functions, variables, and asms."
 msgstr ""
 
-#: common.opt:2470
+#: common.opt:2474
 msgid "Perform superblock formation via tail duplication."
 msgstr ""
 
-#: common.opt:2474
+#: common.opt:2478
 msgid "For targets that normally need trampolines for nested functions, always generate them instead of using descriptors."
 msgstr ""
 
-#: common.opt:2482
+#: common.opt:2486
 msgid "Assume floating-point operations can trap."
 msgstr ""
 
-#: common.opt:2486
+#: common.opt:2490
 msgid "Trap for signed overflow in addition, subtraction and multiplication."
 msgstr ""
 
-#: common.opt:2490
+#: common.opt:2494
 msgid "Enable SSA-CCP optimization on trees."
 msgstr ""
 
-#: common.opt:2494
+#: common.opt:2498
 msgid "Enable SSA-BIT-CCP optimization on trees."
 msgstr ""
 
-#: common.opt:2502
+#: common.opt:2506
 msgid "Enable loop header copying on trees."
 msgstr ""
 
-#: common.opt:2510
+#: common.opt:2514
 msgid "Enable SSA coalescing of user variables."
 msgstr ""
 
-#: common.opt:2518
+#: common.opt:2522
 msgid "Enable copy propagation on trees."
 msgstr ""
 
-#: common.opt:2526
+#: common.opt:2530
 msgid "Transform condition stores into unconditional ones."
 msgstr ""
 
-#: common.opt:2530
+#: common.opt:2534
 msgid "Perform conversions of switch initializations."
 msgstr ""
 
-#: common.opt:2534
+#: common.opt:2538
 msgid "Enable SSA dead code elimination optimization on trees."
 msgstr ""
 
-#: common.opt:2538
+#: common.opt:2542
 msgid "Enable dominator optimizations."
 msgstr ""
 
-#: common.opt:2542
+#: common.opt:2546
 msgid "Enable tail merging on trees."
 msgstr ""
 
-#: common.opt:2546
+#: common.opt:2550
 msgid "Enable dead store elimination."
 msgstr ""
 
-#: common.opt:2550
+#: common.opt:2554
 msgid "Enable forward propagation on trees."
 msgstr ""
 
-#: common.opt:2554
+#: common.opt:2558
 msgid "Enable Full Redundancy Elimination (FRE) on trees."
 msgstr ""
 
-#: common.opt:2558
+#: common.opt:2562
 msgid "Enable string length optimizations on trees."
 msgstr ""
 
-#: common.opt:2562
+#: common.opt:2566
 msgid "Detect paths that trigger erroneous or undefined behavior due to dereferencing a null pointer.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
-#: common.opt:2568
+#: common.opt:2572
 msgid "Detect paths that trigger erroneous or undefined behavior due to a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
-#: common.opt:2575
+#: common.opt:2579
 msgid "Enable loop distribution on trees."
 msgstr ""
 
-#: common.opt:2579
+#: common.opt:2583
 msgid "Enable loop distribution for patterns transformed into a library call."
 msgstr ""
 
-#: common.opt:2583
+#: common.opt:2587
 msgid "Enable loop invariant motion on trees."
 msgstr ""
 
-#: common.opt:2591
+#: common.opt:2595
 msgid "Create canonical induction variables in loops."
 msgstr ""
 
-#: common.opt:2595
+#: common.opt:2599
 msgid "Enable loop optimizations on tree level."
 msgstr ""
 
-#: common.opt:2599
+#: common.opt:2603
 msgid "-ftree-parallelize-loops=<number>\tEnable automatic parallelization of loops."
 msgstr ""
 
-#: common.opt:2603
+#: common.opt:2607
 msgid "Enable hoisting loads from conditional pointers."
 msgstr ""
 
-#: common.opt:2607
+#: common.opt:2611
 msgid "Enable SSA-PRE optimization on trees."
 msgstr ""
 
-#: common.opt:2611
+#: common.opt:2615
 msgid "In SSA-PRE optimization on trees, enable partial-partial redundancy elimination."
 msgstr ""
 
-#: common.opt:2615
+#: common.opt:2619
 msgid "Perform function-local points-to analysis on trees."
 msgstr ""
 
-#: common.opt:2619
+#: common.opt:2623
 msgid "Enable reassociation on tree level."
 msgstr ""
 
-#: common.opt:2627
+#: common.opt:2631
 msgid "Enable SSA code sinking on trees."
 msgstr ""
 
-#: common.opt:2631
+#: common.opt:2635
 msgid "Perform straight-line strength reduction."
 msgstr ""
 
-#: common.opt:2635
+#: common.opt:2639
 msgid "Perform scalar replacement of aggregates."
 msgstr ""
 
-#: common.opt:2639
+#: common.opt:2643
 msgid "Replace temporary expressions in the SSA->normal pass."
 msgstr ""
 
-#: common.opt:2643
+#: common.opt:2647
 msgid "Perform live range splitting during the SSA->normal pass."
 msgstr ""
 
-#: common.opt:2647
+#: common.opt:2651
 msgid "Perform Value Range Propagation on trees."
 msgstr ""
 
-#: common.opt:2651
+#: common.opt:2655
 msgid "Split paths leading to loop backedges."
 msgstr ""
 
-#: common.opt:2655
+#: common.opt:2659
 msgid "Assume common declarations may be overridden with ones with a larger trailing array."
 msgstr ""
 
-#: common.opt:2660
+#: common.opt:2664
 msgid "Compile whole compilation unit at a time."
 msgstr ""
 
-#: common.opt:2664
+#: common.opt:2668
 msgid "Perform loop unrolling when iteration count is known."
 msgstr ""
 
-#: common.opt:2668
+#: common.opt:2672
 msgid "Perform loop unrolling for all loops."
 msgstr ""
 
-#: common.opt:2679
+#: common.opt:2683
 msgid "Allow optimization for floating-point arithmetic which may change the result of the operation due to rounding."
 msgstr ""
 
-#: common.opt:2684
+#: common.opt:2688
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr ""
 
-#: common.opt:2692
+#: common.opt:2696
 msgid "Allow math optimizations that may violate IEEE or ISO standards."
 msgstr ""
 
-#: common.opt:2696
+#: common.opt:2700
 msgid "Perform loop unswitching."
 msgstr ""
 
-#: common.opt:2700
+#: common.opt:2704
 msgid "Perform loop splitting."
 msgstr ""
 
-#: common.opt:2704
+#: common.opt:2708
 msgid "Just generate unwind tables for exception handling."
 msgstr ""
 
-#: common.opt:2708
+#: common.opt:2712
 msgid "Use the bfd linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2712
+#: common.opt:2716
 msgid "Use the gold linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2724
+#: common.opt:2728
 msgid "Perform variable tracking."
 msgstr ""
 
-#: common.opt:2732
+#: common.opt:2736
 msgid "Perform variable tracking by annotating assignments."
 msgstr ""
 
-#: common.opt:2738
+#: common.opt:2742
 msgid "Toggle -fvar-tracking-assignments."
 msgstr ""
 
-#: common.opt:2746
+#: common.opt:2750
 msgid "Perform variable tracking and also tag variables that are uninitialized."
 msgstr ""
 
-#: common.opt:2751
+#: common.opt:2755
 msgid "Enable vectorization on trees."
 msgstr ""
 
-#: common.opt:2759
+#: common.opt:2763
 msgid "Enable loop vectorization on trees."
 msgstr ""
 
-#: common.opt:2763
+#: common.opt:2767
 msgid "Enable basic block vectorization (SLP) on trees."
 msgstr ""
 
-#: common.opt:2767
+#: common.opt:2771
 msgid "Specifies the cost model for vectorization. -fvect-cost-model=[unlimited|dynamic|cheap]\tSpecifies the cost model for vectorization."
 msgstr ""
 
-#: common.opt:2772
+#: common.opt:2776
 msgid "-fsimd-cost-model=[unlimited|dynamic|cheap]\tSpecifies the vectorization cost model for code marked with a simd directive."
 msgstr ""
 
-#: common.opt:2775
+#: common.opt:2779
 #, c-format
 msgid "unknown vectorizer cost model %qs"
 msgstr ""
 
-#: common.opt:2788
+#: common.opt:2792
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr ""
 
-#: common.opt:2796
+#: common.opt:2800
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr ""
 
-#: common.opt:2806
+#: common.opt:2810
 msgid "Add extra commentary to assembler output."
 msgstr ""
 
-#: common.opt:2810
+#: common.opt:2814
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility."
 msgstr ""
 
-#: common.opt:2813
+#: common.opt:2817
 #, c-format
 msgid "unrecognized visibility value %qs"
 msgstr ""
 
-#: common.opt:2829
+#: common.opt:2833
 msgid "Validate vtable pointers before using them."
 msgstr ""
 
-#: common.opt:2832
+#: common.opt:2836
 #, c-format
 msgid "unknown vtable verify initialization priority %qs"
 msgstr ""
 
-#: common.opt:2845
+#: common.opt:2849
 msgid "Output vtable verification counters."
 msgstr ""
 
-#: common.opt:2849
+#: common.opt:2853
 msgid "Output vtable verification pointer sets information."
 msgstr ""
 
-#: common.opt:2853
+#: common.opt:2857
 msgid "Use expression value profiles in optimizations."
 msgstr ""
 
-#: common.opt:2857
+#: common.opt:2861
 msgid "Construct webs and split unrelated uses of single variable."
 msgstr ""
 
-#: common.opt:2861
+#: common.opt:2865
 msgid "Enable conditional dead code elimination for builtin calls."
 msgstr ""
 
-#: common.opt:2865
+#: common.opt:2869
 msgid "Perform whole program optimizations."
 msgstr ""
 
-#: common.opt:2869
+#: common.opt:2873
 msgid "Assume pointer overflow wraps around."
 msgstr ""
 
-#: common.opt:2873
+#: common.opt:2877
 msgid "Assume signed arithmetic overflow wraps around."
 msgstr ""
 
-#: common.opt:2877
+#: common.opt:2881
 msgid "Put zero initialized data in the bss section."
 msgstr ""
 
-#: common.opt:2881
+#: common.opt:2885
 msgid "Generate debug information in default format."
 msgstr ""
 
-#: common.opt:2885
+#: common.opt:2889
 msgid "Assume assembler support for (DWARF2+) .loc directives"
 msgstr ""
 
-#: common.opt:2889
+#: common.opt:2893
 msgid "Assume assembler support for view in (DWARF2+) .loc directives"
 msgstr ""
 
-#: common.opt:2892 common.opt:2896 common.opt:2900 common.opt:2904
+#: common.opt:2896 common.opt:2900 common.opt:2904 common.opt:2908
 #, fuzzy, c-format
 #| msgid "switch %qs is no longer supported"
 msgid "switch %qs no longer supported"
 msgstr "switch %qs không còn tiếp tục được hỗ trợ nữa"
 
-#: common.opt:2909
+#: common.opt:2913
 msgid "Record DW_AT_decl_column and DW_AT_call_column in DWARF."
 msgstr ""
 
-#: common.opt:2913
+#: common.opt:2917
 msgid "Generate debug information in default version of DWARF format."
 msgstr ""
 
-#: common.opt:2917
+#: common.opt:2921
 msgid "Generate debug information in DWARF v2 (or later) format."
 msgstr ""
 
-#: common.opt:2921
+#: common.opt:2925
 msgid "Generate debug information in default extended format."
 msgstr ""
 
-#: common.opt:2925
+#: common.opt:2929
 #, fuzzy
 #| msgid "Generate a single exit point for each function."
 msgid "Generate extended entry point information for inlined functions"
 msgstr "Tạo ra một điểm ra khỏi riêng lẻ cho mỗi hàm."
 
-#: common.opt:2929
+#: common.opt:2933
 msgid "Compute locview reset points based on insn length estimates"
 msgstr ""
 
-#: common.opt:2937
+#: common.opt:2941
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:2941
+#: common.opt:2945
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:2945
+#: common.opt:2949
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr ""
 
-#: common.opt:2949
+#: common.opt:2953
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr ""
 
-#: common.opt:2953
+#: common.opt:2957
 msgid "Generate debug information in separate .dwo files."
 msgstr ""
 
-#: common.opt:2957
+#: common.opt:2961
 msgid "Generate debug information in STABS format."
 msgstr ""
 
-#: common.opt:2961
+#: common.opt:2965
 msgid "Generate debug information in extended STABS format."
 msgstr ""
 
-#: common.opt:2965
+#: common.opt:2969
 msgid "Emit progressive recommended breakpoint locations."
 msgstr ""
 
-#: common.opt:2969
+#: common.opt:2973
 msgid "Don't emit DWARF additions beyond selected version."
 msgstr ""
 
-#: common.opt:2973
+#: common.opt:2977
 msgid "Toggle debug information generation."
 msgstr ""
 
-#: common.opt:2977
+#: common.opt:2981
 msgid "Augment variable location lists with progressive views."
 msgstr ""
 
-#: common.opt:2984
+#: common.opt:2988
 msgid "Generate debug information in VMS format."
 msgstr ""
 
-#: common.opt:2988
+#: common.opt:2992
 msgid "Generate debug information in XCOFF format."
 msgstr ""
 
-#: common.opt:2992
+#: common.opt:2996
 msgid "Generate debug information in extended XCOFF format."
 msgstr ""
 
-#: common.opt:3010
+#: common.opt:3014
 msgid "Generate compressed debug sections."
 msgstr ""
 
-#: common.opt:3014
+#: common.opt:3018
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>."
 msgstr "-gz=<định dạng>\tTạo phần gỡ lỗi nén theo định dạng <định dạng>."
 
-#: common.opt:3021
+#: common.opt:3025
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory."
 msgstr "-iplugindir=<dir>\tĐặt <dir> cho thư mục phần bổ sung mặc định."
 
-#: common.opt:3025
+#: common.opt:3029
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory."
 msgstr "-imultiarch <dir>\tĐặt <dir> để cho thư mục con bao gồm đa kiến trúc."
 
-#: common.opt:3047
+#: common.opt:3051
 msgid "-o <file>\tPlace output into <file>."
 msgstr "-o <tập tin>\tĐặt kết xuất vào <tập tin>"
 
-#: common.opt:3051
+#: common.opt:3055
 msgid "Enable function profiling."
 msgstr ""
 
-#: common.opt:3061
+#: common.opt:3065
 msgid "Like -pedantic but issue them as errors."
 msgstr ""
 
-#: common.opt:3101
+#: common.opt:3105
 msgid "Do not display functions compiled or elapsed time."
 msgstr ""
 
-#: common.opt:3133
+#: common.opt:3137
 msgid "Enable verbose output."
 msgstr "Bật kết xuất chi tiết."
 
-#: common.opt:3137
+#: common.opt:3141
 msgid "Display the compiler's version."
 msgstr "Hiển thị thông tin về phiên bản của bộ biên dịch."
 
-#: common.opt:3141
+#: common.opt:3145
 msgid "Suppress warnings."
 msgstr "Thu hồi cảnh báo."
 
-#: common.opt:3151
+#: common.opt:3155
 msgid "Create a shared library."
 msgstr "Tạo thư viện dùng chung."
 
-#: common.opt:3196
+#: common.opt:3200
 #, fuzzy
 #| msgid "Don't create a position independent executable."
 msgid "Don't create a dynamically linked position independent executable."
 msgstr "Đừng tạo một bản thực hiện không phụ thuộc vào vị trí."
 
-#: common.opt:3200
+#: common.opt:3204
 #, fuzzy
 #| msgid "Create a position independent executable."
 msgid "Create a dynamically linked position independent executable."
 msgstr "Tạo một bản thực hiện không phụ thuộc vào vị trí."
 
-#: common.opt:3204
+#: common.opt:3208
 #, fuzzy
 #| msgid "Create a position independent executable."
 msgid "Create a static position independent executable."
 msgstr "Tạo một bản thực hiện không phụ thuộc vào vị trí."
 
-#: common.opt:3211
+#: common.opt:3215
 msgid "Use caller save register across calls if possible."
 msgstr ""
 
-#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:598 cp/cvt.c:1308
+#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:599 cp/cvt.c:1308
 #: cp/cvt.c:1561
 #, gcc-internal-format
 msgid "value computed is not used"
@@ -15988,7 +15990,7 @@
 msgstr "cần kiểu boolean"
 
 #: go/gofrontend/expressions.cc:4331 c/c-parser.c:13477 c/c-parser.c:13484
-#: cp/parser.c:33264 cp/parser.c:33271
+#: cp/parser.c:33261 cp/parser.c:33268
 #, gcc-internal-format
 msgid "expected integer"
 msgstr "Mong đợi một số nguyên"
@@ -16408,14 +16410,14 @@
 msgid "ignoring attribute %qE because it conflicts with attribute %qs"
 msgstr "thuộc tính %s của %qs xung đột với thuộc tính %s tại %L"
 
-#: attribs.c:449 c-family/c-attribs.c:1894 cp/decl.c:13690 cp/friend.c:302
-#: cp/tree.c:4559
+#: attribs.c:449 c-family/c-attribs.c:1905 cp/decl.c:13714 cp/friend.c:302
+#: cp/tree.c:4607
 #, gcc-internal-format
 msgid "previous declaration here"
 msgstr "khai báo trước ở đây"
 
 #. Warn about and ignore all others for now, but store them.
-#: attribs.c:564 c-family/c-attribs.c:2717 objc/objc-act.c:4963
+#: attribs.c:564 c-family/c-attribs.c:2728 objc/objc-act.c:4963
 #: objc/objc-act.c:6932 objc/objc-act.c:8119 objc/objc-act.c:8170
 #, gcc-internal-format
 msgid "%qE attribute directive ignored"
@@ -16434,17 +16436,17 @@
 #. This is a c++11 attribute that appertains to a
 #. type-specifier, outside of the definition of, a class
 #. type.  Ignore it.
-#: attribs.c:590 cp/decl.c:10999
+#: attribs.c:590 cp/decl.c:11023
 #, gcc-internal-format
 msgid "attribute ignored"
 msgstr "thuộc tính bị bỏ qua"
 
-#: attribs.c:592 cp/decl.c:11000
+#: attribs.c:592 cp/decl.c:11024
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
 
-#: attribs.c:610 c-family/c-attribs.c:3219
+#: attribs.c:610 c-family/c-attribs.c:3230
 #, gcc-internal-format
 msgid "%qE attribute does not apply to types"
 msgstr ""
@@ -16460,40 +16462,40 @@
 msgstr ""
 
 #: attribs.c:691 attribs.c:1622 attribs.c:1632 attribs.c:1642
-#: c-family/c-attribs.c:540 c-family/c-attribs.c:559 c-family/c-attribs.c:577
-#: c-family/c-attribs.c:607 c-family/c-attribs.c:628 c-family/c-attribs.c:649
-#: c-family/c-attribs.c:690 c-family/c-attribs.c:717 c-family/c-attribs.c:733
-#: c-family/c-attribs.c:750 c-family/c-attribs.c:766 c-family/c-attribs.c:792
-#: c-family/c-attribs.c:807 c-family/c-attribs.c:835 c-family/c-attribs.c:852
-#: c-family/c-attribs.c:870 c-family/c-attribs.c:893 c-family/c-attribs.c:931
-#: c-family/c-attribs.c:954 c-family/c-attribs.c:971 c-family/c-attribs.c:1000
-#: c-family/c-attribs.c:1021 c-family/c-attribs.c:1042
-#: c-family/c-attribs.c:1069 c-family/c-attribs.c:1099
-#: c-family/c-attribs.c:1136 c-family/c-attribs.c:1189
-#: c-family/c-attribs.c:1255 c-family/c-attribs.c:1313
-#: c-family/c-attribs.c:1402 c-family/c-attribs.c:1432
-#: c-family/c-attribs.c:1483 c-family/c-attribs.c:1998
-#: c-family/c-attribs.c:2035 c-family/c-attribs.c:2096
-#: c-family/c-attribs.c:2152 c-family/c-attribs.c:2230
-#: c-family/c-attribs.c:2312 c-family/c-attribs.c:2371
-#: c-family/c-attribs.c:2390 c-family/c-attribs.c:2498
-#: c-family/c-attribs.c:2514 c-family/c-attribs.c:2530
-#: c-family/c-attribs.c:2551 c-family/c-attribs.c:2608
-#: c-family/c-attribs.c:2635 c-family/c-attribs.c:2690
-#: c-family/c-attribs.c:2870 c-family/c-attribs.c:2891
-#: c-family/c-attribs.c:3004 c-family/c-attribs.c:3031
-#: c-family/c-attribs.c:3221 c-family/c-attribs.c:3239
-#: c-family/c-attribs.c:3262 c-family/c-attribs.c:3301
-#: c-family/c-attribs.c:3383 c-family/c-attribs.c:3439
-#: c-family/c-attribs.c:3455 c-family/c-attribs.c:3549
-#: c-family/c-common.c:5600 config/darwin.c:2072 config/arm/arm.c:6868
+#: c-family/c-attribs.c:547 c-family/c-attribs.c:566 c-family/c-attribs.c:584
+#: c-family/c-attribs.c:614 c-family/c-attribs.c:635 c-family/c-attribs.c:656
+#: c-family/c-attribs.c:697 c-family/c-attribs.c:728 c-family/c-attribs.c:744
+#: c-family/c-attribs.c:761 c-family/c-attribs.c:777 c-family/c-attribs.c:803
+#: c-family/c-attribs.c:818 c-family/c-attribs.c:846 c-family/c-attribs.c:863
+#: c-family/c-attribs.c:881 c-family/c-attribs.c:904 c-family/c-attribs.c:942
+#: c-family/c-attribs.c:965 c-family/c-attribs.c:982 c-family/c-attribs.c:1011
+#: c-family/c-attribs.c:1032 c-family/c-attribs.c:1053
+#: c-family/c-attribs.c:1080 c-family/c-attribs.c:1110
+#: c-family/c-attribs.c:1147 c-family/c-attribs.c:1200
+#: c-family/c-attribs.c:1266 c-family/c-attribs.c:1324
+#: c-family/c-attribs.c:1413 c-family/c-attribs.c:1443
+#: c-family/c-attribs.c:1494 c-family/c-attribs.c:2009
+#: c-family/c-attribs.c:2046 c-family/c-attribs.c:2107
+#: c-family/c-attribs.c:2163 c-family/c-attribs.c:2241
+#: c-family/c-attribs.c:2323 c-family/c-attribs.c:2382
+#: c-family/c-attribs.c:2401 c-family/c-attribs.c:2509
+#: c-family/c-attribs.c:2525 c-family/c-attribs.c:2541
+#: c-family/c-attribs.c:2562 c-family/c-attribs.c:2619
+#: c-family/c-attribs.c:2646 c-family/c-attribs.c:2701
+#: c-family/c-attribs.c:2881 c-family/c-attribs.c:2902
+#: c-family/c-attribs.c:3015 c-family/c-attribs.c:3042
+#: c-family/c-attribs.c:3232 c-family/c-attribs.c:3250
+#: c-family/c-attribs.c:3273 c-family/c-attribs.c:3312
+#: c-family/c-attribs.c:3394 c-family/c-attribs.c:3450
+#: c-family/c-attribs.c:3466 c-family/c-attribs.c:3560
+#: c-family/c-common.c:5598 config/darwin.c:2072 config/arm/arm.c:6868
 #: config/arm/arm.c:6896 config/arm/arm.c:6913 config/avr/avr.c:9698
-#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6497
-#: config/i386/i386.c:41520 config/ia64/ia64.c:788
-#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33056
-#: config/spu/spu.c:3743 ada/gcc-interface/utils.c:6244
-#: ada/gcc-interface/utils.c:6261 ada/gcc-interface/utils.c:6277
-#: ada/gcc-interface/utils.c:6303 brig/brig-lang.c:476 lto/lto-lang.c:283
+#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6500
+#: config/i386/i386.c:41514 config/ia64/ia64.c:788
+#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33112
+#: config/spu/spu.c:3743 ada/gcc-interface/utils.c:6249
+#: ada/gcc-interface/utils.c:6266 ada/gcc-interface/utils.c:6282
+#: ada/gcc-interface/utils.c:6308 brig/brig-lang.c:476 lto/lto-lang.c:283
 #, gcc-internal-format
 msgid "%qE attribute ignored"
 msgstr "thuộc tính %qE bị lờ đi"
@@ -16865,89 +16867,105 @@
 msgid "%Kattempt to free a non-heap object"
 msgstr ""
 
-#: calls.c:1434
+#: calls.c:1291 file-prefix-map.c:50
 #, fuzzy, gcc-internal-format
+#| msgid "invalid argument to %qD"
+msgid "invalid argument %qs to %qs"
+msgstr "đối số không hợp lệ cho %qD"
+
+#: calls.c:1452
+#, fuzzy, gcc-internal-format
 msgid "%Kargument %i value %qE is negative"
 msgstr "Đối số của hàm %s tại %L là âm"
 
-#: calls.c:1452
+#: calls.c:1470
 #, fuzzy, gcc-internal-format
 msgid "%Kargument %i value is zero"
 msgstr "Giá trị bước DO (làm) là số không"
 
-#: calls.c:1469
+#: calls.c:1487
 #, fuzzy, gcc-internal-format
 msgid "%Kargument %i value %qE exceeds maximum object size %E"
 msgstr "Đối số của hàm %s tại %L là âm"
 
-#: calls.c:1483
+#: calls.c:1501
 #, fuzzy, gcc-internal-format
 msgid "%Kargument %i range [%E, %E] is negative"
 msgstr "Đối số của hàm %s tại %L là âm"
 
-#: calls.c:1490
+#: calls.c:1508
 #, fuzzy, gcc-internal-format
 msgid "%Kargument %i range [%E, %E] exceeds maximum object size %E"
 msgstr "Đối số của hàm %s tại %L là âm"
 
-#: calls.c:1520
+#: calls.c:1538
 #, gcc-internal-format
 msgid "%Kproduct %<%E * %E%> of arguments %i and %i exceeds %<SIZE_MAX%>"
 msgstr ""
 
-#: calls.c:1526
+#: calls.c:1544
 #, gcc-internal-format
 msgid "%Kproduct %<%E * %E%> of arguments %i and %i exceeds maximum object size %E"
 msgstr ""
 
-#: calls.c:1537 calls.c:1540
+#: calls.c:1555 calls.c:1558
 #, fuzzy, gcc-internal-format
 msgid "argument %i in the range [%E, %E]"
 msgstr "đối số 3 phải nằm trong vùng 0…15"
 
-#: calls.c:1551
+#: calls.c:1569
 #, fuzzy, gcc-internal-format
 msgid "in a call to built-in allocation function %qD"
 msgstr "gọi hàm nội bộ"
 
-#: calls.c:1554
+#: calls.c:1572
 #, fuzzy, gcc-internal-format
 msgid "in a call to allocation function %qD declared here"
 msgstr "hàm chung dòng %q+D được khai báo yếu"
 
-#: calls.c:1711
+#: calls.c:1835
 #, gcc-internal-format
-msgid "%qD argument %i declared attribute %<nonstring%> is smaller than the specified bound %E"
+msgid "%qD argument %i declared attribute %<nonstring%> is smaller than the specified bound %wu"
 msgstr ""
 
-#: calls.c:1716
+#: calls.c:1841
+#, gcc-internal-format
+msgid "%qD argument %i declared attribute %<nonstring%> is smaller than the specified bound [%E, %E]"
+msgstr ""
+
+#: calls.c:1847
+#, gcc-internal-format
+msgid "%qD argument %i declared attribute %<nonstring%> may be smaller than the specified bound [%E, %E]"
+msgstr ""
+
+#: calls.c:1857
 #, fuzzy, gcc-internal-format
 #| msgid "%qD was not declared %<constexpr%>"
 msgid "%qD argument %i declared attribute %<nonstring%>"
 msgstr "%qD chưa được khai báo %<constexpr%>"
 
-#: calls.c:1721
+#: calls.c:1862
 #, fuzzy, gcc-internal-format
 #| msgid "routine %qD declared here"
 msgid "argument %qD declared here"
 msgstr "%qD được khai báo ở đây"
 
-#: calls.c:1735
+#: calls.c:1876
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot tail-call: %s"
 msgstr "[không tìm thấy %s]"
 
-#: calls.c:3365
+#: calls.c:3506
 #, gcc-internal-format
 msgid "function call has aggregate value"
 msgstr "cú gọi hàm có giá trị tập hợp"
 
-#: calls.c:4059
+#: calls.c:4200
 #, gcc-internal-format
 msgid "passing too large argument on stack"
 msgstr "chuyển đối số quá lớn cho ngăn xếp"
 
-#: cfgexpand.c:1665 function.c:1002 varasm.c:2231
+#: cfgexpand.c:1665 function.c:1002 varasm.c:2242
 #, gcc-internal-format
 msgid "size of variable %q+D is too large"
 msgstr "kích cỡ biến %q+D quá lớn"
@@ -17524,237 +17542,237 @@
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr ""
 
-#: cgraph.c:3051
+#: cgraph.c:3056
 #, gcc-internal-format
 msgid "caller edge count invalid"
 msgstr ""
 
-#: cgraph.c:3135
+#: cgraph.c:3140
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr ""
 
-#: cgraph.c:3142
+#: cgraph.c:3147
 #, gcc-internal-format
 msgid "cgraph count invalid"
 msgstr ""
 
-#: cgraph.c:3147
+#: cgraph.c:3152
 #, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr ""
 
-#: cgraph.c:3152
+#: cgraph.c:3157
 #, gcc-internal-format
 msgid "local symbols must be defined"
 msgstr "ký hiệu cục bộ phải được định nghĩa"
 
-#: cgraph.c:3157
+#: cgraph.c:3162
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr ""
 
-#: cgraph.c:3162
+#: cgraph.c:3167
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr ""
 
-#: cgraph.c:3167
+#: cgraph.c:3172
 #, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr ""
 
-#: cgraph.c:3174
+#: cgraph.c:3179
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for indirect edge from %s"
 msgstr ""
 
-#: cgraph.c:3181
+#: cgraph.c:3186
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr ""
 
-#: cgraph.c:3196
+#: cgraph.c:3201
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr ""
 
-#: cgraph.c:3206
+#: cgraph.c:3211
 #, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr "inlined_to con trỏ là sai"
 
-#: cgraph.c:3211
+#: cgraph.c:3216
 #, gcc-internal-format
 msgid "multiple inline callers"
 msgstr "nhiều bộ gọi chung dòng"
 
-#: cgraph.c:3218
+#: cgraph.c:3223
 #, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr ""
 
-#: cgraph.c:3239
+#: cgraph.c:3244
 #, gcc-internal-format
 msgid "caller edge count does not match BB count"
 msgstr ""
 
-#: cgraph.c:3261
+#: cgraph.c:3266
 #, gcc-internal-format
 msgid "indirect call count does not match BB count"
 msgstr ""
 
-#: cgraph.c:3272
+#: cgraph.c:3277
 #, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr ""
 
-#: cgraph.c:3277
+#: cgraph.c:3282
 #, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr "con trỏ inlined_to chỉ đến chính nó"
 
-#: cgraph.c:3289
+#: cgraph.c:3294
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr "cgraph_node có clone_of sai"
 
-#: cgraph.c:3301
+#: cgraph.c:3306
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr "cgraph_node có danh sách nhân bản sai"
 
-#: cgraph.c:3307
+#: cgraph.c:3312
 #, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr ""
 
-#: cgraph.c:3312
+#: cgraph.c:3317
 #, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr ""
 
-#: cgraph.c:3317
+#: cgraph.c:3322
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr ""
 
-#: cgraph.c:3329
+#: cgraph.c:3334
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr "Bí danh có cạnh gọi"
 
-#: cgraph.c:3337
+#: cgraph.c:3342
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr "Bí danh có tham chiếu non-alias"
 
-#: cgraph.c:3342
+#: cgraph.c:3347
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr ""
 
-#: cgraph.c:3349
+#: cgraph.c:3354
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr ""
 
-#: cgraph.c:3358
+#: cgraph.c:3363
 #, gcc-internal-format
 msgid "Instrumentation clone does not reference original node"
 msgstr ""
 
-#: cgraph.c:3365
+#: cgraph.c:3370
 #, gcc-internal-format
 msgid "Not instrumented node has non-NULL original declaration"
 msgstr ""
 
-#: cgraph.c:3375
+#: cgraph.c:3380
 #, gcc-internal-format
 msgid "Instrumented node has wrong original declaration"
 msgstr ""
 
-#: cgraph.c:3393
+#: cgraph.c:3398
 #, gcc-internal-format
 msgid "Node has more than one chkp reference"
 msgstr ""
 
-#: cgraph.c:3398
+#: cgraph.c:3403
 #, gcc-internal-format
 msgid "Wrong node is referenced with chkp reference"
 msgstr ""
 
-#: cgraph.c:3406
+#: cgraph.c:3411
 #, gcc-internal-format
 msgid "Analyzed node has no reference to instrumented version"
 msgstr ""
 
-#: cgraph.c:3420
+#: cgraph.c:3425
 #, gcc-internal-format
 msgid "Alias chain for instrumented node is broken"
 msgstr ""
 
-#: cgraph.c:3429
+#: cgraph.c:3434
 #, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3434
+#: cgraph.c:3439
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3439
+#: cgraph.c:3444
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr ""
 
-#: cgraph.c:3445
+#: cgraph.c:3450
 #, gcc-internal-format
 msgid "Instrumentation thunk has wrong edge callee"
 msgstr ""
 
-#: cgraph.c:3481
+#: cgraph.c:3486
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr "call_stmt được chia sẻ:"
 
-#: cgraph.c:3489
+#: cgraph.c:3494
 #, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr ""
 
-#: cgraph.c:3498
+#: cgraph.c:3503
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr ""
 
-#: cgraph.c:3508
+#: cgraph.c:3513
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr ""
 
-#: cgraph.c:3518
+#: cgraph.c:3523
 #, gcc-internal-format
 msgid "reference to dead statement"
 msgstr ""
 
-#: cgraph.c:3531
+#: cgraph.c:3536
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3543
+#: cgraph.c:3548
 #, gcc-internal-format, gfc-internal-format
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3554
+#: cgraph.c:3559
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr "verify_cgraph_node gặp lỗi"
 
-#: cgraph.c:3661 varpool.c:306
+#: cgraph.c:3666 varpool.c:306
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: section %s is missing"
 msgstr "%s: phần %s còn thiếu"
@@ -17785,12 +17803,12 @@
 msgstr ""
 
 #. include_self=
-#: cgraphunit.c:981 c/c-decl.c:11282
+#: cgraphunit.c:981 c/c-decl.c:11302
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F được dùng mà chưa từng được định nghĩa"
 
-#: cgraphunit.c:983 c/c-decl.c:11291
+#: cgraphunit.c:983 c/c-decl.c:11311
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr ""
@@ -17908,12 +17926,12 @@
 msgid "cannot find '%s'"
 msgstr "không tìm thấy “%s”"
 
-#: collect-utils.c:183 collect2.c:2361 collect2.c:2560 gcc.c:3080 gcc.c:6856
+#: collect-utils.c:183 collect2.c:2387 collect2.c:2586 gcc.c:3080 gcc.c:6856
 #, gcc-internal-format
 msgid "pex_init failed: %m"
 msgstr "pex_init bị lỗi: %m"
 
-#: collect-utils.c:192 collect2.c:2370 collect2.c:2568 gcc.c:8498
+#: collect-utils.c:192 collect2.c:2396 collect2.c:2594 gcc.c:8498
 #, gcc-internal-format
 msgid "%s: %m"
 msgstr "%s: %m"
@@ -17923,95 +17941,95 @@
 msgid "COLLECT_LTO_WRAPPER must be set"
 msgstr "COLLECT_LTO_WRAPPER phải được đặt"
 
-#: collect2.c:966 gcc.c:7382 lto-wrapper.c:1666
+#: collect2.c:969 gcc.c:7382 lto-wrapper.c:1692
 #: config/i386/intelmic-mkoffload.c:556 config/nvptx/mkoffload.c:405
 #, gcc-internal-format
 msgid "atexit failed"
 msgstr "atexit gặp lỗi"
 
-#: collect2.c:1064
+#: collect2.c:1067
 #, gcc-internal-format
 msgid "no arguments"
 msgstr "không có đối số nào"
 
-#: collect2.c:1303 opts.c:904
+#: collect2.c:1311 opts.c:904
 #, gcc-internal-format
 msgid "LTO support has not been enabled in this configuration"
 msgstr "Phần hỗ trợ LTO không được bật trong cấu hình này"
 
-#: collect2.c:1344
+#: collect2.c:1352
 #, gcc-internal-format
 msgid "can't open %s: %m"
 msgstr "không thể mở %s: %m"
 
-#: collect2.c:1450
+#: collect2.c:1472
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown demangling style '%s'"
 msgstr "không rõ kiểu khắt khe \"%s\""
 
 # Literal: don't translate; Nghĩa chữ: dừng dịch
-#: collect2.c:1546 collect2.c:1729 collect2.c:1769
+#: collect2.c:1574 collect2.c:1757 collect2.c:1797
 #, gcc-internal-format
 msgid "fopen %s: %m"
 msgstr "fopen %s: %m"
 
 # Literal: don't translate; Nghĩa chữ: dừng dịch
-#: collect2.c:1549 collect2.c:1734 collect2.c:1772
+#: collect2.c:1577 collect2.c:1762 collect2.c:1800
 #, gcc-internal-format
 msgid "fclose %s: %m"
 msgstr "fclose %s: %m"
 
-#: collect2.c:2335
+#: collect2.c:2361
 #, gcc-internal-format
 msgid "cannot find 'nm'"
 msgstr "không tìm thấy “nm”"
 
-#: collect2.c:2383
+#: collect2.c:2409
 #, gcc-internal-format
 msgid "can't open nm output: %m"
 msgstr "không thể mở kết xuất nm: %m"
 
-#: collect2.c:2467
+#: collect2.c:2493
 #, gcc-internal-format, gfc-internal-format
 msgid "init function found in object %s"
 msgstr "hàm init được tìm trong đối tượng %s"
 
-#: collect2.c:2478
+#: collect2.c:2504
 #, gcc-internal-format, gfc-internal-format
 msgid "fini function found in object %s"
 msgstr "hàm fini được tìm trong đối tượng %s"
 
-#: collect2.c:2535
+#: collect2.c:2561
 #, gcc-internal-format
 msgid "cannot find 'ldd'"
 msgstr "không tìm thấy “ldd”"
 
-#: collect2.c:2581
+#: collect2.c:2607
 #, gcc-internal-format
 msgid "can't open ldd output: %m"
 msgstr "không thể mở kết xuất ldd: %m"
 
-#: collect2.c:2599
+#: collect2.c:2625
 #, gcc-internal-format, gfc-internal-format
 msgid "dynamic dependency %s not found"
 msgstr "không tìm thấy quan hệ phụ thuộc năng động %s"
 
-#: collect2.c:2611
+#: collect2.c:2637
 #, gcc-internal-format, gfc-internal-format
 msgid "unable to open dynamic dependency '%s'"
 msgstr "không thể mở quan hệ phụ thuộc năng động “%s”"
 
-#: collect2.c:2765
+#: collect2.c:2791
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: not a COFF file"
 msgstr "%s: không phải là một tập tin COFF"
 
-#: collect2.c:2930
+#: collect2.c:2961
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: cannot open as COFF file"
 msgstr "%s: không thể mở dưới dạng tập tin COFF"
 
-#: collect2.c:2989
+#: collect2.c:3020
 #, gcc-internal-format, gfc-internal-format
 msgid "library lib%s not found"
 msgstr "không tìm thấy thư viện lib%s"
@@ -18222,12 +18240,12 @@
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr ""
 
-#: dwarf2out.c:10901
+#: dwarf2out.c:10909
 #, gcc-internal-format
 msgid "-gdwarf-6 is output as version 5 with incompatibilities"
 msgstr ""
 
-#: dwarf2out.c:14415
+#: dwarf2out.c:14423
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
@@ -18347,12 +18365,6 @@
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr ""
 
-#: file-prefix-map.c:50
-#, fuzzy, gcc-internal-format
-#| msgid "invalid argument to %qD"
-msgid "invalid argument %qs to %qs"
-msgstr "đối số không hợp lệ cho %qD"
-
 #: final.c:1868
 #, gcc-internal-format
 msgid "the frame size of %wd bytes is larger than %wd bytes"
@@ -18373,42 +18385,42 @@
 msgid "large fixed-point constant implicitly truncated to fixed-point type"
 msgstr ""
 
-#: fold-const.c:4151 fold-const.c:4161
+#: fold-const.c:4157 fold-const.c:4167
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d due to width of bit-field"
 msgstr ""
 
-#: fold-const.c:5478 tree-ssa-reassoc.c:2374 tree-ssa-reassoc.c:3214
+#: fold-const.c:5484 tree-ssa-reassoc.c:2379 tree-ssa-reassoc.c:3219
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
 
-#: fold-const.c:5928 fold-const.c:5942
+#: fold-const.c:5934 fold-const.c:5948
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr "so sánh luôn là %d"
 
-#: fold-const.c:6085
+#: fold-const.c:6091
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr ""
 
-#: fold-const.c:6090
+#: fold-const.c:6096
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr ""
 
-#: fold-const.c:8310
+#: fold-const.c:8316
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr ""
 
-#: fold-const.c:8710
+#: fold-const.c:8716
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr ""
 
-#: fold-const.c:12063
+#: fold-const.c:12069
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr ""
@@ -18418,7 +18430,7 @@
 msgid "total size of local objects too large"
 msgstr ""
 
-#: function.c:1776 gimplify.c:6270
+#: function.c:1776 gimplify.c:6273
 #, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr ""
@@ -18726,7 +18738,7 @@
 msgid "%s: linker input file unused because linking not done"
 msgstr ""
 
-#: gcc.c:8420 c-family/c-opts.c:770
+#: gcc.c:8420 c-family/c-opts.c:768
 #, gcc-internal-format
 msgid "cannot use %<-%> as input filename for a precompiled header"
 msgstr ""
@@ -18962,7 +18974,7 @@
 msgid "%G%qD destination unchanged after copying no bytes"
 msgstr ""
 
-#: gimple-fold.c:2052 tree-ssa-strlen.c:2050
+#: gimple-fold.c:2052 tree-ssa-strlen.c:2074
 msgid "%G%qD specified bound %E equals destination size"
 msgstr ""
 
@@ -18984,12 +18996,12 @@
 msgid "null pointer dereference"
 msgstr ""
 
-#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12451
-#: tree.c:12488 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10147
-#: c/c-typeck.c:10164 c/gimple-parser.c:1616 c/gimple-parser.c:1624
+#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12455
+#: tree.c:12492 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10152
+#: c/c-typeck.c:10169 c/gimple-parser.c:1616 c/gimple-parser.c:1624
 #: cp/call.c:6493 cp/call.c:8098 cp/constexpr.c:820 cp/constexpr.c:2309
-#: cp/cvt.c:1015 cp/cvt.c:1042 cp/decl.c:7334 cp/decl2.c:5256 cp/pt.c:8334
-#: cp/semantics.c:1836 cp/semantics.c:4053 cp/typeck.c:1700 cp/typeck.c:1895
+#: cp/cvt.c:1015 cp/cvt.c:1042 cp/decl.c:7355 cp/decl2.c:5246 cp/pt.c:8348
+#: cp/semantics.c:1836 cp/semantics.c:4056 cp/typeck.c:1700 cp/typeck.c:1895
 #: cp/typeck.c:3837
 #, gcc-internal-format
 msgid "declared here"
@@ -19000,294 +19012,294 @@
 msgid "nonnull argument %qD compared to NULL"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2517 gimple-ssa-sprintf.c:2637
+#: gimple-ssa-sprintf.c:2555 gimple-ssa-sprintf.c:2675
 #, gcc-internal-format
 msgid "%qE output may be truncated before the last format character"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2519 gimple-ssa-sprintf.c:2639
+#: gimple-ssa-sprintf.c:2557 gimple-ssa-sprintf.c:2677
 #, gcc-internal-format
 msgid "%qE output truncated before the last format character"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2522 gimple-ssa-sprintf.c:2642
+#: gimple-ssa-sprintf.c:2560 gimple-ssa-sprintf.c:2680
 #, gcc-internal-format
 msgid "%qE may write a terminating nul past the end of the destination"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2524 gimple-ssa-sprintf.c:2644
+#: gimple-ssa-sprintf.c:2562 gimple-ssa-sprintf.c:2682
 #, gcc-internal-format
 msgid "%qE writing a terminating nul past the end of the destination"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2534
+#: gimple-ssa-sprintf.c:2572
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size %wu"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.c:2541
+#: gimple-ssa-sprintf.c:2579
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size %wu"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.c:2548
+#: gimple-ssa-sprintf.c:2586
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size %wu"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.c:2559
+#: gimple-ssa-sprintf.c:2597
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2562
+#: gimple-ssa-sprintf.c:2600
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2564
+#: gimple-ssa-sprintf.c:2602
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2576
+#: gimple-ssa-sprintf.c:2614
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2579
+#: gimple-ssa-sprintf.c:2617
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2582
+#: gimple-ssa-sprintf.c:2620
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2591
+#: gimple-ssa-sprintf.c:2629
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2594
+#: gimple-ssa-sprintf.c:2632
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2597
+#: gimple-ssa-sprintf.c:2635
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2606
+#: gimple-ssa-sprintf.c:2644
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2609
+#: gimple-ssa-sprintf.c:2647
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2611
+#: gimple-ssa-sprintf.c:2649
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2653
+#: gimple-ssa-sprintf.c:2691
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size between %wu and %wu"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.c:2660
+#: gimple-ssa-sprintf.c:2698
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size between %wu and %wu"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.c:2668
+#: gimple-ssa-sprintf.c:2706
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size between %wu and %wu"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.c:2680
+#: gimple-ssa-sprintf.c:2718
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2683
+#: gimple-ssa-sprintf.c:2721
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2686
+#: gimple-ssa-sprintf.c:2724
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2699
+#: gimple-ssa-sprintf.c:2737
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2702
+#: gimple-ssa-sprintf.c:2740
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2705
+#: gimple-ssa-sprintf.c:2743
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2715
+#: gimple-ssa-sprintf.c:2753
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2718
+#: gimple-ssa-sprintf.c:2756
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2721
+#: gimple-ssa-sprintf.c:2759
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2730
+#: gimple-ssa-sprintf.c:2768
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2733
+#: gimple-ssa-sprintf.c:2771
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2736
+#: gimple-ssa-sprintf.c:2774
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2825
+#: gimple-ssa-sprintf.c:2863
 #, fuzzy, gcc-internal-format
 msgid "%<%.*s%> directive argument is null"
 msgstr "Đối số âm N tại %L"
 
-#: gimple-ssa-sprintf.c:2890
+#: gimple-ssa-sprintf.c:2928
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes exceeds minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2897
+#: gimple-ssa-sprintf.c:2935
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may exceed minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2900
+#: gimple-ssa-sprintf.c:2938
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes exceeds minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2929
+#: gimple-ssa-sprintf.c:2967
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2936
+#: gimple-ssa-sprintf.c:2974
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2939
+#: gimple-ssa-sprintf.c:2977
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may cause result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2949
+#: gimple-ssa-sprintf.c:2987
 #, gcc-internal-format
 msgid "assuming directive output of %wu byte"
 msgid_plural "assuming directive output of %wu bytes"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.c:2956
+#: gimple-ssa-sprintf.c:2994
 #, fuzzy, gcc-internal-format
 msgid "directive argument %qE"
 msgstr "Đối số âm N tại %L"
 
-#: gimple-ssa-sprintf.c:2958
+#: gimple-ssa-sprintf.c:2996
 #, gcc-internal-format
 msgid "directive argument in the range [%E, %E]"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2962
+#: gimple-ssa-sprintf.c:3000
 #, gcc-internal-format
 msgid "using the range [%E, %E] for directive argument"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2982
+#: gimple-ssa-sprintf.c:3020
 #, gcc-internal-format
 msgid "%qE output %wu byte into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2983
+#: gimple-ssa-sprintf.c:3021
 #, gcc-internal-format
 msgid "%qE output %wu bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2987
+#: gimple-ssa-sprintf.c:3025
 #, gcc-internal-format
 msgid "%qE output between %wu and %wu bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2992
+#: gimple-ssa-sprintf.c:3030
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes (assuming %wu) into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2997
+#: gimple-ssa-sprintf.c:3035
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3368
+#: gimple-ssa-sprintf.c:3406
 #, gcc-internal-format
 msgid "%<%.*s%> directive width out of range"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3402
+#: gimple-ssa-sprintf.c:3440
 #, gcc-internal-format
 msgid "%<%.*s%> directive precision out of range"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3893
+#: gimple-ssa-sprintf.c:3931
 #, gcc-internal-format
 msgid "specified bound %wu exceeds maximum object size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3899
+#: gimple-ssa-sprintf.c:3937
 #, gcc-internal-format
 msgid "specified bound %wu exceeds %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3949
+#: gimple-ssa-sprintf.c:3987
 #, fuzzy, gcc-internal-format
 msgid "null destination pointer"
 msgstr "con trỏ rỗng"
 
-#: gimple-ssa-sprintf.c:3966
+#: gimple-ssa-sprintf.c:4004
 #, gcc-internal-format
 msgid "specified bound %wu exceeds the size %wu of the destination object"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3978
+#: gimple-ssa-sprintf.c:4016
 #, fuzzy, gcc-internal-format
 msgid "null format string"
 msgstr "%s trong chuỗi định dạng tại %L"
@@ -19490,10 +19502,10 @@
 msgstr ""
 
 #: gimple-ssa-warn-restrict.c:1678 c/c-decl.c:3603 c/c-decl.c:3874
-#: c/c-typeck.c:8345 cp/class.c:1346 cp/class.c:3098 cp/decl.c:3979
-#: cp/decl.c:10753 cp/decl.c:11151 cp/decl.c:11160 cp/friend.c:384
+#: c/c-typeck.c:8350 cp/class.c:1346 cp/class.c:3102 cp/decl.c:3979
+#: cp/decl.c:10777 cp/decl.c:11175 cp/decl.c:11184 cp/friend.c:384
 #: cp/friend.c:393 cp/parser.c:3275 cp/parser.c:3372 cp/parser.c:3422
-#: cp/parser.c:6327 cp/parser.c:21027
+#: cp/parser.c:6330 cp/parser.c:21024
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD được khai báo ở đây"
@@ -19563,219 +19575,219 @@
 msgid "using result of function returning %<void%>"
 msgstr ""
 
-#: gimplify.c:6128
+#: gimplify.c:6131
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid lvalue in asm output %d"
 msgstr ""
 
-#: gimplify.c:6271
+#: gimplify.c:6274
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr ""
 
-#: gimplify.c:6311 gimplify.c:6320
+#: gimplify.c:6314 gimplify.c:6323
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr ""
 
-#: gimplify.c:6928
+#: gimplify.c:6931
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in target region"
 msgstr ""
 
-#: gimplify.c:6930
+#: gimplify.c:6933
 #, gcc-internal-format
 msgid "enclosing target region"
 msgstr ""
 
-#: gimplify.c:6942
+#: gimplify.c:6945
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in untied task"
 msgstr ""
 
-#: gimplify.c:6944
+#: gimplify.c:6947
 #, gcc-internal-format
 msgid "enclosing task"
 msgstr ""
 
-#: gimplify.c:7016
+#: gimplify.c:7019
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D not declared in class"
 msgid "%qE not specified in enclosing %qs"
 msgstr "%q#D chưa được khai báo trong lớp"
 
-#: gimplify.c:7018
+#: gimplify.c:7021
 #, fuzzy, gcc-internal-format
 #| msgid "enclosing %s"
 msgid "enclosing %qs"
 msgstr "bao quanh %s"
 
-#: gimplify.c:7143
+#: gimplify.c:7146
 #, gcc-internal-format
 msgid "%qE not specified in enclosing OpenACC %qs construct"
 msgstr ""
 
-#: gimplify.c:7145
+#: gimplify.c:7148
 #, gcc-internal-format
 msgid "enclosing OpenACC %qs construct"
 msgstr ""
 
-#: gimplify.c:7198
+#: gimplify.c:7201
 #, gcc-internal-format
 msgid "%qE with %<link%> clause used in %<routine%> function"
 msgstr ""
 
-#: gimplify.c:7206
+#: gimplify.c:7209
 #, gcc-internal-format
 msgid "%qE requires a %<declare%> directive for use in a %<routine%> function"
 msgstr ""
 
-#: gimplify.c:7272 gimplify.c:7872
+#: gimplify.c:7275 gimplify.c:7875
 #, gcc-internal-format
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr ""
 
-#: gimplify.c:7293
+#: gimplify.c:7296
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr ""
 
-#: gimplify.c:7411 gimplify.c:7443
+#: gimplify.c:7414 gimplify.c:7446
 #, gcc-internal-format
 msgid "iteration variable %qE is predetermined linear"
 msgstr ""
 
-#: gimplify.c:7414
+#: gimplify.c:7417
 #, gcc-internal-format
 msgid "iteration variable %qE should be private"
 msgstr ""
 
-#: gimplify.c:7428
+#: gimplify.c:7431
 #, gcc-internal-format
 msgid "iteration variable %qE should not be firstprivate"
 msgstr ""
 
-#: gimplify.c:7431
+#: gimplify.c:7434
 #, gcc-internal-format
 msgid "iteration variable %qE should not be reduction"
 msgstr ""
 
-#: gimplify.c:7434
+#: gimplify.c:7437
 #, gcc-internal-format
 msgid "iteration variable %qE should not be linear"
 msgstr ""
 
-#: gimplify.c:7437
+#: gimplify.c:7440
 #, gcc-internal-format
 msgid "iteration variable %qE should not be lastprivate"
 msgstr ""
 
-#: gimplify.c:7440
+#: gimplify.c:7443
 #, gcc-internal-format
 msgid "iteration variable %qE should not be private"
 msgstr ""
 
-#: gimplify.c:7742
+#: gimplify.c:7745
 #, gcc-internal-format
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr ""
 
-#: gimplify.c:7949
+#: gimplify.c:7952
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr ""
 
-#: gimplify.c:8160
+#: gimplify.c:8163
 #, gcc-internal-format
 msgid "%qE appears more than once in map clauses"
 msgstr ""
 
-#: gimplify.c:8464
+#: gimplify.c:8467
 #, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr ""
 
-#: gimplify.c:8484
+#: gimplify.c:8487
 #, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr ""
 
-#: gimplify.c:8510
+#: gimplify.c:8513
 #, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr ""
 
-#: gimplify.c:8775
+#: gimplify.c:8778
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr ""
 
-#: gimplify.c:8808
+#: gimplify.c:8811
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:9000
+#: gimplify.c:9003
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:9051
+#: gimplify.c:9054
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr ""
 
-#: gimplify.c:9133
+#: gimplify.c:9136
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to present_or_copy"
 msgstr ""
 
-#: gimplify.c:9278
+#: gimplify.c:9281
 #, gcc-internal-format
 msgid "invalid private reduction on %qE"
 msgstr ""
 
-#: gimplify.c:11103 omp-low.c:2791
+#: gimplify.c:11106 omp-low.c:2791
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: gimplify.c:11121
+#: gimplify.c:11124
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr ""
 
-#: gimplify.c:11134
+#: gimplify.c:11137
 #, gcc-internal-format
 msgid "number of variables in %<depend(sink)%> clause does not match number of iteration variables"
 msgstr ""
 
-#: gimplify.c:11147
+#: gimplify.c:11150
 #, gcc-internal-format
 msgid "more than one %<depend(source)%> clause on an %<ordered%> construct"
 msgstr ""
 
-#: gimplify.c:11158
+#: gimplify.c:11161
 #, gcc-internal-format
 msgid "%<depend(source)%> clause specified together with %<depend(sink:)%> clauses on the same construct"
 msgstr ""
 
-#: gimplify.c:12393
+#: gimplify.c:12396
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr "gimplification gặp lỗi"
 
-#: gimplify.c:12936
+#: gimplify.c:12939
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr ""
 
-#: gimplify.c:12941
+#: gimplify.c:12944
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr ""
 
-#: gimplify.c:12948
+#: gimplify.c:12951
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr ""
@@ -20246,47 +20258,47 @@
 msgid "Max. number of generated reload insns per insn is achieved (%d)\n"
 msgstr ""
 
-#: lto-cgraph.c:1294
+#: lto-cgraph.c:1296
 #, gcc-internal-format, gfc-internal-format
 msgid "bytecode stream: found multiple instances of cgraph node with uid %d"
 msgstr ""
 
-#: lto-cgraph.c:1472
+#: lto-cgraph.c:1474
 #, gcc-internal-format
 msgid "bytecode stream: no caller found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1478
+#: lto-cgraph.c:1480
 #, gcc-internal-format
 msgid "bytecode stream: no callee found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1552
+#: lto-cgraph.c:1554
 #, gcc-internal-format
 msgid "bytecode stream: found empty cgraph node"
 msgstr ""
 
-#: lto-cgraph.c:1730
+#: lto-cgraph.c:1732
 #, gcc-internal-format, gfc-internal-format
 msgid "At most %i profile runs is supported. Perhaps corrupted profile?"
 msgstr ""
 
-#: lto-cgraph.c:1817
+#: lto-cgraph.c:1819
 #, gcc-internal-format, gfc-internal-format
 msgid "Profile information in %s corrupted"
 msgstr ""
 
-#: lto-cgraph.c:1855
+#: lto-cgraph.c:1857
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO cgraph in %s"
 msgstr "không thể tìm thấy LTO cgraph trong %s"
 
-#: lto-cgraph.c:1865
+#: lto-cgraph.c:1867
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO section refs in %s"
 msgstr "không thể tìm thấy tham chiếu phần LTO trong %s"
 
-#: lto-cgraph.c:1946
+#: lto-cgraph.c:1948
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid offload table in %s"
 msgstr ""
@@ -20357,83 +20369,89 @@
 msgid "bytecode stream in file %qs generated with LTO version %d.%d instead of the expected %d.%d"
 msgstr ""
 
-#: lto-wrapper.c:117
+#: lto-wrapper.c:118
 #, gcc-internal-format
 msgid "deleting LTRANS file %s: %m"
 msgstr "đang xóa bỏ tập tin LTRANS %s: %m"
 
-#: lto-wrapper.c:154
+#: lto-wrapper.c:155
 #, gcc-internal-format
 msgid "malformed COLLECT_GCC_OPTIONS"
 msgstr "COLLECT_GCC_OPTIONS dị hình"
 
-#: lto-wrapper.c:308
+#: lto-wrapper.c:309
 #, gcc-internal-format, gfc-internal-format
 msgid "Option %s with different values"
 msgstr "Tùy chọn %s với các giá trị khác biệt"
 
-#: lto-wrapper.c:392
+#: lto-wrapper.c:393
 #, gcc-internal-format, gfc-internal-format
 msgid "Option %s not used consistently in all LTO input files"
 msgstr ""
 
-#: lto-wrapper.c:832
+#: lto-wrapper.c:833
 #, gcc-internal-format, gfc-internal-format
 msgid "problem with building target image for %s\n"
 msgstr ""
 
-#: lto-wrapper.c:852
+#: lto-wrapper.c:853
 #, gcc-internal-format
 msgid "reading input file"
 msgstr "đang đọc tập tin đầu vào"
 
-#: lto-wrapper.c:857
+#: lto-wrapper.c:858
 #, gcc-internal-format
 msgid "writing output file"
 msgstr "đang ghi tập tin đầu ra"
 
-#: lto-wrapper.c:889
+#: lto-wrapper.c:890
 #, gcc-internal-format
 msgid "installation error, can't find crtoffloadtable.o"
 msgstr ""
 
-#: lto-wrapper.c:1000 lto-wrapper.c:1012
+#: lto-wrapper.c:1001 lto-wrapper.c:1013
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s: %s"
 msgid "%s: %s\n"
 msgstr "%s: %s"
 
-#: lto-wrapper.c:1056
+#: lto-wrapper.c:1064
 #, gcc-internal-format
 msgid "environment variable COLLECT_GCC must be set"
 msgstr "biến môi trường COLLECT_GCC cần được đặt"
 
-#: lto-wrapper.c:1060 config/nvptx/mkoffload.c:363
+#: lto-wrapper.c:1068 config/nvptx/mkoffload.c:363
 #, gcc-internal-format
 msgid "environment variable COLLECT_GCC_OPTIONS must be set"
 msgstr "biến môi trường COLLECT_GCC_OPTIONS cần được đặt"
 
-#: lto-wrapper.c:1229 lto-wrapper.c:1285
+#: lto-wrapper.c:1237 lto-wrapper.c:1293
 #, gcc-internal-format
 msgid "cannot open %s: %m"
 msgstr "không thể mở %s: %m"
 
-#: lto-wrapper.c:1232 lto-wrapper.c:1291
+#: lto-wrapper.c:1240 lto-wrapper.c:1299
 #, gcc-internal-format
 msgid "cannot read %s: %m"
 msgstr "không thể đọc %s: %m"
 
-#: lto-wrapper.c:1259
+#: lto-wrapper.c:1267
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid format of %s"
 msgstr "định dạng của %s không hợp lệ"
 
 # Literal: don't translate; Nghĩa chữ: dừng dịch
-#: lto-wrapper.c:1482
+#: lto-wrapper.c:1491
 #, gcc-internal-format
 msgid "fopen: %s: %m"
 msgstr "fopen: %s: %m"
 
+#: lto-wrapper.c:1508
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "Could not open output file '%s'\n"
+msgid "Corrupted ltrans output file %s"
+msgstr "Không thể mở tập tin kết xuất “%s”\n"
+
 #: multiple_target.c:76
 #, gcc-internal-format
 msgid "the call requires ifunc, which is not supported by this target"
@@ -20789,12 +20807,12 @@
 msgid "unrecognized argument in option %qs"
 msgstr "không nhận ra đối số tới tùy chọn %qs"
 
-#: opts-common.c:1198 config/i386/i386.c:3206
+#: opts-common.c:1198 config/i386/i386.c:3209
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "đối số hợp lệ cho cho %qs là: %s"
 
-#: opts-common.c:1201 config/i386/i386.c:3209
+#: opts-common.c:1201 config/i386/i386.c:3212
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "đối số hợp lệ cho cho %qs là: %s"
@@ -21412,22 +21430,22 @@
 msgid "output operand %d must use %<&%> constraint"
 msgstr ""
 
-#: regcprop.c:1187
+#: regcprop.c:1193
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad next_regno for empty chain (%u)"
 msgstr ""
 
-#: regcprop.c:1199
+#: regcprop.c:1205
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: Loop in regno chain (%u)"
 msgstr ""
 
-#: regcprop.c:1202
+#: regcprop.c:1208
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad oldest_regno (%u)"
 msgstr ""
 
-#: regcprop.c:1214
+#: regcprop.c:1220
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Non-empty reg in chain (%s %u %i)"
 msgstr ""
@@ -21471,7 +21489,7 @@
 msgstr ""
 
 #: reginfo.c:789 config/powerpcspe/powerpcspe.c:32259
-#: config/rs6000/rs6000.c:29453
+#: config/rs6000/rs6000.c:29530
 #, gcc-internal-format
 msgid "conflicts with %qD"
 msgstr "xung đột với %qD"
@@ -21717,153 +21735,158 @@
 msgid "function symbol is not function"
 msgstr "ký hiệu hàm không phải là một hàm"
 
-#: symtab.c:1006
+#: symtab.c:1005
 #, gcc-internal-format
+msgid "inconsistent `ifunc' attribute"
+msgstr ""
+
+#: symtab.c:1013
+#, gcc-internal-format
 msgid "variable symbol is not variable"
 msgstr "ký hiệu biến đổi không là một biến"
 
-#: symtab.c:1012
+#: symtab.c:1019
 #, gcc-internal-format
 msgid "node has unknown type"
 msgstr "nút có kiểu không hiểu"
 
-#: symtab.c:1021
+#: symtab.c:1028
 #, gcc-internal-format
 msgid "node not found node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.c:1029
+#: symtab.c:1036
 #, gcc-internal-format
 msgid "node differs from node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.c:1038
+#: symtab.c:1045
 #, gcc-internal-format
 msgid "assembler name hash list corrupted"
 msgstr ""
 
-#: symtab.c:1051
+#: symtab.c:1058
 #, gcc-internal-format
 msgid "node not found in symtab assembler name hash"
 msgstr ""
 
-#: symtab.c:1058
+#: symtab.c:1065
 #, gcc-internal-format
 msgid "double linked list of assembler names corrupted"
 msgstr ""
 
-#: symtab.c:1063
+#: symtab.c:1070
 #, gcc-internal-format
 msgid "node has body_removed but is definition"
 msgstr ""
 
-#: symtab.c:1068
+#: symtab.c:1075
 #, fuzzy, gcc-internal-format
 #| msgid "%qs at %L is not a function"
 msgid "node is analyzed but it is not a definition"
 msgstr "“%qs” tại %L không phải là một hàm"
 
-#: symtab.c:1073
+#: symtab.c:1080
 #, gcc-internal-format
 msgid "node is alias but not implicit alias"
 msgstr ""
 
-#: symtab.c:1078
+#: symtab.c:1085
 #, gcc-internal-format
 msgid "node is alias but not definition"
 msgstr ""
 
-#: symtab.c:1083
+#: symtab.c:1090
 #, gcc-internal-format
 msgid "node is weakref but not an transparent_alias"
 msgstr ""
 
-#: symtab.c:1088
+#: symtab.c:1095
 #, gcc-internal-format
 msgid "node is transparent_alias but not an alias"
 msgstr ""
 
-#: symtab.c:1097
+#: symtab.c:1104
 #, gcc-internal-format
 msgid "node is in same_comdat_group list but has no comdat_group"
 msgstr ""
 
-#: symtab.c:1102
+#: symtab.c:1109
 #, gcc-internal-format
 msgid "same_comdat_group list across different groups"
 msgstr ""
 
-#: symtab.c:1107
+#: symtab.c:1114
 #, gcc-internal-format
 msgid "mixing different types of symbol in same comdat groups is not supported"
 msgstr ""
 
-#: symtab.c:1112
+#: symtab.c:1119
 #, gcc-internal-format
 msgid "node is alone in a comdat group"
 msgstr ""
 
-#: symtab.c:1119
+#: symtab.c:1126
 #, gcc-internal-format
 msgid "same_comdat_group is not a circular list"
 msgstr ""
 
-#: symtab.c:1134
+#: symtab.c:1141
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local symbol referred to by %s outside its comdat"
 msgstr ""
 
-#: symtab.c:1144
+#: symtab.c:1151
 #, gcc-internal-format
 msgid "implicit_section flag is set but section isn't"
 msgstr ""
 
-#: symtab.c:1151
+#: symtab.c:1158
 #, gcc-internal-format
 msgid "Both section and comdat group is set"
 msgstr ""
 
-#: symtab.c:1163
+#: symtab.c:1170
 #, gcc-internal-format
 msgid "Alias and target's section differs"
 msgstr ""
 
-#: symtab.c:1170
+#: symtab.c:1177
 #, gcc-internal-format
 msgid "Alias and target's comdat groups differs"
 msgstr ""
 
-#: symtab.c:1185
+#: symtab.c:1192
 #, gcc-internal-format
 msgid "Transparent alias and target's assembler names differs"
 msgstr ""
 
-#: symtab.c:1193
+#: symtab.c:1200
 #, gcc-internal-format
 msgid "Chained transparent aliases"
 msgstr ""
 
-#: symtab.c:1216 symtab.c:1253
+#: symtab.c:1223 symtab.c:1260
 #, gcc-internal-format
 msgid "symtab_node::verify failed"
 msgstr "symtab_node::verify gặp lỗi"
 
-#: symtab.c:1249
+#: symtab.c:1256
 #, gcc-internal-format
 msgid "Two symbols with same comdat_group are not linked by the same_comdat_group list."
 msgstr ""
 
-#: symtab.c:1658
+#: symtab.c:1665
 #, gcc-internal-format
 msgid "function %q+D part of alias cycle"
 msgstr ""
 
-#: symtab.c:1660
+#: symtab.c:1667
 #, gcc-internal-format
 msgid "variable %q+D part of alias cycle"
 msgstr ""
 
-#: symtab.c:1688
+#: symtab.c:1695
 #, gcc-internal-format
 msgid "section of alias %q+D must match section of its target"
 msgstr ""
@@ -22680,7 +22703,7 @@
 msgid "the first argument of a VEC_COND_EXPR must be of a boolean vector type of the same number of elements as the result"
 msgstr ""
 
-#: tree-cfg.c:4395 c/c-typeck.c:5212
+#: tree-cfg.c:4395 c/c-typeck.c:5217
 #, gcc-internal-format
 msgid "type mismatch in conditional expression"
 msgstr "kiểu không khớp trong biểu thức điều kiện"
@@ -23031,22 +23054,22 @@
 msgid "missing edge %i->%i"
 msgstr "thiếu edge %i->%i"
 
-#: tree-cfg.c:9379
+#: tree-cfg.c:9388
 #, gcc-internal-format
 msgid "%<noreturn%> function does return"
 msgstr "%<noreturn%> hàm trả về"
 
-#: tree-cfg.c:9400 tree-cfg.c:9432
+#: tree-cfg.c:9409 tree-cfg.c:9441
 #, gcc-internal-format
 msgid "control reaches end of non-void function"
 msgstr ""
 
-#: tree-cfg.c:9498 cp/cvt.c:1039
+#: tree-cfg.c:9507 cp/cvt.c:1039
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgstr ""
 
-#: tree-cfg.c:9503 cp/cvt.c:1046
+#: tree-cfg.c:9512 cp/cvt.c:1046
 #, gcc-internal-format
 msgid "ignoring return value of function declared with attribute warn_unused_result"
 msgstr ""
@@ -23312,44 +23335,44 @@
 msgid "stmt volatile flag not up-to-date"
 msgstr ""
 
-#: tree-ssa-strlen.c:1975
+#: tree-ssa-strlen.c:1999
 msgid "%G%qD output truncated before terminating nul copying %E byte from a string of the same length"
 msgid_plural "%G%qD output truncated before terminating nul copying %E bytes from a string of the same length"
 msgstr[0] ""
 
-#: tree-ssa-strlen.c:1989
+#: tree-ssa-strlen.c:2013
 msgid "%G%qD output truncated copying %E byte from a string of length %wu"
 msgid_plural "%G%qD output truncated copying %E bytes from a string of length %wu"
 msgstr[0] ""
 
-#: tree-ssa-strlen.c:1996
+#: tree-ssa-strlen.c:2020
 msgid "%G%qD output truncated copying between %wu and %wu bytes from a string of length %wu"
 msgstr ""
 
-#: tree-ssa-strlen.c:2008
+#: tree-ssa-strlen.c:2032
 msgid "%G%qD output may be truncated copying %E byte from a string of length %wu"
 msgid_plural "%G%qD output may be truncated copying %E bytes from a string of length %wu"
 msgstr[0] ""
 
-#: tree-ssa-strlen.c:2015 tree-ssa-strlen.c:2029
+#: tree-ssa-strlen.c:2039 tree-ssa-strlen.c:2053
 msgid "%G%qD output may be truncated copying between %wu and %wu bytes from a string of length %wu"
 msgstr ""
 
-#: tree-ssa-strlen.c:2150
+#: tree-ssa-strlen.c:2174
 msgid "%G%qD output truncated before terminating nul copying as many bytes from a string as its length"
 msgstr ""
 
-#: tree-ssa-strlen.c:2156
+#: tree-ssa-strlen.c:2180
 msgid "%G%qD specified bound depends on the length of the source argument"
 msgstr ""
 
-#: tree-ssa-strlen.c:2163
+#: tree-ssa-strlen.c:2187
 #, fuzzy, gcc-internal-format
 #| msgid "length modifier"
 msgid "length computed here"
 msgstr "đồ sửa đổi bề dài"
 
-#: tree-ssa-uninit.c:191 varasm.c:331
+#: tree-ssa-uninit.c:191 varasm.c:342
 #, gcc-internal-format
 msgid "%qD was declared here"
 msgstr "%qD đã được khai báo ở đây"
@@ -23524,27 +23547,27 @@
 msgid "target specific builtin not available"
 msgstr ""
 
-#: tree-vect-generic.c:287
+#: tree-vect-generic.c:283
 #, gcc-internal-format
 msgid "vector operation will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-generic.c:290
+#: tree-vect-generic.c:286
 #, gcc-internal-format
 msgid "vector operation will be expanded in parallel"
 msgstr ""
 
-#: tree-vect-generic.c:341
+#: tree-vect-generic.c:337
 #, gcc-internal-format
 msgid "vector operation will be expanded with a single scalar operation"
 msgstr ""
 
-#: tree-vect-generic.c:941
+#: tree-vect-generic.c:937
 #, gcc-internal-format
 msgid "vector condition will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-generic.c:1373
+#: tree-vect-generic.c:1369
 #, gcc-internal-format
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr ""
@@ -23554,31 +23577,31 @@
 msgid "vectorization did not happen for a simd loop"
 msgstr ""
 
-#: tree-vrp.c:4930 tree-vrp.c:4974
+#: tree-vrp.c:4931 tree-vrp.c:4975
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is above array bounds"
 msgid "array subscript %E is above array bounds of %qT"
 msgstr "chỉ số mảng lớn hơn cận trên"
 
-#: tree-vrp.c:4956
+#: tree-vrp.c:4957
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is outside array bounds"
 msgid "array subscript [%E, %E] is outside array bounds of %qT"
 msgstr "chỉ số mảng nằm ngoài phạm vi của mảng"
 
-#: tree-vrp.c:4988
+#: tree-vrp.c:4989
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is below array bounds"
 msgid "array subscript %E is below array bounds of %qT"
 msgstr "chỉ số mảng nhỏ hơn cận dưới"
 
-#: tree-vrp.c:5046
+#: tree-vrp.c:5047
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is below array bounds"
 msgid "array subscript %wi is below array bounds of %qT"
 msgstr "chỉ số mảng nhỏ hơn cận dưới"
 
-#: tree-vrp.c:5060
+#: tree-vrp.c:5061
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is above array bounds"
 msgid "array subscript %wu is above array bounds of %qT"
@@ -23594,92 +23617,92 @@
 msgid "side-effects element in no-side-effects CONSTRUCTOR"
 msgstr ""
 
-#: tree.c:7852
+#: tree.c:7856
 #, gcc-internal-format
 msgid "arrays of functions are not meaningful"
 msgstr ""
 
-#: tree.c:8019
+#: tree.c:8023
 #, gcc-internal-format
 msgid "function return type cannot be function"
 msgstr "kiểu trả về hàm không thể là hàm"
 
-#: tree.c:9327 tree.c:9412 tree.c:9473
+#: tree.c:9331 tree.c:9416 tree.c:9477
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: %s, have %s in %s, at %s:%d"
 msgstr "kiểm tra cây: %s, có %s trong %s, tại %s:%d"
 
-#: tree.c:9364
+#: tree.c:9368
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected none of %s, have %s in %s, at %s:%d"
 msgstr "tree check: cần không gì của %s, có %s trong %s, tại %s:%d"
 
-#: tree.c:9377
+#: tree.c:9381
 #, gcc-internal-format
 msgid "tree check: expected class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "tree check: cần lớp %qs, có %qs (%s) trong %s, tại %s:%d"
 
-#: tree.c:9426
+#: tree.c:9430
 #, gcc-internal-format
 msgid "tree check: did not expect class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9439
+#: tree.c:9443
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected omp_clause %s, have %s in %s, at %s:%d"
 msgstr "tree check: cần omp_clause %s, có %s trong %s, tại %s:%d"
 
-#: tree.c:9499
+#: tree.c:9503
 #, gcc-internal-format
 msgid "tree check: expected tree that contains %qs structure, have %qs in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9513
+#: tree.c:9517
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_int_cst with %d elts in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9525
+#: tree.c:9529
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_vec with %d elts in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9538
+#: tree.c:9542
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of %s with %d operands in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9551
+#: tree.c:9555
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of omp_clause %s with %d operands in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:12446
+#: tree.c:12450
 #, gcc-internal-format
 msgid "%qD is deprecated: %s"
 msgstr "%qD đã lạc hậu: %s"
 
-#: tree.c:12449
+#: tree.c:12453
 #, gcc-internal-format
 msgid "%qD is deprecated"
 msgstr "%qD đã lạc hậu"
 
-#: tree.c:12473 tree.c:12495
+#: tree.c:12477 tree.c:12499
 #, gcc-internal-format
 msgid "%qE is deprecated: %s"
 msgstr "%qE đã lạc hậu: %s"
 
-#: tree.c:12476 tree.c:12498
+#: tree.c:12480 tree.c:12502
 #, gcc-internal-format
 msgid "%qE is deprecated"
 msgstr "%qE đã lạc hậu"
 
-#: tree.c:12482 tree.c:12503
+#: tree.c:12486 tree.c:12507
 #, gcc-internal-format, gfc-internal-format
 msgid "type is deprecated: %s"
 msgstr "kiểu đã lạc hậu: %s"
 
-#: tree.c:12485 tree.c:12506
+#: tree.c:12489 tree.c:12510
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr "kiểu đã lạc hậu"
@@ -23704,243 +23727,243 @@
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.c:13043
+#: tree.c:13047
 #, gcc-internal-format, gfc-internal-format
 msgid "type variant differs by %s"
 msgstr ""
 
-#: tree.c:13084
+#: tree.c:13088
 #, gcc-internal-format
 msgid "type variant has different TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13086
+#: tree.c:13090
 #, gcc-internal-format
 msgid "type variant's TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13088
+#: tree.c:13092
 #, gcc-internal-format
 msgid "type's TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13108
+#: tree.c:13112
 #, gcc-internal-format
 msgid "type variant with TYPE_ALIAS_SET_KNOWN_P"
 msgstr ""
 
-#: tree.c:13121
+#: tree.c:13125
 #, gcc-internal-format
 msgid "type variant has different TYPE_VFIELD"
 msgstr ""
 
-#: tree.c:13157
+#: tree.c:13161
 #, gcc-internal-format
 msgid "type variant has different TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13159
+#: tree.c:13163
 #, gcc-internal-format
 msgid "type variant's TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13161
+#: tree.c:13165
 #, gcc-internal-format
 msgid "type's TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13199
+#: tree.c:13203
 #, gcc-internal-format
 msgid "type variant has different TYPE_FIELDS"
 msgstr ""
 
-#: tree.c:13201
+#: tree.c:13205
 #, gcc-internal-format
 msgid "first mismatch is field"
 msgstr ""
 
-#: tree.c:13203
+#: tree.c:13207
 #, gcc-internal-format
 msgid "and field"
 msgstr ""
 
-#: tree.c:13220
+#: tree.c:13224
 #, gcc-internal-format
 msgid "type variant has different TREE_TYPE"
 msgstr ""
 
-#: tree.c:13222 tree.c:13233
+#: tree.c:13226 tree.c:13237
 #, gcc-internal-format
 msgid "type variant's TREE_TYPE"
 msgstr ""
 
-#: tree.c:13224 tree.c:13235
+#: tree.c:13228 tree.c:13239
 #, gcc-internal-format
 msgid "type's TREE_TYPE"
 msgstr ""
 
-#: tree.c:13231
+#: tree.c:13235
 #, fuzzy, gcc-internal-format
 #| msgid "-mnop-mcount is not compatible with this target"
 msgid "type is not compatible with its variant"
 msgstr "-mnop-mcount không tương thích với đích này"
 
-#: tree.c:13534
+#: tree.c:13538
 #, gcc-internal-format
 msgid "Main variant is not defined"
 msgstr ""
 
-#: tree.c:13539
+#: tree.c:13543
 #, gcc-internal-format
 msgid "TYPE_MAIN_VARIANT has different TYPE_MAIN_VARIANT"
 msgstr ""
 
-#: tree.c:13551
+#: tree.c:13555
 #, gcc-internal-format
 msgid "TYPE_CANONICAL has different TYPE_CANONICAL"
 msgstr ""
 
-#: tree.c:13569
+#: tree.c:13573
 #, gcc-internal-format
 msgid "TYPE_CANONICAL is not compatible"
 msgstr ""
 
-#: tree.c:13577
+#: tree.c:13581
 #, gcc-internal-format
 msgid "TYPE_MODE of TYPE_CANONICAL is not compatible"
 msgstr ""
 
-#: tree.c:13583
+#: tree.c:13587
 #, gcc-internal-format
 msgid "TYPE_CANONICAL of main variant is not main variant"
 msgstr ""
 
-#: tree.c:13599
+#: tree.c:13603
 #, gcc-internal-format
 msgid "TYPE_VFIELD is not FIELD_DECL nor TREE_LIST"
 msgstr ""
 
-#: tree.c:13609
+#: tree.c:13613
 #, gcc-internal-format
 msgid "TYPE_NEXT_PTR_TO is not POINTER_TYPE"
 msgstr ""
 
-#: tree.c:13619
+#: tree.c:13623
 #, gcc-internal-format
 msgid "TYPE_NEXT_REF_TO is not REFERENCE_TYPE"
 msgstr ""
 
-#: tree.c:13640
+#: tree.c:13644
 #, gcc-internal-format
 msgid "TYPE_BINFO is not TREE_BINFO"
 msgstr ""
 
-#: tree.c:13646
+#: tree.c:13650
 #, gcc-internal-format
 msgid "TYPE_BINFO type is not TYPE_MAIN_VARIANT"
 msgstr ""
 
-#: tree.c:13657
+#: tree.c:13661
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not record nor union"
 msgstr ""
 
-#: tree.c:13668
+#: tree.c:13672
 #, gcc-internal-format
 msgid "TYPE_OFFSET_BASETYPE is not record nor union"
 msgstr ""
 
-#: tree.c:13686
+#: tree.c:13690
 #, gcc-internal-format
 msgid "TYPE_ARRAY_MAX_SIZE not INTEGER_CST"
 msgstr ""
 
-#: tree.c:13693
+#: tree.c:13697
 #, gcc-internal-format
 msgid "TYPE_MAX_VALUE_RAW non-NULL"
 msgstr ""
 
-#: tree.c:13700
+#: tree.c:13704
 #, gcc-internal-format
 msgid "TYPE_LANG_SLOT_1 (binfo) field is non-NULL"
 msgstr ""
 
-#: tree.c:13716
+#: tree.c:13720
 #, gcc-internal-format
 msgid "Enum value is not CONST_DECL or INTEGER_CST"
 msgstr ""
 
-#: tree.c:13724
+#: tree.c:13728
 #, gcc-internal-format
 msgid "Enum value type is not INTEGER_TYPE nor convertible to the enum"
 msgstr ""
 
-#: tree.c:13731
+#: tree.c:13735
 #, gcc-internal-format
 msgid "Enum value name is not IDENTIFIER_NODE"
 msgstr ""
 
-#: tree.c:13741
+#: tree.c:13745
 #, gcc-internal-format
 msgid "Array TYPE_DOMAIN is not integer type"
 msgstr ""
 
-#: tree.c:13750
+#: tree.c:13754
 #, gcc-internal-format
 msgid "TYPE_FIELDS defined in incomplete type"
 msgstr ""
 
-#: tree.c:13772
+#: tree.c:13776
 #, gcc-internal-format
 msgid "Wrong tree in TYPE_FIELDS list"
 msgstr ""
 
-#: tree.c:13787
+#: tree.c:13791
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is %i while TYPE_CACHED_VALUES is %p"
 msgstr ""
 
-#: tree.c:13793
+#: tree.c:13797
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES is not TREE_VEC"
 msgstr ""
 
-#: tree.c:13806
+#: tree.c:13810
 #, gcc-internal-format
 msgid "wrong TYPE_CACHED_VALUES entry"
 msgstr ""
 
-#: tree.c:13819
+#: tree.c:13823
 #, gcc-internal-format
 msgid "TREE_PURPOSE is non-NULL in TYPE_ARG_TYPES list"
 msgstr ""
 
-#: tree.c:13825
+#: tree.c:13829
 #, gcc-internal-format
 msgid "Wrong entry in TYPE_ARG_TYPES list"
 msgstr ""
 
-#: tree.c:13832
+#: tree.c:13836
 #, gcc-internal-format
 msgid "TYPE_VALUES_RAW field is non-NULL"
 msgstr ""
 
-#: tree.c:13844
+#: tree.c:13848
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is set while it should not"
 msgstr ""
 
-#: tree.c:13850
+#: tree.c:13854
 #, gcc-internal-format
 msgid "TYPE_STRING_FLAG is set on wrong type code"
 msgstr ""
 
-#: tree.c:13860
+#: tree.c:13864
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not main variant"
 msgstr ""
 
-#: tree.c:13867
+#: tree.c:13871
 #, gcc-internal-format
 msgid "verify_type failed"
 msgstr "verify_type gặp lỗi"
@@ -23965,186 +23988,186 @@
 msgid "corrupted value profile: %s profile counter (%d out of %d) inconsistent with basic-block count (%d)"
 msgstr ""
 
-#: var-tracking.c:7166
+#: var-tracking.c:7184
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded with -fvar-tracking-assignments, retrying without"
 msgstr ""
 
-#: var-tracking.c:7170
+#: var-tracking.c:7188
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded"
 msgstr ""
 
-#: varasm.c:326
+#: varasm.c:337
 #, fuzzy, gcc-internal-format
 #| msgid "%+D causes a section type conflict"
 msgid "%+qD causes a section type conflict with %qD"
 msgstr "%+D là nguyên nhân gây xung đột kiểu phần"
 
-#: varasm.c:329
+#: varasm.c:340
 #, fuzzy, gcc-internal-format
 #| msgid "section type conflict with %D"
 msgid "section type conflict with %qD"
 msgstr "kiểu phần xung đột với %D"
 
-#: varasm.c:334
+#: varasm.c:345
 #, fuzzy, gcc-internal-format
 #| msgid "%+D causes a section type conflict"
 msgid "%+qD causes a section type conflict"
 msgstr "%+D là nguyên nhân gây xung đột kiểu phần"
 
-#: varasm.c:336
+#: varasm.c:347
 #, gcc-internal-format
 msgid "section type conflict"
 msgstr ""
 
-#: varasm.c:1019
+#: varasm.c:1030
 #, gcc-internal-format
 msgid "alignment of %q+D is greater than maximum object file alignment %d"
 msgstr ""
 
-#: varasm.c:1172
+#: varasm.c:1183
 #, fuzzy, gcc-internal-format
 msgid "only zero initializers are allowed in section %qs"
 msgstr "không thể khởi tạo hàm bạn %qs"
 
-#: varasm.c:1378 varasm.c:1387
+#: varasm.c:1389 varasm.c:1398
 #, gcc-internal-format
 msgid "register name not specified for %q+D"
 msgstr ""
 
-#: varasm.c:1389
+#: varasm.c:1400
 #, gcc-internal-format
 msgid "invalid register name for %q+D"
 msgstr "tên thanh ghi cho %q+D không hợp lệ"
 
-#: varasm.c:1391
+#: varasm.c:1402
 #, gcc-internal-format
 msgid "data type of %q+D isn%'t suitable for a register"
 msgstr ""
 
-#: varasm.c:1394
+#: varasm.c:1405
 #, gcc-internal-format
 msgid "the register specified for %q+D cannot be accessed by the current target"
 msgstr ""
 
-#: varasm.c:1397
+#: varasm.c:1408
 #, gcc-internal-format
 msgid "the register specified for %q+D is not general enough to be used as a register variable"
 msgstr ""
 
-#: varasm.c:1400
+#: varasm.c:1411
 #, gcc-internal-format
 msgid "register specified for %q+D isn%'t suitable for data type"
 msgstr ""
 
-#: varasm.c:1410
+#: varasm.c:1421
 #, gcc-internal-format
 msgid "global register variable has initial value"
 msgstr "biến thanh ghi toàn cục có giá trị khởi tạo"
 
-#: varasm.c:1414
+#: varasm.c:1425
 #, gcc-internal-format
 msgid "optimization may eliminate reads and/or writes to register variables"
 msgstr ""
 
-#: varasm.c:1460
+#: varasm.c:1471
 #, gcc-internal-format
 msgid "register name given for non-register variable %q+D"
 msgstr ""
 
-#: varasm.c:1870
+#: varasm.c:1881
 #, gcc-internal-format
 msgid "Patchable function entry > size"
 msgstr ""
 
-#: varasm.c:2069
+#: varasm.c:2080
 #, gcc-internal-format
 msgid "thread-local COMMON data not implemented"
 msgstr ""
 
-#: varasm.c:2102
+#: varasm.c:2113
 #, gcc-internal-format
 msgid "requested alignment for %q+D is greater than implemented alignment of %wu"
 msgstr ""
 
-#: varasm.c:2205 c/c-decl.c:5027 c/c-parser.c:1534
+#: varasm.c:2216 c/c-decl.c:5027 c/c-parser.c:1534
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t known"
 msgstr ""
 
-#: varasm.c:4910
+#: varasm.c:4921
 #, gcc-internal-format
 msgid "initializer for integer/fixed-point value is too complicated"
 msgstr ""
 
-#: varasm.c:4915
+#: varasm.c:4926
 #, gcc-internal-format
 msgid "initializer for floating value is not a floating constant"
 msgstr ""
 
-#: varasm.c:5227
+#: varasm.c:5238
 #, gcc-internal-format
 msgid "invalid initial value for member %qE"
 msgstr ""
 
-#: varasm.c:5487
+#: varasm.c:5498
 #, fuzzy, gcc-internal-format
 #| msgid "%+D declared weak after being used"
 msgid "%+qD declared weak after being used"
 msgstr "%+D đã khai báo weak sau khi được dùng"
 
-#: varasm.c:5539
+#: varasm.c:5550
 #, gcc-internal-format
 msgid "weak declaration of %q+D being applied to a already existing, static definition"
 msgstr ""
 
-#: varasm.c:5575
+#: varasm.c:5586
 #, gcc-internal-format
 msgid "weak declaration of %q+D must be public"
 msgstr ""
 
-#: varasm.c:5579
+#: varasm.c:5590
 #, gcc-internal-format
 msgid "weak declaration of %q+D not supported"
 msgstr ""
 
-#: varasm.c:5608 varasm.c:5912
+#: varasm.c:5619 varasm.c:5926
 #, gcc-internal-format
 msgid "only weak aliases are supported in this configuration"
 msgstr ""
 
-#: varasm.c:5802
+#: varasm.c:5813
 #, gcc-internal-format
 msgid "weakref is not supported in this configuration"
 msgstr "weakref không được hỗ trợ trong cấu hình này"
 
-#: varasm.c:5834
+#: varasm.c:5846
 #, gcc-internal-format
 msgid "ifunc is not supported on this target"
 msgstr ""
 
-#: varasm.c:5892
+#: varasm.c:5904
 #, gcc-internal-format
 msgid "weakref %q+D ultimately targets itself"
 msgstr ""
 
-#: varasm.c:5894
+#: varasm.c:5906
 #, gcc-internal-format
 msgid "weakref %q+D must have static linkage"
 msgstr ""
 
-#: varasm.c:5901
+#: varasm.c:5913
 #, gcc-internal-format
 msgid "alias definitions not supported in this configuration"
 msgstr ""
 
-#: varasm.c:5909
+#: varasm.c:5923
 #, gcc-internal-format
 msgid "ifunc is not supported in this configuration"
 msgstr ""
 
-#: varasm.c:6127 config/sol2.c:159 config/i386/winnt.c:265
+#: varasm.c:6141 config/sol2.c:159 config/i386/winnt.c:265
 #, gcc-internal-format
 msgid "visibility attribute not supported in this configuration; ignored"
 msgstr ""
@@ -24220,181 +24243,187 @@
 msgid "bytecode stream: tag %s is not in the expected range [%s, %s]"
 msgstr ""
 
-#: c-family/c-attribs.c:529
+#: c-family/c-attribs.c:524
+#, fuzzy, gcc-internal-format
+#| msgid "%qE attribute ignored for %qE"
+msgid "%qE attribute ignored for type %qT"
+msgstr "thuộc tính %qE bị lờ đi cho %qE"
+
+#: c-family/c-attribs.c:536
 #, gcc-internal-format
 msgid "%qE attribute ignored for field of type %qT"
 msgstr ""
 
-#: c-family/c-attribs.c:696
+#: c-family/c-attribs.c:706
 #, fuzzy, gcc-internal-format
 #| msgid "attribute %<target%> argument not a string"
 msgid "no_sanitize argument not a string"
 msgstr "thuộc tính %<target%> không là một chuỗi"
 
-#: c-family/c-attribs.c:826 ada/gcc-interface/utils.c:6235
+#: c-family/c-attribs.c:837 ada/gcc-interface/utils.c:6240
 #, gcc-internal-format
 msgid "%qE attribute ignored due to conflict with attribute %qs"
 msgstr ""
 
-#: c-family/c-attribs.c:875
+#: c-family/c-attribs.c:886
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute ignored. Use -fcf-protection option to enable it"
 msgstr "Thuộc tính %qE bị lờ đi với các kiểu"
 
-#: c-family/c-attribs.c:914 c-family/c-attribs.c:920 c-family/c-attribs.c:3388
-#: c-family/c-attribs.c:3423 c-family/c-attribs.c:3429
+#: c-family/c-attribs.c:925 c-family/c-attribs.c:931 c-family/c-attribs.c:3399
+#: c-family/c-attribs.c:3434 c-family/c-attribs.c:3440
 #, gcc-internal-format
 msgid "%qE attribute ignored due to conflict with %qs attribute"
 msgstr ""
 
-#: c-family/c-attribs.c:976 brig/brig-lang.c:482 lto/lto-lang.c:288
+#: c-family/c-attribs.c:987 brig/brig-lang.c:482 lto/lto-lang.c:288
 #, gcc-internal-format
 msgid "%qE attribute has no effect on unit local functions"
 msgstr ""
 
-#: c-family/c-attribs.c:1130
+#: c-family/c-attribs.c:1141
 #, gcc-internal-format
 msgid "%qE attribute have effect only on public objects"
 msgstr ""
 
-#: c-family/c-attribs.c:1159
+#: c-family/c-attribs.c:1170
 #, gcc-internal-format
 msgid "%qE attribute only affects top level objects"
 msgstr "Thuộc tính %qE chỉ được áp dụng cho các đối tượng mức"
 
-#: c-family/c-attribs.c:1198 c-family/c-attribs.c:2682
+#: c-family/c-attribs.c:1209 c-family/c-attribs.c:2693
 #, fuzzy, gcc-internal-format
 #| msgid "%<return%> with a value, in function returning void"
 msgid "%qE attribute on function returning %<void%>"
 msgstr "%<return%> với một giá trị, trong hàm trả lại void (rỗng)"
 
-#: c-family/c-attribs.c:1221 c-family/c-pragma.c:419
+#: c-family/c-attribs.c:1232 c-family/c-pragma.c:419
 #, gcc-internal-format
 msgid "scalar_storage_order is not supported because endianness is not uniform"
 msgstr ""
 
-#: c-family/c-attribs.c:1238
+#: c-family/c-attribs.c:1249
 #, gcc-internal-format
 msgid "scalar_storage_order argument must be one of \"big-endian\" or \"little-endian\""
 msgstr ""
 
-#: c-family/c-attribs.c:1334
+#: c-family/c-attribs.c:1345
 #, gcc-internal-format
 msgid "destructor priorities are not supported"
 msgstr "các quyền ưu tiên hủy tử là không được hỗ trợ"
 
-#: c-family/c-attribs.c:1336
+#: c-family/c-attribs.c:1347
 #, gcc-internal-format
 msgid "constructor priorities are not supported"
 msgstr "các quyền ưu tiên cấu tử là không được hỗ trợ"
 
-#: c-family/c-attribs.c:1358
+#: c-family/c-attribs.c:1369
 #, gcc-internal-format, gfc-internal-format
 msgid "destructor priorities from 0 to %d are reserved for the implementation"
 msgstr ""
 
-#: c-family/c-attribs.c:1363
+#: c-family/c-attribs.c:1374
 #, gcc-internal-format, gfc-internal-format
 msgid "constructor priorities from 0 to %d are reserved for the implementation"
 msgstr ""
 
-#: c-family/c-attribs.c:1371
+#: c-family/c-attribs.c:1382
 #, gcc-internal-format, gfc-internal-format
 msgid "destructor priorities must be integers from 0 to %d inclusive"
 msgstr ""
 
-#: c-family/c-attribs.c:1374
+#: c-family/c-attribs.c:1385
 #, gcc-internal-format, gfc-internal-format
 msgid "constructor priorities must be integers from 0 to %d inclusive"
 msgstr ""
 
-#: c-family/c-attribs.c:1527
+#: c-family/c-attribs.c:1538
 #, gcc-internal-format
 msgid "unknown machine mode %qE"
 msgstr "không hiểu chế độ máy %qE"
 
-#: c-family/c-attribs.c:1557
+#: c-family/c-attribs.c:1568
 #, gcc-internal-format
 msgid "specifying vector types with __attribute__ ((mode)) is deprecated"
 msgstr ""
 
-#: c-family/c-attribs.c:1560
+#: c-family/c-attribs.c:1571
 #, gcc-internal-format
 msgid "use __attribute__ ((vector_size)) instead"
 msgstr "sử dụng  __attribute__ ((vector_size)) để thay thế"
 
-#: c-family/c-attribs.c:1569
+#: c-family/c-attribs.c:1580
 #, gcc-internal-format
 msgid "unable to emulate %qs"
 msgstr "không thể mô phỏng %qs"
 
-#: c-family/c-attribs.c:1582
+#: c-family/c-attribs.c:1593
 #, gcc-internal-format
 msgid "invalid pointer mode %qs"
 msgstr "chế độ con trỏ %qs không hợp lệ"
 
-#: c-family/c-attribs.c:1599
+#: c-family/c-attribs.c:1610
 #, gcc-internal-format
 msgid "signedness of type and machine mode %qs don%'t match"
 msgstr ""
 
-#: c-family/c-attribs.c:1610
+#: c-family/c-attribs.c:1621
 #, gcc-internal-format
 msgid "no data type for mode %qs"
 msgstr "không có kiểu dữ liệu cho chế độ %qs"
 
-#: c-family/c-attribs.c:1620
+#: c-family/c-attribs.c:1631
 #, gcc-internal-format
 msgid "cannot use mode %qs for enumeral types"
 msgstr "không thể dùng chế độ %qs cho các kiểu liệt kê"
 
-#: c-family/c-attribs.c:1647
+#: c-family/c-attribs.c:1658
 #, gcc-internal-format
 msgid "mode %qs applied to inappropriate type"
 msgstr ""
 
-#: c-family/c-attribs.c:1669
+#: c-family/c-attribs.c:1680
 #, gcc-internal-format
 msgid "section attributes are not supported for this target"
 msgstr ""
 
-#: c-family/c-attribs.c:1675
+#: c-family/c-attribs.c:1686
 #, gcc-internal-format
 msgid "section attribute not allowed for %q+D"
 msgstr ""
 
-#: c-family/c-attribs.c:1681
+#: c-family/c-attribs.c:1692
 #, gcc-internal-format
 msgid "section attribute argument not a string constant"
 msgstr "đối số thuộc tính phần không phải là một hằng chuỗi"
 
-#: c-family/c-attribs.c:1690
+#: c-family/c-attribs.c:1701
 #, gcc-internal-format
 msgid "section attribute cannot be specified for local variables"
 msgstr ""
 
-#: c-family/c-attribs.c:1700 config/bfin/bfin.c:4806 config/bfin/bfin.c:4857
+#: c-family/c-attribs.c:1711 config/bfin/bfin.c:4806 config/bfin/bfin.c:4857
 #: config/bfin/bfin.c:4883 config/bfin/bfin.c:4896
 #, gcc-internal-format
 msgid "section of %q+D conflicts with previous declaration"
 msgstr ""
 
-#: c-family/c-attribs.c:1708
+#: c-family/c-attribs.c:1719
 #, gcc-internal-format
 msgid "section of %q+D cannot be overridden"
 msgstr "phần của %q+D không thể bị ghi đè"
 
-#: c-family/c-attribs.c:1773
+#: c-family/c-attribs.c:1784
 #, gcc-internal-format, gfc-internal-format
 msgid "requested alignment %d is larger than %d"
 msgstr ""
 
-#: c-family/c-attribs.c:1866
+#: c-family/c-attribs.c:1877
 #, gcc-internal-format
 msgid "alignment may not be specified for %q+D"
 msgstr ""
 
-#: c-family/c-attribs.c:1886
+#: c-family/c-attribs.c:1897
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute of %qs conflicts with %s attribute at %L"
 msgid "ignoring attribute %<%E (%u)%> because it conflicts with attribute %<%E (%u)%>"
@@ -24401,295 +24430,295 @@
 msgstr "thuộc tính %s của %qs xung đột với thuộc tính %s tại %L"
 
 #. Do not error out for attribute warn_if_not_aligned.
-#: c-family/c-attribs.c:1891 c-family/c-attribs.c:1920
+#: c-family/c-attribs.c:1902 c-family/c-attribs.c:1931
 #, gcc-internal-format
 msgid "alignment for %q+D must be at least %d"
 msgstr "sắp hàng cho %q+D phải ít nhất %d"
 
-#: c-family/c-attribs.c:1916
+#: c-family/c-attribs.c:1927
 #, gcc-internal-format
 msgid "alignment for %q+D was previously specified as %d and may not be decreased"
 msgstr ""
 
-#: c-family/c-attribs.c:1943
+#: c-family/c-attribs.c:1954
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> can only be specified for functions"
 msgid "%<warn_if_not_aligned%> may not be specified for %q+D"
 msgstr "%<inline%> chỉ có thể được chỉ định cho hàm"
 
-#: c-family/c-attribs.c:1986
+#: c-family/c-attribs.c:1997
 #, gcc-internal-format
 msgid "inline function %q+D declared weak"
 msgstr "hàm chung dòng %q+D được khai báo yếu"
 
-#: c-family/c-attribs.c:1991
+#: c-family/c-attribs.c:2002
 #, gcc-internal-format
 msgid "indirect function %q+D cannot be declared weak"
 msgstr ""
 
-#: c-family/c-attribs.c:2015
+#: c-family/c-attribs.c:2026
 #, gcc-internal-format
 msgid "%qE attribute is only applicable on functions"
 msgstr "thuộc tính %qE chỉ áp dụng cho các hàm"
 
-#: c-family/c-attribs.c:2046
+#: c-family/c-attribs.c:2057
 #, gcc-internal-format
 msgid "%q+D defined both normally and as %qE attribute"
 msgstr ""
 
-#: c-family/c-attribs.c:2054
+#: c-family/c-attribs.c:2065
 #, gcc-internal-format
 msgid "weak %q+D cannot be defined %qE"
 msgstr ""
 
-#: c-family/c-attribs.c:2071 c-family/c-attribs.c:2582
+#: c-family/c-attribs.c:2082 c-family/c-attribs.c:2593
 #, gcc-internal-format
 msgid "attribute %qE argument not a string"
 msgstr ""
 
-#: c-family/c-attribs.c:2106
+#: c-family/c-attribs.c:2117
 #, fuzzy, gcc-internal-format
 #| msgid "%+D declared alias after being used"
 msgid "%+qD declared alias after being used"
 msgstr "%+D khai báo bí danh sau khi được sử dụng"
 
-#: c-family/c-attribs.c:2108
+#: c-family/c-attribs.c:2119
 #, fuzzy, gcc-internal-format
 #| msgid "%+D declared ifunc after being used"
 msgid "%+qD declared ifunc after being used"
 msgstr "%q+D đã khai báo ifunc sau khi được dùng"
 
-#: c-family/c-attribs.c:2159
+#: c-family/c-attribs.c:2170
 #, gcc-internal-format
 msgid "indirect function %q+D cannot be declared weakref"
 msgstr ""
 
-#: c-family/c-attribs.c:2181
+#: c-family/c-attribs.c:2192
 #, gcc-internal-format
 msgid "weakref attribute must appear before alias attribute"
 msgstr ""
 
-#: c-family/c-attribs.c:2193
+#: c-family/c-attribs.c:2204
 #, fuzzy, gcc-internal-format
 #| msgid "%+D declared weakref after being used"
 msgid "%+qD declared weakref after being used"
 msgstr "%+D đã khai báo weakref sau khi được dùng"
 
-#: c-family/c-attribs.c:2217
+#: c-family/c-attribs.c:2228
 #, gcc-internal-format
 msgid "%qE attribute ignored on non-class types"
 msgstr ""
 
-#: c-family/c-attribs.c:2223
+#: c-family/c-attribs.c:2234
 #, gcc-internal-format
 msgid "%qE attribute ignored because %qT is already defined"
 msgstr ""
 
-#: c-family/c-attribs.c:2236
+#: c-family/c-attribs.c:2247
 #, gcc-internal-format
 msgid "visibility argument not a string"
 msgstr ""
 
-#: c-family/c-attribs.c:2248
+#: c-family/c-attribs.c:2259
 #, gcc-internal-format
 msgid "%qE attribute ignored on types"
 msgstr "Thuộc tính %qE bị lờ đi với các kiểu"
 
-#: c-family/c-attribs.c:2264
+#: c-family/c-attribs.c:2275
 #, gcc-internal-format
 msgid "visibility argument must be one of \"default\", \"hidden\", \"protected\" or \"internal\""
 msgstr ""
 
-#: c-family/c-attribs.c:2275
+#: c-family/c-attribs.c:2286
 #, gcc-internal-format
 msgid "%qD redeclared with different visibility"
 msgstr ""
 
-#: c-family/c-attribs.c:2278 c-family/c-attribs.c:2282
+#: c-family/c-attribs.c:2289 c-family/c-attribs.c:2293
 #, gcc-internal-format
 msgid "%qD was declared %qs which implies default visibility"
 msgstr ""
 
-#: c-family/c-attribs.c:2320
+#: c-family/c-attribs.c:2331
 #, gcc-internal-format
 msgid "tls_model argument not a string"
 msgstr ""
 
-#: c-family/c-attribs.c:2333
+#: c-family/c-attribs.c:2344
 #, gcc-internal-format
 msgid "tls_model argument must be one of \"local-exec\", \"initial-exec\", \"local-dynamic\" or \"global-dynamic\""
 msgstr ""
 
-#: c-family/c-attribs.c:2353 c-family/c-attribs.c:2656
-#: c-family/c-attribs.c:3497 config/m32c/m32c.c:2944
+#: c-family/c-attribs.c:2364 c-family/c-attribs.c:2667
+#: c-family/c-attribs.c:3508 config/m32c/m32c.c:2944
 #, gcc-internal-format
 msgid "%qE attribute applies only to functions"
 msgstr ""
 
-#: c-family/c-attribs.c:2417
+#: c-family/c-attribs.c:2428
 #, gcc-internal-format
 msgid "alloc_size parameter outside range"
 msgstr ""
 
-#: c-family/c-attribs.c:2443
+#: c-family/c-attribs.c:2454
 #, gcc-internal-format
 msgid "alloc_align parameter outside range"
 msgstr ""
 
-#: c-family/c-attribs.c:2467
+#: c-family/c-attribs.c:2478
 #, gcc-internal-format
 msgid "assume_aligned parameter not integer constant"
 msgstr "tham số assume_aligned không phải là một hằng nguyên"
 
-#: c-family/c-attribs.c:2595
+#: c-family/c-attribs.c:2606
 #, gcc-internal-format
 msgid "only %<inbranch%> and %<notinbranch%> flags are allowed for %<__simd__%> attribute"
 msgstr ""
 
-#: c-family/c-attribs.c:2662 c-family/c-attribs.c:3503
+#: c-family/c-attribs.c:2673 c-family/c-attribs.c:3514
 #, gcc-internal-format
 msgid "can%'t set %qE attribute after definition"
 msgstr ""
 
-#: c-family/c-attribs.c:2727
+#: c-family/c-attribs.c:2738
 #, gcc-internal-format
 msgid "%qE attribute duplicated"
 msgstr "thuộc tính %qE bị trùng"
 
-#: c-family/c-attribs.c:2729
+#: c-family/c-attribs.c:2740
 #, gcc-internal-format
 msgid "%qE attribute follows %qE"
 msgstr "thuộc tính %qE theo %qE"
 
-#: c-family/c-attribs.c:2828
+#: c-family/c-attribs.c:2839
 #, gcc-internal-format
 msgid "type was previously declared %qE"
 msgstr ""
 
-#: c-family/c-attribs.c:2841 cp/class.c:4397
+#: c-family/c-attribs.c:2852 cp/class.c:4401
 #, gcc-internal-format
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
 msgstr ""
 
-#: c-family/c-attribs.c:2899
+#: c-family/c-attribs.c:2910
 #, gcc-internal-format
 msgid "%qE argument not an identifier"
 msgstr "%qE đối số không phải là một định danh"
 
-#: c-family/c-attribs.c:2910
+#: c-family/c-attribs.c:2921
 #, gcc-internal-format
 msgid "%qD is not compatible with %qD"
 msgstr "%qD không tương thích với %qD"
 
-#: c-family/c-attribs.c:2913
+#: c-family/c-attribs.c:2924
 #, gcc-internal-format
 msgid "%qE argument is not a function"
 msgstr ""
 
-#: c-family/c-attribs.c:2961
+#: c-family/c-attribs.c:2972
 #, gcc-internal-format
 msgid "deprecated message is not a string"
 msgstr ""
 
-#: c-family/c-attribs.c:3002
+#: c-family/c-attribs.c:3013
 #, gcc-internal-format
 msgid "%qE attribute ignored for %qE"
 msgstr "thuộc tính %qE bị lờ đi cho %qE"
 
-#: c-family/c-attribs.c:3065
+#: c-family/c-attribs.c:3076
 #, gcc-internal-format
 msgid "invalid vector type for attribute %qE"
 msgstr ""
 
-#: c-family/c-attribs.c:3071 ada/gcc-interface/utils.c:3896
+#: c-family/c-attribs.c:3082 ada/gcc-interface/utils.c:3899
 #, gcc-internal-format
 msgid "vector size not an integral multiple of component size"
 msgstr ""
 
-#: c-family/c-attribs.c:3077 ada/gcc-interface/utils.c:3903
+#: c-family/c-attribs.c:3088 ada/gcc-interface/utils.c:3906
 #, gcc-internal-format
 msgid "zero vector size"
 msgstr "kích thước véc-tơ không"
 
-#: c-family/c-attribs.c:3085
+#: c-family/c-attribs.c:3096
 #, gcc-internal-format
 msgid "number of components of the vector not a power of two"
 msgstr ""
 
-#: c-family/c-attribs.c:3118 ada/gcc-interface/utils.c:6092
+#: c-family/c-attribs.c:3129 ada/gcc-interface/utils.c:6098
 #, gcc-internal-format
 msgid "nonnull attribute without arguments on a non-prototype"
 msgstr ""
 
-#: c-family/c-attribs.c:3137 ada/gcc-interface/utils.c:6106
+#: c-family/c-attribs.c:3148 ada/gcc-interface/utils.c:6112
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument has invalid operand number (argument %lu)"
 msgstr ""
 
-#: c-family/c-attribs.c:3159 ada/gcc-interface/utils.c:6128
+#: c-family/c-attribs.c:3170 ada/gcc-interface/utils.c:6134
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument with out-of-range operand number (argument %lu, operand %lu)"
 msgstr ""
 
-#: c-family/c-attribs.c:3168 ada/gcc-interface/utils.c:6137
+#: c-family/c-attribs.c:3179 ada/gcc-interface/utils.c:6143
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument references non-pointer operand (argument %lu, operand %lu)"
 msgstr ""
 
-#: c-family/c-attribs.c:3208
+#: c-family/c-attribs.c:3219
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on types"
 msgid "%qE attribute ignored on objects of type %qT"
 msgstr "Thuộc tính %qE bị lờ đi với các kiểu"
 
-#: c-family/c-attribs.c:3216
+#: c-family/c-attribs.c:3227
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute doesn't apply to functions"
 msgid "%qE attribute does not apply to functions"
 msgstr "Thuộc tính %qE không được áp dụng cho các hàm"
 
-#: c-family/c-attribs.c:3273
+#: c-family/c-attribs.c:3284
 #, gcc-internal-format
 msgid "cleanup argument not an identifier"
 msgstr "dọn các đối số không phải định danh"
 
-#: c-family/c-attribs.c:3280
+#: c-family/c-attribs.c:3291
 #, gcc-internal-format
 msgid "cleanup argument not a function"
 msgstr "dọn các đối số không phải hàm"
 
-#: c-family/c-attribs.c:3317
+#: c-family/c-attribs.c:3328
 #, gcc-internal-format
 msgid "%qE attribute requires prototypes with named arguments"
 msgstr ""
 
-#: c-family/c-attribs.c:3325
+#: c-family/c-attribs.c:3336
 #, gcc-internal-format
 msgid "%qE attribute only applies to variadic functions"
 msgstr ""
 
-#: c-family/c-attribs.c:3341 ada/gcc-interface/utils.c:6179
+#: c-family/c-attribs.c:3352 ada/gcc-interface/utils.c:6185
 #, gcc-internal-format
 msgid "requested position is not an integer constant"
 msgstr ""
 
-#: c-family/c-attribs.c:3349 ada/gcc-interface/utils.c:6186
+#: c-family/c-attribs.c:3360 ada/gcc-interface/utils.c:6192
 #, gcc-internal-format
 msgid "requested position is less than zero"
 msgstr ""
 
-#: c-family/c-attribs.c:3404
+#: c-family/c-attribs.c:3415
 #, fuzzy, gcc-internal-format
 #| msgid "Expected binding attribute at %C"
 msgid "empty string in attribute %<target%>"
 msgstr "Cần thuộc tính ràng buộc tại %C"
 
-#: c-family/c-attribs.c:3520
+#: c-family/c-attribs.c:3531
 #, gcc-internal-format
 msgid "returns_nonnull attribute on a function not returning a pointer"
 msgstr ""
 
-#: c-family/c-attribs.c:3535
+#: c-family/c-attribs.c:3546
 #, gcc-internal-format
 msgid "%qE attribute is only valid on %<struct%> type"
 msgstr ""
@@ -24734,13 +24763,13 @@
 msgid "__builtin_shuffle argument vector(s) inner type must have the same size as inner type of the mask"
 msgstr ""
 
-#: c-family/c-common.c:1262 c-family/c-warn.c:1194
+#: c-family/c-common.c:1262 c-family/c-warn.c:1202
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "unsigned conversion from %qT to %qT changes value from %qE to %qE"
 msgstr "chuyển đổi từ %qT sang %qT là chưa rõ ràng"
 
-#: c-family/c-common.c:1267 c-family/c-warn.c:1202
+#: c-family/c-common.c:1267 c-family/c-warn.c:1210
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "unsigned conversion from %qT to %qT changes the value of %qE"
@@ -24873,7 +24902,7 @@
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "gợi ý là dùng dấu ngoặc đơn bao quanh phép gán được dùng như là giá trị chân lý"
 
-#: c-family/c-common.c:3518 c/c-decl.c:4325 c/c-decl.c:6430 c/c-typeck.c:14177
+#: c-family/c-common.c:3518 c/c-decl.c:4325 c/c-decl.c:6450 c/c-typeck.c:14182
 #, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr "dùng %<restrict%> không hợp lệ"
@@ -24953,7 +24982,7 @@
 msgid "duplicate case value"
 msgstr "trùng giá trị cho case"
 
-#: c-family/c-common.c:4867 c-family/c-warn.c:2216
+#: c-family/c-common.c:4867 c-family/c-warn.c:2225
 #, gcc-internal-format
 msgid "previously used here"
 msgstr "cái trước được dùng là ở đây"
@@ -24998,194 +25027,194 @@
 msgid "missing sentinel in function call"
 msgstr ""
 
-#: c-family/c-common.c:5411
+#: c-family/c-common.c:5409
 #, gcc-internal-format, gfc-internal-format
 msgid "null argument where non-null required (argument %lu)"
 msgstr ""
 
-#: c-family/c-common.c:5506 c-family/c-common.c:5553
+#: c-family/c-common.c:5504 c-family/c-common.c:5551
 #, gcc-internal-format
 msgid "bad option %qs to attribute %<optimize%>"
 msgstr ""
 
-#: c-family/c-common.c:5509 c-family/c-common.c:5557
+#: c-family/c-common.c:5507 c-family/c-common.c:5555
 #, fuzzy, gcc-internal-format
 msgid "bad option %qs to pragma %<optimize%>"
 msgstr "thao tác không hợp lệ cho %<#pragma omp atomic%>"
 
-#: c-family/c-common.c:5589
+#: c-family/c-common.c:5587
 #, gcc-internal-format
 msgid "%<fallthrough%> attribute specified multiple times"
 msgstr ""
 
-#: c-family/c-common.c:5593
+#: c-family/c-common.c:5591
 #, gcc-internal-format
 msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr ""
 
-#: c-family/c-common.c:5733 c-family/c-common.c:6485 c-family/c-common.c:6558
+#: c-family/c-common.c:5731 c-family/c-common.c:6477 c-family/c-common.c:6550
 #: c/c-typeck.c:3555
 #, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr "quá ít đối số cho hàm %qE"
 
-#: c-family/c-common.c:5738 c-family/c-common.c:6584 c/c-typeck.c:3284
+#: c-family/c-common.c:5736 c-family/c-common.c:6576 c/c-typeck.c:3284
 #, gcc-internal-format
 msgid "too many arguments to function %qE"
 msgstr "quá nhiều đối số cho hàm %qE"
 
-#: c-family/c-common.c:5769
+#: c-family/c-common.c:5767
 #, fuzzy, gcc-internal-format
 #| msgid "%qs argument of %qs intrinsic at %L must be a constant"
 msgid "third argument to function %qE must be a constant integer"
 msgstr "đối số %qs của %qs intrinsict tại %L phải là hằng"
 
-#: c-family/c-common.c:5794
+#: c-family/c-common.c:5792
 #, gcc-internal-format
 msgid "second argument to function %qE must be a constant integer power of 2 between %qi and %qu bits"
 msgstr ""
 
-#: c-family/c-common.c:5815 c-family/c-common.c:5859
+#: c-family/c-common.c:5813 c-family/c-common.c:5857
 #, gcc-internal-format
 msgid "non-floating-point argument in call to function %qE"
 msgstr ""
 
-#: c-family/c-common.c:5838
+#: c-family/c-common.c:5836
 #, gcc-internal-format
 msgid "non-floating-point arguments in call to function %qE"
 msgstr ""
 
-#: c-family/c-common.c:5852
+#: c-family/c-common.c:5850
 #, gcc-internal-format
 msgid "non-const integer argument %u in call to function %qE"
 msgstr ""
 
-#: c-family/c-common.c:5872
+#: c-family/c-common.c:5870
 #, gcc-internal-format
 msgid "non-integer argument 3 in call to function %qE"
 msgstr ""
 
-#: c-family/c-common.c:5889 c-family/c-common.c:5925
+#: c-family/c-common.c:5887 c-family/c-common.c:5923
 #, gcc-internal-format
 msgid "argument %u in call to function %qE does not have integral type"
 msgstr ""
 
-#: c-family/c-common.c:5896
+#: c-family/c-common.c:5894
 #, fuzzy, gcc-internal-format
 msgid "argument 3 in call to function %qE does not have pointer to integral type"
 msgstr "%qE không có con trỏ hay kiểu mảng"
 
-#: c-family/c-common.c:5902
+#: c-family/c-common.c:5900
 #, fuzzy, gcc-internal-format
 msgid "argument 3 in call to function %qE has pointer to enumerated type"
 msgstr "Cảnh báo khi xóa một con trỏ tới kiểu không hoàn toàn."
 
-#: c-family/c-common.c:5908
+#: c-family/c-common.c:5906
 #, gcc-internal-format
 msgid "argument 3 in call to function %qE has pointer to boolean type"
 msgstr ""
 
-#: c-family/c-common.c:5931
+#: c-family/c-common.c:5929
 #, gcc-internal-format
 msgid "argument 3 in call to function %qE has enumerated type"
 msgstr ""
 
-#: c-family/c-common.c:5937
+#: c-family/c-common.c:5935
 #, gcc-internal-format
 msgid "argument 3 in call to function %qE has boolean type"
 msgstr ""
 
-#: c-family/c-common.c:6184
+#: c-family/c-common.c:6183
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to static data member %qD"
 msgstr ""
 
-#: c-family/c-common.c:6189
+#: c-family/c-common.c:6188
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> when %<operator[]%> is overloaded"
 msgstr ""
 
-#: c-family/c-common.c:6196
+#: c-family/c-common.c:6195
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to a non constant address"
 msgstr ""
 
-#: c-family/c-common.c:6209
+#: c-family/c-common.c:6208
 #, gcc-internal-format
 msgid "attempt to take address of bit-field structure member %qD"
 msgstr ""
 
-#: c-family/c-common.c:6261
+#: c-family/c-common.c:6260
 #, gcc-internal-format
 msgid "index %E denotes an offset greater than size of %qT"
 msgstr ""
 
-#: c-family/c-common.c:6427 cp/init.c:3004 cp/init.c:3023
+#: c-family/c-common.c:6419 cp/init.c:3020 cp/init.c:3039
 #, gcc-internal-format
 msgid "size of array is too large"
 msgstr "kích cỡ mảng là quá lớn"
 
-#: c-family/c-common.c:6517
+#: c-family/c-common.c:6509
 #, gcc-internal-format
 msgid "operand type %qT is incompatible with argument %d of %qE"
 msgstr ""
 
-#: c-family/c-common.c:6651
+#: c-family/c-common.c:6643
 #, gcc-internal-format
 msgid "incorrect number of arguments to function %qE"
 msgstr ""
 
-#: c-family/c-common.c:6665
+#: c-family/c-common.c:6657
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a non-void pointer type"
 msgstr ""
 
-#: c-family/c-common.c:6674
+#: c-family/c-common.c:6666
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a constant size type"
 msgstr ""
 
-#: c-family/c-common.c:6685
+#: c-family/c-common.c:6677
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a nonzero size object"
 msgstr ""
 
-#: c-family/c-common.c:6706
+#: c-family/c-common.c:6698
 #, gcc-internal-format
 msgid "argument %d of %qE must be a pointer type"
 msgstr ""
 
-#: c-family/c-common.c:6714
+#: c-family/c-common.c:6706
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must be a pointer to a constant size type"
 msgstr "đối số %d của %qE phải là một địa chỉ"
 
-#: c-family/c-common.c:6720
+#: c-family/c-common.c:6712
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a function"
 msgstr "đối số %d của %qE phải là bội số của %d"
 
-#: c-family/c-common.c:6728
+#: c-family/c-common.c:6720
 #, gcc-internal-format
 msgid "size mismatch in argument %d of %qE"
 msgstr ""
 
-#: c-family/c-common.c:6740
+#: c-family/c-common.c:6732
 #, gcc-internal-format
 msgid "non-integer memory model argument %d of %qE"
 msgstr ""
 
-#: c-family/c-common.c:6753
+#: c-family/c-common.c:6745
 #, gcc-internal-format
 msgid "invalid memory model argument %d of %qE"
 msgstr ""
 
-#: c-family/c-common.c:7672
+#: c-family/c-common.c:7664
 #, gcc-internal-format
 msgid "index value is out of bound"
 msgstr "giá trị chỉ mục nằm ngoài phạm vi cho phép"
 
-#: c-family/c-common.c:7714 c-family/c-common.c:7763 c-family/c-common.c:7779
+#: c-family/c-common.c:7706 c-family/c-common.c:7755 c-family/c-common.c:7771
 #, gcc-internal-format
 msgid "conversion of scalar %qT to vector %qT involves truncation"
 msgstr ""
@@ -25192,22 +25221,22 @@
 
 #. Reject arguments that are built-in functions with
 #. no library fallback.
-#: c-family/c-common.c:7867
+#: c-family/c-common.c:7859
 #, gcc-internal-format
 msgid "built-in function %qE must be directly called"
 msgstr ""
 
-#: c-family/c-common.c:7889 c/c-decl.c:6177
+#: c-family/c-common.c:7881 c/c-decl.c:6197
 #, gcc-internal-format
 msgid "size of array %qE is too large"
 msgstr "kích cỡ mảng %qE quá lớn"
 
-#: c-family/c-common.c:7891 c/c-decl.c:6180
+#: c-family/c-common.c:7883 c/c-decl.c:6200
 #, gcc-internal-format
 msgid "size of unnamed array is too large"
 msgstr "kích thước của mảng chưa đặt tên là quá lớn"
 
-#: c-family/c-common.c:7921
+#: c-family/c-common.c:7913
 #, gcc-internal-format
 msgid "environment variable SOURCE_DATE_EPOCH must expand to a non-negative integer less than or equal to %wd"
 msgstr ""
@@ -25732,7 +25761,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr ""
 
-#: c-family/c-omp.c:557 cp/semantics.c:8186
+#: c-family/c-omp.c:557 cp/semantics.c:8189
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr ""
@@ -25747,22 +25776,22 @@
 msgid "%qE is not initialized"
 msgstr "%qE chưa được khởi tạo"
 
-#: c-family/c-omp.c:599 cp/semantics.c:8076
+#: c-family/c-omp.c:599 cp/semantics.c:8079
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.c:704 cp/semantics.c:7732
+#: c-family/c-omp.c:704 cp/semantics.c:7735
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.c:711 cp/semantics.c:8082
+#: c-family/c-omp.c:711 cp/semantics.c:8085
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "thiếu biểu thức gia số"
 
-#: c-family/c-omp.c:775 cp/semantics.c:7847
+#: c-family/c-omp.c:775 cp/semantics.c:7850
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "biểu thức gia không hợp lệ"
@@ -25817,112 +25846,127 @@
 msgid "%<-Wabi=1%> is not supported, using =2"
 msgstr "%<-Wabi=1%> không được hỗ trợ, dùng =2"
 
-#: c-family/c-opts.c:612 fortran/cpp.c:350
+#: c-family/c-opts.c:610 fortran/cpp.c:350
 #, gcc-internal-format
 msgid "output filename specified twice"
 msgstr "tên tập tin kết xuất được chỉ ra hai lần"
 
-#: c-family/c-opts.c:799
+#: c-family/c-opts.c:797
 #, gcc-internal-format
 msgid "-fexcess-precision=standard for C++"
 msgstr "-fexcess-precision=standard dành cho C++"
 
-#: c-family/c-opts.c:834
+#: c-family/c-opts.c:832
 #, gcc-internal-format
 msgid "-fno-gnu89-inline is only supported in GNU99 or C99 mode"
 msgstr ""
 
-#: c-family/c-opts.c:880
+#: c-family/c-opts.c:878
 #, gcc-internal-format
 msgid "-Wformat-y2k ignored without -Wformat"
 msgstr "-Wformat-y2k bị lờ đi nếu không có -Wformat"
 
-#: c-family/c-opts.c:882
+#: c-family/c-opts.c:880
 #, gcc-internal-format
 msgid "-Wformat-extra-args ignored without -Wformat"
 msgstr "-Wformat-extra-args bị lờ đi nếu không có -Wformat"
 
-#: c-family/c-opts.c:884
+#: c-family/c-opts.c:882
 #, gcc-internal-format
 msgid "-Wformat-zero-length ignored without -Wformat"
 msgstr "-Wformat-zero-length bị lờ đi nếu không có -Wformat"
 
-#: c-family/c-opts.c:886
+#: c-family/c-opts.c:884
 #, gcc-internal-format
 msgid "-Wformat-nonliteral ignored without -Wformat"
 msgstr "-Wformat-nonliteral bị lờ đi nếu không có -Wformat"
 
-#: c-family/c-opts.c:888
+#: c-family/c-opts.c:886
 #, gcc-internal-format
 msgid "-Wformat-contains-nul ignored without -Wformat"
 msgstr "-Wformat-contains-nul bị lờ đi nếu không có -Wformat"
 
-#: c-family/c-opts.c:890
+#: c-family/c-opts.c:888
 #, gcc-internal-format
 msgid "-Wformat-security ignored without -Wformat"
 msgstr "-Wformat-security bị lờ đi nếu không có -Wformat"
 
-#: c-family/c-opts.c:928
+#: c-family/c-opts.c:918
 #, gcc-internal-format
 msgid "%<-fabi-compat-version=1%> is not supported, using =2"
 msgstr "%<-fabi-compat-version=1%> không được hỗ trợ, dùng =2"
 
-#: c-family/c-opts.c:988
+#: c-family/c-opts.c:944
 #, gcc-internal-format
+msgid "-Wabi won't warn about anything"
+msgstr ""
+
+#: c-family/c-opts.c:946
+#, gcc-internal-format
+msgid "-Wabi warns about differences from the most up-to-date ABI, which is also used by default"
+msgstr ""
+
+#: c-family/c-opts.c:949
+#, gcc-internal-format
+msgid "use e.g. -Wabi=11 to warn about changes from GCC 7"
+msgstr ""
+
+#: c-family/c-opts.c:1003
+#, gcc-internal-format
 msgid "external TLS initialization functions not supported on this target"
 msgstr ""
 
-#: c-family/c-opts.c:1001
+#: c-family/c-opts.c:1016
 #, gcc-internal-format, gfc-internal-format
 msgid "too many filenames given.  Type %s --help for usage"
 msgstr "chỉ ra quá nhiều tên tập tin. Gõ lệnh %s --help để biết cách dùng"
 
-#: c-family/c-opts.c:1016
+#: c-family/c-opts.c:1031
 #, gcc-internal-format
 msgid "opening output file %s: %m"
 msgstr "mở tập tin kết xuất %s: %m"
 
-#: c-family/c-opts.c:1036
+#: c-family/c-opts.c:1051
 #, gcc-internal-format, gfc-internal-format
 msgid "the \"%s\" debug format cannot be used with pre-compiled headers"
 msgstr ""
 
-#: c-family/c-opts.c:1190
+#: c-family/c-opts.c:1205
 #, gcc-internal-format
 msgid "opening dependency file %s: %m"
 msgstr "mở tập tin phụ thuộc %s: %m"
 
-#: c-family/c-opts.c:1201
+#: c-family/c-opts.c:1216
 #, gcc-internal-format
 msgid "closing dependency file %s: %m"
 msgstr "đóng tập tin phụ thuộc %s: %m"
 
-#: c-family/c-opts.c:1204
+#: c-family/c-opts.c:1219
 #, gcc-internal-format
 msgid "when writing output to %s: %m"
 msgstr "khi ghi kết xuất ra %s: %m"
 
-#: c-family/c-opts.c:1284
+#: c-family/c-opts.c:1299
 #, gcc-internal-format
 msgid "to generate dependencies you must specify either -M or -MM"
 msgstr ""
 
-#: c-family/c-opts.c:1307
+#: c-family/c-opts.c:1322
 #, gcc-internal-format
 msgid "-MG may only be used with -M or -MM"
 msgstr "-MG chỉ nên dùng với -M hoặc -MM"
 
-#: c-family/c-opts.c:1340
+#: c-family/c-opts.c:1355
 #, gcc-internal-format
 msgid "-fdirectives-only is incompatible with -Wunused_macros"
 msgstr ""
 
-#: c-family/c-opts.c:1342
+#: c-family/c-opts.c:1357
 #, gcc-internal-format
 msgid "-fdirectives-only is incompatible with -traditional"
 msgstr ""
 
-#: c-family/c-opts.c:1534
+#: c-family/c-opts.c:1549
 #, gcc-internal-format
 msgid "too late for # directive to set debug directory"
 msgstr ""
@@ -26308,746 +26352,746 @@
 msgid "wrong type argument to %s"
 msgstr "sai kiểu đối số cho %s"
 
-#: c-family/c-warn.c:53 c-family/c-warn.c:66 cp/constexpr.c:1847
+#: c-family/c-warn.c:54 c-family/c-warn.c:67 cp/constexpr.c:1847
 #: cp/constexpr.c:4099
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "tràn trong biểu thức hằng"
 
-#: c-family/c-warn.c:93
+#: c-family/c-warn.c:94
 #, fuzzy, gcc-internal-format
 #| msgid "integer overflow in expression"
 msgid "integer overflow in expression %qE of type %qT results in %qE"
 msgstr "tràn số nguyên trong biểu thức"
 
-#: c-family/c-warn.c:95
+#: c-family/c-warn.c:96
 #, fuzzy, gcc-internal-format
 #| msgid "integer overflow in expression"
 msgid "integer overflow in expression of type %qT results in %qE"
 msgstr "tràn số nguyên trong biểu thức"
 
-#: c-family/c-warn.c:101
+#: c-family/c-warn.c:102
 #, fuzzy, gcc-internal-format
 #| msgid "floating point overflow in expression"
 msgid "floating point overflow in expression %qE of type %qT results in %qE"
 msgstr "tràn số dấu chấm động trong biểu thức"
 
-#: c-family/c-warn.c:103
+#: c-family/c-warn.c:104
 #, fuzzy, gcc-internal-format
 #| msgid "floating point overflow in expression"
 msgid "floating point overflow in expression of type %qT results in %qE"
 msgstr "tràn số dấu chấm động trong biểu thức"
 
-#: c-family/c-warn.c:109
+#: c-family/c-warn.c:110
 #, fuzzy, gcc-internal-format
 #| msgid "fixed-point overflow in expression"
 msgid "fixed-point overflow in expression %qE of type %qT results in %qE"
 msgstr "tràn số dấu chấm tĩnh trong biểu thức"
 
-#: c-family/c-warn.c:111
+#: c-family/c-warn.c:112
 #, fuzzy, gcc-internal-format
 #| msgid "fixed-point overflow in expression"
 msgid "fixed-point overflow in expression of type %qT results in %qE"
 msgstr "tràn số dấu chấm tĩnh trong biểu thức"
 
-#: c-family/c-warn.c:117
+#: c-family/c-warn.c:118
 #, fuzzy, gcc-internal-format
 #| msgid "vector overflow in expression"
 msgid "vector overflow in expression %qE of type %qT results in %qE"
 msgstr "tràn véc-tơ trong biểu thức"
 
-#: c-family/c-warn.c:119
+#: c-family/c-warn.c:120
 #, fuzzy, gcc-internal-format
 #| msgid "vector overflow in expression"
 msgid "vector overflow in expression of type %qT results in %qE"
 msgstr "tràn véc-tơ trong biểu thức"
 
-#: c-family/c-warn.c:126
+#: c-family/c-warn.c:127
 #, fuzzy, gcc-internal-format
 #| msgid "complex integer overflow in expression"
 msgid "complex integer overflow in expression %qE of type %qT results in %qE"
 msgstr "tràn số nguyên phức trong biểu thức"
 
-#: c-family/c-warn.c:128
+#: c-family/c-warn.c:129
 #, fuzzy, gcc-internal-format
 #| msgid "complex integer overflow in expression"
 msgid "complex integer overflow in expression of type %qT results in %qE"
 msgstr "tràn số nguyên phức trong biểu thức"
 
-#: c-family/c-warn.c:132
+#: c-family/c-warn.c:133
 #, fuzzy, gcc-internal-format
 #| msgid "floating point overflow in expression"
 msgid "complex floating point overflow in expression %qE of type %qT results in %qE"
 msgstr "tràn số dấu chấm động trong biểu thức"
 
-#: c-family/c-warn.c:134
+#: c-family/c-warn.c:135
 #, fuzzy, gcc-internal-format
 #| msgid "floating point overflow in expression"
 msgid "complex floating point overflow in expression of type %qT results in %qE"
 msgstr "tràn số dấu chấm động trong biểu thức"
 
-#: c-family/c-warn.c:216
+#: c-family/c-warn.c:217
 #, gcc-internal-format
 msgid "logical %<or%> applied to non-boolean constant"
 msgstr ""
 
-#: c-family/c-warn.c:219
+#: c-family/c-warn.c:220
 #, gcc-internal-format
 msgid "logical %<and%> applied to non-boolean constant"
 msgstr ""
 
-#: c-family/c-warn.c:289
+#: c-family/c-warn.c:290
 #, gcc-internal-format
 msgid "logical %<or%> of collectively exhaustive tests is always true"
 msgstr ""
 
-#: c-family/c-warn.c:293
+#: c-family/c-warn.c:294
 #, gcc-internal-format
 msgid "logical %<and%> of mutually exclusive tests is always false"
 msgstr ""
 
-#: c-family/c-warn.c:303
+#: c-family/c-warn.c:304
 #, gcc-internal-format
 msgid "logical %<or%> of equal expressions"
 msgstr ""
 
-#: c-family/c-warn.c:306
+#: c-family/c-warn.c:307
 #, gcc-internal-format
 msgid "logical %<and%> of equal expressions"
 msgstr ""
 
-#: c-family/c-warn.c:384
+#: c-family/c-warn.c:385
 #, fuzzy, gcc-internal-format
 #| msgid "Warn if a comparison always evaluates to true or false."
 msgid "bitwise comparison always evaluates to false"
 msgstr "Cảnh báo khi so sánh luôn ước lượng là đúng hoặc là sai."
 
-#: c-family/c-warn.c:387
+#: c-family/c-warn.c:388
 #, fuzzy, gcc-internal-format
 #| msgid "Warn if a comparison always evaluates to true or false."
 msgid "bitwise comparison always evaluates to true"
 msgstr "Cảnh báo khi so sánh luôn ước lượng là đúng hoặc là sai."
 
-#: c-family/c-warn.c:441
+#: c-family/c-warn.c:442
 #, gcc-internal-format
 msgid "self-comparison always evaluates to true"
 msgstr ""
 
-#: c-family/c-warn.c:444
+#: c-family/c-warn.c:445
 #, gcc-internal-format
 msgid "self-comparison always evaluates to false"
 msgstr ""
 
-#: c-family/c-warn.c:494
+#: c-family/c-warn.c:495
 #, gcc-internal-format
 msgid "logical not is only applied to the left hand side of comparison"
 msgstr ""
 
-#: c-family/c-warn.c:502
+#: c-family/c-warn.c:503
 #, gcc-internal-format
 msgid "add parentheses around left hand side expression to silence this warning"
 msgstr ""
 
-#: c-family/c-warn.c:636
+#: c-family/c-warn.c:637
 #, gcc-internal-format
 msgid "type-punning to incomplete type might break strict-aliasing rules"
 msgstr ""
 
-#: c-family/c-warn.c:654
+#: c-family/c-warn.c:655
 #, gcc-internal-format
 msgid "dereferencing type-punned pointer will break strict-aliasing rules"
 msgstr ""
 
-#: c-family/c-warn.c:662 c-family/c-warn.c:680
+#: c-family/c-warn.c:663 c-family/c-warn.c:681
 #, gcc-internal-format
 msgid "dereferencing type-punned pointer might break strict-aliasing rules"
 msgstr ""
 
-#: c-family/c-warn.c:803
+#: c-family/c-warn.c:811
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to use the size of the destination?"
 msgstr ""
 
-#: c-family/c-warn.c:834
+#: c-family/c-warn.c:842
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the destination; did you mean to remove the addressof?"
 msgstr ""
 
-#: c-family/c-warn.c:841
+#: c-family/c-warn.c:849
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the destination; did you mean to provide an explicit length?"
 msgstr ""
 
-#: c-family/c-warn.c:846
+#: c-family/c-warn.c:854
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the destination; did you mean to dereference it?"
 msgstr ""
 
-#: c-family/c-warn.c:858
+#: c-family/c-warn.c:866
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the destination; expected %qT or an explicit length"
 msgstr ""
 
-#: c-family/c-warn.c:874
+#: c-family/c-warn.c:882
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to remove the addressof?"
 msgstr ""
 
-#: c-family/c-warn.c:881
+#: c-family/c-warn.c:889
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to provide an explicit length?"
 msgstr ""
 
-#: c-family/c-warn.c:886
+#: c-family/c-warn.c:894
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to dereference it?"
 msgstr ""
 
-#: c-family/c-warn.c:898
+#: c-family/c-warn.c:906
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the source; expected %qT or an explicit length"
 msgstr ""
 
-#: c-family/c-warn.c:914
+#: c-family/c-warn.c:922
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the first source; did you mean to remove the addressof?"
 msgstr ""
 
-#: c-family/c-warn.c:921
+#: c-family/c-warn.c:929
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the first source; did you mean to provide an explicit length?"
 msgstr ""
 
-#: c-family/c-warn.c:926
+#: c-family/c-warn.c:934
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the first source; did you mean to dereference it?"
 msgstr ""
 
-#: c-family/c-warn.c:938
+#: c-family/c-warn.c:946
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the first source; expected %qT or an explicit length"
 msgstr ""
 
-#: c-family/c-warn.c:954
+#: c-family/c-warn.c:962
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the second source; did you mean to remove the addressof?"
 msgstr ""
 
-#: c-family/c-warn.c:961
+#: c-family/c-warn.c:969
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the second source; did you mean to provide an explicit length?"
 msgstr ""
 
-#: c-family/c-warn.c:966
+#: c-family/c-warn.c:974
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the second source; did you mean to dereference it?"
 msgstr ""
 
-#: c-family/c-warn.c:978
+#: c-family/c-warn.c:986
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the second source; expected %qT or an explicit length"
 msgstr ""
 
-#: c-family/c-warn.c:1007 c-family/c-warn.c:1014
+#: c-family/c-warn.c:1015 c-family/c-warn.c:1022
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified parameter type %qT of %q+D"
 msgstr ""
 
-#: c-family/c-warn.c:1024
+#: c-family/c-warn.c:1032
 #, gcc-internal-format
 msgid "first argument of %q+D should be %<int%>"
 msgstr "đối số đầu tiên của %q+D phải là %<int%>"
 
-#: c-family/c-warn.c:1033
+#: c-family/c-warn.c:1041
 #, gcc-internal-format
 msgid "second argument of %q+D should be %<char **%>"
 msgstr ""
 
-#: c-family/c-warn.c:1042
+#: c-family/c-warn.c:1050
 #, gcc-internal-format
 msgid "third argument of %q+D should probably be %<char **%>"
 msgstr ""
 
-#: c-family/c-warn.c:1053
+#: c-family/c-warn.c:1061
 #, gcc-internal-format
 msgid "%q+D takes only zero or two arguments"
 msgstr "%q+D chỉ nhận không hoặc hai đối số"
 
-#: c-family/c-warn.c:1057
+#: c-family/c-warn.c:1065
 #, gcc-internal-format
 msgid "%q+D declared as variadic function"
 msgstr ""
 
-#: c-family/c-warn.c:1099
+#: c-family/c-warn.c:1107
 #, gcc-internal-format
 msgid "conversion to %qT from boolean expression"
 msgstr ""
 
-#: c-family/c-warn.c:1117 c-family/c-warn.c:1192
+#: c-family/c-warn.c:1125 c-family/c-warn.c:1200
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "conversion from %qT to %qT changes value from %qE to %qE"
 msgstr "chuyển đổi từ %qT sang %qT là chưa rõ ràng"
 
-#: c-family/c-warn.c:1121 c-family/c-warn.c:1200
+#: c-family/c-warn.c:1129 c-family/c-warn.c:1208
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "conversion from %qT to %qT changes the value of %qE"
 msgstr "chuyển đổi từ %qT sang %qT là chưa rõ ràng"
 
-#: c-family/c-warn.c:1141
+#: c-family/c-warn.c:1149
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "conversion from %qT to %qT discards imaginary component"
 msgstr "chuyển đổi từ %qT sang %qT là chưa rõ ràng"
 
-#: c-family/c-warn.c:1153
+#: c-family/c-warn.c:1161
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "conversion from %qT to %qT may change value"
 msgstr "chuyển đổi từ %qT sang %qT là chưa rõ ràng"
 
-#: c-family/c-warn.c:1213 c-family/c-warn.c:1230 c-family/c-warn.c:1247
+#: c-family/c-warn.c:1221 c-family/c-warn.c:1238 c-family/c-warn.c:1255
 #, fuzzy, gcc-internal-format
 #| msgid "Change of value in conversion from %qs to %qs at %L"
 msgid "overflow in conversion from %qT to %qT changes value from %qE to %qE"
 msgstr "Đổi giá trị trong chuyển đổi từ %qs sang %qs tại %L"
 
-#: c-family/c-warn.c:1218 c-family/c-warn.c:1235 c-family/c-warn.c:1252
+#: c-family/c-warn.c:1226 c-family/c-warn.c:1243 c-family/c-warn.c:1260
 #, fuzzy, gcc-internal-format
 #| msgid "Change of value in conversion from %qs to %qs at %L"
 msgid "overflow in conversion from %qT to %qT changes the value of %qE"
 msgstr "Đổi giá trị trong chuyển đổi từ %qs sang %qs tại %L"
 
-#: c-family/c-warn.c:1282
+#: c-family/c-warn.c:1290
 #, gcc-internal-format
 msgid "case value %qs not in enumerated type"
 msgstr ""
 
-#: c-family/c-warn.c:1287
+#: c-family/c-warn.c:1295
 #, gcc-internal-format
 msgid "case value %qs not in enumerated type %qT"
 msgstr ""
 
-#: c-family/c-warn.c:1348
+#: c-family/c-warn.c:1356
 #, gcc-internal-format
 msgid "switch missing default case"
 msgstr "switch thiếu case mặc định"
 
-#: c-family/c-warn.c:1393
+#: c-family/c-warn.c:1401
 #, gcc-internal-format
 msgid "switch condition has boolean value"
 msgstr ""
 
-#: c-family/c-warn.c:1466
+#: c-family/c-warn.c:1474
 #, gcc-internal-format
 msgid "enumeration value %qE not handled in switch"
 msgstr ""
 
-#: c-family/c-warn.c:1494
+#: c-family/c-warn.c:1502
 #, gcc-internal-format
 msgid "the omitted middle operand in ?: will always be %<true%>, suggest explicit middle operand"
 msgstr ""
 
-#: c-family/c-warn.c:1515
+#: c-family/c-warn.c:1523
 #, gcc-internal-format
 msgid "assignment of member %qD in read-only object"
 msgstr ""
 
-#: c-family/c-warn.c:1517
+#: c-family/c-warn.c:1525
 #, gcc-internal-format
 msgid "increment of member %qD in read-only object"
 msgstr ""
 
-#: c-family/c-warn.c:1519
+#: c-family/c-warn.c:1527
 #, gcc-internal-format
 msgid "decrement of member %qD in read-only object"
 msgstr ""
 
-#: c-family/c-warn.c:1521
+#: c-family/c-warn.c:1529
 #, gcc-internal-format
 msgid "member %qD in read-only object used as %<asm%> output"
 msgstr ""
 
-#: c-family/c-warn.c:1525
+#: c-family/c-warn.c:1533
 #, gcc-internal-format
 msgid "assignment of read-only member %qD"
 msgstr "gán thành viên chỉ-đọc %qD"
 
-#: c-family/c-warn.c:1526
+#: c-family/c-warn.c:1534
 #, gcc-internal-format
 msgid "increment of read-only member %qD"
 msgstr "gia số cho thành viên chỉ-đọc %qD"
 
-#: c-family/c-warn.c:1527
+#: c-family/c-warn.c:1535
 #, gcc-internal-format
 msgid "decrement of read-only member %qD"
 msgstr "giảm thành viên chỉ-đọc %qD"
 
-#: c-family/c-warn.c:1528
+#: c-family/c-warn.c:1536
 #, gcc-internal-format
 msgid "read-only member %qD used as %<asm%> output"
 msgstr ""
 
-#: c-family/c-warn.c:1532
+#: c-family/c-warn.c:1540
 #, gcc-internal-format
 msgid "assignment of read-only variable %qD"
 msgstr "gán cho biến chỉ đọc %qD"
 
-#: c-family/c-warn.c:1533
+#: c-family/c-warn.c:1541
 #, gcc-internal-format
 msgid "increment of read-only variable %qD"
 msgstr ""
 
-#: c-family/c-warn.c:1534
+#: c-family/c-warn.c:1542
 #, gcc-internal-format
 msgid "decrement of read-only variable %qD"
 msgstr ""
 
-#: c-family/c-warn.c:1535
+#: c-family/c-warn.c:1543
 #, gcc-internal-format
 msgid "read-only variable %qD used as %<asm%> output"
 msgstr ""
 
-#: c-family/c-warn.c:1538
+#: c-family/c-warn.c:1546
 #, gcc-internal-format
 msgid "assignment of read-only parameter %qD"
 msgstr ""
 
-#: c-family/c-warn.c:1539
+#: c-family/c-warn.c:1547
 #, gcc-internal-format
 msgid "increment of read-only parameter %qD"
 msgstr ""
 
-#: c-family/c-warn.c:1540
+#: c-family/c-warn.c:1548
 #, gcc-internal-format
 msgid "decrement of read-only parameter %qD"
 msgstr ""
 
-#: c-family/c-warn.c:1541
+#: c-family/c-warn.c:1549
 #, gcc-internal-format
 msgid "read-only parameter %qD use as %<asm%> output"
 msgstr ""
 
-#: c-family/c-warn.c:1546
+#: c-family/c-warn.c:1554
 #, gcc-internal-format
 msgid "assignment of read-only named return value %qD"
 msgstr ""
 
-#: c-family/c-warn.c:1548
+#: c-family/c-warn.c:1556
 #, gcc-internal-format
 msgid "increment of read-only named return value %qD"
 msgstr ""
 
-#: c-family/c-warn.c:1550
+#: c-family/c-warn.c:1558
 #, gcc-internal-format
 msgid "decrement of read-only named return value %qD"
 msgstr ""
 
-#: c-family/c-warn.c:1552
+#: c-family/c-warn.c:1560
 #, gcc-internal-format
 msgid "read-only named return value %qD used as %<asm%>output"
 msgstr ""
 
-#: c-family/c-warn.c:1557
+#: c-family/c-warn.c:1565
 #, gcc-internal-format
 msgid "assignment of function %qD"
 msgstr "gán của hàm %qD"
 
-#: c-family/c-warn.c:1558
+#: c-family/c-warn.c:1566
 #, gcc-internal-format
 msgid "increment of function %qD"
 msgstr "số gia của hàm %qD"
 
-#: c-family/c-warn.c:1559
+#: c-family/c-warn.c:1567
 #, gcc-internal-format
 msgid "decrement of function %qD"
 msgstr "số giảm của hàm %qD"
 
-#: c-family/c-warn.c:1560
+#: c-family/c-warn.c:1568
 #, gcc-internal-format
 msgid "function %qD used as %<asm%> output"
 msgstr ""
 
-#: c-family/c-warn.c:1563 c/c-typeck.c:4762
+#: c-family/c-warn.c:1571 c/c-typeck.c:4767
 #, gcc-internal-format
 msgid "assignment of read-only location %qE"
 msgstr ""
 
-#: c-family/c-warn.c:1564 c/c-typeck.c:4765
+#: c-family/c-warn.c:1572 c/c-typeck.c:4770
 #, gcc-internal-format
 msgid "increment of read-only location %qE"
 msgstr ""
 
-#: c-family/c-warn.c:1565 c/c-typeck.c:4768
+#: c-family/c-warn.c:1573 c/c-typeck.c:4773
 #, gcc-internal-format
 msgid "decrement of read-only location %qE"
 msgstr ""
 
-#: c-family/c-warn.c:1566
+#: c-family/c-warn.c:1574
 #, gcc-internal-format
 msgid "read-only location %qE used as %<asm%> output"
 msgstr ""
 
-#: c-family/c-warn.c:1580
+#: c-family/c-warn.c:1588
 #, gcc-internal-format
 msgid "lvalue required as left operand of assignment"
 msgstr ""
 
-#: c-family/c-warn.c:1583
+#: c-family/c-warn.c:1591
 #, gcc-internal-format
 msgid "lvalue required as increment operand"
 msgstr "lvalue được yêu cầu như là toán hạng gia"
 
-#: c-family/c-warn.c:1586
+#: c-family/c-warn.c:1594
 #, gcc-internal-format
 msgid "lvalue required as decrement operand"
 msgstr "lvalue được yêu cầu như là toán hạng giảm"
 
-#: c-family/c-warn.c:1589
+#: c-family/c-warn.c:1597
 #, gcc-internal-format
 msgid "lvalue required as unary %<&%> operand"
 msgstr ""
 
-#: c-family/c-warn.c:1592
+#: c-family/c-warn.c:1600
 #, gcc-internal-format
 msgid "lvalue required in asm statement"
 msgstr ""
 
-#: c-family/c-warn.c:1609
+#: c-family/c-warn.c:1617
 #, gcc-internal-format
 msgid "invalid type argument (have %qT)"
 msgstr "kiểu tham số không hợp lệ (có %qT)"
 
-#: c-family/c-warn.c:1613
+#: c-family/c-warn.c:1621
 #, gcc-internal-format
 msgid "invalid type argument of array indexing (have %qT)"
 msgstr ""
 
-#: c-family/c-warn.c:1618
+#: c-family/c-warn.c:1626
 #, gcc-internal-format
 msgid "invalid type argument of unary %<*%> (have %qT)"
 msgstr ""
 
-#: c-family/c-warn.c:1623
+#: c-family/c-warn.c:1631
 #, gcc-internal-format
 msgid "invalid type argument of %<->%> (have %qT)"
 msgstr "kiểu tham số không hợp lệ của %<->%> (có %qT)"
 
-#: c-family/c-warn.c:1628
+#: c-family/c-warn.c:1636
 #, gcc-internal-format
 msgid "invalid type argument of %<->*%> (have %qT)"
 msgstr "kiểu tham số không hợp lệ của %<->*%> (có %qT)"
 
-#: c-family/c-warn.c:1633
+#: c-family/c-warn.c:1641
 #, gcc-internal-format
 msgid "invalid type argument of implicit conversion (have %qT)"
 msgstr ""
 
-#: c-family/c-warn.c:1654
+#: c-family/c-warn.c:1662
 #, gcc-internal-format
 msgid "array subscript has type %<char%>"
 msgstr ""
 
-#: c-family/c-warn.c:1689 c-family/c-warn.c:1692
+#: c-family/c-warn.c:1697 c-family/c-warn.c:1700
 #, gcc-internal-format
 msgid "suggest parentheses around %<+%> inside %<<<%>"
 msgstr "đề nghị bao %<+%> bằng dấu ngoặc đơn phía trong %<<<%>"
 
-#: c-family/c-warn.c:1695 c-family/c-warn.c:1698
+#: c-family/c-warn.c:1703 c-family/c-warn.c:1706
 #, gcc-internal-format
 msgid "suggest parentheses around %<-%> inside %<<<%>"
 msgstr "đề nghị bao %<-%> bằng dấu ngoặc đơn phía trong %<<<%>"
 
-#: c-family/c-warn.c:1704 c-family/c-warn.c:1707
+#: c-family/c-warn.c:1712 c-family/c-warn.c:1715
 #, gcc-internal-format
 msgid "suggest parentheses around %<+%> inside %<>>%>"
 msgstr "đề nghị bao %<+%> bằng dấu ngoặc đơn phía trong %<>>%>"
 
-#: c-family/c-warn.c:1710 c-family/c-warn.c:1713
+#: c-family/c-warn.c:1718 c-family/c-warn.c:1721
 #, gcc-internal-format
 msgid "suggest parentheses around %<-%> inside %<>>%>"
 msgstr "đề nghị bao %<-%> bằng dấu ngoặc đơn phía trong %<>>%>"
 
-#: c-family/c-warn.c:1719 c-family/c-warn.c:1722
+#: c-family/c-warn.c:1727 c-family/c-warn.c:1730
 #, gcc-internal-format
 msgid "suggest parentheses around %<&&%> within %<||%>"
 msgstr "gợi ý bao quanh %<&&%> bằng dấu ngoặc đơn phía trong %<||%>"
 
-#: c-family/c-warn.c:1729 c-family/c-warn.c:1733
+#: c-family/c-warn.c:1737 c-family/c-warn.c:1741
 #, gcc-internal-format
 msgid "suggest parentheses around arithmetic in operand of %<|%>"
 msgstr "gợi ý là dùng dấu ngoặc đơn bao quanh biểu thức toán học trong toán hạng của %<|%>"
 
-#: c-family/c-warn.c:1737 c-family/c-warn.c:1740
+#: c-family/c-warn.c:1745 c-family/c-warn.c:1748
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<|%>"
 msgstr "gợi ý là dùng dấu ngoặc đơn bao quanh biểu thức so sánh trong toán hạng của %<|%>"
 
-#: c-family/c-warn.c:1745
+#: c-family/c-warn.c:1753
 #, gcc-internal-format
 msgid "suggest parentheses around operand of %<!%> or change %<|%> to %<||%> or %<!%> to %<~%>"
 msgstr "gợi ý là dùng dấu ngoặc đơn bao quanh biểu thức so sánh trong toán hạng của %<!%> hay thay đổi %<|%> thành %<||%> hay %<!%> thành %<~%>"
 
-#: c-family/c-warn.c:1753 c-family/c-warn.c:1757
+#: c-family/c-warn.c:1761 c-family/c-warn.c:1765
 #, gcc-internal-format
 msgid "suggest parentheses around arithmetic in operand of %<^%>"
 msgstr "gợi ý là dùng dấu ngoặc đơn bao quanh biểu thức toán học trong toán hạng của %<^%>"
 
-#: c-family/c-warn.c:1761 c-family/c-warn.c:1764
+#: c-family/c-warn.c:1769 c-family/c-warn.c:1772
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<^%>"
 msgstr "gợi ý là dùng dấu ngoặc đơn bao quanh biểu thức so sánh trong toán hạng của %<^%>"
 
-#: c-family/c-warn.c:1770 c-family/c-warn.c:1773
+#: c-family/c-warn.c:1778 c-family/c-warn.c:1781
 #, gcc-internal-format
 msgid "suggest parentheses around %<+%> in operand of %<&%>"
 msgstr "đề nghị bao %<+%> bằng dấu ngoặc đơn toán hạng của %<&%>"
 
-#: c-family/c-warn.c:1776 c-family/c-warn.c:1779
+#: c-family/c-warn.c:1784 c-family/c-warn.c:1787
 #, gcc-internal-format
 msgid "suggest parentheses around %<-%> in operand of %<&%>"
 msgstr "đề nghị bao %<-%> bằng dấu ngoặc đơn toán hạng của %<&%>"
 
-#: c-family/c-warn.c:1783 c-family/c-warn.c:1786
+#: c-family/c-warn.c:1791 c-family/c-warn.c:1794
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<&%>"
 msgstr "gợi ý là dùng dấu ngoặc đơn bao quanh biểu thức so sánh trong toán hạng của %<&%>"
 
-#: c-family/c-warn.c:1791
+#: c-family/c-warn.c:1799
 #, gcc-internal-format
 msgid "suggest parentheses around operand of %<!%> or change %<&%> to %<&&%> or %<!%> to %<~%>"
 msgstr "gợi ý là dùng dấu ngoặc đơn bao quanh biểu thức so sánh trong toán hạng của %<!%> hoặc thay đổi %<&%> thành %<&&%> hay %<!%> thành %<~%>"
 
-#: c-family/c-warn.c:1798 c-family/c-warn.c:1801
+#: c-family/c-warn.c:1806 c-family/c-warn.c:1809
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<==%>"
 msgstr "gợi ý là dùng dấu ngoặc đơn bao quanh biểu thức so sánh trong toán hạng của %<==%>"
 
-#: c-family/c-warn.c:1806 c-family/c-warn.c:1809
+#: c-family/c-warn.c:1814 c-family/c-warn.c:1817
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<!=%>"
 msgstr "gợi ý là dùng dấu ngoặc đơn bao quanh biểu thức so sánh trong toán hạng của %<!=%>"
 
-#: c-family/c-warn.c:1819 c-family/c-warn.c:1825
+#: c-family/c-warn.c:1827 c-family/c-warn.c:1833
 #, gcc-internal-format
 msgid "comparisons like %<X<=Y<=Z%> do not have their mathematical meaning"
 msgstr ""
 
-#: c-family/c-warn.c:1841
+#: c-family/c-warn.c:1849
 #, gcc-internal-format
 msgid "label %q+D defined but not used"
 msgstr "nhãn %q+D được định nghĩa nhưng chưa được dùng"
 
-#: c-family/c-warn.c:1843
+#: c-family/c-warn.c:1851
 #, gcc-internal-format
 msgid "label %q+D declared but not defined"
 msgstr "nhãn %q+D được khai báo nhưng chưa được định nghĩa"
 
-#: c-family/c-warn.c:1866
+#: c-family/c-warn.c:1874
 #, gcc-internal-format
 msgid "division by zero"
 msgstr "chia cho 0"
 
-#: c-family/c-warn.c:1886
+#: c-family/c-warn.c:1894
 #, gcc-internal-format
 msgid "%<memset%> used with constant zero length parameter; this could be due to transposed parameters"
 msgstr ""
 
-#: c-family/c-warn.c:1909
+#: c-family/c-warn.c:1918
 #, gcc-internal-format
 msgid "%<memset%> used with length equal to number of elements without multiplication by element size"
 msgstr ""
 
-#: c-family/c-warn.c:1948 c/c-typeck.c:11499 c/c-typeck.c:11667
+#: c-family/c-warn.c:1957 c/c-typeck.c:11504 c/c-typeck.c:11672
 #: cp/typeck.c:5048
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr ""
 
-#: c-family/c-warn.c:1998
+#: c-family/c-warn.c:2007
 #, gcc-internal-format
 msgid "comparison of integer expressions of different signedness: %qT and %qT"
 msgstr ""
 
-#: c-family/c-warn.c:2051
+#: c-family/c-warn.c:2060
 #, gcc-internal-format
 msgid "promoted ~unsigned is always non-zero"
 msgstr ""
 
-#: c-family/c-warn.c:2054
+#: c-family/c-warn.c:2063
 #, gcc-internal-format
 msgid "comparison of promoted ~unsigned with constant"
 msgstr ""
 
-#: c-family/c-warn.c:2064
+#: c-family/c-warn.c:2073
 #, gcc-internal-format
 msgid "comparison of promoted ~unsigned with unsigned"
 msgstr ""
 
-#: c-family/c-warn.c:2118
+#: c-family/c-warn.c:2127
 #, gcc-internal-format
 msgid "unused parameter %qD"
 msgstr "tham số chưa dùng %q+D"
 
-#: c-family/c-warn.c:2180
+#: c-family/c-warn.c:2189
 #, gcc-internal-format
 msgid "typedef %qD locally defined but not used"
 msgstr ""
 
-#: c-family/c-warn.c:2215
+#: c-family/c-warn.c:2224
 #, gcc-internal-format
 msgid "duplicated %<if%> condition"
 msgstr ""
 
-#: c-family/c-warn.c:2244
+#: c-family/c-warn.c:2253
 #, gcc-internal-format
 msgid "optimization attribute on %qD follows definition but the attribute doesn%'t match"
 msgstr ""
 
-#: c-family/c-warn.c:2254
+#: c-family/c-warn.c:2261
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %qD with attribute noinline"
 msgid "inline declaration of %qD follows declaration with attribute %qs"
 msgstr "khai báo trước đây của %qD với không chung dòng thuộc tính"
 
-#: c-family/c-warn.c:2259
+#: c-family/c-warn.c:2266
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %qD with attribute noinline"
 msgid "declaration of %q+D with attribute %qs follows inline declaration"
 msgstr "khai báo trước đây của %qD với không chung dòng thuộc tính"
 
-#: c-family/c-warn.c:2306
+#: c-family/c-warn.c:2313
 #, gcc-internal-format
 msgid "result of %qE requires %u bits to represent, but %qT only has %u bits"
 msgstr ""
 
-#: c-family/c-warn.c:2344 c-family/c-warn.c:2368
+#: c-family/c-warn.c:2351 c-family/c-warn.c:2375
 #, gcc-internal-format
 msgid "comparison of constant %qE with boolean expression is always false"
 msgstr ""
 
-#: c-family/c-warn.c:2347 c-family/c-warn.c:2365
+#: c-family/c-warn.c:2354 c-family/c-warn.c:2372
 #, gcc-internal-format
 msgid "comparison of constant %qE with boolean expression is always true"
 msgstr ""
 
-#: c-family/c-warn.c:2415
+#: c-family/c-warn.c:2422
 msgid "passing argument %i to restrict-qualified parameter aliases with argument %Z"
 msgid_plural "passing argument %i to restrict-qualified parameter aliases with arguments %Z"
 msgstr[0] ""
 
-#: c-family/c-warn.c:2480 c/c-typeck.c:5288 cp/call.c:5365
+#: c-family/c-warn.c:2487 c/c-typeck.c:5293 cp/call.c:5365
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr ""
 
-#: c-family/c-warn.c:2586
+#: c-family/c-warn.c:2593
 #, gcc-internal-format
 msgid "macro expands to multiple statements"
 msgstr ""
 
-#: c-family/c-warn.c:2587
+#: c-family/c-warn.c:2594
 #, gcc-internal-format
 msgid "some parts of macro expansion are not guarded by this %qs clause"
 msgstr ""
@@ -27062,7 +27106,7 @@
 msgid "too many input files"
 msgstr "quá nhiều tập tin nhập vào"
 
-#: common/config/aarch64/aarch64-common.c:319 config/aarch64/aarch64.c:10686
+#: common/config/aarch64/aarch64-common.c:319 config/aarch64/aarch64.c:10702
 #, gcc-internal-format
 msgid "unknown value %qs for -mcpu"
 msgstr "không hiểu giá trị %qs dành cho -mcpu"
@@ -27093,13 +27137,13 @@
 msgstr ""
 
 #: common/config/arm/arm-common.c:322 common/config/arm/arm-common.c:376
-#: common/config/arm/arm-common.c:423 config/aarch64/aarch64.c:10639
+#: common/config/arm/arm-common.c:423 config/aarch64/aarch64.c:10655
 #, gcc-internal-format
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr "đối số hợp lệ là: %s; có phải ý bạn là là: %qs?"
 
 #: common/config/arm/arm-common.c:325 common/config/arm/arm-common.c:379
-#: common/config/arm/arm-common.c:426 config/aarch64/aarch64.c:10642
+#: common/config/arm/arm-common.c:426 config/aarch64/aarch64.c:10658
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments are: %s"
@@ -27583,12 +27627,12 @@
 msgid "profiler support for VxWorks"
 msgstr ""
 
-#: config/aarch64/aarch64-builtins.c:1109 config/arm/arm-builtins.c:2262
+#: config/aarch64/aarch64-builtins.c:1109 config/arm/arm-builtins.c:2272
 #, gcc-internal-format
 msgid "%Kargument %d must be a constant immediate"
 msgstr ""
 
-#: config/aarch64/aarch64-builtins.c:1180 config/arm/arm-builtins.c:2492
+#: config/aarch64/aarch64-builtins.c:1180 config/arm/arm-builtins.c:2502
 #, gcc-internal-format
 msgid "%Klane index must be a constant immediate"
 msgstr ""
@@ -27598,185 +27642,185 @@
 msgid "%Ktotal size and element size must be a non-zero constant immediate"
 msgstr ""
 
-#: config/aarch64/aarch64.c:1053
+#: config/aarch64/aarch64.c:1069
 #, gcc-internal-format
 msgid "%qs is incompatible with %s %s"
 msgstr "%qs không tương thích với %s %s"
 
-#: config/aarch64/aarch64.c:1055
+#: config/aarch64/aarch64.c:1071
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with %s %s"
 msgstr ""
 
-#: config/aarch64/aarch64.c:3772
+#: config/aarch64/aarch64.c:3788
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10287
+#: config/aarch64/aarch64.c:10303
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown flag passed in -moverride=%s (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10331
+#: config/aarch64/aarch64.c:10347
 #, gcc-internal-format, gfc-internal-format
 msgid "%s string ill-formed\n"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10388
+#: config/aarch64/aarch64.c:10404
 #, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10406
+#: config/aarch64/aarch64.c:10422
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown tuning option (%s)"
 msgstr "không hiểu tùy chọn chỉnh (%s)"
 
-#: config/aarch64/aarch64.c:10683
+#: config/aarch64/aarch64.c:10699
 #, fuzzy, gcc-internal-format
 #| msgid "missing cpu name in -mcpu=%qs"
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr "thiếu cpu trong -mcpu=%qs"
 
-#: config/aarch64/aarch64.c:10690
+#: config/aarch64/aarch64.c:10706
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%>"
 msgid "invalid feature modifier in %<-mcpu=%s%>"
 msgstr "dùng %<auto%> không hợp lệ"
 
-#: config/aarch64/aarch64.c:10717
+#: config/aarch64/aarch64.c:10733
 #, fuzzy, gcc-internal-format
 #| msgid "missing arch name in -march=%qs"
 msgid "missing arch name in %<-march=%s%>"
 msgstr "thiếu tên kiến trúc trong -march=%qs"
 
-#: config/aarch64/aarch64.c:10720
+#: config/aarch64/aarch64.c:10736
 #, gcc-internal-format
 msgid "unknown value %qs for -march"
 msgstr "không hiểu giá trị %qs cho -march"
 
-#: config/aarch64/aarch64.c:10724
+#: config/aarch64/aarch64.c:10740
 #, gcc-internal-format
 msgid "invalid feature modifier in %<-march=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10750
+#: config/aarch64/aarch64.c:10766
 #, fuzzy, gcc-internal-format
 #| msgid "missing cpu name in -mtune=%qs"
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr "thiếu tên cpu trong -mcpu=%qs"
 
-#: config/aarch64/aarch64.c:10753
+#: config/aarch64/aarch64.c:10769
 #, gcc-internal-format
 msgid "unknown value %qs for -mtune"
 msgstr "không hiểu giá trị %qs dành cho -mtune"
 
-#: config/aarch64/aarch64.c:10871 config/arm/arm.c:3173
+#: config/aarch64/aarch64.c:10887 config/arm/arm.c:3173
 #, gcc-internal-format, gfc-internal-format
 msgid "switch -mcpu=%s conflicts with -march=%s switch"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10906
+#: config/aarch64/aarch64.c:10922
 #, fuzzy, gcc-internal-format
 #| msgid "Assembler does not support -mabi=ilp32"
 msgid "assembler does not support -mabi=ilp32"
 msgstr "Assembler không hỗ trợ -mabi=ilp32"
 
-#: config/aarch64/aarch64.c:10913
+#: config/aarch64/aarch64.c:10929
 #, gcc-internal-format
 msgid "return address signing is only supported for -mabi=lp64"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10975
+#: config/aarch64/aarch64.c:10991
 #, gcc-internal-format
 msgid "code model %qs with -f%s"
 msgstr "mô hình mã %qs với -f%s"
 
-#: config/aarch64/aarch64.c:11138
+#: config/aarch64/aarch64.c:11154
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11141
+#: config/aarch64/aarch64.c:11157
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11145 config/aarch64/aarch64.c:11184
-#: config/aarch64/aarch64.c:11257
+#: config/aarch64/aarch64.c:11161 config/aarch64/aarch64.c:11200
+#: config/aarch64/aarch64.c:11273
 #, gcc-internal-format
 msgid "invalid value (\"%s\") in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11177
+#: config/aarch64/aarch64.c:11193
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11180
+#: config/aarch64/aarch64.c:11196
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11213
+#: config/aarch64/aarch64.c:11229
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"tune=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11253
+#: config/aarch64/aarch64.c:11269
 #, fuzzy, gcc-internal-format
 #| msgid "missing %<=%> (after %<getter%> attribute)"
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr "thiếu %<=%> (sau thuộc tính %<getter%>)"
 
-#: config/aarch64/aarch64.c:11306 config/aarch64/aarch64.c:11483
+#: config/aarch64/aarch64.c:11322 config/aarch64/aarch64.c:11499
 #, fuzzy, gcc-internal-format
 #| msgid "malformed %<#pragma init%>"
 msgid "malformed %<target()%> pragma or attribute"
 msgstr "%<#pragma init%> sai dạng"
 
-#: config/aarch64/aarch64.c:11354
+#: config/aarch64/aarch64.c:11370
 #, fuzzy, gcc-internal-format
 #| msgid "%<no-custom-%s%> does not accept arguments"
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr "%<no-custom-%s%> không chấp nhận đối số"
 
-#: config/aarch64/aarch64.c:11362
+#: config/aarch64/aarch64.c:11378
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11416
+#: config/aarch64/aarch64.c:11432
 #, fuzzy, gcc-internal-format
 #| msgid "attribute(target(\"%s\")) is unknown"
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr "thuộc tính(đích(\"%s\")) là không hiểu"
 
-#: config/aarch64/aarch64.c:11473 config/arm/arm.c:30742
-#: config/i386/i386.c:5440 config/powerpcspe/powerpcspe.c:39760
-#: config/rs6000/rs6000.c:36904 config/s390/s390.c:15746
+#: config/aarch64/aarch64.c:11489 config/arm/arm.c:30742
+#: config/i386/i386.c:5443 config/powerpcspe/powerpcspe.c:39760
+#: config/rs6000/rs6000.c:36960 config/s390/s390.c:15746
 #, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "thuộc tính %<target%> không là một chuỗi"
 
-#: config/aarch64/aarch64.c:11500
+#: config/aarch64/aarch64.c:11516
 #, fuzzy, gcc-internal-format
 #| msgid "attribute(target(\"%s\")) is unknown"
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr "thuộc tính(đích(\"%s\")) là không hiểu"
 
-#: config/aarch64/aarch64.c:11509
+#: config/aarch64/aarch64.c:11525
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13571
+#: config/aarch64/aarch64.c:13587
 #, gcc-internal-format
 msgid "%Klane %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13573
+#: config/aarch64/aarch64.c:13589
 #, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr ""
@@ -27836,8 +27880,8 @@
 msgid "bad value %qs for -mmemory-latency"
 msgstr "giá trị sai %qs cho -mmemory-latency"
 
-#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6526
-#: config/arc/arc.c:6800 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
+#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6517
+#: config/arc/arc.c:6791 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
 #: config/tilepro/tilepro.c:3108
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -27949,11 +27993,11 @@
 #: config/arm/arm.c:7029 config/avr/avr.c:9718 config/avr/avr.c:9734
 #: config/bfin/bfin.c:4705 config/bfin/bfin.c:4766 config/bfin/bfin.c:4795
 #: config/epiphany/epiphany.c:491 config/h8300/h8300.c:5459
-#: config/i386/i386.c:6452 config/i386/i386.c:12479 config/i386/i386.c:41424
-#: config/i386/i386.c:41474 config/i386/i386.c:41544 config/m68k/m68k.c:780
+#: config/i386/i386.c:6455 config/i386/i386.c:12482 config/i386/i386.c:41418
+#: config/i386/i386.c:41468 config/i386/i386.c:41538 config/m68k/m68k.c:780
 #: config/mcore/mcore.c:3070 config/nvptx/nvptx.c:4611
 #: config/powerpcspe/powerpcspe.c:35785 config/riscv/riscv.c:2698
-#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:32982
+#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:33038
 #: config/rx/rx.c:2719 config/rx/rx.c:2745 config/s390/s390.c:1056
 #: config/s390/s390.c:1143 config/sh/sh.c:8428 config/sh/sh.c:8446
 #: config/sh/sh.c:8470 config/sh/sh.c:8541 config/sh/sh.c:8564
@@ -27963,138 +28007,138 @@
 msgid "%qE attribute only applies to functions"
 msgstr "thuộc tính %qE chỉ áp dụng cho các hàm"
 
-#: config/arc/arc.c:6425
+#: config/arc/arc.c:6416
 #, gcc-internal-format
 msgid "__builtin_arc_aligned with non-constant alignment"
 msgstr ""
 
-#: config/arc/arc.c:6433
+#: config/arc/arc.c:6424
 #, gcc-internal-format
 msgid "invalid alignment value for __builtin_arc_aligned"
 msgstr ""
 
-#: config/arc/arc.c:6596
+#: config/arc/arc.c:6587
 #, gcc-internal-format
 msgid "operand 1 should be an unsigned 3-bit immediate"
 msgstr ""
 
-#: config/arc/arc.c:6637 config/arc/arc.c:6734
+#: config/arc/arc.c:6628 config/arc/arc.c:6725
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6670 config/arc/arc.c:6702
+#: config/arc/arc.c:6661 config/arc/arc.c:6693
 #, gcc-internal-format
 msgid "operand 1 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6674 config/arc/arc.c:6706
+#: config/arc/arc.c:6665 config/arc/arc.c:6697
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 8-bit value"
 msgstr ""
 
-#: config/arc/arc.c:6738
+#: config/arc/arc.c:6729
 #, gcc-internal-format
 msgid "operand 3 should be an unsigned 8-bit value"
 msgstr ""
 
-#: config/arc/arc.c:6771
+#: config/arc/arc.c:6762
 #, gcc-internal-format
 msgid "operand 4 should be an unsigned 8-bit value (0-255)"
 msgstr ""
 
-#: config/arc/arc.c:6775
+#: config/arc/arc.c:6766
 #, gcc-internal-format
 msgid "operand 3 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6782
+#: config/arc/arc.c:6773
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (subreg 0-7)"
 msgstr ""
 
-#: config/arc/arc.c:6785
+#: config/arc/arc.c:6776
 #, gcc-internal-format
 msgid "operand 2 should be an even 3-bit value (subreg 0,2,4,6)"
 msgstr ""
 
-#: config/arc/arc.c:6832
+#: config/arc/arc.c:6823
 #, gcc-internal-format, gfc-internal-format
 msgid "builtin requires an immediate for operand %d"
 msgstr ""
 
-#: config/arc/arc.c:6837
+#: config/arc/arc.c:6828
 #, gcc-internal-format, gfc-internal-format
 msgid "operand %d should be a 6 bit unsigned immediate"
 msgstr ""
 
-#: config/arc/arc.c:6841
+#: config/arc/arc.c:6832
 #, gcc-internal-format, gfc-internal-format
 msgid "operand %d should be a 8 bit unsigned immediate"
 msgstr ""
 
-#: config/arc/arc.c:6845
+#: config/arc/arc.c:6836
 #, gcc-internal-format, gfc-internal-format
 msgid "operand %d should be a 3 bit unsigned immediate"
 msgstr ""
 
-#: config/arc/arc.c:6848
+#: config/arc/arc.c:6839
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown builtin immediate operand type for operand %d"
 msgstr ""
 
-#: config/arc/arc.c:6899
+#: config/arc/arc.c:6890
 #, gcc-internal-format
 msgid "register number must be a compile-time constant. Try giving higher optimization levels"
 msgstr ""
 
-#: config/arc/arc.c:7685
+#: config/arc/arc.c:7747
 #, gcc-internal-format
 msgid "Insn addresses not set after shorten_branches"
 msgstr ""
 
-#: config/arc/arc.c:7894
+#: config/arc/arc.c:7956
 #, gcc-internal-format
 msgid "insn addresses not freed"
 msgstr ""
 
-#: config/arc/arc.c:10682
+#: config/arc/arc.c:10670
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only available for 32-bit"
 msgid "%qE attribute only valid for ARCv2 architecture"
 msgstr "Thuộc tính %qE chỉ dùng được trên hệ thống 32-bit"
 
-#: config/arc/arc.c:10690 config/arc/arc.c:10729
+#: config/arc/arc.c:10678 config/arc/arc.c:10717
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qE attribute"
 msgid "argument of %qE attribute is missing"
 msgstr "đối số của thuộc tính %qE không hợp lệ"
 
-#: config/arc/arc.c:10701 config/arc/arc.c:10740 config/arc/arc.c:10842
+#: config/arc/arc.c:10689 config/arc/arc.c:10728 config/arc/arc.c:10830
 #: config/avr/avr.c:9790
 #, gcc-internal-format
 msgid "%qE attribute allows only an integer constant argument"
 msgstr ""
 
-#: config/arc/arc.c:10721
+#: config/arc/arc.c:10709
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only available for 32-bit"
 msgid "%qE attribute only valid for ARC EM architecture"
 msgstr "Thuộc tính %qE chỉ dùng được trên hệ thống 32-bit"
 
-#: config/arc/arc.c:10776
+#: config/arc/arc.c:10764
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to SH2A"
 msgid "%qE attribute only applies to types"
 msgstr "Thuộc tính %qE chỉ được áp dụng cho SH2A"
 
-#: config/arc/arc.c:10782
+#: config/arc/arc.c:10770
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored"
 msgid "argument of %qE attribute ignored"
 msgstr "thuộc tính %qE bị lờ đi"
 
-#: config/arc/arc.c:10832 config/avr/avr.c:9777 config/bfin/bfin.c:4827
+#: config/arc/arc.c:10820 config/avr/avr.c:9777 config/bfin/bfin.c:4827
 #: config/i386/winnt.c:63 config/msp430/msp430.c:2018
 #: config/nvptx/nvptx.c:4634
 #, gcc-internal-format
@@ -28101,175 +28145,175 @@
 msgid "%qE attribute only applies to variables"
 msgstr "Thuộc tính %qE chỉ được áp dụng cho các biến"
 
-#: config/arm/arm-builtins.c:2370
+#: config/arm/arm-builtins.c:2380
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "this builtin is not supported for this target"
 msgstr "-fdata-sections không được hỗ trợ cho đích này"
 
-#: config/arm/arm-builtins.c:2475
+#: config/arm/arm-builtins.c:2485
 #, gcc-internal-format
 msgid "You must enable NEON instructions (e.g. -mfloat-abi=softfp -mfpu=neon) to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2513
+#: config/arm/arm-builtins.c:2523
 #, gcc-internal-format
 msgid "You must enable VFP instructions to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2573
+#: config/arm/arm-builtins.c:2583
 #, gcc-internal-format
 msgid "You must enable crypto instructions (e.g. include -mfloat-abi=softfp -mfpu=crypto-neon...) to use these intrinsics."
 msgstr ""
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:2633 config/arm/arm-builtins.c:2737
+#: config/arm/arm-builtins.c:2643 config/arm/arm-builtins.c:2747
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr "bộ chọn phải là một giá trị trực tiếp"
 
-#: config/arm/arm-builtins.c:2641 config/arm/arm-builtins.c:2686
-#: config/arm/arm-builtins.c:2744 config/arm/arm-builtins.c:2753
+#: config/arm/arm-builtins.c:2651 config/arm/arm-builtins.c:2696
+#: config/arm/arm-builtins.c:2754 config/arm/arm-builtins.c:2763
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr "vùng bộ chọn phải nằm từ 0 đến 7"
 
-#: config/arm/arm-builtins.c:2646 config/arm/arm-builtins.c:2755
+#: config/arm/arm-builtins.c:2656 config/arm/arm-builtins.c:2765
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr "vùng bộ chọn phải nằm từ 0 đến 3"
 
-#: config/arm/arm-builtins.c:2651 config/arm/arm-builtins.c:2757
+#: config/arm/arm-builtins.c:2661 config/arm/arm-builtins.c:2767
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr "vùng bộ chọn phải nằm từ 0 đến 1"
 
-#: config/arm/arm-builtins.c:2823
+#: config/arm/arm-builtins.c:2833
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr "mặt nạ phải là một giá trị trực tiếp"
 
-#: config/arm/arm-builtins.c:2828
+#: config/arm/arm-builtins.c:2838
 #, gcc-internal-format
 msgid "the range of mask should be in 0 to 255"
 msgstr "vùng mặt nạ phải nằm từ 0 đến 255"
 
-#: config/arm/arm-builtins.c:3016
+#: config/arm/arm-builtins.c:3026
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr "vùng của số lượng phải nằm trong vùn 0 đến 32.  hãy kiểm tra bên trong _mm_rori_pi16 trong mã."
 
-#: config/arm/arm-builtins.c:3018
+#: config/arm/arm-builtins.c:3028
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr "vùng của số lượng phải nằm trong vùn 0 đến 32.  hãy kiểm tra bên trong _mm_rori_pi32 trong mã."
 
-#: config/arm/arm-builtins.c:3020
+#: config/arm/arm-builtins.c:3030
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr "vùng của số lượng phải nằm trong vùn 0 đến 32.  hãy kiểm tra bên trong _mm_ror_pi16 trong mã."
 
-#: config/arm/arm-builtins.c:3022
+#: config/arm/arm-builtins.c:3032
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr "vùng của số lượng phải nằm trong vùn 0 đến 32.  hãy kiểm tra bên trong _mm_ror_pi32 trong mã."
 
-#: config/arm/arm-builtins.c:3028
+#: config/arm/arm-builtins.c:3038
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr "vùng của số lượng phải nằm trong vùn 0 đến 64.  hãy kiểm tra bên trong _mm_rori_si64 trong mã."
 
-#: config/arm/arm-builtins.c:3030
+#: config/arm/arm-builtins.c:3040
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr "vùng của số lượng phải nằm trong vùn 0 đến 64.  hãy kiểm tra bên trong _mm_ror_si64 trong mã."
 
-#: config/arm/arm-builtins.c:3035
+#: config/arm/arm-builtins.c:3045
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_srli_pi16 trong mã."
 
-#: config/arm/arm-builtins.c:3037
+#: config/arm/arm-builtins.c:3047
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_srli_pi32 trong mã."
 
-#: config/arm/arm-builtins.c:3039
+#: config/arm/arm-builtins.c:3049
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_srli_si64 trong mã."
 
-#: config/arm/arm-builtins.c:3041
+#: config/arm/arm-builtins.c:3051
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_slli_pi16 trong mã."
 
-#: config/arm/arm-builtins.c:3043
+#: config/arm/arm-builtins.c:3053
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_slli_pi32 trong mã."
 
-#: config/arm/arm-builtins.c:3045
+#: config/arm/arm-builtins.c:3055
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_slli_si64 trong mã."
 
-#: config/arm/arm-builtins.c:3047
+#: config/arm/arm-builtins.c:3057
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_srai_pi16 trong mã."
 
-#: config/arm/arm-builtins.c:3049
+#: config/arm/arm-builtins.c:3059
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_srai_pi32 trong mã."
 
-#: config/arm/arm-builtins.c:3051
+#: config/arm/arm-builtins.c:3061
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_srai_si64 trong mã."
 
-#: config/arm/arm-builtins.c:3053
+#: config/arm/arm-builtins.c:3063
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_srl_pi16 trong mã."
 
-#: config/arm/arm-builtins.c:3055
+#: config/arm/arm-builtins.c:3065
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_srl_pi32 trong mã."
 
-#: config/arm/arm-builtins.c:3057
+#: config/arm/arm-builtins.c:3067
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_srl_si64 trong mã."
 
-#: config/arm/arm-builtins.c:3059
+#: config/arm/arm-builtins.c:3069
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_sll_pi16 trong mã."
 
-#: config/arm/arm-builtins.c:3061
+#: config/arm/arm-builtins.c:3071
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_sll_pi32 trong mã."
 
-#: config/arm/arm-builtins.c:3063
+#: config/arm/arm-builtins.c:3073
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_sll_si64 trong mã."
 
-#: config/arm/arm-builtins.c:3065
+#: config/arm/arm-builtins.c:3075
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_sra_pi16 trong mã."
 
-#: config/arm/arm-builtins.c:3067
+#: config/arm/arm-builtins.c:3077
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_sra_pi32 trong mã."
 
-#: config/arm/arm-builtins.c:3069
+#: config/arm/arm-builtins.c:3079
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_sra_si64 trong mã."
@@ -29179,561 +29223,561 @@
 msgid "can%'t set position in PCH file: %m"
 msgstr "Không thể đặt vị trí trong tập tin PCH: %m"
 
-#: config/i386/i386.c:3177
+#: config/i386/i386.c:3180
 #, fuzzy, gcc-internal-format
 msgid "wrong argument %qs to option %qs"
 msgstr "sai đối số %s cho tùy chọn %s"
 
-#: config/i386/i386.c:3183
+#: config/i386/i386.c:3186
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr ""
 
-#: config/i386/i386.c:3193
+#: config/i386/i386.c:3196
 #, fuzzy, gcc-internal-format
 msgid "wrong strategy name %qs specified for option %qs"
 msgstr "sai đối số %s cho tùy chọn %s"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3219
+#: config/i386/i386.c:3222
 #, fuzzy, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr "-mstringop-strategy=rep_8byte không hỗ trợ mã 32-bit"
 
-#: config/i386/i386.c:3232
+#: config/i386/i386.c:3235
 #, fuzzy, gcc-internal-format
 msgid "unknown alignment %qs specified for option %qs"
 msgstr "không hiểu hàm đặc tả %qs"
 
-#: config/i386/i386.c:3242
+#: config/i386/i386.c:3245
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr ""
 
-#: config/i386/i386.c:3249
+#: config/i386/i386.c:3252
 #, fuzzy, gcc-internal-format
 msgid "too many size ranges specified in option %qs"
 msgstr "không chỉ định tên lớp với %qs"
 
-#: config/i386/i386.c:3302
+#: config/i386/i386.c:3305
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unknown register name: %s"
 msgid "unknown parameter to option -mtune-ctrl: %s"
 msgstr "không hiểu tên thanh ghi: %s"
 
-#: config/i386/i386.c:3726
+#: config/i386/i386.c:3729
 #, gcc-internal-format
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr ""
 
-#: config/i386/i386.c:3775
+#: config/i386/i386.c:3778
 #, fuzzy, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "%stune=x86-64%s đã lỗi thời, dùng %stune=k8%s hay %stune=generic%s để thay thế là thích hợp"
 
-#: config/i386/i386.c:3777
+#: config/i386/i386.c:3780
 #, fuzzy, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr "%stune=x86-64%s đã lỗi thời, dùng %stune=k8%s hay %stune=generic%s để thay thế là thích hợp"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3804
+#: config/i386/i386.c:3807
 #, gcc-internal-format
 msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgstr "-mstringop-strategy=rep_8byte không hỗ trợ mã 32-bit"
 
-#: config/i386/i386.c:3821
+#: config/i386/i386.c:3824
 #, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr ""
 
-#: config/i386/i386.c:3833
+#: config/i386/i386.c:3836
 #, fuzzy, gcc-internal-format
 #| msgid "%<-Wabi=1%> is not supported, using =2"
 msgid "-mabi=ms not supported with X32 ABI"
 msgstr "%<-Wabi=1%> không được hỗ trợ, dùng =2"
 
-#: config/i386/i386.c:3851 config/i386/i386.c:3860 config/i386/i386.c:3872
-#: config/i386/i386.c:3883 config/i386/i386.c:3894
+#: config/i386/i386.c:3854 config/i386/i386.c:3863 config/i386/i386.c:3875
+#: config/i386/i386.c:3886 config/i386/i386.c:3897
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr ""
 
-#: config/i386/i386.c:3863 config/i386/i386.c:3875
+#: config/i386/i386.c:3866 config/i386/i386.c:3878
 #, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "mô hình mã %qs không được hỗ trợ trong chế độ x32"
 
-#: config/i386/i386.c:3881 config/i386/i386.c:3890 config/i386/i386.c:5213
+#: config/i386/i386.c:3884 config/i386/i386.c:3893 config/i386/i386.c:5216
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "mô hình mã %s không hỗ trợ chế độ PIC"
 
-#: config/i386/i386.c:3918
+#: config/i386/i386.c:3921
 #, gcc-internal-format
 msgid "-masm=intel not supported in this configuration"
 msgstr "-masm=intel không được hỗ trợ trong cấu hình này"
 
-#: config/i386/i386.c:3923
+#: config/i386/i386.c:3926
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "chế độ %i-bit chưa được biên dịch bên trong"
 
-#: config/i386/i386.c:3932
+#: config/i386/i386.c:3935
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386.c:3934
+#: config/i386/i386.c:3937
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386.c:3941
+#: config/i386/i386.c:3944
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386.c:3943
+#: config/i386/i386.c:3946
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386.c:3951 config/i386/i386.c:4265
+#: config/i386/i386.c:3954 config/i386/i386.c:4268
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "CPU bạn chọn không hỗ trợ chỉ lệnh x86-64"
 
-#: config/i386/i386.c:4197 config/i386/i386.c:4200
+#: config/i386/i386.c:4200 config/i386/i386.c:4203
 #, gcc-internal-format
 msgid "Intel MPX does not support x32"
 msgstr "Intel MPX không hỗ trợ x32"
 
-#: config/i386/i386.c:4205
+#: config/i386/i386.c:4208
 #, gcc-internal-format
 msgid "bad value (%qs) for %<-march=%> switch"
 msgstr "sai giá trị (%qs) cho tùy chọn %<-march=%>"
 
-#: config/i386/i386.c:4206
+#: config/i386/i386.c:4209
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%qs) for %<-march=%> switch"
 msgid "bad value (%qs) for %<target(\"arch=\")%> attribute"
 msgstr "sai giá trị (%qs) cho tùy chọn %<-march=%>"
 
-#: config/i386/i386.c:4228
+#: config/i386/i386.c:4231
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "đối số hợp lệ cho cho %qs là: %s"
 
-#: config/i386/i386.c:4230
+#: config/i386/i386.c:4233
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr "đối số hợp lệ cho cho %qs là: %s"
 
-#: config/i386/i386.c:4235
+#: config/i386/i386.c:4238
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "đối số hợp lệ cho cho %qs là: %s"
 
-#: config/i386/i386.c:4236
+#: config/i386/i386.c:4239
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "đối số hợp lệ cho cho %qs là: %s"
 
-#: config/i386/i386.c:4284
+#: config/i386/i386.c:4287
 #, fuzzy, gcc-internal-format
 msgid "bad value (%qs) for %<-mtune=%> switch"
 msgstr "sai giá trị (%s) cho chuyển -mtune"
 
-#: config/i386/i386.c:4285
+#: config/i386/i386.c:4288
 #, fuzzy, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"tune=\")%> attribute"
 msgstr "sai giá trị (%s) cho chuyển -mtune"
 
-#: config/i386/i386.c:4305
+#: config/i386/i386.c:4308
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "đối số hợp lệ cho cho %qs là: %s"
 
-#: config/i386/i386.c:4307
+#: config/i386/i386.c:4310
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr "đối số hợp lệ cho cho %qs là: %s"
 
-#: config/i386/i386.c:4312
+#: config/i386/i386.c:4315
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "đối số hợp lệ cho cho %qs là: %s"
 
-#: config/i386/i386.c:4313
+#: config/i386/i386.c:4316
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "đối số hợp lệ cho cho %qs là: %s"
 
-#: config/i386/i386.c:4379
+#: config/i386/i386.c:4382
 #, gcc-internal-format
 msgid "-mregparm is ignored in 64-bit mode"
 msgstr "-mregparm bị bỏ qua trên chế độ 64-bit"
 
-#: config/i386/i386.c:4381
+#: config/i386/i386.c:4384
 #, gcc-internal-format
 msgid "-mregparm is ignored for Intel MCU psABI"
 msgstr "-mregparm bị bỏ qua trên chế độ 64-bit"
 
-#: config/i386/i386.c:4384
+#: config/i386/i386.c:4387
 #, gcc-internal-format, gfc-internal-format
 msgid "-mregparm=%d is not between 0 and %d"
 msgstr "-mregparm=%d không nằm giữa 0 và %d"
 
-#: config/i386/i386.c:4417
+#: config/i386/i386.c:4420
 #, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "%<-mrtd%> bị bỏ qua trong chế độ 64bit"
 
-#: config/i386/i386.c:4418
+#: config/i386/i386.c:4421
 #, fuzzy, gcc-internal-format
 #| msgid "%<-mrtd%> is ignored in 64bit mode"
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "%<-mrtd%> bị bỏ qua trong chế độ 64bit"
 
-#: config/i386/i386.c:4497
+#: config/i386/i386.c:4500
 #, gcc-internal-format
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "-mpreferred-stack-boundary không được hỗ trợ trên đích này"
 
-#: config/i386/i386.c:4500
+#: config/i386/i386.c:4503
 #, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d không nằm giữa %d và %d"
 
-#: config/i386/i386.c:4523
+#: config/i386/i386.c:4526
 #, gcc-internal-format, gfc-internal-format
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr "-mincoming-stack-boundary=%d không ở giữa %d và 12"
 
-#: config/i386/i386.c:4536
+#: config/i386/i386.c:4539
 #, gcc-internal-format
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "-mnop-mcount không tương thích với đích này"
 
-#: config/i386/i386.c:4539
+#: config/i386/i386.c:4542
 #, gcc-internal-format
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr "-mnop-mcount không được thực hiện cho -fPIC"
 
-#: config/i386/i386.c:4545
+#: config/i386/i386.c:4548
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "%<-msseregparm%> được dùng mà không bật SSE"
 
-#: config/i386/i386.c:4546
+#: config/i386/i386.c:4549
 #, fuzzy, gcc-internal-format
 #| msgid "%<-msseregparm%> used without SSE enabled"
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "%<-msseregparm%> được dùng mà không bật SSE"
 
-#: config/i386/i386.c:4556
+#: config/i386/i386.c:4559
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "Chỉ lệnh SSE đặt là tắt, sử dụng số học 387"
 
-#: config/i386/i386.c:4563
+#: config/i386/i386.c:4566
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr ""
 
-#: config/i386/i386.c:4613
+#: config/i386/i386.c:4616
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr ""
 
-#: config/i386/i386.c:4615
+#: config/i386/i386.c:4618
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr ""
 
-#: config/i386/i386.c:4629
+#: config/i386/i386.c:4632
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr ""
 
-#: config/i386/i386.c:4631
+#: config/i386/i386.c:4634
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr ""
 
-#: config/i386/i386.c:4741
+#: config/i386/i386.c:4744
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr "-mfentry không hỗ trợ cho 32-bit trong tổ hợp cùng với -fpic"
 
-#: config/i386/i386.c:4744
+#: config/i386/i386.c:4747
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr "-mno-fentry không tương thích với SEH"
 
-#: config/i386/i386.c:4748
+#: config/i386/i386.c:4751
 #, gcc-internal-format
 msgid "-mcall-ms2sysv-xlogues isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386.c:4813 config/powerpcspe/powerpcspe.c:5663
+#: config/i386/i386.c:4816 config/powerpcspe/powerpcspe.c:5663
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown option for -mrecip=%s"
 msgstr "không hiểu tùy chọn cho -mrecip=%s"
 
-#: config/i386/i386.c:4870 config/powerpcspe/powerpcspe.c:5339
+#: config/i386/i386.c:4873 config/powerpcspe/powerpcspe.c:5339
 #, gcc-internal-format
 msgid "%qs is not a valid number in -mstack-protector-guard-offset="
 msgstr ""
 
-#: config/i386/i386.c:4875 config/powerpcspe/powerpcspe.c:5344
+#: config/i386/i386.c:4878 config/powerpcspe/powerpcspe.c:5344
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid option to the preprocessor"
 msgid "%qs is not a valid offset in -mstack-protector-guard-offset="
 msgstr "“%qs” không phải là một tùy chọn hợp lệ cho bộ tiền xử lý"
 
-#: config/i386/i386.c:4907 config/powerpcspe/powerpcspe.c:5356
+#: config/i386/i386.c:4910 config/powerpcspe/powerpcspe.c:5356
 #, gcc-internal-format
 msgid "%qs is not a valid base register in -mstack-protector-guard-reg="
 msgstr ""
 
-#: config/i386/i386.c:5506 config/i386/i386.c:5553 config/s390/s390.c:15812
+#: config/i386/i386.c:5509 config/i386/i386.c:5556 config/s390/s390.c:15812
 #: config/s390/s390.c:15862 config/s390/s390.c:15879
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr "thuộc tính(đích(\"%s\")) là không hiểu"
 
-#: config/i386/i386.c:5534
+#: config/i386/i386.c:5537
 #, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr "tùy chọn (\"%s\") đã sẵn được đưa ra rồi"
 
-#: config/i386/i386.c:5837
+#: config/i386/i386.c:5840
 #, fuzzy, gcc-internal-format
 #| msgid "cdecl and thiscall attributes are not compatible"
 msgid "interrupt and naked attributes are not compatible"
 msgstr "các thuộc tính cdecl và thiscall không tương thích với nhau"
 
-#: config/i386/i386.c:5852
+#: config/i386/i386.c:5855
 #, gcc-internal-format
 msgid "Only DWARF debug format is supported for interrupt service routine."
 msgstr ""
 
-#: config/i386/i386.c:5901
+#: config/i386/i386.c:5904
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s và -mcall-%s là không tương thích"
 
-#: config/i386/i386.c:5913
+#: config/i386/i386.c:5916
 #, gcc-internal-format
 msgid "%<-mindirect-branch=thunk-extern%>, %<-fcf-protection=branch%> and %<-fcheck-pointer-bounds%> are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5949
+#: config/i386/i386.c:5952
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s và -mcall-%s là không tương thích"
 
-#: config/i386/i386.c:6047
+#: config/i386/i386.c:6050
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in %s service routine"
 msgstr ""
 
-#: config/i386/i386.c:6051
+#: config/i386/i386.c:6054
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in function with no_caller_saved_registers attribute"
 msgstr ""
 
-#: config/i386/i386.c:6465 config/i386/i386.c:6516
+#: config/i386/i386.c:6468 config/i386/i386.c:6519
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6470
+#: config/i386/i386.c:6473
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "thuộc tính regparam và thiscall không tương thích với nhau"
 
-#: config/i386/i386.c:6477 config/i386/i386.c:41444
+#: config/i386/i386.c:6480 config/i386/i386.c:41438
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr ""
 
-#: config/i386/i386.c:6483
+#: config/i386/i386.c:6486
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr ""
 
-#: config/i386/i386.c:6508 config/i386/i386.c:6551
+#: config/i386/i386.c:6511 config/i386/i386.c:6554
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6512
+#: config/i386/i386.c:6515
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6520 config/i386/i386.c:6569
+#: config/i386/i386.c:6523 config/i386/i386.c:6572
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "các thuộc tính fastcall và thiscall không tương thích với nhau"
 
-#: config/i386/i386.c:6530 config/i386/i386.c:6547
+#: config/i386/i386.c:6533 config/i386/i386.c:6550
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6534
+#: config/i386/i386.c:6537
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6538 config/i386/i386.c:6565
+#: config/i386/i386.c:6541 config/i386/i386.c:6568
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "các thuộc tính stdcall và thiscal không tương thích với nhau"
 
-#: config/i386/i386.c:6555 config/i386/i386.c:6573
+#: config/i386/i386.c:6558 config/i386/i386.c:6576
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "các thuộc tính cdecl và thiscall không tương thích với nhau"
 
-#: config/i386/i386.c:6561
+#: config/i386/i386.c:6564
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr ""
 
-#: config/i386/i386.c:6805
+#: config/i386/i386.c:6808
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:6808
+#: config/i386/i386.c:6811
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:7126
+#: config/i386/i386.c:7129
 #, gcc-internal-format
 msgid "X32 does not support ms_abi attribute"
 msgstr ""
 
-#: config/i386/i386.c:7160
+#: config/i386/i386.c:7163
 #, gcc-internal-format
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr ""
 
-#: config/i386/i386.c:7502
+#: config/i386/i386.c:7505
 #, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7508
+#: config/i386/i386.c:7511
 #, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7522
+#: config/i386/i386.c:7525
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7528
+#: config/i386/i386.c:7531
 #, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7544
+#: config/i386/i386.c:7547
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7550
+#: config/i386/i386.c:7553
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7566
+#: config/i386/i386.c:7569
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7572
+#: config/i386/i386.c:7575
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7754
+#: config/i386/i386.c:7757
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:7871
+#: config/i386/i386.c:7874
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:7989
+#: config/i386/i386.c:7992
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:8152
+#: config/i386/i386.c:8155
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.c:8158
+#: config/i386/i386.c:8161
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.c:8174
+#: config/i386/i386.c:8177
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr ""
 
-#: config/i386/i386.c:8471 config/i386/i386.c:8750 config/i386/i386.c:9276
+#: config/i386/i386.c:8474 config/i386/i386.c:8753 config/i386/i386.c:9279
 #, gcc-internal-format
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:8473 config/i386/i386.c:8752 config/i386/i386.c:9278
+#: config/i386/i386.c:8476 config/i386/i386.c:8755 config/i386/i386.c:9281
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr ""
 
-#: config/i386/i386.c:9178
+#: config/i386/i386.c:9181
 #, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr ""
 
-#: config/i386/i386.c:11601
+#: config/i386/i386.c:11604
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-mnop-mcount is not compatible with this target"
 msgid "-mcall-ms2sysv-xlogues is not compatible with %s"
 msgstr "-mnop-mcount không tương thích với đích này"
 
-#: config/i386/i386.c:13593
+#: config/i386/i386.c:13596
 #, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr ""
 
-#: config/i386/i386.c:13683
+#: config/i386/i386.c:13686
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr ""
 
-#: config/i386/i386.c:14970
+#: config/i386/i386.c:14973
 #, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr ""
 
-#: config/i386/i386.c:14990
+#: config/i386/i386.c:14993
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
 msgstr ""
@@ -29740,314 +29784,314 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:15001
+#: config/i386/i386.c:15004
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr ""
 
-#: config/i386/i386.c:17939
+#: config/i386/i386.c:17942
 #, gcc-internal-format
 msgid "'V' modifier on non-integer register"
 msgstr ""
 
-#: config/i386/i386.c:17950 config/i386/i386.c:17964
+#: config/i386/i386.c:17953 config/i386/i386.c:17967
 #, gcc-internal-format
 msgid "unsupported size for integer register"
 msgstr ""
 
-#: config/i386/i386.c:17996
+#: config/i386/i386.c:17999
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr ""
 
-#: config/i386/i386.c:18011
+#: config/i386/i386.c:18014
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr ""
 
-#: config/i386/i386.c:18202
+#: config/i386/i386.c:18205
 #, gcc-internal-format
 msgid "non-integer operand used with operand code 'z'"
 msgstr ""
 
-#: config/i386/i386.c:28467
+#: config/i386/i386.c:28470
 #, gcc-internal-format
 msgid "interrupt service routine can't be called directly"
 msgstr ""
 
-#: config/i386/i386.c:29995
+#: config/i386/i386.c:29998
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in -fabi-version=12 (GCC 8)"
 msgstr ""
 
-#: config/i386/i386.c:32435
+#: config/i386/i386.c:32438
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr ""
 
-#: config/i386/i386.c:32485
+#: config/i386/i386.c:32488
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for %s"
 msgstr ""
 
-#: config/i386/i386.c:32495
+#: config/i386/i386.c:32498
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr ""
 
-#: config/i386/i386.c:32657
+#: config/i386/i386.c:32660
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386.c:32662 config/i386/i386.c:32938
-#: config/rs6000/rs6000.c:37850
+#: config/i386/i386.c:32665 config/i386/i386.c:32941
+#: config/rs6000/rs6000.c:37906
 #, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr ""
 
-#: config/i386/i386.c:32795 config/rs6000/rs6000.c:37607
+#: config/i386/i386.c:32798 config/rs6000/rs6000.c:37663
 #, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr ""
 
-#: config/i386/i386.c:33207
+#: config/i386/i386.c:33210
 #, gcc-internal-format
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr ""
 
-#: config/i386/i386.c:33232 config/i386/i386.c:33282
+#: config/i386/i386.c:33235 config/i386/i386.c:33285
 #, gcc-internal-format, gfc-internal-format
 msgid "Parameter to builtin not valid: %s"
 msgstr ""
 
-#: config/i386/i386.c:33975 config/i386/i386.c:35415
+#: config/i386/i386.c:33978 config/i386/i386.c:35418
 #, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "đối số cuối phải là giá trị trực tiếp 2-bít"
 
-#: config/i386/i386.c:34370
+#: config/i386/i386.c:34373
 #, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "đối số thứ năm phải là giá trị trực tiếp 8-bit"
 
-#: config/i386/i386.c:34465
+#: config/i386/i386.c:34468
 #, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "đối số thứ ba phải là giá trị trực tiếp 8-bit"
 
-#: config/i386/i386.c:35346
+#: config/i386/i386.c:35349
 #, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "đối số cuối phải là giá trị trực tiếp 1-bít"
 
-#: config/i386/i386.c:35361
+#: config/i386/i386.c:35364
 #, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "đối số cuối phải là giá trị trực tiếp 3-bít"
 
-#: config/i386/i386.c:35394
+#: config/i386/i386.c:35397
 #, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "đối số cuối phải là giá trị trực tiếp 4-bít"
 
-#: config/i386/i386.c:35434
+#: config/i386/i386.c:35437
 #, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "đối số cuối phải là giá trị trực tiếp 1-bít"
 
-#: config/i386/i386.c:35447
+#: config/i386/i386.c:35450
 #, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "đối số cuối phải là giá trị trực tiếp 5-bít"
 
-#: config/i386/i386.c:35457
+#: config/i386/i386.c:35460
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:35462 config/i386/i386.c:36249
+#: config/i386/i386.c:35465 config/i386/i386.c:36252
 #, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "đối số cuối phải là giá trị trực tiếp 8-bít"
 
-#: config/i386/i386.c:35596
+#: config/i386/i386.c:35599
 #, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr "đối số thứ năm phải là giá trị trực tiếp 8-bit"
 
-#: config/i386/i386.c:35601
+#: config/i386/i386.c:35604
 #, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr "chế độ so sánh không đúng"
 
-#: config/i386/i386.c:35607 config/i386/i386.c:35814
+#: config/i386/i386.c:35610 config/i386/i386.c:35817
 #, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr "lệnh không đúng:"
 
-#: config/i386/i386.c:35796
+#: config/i386/i386.c:35799
 #, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "đối số trực tiếp phải là giá trị trực tiếp 4-bít"
 
-#: config/i386/i386.c:35802
+#: config/i386/i386.c:35805
 #, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "đối số trực tiếp phải là giá trị trực tiếp 5-bít"
 
-#: config/i386/i386.c:35805
+#: config/i386/i386.c:35808
 #, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "đối số trực tiếp phải là giá trị trực tiếp 8-bít"
 
-#: config/i386/i386.c:36247
+#: config/i386/i386.c:36250
 #, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "đối số cuối phải là giá trị trực tiếp 32-bít"
 
-#: config/i386/i386.c:36329 config/powerpcspe/powerpcspe.c:16219
-#: config/rs6000/rs6000.c:15304
+#: config/i386/i386.c:36332 config/powerpcspe/powerpcspe.c:16219
+#: config/rs6000/rs6000.c:15348
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr ""
 
-#: config/i386/i386.c:36539
+#: config/i386/i386.c:36542
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr ""
 
-#: config/i386/i386.c:36543
+#: config/i386/i386.c:36546
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "%qE cần là tùy chọn %s"
 
-#: config/i386/i386.c:37381
+#: config/i386/i386.c:37375
 #, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "đối số cuối phải là giá trị trực tiếp"
 
-#: config/i386/i386.c:38108 config/i386/i386.c:38290
+#: config/i386/i386.c:38102 config/i386/i386.c:38284
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "đối số cuối phải là tỷ lệ 1, 2, 4, 8"
 
-#: config/i386/i386.c:38343
+#: config/i386/i386.c:38337
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "đối số thứ tư phải là tỷ lệ 1, 2, 4, 8"
 
-#: config/i386/i386.c:38349
+#: config/i386/i386.c:38343
 #, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr "lệnh không đúng:"
 
-#: config/i386/i386.c:38368
+#: config/i386/i386.c:38362
 #, gcc-internal-format
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:41431
+#: config/i386/i386.c:41425
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "Thuộc tính %qE chỉ dùng được trên hệ thống 32-bit"
 
-#: config/i386/i386.c:41452
+#: config/i386/i386.c:41446
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr ""
 
-#: config/i386/i386.c:41485 config/i386/i386.c:41494
+#: config/i386/i386.c:41479 config/i386/i386.c:41488
 #, gcc-internal-format
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:41530 config/powerpcspe/powerpcspe.c:35868
-#: config/rs6000/rs6000.c:33065
+#: config/i386/i386.c:41524 config/powerpcspe/powerpcspe.c:35868
+#: config/rs6000/rs6000.c:33121
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr ""
 
-#: config/i386/i386.c:41555 config/i386/i386.c:41577 config/ia64/ia64.c:815
+#: config/i386/i386.c:41549 config/i386/i386.c:41571 config/ia64/ia64.c:815
 #: config/s390/s390.c:1153
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr ""
 
-#: config/i386/i386.c:41565 config/i386/i386.c:41587 config/s390/s390.c:1182
+#: config/i386/i386.c:41559 config/i386/i386.c:41581 config/s390/s390.c:1182
 #, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr ""
 
-#: config/i386/i386.c:41619
+#: config/i386/i386.c:41613
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386.c:41626
+#: config/i386/i386.c:41620
 #, gcc-internal-format, gfc-internal-format
 msgid "interrupt service routine should have unsigned %sint as the second argument"
 msgstr ""
 
-#: config/i386/i386.c:41636
+#: config/i386/i386.c:41630
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386.c:41639
+#: config/i386/i386.c:41633
 #, gcc-internal-format
 msgid "interrupt service routine can't have non-void return value"
 msgstr ""
 
-#: config/i386/i386.c:44676
+#: config/i386/i386.c:44670
 #, gcc-internal-format
 msgid "alternatives not allowed in asm flag output"
 msgstr ""
 
-#: config/i386/i386.c:44740
+#: config/i386/i386.c:44734
 #, gcc-internal-format
 msgid "unknown asm flag output %qs"
 msgstr ""
 
-#: config/i386/i386.c:44769
+#: config/i386/i386.c:44763
 #, gcc-internal-format
 msgid "invalid type for asm flag output"
 msgstr ""
 
-#: config/i386/i386.c:50634
+#: config/i386/i386.c:50628
 #, fuzzy, gcc-internal-format
 #| msgid "unknown pointer size model %qs"
 msgid "unknown architecture specific memory model"
 msgstr "không hiểu mô hình kích thước con trỏ %qs"
 
-#: config/i386/i386.c:50641
+#: config/i386/i386.c:50635
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50647
+#: config/i386/i386.c:50641
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50671 config/i386/i386.c:50787
+#: config/i386/i386.c:50665 config/i386/i386.c:50781
 #, gcc-internal-format, gfc-internal-format
 msgid "unsupported simdlen %d"
 msgstr "simdlen không được hỗ trợ %d"
 
-#: config/i386/i386.c:50690
+#: config/i386/i386.c:50684
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %qD"
 msgid "unsupported return type %qT for simd"
 msgstr "đối số không được hỗ trợ cho %D"
 
-#: config/i386/i386.c:50712
+#: config/i386/i386.c:50706
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %qD"
 msgid "unsupported argument type %qT for simd"
 msgstr "đối số không được hỗ trợ cho %D"
 
-#: config/i386/i386.c:51033
+#: config/i386/i386.c:51027
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr ""
@@ -30268,7 +30312,7 @@
 msgstr ""
 
 #: config/m68k/m68k.c:1128 config/powerpcspe/powerpcspe.c:28512
-#: config/rs6000/rs6000.c:25791
+#: config/rs6000/rs6000.c:25868
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr ""
@@ -30849,58 +30893,58 @@
 
 #. Trampoline is not supported on reduced-set registers yet.
 #: config/nds32/nds32.c:2327 config/nds32/nds32.c:2381
-#: config/nds32/nds32.c:3127 config/nds32/nds32.c:3201
-#: config/nds32/nds32.c:3216 config/nds32/nds32.c:3222
-#: config/nds32/nds32.c:3284 config/nds32/nds32.c:3290
-#: config/nds32/nds32.c:3322
+#: config/nds32/nds32.c:3128 config/nds32/nds32.c:3202
+#: config/nds32/nds32.c:3217 config/nds32/nds32.c:3223
+#: config/nds32/nds32.c:3285 config/nds32/nds32.c:3291
+#: config/nds32/nds32.c:3323
 #, gcc-internal-format
 msgid "a nested function is not supported for reduced registers"
 msgstr ""
 
 #. The enum index value for array size is out of range.
-#: config/nds32/nds32.c:3025
+#: config/nds32/nds32.c:3026
 #, gcc-internal-format
 msgid "intrinsic register index is out of range"
 msgstr ""
 
-#: config/nds32/nds32.c:3041 config/nds32/nds32.c:3048
-#: config/nds32/nds32.c:3055 config/nds32/nds32.c:3062
-#: config/nds32/nds32.c:3069
+#: config/nds32/nds32.c:3042 config/nds32/nds32.c:3049
+#: config/nds32/nds32.c:3056 config/nds32/nds32.c:3063
+#: config/nds32/nds32.c:3070
 #, gcc-internal-format
 msgid "CCTL intrinsic function subtype out of range!"
 msgstr ""
 
-#: config/nds32/nds32.c:3508
+#: config/nds32/nds32.c:3509
 #, gcc-internal-format
 msgid "invalid id value for interrupt/exception attribute"
 msgstr ""
 
-#: config/nds32/nds32.c:3536
+#: config/nds32/nds32.c:3537
 #, gcc-internal-format
 msgid "invalid id value for reset attribute"
 msgstr ""
 
-#: config/nds32/nds32.c:3552
+#: config/nds32/nds32.c:3553
 #, gcc-internal-format
 msgid "invalid nmi function for reset attribute"
 msgstr ""
 
-#: config/nds32/nds32.c:3565
+#: config/nds32/nds32.c:3566
 #, gcc-internal-format
 msgid "invalid warm function for reset attribute"
 msgstr ""
 
-#: config/nds32/nds32.c:3638
+#: config/nds32/nds32.c:3639
 #, gcc-internal-format
 msgid "Disable FPU ISA, the ABI option must be enable '-mfloat-abi=soft'"
 msgstr ""
 
-#: config/nds32/nds32.c:3641
+#: config/nds32/nds32.c:3642
 #, gcc-internal-format
 msgid "'-mabi=2fp+' option only support when FPU available, must be enable '-mext-fpu-sp' or '-mext-fpu-dp'"
 msgstr ""
 
-#: config/nds32/nds32.c:3647
+#: config/nds32/nds32.c:3648
 #, fuzzy, gcc-internal-format
 #| msgid "-pipe not supported"
 msgid "position-independent code not supported"
@@ -31241,12 +31285,12 @@
 msgid "junk at end of #pragma longcall"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6154
+#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6152
 #, gcc-internal-format
 msgid "vec_lvsl is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6158
+#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6156
 #, gcc-internal-format
 msgid "vec_lvsr is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
@@ -31296,7 +31340,7 @@
 msgid "vec_insert only accepts 3 arguments"
 msgstr "vec_insert chỉ chấp nhận ba tham số"
 
-#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6868
+#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6866
 #, gcc-internal-format
 msgid "passing arg %d of %qE discards qualifiers from pointer target type"
 msgstr ""
@@ -31382,7 +31426,7 @@
 msgid "target attribute or pragma changes SPE ABI"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4351 config/rs6000/rs6000.c:4223
+#: config/powerpcspe/powerpcspe.c:4351 config/rs6000/rs6000.c:4243
 #, gcc-internal-format
 msgid "AltiVec not supported in this target"
 msgstr "AltiVec không được hỗ trợ ở đích này"
@@ -31529,7 +31573,7 @@
 msgid "-mvsx-small-integer requires -mpower8-vector, -mupper-regs-di, and -mdirect-move"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4959 config/rs6000/rs6000.c:4601
+#: config/powerpcspe/powerpcspe.c:4959 config/rs6000/rs6000.c:4628
 #, gcc-internal-format
 msgid "target attribute or pragma changes long double size"
 msgstr ""
@@ -31570,22 +31614,22 @@
 msgstr ""
 
 #: config/powerpcspe/powerpcspe.c:5140 config/powerpcspe/powerpcspe.c:5155
-#: config/rs6000/rs6000.c:4766 config/rs6000/rs6000.c:4781
+#: config/rs6000/rs6000.c:4791 config/rs6000/rs6000.c:4806
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:5168 config/rs6000/rs6000.c:4794
+#: config/powerpcspe/powerpcspe.c:5168 config/rs6000/rs6000.c:4819
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:5234 config/rs6000/rs6000.c:4828
+#: config/powerpcspe/powerpcspe.c:5234 config/rs6000/rs6000.c:4853
 #, gcc-internal-format
 msgid "target attribute or pragma changes single precision floating point"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:5237 config/rs6000/rs6000.c:4831
+#: config/powerpcspe/powerpcspe.c:5237 config/rs6000/rs6000.c:4856
 #, gcc-internal-format
 msgid "target attribute or pragma changes double precision floating point"
 msgstr ""
@@ -31595,12 +31639,12 @@
 msgid "-mstack-protector-guard=tls needs a valid base register"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:8415 config/rs6000/rs6000.c:7925
+#: config/powerpcspe/powerpcspe.c:8415 config/rs6000/rs6000.c:7950
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11237
+#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11269
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
@@ -31610,7 +31654,7 @@
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11595
+#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11633
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr ""
@@ -31620,12 +31664,12 @@
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12604
+#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12648
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12779
+#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12823
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
@@ -31635,28 +31679,28 @@
 msgid "internal error: builtin function %s already processed"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:13971
+#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:14015
 #, gcc-internal-format
 msgid "argument 1 must be an 8-bit field value"
 msgstr "đối số 1 phải là trường 8-bit"
 
-#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14015
+#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14059
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "đối số 1 phải là kiểu văn có dấu 5-bit"
 
 #: config/powerpcspe/powerpcspe.c:14934 config/powerpcspe/powerpcspe.c:16803
-#: config/rs6000/rs6000.c:14101
+#: config/rs6000/rs6000.c:14145
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "đối số 2 phải là kiểu văn không dấu 5-bit"
 
-#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14119
+#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14163
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "đối số 1 phải là kiểu văn không dấu 1-bit"
 
-#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14135
+#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14179
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 7-bit unsigned literal"
 msgstr "đối số 2 phải là kiểu văn không dấu 5-bit"
@@ -31676,12 +31720,12 @@
 msgid "builtin %s is only valid in 64-bit mode"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14791
+#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14835
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %d must be an unsigned literal"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14793
+#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14837
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr ""
@@ -31703,53 +31747,53 @@
 msgid "hwcap %s is an invalid argument to builtin %s"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15065
+#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15109
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "đối số 3 phải là kiểu văn không dấu 4-bit"
 
-#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15090
+#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15134
 #, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "đối số 3 phải là kiểu văn không dấu 2-bit"
 
-#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15110
+#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15154
 #, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "đối số 3 phải là kiểu văn không dấu 1-bit"
 
-#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15122
+#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15166
 #, gcc-internal-format
 msgid "argument 1 must be 0 or 2"
 msgstr "đối số 1 phải là 0 hay 2"
 
-#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15134
+#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15178
 #, gcc-internal-format
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "đối số 1 phải là kiểu văn không dấu 1-bit"
 
-#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15148
+#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15192
 #, gcc-internal-format
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "đối số 2 phải là kiểu văn không dấu 6-bit"
 
-#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15160
+#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15204
 #, gcc-internal-format
 msgid "argument 2 must be 0 or 1"
 msgstr "đối số 2 phải là 0 hay 1"
 
-#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15168
+#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15212
 #, gcc-internal-format
 msgid "argument 3 must be in the range 0..15"
 msgstr "đối số 3 phải nằm trong vùng 0…15"
 
-#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15237
-#: config/rs6000/rs6000.c:15569
+#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15281
+#: config/rs6000/rs6000.c:15613
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15394
+#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15438
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr ""
@@ -31874,7 +31918,7 @@
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25758
+#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25835
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr "khung stack quá lớn"
@@ -31884,12 +31928,12 @@
 msgid "-fsplit-stack uses register r29"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29459
+#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29536
 #, gcc-internal-format
 msgid "Stack frame larger than 2G is not supported for -fsplit-stack"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30447
+#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30524
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr ""
@@ -31899,22 +31943,22 @@
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32830
+#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32907
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32832
+#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32909
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32834
+#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32911
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32836
+#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32913
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr ""
@@ -31924,7 +31968,7 @@
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32845
+#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32922
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr ""
@@ -32469,78 +32513,78 @@
 "Please use an explicit cpu name.  Valid cpu names are: %s"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6168 config/rs6000/rs6000-c.c:6219
-#: config/rs6000/rs6000-c.c:6489 config/rs6000/rs6000-c.c:6555
-#: config/rs6000/rs6000-c.c:6916 config/rs6000/rs6000-c.c:6963
+#: config/rs6000/rs6000-c.c:6166 config/rs6000/rs6000-c.c:6217
+#: config/rs6000/rs6000-c.c:6487 config/rs6000/rs6000-c.c:6553
+#: config/rs6000/rs6000-c.c:6914 config/rs6000/rs6000-c.c:6961
 #, fuzzy, gcc-internal-format
 #| msgid "builtin %s only accepts a string argument"
 msgid "builtin %qs only accepts 2 arguments"
 msgstr "%s chỉ chấp nhận một tham số"
 
-#: config/rs6000/rs6000-c.c:6292 config/rs6000/rs6000-c.c:6375
-#: config/rs6000/rs6000-c.c:6736
+#: config/rs6000/rs6000-c.c:6290 config/rs6000/rs6000-c.c:6373
+#: config/rs6000/rs6000-c.c:6734
 #, fuzzy, gcc-internal-format
 #| msgid "builtin %s only accepts a string argument"
 msgid "builtin %qs only accepts 3 arguments"
 msgstr "%s chỉ chấp nhận một tham số"
 
-#: config/rs6000/rs6000-c.c:6484
+#: config/rs6000/rs6000-c.c:6482
 #, fuzzy, gcc-internal-format
 #| msgid "builtin %s only accepts a string argument"
 msgid "builtin %qs only accepts 1 argument"
 msgstr "%s chỉ chấp nhận một tham số"
 
-#: config/rs6000/rs6000-c.c:7054
+#: config/rs6000/rs6000-c.c:7052
 #, fuzzy, gcc-internal-format
 #| msgid "Function %qs requires an argument list at %C"
 msgid "builtin %qs requires builtin %qs"
 msgstr "Hàm %qs cần một danh sách đối số tại %C"
 
-#: config/rs6000/rs6000-c.c:7058
+#: config/rs6000/rs6000-c.c:7056
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs not supported in this compiler configuration"
 msgstr "-pie không được hỗ trợ trong cấu hình này"
 
-#: config/rs6000/rs6000-c.c:7068
+#: config/rs6000/rs6000-c.c:7066
 #, gcc-internal-format
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3754 config/rs6000/rs6000.c:3757
-#: config/rs6000/rs6000.c:3760
+#: config/rs6000/rs6000.c:3772 config/rs6000/rs6000.c:3775
+#: config/rs6000/rs6000.c:3778
 #, gcc-internal-format
 msgid "%qs requires %qs or %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3861
+#: config/rs6000/rs6000.c:3879
 #, fuzzy, gcc-internal-format
 #| msgid "-m64 requires PowerPC64 architecture, enabling"
 msgid "%qs requires PowerPC64 architecture, enabling"
 msgstr "-m64 yêu cầu kiến trúc PowerPC64, đang bật"
 
-#: config/rs6000/rs6000.c:4037
+#: config/rs6000/rs6000.c:4057
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated"
 msgid "%qs command-line option is deprecated"
 msgstr "%qs đã lạc hậu"
 
-#: config/rs6000/rs6000.c:4048
+#: config/rs6000/rs6000.c:4068
 #, gcc-internal-format
 msgid "%qs is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4147
+#: config/rs6000/rs6000.c:4167
 #, gcc-internal-format
 msgid "will not generate %qs instructions because assembler lacks %qs support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4240
+#: config/rs6000/rs6000.c:4260
 #, fuzzy, gcc-internal-format
 #| msgid "-mstring is not supported on little endian systems"
 msgid "%qs is not supported on little endian systems"
 msgstr "-mstring không được hỗ trợ trên hệ thống lớn trước"
 
-#: config/rs6000/rs6000.c:4333
+#: config/rs6000/rs6000.c:4353
 #, gcc-internal-format
 msgid "power9 target option is incompatible with %<%s=<xxx>%> for <xxx> less than power9"
 msgstr ""
@@ -32547,7 +32591,7 @@
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:4341
+#: config/rs6000/rs6000.c:4361
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is incompatible with %s %s"
 msgid "%qs incompatible with explicitly disabled options"
@@ -32557,128 +32601,128 @@
 #. error messages.  However, if users have managed to select
 #. power9-fusion without selecting power8-fusion, they
 #. already know about undocumented flags.
-#: config/rs6000/rs6000.c:4366 config/rs6000/rs6000.c:4373
-#: config/rs6000/rs6000.c:4380 config/rs6000/rs6000.c:4388
-#: config/rs6000/rs6000.c:4407 config/rs6000/rs6000.c:4464
-#: config/rs6000/rs6000.c:4468 config/rs6000/rs6000.c:4485
-#: config/rs6000/rs6000.c:4538 config/rs6000/rs6000.c:4565
-#: config/rs6000/rs6000.c:4580 config/rs6000/rs6000.c:4588
-#: config/rs6000/rs6000.c:4684
+#: config/rs6000/rs6000.c:4386 config/rs6000/rs6000.c:4393
+#: config/rs6000/rs6000.c:4400 config/rs6000/rs6000.c:4408
+#: config/rs6000/rs6000.c:4427 config/rs6000/rs6000.c:4484
+#: config/rs6000/rs6000.c:4488 config/rs6000/rs6000.c:4505
+#: config/rs6000/rs6000.c:4558 config/rs6000/rs6000.c:4585
+#: config/rs6000/rs6000.c:4600 config/rs6000/rs6000.c:4608
+#: config/rs6000/rs6000.c:4709
 #, fuzzy, gcc-internal-format
 #| msgid "%qT referred to as %qs"
 msgid "%qs requires %qs"
 msgstr "%qT được coi là %qs"
 
-#: config/rs6000/rs6000.c:4625
+#: config/rs6000/rs6000.c:4650
 #, fuzzy, gcc-internal-format
 #| msgid "using IEEE extended precision long double"
 msgid "Using IEEE extended precision long double"
 msgstr "dùng phần mở rộng số nguyên chính đôi IEEE"
 
-#: config/rs6000/rs6000.c:4627
+#: config/rs6000/rs6000.c:4652
 #, fuzzy, gcc-internal-format
 #| msgid "using IBM extended precision long double"
 msgid "Using IBM extended precision long double"
 msgstr "dùng phần mở rộng số nguyên chính đôi IBM"
 
-#: config/rs6000/rs6000.c:4644
+#: config/rs6000/rs6000.c:4669
 #, fuzzy, gcc-internal-format
 #| msgid "-mfloat128 requires VSX support"
 msgid "%qs requires VSX support"
 msgstr "-mfloat128 cần hỗ trợ VSX"
 
-#: config/rs6000/rs6000.c:4653
+#: config/rs6000/rs6000.c:4678
 #, gcc-internal-format
 msgid "The -mfloat128 option may not be fully supported"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4676
+#: config/rs6000/rs6000.c:4701
 #, fuzzy, gcc-internal-format
 #| msgid "-mfloat128-hardware requires full ISA 3.0 support"
 msgid "%qs requires full ISA 3.0 support"
 msgstr "-mfloat128-hardware cần được ISA 3.0 hỗ trợ"
 
-#: config/rs6000/rs6000.c:4743
+#: config/rs6000/rs6000.c:4768
 #, fuzzy, gcc-internal-format
 #| msgid "Known vectorization library ABIs (for use with the -mveclibabi= option):"
 msgid "unknown vectorization library ABI type (%qs) for %qs switch"
 msgstr "Chưa biết thư viện véc-tơ-hóa ABIs (để dùng với tùy chọn -mveclibabi=):"
 
-#: config/rs6000/rs6000.c:4930
+#: config/rs6000/rs6000.c:4955
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "%qs is not a valid number in %qs"
 msgstr "%qs không hợp lệ cho %qs"
 
-#: config/rs6000/rs6000.c:4935
+#: config/rs6000/rs6000.c:4960
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "%qs is not a valid offset in %qs"
 msgstr "%qs không hợp lệ cho %qs"
 
-#: config/rs6000/rs6000.c:4947
+#: config/rs6000/rs6000.c:4972
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid class name"
 msgid "%qs is not a valid base register in %qs"
 msgstr "“%qs” không phải là một tên lớp đúng"
 
-#: config/rs6000/rs6000.c:4955
+#: config/rs6000/rs6000.c:4980
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid class name"
 msgid "%qs needs a valid base register"
 msgstr "“%qs” không phải là một tên lớp đúng"
 
-#: config/rs6000/rs6000.c:5253
+#: config/rs6000/rs6000.c:5278
 #, fuzzy, gcc-internal-format
 #| msgid "unknown option for -mrecip=%s"
 msgid "unknown option for %<%s=%s%>"
 msgstr "không hiểu tùy chọn cho -mrecip=%s"
 
-#: config/rs6000/rs6000.c:5290
+#: config/rs6000/rs6000.c:5315
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated and has no effect"
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr "%qs đã lỗi thời và không có tác động gì"
 
-#: config/rs6000/rs6000.c:11401
+#: config/rs6000/rs6000.c:11439
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11862
+#: config/rs6000/rs6000.c:11906
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13572
+#: config/rs6000/rs6000.c:13616
 #, gcc-internal-format
 msgid "internal error: builtin function %qs already processed"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14150
+#: config/rs6000/rs6000.c:14194
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 1-bit unsigned literal"
 msgstr "đối số 2 phải là kiểu văn không dấu 5-bit"
 
-#: config/rs6000/rs6000.c:14189
+#: config/rs6000/rs6000.c:14233
 #, fuzzy, gcc-internal-format
 #| msgid "argument %qd is not a constant"
 msgid "argument 1 of %qs must be a constant"
 msgstr "đối số %qd không phải hằng số"
 
-#: config/rs6000/rs6000.c:14247 config/rs6000/rs6000.c:15898
+#: config/rs6000/rs6000.c:14291 config/rs6000/rs6000.c:15942
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs is too large (max. %d)"
 msgid "argument 1 of %qs is out of range"
 msgstr "đối số cho %qs quá lớn (tối đa là %d)"
 
-#: config/rs6000/rs6000.c:14742
+#: config/rs6000/rs6000.c:14786
 #, gcc-internal-format
 msgid "builtin %qs is only valid in 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14939
+#: config/rs6000/rs6000.c:14983
 #, fuzzy, gcc-internal-format
 #| msgid "builtin %s only accepts a string argument"
 msgid "builtin %qs only accepts a string argument"
@@ -32685,7 +32729,7 @@
 msgstr "%s chỉ chấp nhận một tham số"
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000.c:14958
+#: config/rs6000/rs6000.c:15002
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to %qD"
 msgid "cpu %qs is an invalid argument to builtin %qs"
@@ -32692,132 +32736,133 @@
 msgstr "đối số không hợp lệ cho %qD"
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000.c:14986
+#: config/rs6000/rs6000.c:15030
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to %qD"
 msgid "%s %qs is an invalid argument to builtin %qs"
 msgstr "đối số không hợp lệ cho %qD"
 
-#: config/rs6000/rs6000.c:15012
+#: config/rs6000/rs6000.c:15056
 #, gcc-internal-format
 msgid "builtin %qs needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15616
+#: config/rs6000/rs6000.c:15660
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be 0 or 2"
 msgid "second argument to %qs must be 0..12"
 msgstr "đối số 1 phải là 0 hay 2"
 
-#: config/rs6000/rs6000.c:15631
+#: config/rs6000/rs6000.c:15675
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be 0 or 2"
 msgid "third argument to %qs must be 0..12"
 msgstr "đối số 1 phải là 0 hay 2"
 
-#: config/rs6000/rs6000.c:15850
+#: config/rs6000/rs6000.c:15894
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 1 must be a map"
 msgid "argument 1 of %s must be a constant"
 msgstr "đối số 1 phải là ánh xạ"
 
-#: config/rs6000/rs6000.c:15932
+#: config/rs6000/rs6000.c:15976
 #, fuzzy, gcc-internal-format
 #| msgid "this builtin function is only available on the fr450"
 msgid "builtin function %qs is only valid for the cell processor"
 msgstr "hàm dựng sẵn chỉ sẵn có trên fr405"
 
-#: config/rs6000/rs6000.c:15934 config/rs6000/rs6000.c:15936
-#: config/rs6000/rs6000.c:15938 config/rs6000/rs6000.c:15940
-#: config/rs6000/rs6000.c:15946 config/rs6000/rs6000.c:15948
-#: config/rs6000/rs6000.c:15955 config/rs6000/rs6000.c:15962
-#: config/rs6000/rs6000.c:15969 config/rs6000/rs6000.c:15975
+#: config/rs6000/rs6000.c:15978 config/rs6000/rs6000.c:15980
+#: config/rs6000/rs6000.c:15982 config/rs6000/rs6000.c:15984
+#: config/rs6000/rs6000.c:15990 config/rs6000/rs6000.c:15992
+#: config/rs6000/rs6000.c:15999 config/rs6000/rs6000.c:16006
+#: config/rs6000/rs6000.c:16011 config/rs6000/rs6000.c:16014
+#: config/rs6000/rs6000.c:16018 config/rs6000/rs6000.c:16024
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs requires the %qs option"
 msgstr "-mtoc-fusion cần -mpower8-fusion"
 
-#: config/rs6000/rs6000.c:15943 config/rs6000/rs6000.c:15952
-#: config/rs6000/rs6000.c:15959 config/rs6000/rs6000.c:15966
+#: config/rs6000/rs6000.c:15987 config/rs6000/rs6000.c:15996
+#: config/rs6000/rs6000.c:16003
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs requires the %qs and %qs options"
 msgstr "-mtoc-fusion cần -mpower8-fusion"
 
-#: config/rs6000/rs6000.c:15972
+#: config/rs6000/rs6000.c:16021
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs requires ISA 3.0 IEEE 128-bit floating point"
 msgstr "-mtoc-fusion cần -mpower8-fusion"
 
-#: config/rs6000/rs6000.c:15978
+#: config/rs6000/rs6000.c:16027
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs requires the %qs (or newer), and %qs or %qs options"
 msgstr "-mtoc-fusion cần -mpower8-fusion"
 
-#: config/rs6000/rs6000.c:15982
+#: config/rs6000/rs6000.c:16031
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs is not supported with the current options"
 msgstr "-pie không được hỗ trợ trong cấu hình này"
 
-#: config/rs6000/rs6000.c:18218
+#: config/rs6000/rs6000.c:18290
 #, gcc-internal-format
 msgid "internal error: builtin function %qs had an unexpected return type %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18235
+#: config/rs6000/rs6000.c:18307
 #, gcc-internal-format
 msgid "internal error: builtin function %qs, argument %d had unexpected argument type %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:29451
+#: config/rs6000/rs6000.c:29528
 #, fuzzy, gcc-internal-format
 #| msgid "%qE used with %<register%>"
 msgid "%qs uses register r29"
 msgstr "%qE được dùng với %<register%>"
 
-#: config/rs6000/rs6000.c:32748
+#: config/rs6000/rs6000.c:32825
 #, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32842
+#: config/rs6000/rs6000.c:32919
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32850
+#: config/rs6000/rs6000.c:32927
 #, fuzzy, gcc-internal-format
 #| msgid "%<long long%> invalid for %qs"
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "%<long long%> không hợp lệ với %qs"
 
-#: config/rs6000/rs6000.c:32853
+#: config/rs6000/rs6000.c:32930
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:36876
+#: config/rs6000/rs6000.c:36932
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cpu \"%s\" for %s\"%s\"%s"
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "sai cpu \"%s\" cho %s\"%s\"%s"
 
-#: config/rs6000/rs6000.c:36879
+#: config/rs6000/rs6000.c:36935
 #, fuzzy, gcc-internal-format
 #| msgid "%s\"%s\"%s is not allowed"
 msgid "%s%qs%s is not allowed"
 msgstr "%s\"%s\"%s là không được phép"
 
-#: config/rs6000/rs6000.c:36881
+#: config/rs6000/rs6000.c:36937
 #, fuzzy, gcc-internal-format
 #| msgid "%s\"%s\"%s is invalid"
 msgid "%s%qs%s is invalid"
 msgstr "%s\"%s\"%s không hợp lệ"
 
-#: config/rs6000/rs6000.c:37416
+#: config/rs6000/rs6000.c:37472
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:37575
+#: config/rs6000/rs6000.c:37631
 #, gcc-internal-format
 msgid "target_clones attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
@@ -33570,48 +33615,48 @@
 msgid "subprogram %q+F not marked Inline"
 msgstr ""
 
-#: ada/gcc-interface/trans.c:6404
+#: ada/gcc-interface/trans.c:6401
 #, gcc-internal-format
 msgid "out-of-bounds access may be optimized away"
 msgstr ""
 
-#: ada/gcc-interface/trans.c:6406
+#: ada/gcc-interface/trans.c:6403
 #, gcc-internal-format
 msgid "containing loop"
 msgstr "chứa vòng lặp"
 
-#: ada/gcc-interface/utils.c:3887
+#: ada/gcc-interface/utils.c:3890
 #, gcc-internal-format
 msgid "invalid element type for attribute %qs"
 msgstr ""
 
-#: ada/gcc-interface/utils.c:3911
+#: ada/gcc-interface/utils.c:3914
 #, gcc-internal-format
 msgid "number of components of vector not a power of two"
 msgstr "số lượng thành phần của véctơ không thể là mũ của hai"
 
-#: ada/gcc-interface/utils.c:6037 ada/gcc-interface/utils.c:6215
-#: ada/gcc-interface/utils.c:6322
+#: ada/gcc-interface/utils.c:6043 ada/gcc-interface/utils.c:6220
+#: ada/gcc-interface/utils.c:6327
 #, gcc-internal-format
 msgid "%qs attribute ignored"
 msgstr "thuộc tính %qs bị bỏ qua"
 
-#: ada/gcc-interface/utils.c:6158
+#: ada/gcc-interface/utils.c:6164
 #, gcc-internal-format
 msgid "%qs attribute requires prototypes with named arguments"
 msgstr ""
 
-#: ada/gcc-interface/utils.c:6167
+#: ada/gcc-interface/utils.c:6173
 #, gcc-internal-format
 msgid "%qs attribute only applies to variadic functions"
 msgstr ""
 
-#: ada/gcc-interface/utils.c:6282
+#: ada/gcc-interface/utils.c:6287
 #, gcc-internal-format
 msgid "%qE attribute has no effect"
 msgstr ""
 
-#: ada/gcc-interface/utils.c:6406
+#: ada/gcc-interface/utils.c:6411
 #, gcc-internal-format
 msgid "attribute %qs applies to array types only"
 msgstr ""
@@ -33627,7 +33672,7 @@
 #. an unprototyped function, it is compile-time undefined;
 #. making it a constraint in that case was rejected in
 #. DR#252.
-#: c/c-convert.c:101 c/c-typeck.c:2175 c/c-typeck.c:6507 c/c-typeck.c:12138
+#: c/c-convert.c:101 c/c-typeck.c:2175 c/c-typeck.c:6512 c/c-typeck.c:12143
 #: cp/typeck.c:2027 cp/typeck.c:7977 cp/typeck.c:8742
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
@@ -33688,7 +33733,7 @@
 msgid "type of array %q+D completed incompatibly with implicit initialization"
 msgstr ""
 
-#: c/c-decl.c:1567 c/c-decl.c:6701 c/c-decl.c:7574 c/c-decl.c:8381
+#: c/c-decl.c:1567 c/c-decl.c:6721 c/c-decl.c:7594 c/c-decl.c:8401
 #, gcc-internal-format
 msgid "originally defined here"
 msgstr "định nghĩa lần đầu ở đây"
@@ -34093,16 +34138,11 @@
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.c:4548 c/c-decl.c:7147
+#: c/c-decl.c:4548 c/c-decl.c:7167
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr ""
 
-#: c/c-decl.c:4635 cp/decl2.c:1520
-#, gcc-internal-format
-msgid "%q+D in declare target directive does not have mappable type"
-msgstr ""
-
 #: c/c-decl.c:4693
 #, gcc-internal-format
 msgid "%q+D is usually a function"
@@ -34128,7 +34168,7 @@
 #. of VLAs themselves count as VLAs, it does not make
 #. sense to permit them to be initialized given that
 #. ordinary VLAs may not be initialized.
-#: c/c-decl.c:4732 c/c-decl.c:4747 c/c-typeck.c:7630
+#: c/c-decl.c:4732 c/c-decl.c:4747 c/c-typeck.c:7635
 #, gcc-internal-format
 msgid "variable-sized object may not be initialized"
 msgstr "không thể khởi tạo một đối tượng có kích cỡ biến đổi"
@@ -34188,202 +34228,207 @@
 msgid "uninitialized const %qD is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:5268
+#: c/c-decl.c:5224 cp/decl.c:7318
 #, gcc-internal-format
+msgid "%q+D in declare target directive does not have mappable type"
+msgstr ""
+
+#: c/c-decl.c:5288
+#, gcc-internal-format
 msgid "ISO C forbids forward parameter declarations"
 msgstr ""
 
-#: c/c-decl.c:5371
+#: c/c-decl.c:5391
 #, gcc-internal-format
 msgid "defining a type in a compound literal is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:5425 c/c-decl.c:5440
+#: c/c-decl.c:5445 c/c-decl.c:5460
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant"
 msgstr ""
 
-#: c/c-decl.c:5435
+#: c/c-decl.c:5455
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant expression"
 msgstr ""
 
-#: c/c-decl.c:5446
+#: c/c-decl.c:5466
 #, gcc-internal-format
 msgid "negative width in bit-field %qs"
 msgstr ""
 
-#: c/c-decl.c:5451
+#: c/c-decl.c:5471
 #, gcc-internal-format
 msgid "zero width for bit-field %qs"
 msgstr "độ rộng bằng không cho bit-field %qs"
 
-#: c/c-decl.c:5461
+#: c/c-decl.c:5481
 #, gcc-internal-format
 msgid "bit-field %qs has invalid type"
 msgstr ""
 
-#: c/c-decl.c:5467
+#: c/c-decl.c:5487
 #, gcc-internal-format
 msgid "cannot declare bit-field %qs with %<warn_if_not_aligned%> type"
 msgstr ""
 
-#: c/c-decl.c:5478
+#: c/c-decl.c:5498
 #, gcc-internal-format
 msgid "type of bit-field %qs is a GCC extension"
 msgstr ""
 
-#: c/c-decl.c:5484
+#: c/c-decl.c:5504
 #, gcc-internal-format
 msgid "width of %qs exceeds its type"
 msgstr ""
 
-#: c/c-decl.c:5497
+#: c/c-decl.c:5517
 #, gcc-internal-format
 msgid "%qs is narrower than values of its type"
 msgstr ""
 
-#: c/c-decl.c:5512
+#: c/c-decl.c:5532
 #, gcc-internal-format
 msgid "ISO C90 forbids array %qE whose size can%'t be evaluated"
 msgstr ""
 
-#: c/c-decl.c:5515
+#: c/c-decl.c:5535
 #, gcc-internal-format
 msgid "ISO C90 forbids array whose size can%'t be evaluated"
 msgstr ""
 
-#: c/c-decl.c:5522
+#: c/c-decl.c:5542
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array %qE"
 msgstr "ISO C90 cấm mảng có kích thước biến đổi %qE"
 
-#: c/c-decl.c:5524
+#: c/c-decl.c:5544
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array"
 msgstr "ISO C90 cấm mảng có kích thước biến đổi"
 
-#: c/c-decl.c:5733 c/c-decl.c:6107 c/c-decl.c:6117
+#: c/c-decl.c:5753 c/c-decl.c:6127 c/c-decl.c:6137
 #, gcc-internal-format
 msgid "variably modified %qE at file scope"
 msgstr ""
 
-#: c/c-decl.c:5735
+#: c/c-decl.c:5755
 #, gcc-internal-format
 msgid "variably modified field at file scope"
 msgstr ""
 
-#: c/c-decl.c:5755
+#: c/c-decl.c:5775
 #, gcc-internal-format
 msgid "type defaults to %<int%> in declaration of %qE"
 msgstr ""
 
-#: c/c-decl.c:5759
+#: c/c-decl.c:5779
 #, gcc-internal-format
 msgid "type defaults to %<int%> in type name"
 msgstr ""
 
-#: c/c-decl.c:5791
+#: c/c-decl.c:5811
 #, gcc-internal-format
 msgid "duplicate %<const%>"
 msgstr "lặp lại %<const%>"
 
-#: c/c-decl.c:5793
+#: c/c-decl.c:5813
 #, gcc-internal-format
 msgid "duplicate %<restrict%>"
 msgstr "lặp lại %<restrict%>"
 
-#: c/c-decl.c:5795
+#: c/c-decl.c:5815
 #, gcc-internal-format
 msgid "duplicate %<volatile%>"
 msgstr "lặp lại %<volatile%>"
 
-#: c/c-decl.c:5797
+#: c/c-decl.c:5817
 #, gcc-internal-format
 msgid "duplicate %<_Atomic%>"
 msgstr "trùng lặp %<_Atomic%>"
 
-#: c/c-decl.c:5800
+#: c/c-decl.c:5820
 #, gcc-internal-format, gfc-internal-format
 msgid "conflicting named address spaces (%s vs %s)"
 msgstr ""
 
-#: c/c-decl.c:5823 c/c-parser.c:2821
+#: c/c-decl.c:5843 c/c-parser.c:2821
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified array type"
 msgstr ""
 
-#: c/c-decl.c:5837
+#: c/c-decl.c:5857
 #, gcc-internal-format
 msgid "function definition declared %<auto%>"
 msgstr "định nghĩa hàm được khai báo là %<auto%>"
 
-#: c/c-decl.c:5839
+#: c/c-decl.c:5859
 #, gcc-internal-format
 msgid "function definition declared %<register%>"
 msgstr "định nghĩa hàm được khai báo là %<register%>"
 
-#: c/c-decl.c:5841
+#: c/c-decl.c:5861
 #, gcc-internal-format
 msgid "function definition declared %<typedef%>"
 msgstr "định nghĩa hàm được khai báo là %<typedef%>"
 
-#: c/c-decl.c:5843
+#: c/c-decl.c:5863
 #, gcc-internal-format
 msgid "function definition declared %qs"
 msgstr "định nghĩa hàm được khai báo là %qs"
 
-#: c/c-decl.c:5861
+#: c/c-decl.c:5881
 #, gcc-internal-format
 msgid "storage class specified for structure field %qE"
 msgstr ""
 
-#: c/c-decl.c:5864
+#: c/c-decl.c:5884
 #, gcc-internal-format
 msgid "storage class specified for structure field"
 msgstr ""
 
-#: c/c-decl.c:5868
+#: c/c-decl.c:5888
 #, gcc-internal-format
 msgid "storage class specified for parameter %qE"
 msgstr ""
 
-#: c/c-decl.c:5871
+#: c/c-decl.c:5891
 #, gcc-internal-format
 msgid "storage class specified for unnamed parameter"
 msgstr ""
 
-#: c/c-decl.c:5874 cp/decl.c:10935
+#: c/c-decl.c:5894 cp/decl.c:10959
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr ""
 
-#: c/c-decl.c:5891
+#: c/c-decl.c:5911
 #, gcc-internal-format
 msgid "%qE initialized and declared %<extern%>"
 msgstr ""
 
-#: c/c-decl.c:5895
+#: c/c-decl.c:5915
 #, gcc-internal-format
 msgid "%qE has both %<extern%> and initializer"
 msgstr ""
 
-#: c/c-decl.c:5900
+#: c/c-decl.c:5920
 #, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<auto%>"
 msgstr ""
 
-#: c/c-decl.c:5904
+#: c/c-decl.c:5924
 #, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<register%>"
 msgstr ""
 
-#: c/c-decl.c:5909
+#: c/c-decl.c:5929
 #, gcc-internal-format
 msgid "nested function %qE declared %<extern%>"
 msgstr ""
 
-#: c/c-decl.c:5912
+#: c/c-decl.c:5932
 #, gcc-internal-format
 msgid "function-scope %qE implicitly auto and declared %qs"
 msgstr ""
@@ -34391,701 +34436,701 @@
 #. Only the innermost declarator (making a parameter be of
 #. array type which is converted to pointer type)
 #. may have static or type qualifiers.
-#: c/c-decl.c:5959 c/c-decl.c:6328
+#: c/c-decl.c:5979 c/c-decl.c:6348
 #, gcc-internal-format
 msgid "static or type qualifiers in non-parameter array declarator"
 msgstr ""
 
-#: c/c-decl.c:6007
+#: c/c-decl.c:6027
 #, gcc-internal-format
 msgid "declaration of %qE as array of voids"
 msgstr "sự khai báo của %qE như là mảng của void"
 
-#: c/c-decl.c:6009
+#: c/c-decl.c:6029
 #, gcc-internal-format
 msgid "declaration of type name as array of voids"
 msgstr ""
 
-#: c/c-decl.c:6016
+#: c/c-decl.c:6036
 #, gcc-internal-format
 msgid "declaration of %qE as array of functions"
 msgstr "sự khai báo của %qE như là mảng của các hàm"
 
-#: c/c-decl.c:6019
+#: c/c-decl.c:6039
 #, gcc-internal-format
 msgid "declaration of type name as array of functions"
 msgstr ""
 
-#: c/c-decl.c:6027 c/c-decl.c:8085
+#: c/c-decl.c:6047 c/c-decl.c:8105
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr ""
 
-#: c/c-decl.c:6053
+#: c/c-decl.c:6073
 #, gcc-internal-format
 msgid "size of array %qE has non-integer type"
 msgstr ""
 
-#: c/c-decl.c:6057
+#: c/c-decl.c:6077
 #, gcc-internal-format
 msgid "size of unnamed array has non-integer type"
 msgstr ""
 
-#: c/c-decl.c:6064
+#: c/c-decl.c:6084
 #, fuzzy, gcc-internal-format
 msgid "size of array %qE has incomplete type"
 msgstr "đối số %qD có kiểu chưa đầy đủ"
 
-#: c/c-decl.c:6067
+#: c/c-decl.c:6087
 #, fuzzy, gcc-internal-format
 msgid "size of unnamed array has incomplete type"
 msgstr "cỡ của mảng không tên là âm"
 
-#: c/c-decl.c:6078
+#: c/c-decl.c:6098
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array %qE"
 msgstr "ISO C cấm chỉ mảng có độ dài là không %qE"
 
-#: c/c-decl.c:6081
+#: c/c-decl.c:6101
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array"
 msgstr "ISO C cấm chỉ mảng có độ dài là không"
 
-#: c/c-decl.c:6090
+#: c/c-decl.c:6110
 #, gcc-internal-format
 msgid "size of array %qE is negative"
 msgstr "kích cỡ mảng %qE bị âm"
 
-#: c/c-decl.c:6092
+#: c/c-decl.c:6112
 #, gcc-internal-format
 msgid "size of unnamed array is negative"
 msgstr "cỡ của mảng không tên là âm"
 
-#: c/c-decl.c:6216 c/c-decl.c:6871
+#: c/c-decl.c:6236 c/c-decl.c:6891
 #, gcc-internal-format
 msgid "ISO C90 does not support flexible array members"
 msgstr "ISO C90 không hỗ trợ thành viên mảng linh động"
 
 #. C99 6.7.5.2p4
-#: c/c-decl.c:6238
+#: c/c-decl.c:6258
 #, gcc-internal-format
 msgid "%<[*]%> not in a declaration"
 msgstr "%<[*]%> không trong khai báo"
 
-#: c/c-decl.c:6251
+#: c/c-decl.c:6271
 #, gcc-internal-format
 msgid "array type has incomplete element type %qT"
 msgstr ""
 
-#: c/c-decl.c:6257
+#: c/c-decl.c:6277
 #, gcc-internal-format
 msgid "declaration of %qE as multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: c/c-decl.c:6261
+#: c/c-decl.c:6281
 #, gcc-internal-format
 msgid "declaration of multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: c/c-decl.c:6364
+#: c/c-decl.c:6384
 #, gcc-internal-format
 msgid "%qE declared as function returning a function"
 msgstr ""
 
-#: c/c-decl.c:6367
+#: c/c-decl.c:6387
 #, gcc-internal-format
 msgid "type name declared as function returning a function"
 msgstr ""
 
-#: c/c-decl.c:6374
+#: c/c-decl.c:6394
 #, gcc-internal-format
 msgid "%qE declared as function returning an array"
 msgstr ""
 
-#: c/c-decl.c:6377
+#: c/c-decl.c:6397
 #, gcc-internal-format
 msgid "type name declared as function returning an array"
 msgstr ""
 
-#: c/c-decl.c:6418
+#: c/c-decl.c:6438
 #, gcc-internal-format
 msgid "function definition has qualified void return type"
 msgstr "định nghĩa hàm có kiểu trả về là void"
 
-#: c/c-decl.c:6421 cp/decl.c:11201
+#: c/c-decl.c:6441 cp/decl.c:11225
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr ""
 
-#: c/c-decl.c:6459 c/c-decl.c:6668 c/c-decl.c:6721 c/c-decl.c:6805
-#: c/c-decl.c:6926 c/c-parser.c:2823
+#: c/c-decl.c:6479 c/c-decl.c:6688 c/c-decl.c:6741 c/c-decl.c:6825
+#: c/c-decl.c:6946 c/c-parser.c:2823
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified function type"
 msgstr ""
 
-#: c/c-decl.c:6465 c/c-decl.c:6674 c/c-decl.c:6810 c/c-decl.c:6931
+#: c/c-decl.c:6485 c/c-decl.c:6694 c/c-decl.c:6830 c/c-decl.c:6951
 #, gcc-internal-format
 msgid "ISO C forbids qualified function types"
 msgstr ""
 
-#: c/c-decl.c:6559
+#: c/c-decl.c:6579
 #, gcc-internal-format
 msgid "%qs combined with %<auto%> qualifier for %qE"
 msgstr ""
 
-#: c/c-decl.c:6563
+#: c/c-decl.c:6583
 #, gcc-internal-format
 msgid "%qs combined with %<register%> qualifier for %qE"
 msgstr ""
 
-#: c/c-decl.c:6569
+#: c/c-decl.c:6589
 #, gcc-internal-format
 msgid "%qs specified for auto variable %qE"
 msgstr ""
 
-#: c/c-decl.c:6585
+#: c/c-decl.c:6605
 #, gcc-internal-format
 msgid "%qs specified for parameter %qE"
 msgstr ""
 
-#: c/c-decl.c:6588
+#: c/c-decl.c:6608
 #, gcc-internal-format
 msgid "%qs specified for unnamed parameter"
 msgstr ""
 
-#: c/c-decl.c:6594
+#: c/c-decl.c:6614
 #, gcc-internal-format
 msgid "%qs specified for structure field %qE"
 msgstr ""
 
-#: c/c-decl.c:6597
+#: c/c-decl.c:6617
 #, gcc-internal-format
 msgid "%qs specified for structure field"
 msgstr ""
 
-#: c/c-decl.c:6612
+#: c/c-decl.c:6632
 #, gcc-internal-format
 msgid "bit-field %qE has atomic type"
 msgstr ""
 
-#: c/c-decl.c:6614
+#: c/c-decl.c:6634
 #, gcc-internal-format
 msgid "bit-field has atomic type"
 msgstr ""
 
-#: c/c-decl.c:6623
+#: c/c-decl.c:6643
 #, gcc-internal-format
 msgid "alignment specified for typedef %qE"
 msgstr ""
 
-#: c/c-decl.c:6625
+#: c/c-decl.c:6645
 #, gcc-internal-format
 msgid "alignment specified for %<register%> object %qE"
 msgstr ""
 
-#: c/c-decl.c:6630
+#: c/c-decl.c:6650
 #, gcc-internal-format
 msgid "alignment specified for parameter %qE"
 msgstr ""
 
-#: c/c-decl.c:6632
+#: c/c-decl.c:6652
 #, gcc-internal-format
 msgid "alignment specified for unnamed parameter"
 msgstr ""
 
-#: c/c-decl.c:6637
+#: c/c-decl.c:6657
 #, gcc-internal-format
 msgid "alignment specified for bit-field %qE"
 msgstr ""
 
-#: c/c-decl.c:6639
+#: c/c-decl.c:6659
 #, gcc-internal-format
 msgid "alignment specified for unnamed bit-field"
 msgstr ""
 
-#: c/c-decl.c:6642
+#: c/c-decl.c:6662
 #, gcc-internal-format
 msgid "alignment specified for function %qE"
 msgstr ""
 
-#: c/c-decl.c:6649
+#: c/c-decl.c:6669
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of %qE"
 msgstr ""
 
-#: c/c-decl.c:6652
+#: c/c-decl.c:6672
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of unnamed field"
 msgstr ""
 
-#: c/c-decl.c:6683
+#: c/c-decl.c:6703
 #, gcc-internal-format
 msgid "typedef %q+D declared %<inline%>"
 msgstr "typedef %q+D được khai báo %<inline%>"
 
-#: c/c-decl.c:6685
+#: c/c-decl.c:6705
 #, gcc-internal-format
 msgid "typedef %q+D declared %<_Noreturn%>"
 msgstr "typedef %q+D được khai báo %<_Noreturn%>"
 
-#: c/c-decl.c:6727
+#: c/c-decl.c:6747
 #, gcc-internal-format
 msgid "ISO C forbids const or volatile function types"
 msgstr ""
 
 #. C99 6.7.2.1p8
-#: c/c-decl.c:6738
+#: c/c-decl.c:6758
 #, gcc-internal-format
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr ""
 
-#: c/c-decl.c:6755 cp/decl.c:9989
+#: c/c-decl.c:6775 cp/decl.c:10010
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr ""
 
-#: c/c-decl.c:6795
+#: c/c-decl.c:6815
 #, gcc-internal-format
 msgid "attributes in parameter array declarator ignored"
 msgstr ""
 
-#: c/c-decl.c:6837
+#: c/c-decl.c:6857
 #, gcc-internal-format
 msgid "parameter %q+D declared %<inline%>"
 msgstr "đối số %q+D được khai báo %<inline%>"
 
-#: c/c-decl.c:6839
+#: c/c-decl.c:6859
 #, gcc-internal-format
 msgid "parameter %q+D declared %<_Noreturn%>"
 msgstr "đối số %q+D được khai báo %<_Noreturn%>"
 
-#: c/c-decl.c:6852
+#: c/c-decl.c:6872
 #, gcc-internal-format
 msgid "field %qE declared as a function"
 msgstr "trường %qE được khai báo như là một hàm"
 
-#: c/c-decl.c:6859
+#: c/c-decl.c:6879
 #, gcc-internal-format
 msgid "field %qE has incomplete type"
 msgstr ""
 
-#: c/c-decl.c:6861
+#: c/c-decl.c:6881
 #, gcc-internal-format
 msgid "unnamed field has incomplete type"
 msgstr ""
 
-#: c/c-decl.c:6897 c/c-decl.c:6908 c/c-decl.c:6911
+#: c/c-decl.c:6917 c/c-decl.c:6928 c/c-decl.c:6931
 #, gcc-internal-format
 msgid "invalid storage class for function %qE"
 msgstr ""
 
-#: c/c-decl.c:6968
+#: c/c-decl.c:6988
 #, gcc-internal-format
 msgid "cannot inline function %<main%>"
 msgstr ""
 
-#: c/c-decl.c:6970
+#: c/c-decl.c:6990
 #, gcc-internal-format
 msgid "%<main%> declared %<_Noreturn%>"
 msgstr "%<main%> được khai báo %<_Noreturn%>"
 
-#: c/c-decl.c:6981
+#: c/c-decl.c:7001
 #, gcc-internal-format
 msgid "ISO C99 does not support %<_Noreturn%>"
 msgstr "ISO C99 không hỗ trợ %<_Noreturn%>"
 
-#: c/c-decl.c:6984
+#: c/c-decl.c:7004
 #, gcc-internal-format
 msgid "ISO C90 does not support %<_Noreturn%>"
 msgstr "ISO C90 không hỗ trợ %<_Noreturn%>"
 
-#: c/c-decl.c:7013
+#: c/c-decl.c:7033
 #, gcc-internal-format
 msgid "variable previously declared %<static%> redeclared %<extern%>"
 msgstr ""
 
-#: c/c-decl.c:7023
+#: c/c-decl.c:7043
 #, gcc-internal-format
 msgid "variable %q+D declared %<inline%>"
 msgstr "biến %q+D được khai báo %<inline%>"
 
-#: c/c-decl.c:7025
+#: c/c-decl.c:7045
 #, gcc-internal-format
 msgid "variable %q+D declared %<_Noreturn%>"
 msgstr "biến %q+D được khai báo %<_Noreturn%>"
 
-#: c/c-decl.c:7060
+#: c/c-decl.c:7080
 #, gcc-internal-format
 msgid "non-nested function with variably modified type"
 msgstr ""
 
-#: c/c-decl.c:7062
+#: c/c-decl.c:7082
 #, gcc-internal-format
 msgid "object with variably modified type must have no linkage"
 msgstr ""
 
-#: c/c-decl.c:7153 c/c-decl.c:8821
+#: c/c-decl.c:7173 c/c-decl.c:8841
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr ""
 
-#: c/c-decl.c:7163
+#: c/c-decl.c:7183
 #, gcc-internal-format
 msgid "parameter names (without types) in function declaration"
 msgstr ""
 
-#: c/c-decl.c:7201
+#: c/c-decl.c:7221
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has incomplete type"
 msgstr ""
 
-#: c/c-decl.c:7205
+#: c/c-decl.c:7225
 #, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has incomplete type"
 msgstr ""
 
-#: c/c-decl.c:7216
+#: c/c-decl.c:7236
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has void type"
 msgstr "đối số %u (%q+D) có kiểu void"
 
-#: c/c-decl.c:7220
+#: c/c-decl.c:7240
 #, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has void type"
 msgstr "tham số %u có kiểu void"
 
-#: c/c-decl.c:7294
+#: c/c-decl.c:7314
 #, gcc-internal-format
 msgid "%<void%> as only parameter may not be qualified"
 msgstr ""
 
-#: c/c-decl.c:7298 c/c-decl.c:7334
+#: c/c-decl.c:7318 c/c-decl.c:7354
 #, gcc-internal-format
 msgid "%<void%> must be the only parameter"
 msgstr "%<void%> phải là đối số duy nhất"
 
-#: c/c-decl.c:7328
+#: c/c-decl.c:7348
 #, gcc-internal-format
 msgid "parameter %q+D has just a forward declaration"
 msgstr ""
 
-#: c/c-decl.c:7374
+#: c/c-decl.c:7394
 #, gcc-internal-format
 msgid "%<%s %E%> declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr ""
 
-#: c/c-decl.c:7380
+#: c/c-decl.c:7400
 #, gcc-internal-format, gfc-internal-format
 msgid "anonymous %s declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr ""
 
-#: c/c-decl.c:7482
+#: c/c-decl.c:7502
 #, gcc-internal-format
 msgid "enum type defined here"
 msgstr "kiểu enum được định nghĩa ở đây"
 
-#: c/c-decl.c:7488
+#: c/c-decl.c:7508
 #, gcc-internal-format
 msgid "struct defined here"
 msgstr "struct được định nghĩa ở đây"
 
-#: c/c-decl.c:7494
+#: c/c-decl.c:7514
 #, gcc-internal-format
 msgid "union defined here"
 msgstr "union được định nghĩa ở đây"
 
-#: c/c-decl.c:7570
+#: c/c-decl.c:7590
 #, gcc-internal-format
 msgid "redefinition of %<union %E%>"
 msgstr "định nghĩa lại của %<union %E%>"
 
-#: c/c-decl.c:7572
+#: c/c-decl.c:7592
 #, gcc-internal-format
 msgid "redefinition of %<struct %E%>"
 msgstr "định nghĩa lại của %<struct %E%>"
 
-#: c/c-decl.c:7581
+#: c/c-decl.c:7601
 #, gcc-internal-format
 msgid "nested redefinition of %<union %E%>"
 msgstr "định nghĩa lại bị lồng của %<union %E%>"
 
-#: c/c-decl.c:7583
+#: c/c-decl.c:7603
 #, gcc-internal-format
 msgid "nested redefinition of %<struct %E%>"
 msgstr "định nghĩa lại bị lồng của %<struct %E%>"
 
-#: c/c-decl.c:7613 c/c-decl.c:8400
+#: c/c-decl.c:7633 c/c-decl.c:8420
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:7680 cp/decl.c:4802
+#: c/c-decl.c:7700 cp/decl.c:4802
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr ""
 
-#: c/c-decl.c:7685
+#: c/c-decl.c:7705
 #, gcc-internal-format
 msgid "ISO C99 doesn%'t support unnamed structs/unions"
 msgstr ""
 
-#: c/c-decl.c:7688
+#: c/c-decl.c:7708
 #, gcc-internal-format
 msgid "ISO C90 doesn%'t support unnamed structs/unions"
 msgstr ""
 
-#: c/c-decl.c:7781 c/c-decl.c:7799 c/c-decl.c:7860
+#: c/c-decl.c:7801 c/c-decl.c:7819 c/c-decl.c:7880
 #, gcc-internal-format
 msgid "duplicate member %q+D"
 msgstr "thành viên trùng lặp %q+D"
 
-#: c/c-decl.c:7886
+#: c/c-decl.c:7906
 #, gcc-internal-format
 msgid "empty struct has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.c:7889
+#: c/c-decl.c:7909
 #, gcc-internal-format
 msgid "empty union has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.c:7994
+#: c/c-decl.c:8014
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr "union không có thành viên nào"
 
-#: c/c-decl.c:7996
+#: c/c-decl.c:8016
 #, gcc-internal-format
 msgid "union has no members"
 msgstr "union không có thành viên nào"
 
-#: c/c-decl.c:8001
+#: c/c-decl.c:8021
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr "cấu có không thành viên đã đặt tên"
 
-#: c/c-decl.c:8003
+#: c/c-decl.c:8023
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr "struct không có thành viên nào"
 
-#: c/c-decl.c:8064 cp/decl.c:12069
+#: c/c-decl.c:8084 cp/decl.c:12093
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr ""
 
-#: c/c-decl.c:8070
+#: c/c-decl.c:8090
 #, gcc-internal-format
 msgid "flexible array member not at end of struct"
 msgstr ""
 
-#: c/c-decl.c:8076
+#: c/c-decl.c:8096
 #, fuzzy, gcc-internal-format
 msgid "flexible array member in a struct with no named members"
 msgstr "cấu có không thành viên đã đặt tên"
 
-#: c/c-decl.c:8107
+#: c/c-decl.c:8127
 #, gcc-internal-format
 msgid "type %qT is too large"
 msgstr "kiểu %qT quá lớn"
 
-#: c/c-decl.c:8230
+#: c/c-decl.c:8250
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr ""
 
-#: c/c-decl.c:8372
+#: c/c-decl.c:8392
 #, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr ""
 
 #. This enum is a named one that has been declared already.
-#: c/c-decl.c:8379
+#: c/c-decl.c:8399
 #, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr "khai báo lại của %<enum %E%>"
 
-#: c/c-decl.c:8458 cp/decl.c:14423
+#: c/c-decl.c:8478 cp/decl.c:14447
 #, gcc-internal-format
 msgid "specified mode too small for enumeral values"
 msgstr ""
 
-#: c/c-decl.c:8473
+#: c/c-decl.c:8493
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr ""
 
-#: c/c-decl.c:8587 c/c-decl.c:8603
+#: c/c-decl.c:8607 c/c-decl.c:8623
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr ""
 
-#: c/c-decl.c:8598
+#: c/c-decl.c:8618
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr ""
 
-#: c/c-decl.c:8622
+#: c/c-decl.c:8642
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr "tràn giá trị liệt kê"
 
-#: c/c-decl.c:8630
+#: c/c-decl.c:8650
 #, gcc-internal-format
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr ""
 
-#: c/c-decl.c:8715 cp/decl.c:5104 cp/decl.c:14955
+#: c/c-decl.c:8735 cp/decl.c:5104 cp/decl.c:14979
 #, gcc-internal-format
 msgid "inline function %qD given attribute noinline"
 msgstr ""
 
-#: c/c-decl.c:8733
+#: c/c-decl.c:8753
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr "kiểu trả về là một kiểu không hoàn toàn"
 
-#: c/c-decl.c:8744
+#: c/c-decl.c:8764
 #, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr "trả về kiểu mặc định cho %<int%>"
 
-#: c/c-decl.c:8771
+#: c/c-decl.c:8791
 #, gcc-internal-format
 msgid "%q+D defined as variadic function without prototype"
 msgstr ""
 
-#: c/c-decl.c:8830
+#: c/c-decl.c:8850
 #, gcc-internal-format
 msgid "no previous prototype for %qD"
 msgstr "chưa có khai báo nguyên mẫu trước đây cho %qD"
 
-#: c/c-decl.c:8839
+#: c/c-decl.c:8859
 #, gcc-internal-format
 msgid "%qD was used with no prototype before its definition"
 msgstr ""
 
-#: c/c-decl.c:8847 cp/decl.c:15090
+#: c/c-decl.c:8867 cp/decl.c:15114
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "chưa có khai báo trước đây cho %qD"
 
-#: c/c-decl.c:8857
+#: c/c-decl.c:8877
 #, gcc-internal-format
 msgid "%qD was used with no declaration before its definition"
 msgstr ""
 
-#: c/c-decl.c:8876
+#: c/c-decl.c:8896
 #, gcc-internal-format
 msgid "return type of %qD is not %<int%>"
 msgstr ""
 
-#: c/c-decl.c:8878
+#: c/c-decl.c:8898
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr ""
 
-#: c/c-decl.c:8885
+#: c/c-decl.c:8905
 #, gcc-internal-format
 msgid "%qD is normally a non-static function"
 msgstr "%qD thường không phải là hàm non-static"
 
-#: c/c-decl.c:8922
+#: c/c-decl.c:8942
 #, gcc-internal-format
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr ""
 
-#: c/c-decl.c:8937
+#: c/c-decl.c:8957
 #, gcc-internal-format
 msgid "traditional C rejects ISO C style function definitions"
 msgstr ""
 
-#: c/c-decl.c:8953
+#: c/c-decl.c:8973
 #, gcc-internal-format
 msgid "parameter name omitted"
 msgstr "tên đối số bị bỏ qua"
 
-#: c/c-decl.c:8990
+#: c/c-decl.c:9010
 #, gcc-internal-format
 msgid "old-style function definition"
 msgstr "định nghĩa hàm theo cách cũ"
 
-#: c/c-decl.c:8999
+#: c/c-decl.c:9019
 #, gcc-internal-format
 msgid "parameter name missing from parameter list"
 msgstr ""
 
-#: c/c-decl.c:9015
+#: c/c-decl.c:9035
 #, gcc-internal-format
 msgid "%qD declared as a non-parameter"
 msgstr "%qD đã được định nghĩa là không có tham số"
 
-#: c/c-decl.c:9023
+#: c/c-decl.c:9043
 #, gcc-internal-format
 msgid "multiple parameters named %qD"
 msgstr ""
 
-#: c/c-decl.c:9032
+#: c/c-decl.c:9052
 #, gcc-internal-format
 msgid "parameter %qD declared with void type"
 msgstr "đối số %qD được khai báo với kiểu void"
 
-#: c/c-decl.c:9061 c/c-decl.c:9066
+#: c/c-decl.c:9081 c/c-decl.c:9086
 #, gcc-internal-format
 msgid "type of %qD defaults to %<int%>"
 msgstr "kiểu của %qD mặc định đến %<int%>"
 
-#: c/c-decl.c:9086
+#: c/c-decl.c:9106
 #, gcc-internal-format
 msgid "parameter %qD has incomplete type"
 msgstr "đối số %qD có kiểu chưa đầy đủ"
 
-#: c/c-decl.c:9093
+#: c/c-decl.c:9113
 #, gcc-internal-format
 msgid "declaration for parameter %qD but no such parameter"
 msgstr ""
 
-#: c/c-decl.c:9146
+#: c/c-decl.c:9166
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr ""
 
-#: c/c-decl.c:9157
+#: c/c-decl.c:9177
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr "số lượng đối số không giống với nó khi khai báo mẫu hàm"
 
-#: c/c-decl.c:9160 c/c-decl.c:9207 c/c-decl.c:9221
+#: c/c-decl.c:9180 c/c-decl.c:9227 c/c-decl.c:9241
 #, gcc-internal-format
 msgid "prototype declaration"
 msgstr "khai báo mẫu trước"
 
-#: c/c-decl.c:9199
+#: c/c-decl.c:9219
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr ""
 
-#: c/c-decl.c:9204
+#: c/c-decl.c:9224
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr ""
 
-#: c/c-decl.c:9214
+#: c/c-decl.c:9234
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr ""
 
-#: c/c-decl.c:9219
+#: c/c-decl.c:9239
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr ""
 
-#: c/c-decl.c:9470 cp/decl.c:15873
+#: c/c-decl.c:9490 cp/decl.c:15897
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "%<return%> (trả lại) không có giá trị, trong hàm trả lại non-void (không rỗng)"
 
-#: c/c-decl.c:9490 cp/decl.c:15905
+#: c/c-decl.c:9510 cp/decl.c:15929
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "đối số %qD đặt nhưng chưa được dùng"
@@ -35093,247 +35138,247 @@
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:9586
+#: c/c-decl.c:9606
 #, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr ""
 
-#: c/c-decl.c:9591
+#: c/c-decl.c:9611
 #, gcc-internal-format
 msgid "use option -std=c99, -std=gnu99, -std=c11 or -std=gnu11 to compile your code"
 msgstr ""
 
-#: c/c-decl.c:9626
+#: c/c-decl.c:9646
 #, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:9630
+#: c/c-decl.c:9650
 #, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:9637
+#: c/c-decl.c:9657
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "%<struct %E%> được khai báo trong khai báo khởi tạo vòng lặp %<for%>"
 
-#: c/c-decl.c:9642
+#: c/c-decl.c:9662
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "%<union %E%> được khai báo trong khai báo khởi tạo vòng lặp %<for%>"
 
-#: c/c-decl.c:9646
+#: c/c-decl.c:9666
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "%<enum %E%> được khai báo trong khai báo khởi tạo vòng lặp %<for%>"
 
-#: c/c-decl.c:9650
+#: c/c-decl.c:9670
 #, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:9900
+#: c/c-decl.c:9920
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr ""
 
-#: c/c-decl.c:9958 c/c-decl.c:9965
+#: c/c-decl.c:9978 c/c-decl.c:9985
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qE declaration specifier"
 msgstr "cần các định danh khai báo"
 
-#: c/c-decl.c:9992 c/c-decl.c:10376 c/c-decl.c:10766
+#: c/c-decl.c:10012 c/c-decl.c:10396 c/c-decl.c:10786
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr ""
 
-#: c/c-decl.c:10004 cp/parser.c:28261
+#: c/c-decl.c:10024 cp/parser.c:28258
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> là quá dài đối với GCC"
 
-#: c/c-decl.c:10017
+#: c/c-decl.c:10037
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C90 không hỗ trợ %<long long%>"
 
-#: c/c-decl.c:10246 c/c-parser.c:8848
+#: c/c-decl.c:10266 c/c-parser.c:8848
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C90 không hỗ trợ kiểu complex"
 
-#: c/c-decl.c:10292
+#: c/c-decl.c:10312
 #, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr "ISO C không hỗ trợ kiểu saturating"
 
-#: c/c-decl.c:10363 c/c-decl.c:10923
+#: c/c-decl.c:10383 c/c-decl.c:10943
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "lặp lại %qE"
 
-#: c/c-decl.c:10419
+#: c/c-decl.c:10439
 #, gcc-internal-format
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C không hỗ trợ kiểu %<__int%d%>"
 
-#: c/c-decl.c:10441
+#: c/c-decl.c:10461
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr "%<__int%d%> không được hỗ trợ cho đích này"
 
-#: c/c-decl.c:10484
+#: c/c-decl.c:10504
 #, gcc-internal-format
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C90 không hỗ trợ kiểu lô-gíc"
 
-#: c/c-decl.c:10603
+#: c/c-decl.c:10623
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support the %<_Float%d%s%> type"
 msgstr "ISO C không hỗ trợ kiểu %<__int%d%>"
 
-#: c/c-decl.c:10653
+#: c/c-decl.c:10673
 #, fuzzy, gcc-internal-format
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "%<__int%d%> không được hỗ trợ cho đích này"
 
-#: c/c-decl.c:10724
+#: c/c-decl.c:10744
 #, gcc-internal-format
 msgid "ISO C does not support decimal floating point"
 msgstr "ISO C không hỗ trợ kiểu dấu chấm động hệ thập phân"
 
-#: c/c-decl.c:10747 c/c-decl.c:11013 c/c-parser.c:7842
+#: c/c-decl.c:10767 c/c-decl.c:11033 c/c-parser.c:7842
 #, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "kiểu dấu chấm cố định không được hỗ trợ trên đích này"
 
-#: c/c-decl.c:10749
+#: c/c-decl.c:10769
 #, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C không hỗ trợ kiểu dấu chấm cố định"
 
-#: c/c-decl.c:10784
+#: c/c-decl.c:10804
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr ""
 
-#: c/c-decl.c:10797
+#: c/c-decl.c:10817
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr ""
 
-#: c/c-decl.c:10845
+#: c/c-decl.c:10865
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qE không ở đầu của khai báo"
 
-#: c/c-decl.c:10866
+#: c/c-decl.c:10886
 #, gcc-internal-format
 msgid "%qE used with %<auto%>"
 msgstr "%qE được dùng với %<auto%>"
 
-#: c/c-decl.c:10868
+#: c/c-decl.c:10888
 #, gcc-internal-format
 msgid "%qE used with %<register%>"
 msgstr "%qE được dùng với %<register%>"
 
-#: c/c-decl.c:10870
+#: c/c-decl.c:10890
 #, gcc-internal-format
 msgid "%qE used with %<typedef%>"
 msgstr "%qE được dùng với %<typedef%>"
 
-#: c/c-decl.c:10884 c/c-parser.c:7360
+#: c/c-decl.c:10904 c/c-parser.c:7360
 #, gcc-internal-format
 msgid "ISO C99 does not support %qE"
 msgstr "ISO C99 không hỗ trợ %qE"
 
-#: c/c-decl.c:10887 c/c-parser.c:7363
+#: c/c-decl.c:10907 c/c-parser.c:7363
 #, gcc-internal-format
 msgid "ISO C90 does not support %qE"
 msgstr "ISO C90 không hỗ trợ %qE"
 
-#: c/c-decl.c:10899
+#: c/c-decl.c:10919
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<__thread%> trước %<extern%>"
 
-#: c/c-decl.c:10908
+#: c/c-decl.c:10928
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<__thread%> trước %<static%>"
 
-#: c/c-decl.c:10921
+#: c/c-decl.c:10941
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr "trùng %<_Thread_local%> hay %<__thread%>"
 
-#: c/c-decl.c:10929
+#: c/c-decl.c:10949
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr ""
 
-#: c/c-decl.c:10937
+#: c/c-decl.c:10957
 #, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr "%qs được dùng với %qE"
 
-#: c/c-decl.c:11010
+#: c/c-decl.c:11030
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "%<_Sat%> được dùng mà không có %<_Fract%> or %<_Accum%>"
 
-#: c/c-decl.c:11025
+#: c/c-decl.c:11045
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr ""
 
-#: c/c-decl.c:11076 c/c-decl.c:11092 c/c-decl.c:11118
+#: c/c-decl.c:11096 c/c-decl.c:11112 c/c-decl.c:11138
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr ""
 
-#: c/c-decl.c:11514 cp/semantics.c:5348
+#: c/c-decl.c:11534 cp/semantics.c:5351
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:11518 cp/semantics.c:5352
+#: c/c-decl.c:11538 cp/semantics.c:5355
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.c:385 c/c-typeck.c:11426 cp/typeck.c:4680
+#: c/c-fold.c:385 c/c-typeck.c:11431 cp/typeck.c:4680
 #, gcc-internal-format
 msgid "left shift of negative value"
 msgstr "dịch trái của một giá trị âm"
 
-#: c/c-fold.c:395 c/c-typeck.c:11435 cp/typeck.c:4688
+#: c/c-fold.c:395 c/c-typeck.c:11440 cp/typeck.c:4688
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "số lượng dịch trái là số âm"
 
-#: c/c-fold.c:396 c/c-typeck.c:11365 cp/typeck.c:4633
+#: c/c-fold.c:396 c/c-typeck.c:11370 cp/typeck.c:4633
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "số lượng dịch trái là số âm"
 
-#: c/c-fold.c:404 c/c-typeck.c:11454 cp/typeck.c:4696
+#: c/c-fold.c:404 c/c-typeck.c:11459 cp/typeck.c:4696
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "số lượng dịch trái  >= độ rộng của kiểu"
 
-#: c/c-fold.c:405 c/c-typeck.c:11389 cp/typeck.c:4641
+#: c/c-fold.c:405 c/c-typeck.c:11394 cp/typeck.c:4641
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "số lượng dịch phải  >= độ rộng của kiểu"
 
-#: c/c-fold.c:412 c/c-typeck.c:11446
+#: c/c-fold.c:412 c/c-typeck.c:11451
 #, fuzzy, gcc-internal-format
 msgid "left shift count >= width of vector element"
 msgstr "số lượng dịch trái  >= độ rộng của kiểu"
 
-#: c/c-fold.c:413 c/c-typeck.c:11376
+#: c/c-fold.c:413 c/c-typeck.c:11381
 #, fuzzy, gcc-internal-format
 msgid "right shift count >= width of vector element"
 msgstr "số lượng dịch phải  >= độ rộng của kiểu"
@@ -35354,7 +35399,7 @@
 msgid "to match this %qs"
 msgstr "không khớp cho"
 
-#: c/c-parser.c:1216 cp/parser.c:28484
+#: c/c-parser.c:1216 cp/parser.c:28481
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr "cần kết thúc dòng"
@@ -35395,7 +35440,7 @@
 msgstr "không hiểu tên kiểu %qE"
 
 #: c/c-parser.c:1848 c/c-parser.c:11129 c/c-parser.c:16147 c/c-parser.c:16585
-#: c/c-parser.c:17061 cp/parser.c:36007 cp/parser.c:38993
+#: c/c-parser.c:17061 cp/parser.c:36004 cp/parser.c:38990
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "cần các định danh khai báo"
@@ -35410,7 +35455,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "cần %<;%>, định danh hoặc %<(%>"
 
-#: c/c-parser.c:1906 cp/parser.c:30161 cp/parser.c:30235
+#: c/c-parser.c:1906 cp/parser.c:30158 cp/parser.c:30232
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr ""
@@ -35464,7 +35509,7 @@
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr "%<__auto_type%> có lẽ chỉ được dùng với khai báo đơn"
 
-#: c/c-parser.c:2220 cp/parser.c:13002 cp/parser.c:13159
+#: c/c-parser.c:2220 cp/parser.c:12999 cp/parser.c:13156
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "cần %<,%> hoặc %<;%>"
@@ -35492,7 +35537,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C90 không hỗ trợ %<_Static_assert%>"
 
-#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38634
+#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38631
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr "cần chuỗi văn chương"
@@ -35556,13 +35601,13 @@
 #: c/c-parser.c:10745 c/c-parser.c:10798 c/c-parser.c:10814 c/c-parser.c:10860
 #: c/c-parser.c:11496 c/c-parser.c:11537 c/c-parser.c:13445 c/c-parser.c:13681
 #: c/c-parser.c:15544 c/c-parser.c:18218 c/gimple-parser.c:1058
-#: c/gimple-parser.c:1096 cp/parser.c:28487 cp/parser.c:31013
-#: cp/parser.c:31043 cp/parser.c:31113 cp/parser.c:33230 cp/parser.c:38350
+#: c/gimple-parser.c:1096 cp/parser.c:28484 cp/parser.c:31010
+#: cp/parser.c:31040 cp/parser.c:31110 cp/parser.c:33227 cp/parser.c:38347
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "cần định danh"
 
-#: c/c-parser.c:2995 cp/parser.c:18384
+#: c/c-parser.c:2995 cp/parser.c:18381
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "dấu phẩy ở cuối của danh dánh liệt kê"
@@ -35731,12 +35776,12 @@
 msgid "expected statement"
 msgstr "cần biểu thức"
 
-#: c/c-parser.c:5639 cp/parser.c:12516
+#: c/c-parser.c:5639 cp/parser.c:12513
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr ""
 
-#: c/c-parser.c:5681 cp/parser.c:12519
+#: c/c-parser.c:5681 cp/parser.c:12516
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr ""
@@ -36085,7 +36130,7 @@
 msgid "%<__builtin_complex%> operands of different types"
 msgstr "%<__builtin_complex%> toán hạng không đúng kiểu"
 
-#: c/c-parser.c:8891 cp/parser.c:6918
+#: c/c-parser.c:8891 cp/parser.c:6921
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_shuffle%>"
 msgstr "sai số tham số cho %<__builtin_shuffle%>"
@@ -36145,77 +36190,77 @@
 msgid "no type or storage class may be specified here,"
 msgstr ""
 
-#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31073
+#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31070
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "không hiểu thuộc tính tính chất"
 
-#: c/c-parser.c:10682 cp/parser.c:31033
+#: c/c-parser.c:10682 cp/parser.c:31030
 #, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "thiếu %<=%> (sau thuộc tính %<getter%>)"
 
-#: c/c-parser.c:10685 cp/parser.c:31036
+#: c/c-parser.c:10685 cp/parser.c:31033
 #, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "thiếu %<=%> (sau thuộc tính %<setter%>)"
 
-#: c/c-parser.c:10699 cp/parser.c:31051
+#: c/c-parser.c:10699 cp/parser.c:31048
 #, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr ""
 
-#: c/c-parser.c:10704 cp/parser.c:31057
+#: c/c-parser.c:10704 cp/parser.c:31054
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.c:10711 cp/parser.c:31065
+#: c/c-parser.c:10711 cp/parser.c:31062
 #, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr ""
 
-#: c/c-parser.c:10905 cp/parser.c:38674
+#: c/c-parser.c:10905 cp/parser.c:38671
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
 #: c/c-parser.c:10949 c/c-parser.c:16582 c/c-parser.c:16840 c/c-parser.c:16899
-#: c/c-parser.c:16983 cp/parser.c:36004 cp/parser.c:36298 cp/parser.c:36386
-#: cp/parser.c:36457 cp/parser.c:38721 cp/parser.c:38736 cp/parser.c:38752
-#: cp/parser.c:38768 cp/parser.c:38784 cp/parser.c:38811 cp/parser.c:38824
-#: cp/parser.c:38847 cp/parser.c:38860
+#: c/c-parser.c:16983 cp/parser.c:36001 cp/parser.c:36295 cp/parser.c:36383
+#: cp/parser.c:36454 cp/parser.c:38718 cp/parser.c:38733 cp/parser.c:38749
+#: cp/parser.c:38765 cp/parser.c:38781 cp/parser.c:38808 cp/parser.c:38821
+#: cp/parser.c:38844 cp/parser.c:38857
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp flush%> may only be used in compound statements"
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<#pragma omp flush%> chỉ có thể sử dụng trong các biểu thức phức hợp"
 
-#: c/c-parser.c:10972 cp/parser.c:38837
+#: c/c-parser.c:10972 cp/parser.c:38834
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<#pragma acc routine%> phải được áp dụng trước %s"
 
-#: c/c-parser.c:11050 cp/parser.c:38918
+#: c/c-parser.c:11050 cp/parser.c:38915
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<#pragma omp section%> chỉ có thể sử dụng trong cấu trúc %<#pragma omp sections%>"
 
-#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38947 cp/parser.c:38980
+#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38944 cp/parser.c:38977
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "cần câu lệnh for, while hoặc do"
 
-#: c/c-parser.c:11111 cp/parser.c:38711
+#: c/c-parser.c:11111 cp/parser.c:38708
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%> phải là đầu tiên"
 
-#: c/c-parser.c:11421 cp/parser.c:31457
+#: c/c-parser.c:11421 cp/parser.c:31454
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "quá nhiều mệnh đề %qs"
 
-#: c/c-parser.c:11443 cp/parser.c:31994
+#: c/c-parser.c:11443 cp/parser.c:31991
 #, gcc-internal-format
 msgid "expected integer expression before ')'"
 msgstr "cần biểu thức nguyên trước “)”"
@@ -36230,54 +36275,54 @@
 msgid "%qD is not a variable"
 msgstr "%qD không phải là một biến"
 
-#: c/c-parser.c:11746 cp/semantics.c:6808
+#: c/c-parser.c:11746 cp/semantics.c:6811
 #, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "%qD không phải là một biến trỏ"
 
-#: c/c-parser.c:11788 cp/parser.c:32073
+#: c/c-parser.c:11788 cp/parser.c:32070
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:11865 cp/parser.c:32137
+#: c/c-parser.c:11865 cp/parser.c:32134
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<none%> or %<present%>"
 msgstr "cần %<none%> hoặc %<shared%>"
 
-#: c/c-parser.c:11867 cp/parser.c:32139
+#: c/c-parser.c:11867 cp/parser.c:32136
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "cần %<none%> hoặc %<shared%>"
 
-#: c/c-parser.c:11968 cp/parser.c:32242
+#: c/c-parser.c:11968 cp/parser.c:32239
 #, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr ""
 
-#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32260
-#: cp/parser.c:36290 cp/parser.c:36378
+#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32257
+#: cp/parser.c:36287 cp/parser.c:36375
 #, gcc-internal-format
 msgid "expected %<data%>"
 msgstr "cần %<data%>"
 
-#: c/c-parser.c:12035 cp/parser.c:32313
+#: c/c-parser.c:12035 cp/parser.c:32310
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:12042 cp/parser.c:32320
+#: c/c-parser.c:12042 cp/parser.c:32317
 #, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr "quá nhiều mệnh đề %<if%>"
 
-#: c/c-parser.c:12044 cp/parser.c:32322
+#: c/c-parser.c:12044 cp/parser.c:32319
 #, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr ""
 
-#: c/c-parser.c:12050 cp/parser.c:32328
+#: c/c-parser.c:12050 cp/parser.c:32325
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -36299,83 +36344,83 @@
 msgid "%<num_tasks%> value must be positive"
 msgstr "%<num_tasks%> giá trị phải dương"
 
-#: c/c-parser.c:12229 cp/semantics.c:6992
+#: c/c-parser.c:12229 cp/semantics.c:6995
 #, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr "%<grainsize%> giá trị phải dương"
 
-#: c/c-parser.c:12276 cp/semantics.c:7021
+#: c/c-parser.c:12276 cp/semantics.c:7024
 #, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr "%<priority%> giá trị phải dương"
 
-#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32545 cp/parser.c:32552
+#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32542 cp/parser.c:32549
 #, gcc-internal-format
 msgid "expected %<tofrom%>"
 msgstr "cần %<tofrom%>"
 
-#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32561 cp/parser.c:32568
+#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32558 cp/parser.c:32565
 #, gcc-internal-format
 msgid "expected %<scalar%>"
 msgstr "cần %<scalar%>"
 
-#: c/c-parser.c:12425 cp/semantics.c:6299
+#: c/c-parser.c:12425 cp/semantics.c:6302
 #, gcc-internal-format
 msgid "%qs expression must be integral"
 msgstr "biểu thức %qs phải là số nguyên"
 
-#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6331
+#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6334
 #, gcc-internal-format
 msgid "%qs value must be positive"
 msgstr "%qs giá trị phải dương"
 
-#: c/c-parser.c:12499 cp/parser.c:31853
+#: c/c-parser.c:12499 cp/parser.c:31850
 #, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "quá nhiều đối số %<static%>"
 
-#: c/c-parser.c:12533 cp/parser.c:31886
+#: c/c-parser.c:12533 cp/parser.c:31883
 #, gcc-internal-format
 msgid "unexpected argument"
 msgstr "gặp tham số thừa"
 
-#: c/c-parser.c:12699 cp/semantics.c:7120
+#: c/c-parser.c:12699 cp/semantics.c:7123
 #, fuzzy, gcc-internal-format
 #| msgid "ordered argument needs positive constant integer expression"
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "cần biểu thức nguyên"
 
-#: c/c-parser.c:12765 cp/parser.c:32626
+#: c/c-parser.c:12765 cp/parser.c:32623
 #, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr "cần biểu thức nguyên"
 
-#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37643
+#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37640
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "cần %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> hoặc định danh"
 
-#: c/c-parser.c:12967 cp/parser.c:32840
+#: c/c-parser.c:12967 cp/parser.c:32837
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr ""
 
-#: c/c-parser.c:13021 cp/parser.c:32856
+#: c/c-parser.c:13021 cp/parser.c:32853
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:13025 cp/parser.c:32859
+#: c/c-parser.c:13025 cp/parser.c:32856
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:13037 cp/semantics.c:6389
+#: c/c-parser.c:13037 cp/semantics.c:6392
 #, fuzzy, gcc-internal-format
 msgid "chunk size value must be positive"
 msgstr "%qs giá trị phải dương"
 
-#: c/c-parser.c:13060 cp/parser.c:32879
+#: c/c-parser.c:13060 cp/parser.c:32876
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "kiểu lịch biểu không hợp lệ"
@@ -36385,12 +36430,12 @@
 msgid "%<num_teams%> value must be positive"
 msgstr "%<num_teams%> giá trị phải dương"
 
-#: c/c-parser.c:13226 cp/semantics.c:6479
+#: c/c-parser.c:13226 cp/semantics.c:6482
 #, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr "%<thread_limit%> giá trị phải dương"
 
-#: c/c-parser.c:13271 cp/semantics.c:6589
+#: c/c-parser.c:13271 cp/semantics.c:6592
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr ""
@@ -36410,17 +36455,17 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:13584 cp/parser.c:33374 cp/parser.c:33599
+#: c/c-parser.c:13584 cp/parser.c:33371 cp/parser.c:33596
 #, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "kiểu phụ thuộc không hợp lệ"
 
-#: c/c-parser.c:13669 cp/parser.c:33447
+#: c/c-parser.c:13669 cp/parser.c:33444
 #, gcc-internal-format
 msgid "invalid map kind"
 msgstr "kiểu ánh xạ không hợp lệ"
 
-#: c/c-parser.c:13767 cp/parser.c:33546
+#: c/c-parser.c:13767 cp/parser.c:33543
 #, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "kiểu dist_schedule không hợp lệ"
@@ -36430,67 +36475,67 @@
 msgid "invalid proc_bind kind"
 msgstr "kiểu proc_bind không hợp lệ"
 
-#: c/c-parser.c:14059 cp/parser.c:33825
+#: c/c-parser.c:14059 cp/parser.c:33822
 #, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr "cần mệnh đề %<#pragma acc%>"
 
-#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33836 cp/parser.c:34143
+#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33833 cp/parser.c:34140
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs không hợp lệ cho %qs"
 
-#: c/c-parser.c:14214 cp/parser.c:34010
+#: c/c-parser.c:14214 cp/parser.c:34007
 #, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "%qs phải là mệnh đề đầu tiên của %qs"
 
-#: c/c-parser.c:14334 cp/parser.c:34132
+#: c/c-parser.c:14334 cp/parser.c:34129
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "cần mệnh đề %<#pragma omp%>"
 
-#: c/c-parser.c:14472 cp/parser.c:36803
+#: c/c-parser.c:14472 cp/parser.c:36800
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14482 cp/parser.c:36813
+#: c/c-parser.c:14482 cp/parser.c:36810
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14502 cp/parser.c:36833
+#: c/c-parser.c:14502 cp/parser.c:36830
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr ""
 
-#: c/c-parser.c:14513 cp/parser.c:36844
+#: c/c-parser.c:14513 cp/parser.c:36841
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr ""
 
-#: c/c-parser.c:14520 cp/parser.c:36851
+#: c/c-parser.c:14520 cp/parser.c:36848
 #, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14528 cp/parser.c:36859
+#: c/c-parser.c:14528 cp/parser.c:36856
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14540 cp/parser.c:36871
+#: c/c-parser.c:14540 cp/parser.c:36868
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14632 cp/parser.c:36957
+#: c/c-parser.c:14632 cp/parser.c:36954
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "cần %<class%>, hoặc %<typename%>"
 
-#: c/c-parser.c:14648 cp/parser.c:36974
+#: c/c-parser.c:14648 cp/parser.c:36971
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr "%<#pragma omp cancel%> chỉ có thể sử dụng trong các biểu thức phức hợp"
@@ -36505,7 +36550,7 @@
 msgid "expected function name"
 msgstr "cần tên hàm"
 
-#: c/c-parser.c:14893 cp/parser.c:38064
+#: c/c-parser.c:14893 cp/parser.c:38061
 #, fuzzy, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr "%qD không phải là hàm thành viên mẫu"
@@ -36515,44 +36560,44 @@
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14953 cp/parser.c:38118 cp/parser.c:38160
+#: c/c-parser.c:14953 cp/parser.c:38115 cp/parser.c:38157
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14970 cp/parser.c:38174
+#: c/c-parser.c:14970 cp/parser.c:38171
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> already applied to %qD"
 msgstr "%<#pragma acc routine%> đã được áp dụng với %D"
 
-#: c/c-parser.c:14979 cp/parser.c:38183
+#: c/c-parser.c:14979 cp/parser.c:38180
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma acc routine%> must be applied before %s"
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr "%<#pragma acc routine%> phải được áp dụng trước %s"
 
-#: c/c-parser.c:14980 cp/parser.c:38184
+#: c/c-parser.c:14980 cp/parser.c:38181
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma acc routine%> must be applied before %s"
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<#pragma acc routine%> phải được áp dụng trước %s"
 
-#: c/c-parser.c:15023 cp/parser.c:37152
+#: c/c-parser.c:15023 cp/parser.c:37149
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr "%<#pragma acc update%> phải chứa ít nhất là một mệnh đề %<device%> hay %<host%> hay %<self%>"
 
-#: c/c-parser.c:15435 cp/parser.c:34511 cp/parser.c:34537
+#: c/c-parser.c:15435 cp/parser.c:34508 cp/parser.c:34534
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "sai dạng thức của %<#pragma omp atomic%>"
 
-#: c/c-parser.c:15439 cp/parser.c:34568 cp/parser.c:34584
+#: c/c-parser.c:15439 cp/parser.c:34565 cp/parser.c:34581
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "thao tác không hợp lệ cho %<#pragma omp atomic%>"
 
-#: c/c-parser.c:15488 cp/semantics.c:8401 cp/semantics.c:8411
+#: c/c-parser.c:15488 cp/semantics.c:8404 cp/semantics.c:8414
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr "%<#pragma omp atomic capture%> sử dụng hai biểu thức khác nhau cho bộ nhớ"
@@ -36562,22 +36607,22 @@
 msgid "expected %<(%> or end of line"
 msgstr "cần %<(%> hoặc xuống dòng"
 
-#: c/c-parser.c:15619 cp/parser.c:35103
+#: c/c-parser.c:15619 cp/parser.c:35100
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:15630 cp/parser.c:35114
+#: c/c-parser.c:15630 cp/parser.c:35111
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:15648 cp/parser.c:35141
+#: c/c-parser.c:15648 cp/parser.c:35138
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "cần câu lệnh for"
 
-#: c/c-parser.c:15718 cp/semantics.c:8066 cp/semantics.c:8153
+#: c/c-parser.c:15718 cp/semantics.c:8069 cp/semantics.c:8156
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "cần khai báo nhắc lại hay sự khởi tạo"
@@ -36587,72 +36632,72 @@
 msgid "not enough perfectly nested loops"
 msgstr ""
 
-#: c/c-parser.c:15862 cp/parser.c:35364
+#: c/c-parser.c:15862 cp/parser.c:35361
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.c:15909 cp/parser.c:35184 cp/parser.c:35226 cp/pt.c:16385
+#: c/c-parser.c:15909 cp/parser.c:35181 cp/parser.c:35223 cp/pt.c:16407
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr ""
 
-#: c/c-parser.c:16000 cp/parser.c:35437
+#: c/c-parser.c:16000 cp/parser.c:35434
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr ""
 
-#: c/c-parser.c:16166 cp/parser.c:35600
+#: c/c-parser.c:16166 cp/parser.c:35597
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr "%<#pragma omp ordered%> với mệnh đề %<depend%> chỉ có thể sử dụng trong các biểu thức phức hợp"
 
-#: c/c-parser.c:16374 cp/parser.c:35799
+#: c/c-parser.c:16374 cp/parser.c:35796
 #, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "cần %<for%> sau %qs"
 
-#: c/c-parser.c:16573 cp/parser.c:35995
+#: c/c-parser.c:16573 cp/parser.c:35992
 #, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "cần %<point%>"
 
-#: c/c-parser.c:16793 cp/parser.c:36232
+#: c/c-parser.c:16793 cp/parser.c:36229
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16806 cp/parser.c:36245
+#: c/c-parser.c:16806 cp/parser.c:36242
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16853 cp/parser.c:36470
+#: c/c-parser.c:16853 cp/parser.c:36467
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:16925 cp/parser.c:36325
+#: c/c-parser.c:16925 cp/parser.c:36322
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16937 cp/parser.c:36337
+#: c/c-parser.c:16937 cp/parser.c:36334
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17011 cp/parser.c:36414
+#: c/c-parser.c:17011 cp/parser.c:36411
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17024 cp/parser.c:36427
+#: c/c-parser.c:17024 cp/parser.c:36424
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17238 cp/parser.c:36680
+#: c/c-parser.c:17238 cp/parser.c:36677
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -36672,32 +36717,32 @@
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17395 cp/parser.c:37273
+#: c/c-parser.c:17395 cp/parser.c:37270
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17474 cp/parser.c:37343
+#: c/c-parser.c:17474 cp/parser.c:37340
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> with clauses in between %<#pragma omp declare target%> without clauses and %<#pragma omp end declare target%>"
 msgstr ""
 
-#: c/c-parser.c:17493 cp/parser.c:37362
+#: c/c-parser.c:17493 cp/parser.c:37359
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17534 cp/parser.c:37409
+#: c/c-parser.c:17534 cp/parser.c:37406
 #, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "cần %<target%>"
 
-#: c/c-parser.c:17541 cp/parser.c:37416
+#: c/c-parser.c:17541 cp/parser.c:37413
 #, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "cần %<declare%>"
 
-#: c/c-parser.c:17547 cp/parser.c:37423
+#: c/c-parser.c:17547 cp/parser.c:37420
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr ""
@@ -36752,47 +36797,47 @@
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:17947 cp/parser.c:37868
+#: c/c-parser.c:17947 cp/parser.c:37865
 #, gcc-internal-format
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr ""
 
-#: c/c-parser.c:18162 cp/semantics.c:7531
+#: c/c-parser.c:18162 cp/semantics.c:7534
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr ""
 
-#: c/c-parser.c:18164 cp/semantics.c:7533
+#: c/c-parser.c:18164 cp/semantics.c:7536
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr ""
 
-#: c/c-parser.c:18168 cp/semantics.c:7535
+#: c/c-parser.c:18168 cp/semantics.c:7538
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr ""
 
-#: c/c-parser.c:18368 cp/parser.c:38565
+#: c/c-parser.c:18368 cp/parser.c:38562
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:18374 cp/parser.c:38571
+#: c/c-parser.c:18374 cp/parser.c:38568
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr "%<__transaction_cancel%> nằm trong một %<__transaction_relaxed%>"
 
-#: c/c-parser.c:18383 cp/parser.c:38580
+#: c/c-parser.c:18383 cp/parser.c:38577
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr "vòng ngoài hơn %<__transaction_cancel%> không nằm trong vòng ngoài hơn %<__transaction_atomic%>"
 
-#: c/c-parser.c:18385 cp/parser.c:38583
+#: c/c-parser.c:18385 cp/parser.c:38580
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr "  hoặc một hàm %<transaction_may_cancel_outer%>"
 
-#: c/c-parser.c:18391 cp/parser.c:38589
+#: c/c-parser.c:18391 cp/parser.c:38586
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr "%<__transaction_cancel%> không nằm trong %<__transaction_atomic%>"
@@ -36807,7 +36852,7 @@
 msgid "%qD has an incomplete type %qT"
 msgstr ""
 
-#: c/c-typeck.c:237 c/c-typeck.c:9994 c/c-typeck.c:10036 cp/call.c:4147
+#: c/c-typeck.c:237 c/c-typeck.c:9999 c/c-typeck.c:10041 cp/call.c:4147
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "sử dụng sai biểu thức void"
@@ -36883,12 +36928,12 @@
 msgid "converting an array compound literal to a pointer is ill-formed in C++"
 msgstr ""
 
-#: c/c-typeck.c:2417 c/c-typeck.c:8641
+#: c/c-typeck.c:2417 c/c-typeck.c:8646
 #, gcc-internal-format
 msgid "%qT has no member named %qE; did you mean %qE?"
 msgstr "%qT không có thành viên nào mang tên %qE; ý bạn là %qE?"
 
-#: c/c-typeck.c:2421 c/c-typeck.c:8645
+#: c/c-typeck.c:2421 c/c-typeck.c:8650
 #, gcc-internal-format
 msgid "%qT has no member named %qE"
 msgstr "%qT không có thành viên nào mang tên %qE"
@@ -37088,463 +37133,463 @@
 msgid "pointer to a function used in subtraction"
 msgstr "con trỏ đến hàm được dùng trong phép trừ"
 
-#: c/c-typeck.c:3847
+#: c/c-typeck.c:3852
 #, gcc-internal-format
 msgid "arithmetic on pointer to an incomplete type"
 msgstr ""
 
-#: c/c-typeck.c:3852 cp/typeck.c:5562
+#: c/c-typeck.c:3857 cp/typeck.c:5562
 #, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr ""
 
-#: c/c-typeck.c:4283
+#: c/c-typeck.c:4288
 #, gcc-internal-format
 msgid "%<~%> on a boolean expression"
 msgstr "%<~%> trên một biểu thức lôgíc"
 
-#: c/c-typeck.c:4287
+#: c/c-typeck.c:4292
 #, gcc-internal-format
 msgid "did you mean to use logical not?"
 msgstr "ý bạn là dùng not lôgíc?"
 
-#: c/c-typeck.c:4296
+#: c/c-typeck.c:4301
 #, gcc-internal-format
 msgid "ISO C does not support %<~%> for complex conjugation"
 msgstr ""
 
-#: c/c-typeck.c:4335
+#: c/c-typeck.c:4340
 #, gcc-internal-format
 msgid "wrong type argument to unary exclamation mark"
 msgstr ""
 
-#: c/c-typeck.c:4393
+#: c/c-typeck.c:4398
 #, gcc-internal-format
 msgid "increment of enumeration value is invalid in C++"
 msgstr "phép gia tăng giá trị kiểu liệt kê là không hợp lệ trong C++"
 
-#: c/c-typeck.c:4396
+#: c/c-typeck.c:4401
 #, gcc-internal-format
 msgid "decrement of enumeration value is invalid in C++"
 msgstr "phép giảm giá trị kiểu liệt kê là không hợp lệ trong C++"
 
-#: c/c-typeck.c:4403
+#: c/c-typeck.c:4408
 #, fuzzy, gcc-internal-format
 msgid "increment of a boolean expression"
 msgstr "cần một biểu thức lôgíc"
 
-#: c/c-typeck.c:4406
+#: c/c-typeck.c:4411
 #, fuzzy, gcc-internal-format
 msgid "decrement of a boolean expression"
 msgstr "cần một biểu thức lôgíc"
 
-#: c/c-typeck.c:4422
+#: c/c-typeck.c:4427
 #, gcc-internal-format
 msgid "ISO C does not support %<++%> and %<--%> on complex types"
 msgstr ""
 
-#: c/c-typeck.c:4447 c/c-typeck.c:4481
+#: c/c-typeck.c:4452 c/c-typeck.c:4486
 #, gcc-internal-format
 msgid "wrong type argument to increment"
 msgstr "đối số sai kiểu cho gia số"
 
-#: c/c-typeck.c:4449 c/c-typeck.c:4484
+#: c/c-typeck.c:4454 c/c-typeck.c:4489
 #, gcc-internal-format
 msgid "wrong type argument to decrement"
 msgstr "sai đối số kiểu để giảm"
 
-#: c/c-typeck.c:4469
+#: c/c-typeck.c:4474
 #, gcc-internal-format
 msgid "increment of pointer to an incomplete type %qT"
 msgstr "tăng con trỏ tới loại không hoàn toàn %qT"
 
-#: c/c-typeck.c:4473
+#: c/c-typeck.c:4478
 #, gcc-internal-format
 msgid "decrement of pointer to an incomplete type %qT"
 msgstr "giảm con trỏ tới loại không hoàn toàn %qT"
 
-#: c/c-typeck.c:4577
+#: c/c-typeck.c:4582
 #, gcc-internal-format
 msgid "taking address of expression of type %<void%>"
 msgstr ""
 
-#: c/c-typeck.c:4636
+#: c/c-typeck.c:4641
 #, gcc-internal-format
 msgid "cannot take address of bit-field %qD"
 msgstr ""
 
-#: c/c-typeck.c:4649
+#: c/c-typeck.c:4654
 #, gcc-internal-format
 msgid "cannot take address of scalar with reverse storage order"
 msgstr ""
 
-#: c/c-typeck.c:4657
+#: c/c-typeck.c:4662
 #, gcc-internal-format
 msgid "address of array with reverse scalar storage order requested"
 msgstr ""
 
-#: c/c-typeck.c:4838
+#: c/c-typeck.c:4843
 #, gcc-internal-format
 msgid "global register variable %qD used in nested function"
 msgstr ""
 
-#: c/c-typeck.c:4841
+#: c/c-typeck.c:4846
 #, gcc-internal-format
 msgid "register variable %qD used in nested function"
 msgstr ""
 
-#: c/c-typeck.c:4846
+#: c/c-typeck.c:4851
 #, gcc-internal-format
 msgid "address of global register variable %qD requested"
 msgstr ""
 
-#: c/c-typeck.c:4848
+#: c/c-typeck.c:4853
 #, gcc-internal-format
 msgid "address of register variable %qD requested"
 msgstr ""
 
-#: c/c-typeck.c:4951
+#: c/c-typeck.c:4956
 #, gcc-internal-format
 msgid "non-lvalue array in conditional expression"
 msgstr ""
 
-#: c/c-typeck.c:5033
+#: c/c-typeck.c:5038
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other result of conditional"
 msgstr ""
 
-#: c/c-typeck.c:5092 c/c-typeck.c:5098
+#: c/c-typeck.c:5097 c/c-typeck.c:5103
 #, gcc-internal-format
 msgid "operand of ?: changes signedness from %qT to %qT due to unsignedness of other operand"
 msgstr ""
 
-#: c/c-typeck.c:5115
+#: c/c-typeck.c:5120
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr with only one void side"
 msgstr ""
 
-#: c/c-typeck.c:5132
+#: c/c-typeck.c:5137
 #, gcc-internal-format
 msgid "pointers to disjoint address spaces used in conditional expression"
 msgstr ""
 
-#: c/c-typeck.c:5143 c/c-typeck.c:5160
+#: c/c-typeck.c:5148 c/c-typeck.c:5165
 #, gcc-internal-format
 msgid "pointer to array loses qualifier in conditional expression"
 msgstr ""
 
-#: c/c-typeck.c:5148 c/c-typeck.c:5165
+#: c/c-typeck.c:5153 c/c-typeck.c:5170
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr between %<void *%> and function pointer"
 msgstr "ISO C cấm chỉ biểu thức điều kiện giữa %<void *%> với con trỏ hàm"
 
-#: c/c-typeck.c:5178
+#: c/c-typeck.c:5183
 #, gcc-internal-format
 msgid "pointer type mismatch in conditional expression"
 msgstr ""
 
-#: c/c-typeck.c:5187 c/c-typeck.c:5198
+#: c/c-typeck.c:5192 c/c-typeck.c:5203
 #, gcc-internal-format
 msgid "pointer/integer type mismatch in conditional expression"
 msgstr ""
 
-#: c/c-typeck.c:5336
+#: c/c-typeck.c:5341
 #, gcc-internal-format
 msgid "left-hand operand of comma expression has no effect"
 msgstr ""
 
-#: c/c-typeck.c:5354 c/c-typeck.c:10636
+#: c/c-typeck.c:5359 c/c-typeck.c:10641
 #, gcc-internal-format
 msgid "right-hand operand of comma expression has no effect"
 msgstr ""
 
-#: c/c-typeck.c:5423
+#: c/c-typeck.c:5428
 msgid "cast adds %q#v qualifier to function type"
 msgstr ""
 
-#: c/c-typeck.c:5429
+#: c/c-typeck.c:5434
 msgid "cast discards %qv qualifier from pointer target type"
 msgstr ""
 
-#: c/c-typeck.c:5464
+#: c/c-typeck.c:5469
 #, gcc-internal-format
 msgid "to be safe all intermediate pointers in cast from %qT to %qT must be %<const%> qualified"
 msgstr ""
 
-#: c/c-typeck.c:5554
+#: c/c-typeck.c:5559
 #, gcc-internal-format
 msgid "cast specifies array type"
 msgstr ""
 
-#: c/c-typeck.c:5560
+#: c/c-typeck.c:5565
 #, gcc-internal-format
 msgid "cast specifies function type"
 msgstr ""
 
-#: c/c-typeck.c:5575
+#: c/c-typeck.c:5580
 #, gcc-internal-format
 msgid "ISO C forbids casting nonscalar to the same type"
 msgstr ""
 
-#: c/c-typeck.c:5595
+#: c/c-typeck.c:5600
 #, gcc-internal-format
 msgid "ISO C forbids casts to union type"
 msgstr "ISO C cấm chỉ áp kiểu thành kiểu hỗn hợp"
 
-#: c/c-typeck.c:5605
+#: c/c-typeck.c:5610
 #, gcc-internal-format
 msgid "cast to union type from type not present in union"
 msgstr ""
 
-#: c/c-typeck.c:5640
+#: c/c-typeck.c:5645
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint generic address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5645
+#: c/c-typeck.c:5650
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to generic address space pointer from disjoint %s address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5650
+#: c/c-typeck.c:5655
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint %s address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5670
+#: c/c-typeck.c:5675
 #, gcc-internal-format
 msgid "cast increases required alignment of target type"
 msgstr ""
 
-#: c/c-typeck.c:5681
+#: c/c-typeck.c:5686
 #, gcc-internal-format
 msgid "cast from pointer to integer of different size"
 msgstr ""
 
-#: c/c-typeck.c:5686
+#: c/c-typeck.c:5691
 #, gcc-internal-format
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr ""
 
-#: c/c-typeck.c:5695 cp/typeck.c:7811
+#: c/c-typeck.c:5700 cp/typeck.c:7811
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr ""
 
-#: c/c-typeck.c:5709
+#: c/c-typeck.c:5714
 #, gcc-internal-format
 msgid "ISO C forbids conversion of function pointer to object pointer type"
 msgstr ""
 
-#: c/c-typeck.c:5718
+#: c/c-typeck.c:5723
 #, gcc-internal-format
 msgid "ISO C forbids conversion of object pointer to function pointer type"
 msgstr ""
 
-#: c/c-typeck.c:5728
+#: c/c-typeck.c:5733
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible types in assignment of %qT to %qT"
 msgid "cast between incompatible function types from %qT to %qT"
 msgstr "phép gán %qT cho %qT không tương thích kiểu"
 
-#: c/c-typeck.c:5815
+#: c/c-typeck.c:5820
 #, gcc-internal-format
 msgid "defining a type in a cast is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:5856
+#: c/c-typeck.c:5861
 #, gcc-internal-format
 msgid "assignment to expression with array type"
 msgstr ""
 
-#: c/c-typeck.c:5982
+#: c/c-typeck.c:5987
 #, gcc-internal-format
 msgid "enum conversion in assignment is invalid in C++"
 msgstr "chuyển đổi enum trong bộ khởi tạo thì không hợp lệ trong C++"
 
-#: c/c-typeck.c:6180 c/c-typeck.c:6202 c/c-typeck.c:6226
+#: c/c-typeck.c:6185 c/c-typeck.c:6207 c/c-typeck.c:6231
 #, gcc-internal-format
 msgid "(near initialization for %qs)"
 msgstr "(gần chỗ khởi tạo cho %qs)"
 
-#: c/c-typeck.c:6241
+#: c/c-typeck.c:6246
 #, gcc-internal-format
 msgid "array initialized from parenthesized string constant"
 msgstr "mảng bị khởi tạo từ hằng số chuỗi nằm trong ngoặc đơn"
 
-#: c/c-typeck.c:6284 c/c-typeck.c:6476 c/c-typeck.c:6908
+#: c/c-typeck.c:6289 c/c-typeck.c:6481 c/c-typeck.c:6913
 #, gcc-internal-format
 msgid "expected %qT but argument is of type %qT"
 msgstr "cần %qT nhưng đối số là kiểu %qT"
 
-#: c/c-typeck.c:6471
+#: c/c-typeck.c:6476
 #, gcc-internal-format
 msgid "enum conversion when passing argument %d of %qE is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:6480
+#: c/c-typeck.c:6485
 #, fuzzy, gcc-internal-format
 #| msgid "enum conversion in assignment is invalid in C++"
 msgid "enum conversion from %qT to %qT in assignment is invalid in C++"
 msgstr "chuyển đổi enum trong bộ khởi tạo thì không hợp lệ trong C++"
 
-#: c/c-typeck.c:6484
+#: c/c-typeck.c:6489
 #, fuzzy, gcc-internal-format
 #| msgid "enum conversion in initialization is invalid in C++"
 msgid "enum conversion from %qT to %qT in initialization is invalid in C++"
 msgstr "chuyển đổi enum trong bộ khởi tạo thì không hợp lệ trong C++"
 
-#: c/c-typeck.c:6489
+#: c/c-typeck.c:6494
 #, fuzzy, gcc-internal-format
 #| msgid "enum conversion in return is invalid in C++"
 msgid "enum conversion from %qT to %qT in return is invalid in C++"
 msgstr "chuyển đổi enum trả về thì không hợp lệ trong C++"
 
-#: c/c-typeck.c:6523
+#: c/c-typeck.c:6528
 #, gcc-internal-format
 msgid "cannot pass rvalue to reference parameter"
 msgstr ""
 
-#: c/c-typeck.c:6656 c/c-typeck.c:6942
+#: c/c-typeck.c:6661 c/c-typeck.c:6947
 msgid "passing argument %d of %qE makes %q#v qualified function pointer from unqualified"
 msgstr ""
 
-#: c/c-typeck.c:6659 c/c-typeck.c:6945
+#: c/c-typeck.c:6664 c/c-typeck.c:6950
 msgid "assignment makes %q#v qualified function pointer from unqualified"
 msgstr ""
 
-#: c/c-typeck.c:6662 c/c-typeck.c:6947
+#: c/c-typeck.c:6667 c/c-typeck.c:6952
 msgid "initialization makes %q#v qualified function pointer from unqualified"
 msgstr ""
 
-#: c/c-typeck.c:6665 c/c-typeck.c:6949
+#: c/c-typeck.c:6670 c/c-typeck.c:6954
 msgid "return makes %q#v qualified function pointer from unqualified"
 msgstr ""
 
-#: c/c-typeck.c:6673 c/c-typeck.c:6840 c/c-typeck.c:6883
+#: c/c-typeck.c:6678 c/c-typeck.c:6845 c/c-typeck.c:6888
 msgid "passing argument %d of %qE discards %qv qualifier from pointer target type"
 msgstr ""
 
-#: c/c-typeck.c:6675 c/c-typeck.c:6842 c/c-typeck.c:6885
+#: c/c-typeck.c:6680 c/c-typeck.c:6847 c/c-typeck.c:6890
 msgid "assignment discards %qv qualifier from pointer target type"
 msgstr ""
 
-#: c/c-typeck.c:6677 c/c-typeck.c:6844 c/c-typeck.c:6887
+#: c/c-typeck.c:6682 c/c-typeck.c:6849 c/c-typeck.c:6892
 msgid "initialization discards %qv qualifier from pointer target type"
 msgstr ""
 
-#: c/c-typeck.c:6679 c/c-typeck.c:6846 c/c-typeck.c:6889
+#: c/c-typeck.c:6684 c/c-typeck.c:6851 c/c-typeck.c:6894
 msgid "return discards %qv qualifier from pointer target type"
 msgstr ""
 
-#: c/c-typeck.c:6688
+#: c/c-typeck.c:6693
 #, gcc-internal-format
 msgid "ISO C prohibits argument conversion to union type"
 msgstr ""
 
-#: c/c-typeck.c:6750
+#: c/c-typeck.c:6755
 #, gcc-internal-format
 msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgstr ""
 
-#: c/c-typeck.c:6762
+#: c/c-typeck.c:6767
 #, gcc-internal-format
 msgid "passing argument %d of %qE from pointer to non-enclosed address space"
 msgstr ""
 
-#: c/c-typeck.c:6766
+#: c/c-typeck.c:6771
 #, gcc-internal-format
 msgid "assignment from pointer to non-enclosed address space"
 msgstr ""
 
-#: c/c-typeck.c:6770
+#: c/c-typeck.c:6775
 #, gcc-internal-format
 msgid "initialization from pointer to non-enclosed address space"
 msgstr ""
 
-#: c/c-typeck.c:6774
+#: c/c-typeck.c:6779
 #, gcc-internal-format
 msgid "return from pointer to non-enclosed address space"
 msgstr ""
 
-#: c/c-typeck.c:6792
+#: c/c-typeck.c:6797
 #, gcc-internal-format
 msgid "argument %d of %qE might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:6798
+#: c/c-typeck.c:6803
 #, gcc-internal-format
 msgid "assignment left-hand side might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:6803
+#: c/c-typeck.c:6808
 #, gcc-internal-format
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:6808 cp/typeck.c:8891
+#: c/c-typeck.c:6813 cp/typeck.c:8891
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:6857
+#: c/c-typeck.c:6862
 #, gcc-internal-format
 msgid "ISO C forbids passing argument %d of %qE between function pointer and %<void *%>"
 msgstr ""
 
-#: c/c-typeck.c:6860
+#: c/c-typeck.c:6865
 #, gcc-internal-format
 msgid "ISO C forbids assignment between function pointer and %<void *%>"
 msgstr ""
 
-#: c/c-typeck.c:6862
+#: c/c-typeck.c:6867
 #, gcc-internal-format
 msgid "ISO C forbids initialization between function pointer and %<void *%>"
 msgstr ""
 
-#: c/c-typeck.c:6864
+#: c/c-typeck.c:6869
 #, gcc-internal-format
 msgid "ISO C forbids return between function pointer and %<void *%>"
 msgstr ""
 
-#: c/c-typeck.c:6904
+#: c/c-typeck.c:6909
 #, gcc-internal-format
 msgid "pointer targets in passing argument %d of %qE differ in signedness"
 msgstr ""
 
-#: c/c-typeck.c:6913
+#: c/c-typeck.c:6918
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible types in assignment of %qT to %qT"
 msgid "pointer targets in assignment from %qT to %qT differ in signedness"
 msgstr "phép gán %qT cho %qT không tương thích kiểu"
 
-#: c/c-typeck.c:6918
+#: c/c-typeck.c:6923
 #, gcc-internal-format
 msgid "pointer targets in initialization of %qT from %qT differ in signedness"
 msgstr ""
 
-#: c/c-typeck.c:6923
+#: c/c-typeck.c:6928
 #, gcc-internal-format
 msgid "pointer targets in returning %qT from a function with return type %qT differ in signedness"
 msgstr ""
 
-#: c/c-typeck.c:6961
+#: c/c-typeck.c:6966
 #, gcc-internal-format
 msgid "passing argument %d of %qE from incompatible pointer type"
 msgstr ""
 
-#: c/c-typeck.c:6967
+#: c/c-typeck.c:6972
 #, fuzzy, gcc-internal-format
 #| msgid "increment of pointer to an incomplete type %qT"
 msgid "assignment to %qT from incompatible pointer type %qT"
 msgstr "tăng con trỏ tới loại không hoàn toàn %qT"
 
-#: c/c-typeck.c:6972
+#: c/c-typeck.c:6977
 #, fuzzy, gcc-internal-format
 msgid "initialization of %qT from incompatible pointer type %qT"
 msgstr "(gần chỗ khởi tạo cho %qs)"
 
-#: c/c-typeck.c:6977
+#: c/c-typeck.c:6982
 #, fuzzy, gcc-internal-format
 #| msgid "return with value in function with no return type"
 msgid "returning %qT from a function with incompatible return type %qT"
@@ -37552,782 +37597,782 @@
 
 #. ??? This should not be an error when inlining calls to
 #. unprototyped functions.
-#: c/c-typeck.c:6991 c/c-typeck.c:7514 cp/typeck.c:2063
+#: c/c-typeck.c:6996 c/c-typeck.c:7519 cp/typeck.c:2063
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "sai sử dụng mảng không phải lvalue"
 
-#: c/c-typeck.c:7004
+#: c/c-typeck.c:7009
 #, gcc-internal-format
 msgid "passing argument %d of %qE makes pointer from integer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7010
+#: c/c-typeck.c:7015
 #, gcc-internal-format
 msgid "assignment to %qT from %qT makes pointer from integer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7015
+#: c/c-typeck.c:7020
 #, gcc-internal-format
 msgid "initialization of %qT from %qT makes pointer from integer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7019
+#: c/c-typeck.c:7024
 #, gcc-internal-format
 msgid "returning %qT from a function with return type %qT makes pointer from integer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7035
+#: c/c-typeck.c:7040
 #, gcc-internal-format
 msgid "passing argument %d of %qE makes integer from pointer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7041
+#: c/c-typeck.c:7046
 #, fuzzy, gcc-internal-format
 msgid "assignment to %qT from %qT makes integer from pointer without a cast"
 msgstr "đối số %d của %qE phải là bội số của %d"
 
-#: c/c-typeck.c:7046
+#: c/c-typeck.c:7051
 #, gcc-internal-format
 msgid "initialization of %qT from %qT makes integer from pointer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7050
+#: c/c-typeck.c:7055
 #, gcc-internal-format
 msgid "returning %qT from a function with return type %qT makes integer from pointer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7073
+#: c/c-typeck.c:7078
 #, gcc-internal-format
 msgid "incompatible type for argument %d of %qE"
 msgstr "kiểu không tương thích cho đối số %d của %qE"
 
-#: c/c-typeck.c:7078
+#: c/c-typeck.c:7083
 #, gcc-internal-format
 msgid "incompatible types when assigning to type %qT from type %qT"
 msgstr ""
 
-#: c/c-typeck.c:7083
+#: c/c-typeck.c:7088
 #, gcc-internal-format
 msgid "incompatible types when initializing type %qT using type %qT"
 msgstr ""
 
-#: c/c-typeck.c:7088
+#: c/c-typeck.c:7093
 #, gcc-internal-format
 msgid "incompatible types when returning type %qT but %qT was expected"
 msgstr ""
 
-#: c/c-typeck.c:7152
+#: c/c-typeck.c:7157
 #, gcc-internal-format
 msgid "traditional C rejects automatic aggregate initialization"
 msgstr ""
 
-#: c/c-typeck.c:7388 c/c-typeck.c:8284 cp/typeck2.c:1045
+#: c/c-typeck.c:7393 c/c-typeck.c:8289 cp/typeck2.c:1045
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "đã khởi tạo một bộ phận mảng dẻo"
 
-#: c/c-typeck.c:7398 cp/typeck2.c:1059
+#: c/c-typeck.c:7403 cp/typeck2.c:1059
 #, gcc-internal-format
 msgid "char-array initialized from wide string"
 msgstr "mảng ký tự bị khởi tạo từ chuỗi rộng"
 
-#: c/c-typeck.c:7407
+#: c/c-typeck.c:7412
 #, gcc-internal-format
 msgid "wide character array initialized from non-wide string"
 msgstr "mảng ký tự rộng bị khởi tạo từ chuỗi không phải rộng"
 
-#: c/c-typeck.c:7413
+#: c/c-typeck.c:7418
 #, gcc-internal-format
 msgid "wide character array initialized from incompatible wide string"
 msgstr "mảng ký tự rộng bị khởi tạo từ chuỗi rộng không tương thích"
 
-#: c/c-typeck.c:7446
+#: c/c-typeck.c:7451
 #, gcc-internal-format
 msgid "array of inappropriate type initialized from string constant"
 msgstr "mảng loại không thích hợp bị khởi tạo từ hằng số chuỗi"
 
-#: c/c-typeck.c:7533 c/c-typeck.c:7557 c/c-typeck.c:7560 c/c-typeck.c:7568
-#: c/c-typeck.c:7608 c/c-typeck.c:9131 c/c-typeck.c:9181
+#: c/c-typeck.c:7538 c/c-typeck.c:7562 c/c-typeck.c:7565 c/c-typeck.c:7573
+#: c/c-typeck.c:7613 c/c-typeck.c:9136 c/c-typeck.c:9186
 #, gcc-internal-format
 msgid "initializer element is not constant"
 msgstr "yếu tố khởi tạo không phải hằng số"
 
-#: c/c-typeck.c:7542
+#: c/c-typeck.c:7547
 #, gcc-internal-format
 msgid "array initialized from non-constant array expression"
 msgstr "mảng bị khởi tạo từ biểu tượng mảng không phải hằng số"
 
-#: c/c-typeck.c:7573 c/c-typeck.c:7621 c/c-typeck.c:9191
+#: c/c-typeck.c:7578 c/c-typeck.c:7626 c/c-typeck.c:9196
 #, gcc-internal-format
 msgid "initializer element is not a constant expression"
 msgstr "yếu tố khởi tạo không phải là một biểu tượng hằng số"
 
-#: c/c-typeck.c:7615 c/c-typeck.c:9186
+#: c/c-typeck.c:7620 c/c-typeck.c:9191
 #, gcc-internal-format
 msgid "initializer element is not computable at load time"
 msgstr "yếu tố khởi tạo không tính được vào lúc nạp"
 
-#: c/c-typeck.c:7634
+#: c/c-typeck.c:7639
 #, gcc-internal-format
 msgid "invalid initializer"
 msgstr "bộ khởi tạo sai"
 
-#: c/c-typeck.c:7912 cp/decl.c:6396
+#: c/c-typeck.c:7917 cp/decl.c:6396
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr ""
 
-#: c/c-typeck.c:8132
+#: c/c-typeck.c:8137
 #, gcc-internal-format
 msgid "extra brace group at end of initializer"
 msgstr "gặp nhóm ngoặc móc thừa tại kết thúc của bộ khởi tạo"
 
-#: c/c-typeck.c:8215
+#: c/c-typeck.c:8220
 #, gcc-internal-format
 msgid "braces around scalar initializer"
 msgstr "ngoặc chung quanh bộ khởi tạo vô hướng"
 
-#: c/c-typeck.c:8281 c/c-typeck.c:9615 cp/typeck2.c:1084 cp/typeck2.c:1297
+#: c/c-typeck.c:8286 c/c-typeck.c:9620 cp/typeck2.c:1084 cp/typeck2.c:1297
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "bộ phận mảng dẻo bị khởi tạo trong một ngữ cảnh lồng nhau"
 
-#: c/c-typeck.c:8318
+#: c/c-typeck.c:8323
 #, gcc-internal-format
 msgid "missing braces around initializer"
 msgstr "thiếu ngoặc móc chung quanh bộ khởi tạo"
 
-#: c/c-typeck.c:8341
+#: c/c-typeck.c:8346
 #, gcc-internal-format
 msgid "missing initializer for field %qD of %qT"
 msgstr ""
 
-#: c/c-typeck.c:8365
+#: c/c-typeck.c:8370
 #, gcc-internal-format
 msgid "empty scalar initializer"
 msgstr "bộ khởi tạo vô hướng vẫn trống"
 
-#: c/c-typeck.c:8370
+#: c/c-typeck.c:8375
 #, gcc-internal-format
 msgid "extra elements in scalar initializer"
 msgstr "gặp yếu tố thừa trong bộ khởi tạo vô hướng"
 
-#: c/c-typeck.c:8483 c/c-typeck.c:8565
+#: c/c-typeck.c:8488 c/c-typeck.c:8570
 #, gcc-internal-format
 msgid "array index in non-array initializer"
 msgstr "gặp chỉ mục mảng trong bộ khởi tạo không phải mảng"
 
-#: c/c-typeck.c:8488 c/c-typeck.c:8627
+#: c/c-typeck.c:8493 c/c-typeck.c:8632
 #, gcc-internal-format
 msgid "field name not in record or union initializer"
 msgstr "không có tên trường trong bộ khởi tạo hợp hoặc mục ghi"
 
-#: c/c-typeck.c:8538
+#: c/c-typeck.c:8543
 #, gcc-internal-format
 msgid "array index in initializer not of integer type"
 msgstr "bộ khởi tạo chứa một chỉ mục mảng không có loại số nguyên"
 
-#: c/c-typeck.c:8547 c/c-typeck.c:8556
+#: c/c-typeck.c:8552 c/c-typeck.c:8561
 #, gcc-internal-format
 msgid "array index in initializer is not an integer constant expression"
 msgstr "bộ khởi tạo chứa một chỉ mục mảng không phải là một biểu tượng hằng số nguyên"
 
-#: c/c-typeck.c:8561 c/c-typeck.c:8563
+#: c/c-typeck.c:8566 c/c-typeck.c:8568
 #, gcc-internal-format
 msgid "nonconstant array index in initializer"
 msgstr "bộ khởi tạo chứa một chỉ mục mảng không phải hằng số"
 
-#: c/c-typeck.c:8567 c/c-typeck.c:8570
+#: c/c-typeck.c:8572 c/c-typeck.c:8575
 #, gcc-internal-format
 msgid "array index in initializer exceeds array bounds"
 msgstr "bộ khởi tạo chứa một chỉ mục mảng vượt quá giới hạn mảng"
 
-#: c/c-typeck.c:8589
+#: c/c-typeck.c:8594
 #, gcc-internal-format
 msgid "empty index range in initializer"
 msgstr "bộ khởi tạo chứa phạm vi chỉ mục vẫn trống"
 
-#: c/c-typeck.c:8598
+#: c/c-typeck.c:8603
 #, gcc-internal-format
 msgid "array index range in initializer exceeds array bounds"
 msgstr "bộ khởi tạo chứa một phạm vi chỉ mục mảng vượt quá giới hạn mảng"
 
-#: c/c-typeck.c:8700 c/c-typeck.c:8730 c/c-typeck.c:9274
+#: c/c-typeck.c:8705 c/c-typeck.c:8735 c/c-typeck.c:9279
 #, gcc-internal-format
 msgid "initialized field with side-effects overwritten"
 msgstr "trường đã khởi tạo với hiệu ứng khác bị ghi đè"
 
-#: c/c-typeck.c:8704 c/c-typeck.c:8734 c/c-typeck.c:9277
+#: c/c-typeck.c:8709 c/c-typeck.c:8739 c/c-typeck.c:9282
 #, gcc-internal-format
 msgid "initialized field overwritten"
 msgstr "trường đã khởi tạo bị ghi đè"
 
-#: c/c-typeck.c:9208
+#: c/c-typeck.c:9213
 #, gcc-internal-format
 msgid "enum conversion in initialization is invalid in C++"
 msgstr "chuyển đổi enum trong bộ khởi tạo thì không hợp lệ trong C++"
 
-#: c/c-typeck.c:9496
+#: c/c-typeck.c:9501
 #, gcc-internal-format
 msgid "excess elements in char array initializer"
 msgstr "gặp yếu tố thừa trong bộ khởi tạo mảng ký tự"
 
-#: c/c-typeck.c:9503 c/c-typeck.c:9574
+#: c/c-typeck.c:9508 c/c-typeck.c:9579
 #, gcc-internal-format
 msgid "excess elements in struct initializer"
 msgstr "gặp yếu tố thừa trong bộ khởi tạo cấu trúc"
 
-#: c/c-typeck.c:9518
+#: c/c-typeck.c:9523
 #, gcc-internal-format
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr ""
 
-#: c/c-typeck.c:9589
+#: c/c-typeck.c:9594
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr "một bộ phận mảng dẻo bị khởi tạo một cách không phải tĩnh"
 
-#: c/c-typeck.c:9687
+#: c/c-typeck.c:9692
 #, gcc-internal-format
 msgid "excess elements in union initializer"
 msgstr "gặp yếu tố thừa trong bộ khởi tạo hợp"
 
-#: c/c-typeck.c:9709
+#: c/c-typeck.c:9714
 #, gcc-internal-format
 msgid "traditional C rejects initialization of unions"
 msgstr ""
 
-#: c/c-typeck.c:9777
+#: c/c-typeck.c:9782
 #, gcc-internal-format
 msgid "excess elements in array initializer"
 msgstr "gặp yếu tố thừa trong bộ khởi tạo mảng"
 
-#: c/c-typeck.c:9811
+#: c/c-typeck.c:9816
 #, gcc-internal-format
 msgid "excess elements in vector initializer"
 msgstr "gặp yếu tố thừa trong bộ khởi tạo véc-tơ"
 
-#: c/c-typeck.c:9843
+#: c/c-typeck.c:9848
 #, gcc-internal-format
 msgid "excess elements in scalar initializer"
 msgstr "gặp yếu tố thừa trong bộ khởi tạo vô hướng"
 
-#: c/c-typeck.c:10086
+#: c/c-typeck.c:10091
 #, gcc-internal-format
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C cấm %<goto *expr;%>"
 
-#: c/c-typeck.c:10113 c/gimple-parser.c:1604 cp/typeck.c:9113
+#: c/c-typeck.c:10118 c/gimple-parser.c:1604 cp/typeck.c:9113
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "hàm đã khai báo %<noreturn%> có một câu lệnh %<return%>"
 
-#: c/c-typeck.c:10139 c/c-typeck.c:10143
+#: c/c-typeck.c:10144 c/c-typeck.c:10148
 #, gcc-internal-format
 msgid "%<return%> with no value, in function returning non-void"
 msgstr "%<return%> (trả lại) không có giá trị, trong hàm trả lại non-void (không rỗng)"
 
-#: c/c-typeck.c:10157 c/gimple-parser.c:1614
+#: c/c-typeck.c:10162 c/gimple-parser.c:1614
 #, gcc-internal-format
 msgid "%<return%> with a value, in function returning void"
 msgstr "%<return%> với một giá trị, trong hàm trả lại void (rỗng)"
 
-#: c/c-typeck.c:10160
+#: c/c-typeck.c:10165
 #, gcc-internal-format
 msgid "ISO C forbids %<return%> with expression, in function returning void"
 msgstr ""
 
-#: c/c-typeck.c:10236
+#: c/c-typeck.c:10241
 #, gcc-internal-format
 msgid "function returns address of label"
 msgstr "hàm trả về địa chỉ của biến cục bộ"
 
-#: c/c-typeck.c:10327 cp/semantics.c:1171
+#: c/c-typeck.c:10332 cp/semantics.c:1171
 #, gcc-internal-format
 msgid "switch quantity not an integer"
 msgstr ""
 
-#: c/c-typeck.c:10352
+#: c/c-typeck.c:10357
 #, gcc-internal-format
 msgid "%<long%> switch expression not converted to %<int%> in ISO C"
 msgstr ""
 
-#: c/c-typeck.c:10390 c/c-typeck.c:10398
+#: c/c-typeck.c:10395 c/c-typeck.c:10403
 #, gcc-internal-format
 msgid "case label is not an integer constant expression"
 msgstr ""
 
-#: c/c-typeck.c:10404 cp/parser.c:11067
+#: c/c-typeck.c:10409 cp/parser.c:11067
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr ""
 
-#: c/c-typeck.c:10406
+#: c/c-typeck.c:10411
 #, gcc-internal-format
 msgid "%<default%> label not within a switch statement"
 msgstr ""
 
-#: c/c-typeck.c:10578 cp/parser.c:12356
+#: c/c-typeck.c:10583 cp/parser.c:12353
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr ""
 
-#: c/c-typeck.c:10580 cp/parser.c:12379
+#: c/c-typeck.c:10585 cp/parser.c:12376
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "câu lệnh “continue” nằm ở ngoài một vòng lặp"
 
-#: c/c-typeck.c:10585 cp/parser.c:12369
+#: c/c-typeck.c:10590 cp/parser.c:12366
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr ""
 
-#: c/c-typeck.c:10590
+#: c/c-typeck.c:10595
 #, gcc-internal-format
 msgid "break statement within %<#pragma simd%> loop body"
 msgstr ""
 
-#: c/c-typeck.c:10592
+#: c/c-typeck.c:10597
 #, gcc-internal-format
 msgid "continue statement within %<#pragma simd%> loop body"
 msgstr ""
 
-#: c/c-typeck.c:10618 cp/cp-gimplify.c:432
+#: c/c-typeck.c:10623 cp/cp-gimplify.c:432
 #, gcc-internal-format
 msgid "statement with no effect"
 msgstr "câu lệnh không có tác dụng"
 
-#: c/c-typeck.c:10662
+#: c/c-typeck.c:10667
 #, gcc-internal-format
 msgid "expression statement has incomplete type"
 msgstr ""
 
-#: c/c-typeck.c:11476 c/c-typeck.c:11644 cp/typeck.c:5017
+#: c/c-typeck.c:11481 c/c-typeck.c:11649 cp/typeck.c:5017
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr ""
 
-#: c/c-typeck.c:11484 c/c-typeck.c:11652 cp/typeck.c:5030
+#: c/c-typeck.c:11489 c/c-typeck.c:11657 cp/typeck.c:5030
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr ""
 
-#: c/c-typeck.c:11509 c/c-typeck.c:11677 cp/typeck.c:5058
+#: c/c-typeck.c:11514 c/c-typeck.c:11682 cp/typeck.c:5058
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr ""
 
-#: c/c-typeck.c:11523 cp/typeck.c:4743
+#: c/c-typeck.c:11528 cp/typeck.c:4743
 #, gcc-internal-format
 msgid "comparing floating point with == or != is unsafe"
 msgstr ""
 
-#: c/c-typeck.c:11541 c/c-typeck.c:11562
+#: c/c-typeck.c:11546 c/c-typeck.c:11567
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<false%> for the address of %qD will never be NULL"
 msgstr ""
 
-#: c/c-typeck.c:11547 c/c-typeck.c:11568
+#: c/c-typeck.c:11552 c/c-typeck.c:11573
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<true%> for the address of %qD will never be NULL"
 msgstr ""
 
-#: c/c-typeck.c:11589 c/c-typeck.c:11718
+#: c/c-typeck.c:11594 c/c-typeck.c:11723
 #, gcc-internal-format
 msgid "comparison of pointers to disjoint address spaces"
 msgstr ""
 
-#: c/c-typeck.c:11596 c/c-typeck.c:11602
+#: c/c-typeck.c:11601 c/c-typeck.c:11607
 #, gcc-internal-format
 msgid "ISO C forbids comparison of %<void *%> with function pointer"
 msgstr "ISO C cấm chỉ việc so sánh của %<void *%> với con trỏ hàm"
 
-#: c/c-typeck.c:11609 c/c-typeck.c:11728
+#: c/c-typeck.c:11614 c/c-typeck.c:11733
 #, gcc-internal-format
 msgid "comparison of distinct pointer types lacks a cast"
 msgstr ""
 
-#: c/c-typeck.c:11621 c/c-typeck.c:11626 c/c-typeck.c:11754 c/c-typeck.c:11759
+#: c/c-typeck.c:11626 c/c-typeck.c:11631 c/c-typeck.c:11759 c/c-typeck.c:11764
 #, gcc-internal-format
 msgid "comparison between pointer and integer"
 msgstr ""
 
-#: c/c-typeck.c:11706
+#: c/c-typeck.c:11711
 #, gcc-internal-format
 msgid "comparison of complete and incomplete pointers"
 msgstr ""
 
-#: c/c-typeck.c:11708
+#: c/c-typeck.c:11713
 #, gcc-internal-format
 msgid "ISO C forbids ordered comparisons of pointers to functions"
 msgstr ""
 
-#: c/c-typeck.c:11713
+#: c/c-typeck.c:11718
 #, gcc-internal-format
 msgid "ordered comparison of pointer with null pointer"
 msgstr ""
 
-#: c/c-typeck.c:11736 c/c-typeck.c:11739 c/c-typeck.c:11746 c/c-typeck.c:11749
+#: c/c-typeck.c:11741 c/c-typeck.c:11744 c/c-typeck.c:11751 c/c-typeck.c:11754
 #: cp/typeck.c:5081 cp/typeck.c:5088
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr ""
 
-#: c/c-typeck.c:11811
+#: c/c-typeck.c:11816
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
 msgstr ""
 
-#: c/c-typeck.c:12126
+#: c/c-typeck.c:12131
 #, gcc-internal-format
 msgid "used array that cannot be converted to pointer where scalar is required"
 msgstr ""
 
-#: c/c-typeck.c:12130
+#: c/c-typeck.c:12135
 #, gcc-internal-format
 msgid "used struct type value where scalar is required"
 msgstr ""
 
-#: c/c-typeck.c:12134
+#: c/c-typeck.c:12139
 #, gcc-internal-format
 msgid "used union type value where scalar is required"
 msgstr ""
 
-#: c/c-typeck.c:12150
+#: c/c-typeck.c:12155
 #, gcc-internal-format
 msgid "used vector type where scalar is required"
 msgstr ""
 
-#: c/c-typeck.c:12340 cp/semantics.c:8508
+#: c/c-typeck.c:12345 cp/semantics.c:8511
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma acc update%> phải chứa ít nhất là một mệnh đề %<device%> hay %<host%> hay %<self%>"
 
-#: c/c-typeck.c:12379 cp/semantics.c:8545
+#: c/c-typeck.c:12384 cp/semantics.c:8548
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12423 c/c-typeck.c:13581 c/c-typeck.c:13642 c/c-typeck.c:13704
+#: c/c-typeck.c:12428 c/c-typeck.c:13586 c/c-typeck.c:13647 c/c-typeck.c:13709
 #, gcc-internal-format
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "%<_Atomic%> %qE trong mệnh đề %qs"
 
-#: c/c-typeck.c:12436 c/c-typeck.c:13628 cp/semantics.c:4546
-#: cp/semantics.c:6717
+#: c/c-typeck.c:12441 c/c-typeck.c:13633 cp/semantics.c:4549
+#: cp/semantics.c:6720
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12445 c/c-typeck.c:13652 cp/semantics.c:4556
-#: cp/semantics.c:6735
+#: c/c-typeck.c:12450 c/c-typeck.c:13657 cp/semantics.c:4559
+#: cp/semantics.c:6738
 #, gcc-internal-format
 msgid "%qE is a member of a union"
 msgstr "%qE không phải là thành viên của union"
 
-#: c/c-typeck.c:12455 cp/semantics.c:4570 cp/semantics.c:6760
+#: c/c-typeck.c:12460 cp/semantics.c:4573 cp/semantics.c:6763
 #, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD không phải một biến trong mệnh đề %qs"
 
-#: c/c-typeck.c:12459 c/c-typeck.c:13669 cp/semantics.c:4574
-#: cp/semantics.c:6763
+#: c/c-typeck.c:12464 c/c-typeck.c:13674 cp/semantics.c:4577
+#: cp/semantics.c:6766
 #, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qE không phải một biến trong mệnh đề %qs"
 
-#: c/c-typeck.c:12466
+#: c/c-typeck.c:12471
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %qs clause"
 msgstr "%<_Atomic%> %qD trong mệnh đề %qs"
 
-#: c/c-typeck.c:12475 c/c-typeck.c:13676 c/c-typeck.c:13778
-#: cp/semantics.c:4591 cp/semantics.c:6769 cp/semantics.c:6931
+#: c/c-typeck.c:12480 c/c-typeck.c:13681 c/c-typeck.c:13783
+#: cp/semantics.c:4594 cp/semantics.c:6772 cp/semantics.c:6934
 #, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD không phải một biến trong mệnh đề %qs"
 
-#: c/c-typeck.c:12511 cp/semantics.c:4623
+#: c/c-typeck.c:12516 cp/semantics.c:4626
 #, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr ""
 
-#: c/c-typeck.c:12518 cp/semantics.c:4630
+#: c/c-typeck.c:12523 cp/semantics.c:4633
 #, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr ""
 
-#: c/c-typeck.c:12545 c/c-typeck.c:12609 c/c-typeck.c:12867
-#: cp/semantics.c:4666 cp/semantics.c:4730
+#: c/c-typeck.c:12550 c/c-typeck.c:12614 c/c-typeck.c:12872
+#: cp/semantics.c:4669 cp/semantics.c:4733
 #, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12564 cp/semantics.c:4685
+#: c/c-typeck.c:12569 cp/semantics.c:4688
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12572 cp/semantics.c:4693
+#: c/c-typeck.c:12577 cp/semantics.c:4696
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12581 c/c-typeck.c:12691 cp/semantics.c:4702
-#: cp/semantics.c:4812
+#: c/c-typeck.c:12586 c/c-typeck.c:12696 cp/semantics.c:4705
+#: cp/semantics.c:4815
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12598 cp/semantics.c:4719
+#: c/c-typeck.c:12603 cp/semantics.c:4722
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12635 cp/semantics.c:4756
+#: c/c-typeck.c:12640 cp/semantics.c:4759
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12650 cp/semantics.c:4771
+#: c/c-typeck.c:12655 cp/semantics.c:4774
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12683 cp/semantics.c:4804
+#: c/c-typeck.c:12688 cp/semantics.c:4807
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12701 c/c-typeck.c:12810 cp/semantics.c:4822
-#: cp/semantics.c:4934
+#: c/c-typeck.c:12706 c/c-typeck.c:12815 cp/semantics.c:4825
+#: cp/semantics.c:4937
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12709 cp/semantics.c:4830
+#: c/c-typeck.c:12714 cp/semantics.c:4833
 #, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr "%qE không có con trỏ hay kiểu mảng"
 
-#: c/c-typeck.c:13103 c/c-typeck.c:13113
+#: c/c-typeck.c:13108 c/c-typeck.c:13118
 #, gcc-internal-format
 msgid "%qD in %<reduction%> clause is a zero size array"
 msgstr "%qD trong mệnh đề %<reduction%> là một mạng cỡ không"
 
-#: c/c-typeck.c:13130
+#: c/c-typeck.c:13135
 #, gcc-internal-format
 msgid "%<_Atomic%> %qE in %<reduction%> clause"
 msgstr "%<_Atomic%> %qE trong mệnh đề %<reduction%>"
 
-#: c/c-typeck.c:13178
+#: c/c-typeck.c:13183
 #, gcc-internal-format
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "%qE có kiểu không hợp lệ cho %<reduction(%s)%>"
 
-#: c/c-typeck.c:13187 cp/semantics.c:5755
+#: c/c-typeck.c:13192 cp/semantics.c:5758
 #, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr ""
 
-#: c/c-typeck.c:13275
+#: c/c-typeck.c:13280
 #, gcc-internal-format
 msgid "variable length element type in array %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13293 c/c-typeck.c:13836 cp/semantics.c:7249
+#: c/c-typeck.c:13298 c/c-typeck.c:13841 cp/semantics.c:7252
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13305 cp/semantics.c:7289
+#: c/c-typeck.c:13310 cp/semantics.c:7292
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE phải là %<threadprivate%> với %<copyin%>"
 
-#: c/c-typeck.c:13319 cp/semantics.c:5929
+#: c/c-typeck.c:13324 cp/semantics.c:5932
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr ""
 
-#: c/c-typeck.c:13327
+#: c/c-typeck.c:13332
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with type %qT"
 msgstr ""
 
-#: c/c-typeck.c:13335
+#: c/c-typeck.c:13340
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13354 cp/semantics.c:5999
+#: c/c-typeck.c:13359 cp/semantics.c:6002
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
-#: c/c-typeck.c:13384 c/c-typeck.c:13771 cp/semantics.c:6083
-#: cp/semantics.c:6924
+#: c/c-typeck.c:13389 c/c-typeck.c:13776 cp/semantics.c:6086
+#: cp/semantics.c:6927
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr ""
 
-#: c/c-typeck.c:13393 cp/semantics.c:6092
+#: c/c-typeck.c:13398 cp/semantics.c:6095
 #, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr ""
 
-#: c/c-typeck.c:13404 c/c-typeck.c:13434 c/c-typeck.c:13463
+#: c/c-typeck.c:13409 c/c-typeck.c:13439 c/c-typeck.c:13468
 #, gcc-internal-format
 msgid "%qE appears more than once in data clauses"
 msgstr ""
 
-#: c/c-typeck.c:13411 c/c-typeck.c:13440 c/c-typeck.c:13600 c/c-typeck.c:13714
-#: c/c-typeck.c:13720 c/c-typeck.c:13733 c/c-typeck.c:13742
-#: cp/semantics.c:6102 cp/semantics.c:6109 cp/semantics.c:6160
-#: cp/semantics.c:6166 cp/semantics.c:6203 cp/semantics.c:6680
-#: cp/semantics.c:6817 cp/semantics.c:6823 cp/semantics.c:6836
-#: cp/semantics.c:6845
+#: c/c-typeck.c:13416 c/c-typeck.c:13445 c/c-typeck.c:13605 c/c-typeck.c:13719
+#: c/c-typeck.c:13725 c/c-typeck.c:13738 c/c-typeck.c:13747
+#: cp/semantics.c:6105 cp/semantics.c:6112 cp/semantics.c:6163
+#: cp/semantics.c:6169 cp/semantics.c:6206 cp/semantics.c:6683
+#: cp/semantics.c:6820 cp/semantics.c:6826 cp/semantics.c:6839
+#: cp/semantics.c:6848
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
-#: c/c-typeck.c:13413 c/c-typeck.c:13442 c/c-typeck.c:13722 c/c-typeck.c:13744
-#: cp/semantics.c:6111 cp/semantics.c:6168 cp/semantics.c:6825
-#: cp/semantics.c:6847
+#: c/c-typeck.c:13418 c/c-typeck.c:13447 c/c-typeck.c:13727 c/c-typeck.c:13749
+#: cp/semantics.c:6114 cp/semantics.c:6171 cp/semantics.c:6828
+#: cp/semantics.c:6850
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr ""
 
-#: c/c-typeck.c:13427 cp/semantics.c:6154
+#: c/c-typeck.c:13432 cp/semantics.c:6157
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13456 cp/semantics.c:6197
+#: c/c-typeck.c:13461 cp/semantics.c:6200
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13475 cp/semantics.c:6545
+#: c/c-typeck.c:13480 cp/semantics.c:6548
 #, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "%qE không phải một biến trong mệnh đề %<aligned%>"
 
-#: c/c-typeck.c:13482
+#: c/c-typeck.c:13487
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array"
 msgstr ""
 
-#: c/c-typeck.c:13489
+#: c/c-typeck.c:13494
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<aligned%> clause"
 msgstr "%qD không phải một biến trong mệnh đề  %<aligned%>"
 
-#: c/c-typeck.c:13496
+#: c/c-typeck.c:13501
 #, gcc-internal-format
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:13551 cp/semantics.c:6627
+#: c/c-typeck.c:13556 cp/semantics.c:6630
 #, gcc-internal-format
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr "%qE không phải một biến trong mệnh đề %<depend%>"
 
-#: c/c-typeck.c:13573 cp/semantics.c:6658
+#: c/c-typeck.c:13578 cp/semantics.c:6661
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13597 c/c-typeck.c:13731 cp/semantics.c:6677
-#: cp/semantics.c:6834
+#: c/c-typeck.c:13602 c/c-typeck.c:13736 cp/semantics.c:6680
+#: cp/semantics.c:6837
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr ""
 
-#: c/c-typeck.c:13603 c/c-typeck.c:13735 cp/semantics.c:6683
-#: cp/semantics.c:6838
+#: c/c-typeck.c:13608 c/c-typeck.c:13740 cp/semantics.c:6686
+#: cp/semantics.c:6841
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr ""
 
-#: c/c-typeck.c:13635 cp/semantics.c:6724
+#: c/c-typeck.c:13640 cp/semantics.c:6727
 #, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qE không phải một kiểu ánh xạ được trong mệnh đề %qs"
 
-#: c/c-typeck.c:13695 c/c-typeck.c:13785 cp/semantics.c:6799
-#: cp/semantics.c:6938
+#: c/c-typeck.c:13700 c/c-typeck.c:13790 cp/semantics.c:6802
+#: cp/semantics.c:6941
 #, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD không phải một biến trong mệnh đề %qs"
 
-#: c/c-typeck.c:13766 cp/semantics.c:6918
+#: c/c-typeck.c:13771 cp/semantics.c:6921
 #, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE không phải một biến cũng không phải tên hàm trong mệnh đề %qs"
 
-#: c/c-typeck.c:13794 cp/semantics.c:6947
+#: c/c-typeck.c:13799 cp/semantics.c:6950
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr ""
 
-#: c/c-typeck.c:13808 cp/semantics.c:6962
+#: c/c-typeck.c:13813 cp/semantics.c:6965
 #, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD không phải một đối số trong mệnh đề %<uniform%>"
 
-#: c/c-typeck.c:13811 cp/semantics.c:6964
+#: c/c-typeck.c:13816 cp/semantics.c:6967
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qE không phải một đối số trong mệnh đề %<uniform%>"
 
-#: c/c-typeck.c:13826
+#: c/c-typeck.c:13831
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer nor an array"
 msgstr ""
 
-#: c/c-typeck.c:13900 cp/semantics.c:6359
+#: c/c-typeck.c:13905 cp/semantics.c:6362
 #, gcc-internal-format
 msgid "%<nonmonotonic%> modifier specified for %qs schedule kind"
 msgstr ""
 
-#: c/c-typeck.c:13931 cp/semantics.c:7141
+#: c/c-typeck.c:13936 cp/semantics.c:7144
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:13981 cp/semantics.c:7332
+#: c/c-typeck.c:13986 cp/semantics.c:7335
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr ""
 
-#: c/c-typeck.c:14001 cp/semantics.c:7223
+#: c/c-typeck.c:14006 cp/semantics.c:7226
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:14013 cp/semantics.c:7236
+#: c/c-typeck.c:14018 cp/semantics.c:7239
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14031 cp/semantics.c:7203
+#: c/c-typeck.c:14036 cp/semantics.c:7206
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14204
+#: c/c-typeck.c:14209
 #, gcc-internal-format
 msgid "cannot use %<va_arg%> with reverse storage order"
 msgstr ""
 
-#: c/c-typeck.c:14209
+#: c/c-typeck.c:14214
 #, gcc-internal-format
 msgid "second argument to %<va_arg%> is of incomplete type %qT"
 msgstr ""
 
-#: c/c-typeck.c:14215
+#: c/c-typeck.c:14220
 #, gcc-internal-format
 msgid "C++ requires promoted type, not enum type, in %<va_arg%>"
 msgstr ""
@@ -38453,7 +38498,7 @@
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "  không hiểu chuyển đổi cho đối số %d từ %qT thành %qT"
 
-#: cp/call.c:3441 cp/pt.c:6495
+#: cp/call.c:3441 cp/pt.c:6509
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -38752,7 +38797,7 @@
 msgid "%q#D is private within this context"
 msgstr ""
 
-#: cp/call.c:6478 cp/decl.c:7343
+#: cp/call.c:6478 cp/decl.c:7364
 #, gcc-internal-format
 msgid "declared private here"
 msgstr "đã được khai báo ở đây"
@@ -38762,7 +38807,7 @@
 msgid "%q#D is protected within this context"
 msgstr ""
 
-#: cp/call.c:6486 cp/decl.c:7344
+#: cp/call.c:6486 cp/decl.c:7365
 #, gcc-internal-format
 msgid "declared protected here"
 msgstr "được khai báo bảo vệ ở đây"
@@ -39071,7 +39116,7 @@
 msgid "call to non-function %qD"
 msgstr ""
 
-#: cp/call.c:9119 cp/pt.c:15053 cp/typeck.c:2901
+#: cp/call.c:9119 cp/pt.c:15075 cp/typeck.c:2901
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "không thể gọi cấu tử %<%T::%D%> một cách trực tiếp"
@@ -39292,263 +39337,263 @@
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr ""
 
-#: cp/class.c:2098
+#: cp/class.c:2103
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr ""
 
-#: cp/class.c:2110
+#: cp/class.c:2115
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr ""
 
-#: cp/class.c:2152
+#: cp/class.c:2156
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr ""
 
-#: cp/class.c:2156
+#: cp/class.c:2160
 #, gcc-internal-format
 msgid "%q#D is public, but requires an existing %q#T object"
 msgstr ""
 
-#: cp/class.c:2430
+#: cp/class.c:2434
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr ""
 
-#: cp/class.c:2785
+#: cp/class.c:2789
 #, gcc-internal-format
 msgid "%qD can be marked override"
 msgstr "%q#D không thể được tạo đè"
 
-#: cp/class.c:2797
+#: cp/class.c:2801
 #, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr ""
 
-#: cp/class.c:2799
+#: cp/class.c:2803
 #, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr ""
 
-#: cp/class.c:2861
+#: cp/class.c:2865
 #, gcc-internal-format
 msgid "%qD was hidden"
 msgstr "%q+D bị ẩn"
 
-#: cp/class.c:2863
+#: cp/class.c:2867
 #, gcc-internal-format
 msgid "  by %qD"
 msgstr "  bởi %q+D"
 
-#: cp/class.c:2896
+#: cp/class.c:2900
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr ""
 
-#: cp/class.c:2906 cp/name-lookup.c:3293 cp/parser.c:19720
+#: cp/class.c:2910 cp/name-lookup.c:3293 cp/parser.c:19717
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
 
-#: cp/class.c:3097
+#: cp/class.c:3101
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr ""
 
-#: cp/class.c:3213
+#: cp/class.c:3217
 #, gcc-internal-format
 msgid "bit-field %q+#D with non-integral type"
 msgstr ""
 
-#: cp/class.c:3229
+#: cp/class.c:3233
 #, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr ""
 
-#: cp/class.c:3234
+#: cp/class.c:3238
 #, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr "độ rộng bị âm trong trường bít %q+D"
 
-#: cp/class.c:3239
+#: cp/class.c:3243
 #, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr "trường bít %q+D có độ rộng là không"
 
-#: cp/class.c:3249
+#: cp/class.c:3253
 #, gcc-internal-format
 msgid "width of %qD exceeds its type"
 msgstr ""
 
-#: cp/class.c:3255
+#: cp/class.c:3259
 #, gcc-internal-format
 msgid "%qD is too small to hold all values of %q#T"
 msgstr ""
 
-#: cp/class.c:3316
+#: cp/class.c:3320
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr ""
 
-#: cp/class.c:3319
+#: cp/class.c:3323
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr ""
 
-#: cp/class.c:3321
+#: cp/class.c:3325
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr ""
 
-#: cp/class.c:3325
+#: cp/class.c:3329
 #, gcc-internal-format
 msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/class.c:3453
+#: cp/class.c:3457
 #, gcc-internal-format
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr ""
 
-#: cp/class.c:3460
+#: cp/class.c:3464
 #, fuzzy, gcc-internal-format
 #| msgid "  non-static data member %qD has non-literal type"
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr "  thành viên dữ liệu không-tĩnh %qD có kiểu không-văn-chương"
 
-#: cp/class.c:3470
+#: cp/class.c:3474
 #, gcc-internal-format
 msgid "field %q+D invalidly declared function type"
 msgstr ""
 
-#: cp/class.c:3476
+#: cp/class.c:3480
 #, gcc-internal-format
 msgid "field %q+D invalidly declared method type"
 msgstr ""
 
-#: cp/class.c:3536
+#: cp/class.c:3540
 #, gcc-internal-format
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr ""
 
-#: cp/class.c:3585
+#: cp/class.c:3589
 #, gcc-internal-format
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr ""
 
-#: cp/class.c:3591
+#: cp/class.c:3595
 #, gcc-internal-format
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr ""
 
-#: cp/class.c:3617
+#: cp/class.c:3621
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr ""
 
-#: cp/class.c:3658
+#: cp/class.c:3662
 #, gcc-internal-format
 msgid "field %q#D with same name as class"
 msgstr "trường %q#D với cùng tên với lớp"
 
-#: cp/class.c:3681
+#: cp/class.c:3685
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr "%q#T có thành viên dữ liệu con trỏ"
 
-#: cp/class.c:3686
+#: cp/class.c:3690
 #, gcc-internal-format
 msgid "  but does not override %<%T(const %T&)%>"
 msgstr "  nhưng không đè %<%T(const %T&)%>"
 
-#: cp/class.c:3688
+#: cp/class.c:3692
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr "  hoặc %<operator=(const %T&)%>"
 
-#: cp/class.c:3692
+#: cp/class.c:3696
 #, gcc-internal-format
 msgid "  but does not override %<operator=(const %T&)%>"
 msgstr "  nhưng không được ghi đè %<operator=(const %T&)%>"
 
-#: cp/class.c:4097
+#: cp/class.c:4101
 #, gcc-internal-format
 msgid "alignment of %qD increased in -fabi-version=9 (GCC 5.2)"
 msgstr ""
 
-#: cp/class.c:4100
+#: cp/class.c:4104
 #, gcc-internal-format
 msgid "alignment of %qD will increase in -fabi-version=9"
 msgstr ""
 
-#: cp/class.c:4378
+#: cp/class.c:4382
 #, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr ""
 
-#: cp/class.c:4813
+#: cp/class.c:4817
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr ""
 
-#: cp/class.c:4834
+#: cp/class.c:4838
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr ""
 
-#: cp/class.c:5350 cp/constexpr.c:237
+#: cp/class.c:5367 cp/constexpr.c:237
 #, gcc-internal-format
 msgid "enclosing class of %<constexpr%> non-static member function %q+#D is not a literal type"
 msgstr ""
 
-#: cp/class.c:5374
+#: cp/class.c:5391
 #, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr "%q+T không là kiểu văn chương vì:"
 
-#: cp/class.c:5377
+#: cp/class.c:5394
 #, gcc-internal-format
 msgid "  %qT is a closure type, which is only literal in C++17 and later"
 msgstr ""
 
-#: cp/class.c:5380
+#: cp/class.c:5397
 #, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr "  %q+T có một cấu tử non-trivial"
 
-#: cp/class.c:5387
+#: cp/class.c:5404
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no %<constexpr%> constructor that is not a copy or move constructor"
 msgstr ""
 
-#: cp/class.c:5420
+#: cp/class.c:5437
 #, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "  lớp cơ sở %qT của %q+T là non-literal"
 
-#: cp/class.c:5435
+#: cp/class.c:5452
 #, gcc-internal-format
 msgid "  non-static data member %qD has non-literal type"
 msgstr "  thành viên dữ liệu không-tĩnh %qD có kiểu không-văn-chương"
 
-#: cp/class.c:5442
+#: cp/class.c:5459
 #, gcc-internal-format
 msgid "  non-static data member %qD has volatile type"
 msgstr "  thành viên dữ liệu không-tĩnh %qD có kiểu hay thay đổi"
 
-#: cp/class.c:5561
+#: cp/class.c:5578
 #, gcc-internal-format
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "lớp cơ sở %q+T có một hủy tử non-trivial truy cập được"
 
-#: cp/class.c:5590
+#: cp/class.c:5607
 #, gcc-internal-format
 msgid "non-static reference %q#D in class without a constructor"
 msgstr ""
 
-#: cp/class.c:5596
+#: cp/class.c:5613
 #, gcc-internal-format
 msgid "non-static const member %q#D in class without a constructor"
 msgstr ""
@@ -39555,152 +39600,152 @@
 
 #. If the function is defaulted outside the class, we just
 #. give the synthesis error.
-#: cp/class.c:5624
+#: cp/class.c:5641
 #, gcc-internal-format
 msgid "%q+D declared to take const reference, but implicit declaration would take non-const"
 msgstr ""
 
-#: cp/class.c:5898
+#: cp/class.c:5915
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:5910
+#: cp/class.c:5927
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:6133
+#: cp/class.c:6150
 #, gcc-internal-format
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr ""
 
-#: cp/class.c:6291
+#: cp/class.c:6308
 #, gcc-internal-format
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr ""
 
-#: cp/class.c:6576
+#: cp/class.c:6593
 #, gcc-internal-format
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr ""
 
-#: cp/class.c:6578
+#: cp/class.c:6595
 #, gcc-internal-format
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr ""
 
-#: cp/class.c:6583
+#: cp/class.c:6600
 #, gcc-internal-format
 msgid "array member %q#D declared here"
 msgstr "thành viên mảng %q#D đã khai báo ở đây"
 
-#: cp/class.c:6610
+#: cp/class.c:6627
 #, gcc-internal-format
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr ""
 
-#: cp/class.c:6612
+#: cp/class.c:6629
 #, gcc-internal-format
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr ""
 
-#: cp/class.c:6620 cp/class.c:6650
+#: cp/class.c:6637 cp/class.c:6667
 #, gcc-internal-format
 msgid "in the definition of %q#T"
 msgstr "trong định nghĩa của %q#T"
 
-#: cp/class.c:6628
+#: cp/class.c:6645
 #, gcc-internal-format
 msgid "flexible array member %qD not at end of %q#T"
 msgstr ""
 
-#: cp/class.c:6630
+#: cp/class.c:6647
 #, gcc-internal-format
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr ""
 
-#: cp/class.c:6648
+#: cp/class.c:6665
 #, gcc-internal-format
 msgid "next member %q#D declared here"
 msgstr "thành viên kế %q#D đã khai báo ở đây"
 
-#: cp/class.c:6760 cp/parser.c:23239
+#: cp/class.c:6777 cp/parser.c:23236
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "định nghĩa lại của %q#T"
 
-#: cp/class.c:6897
+#: cp/class.c:6914
 #, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr ""
 
-#: cp/class.c:6925
+#: cp/class.c:6942
 #, gcc-internal-format
 msgid "type transparent %q#T does not have any fields"
 msgstr ""
 
-#: cp/class.c:6931
+#: cp/class.c:6948
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr ""
 
-#: cp/class.c:6935
+#: cp/class.c:6952
 #, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr ""
 
-#: cp/class.c:6941
+#: cp/class.c:6958
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:7071
+#: cp/class.c:7088
 #, gcc-internal-format
 msgid "definition of %qD does not match %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/class.c:7082
+#: cp/class.c:7099
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr ""
 
-#: cp/class.c:7582
+#: cp/class.c:7599
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr ""
 
-#: cp/class.c:7672
+#: cp/class.c:7689
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr ""
 
-#: cp/class.c:7817
+#: cp/class.c:7834
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr ""
 
-#: cp/class.c:7844
+#: cp/class.c:7861
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr ""
 
-#: cp/class.c:7870
+#: cp/class.c:7887
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr ""
 
-#: cp/class.c:7873
+#: cp/class.c:7890
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr ""
 
-#: cp/class.c:7948 cp/class.c:7990
+#: cp/class.c:7965 cp/class.c:8007
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "không đủ thông tin kiểu"
 
-#: cp/class.c:7968
+#: cp/class.c:7985
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr ""
@@ -39710,12 +39755,12 @@
 #. A name N used in a class S shall refer to the same declaration
 #. in its context and when re-evaluated in the completed scope of
 #. S.
-#: cp/class.c:8235
+#: cp/class.c:8252
 #, gcc-internal-format
 msgid "declaration of %q#D"
 msgstr "khai báo của %q#D"
 
-#: cp/class.c:8237
+#: cp/class.c:8254
 #, gcc-internal-format
 msgid "changes meaning of %qD from %q#D"
 msgstr "thay đổi nghĩa của %qD từ %q#D"
@@ -40112,17 +40157,17 @@
 msgid "unexpected AST of kind %s"
 msgstr "cần AST thuộc kiểu %s"
 
-#: cp/cp-gimplify.c:1415
+#: cp/cp-gimplify.c:1416
 #, gcc-internal-format
 msgid "throw will always call terminate()"
 msgstr ""
 
-#: cp/cp-gimplify.c:1418
+#: cp/cp-gimplify.c:1419
 #, gcc-internal-format
 msgid "in C++11 destructors default to noexcept"
 msgstr ""
 
-#: cp/cp-gimplify.c:1429
+#: cp/cp-gimplify.c:1430
 #, gcc-internal-format
 msgid "in C++11 this throw will terminate because destructors default to noexcept"
 msgstr ""
@@ -40540,7 +40585,7 @@
 msgid "redeclaration %qD differs in %<constexpr%> from previous declaration"
 msgstr "sự khai báo lại %q+D khác trong %<constexpr%>"
 
-#: cp/decl.c:1304 cp/decl.c:13843
+#: cp/decl.c:1304 cp/decl.c:13867
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr "khai báo trước đây %q#D"
@@ -40869,7 +40914,7 @@
 msgid "  enters OpenMP structured block"
 msgstr "  vào khối được cấu trúc OpenMP"
 
-#: cp/decl.c:3434 cp/parser.c:12366 cp/parser.c:12387
+#: cp/decl.c:3434 cp/parser.c:12363 cp/parser.c:12384
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr ""
@@ -40879,7 +40924,7 @@
 msgid "%qD is not a type"
 msgstr "%qD không phải là một kiểu"
 
-#: cp/decl.c:3838 cp/parser.c:6366
+#: cp/decl.c:3838 cp/parser.c:6369
 #, gcc-internal-format
 msgid "%qD used without template parameters"
 msgstr ""
@@ -41257,8 +41302,8 @@
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.c:6011 cp/decl.c:6234 cp/typeck2.c:1310 cp/typeck2.c:1590
-#: cp/typeck2.c:1638 cp/typeck2.c:1685
+#: cp/decl.c:6011 cp/decl.c:6234 cp/typeck2.c:1310 cp/typeck2.c:1593
+#: cp/typeck2.c:1641 cp/typeck2.c:1688
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "quá nhiều bộ khởi tạo cho %qT"
@@ -41333,12 +41378,12 @@
 msgid "assignment (not initialization) in declaration"
 msgstr ""
 
-#: cp/decl.c:6873 cp/decl.c:12605
+#: cp/decl.c:6873 cp/decl.c:12629
 #, fuzzy, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C++ không cho phép %<alignof%> với một non-type"
 
-#: cp/decl.c:6877 cp/decl.c:12609
+#: cp/decl.c:6877 cp/decl.c:12633
 #, gcc-internal-format
 msgid "%<register%> storage class specifier used"
 msgstr ""
@@ -41363,43 +41408,43 @@
 msgid "function %q#D is initialized like a variable"
 msgstr ""
 
-#: cp/decl.c:7329
+#: cp/decl.c:7350
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr ""
 
-#: cp/decl.c:7332
+#: cp/decl.c:7353
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.c:7339
+#: cp/decl.c:7360
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "không thể chuyển đổi %qT thành %qT"
 
-#: cp/decl.c:7365
+#: cp/decl.c:7386
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:7374
+#: cp/decl.c:7395
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:7592
+#: cp/decl.c:7613
 #, fuzzy, gcc-internal-format
 #| msgid "source is a pointer to incomplete type"
 msgid "structured binding refers to incomplete type %qT"
 msgstr "nguồn là một hàm trỏ tới loại không hoàn toàn"
 
-#: cp/decl.c:7608
+#: cp/decl.c:7629
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr "ISO C90 cấm mảng có kích thước biến đổi %qE"
 
-#: cp/decl.c:7617 cp/decl.c:7702
+#: cp/decl.c:7638 cp/decl.c:7723
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "initializer provided for function"
 msgid "%u name provided for structured binding"
@@ -41406,894 +41451,894 @@
 msgid_plural "%u names provided for structured binding"
 msgstr[0] "bộ khởi tạo được cung cấp cho hàm"
 
-#: cp/decl.c:7621
+#: cp/decl.c:7642
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
 msgstr[0] ""
 
-#: cp/decl.c:7624
+#: cp/decl.c:7645
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] ""
 
-#: cp/decl.c:7669
+#: cp/decl.c:7690
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr "ISO C90 cấm mảng có kích thước biến đổi %qE"
 
-#: cp/decl.c:7695
+#: cp/decl.c:7716
 #, fuzzy, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "kích cỡ mảng không phải là biểu thức hằng số nguyên"
 
-#: cp/decl.c:7704
+#: cp/decl.c:7725
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.c:7725
+#: cp/decl.c:7746
 #, fuzzy, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr "(gần chỗ khởi tạo cho %qs)"
 
-#: cp/decl.c:7751
+#: cp/decl.c:7772
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr "không thể chuyển đổi kiểu %qT thành %qT"
 
-#: cp/decl.c:7756
+#: cp/decl.c:7777
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "không thể giải mã địa chỉ"
 
-#: cp/decl.c:7761
+#: cp/decl.c:7782
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose lambda closure type %qT"
 msgstr "không thể chuyển đổi kiểu %qT thành %qT"
 
-#: cp/decl.c:7765
+#: cp/decl.c:7786
 #, fuzzy, gcc-internal-format
 #| msgid "source is of incomplete class type"
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "nguồn có loại lớp không hoàn toàn"
 
-#: cp/decl.c:7774
+#: cp/decl.c:7795
 #, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr ""
 
-#: cp/decl.c:8213
+#: cp/decl.c:8234
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:8216
+#: cp/decl.c:8237
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:8222
+#: cp/decl.c:8243
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:8450
+#: cp/decl.c:8471
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr ""
 
-#: cp/decl.c:8454
+#: cp/decl.c:8475
 #, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "thiếu kích thước mảng trong %qT"
 
-#: cp/decl.c:8457
+#: cp/decl.c:8478
 #, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "mảng có kích thước không %qT"
 
-#: cp/decl.c:8473
+#: cp/decl.c:8494
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.c:8475
+#: cp/decl.c:8496
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.c:8499
+#: cp/decl.c:8520
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD được khai báo là một biến %<virtual%>"
 
-#: cp/decl.c:8501
+#: cp/decl.c:8522
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr ""
 
-#: cp/decl.c:8506
+#: cp/decl.c:8527
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD được khai báo như là đối số %<virtual%>"
 
-#: cp/decl.c:8508
+#: cp/decl.c:8529
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD được khai báo là một đối số %<inline%>"
 
-#: cp/decl.c:8510
+#: cp/decl.c:8531
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:8515
+#: cp/decl.c:8536
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD được khai báo như là kiểu %<virtual%>"
 
-#: cp/decl.c:8517
+#: cp/decl.c:8538
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD được khai báo là một kiểu %<inline%>"
 
-#: cp/decl.c:8519
+#: cp/decl.c:8540
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr ""
 
-#: cp/decl.c:8524
+#: cp/decl.c:8545
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD được khai báo như là trường %<virtual%>"
 
-#: cp/decl.c:8526
+#: cp/decl.c:8547
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD được khai báo là một trường %<inline%>"
 
-#: cp/decl.c:8528
+#: cp/decl.c:8549
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr ""
 
-#: cp/decl.c:8535
+#: cp/decl.c:8556
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D được khai báo là friend"
 
-#: cp/decl.c:8542
+#: cp/decl.c:8563
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr ""
 
-#: cp/decl.c:8574
+#: cp/decl.c:8595
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr ""
 
-#: cp/decl.c:8614
+#: cp/decl.c:8635
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr ""
 
-#: cp/decl.c:8624
+#: cp/decl.c:8645
 #, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr ""
 
-#: cp/decl.c:8630
+#: cp/decl.c:8651
 #, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr ""
 
-#: cp/decl.c:8632
+#: cp/decl.c:8653
 #, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr ""
 
-#: cp/decl.c:8703
+#: cp/decl.c:8724
 #, gcc-internal-format
 msgid "concept %qD has no definition"
 msgstr ""
 
-#: cp/decl.c:8772
+#: cp/decl.c:8793
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr ""
 
 #. Something like `template <class T> friend void f<T>()'.
-#: cp/decl.c:8782
+#: cp/decl.c:8803
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr ""
 
-#: cp/decl.c:8800
+#: cp/decl.c:8821
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:8808
+#: cp/decl.c:8829
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:8857
+#: cp/decl.c:8878
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr ""
 
-#: cp/decl.c:8859
+#: cp/decl.c:8880
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr ""
 
-#: cp/decl.c:8861
+#: cp/decl.c:8882
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "cannot declare %<::main%> to be %<constexpr%>"
 msgstr "hủy tử không thể là %<constexpr%>"
 
-#: cp/decl.c:8863
+#: cp/decl.c:8884
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr ""
 
-#: cp/decl.c:8920
+#: cp/decl.c:8941
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.c:8921
+#: cp/decl.c:8942
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.c:8929
+#: cp/decl.c:8950
 #, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr ""
 
-#: cp/decl.c:8930
+#: cp/decl.c:8951
 #, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr ""
 
-#: cp/decl.c:8940
+#: cp/decl.c:8961
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared at namespace scope"
 msgstr ""
 
-#: cp/decl.c:8946
+#: cp/decl.c:8967
 #, gcc-internal-format
 msgid "deduction guide %qD must not have a function body"
 msgstr ""
 
-#: cp/decl.c:8959
+#: cp/decl.c:8980
 #, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr ""
 
-#: cp/decl.c:8969
+#: cp/decl.c:8990
 #, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr ""
 
-#: cp/decl.c:8977
+#: cp/decl.c:8998
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:8983
+#: cp/decl.c:9004
 #, gcc-internal-format
 msgid "floating point suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:8991
+#: cp/decl.c:9012
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/decl.c:8996
+#: cp/decl.c:9017
 #, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "%qD phải là một hàm không-thành-viên"
 
-#: cp/decl.c:9076
+#: cp/decl.c:9097
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> phải trả về %<int%>"
 
-#: cp/decl.c:9116
+#: cp/decl.c:9137
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr ""
 
-#: cp/decl.c:9121
+#: cp/decl.c:9142
 #, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr ""
 
-#: cp/decl.c:9123
+#: cp/decl.c:9144
 #, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr "%q#D đã là mặc định rõ ràng ở đây"
 
-#: cp/decl.c:9140
+#: cp/decl.c:9161
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr ""
 
-#: cp/decl.c:9329
+#: cp/decl.c:9350
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr ""
 
-#: cp/decl.c:9337
+#: cp/decl.c:9358
 #, gcc-internal-format
 msgid "a non-template variable cannot be %<concept%>"
 msgstr ""
 
-#: cp/decl.c:9344
+#: cp/decl.c:9365
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.c:9464
+#: cp/decl.c:9485
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr ""
 
-#: cp/decl.c:9468
+#: cp/decl.c:9489
 #, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr ""
 
-#: cp/decl.c:9472
+#: cp/decl.c:9493
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr ""
 
-#: cp/decl.c:9486
+#: cp/decl.c:9507
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:9493
+#: cp/decl.c:9514
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr ""
 
-#: cp/decl.c:9498
+#: cp/decl.c:9519
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:9598
+#: cp/decl.c:9619
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:9600
+#: cp/decl.c:9621
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:9630 cp/decl.c:9680
+#: cp/decl.c:9651 cp/decl.c:9701
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "kích cỡ mảng không phải là biểu thức hằng số nguyên"
 
-#: cp/decl.c:9646
+#: cp/decl.c:9667
 #, gcc-internal-format
 msgid "size of array %qD is negative"
 msgstr "kích cỡ mảng %qD bị âm"
 
-#: cp/decl.c:9648 cp/init.c:3651
+#: cp/decl.c:9669 cp/init.c:3667
 #, gcc-internal-format
 msgid "size of array is negative"
 msgstr "kích cỡ mảng bị âm"
 
-#: cp/decl.c:9662
+#: cp/decl.c:9683
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C++ cấm mảng có kích thước bằng không %qD"
 
-#: cp/decl.c:9664
+#: cp/decl.c:9685
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++ cấm mảng có kích thước bằng không"
 
-#: cp/decl.c:9677
+#: cp/decl.c:9698
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr ""
 
-#: cp/decl.c:9686
+#: cp/decl.c:9707
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++ cấm biến có kích thước biến đổi %qD"
 
-#: cp/decl.c:9688
+#: cp/decl.c:9709
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++ cấm biến có kích thước biến đổi"
 
-#: cp/decl.c:9694
+#: cp/decl.c:9715
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr "mảng có độ dài biến đổi %qD được dùng"
 
-#: cp/decl.c:9697
+#: cp/decl.c:9718
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr "mảng có độ dài biến đổi được dùng"
 
-#: cp/decl.c:9746
+#: cp/decl.c:9767
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "tràn kích thước mảng"
 
-#: cp/decl.c:9799
+#: cp/decl.c:9820
 #, gcc-internal-format
 msgid "%qD declared as array of %qT"
 msgstr "%qD được khai báo là mảng của %qT"
 
-#: cp/decl.c:9809
+#: cp/decl.c:9830
 #, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "sự khai báo của %qD như là mảng void"
 
-#: cp/decl.c:9811
+#: cp/decl.c:9832
 #, gcc-internal-format
 msgid "creating array of void"
 msgstr "tạo mảng void"
 
-#: cp/decl.c:9816
+#: cp/decl.c:9837
 #, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "sự khai báo của %qD như là mảng của các hàm"
 
-#: cp/decl.c:9818
+#: cp/decl.c:9839
 #, gcc-internal-format
 msgid "creating array of functions"
 msgstr "tạo mảng hàm"
 
-#: cp/decl.c:9823
+#: cp/decl.c:9844
 #, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "sự khai báo của %qD như là mảng của các tham chiếu"
 
-#: cp/decl.c:9825
+#: cp/decl.c:9846
 #, gcc-internal-format
 msgid "creating array of references"
 msgstr "tạo mảng tham chiếu"
 
-#: cp/decl.c:9830
+#: cp/decl.c:9851
 #, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "sự khai báo của %qD như là mảng của các thành viên hàm"
 
-#: cp/decl.c:9832
+#: cp/decl.c:9853
 #, gcc-internal-format
 msgid "creating array of function members"
 msgstr "tạo mảng của thành viên hàm"
 
-#: cp/decl.c:9846
+#: cp/decl.c:9867
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.c:9850
+#: cp/decl.c:9871
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.c:9909
+#: cp/decl.c:9930
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr ""
 
-#: cp/decl.c:9912
+#: cp/decl.c:9933
 #, gcc-internal-format
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr ""
 
-#: cp/decl.c:9922
+#: cp/decl.c:9943
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr ""
 
-#: cp/decl.c:9925
+#: cp/decl.c:9946
 #, gcc-internal-format
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr ""
 
-#: cp/decl.c:9937
+#: cp/decl.c:9958
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr ""
 
-#: cp/decl.c:9940
+#: cp/decl.c:9961
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr ""
 
-#: cp/decl.c:9948
+#: cp/decl.c:9969
 #, fuzzy, gcc-internal-format
 #| msgid "no processor type specified for linking"
 msgid "return type specified for deduction guide"
 msgstr "chưa ghi rõ loại bộ xử lý cần liên kết"
 
-#: cp/decl.c:9951
+#: cp/decl.c:9972
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.c:9955
+#: cp/decl.c:9976
 #, gcc-internal-format
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.c:9964
+#: cp/decl.c:9985
 #, gcc-internal-format
 msgid "decl-specifier in declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.c:9985
+#: cp/decl.c:10006
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr ""
 
-#: cp/decl.c:9992
+#: cp/decl.c:10013
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "biến hay trường được khai báo là void"
 
-#: cp/decl.c:10007
+#: cp/decl.c:10028
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "%<inline%> được chỉ định cho khai báo lớp bạn"
 
-#: cp/decl.c:10013
+#: cp/decl.c:10034
 #, fuzzy, gcc-internal-format
 msgid "inline variables are only available with -std=c++17 or -std=gnu++17"
 msgstr "inline namespaces chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/decl.c:10268
+#: cp/decl.c:10292
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "cách dùng không đúng tên từ hạn định %<::%D%>"
 
-#: cp/decl.c:10271 cp/decl.c:10291
+#: cp/decl.c:10295 cp/decl.c:10315
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "cách dùng không đúng tên từ hạn định %<%T::%D%>"
 
-#: cp/decl.c:10274
+#: cp/decl.c:10298
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "cách dùng không đúng tên từ hạn định %<%D::%D%>"
 
-#: cp/decl.c:10283
+#: cp/decl.c:10307
 #, gcc-internal-format
 msgid "%q#T is not a class or a namespace"
 msgstr "%q#T không phải là một lớp hay namespace"
 
-#: cp/decl.c:10305 cp/decl.c:10398 cp/decl.c:10407 cp/decl.c:11970
+#: cp/decl.c:10329 cp/decl.c:10422 cp/decl.c:10431 cp/decl.c:11994
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "sự khai báo của %qD như là non-function"
 
-#: cp/decl.c:10311
+#: cp/decl.c:10335
 #, gcc-internal-format
 msgid "declaration of %qD as non-member"
 msgstr "sự khai báo của %qD như là non-member"
 
-#: cp/decl.c:10339
+#: cp/decl.c:10363
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr ""
 
-#: cp/decl.c:10390
+#: cp/decl.c:10414
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "định nghĩa hàm không khai báo đối số"
 
-#: cp/decl.c:10415
+#: cp/decl.c:10439
 #, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "sự khai báo của %qD như là %<typedef%>"
 
-#: cp/decl.c:10420
+#: cp/decl.c:10444
 #, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "khai báo của %qD như là đối số"
 
-#: cp/decl.c:10454
+#: cp/decl.c:10478
 #, gcc-internal-format
 msgid "%<concept%> cannot appear in a typedef declaration"
 msgstr ""
 
-#: cp/decl.c:10460
+#: cp/decl.c:10484
 #, gcc-internal-format
 msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgstr ""
 
-#: cp/decl.c:10468
+#: cp/decl.c:10492
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr ""
 
-#: cp/decl.c:10474
+#: cp/decl.c:10498
 #, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr ""
 
-#: cp/decl.c:10515
+#: cp/decl.c:10539
 #, gcc-internal-format
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr ""
 
-#: cp/decl.c:10564 cp/decl.c:10567 cp/decl.c:10570
+#: cp/decl.c:10588 cp/decl.c:10591 cp/decl.c:10594
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr ""
 
-#: cp/decl.c:10586
+#: cp/decl.c:10610
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr "%<__int%d%> không được hỗ trợ cho đích này"
 
-#: cp/decl.c:10592
+#: cp/decl.c:10616
 #, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ không hỗ trợ %<__int%d%> cho %qs"
 
-#: cp/decl.c:10614 cp/decl.c:10634
+#: cp/decl.c:10638 cp/decl.c:10658
 #, gcc-internal-format
 msgid "%<signed%> or %<unsigned%> invalid for %qs"
 msgstr "%<signed%> hoặc %<unsigned%> không hợp lệ với %qs"
 
-#: cp/decl.c:10616
+#: cp/decl.c:10640
 #, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgstr "%<signed%> và %<unsigned%> được chỉ định cùng với nhau cho %qs"
 
-#: cp/decl.c:10618
+#: cp/decl.c:10642
 #, gcc-internal-format
 msgid "%<long long%> invalid for %qs"
 msgstr "%<long long%> không hợp lệ với %qs"
 
-#: cp/decl.c:10620
+#: cp/decl.c:10644
 #, gcc-internal-format
 msgid "%<long%> invalid for %qs"
 msgstr "%<long%>không hợp lệ với %qs"
 
-#: cp/decl.c:10622
+#: cp/decl.c:10646
 #, gcc-internal-format
 msgid "%<short%> invalid for %qs"
 msgstr "%<short%> không hợp lệ với %qs"
 
-#: cp/decl.c:10624
+#: cp/decl.c:10648
 #, gcc-internal-format
 msgid "%<long%> or %<short%> invalid for %qs"
 msgstr "%<long%> hoặc %<short%> không hợp lệ với %qs"
 
-#: cp/decl.c:10626
+#: cp/decl.c:10650
 #, gcc-internal-format
 msgid "%<long%>, %<int%>, %<short%>, or %<char%> invalid for %qs"
 msgstr "%<long%>, %<int%>, %<short%>, hoặc %<char%> không hợp lệ cho %qs"
 
-#: cp/decl.c:10628
+#: cp/decl.c:10652
 #, gcc-internal-format
 msgid "%<long%> or %<short%> specified with char for %qs"
 msgstr "%<long%> hoặc %<short%> đựoc chỉ định với kiểu char với %qs"
 
-#: cp/decl.c:10630
+#: cp/decl.c:10654
 #, gcc-internal-format
 msgid "%<long%> and %<short%> specified together for %qs"
 msgstr "%<long%> và %<short%> được chỉ định cùng nhau với %qs"
 
-#: cp/decl.c:10636
+#: cp/decl.c:10660
 #, gcc-internal-format
 msgid "%<short%> or %<long%> invalid for %qs"
 msgstr "%<short%> hoặc %<long%> không hợp lệ với %qs"
 
-#: cp/decl.c:10644
+#: cp/decl.c:10668
 #, gcc-internal-format
 msgid "long, short, signed or unsigned used invalidly for %qs"
 msgstr ""
 
-#: cp/decl.c:10712
+#: cp/decl.c:10736
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "số ảo không hợp lệ cho %qs"
 
-#: cp/decl.c:10751
+#: cp/decl.c:10775
 #, gcc-internal-format
 msgid "template placeholder type %qT must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.c:10769
+#: cp/decl.c:10793
 #, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr ""
 
-#: cp/decl.c:10775
+#: cp/decl.c:10799
 #, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<constexpr%>"
 msgstr ""
 
-#: cp/decl.c:10785
+#: cp/decl.c:10809
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:10790
+#: cp/decl.c:10814
 #, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr ""
 
-#: cp/decl.c:10796
+#: cp/decl.c:10820
 #, gcc-internal-format
 msgid "storage class specifiers invalid in parameter declarations"
 msgstr ""
 
-#: cp/decl.c:10800
+#: cp/decl.c:10824
 #, gcc-internal-format
 msgid "a parameter cannot be declared %<concept%>"
 msgstr ""
 
-#: cp/decl.c:10805
+#: cp/decl.c:10829
 #, gcc-internal-format
 msgid "a parameter cannot be declared %<constexpr%>"
 msgstr ""
 
-#: cp/decl.c:10815
+#: cp/decl.c:10839
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "%<virtual%> ngoài khai báo lớp"
 
-#: cp/decl.c:10825
+#: cp/decl.c:10849
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %<inline%>"
 msgstr "hủy tử không thể là %<concept%>"
 
-#: cp/decl.c:10828
+#: cp/decl.c:10852
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %<typedef%>"
 msgstr "định nghĩa hàm được khai báo là %<typedef%>"
 
-#: cp/decl.c:10830
+#: cp/decl.c:10854
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %<constexpr%>"
 msgstr "hủy tử không thể là %<constexpr%>"
 
-#: cp/decl.c:10834
+#: cp/decl.c:10858
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr "định nghĩa hàm được khai báo là %qs"
 
-#: cp/decl.c:10839
+#: cp/decl.c:10863
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %<concept%>"
 msgstr "hủy tử không thể là %<concept%>"
 
-#: cp/decl.c:10845
+#: cp/decl.c:10869
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %<register%>"
 msgstr "định nghĩa hàm được khai báo là %<register%>"
 
-#: cp/decl.c:10849
+#: cp/decl.c:10873
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %<static%>"
 msgstr "định nghĩa hàm được khai báo là %<auto%>"
 
-#: cp/decl.c:10853
+#: cp/decl.c:10877
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %<extern%>"
 msgstr "định nghĩa hàm được khai báo là %<register%>"
 
-#: cp/decl.c:10857
+#: cp/decl.c:10881
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %<mutable%>"
 msgstr "định nghĩa hàm được khai báo là %<auto%>"
 
-#: cp/decl.c:10861
+#: cp/decl.c:10885
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr "định nghĩa hàm được khai báo là %<auto%>"
 
-#: cp/decl.c:10872
+#: cp/decl.c:10896
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr "định nghĩa hàm được khai báo là %qs"
 
-#: cp/decl.c:10875
+#: cp/decl.c:10899
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10906
+#: cp/decl.c:10930
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr ""
 
-#: cp/decl.c:10929
+#: cp/decl.c:10953
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr ""
 
-#: cp/decl.c:10933
+#: cp/decl.c:10957
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr ""
 
-#: cp/decl.c:10946
+#: cp/decl.c:10970
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr ""
 
-#: cp/decl.c:10950
+#: cp/decl.c:10974
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10957
+#: cp/decl.c:10981
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr ""
 
-#: cp/decl.c:10969
+#: cp/decl.c:10993
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr ""
 
-#: cp/decl.c:11050
+#: cp/decl.c:11074
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %q#D"
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "cho khai báo hàm mẫu %q+D"
 
-#: cp/decl.c:11098
+#: cp/decl.c:11122
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.c:11118
+#: cp/decl.c:11142
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.c:11121
+#: cp/decl.c:11145
 #, gcc-internal-format
 msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgstr "kiểu trả về deduced chỉ sẵn sàng với -std=c++14 hay -std=gnu++14"
 
-#: cp/decl.c:11127
+#: cp/decl.c:11151
 #, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr ""
 
-#: cp/decl.c:11134
+#: cp/decl.c:11158
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:11147
+#: cp/decl.c:11171
 #, fuzzy, gcc-internal-format
 msgid "deduced class type %qD in function return type"
 msgstr "kiểu lớp %qT chưa hoàn thiện"
 
-#: cp/decl.c:11156
+#: cp/decl.c:11180
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr ""
 
-#: cp/decl.c:11169
+#: cp/decl.c:11193
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
@@ -42300,306 +42345,306 @@
 
 #. Not using maybe_warn_cpp0x because this should
 #. always be an error.
-#: cp/decl.c:11180
+#: cp/decl.c:11204
 #, gcc-internal-format
 msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/decl.c:11183
+#: cp/decl.c:11207
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.c:11212
+#: cp/decl.c:11236
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr ""
 
-#: cp/decl.c:11218
+#: cp/decl.c:11242
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr ""
 
-#: cp/decl.c:11247
+#: cp/decl.c:11271
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.c:11248
+#: cp/decl.c:11272
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "cấu tử không thể là hàm thành viên tĩnh"
 
-#: cp/decl.c:11252
+#: cp/decl.c:11276
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.c:11253
+#: cp/decl.c:11277
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.c:11261
+#: cp/decl.c:11285
 #, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr ""
 
-#: cp/decl.c:11262
+#: cp/decl.c:11286
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not have parameters"
 msgid "constructors may not be ref-qualified"
 msgstr "hủy tử không được có đối số"
 
-#: cp/decl.c:11280
+#: cp/decl.c:11304
 #, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
 msgstr ""
 
 #. Cannot be both friend and virtual.
-#: cp/decl.c:11295
+#: cp/decl.c:11319
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr ""
 
-#: cp/decl.c:11299
+#: cp/decl.c:11323
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr ""
 
-#: cp/decl.c:11301
+#: cp/decl.c:11325
 #, gcc-internal-format
 msgid "can%'t define friend function %qs in a local class definition"
 msgstr ""
 
-#: cp/decl.c:11313
+#: cp/decl.c:11337
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr ""
 
-#: cp/decl.c:11339
+#: cp/decl.c:11363
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "hủy tử không được có đối số"
 
-#: cp/decl.c:11379
+#: cp/decl.c:11403
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "không thể khai báo con trỏ đến %q#T"
 
-#: cp/decl.c:11392 cp/decl.c:11399
+#: cp/decl.c:11416 cp/decl.c:11423
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "không thể khai báo tham chiếu đến %q#T"
 
-#: cp/decl.c:11401
+#: cp/decl.c:11425
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "không thể khai báo con trỏ cho thành viên %q#T"
 
-#: cp/decl.c:11430
+#: cp/decl.c:11454
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr ""
 
-#: cp/decl.c:11431
+#: cp/decl.c:11455
 #, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr ""
 
-#: cp/decl.c:11504
+#: cp/decl.c:11528
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.c:11574
+#: cp/decl.c:11598
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "template-id %qD được dùng như bộ khai báo"
 
-#: cp/decl.c:11599
+#: cp/decl.c:11623
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr ""
 
-#: cp/decl.c:11605
+#: cp/decl.c:11629
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr ""
 
-#: cp/decl.c:11635
+#: cp/decl.c:11659
 #, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.c:11637
+#: cp/decl.c:11661
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "không thể khai báo tham chiếu đến %q#T"
 
-#: cp/decl.c:11645
+#: cp/decl.c:11669
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.c:11685
+#: cp/decl.c:11709
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr ""
 
-#: cp/decl.c:11693
+#: cp/decl.c:11717
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.c:11695
+#: cp/decl.c:11719
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.c:11706
+#: cp/decl.c:11730
 #, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "%<explicit%> ngoài khai báo lớp"
 
-#: cp/decl.c:11709
+#: cp/decl.c:11733
 #, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr ""
 
-#: cp/decl.c:11712
+#: cp/decl.c:11736
 #, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr ""
 
-#: cp/decl.c:11721
+#: cp/decl.c:11745
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:11726
+#: cp/decl.c:11750
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:11732
+#: cp/decl.c:11756
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:11737
+#: cp/decl.c:11761
 #, gcc-internal-format
 msgid "static %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:11742
+#: cp/decl.c:11766
 #, gcc-internal-format
 msgid "const %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:11747
+#: cp/decl.c:11771
 #, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:11778
+#: cp/decl.c:11802
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "typedef được khai báo %<auto%>"
 
-#: cp/decl.c:11783
+#: cp/decl.c:11807
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.c:11787
+#: cp/decl.c:11811
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr ""
 
-#: cp/decl.c:11813
+#: cp/decl.c:11837
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr ""
 
-#: cp/decl.c:11900
+#: cp/decl.c:11924
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "%<inline%> được chỉ định cho khai báo lớp bạn"
 
-#: cp/decl.c:11908
+#: cp/decl.c:11932
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "các đối số tạm không thể là bạn"
 
-#: cp/decl.c:11910
+#: cp/decl.c:11934
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr ""
 
-#: cp/decl.c:11914
+#: cp/decl.c:11938
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr ""
 
-#: cp/decl.c:11927
+#: cp/decl.c:11951
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr ""
 
-#: cp/decl.c:11947
+#: cp/decl.c:11971
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr ""
 
-#: cp/decl.c:11951
+#: cp/decl.c:11975
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.c:11961
+#: cp/decl.c:11985
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr ""
 
-#: cp/decl.c:11976
+#: cp/decl.c:12000
 #, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr ""
 
-#: cp/decl.c:11995
+#: cp/decl.c:12019
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "không thể dùng %<::%> trong khai báo đối số"
 
-#: cp/decl.c:12001
+#: cp/decl.c:12025
 #, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr ""
 
-#: cp/decl.c:12003
+#: cp/decl.c:12027
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12052 cp/parser.c:3270
+#: cp/decl.c:12076 cp/parser.c:3270
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr ""
 
-#: cp/decl.c:12056
+#: cp/decl.c:12080
 #, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr "thành viên dữ liệu không-tĩnh được khai báo giữ chỗ %qT"
 
-#: cp/decl.c:12080
+#: cp/decl.c:12104
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids zero-size array %qD"
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C++ cấm mảng có kích thước bằng không %qD"
 
-#: cp/decl.c:12083
+#: cp/decl.c:12107
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array members"
@@ -42606,158 +42651,158 @@
 msgstr "ISO C90 không hỗ trợ thành viên mảng linh động"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:12099
+#: cp/decl.c:12123
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "dùng %<::%> không hợp lệ"
 
-#: cp/decl.c:12121
+#: cp/decl.c:12145
 #, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr ""
 
-#: cp/decl.c:12130
+#: cp/decl.c:12154
 #, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "hàm %qD được khai báo %<virtual%> trong một union"
 
-#: cp/decl.c:12139
+#: cp/decl.c:12163
 #, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr ""
 
-#: cp/decl.c:12153
+#: cp/decl.c:12177
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr ""
 
-#: cp/decl.c:12160
+#: cp/decl.c:12184
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "sự khai báo của %qD như là thành viên của %qT"
 
-#: cp/decl.c:12166
+#: cp/decl.c:12190
 #, gcc-internal-format
 msgid "a destructor cannot be %<concept%>"
 msgstr "hủy tử không thể là %<concept%>"
 
-#: cp/decl.c:12171
+#: cp/decl.c:12195
 #, gcc-internal-format
 msgid "a destructor cannot be %<constexpr%>"
 msgstr "hủy tử không thể là %<constexpr%>"
 
-#: cp/decl.c:12177
+#: cp/decl.c:12201
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr ""
 
-#: cp/decl.c:12185
+#: cp/decl.c:12209
 #, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr "cấu tử không thể là %<concept%>"
 
-#: cp/decl.c:12190
+#: cp/decl.c:12214
 #, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr "cấu tử không thể là hàm thành viên tĩnh"
 
-#: cp/decl.c:12199
+#: cp/decl.c:12223
 #, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr ""
 
-#: cp/decl.c:12202
+#: cp/decl.c:12226
 #, gcc-internal-format
 msgid "variable template declared here"
 msgstr ""
 
-#: cp/decl.c:12257
+#: cp/decl.c:12281
 #, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr ""
 
-#: cp/decl.c:12262
+#: cp/decl.c:12286
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr ""
 
-#: cp/decl.c:12272
+#: cp/decl.c:12296
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr ""
 
-#: cp/decl.c:12318
+#: cp/decl.c:12342
 #, gcc-internal-format
 msgid "static data member %qE declared %<concept%>"
 msgstr ""
 
-#: cp/decl.c:12322
+#: cp/decl.c:12346
 #, fuzzy, gcc-internal-format
 #| msgid "  non-static data member %qD has non-literal type"
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "  thành viên dữ liệu không-tĩnh %qD có kiểu không-văn-chương"
 
-#: cp/decl.c:12350
+#: cp/decl.c:12374
 #, gcc-internal-format
 msgid "non-static data member %qE declared %<concept%>"
 msgstr ""
 
-#: cp/decl.c:12354
+#: cp/decl.c:12378
 #, gcc-internal-format
 msgid "non-static data member %qE declared %<constexpr%>"
 msgstr ""
 
-#: cp/decl.c:12409
+#: cp/decl.c:12433
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:12411
+#: cp/decl.c:12435
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:12415
+#: cp/decl.c:12439
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:12418
+#: cp/decl.c:12442
 #, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:12423
+#: cp/decl.c:12447
 #, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr ""
 
-#: cp/decl.c:12434
+#: cp/decl.c:12458
 #, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.c:12438
+#: cp/decl.c:12462
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.c:12446
+#: cp/decl.c:12470
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr ""
 
-#: cp/decl.c:12453
+#: cp/decl.c:12477
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr ""
 
-#: cp/decl.c:12454
+#: cp/decl.c:12478
 #, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr ""
 
-#: cp/decl.c:12489
+#: cp/decl.c:12513
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr ""
@@ -42764,77 +42809,77 @@
 
 #. 7.1.1: There can be no static function declarations within a
 #. block.
-#: cp/decl.c:12497
+#: cp/decl.c:12521
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr ""
 
-#: cp/decl.c:12533
+#: cp/decl.c:12557
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "%<static%> không sử dụng khi định nghĩa (như ngược với khai báo) một thành viên dữ liệu tĩnh"
 
-#: cp/decl.c:12540
+#: cp/decl.c:12564
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr ""
 
-#: cp/decl.c:12546
+#: cp/decl.c:12570
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr ""
 
-#: cp/decl.c:12553
+#: cp/decl.c:12577
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "chưa định nghĩa biến môi trường%qs"
 
-#: cp/decl.c:12574
+#: cp/decl.c:12598
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "khai báo của %q#D chưa có bộ khởi tạo"
 
-#: cp/decl.c:12585
+#: cp/decl.c:12609
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr ""
 
-#: cp/decl.c:12589
+#: cp/decl.c:12613
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr ""
 
-#: cp/decl.c:12754
+#: cp/decl.c:12778
 #, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr ""
 
-#: cp/decl.c:12757
+#: cp/decl.c:12781
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr ""
 
-#: cp/decl.c:12841
+#: cp/decl.c:12865
 #, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:12845
+#: cp/decl.c:12869
 #, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "không thể dùng %<::%> trong khai báo đối số"
 
-#: cp/decl.c:12868
+#: cp/decl.c:12892
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr ""
 
-#: cp/decl.c:12895
+#: cp/decl.c:12919
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.c:12897
+#: cp/decl.c:12921
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr ""
@@ -42854,176 +42899,176 @@
 #. or implicitly defined), there's no need to worry about their
 #. existence.  Theoretically, they should never even be
 #. instantiated, but that's hard to forestall.
-#: cp/decl.c:13150
+#: cp/decl.c:13174
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr ""
 
-#: cp/decl.c:13228
+#: cp/decl.c:13252
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr ""
 
-#: cp/decl.c:13234
+#: cp/decl.c:13258
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD không được khai báo như là tĩnh"
 
-#: cp/decl.c:13261
+#: cp/decl.c:13285
 #, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr ""
 
-#: cp/decl.c:13267
+#: cp/decl.c:13291
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr ""
 
-#: cp/decl.c:13277
+#: cp/decl.c:13301
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr ""
 
 #. 13.4.0.3
-#: cp/decl.c:13303
+#: cp/decl.c:13327
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading operator ?:"
 msgstr ""
 
 #. Variadic.
-#: cp/decl.c:13314
+#: cp/decl.c:13338
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr ""
 
-#: cp/decl.c:13338
+#: cp/decl.c:13362
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly one argument"
 msgid "%qD must have either zero or one argument"
 msgstr "%qD cần chính các là một đối số"
 
-#: cp/decl.c:13339
+#: cp/decl.c:13363
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have either one or two arguments"
 msgstr "%qD cần chính các là hai đối số"
 
-#: cp/decl.c:13350
+#: cp/decl.c:13374
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its argument"
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "postfix %qD phải nhận %<int%> như là đối số của nó"
 
-#: cp/decl.c:13351
+#: cp/decl.c:13375
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its second argument"
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "postfix %qD phải nhận %<int%> như là đối số thứ hai của nó"
 
-#: cp/decl.c:13361
+#: cp/decl.c:13385
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have no arguments"
 msgstr "%qD cần chính các là hai đối số"
 
-#: cp/decl.c:13362 cp/decl.c:13371
+#: cp/decl.c:13386 cp/decl.c:13395
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly one argument"
 msgid "%qD must have exactly one argument"
 msgstr "%qD cần chính các là một đối số"
 
-#: cp/decl.c:13372
+#: cp/decl.c:13396
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have exactly two arguments"
 msgstr "%qD cần chính các là hai đối số"
 
-#: cp/decl.c:13389 cp/decl.c:13392
+#: cp/decl.c:13413 cp/decl.c:13416
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD không thể có đối số mặc định"
 
-#: cp/decl.c:13419
+#: cp/decl.c:13443
 #, gcc-internal-format
 msgid "conversion to a reference to void will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13421
+#: cp/decl.c:13445
 #, gcc-internal-format
 msgid "conversion to void will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13428
+#: cp/decl.c:13452
 #, gcc-internal-format
 msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13430
+#: cp/decl.c:13454
 #, gcc-internal-format
 msgid "conversion to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13438
+#: cp/decl.c:13462
 #, gcc-internal-format
 msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13440
+#: cp/decl.c:13464
 #, gcc-internal-format
 msgid "conversion to a base class will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13455
+#: cp/decl.c:13479
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr ""
 
-#: cp/decl.c:13474
+#: cp/decl.c:13498
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "tiền tố %qD cần trả về %qT"
 
-#: cp/decl.c:13480
+#: cp/decl.c:13504
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "hậu tố %qD cần trả về %qT"
 
-#: cp/decl.c:13492
+#: cp/decl.c:13516
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD cần trả về bằng giá trị"
 
-#: cp/decl.c:13547
+#: cp/decl.c:13571
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr ""
 
-#: cp/decl.c:13570
+#: cp/decl.c:13594
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr ""
 
-#: cp/decl.c:13573
+#: cp/decl.c:13597
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr ""
 
-#: cp/decl.c:13575
+#: cp/decl.c:13599
 #, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr ""
 
-#: cp/decl.c:13583
+#: cp/decl.c:13607
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "%qT được coi là %qs"
 
-#: cp/decl.c:13584 cp/decl.c:13591
+#: cp/decl.c:13608 cp/decl.c:13615
 #, fuzzy, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr "%q+T có một khai báo trước ở đây"
 
-#: cp/decl.c:13590
+#: cp/decl.c:13614
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "%qT được coi là enum"
@@ -43035,94 +43080,94 @@
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:13605
+#: cp/decl.c:13629
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr ""
 
-#: cp/decl.c:13659 cp/name-lookup.c:4652
+#: cp/decl.c:13683 cp/name-lookup.c:4652
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr ""
 
-#: cp/decl.c:13689 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6425
-#: cp/pt.c:9209
+#: cp/decl.c:13713 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6428
+#: cp/pt.c:9223
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT không phải một mẫu"
 
-#: cp/decl.c:13694
+#: cp/decl.c:13718
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:13703 cp/name-lookup.c:4079 cp/name-lookup.c:4086
-#: cp/name-lookup.c:4939 cp/parser.c:6376 cp/parser.c:26300
+#: cp/decl.c:13727 cp/name-lookup.c:4079 cp/name-lookup.c:4086
+#: cp/name-lookup.c:4939 cp/parser.c:6379 cp/parser.c:26297
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr ""
 
-#: cp/decl.c:13806
+#: cp/decl.c:13830
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr ""
 
-#: cp/decl.c:13842
+#: cp/decl.c:13866
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr ""
 
-#: cp/decl.c:13982
+#: cp/decl.c:14006
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr ""
 
-#: cp/decl.c:13989
+#: cp/decl.c:14013
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr "%qT được định nghĩa với cơ sở đa trực tiếp"
 
-#: cp/decl.c:14000
+#: cp/decl.c:14024
 #, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr "%qT được định nghĩa cơ sở trực tiếp ảo"
 
-#: cp/decl.c:14025
+#: cp/decl.c:14049
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr ""
 
-#: cp/decl.c:14055
+#: cp/decl.c:14079
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr ""
 
-#: cp/decl.c:14057
+#: cp/decl.c:14081
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr ""
 
-#: cp/decl.c:14202
+#: cp/decl.c:14226
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14205 cp/decl.c:14213 cp/decl.c:14225 cp/parser.c:18284
+#: cp/decl.c:14229 cp/decl.c:14237 cp/decl.c:14249 cp/parser.c:18281
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "định nghĩa trước ở đây"
 
-#: cp/decl.c:14210
+#: cp/decl.c:14234
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14222
+#: cp/decl.c:14246
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14300
+#: cp/decl.c:14324
 #, fuzzy, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr "đối số %d của %qE phải là một địa chỉ"
@@ -43131,78 +43176,78 @@
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:14447
+#: cp/decl.c:14471
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr ""
 
-#: cp/decl.c:14619
+#: cp/decl.c:14643
 #, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr ""
 
-#: cp/decl.c:14629
+#: cp/decl.c:14653
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr ""
 
-#: cp/decl.c:14678
+#: cp/decl.c:14702
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr ""
 
-#: cp/decl.c:14679
+#: cp/decl.c:14703
 #, fuzzy, gcc-internal-format
 #| msgid "increment of enumeration value is invalid in C++"
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "phép gia tăng giá trị kiểu liệt kê là không hợp lệ trong C++"
 
-#: cp/decl.c:14690
+#: cp/decl.c:14714
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr ""
 
-#: cp/decl.c:14710
+#: cp/decl.c:14734
 #, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr ""
 
-#: cp/decl.c:14821
+#: cp/decl.c:14845
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "kiểu trả về %q#T là một kiểu không hoàn toàn"
 
-#: cp/decl.c:14999 cp/typeck.c:9286
+#: cp/decl.c:15023 cp/typeck.c:9286
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> cần trả về một tham chiếu đến %<*this%>"
 
-#: cp/decl.c:15344
+#: cp/decl.c:15368
 #, gcc-internal-format
 msgid "invalid function declaration"
 msgstr "khai báo hàm không hợp lệ"
 
-#: cp/decl.c:15786
+#: cp/decl.c:15810
 #, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr ""
 
-#: cp/decl.c:15788 cp/typeck.c:9166
+#: cp/decl.c:15812 cp/typeck.c:9166
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr ""
 
-#: cp/decl.c:15996
+#: cp/decl.c:16020
 #, gcc-internal-format
 msgid "invalid member function declaration"
 msgstr "khai báo hàm thành viên không hợp lệ"
 
-#: cp/decl.c:16010
+#: cp/decl.c:16034
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD đã sẵn định nghĩa trong %qT"
 
-#: cp/decl.c:16386
+#: cp/decl.c:16410
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -43242,7 +43287,7 @@
 msgid "deleting %qT is undefined"
 msgstr ""
 
-#: cp/decl2.c:585 cp/pt.c:5552
+#: cp/decl2.c:585 cp/pt.c:5566
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "cho khai báo hàm mẫu %q+D"
@@ -43255,7 +43300,7 @@
 #. [temp.mem]
 #.
 #. A destructor shall not be a member template.
-#: cp/decl2.c:640 cp/pt.c:5511
+#: cp/decl2.c:640 cp/pt.c:5525
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr ""
@@ -43432,47 +43477,47 @@
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "%<operator delete%> nhận kiểu %qT như là đối số thứ nhất"
 
-#: cp/decl2.c:2660
+#: cp/decl2.c:2650
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2664
+#: cp/decl2.c:2654
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2669
+#: cp/decl2.c:2659
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2677
+#: cp/decl2.c:2667
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr ""
 
-#: cp/decl2.c:2695
+#: cp/decl2.c:2685
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2699
+#: cp/decl2.c:2689
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2704
+#: cp/decl2.c:2694
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2711
+#: cp/decl2.c:2701
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr ""
 
-#: cp/decl2.c:4309
+#: cp/decl2.c:4299
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using unnamed type, is used but never defined"
 msgstr "hàm chung dòng %qD được dùng nhưng chưa bao giờ được định nghĩa"
@@ -43481,64 +43526,64 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4318
+#: cp/decl2.c:4308
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4322
+#: cp/decl2.c:4312
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4326
+#: cp/decl2.c:4316
 #, gcc-internal-format
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr ""
 
-#: cp/decl2.c:4334
+#: cp/decl2.c:4324
 #, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr ""
 
-#: cp/decl2.c:4338
+#: cp/decl2.c:4328
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4341
+#: cp/decl2.c:4331
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4529
+#: cp/decl2.c:4519
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D conflicts with a previous declaration"
 msgid "mangling of %q#D as %qE conflicts with a previous mangle"
 msgstr "%q#D xung đột với khai báo trước"
 
-#: cp/decl2.c:4532
+#: cp/decl2.c:4522
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q#D"
 msgid "previous mangling %q#D"
 msgstr "khai báo trước đây %q#D"
 
-#: cp/decl2.c:4534
+#: cp/decl2.c:4524
 #, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr ""
 
-#: cp/decl2.c:4606 cp/decl2.c:4609
+#: cp/decl2.c:4596 cp/decl2.c:4599
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.c:4956
+#: cp/decl2.c:4946
 #, gcc-internal-format
 msgid "inline function %qD used but never defined"
 msgstr "hàm chung dòng %qD được dùng nhưng chưa bao giờ được định nghĩa"
 
-#: cp/decl2.c:5143
+#: cp/decl2.c:5133
 #, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr ""
@@ -43545,18 +43590,18 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5251
+#: cp/decl2.c:5241
 #, fuzzy, gcc-internal-format
 #| msgid "converting far pointer to near pointer"
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr "không thể chuyển đổi thành kiểu con trỏ"
 
-#: cp/decl2.c:5254
+#: cp/decl2.c:5244
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "dùng hàm bị xóa %qD"
 
-#: cp/decl2.c:5307
+#: cp/decl2.c:5297
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr ""
@@ -43844,334 +43889,334 @@
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr "định nghĩa lại của đối số mặc định của %q#D"
 
-#: cp/init.c:613
+#: cp/init.c:629
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr ""
 
-#: cp/init.c:615
+#: cp/init.c:631
 #, fuzzy, gcc-internal-format
 #| msgid "union defined here"
 msgid "defined here"
 msgstr "union được định nghĩa ở đây"
 
-#: cp/init.c:673
+#: cp/init.c:689
 #, fuzzy, gcc-internal-format
 msgid "initializer for flexible array member %q#D"
 msgstr "đã khởi tạo một bộ phận mảng dẻo"
 
-#: cp/init.c:699
+#: cp/init.c:715
 #, gcc-internal-format
 msgid "%qD should be initialized in the member initialization list"
 msgstr ""
 
-#: cp/init.c:720
+#: cp/init.c:736
 #, gcc-internal-format
 msgid "%qD is initialized with itself"
 msgstr "%qD được khởi tạo bằng chính nó"
 
-#: cp/init.c:831
+#: cp/init.c:847
 #, gcc-internal-format
 msgid "invalid initializer for array member %q#D"
 msgstr ""
 
-#: cp/init.c:845 cp/init.c:869 cp/init.c:2410 cp/method.c:1368
+#: cp/init.c:861 cp/init.c:885 cp/init.c:2427 cp/method.c:1368
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr ""
 
-#: cp/init.c:847 cp/init.c:864 cp/init.c:871 cp/init.c:2395 cp/init.c:2423
+#: cp/init.c:863 cp/init.c:880 cp/init.c:887 cp/init.c:2412 cp/init.c:2440
 #: cp/method.c:1371 cp/method.c:1382
 #, gcc-internal-format
 msgid "%q#D should be initialized"
 msgstr "%q#D nên được khởi tạo"
 
-#: cp/init.c:862 cp/init.c:2382 cp/method.c:1379
+#: cp/init.c:878 cp/init.c:2399 cp/method.c:1379
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr ""
 
-#: cp/init.c:1041
+#: cp/init.c:1057
 #, gcc-internal-format
 msgid "%qD will be initialized after"
 msgstr "%qD sẽ được khởi tạo sau"
 
-#: cp/init.c:1044
+#: cp/init.c:1060
 #, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr ""
 
-#: cp/init.c:1048
+#: cp/init.c:1064
 #, gcc-internal-format
 msgid "  %q#D"
 msgstr "  %q#D"
 
-#: cp/init.c:1050
+#: cp/init.c:1066
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr "  cơ sở %qT"
 
-#: cp/init.c:1052
+#: cp/init.c:1068
 #, gcc-internal-format
 msgid "  when initialized here"
 msgstr "  khi khởi tạo ở đây"
 
-#: cp/init.c:1069
+#: cp/init.c:1085
 #, gcc-internal-format
 msgid "multiple initializations given for %qD"
 msgstr ""
 
-#: cp/init.c:1073
+#: cp/init.c:1089
 #, gcc-internal-format
 msgid "multiple initializations given for base %qT"
 msgstr ""
 
-#: cp/init.c:1158
+#: cp/init.c:1174
 #, gcc-internal-format
 msgid "initializations for multiple members of %qT"
 msgstr ""
 
-#: cp/init.c:1255
+#: cp/init.c:1271
 #, gcc-internal-format
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr ""
 
-#: cp/init.c:1482 cp/init.c:1501
+#: cp/init.c:1498 cp/init.c:1517
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr ""
 
-#: cp/init.c:1488
+#: cp/init.c:1504
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr ""
 
-#: cp/init.c:1495
+#: cp/init.c:1511
 #, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr ""
 
-#: cp/init.c:1534
+#: cp/init.c:1550
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr ""
 
-#: cp/init.c:1542
+#: cp/init.c:1558
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr ""
 
-#: cp/init.c:1589
+#: cp/init.c:1605
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr ""
 
-#: cp/init.c:1597
+#: cp/init.c:1613
 #, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr ""
 
-#: cp/init.c:1600
+#: cp/init.c:1616
 #, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr "kiểu %qT không là cơ sở trực tiếp của %qT"
 
-#: cp/init.c:1710 cp/init.c:4386 cp/typeck2.c:1175
+#: cp/init.c:1727 cp/init.c:4402 cp/typeck2.c:1175
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
 
-#: cp/init.c:2019 cp/semantics.c:3268
+#: cp/init.c:2036 cp/semantics.c:3271
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qT không phải là kiểu lớp"
 
-#: cp/init.c:2075
+#: cp/init.c:2092
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr ""
 
-#: cp/init.c:2089
+#: cp/init.c:2106
 #, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr "con trỏ cho trường bít %qD không hợp lệ"
 
-#: cp/init.c:2175 cp/typeck.c:1893
+#: cp/init.c:2192 cp/typeck.c:1893
 #, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr ""
 
-#: cp/init.c:2182 cp/semantics.c:1835
+#: cp/init.c:2199 cp/semantics.c:1835
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr ""
 
-#: cp/init.c:2379
+#: cp/init.c:2396
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2387
+#: cp/init.c:2404
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2391
+#: cp/init.c:2408
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr ""
 
-#: cp/init.c:2407
+#: cp/init.c:2424
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2415
+#: cp/init.c:2432
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2419
+#: cp/init.c:2436
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr ""
 
-#: cp/init.c:2710
+#: cp/init.c:2727
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2721
+#: cp/init.c:2738
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2732
+#: cp/init.c:2749
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2880
+#: cp/init.c:2896
 #, gcc-internal-format
 msgid "integer overflow in array size"
 msgstr "tràn số nguyên trong kích thước mảng"
 
-#: cp/init.c:2890
+#: cp/init.c:2906
 #, gcc-internal-format
 msgid "array size in new-expression must be constant"
 msgstr ""
 
-#: cp/init.c:2904
+#: cp/init.c:2920
 #, gcc-internal-format
 msgid "variably modified type not allowed in new-expression"
 msgstr ""
 
-#: cp/init.c:2920
+#: cp/init.c:2936
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by typedef"
 msgstr ""
 
-#: cp/init.c:2922
+#: cp/init.c:2938
 #, gcc-internal-format
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr ""
 
-#: cp/init.c:2932
+#: cp/init.c:2948
 #, gcc-internal-format
 msgid "invalid type %<void%> for new"
 msgstr "kiểu không hợp lệ %<void%> cho new"
 
-#: cp/init.c:2975
+#: cp/init.c:2991
 #, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr ""
 
-#: cp/init.c:3101
+#: cp/init.c:3117
 #, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr ""
 
-#: cp/init.c:3108 cp/search.c:1023
+#: cp/init.c:3124 cp/search.c:1026
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr ""
 
-#: cp/init.c:3181
+#: cp/init.c:3197
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr ""
 
-#: cp/init.c:3184
+#: cp/init.c:3200
 #, gcc-internal-format
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr ""
 
-#: cp/init.c:3187
+#: cp/init.c:3203
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr ""
 
-#: cp/init.c:3370
+#: cp/init.c:3386
 #, gcc-internal-format
 msgid "parenthesized initializer in array new"
 msgstr ""
 
-#: cp/init.c:3633
+#: cp/init.c:3649
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr ""
 
-#: cp/init.c:3665
+#: cp/init.c:3681
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr ""
 
-#: cp/init.c:3674
+#: cp/init.c:3690
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr ""
 
-#: cp/init.c:3743
+#: cp/init.c:3759
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete [] operator:"
 msgstr ""
 
-#: cp/init.c:3747
+#: cp/init.c:3763
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete [] will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4295
+#: cp/init.c:4311
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "bộ khởi tạo kết thúc bất ngờ"
 
-#: cp/init.c:4599
+#: cp/init.c:4615
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr ""
 
-#: cp/init.c:4623
+#: cp/init.c:4639
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete operator:"
 msgstr ""
 
-#: cp/init.c:4628
+#: cp/init.c:4644
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4642
+#: cp/init.c:4658
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4647
+#: cp/init.c:4663
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4954
+#: cp/init.c:4970
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr ""
@@ -44655,7 +44700,7 @@
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr ""
 
-#: cp/name-lookup.c:5111 cp/name-lookup.c:7065
+#: cp/name-lookup.c:5111 cp/name-lookup.c:7073
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr ""
@@ -44703,56 +44748,56 @@
 msgid "it was later defined here"
 msgstr "struct được định nghĩa ở đây"
 
-#: cp/name-lookup.c:6687
+#: cp/name-lookup.c:6695
 #, gcc-internal-format
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn't a template"
 msgstr ""
 
-#: cp/name-lookup.c:7059
+#: cp/name-lookup.c:7067
 #, fuzzy, gcc-internal-format
 #| msgid "switch %qs is no longer supported"
 msgid "strong using directive no longer supported"
 msgstr "switch %qs không còn tiếp tục được hỗ trợ nữa"
 
-#: cp/name-lookup.c:7062
+#: cp/name-lookup.c:7070
 #, gcc-internal-format
 msgid "you may use an inline namespace instead"
 msgstr ""
 
-#: cp/name-lookup.c:7079
+#: cp/name-lookup.c:7087
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on types"
 msgid "attributes ignored on local using directive"
 msgstr "Thuộc tính %qE bị lờ đi với các kiểu"
 
-#: cp/name-lookup.c:7163
+#: cp/name-lookup.c:7171
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr ""
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:7183
+#: cp/name-lookup.c:7191
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot nest more than %d namespaces"
 msgstr ""
 
-#: cp/name-lookup.c:7218
+#: cp/name-lookup.c:7226
 #, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr ""
 
-#: cp/name-lookup.c:7219
+#: cp/name-lookup.c:7227
 #, fuzzy, gcc-internal-format
 #| msgid "label %qD defined here"
 msgid "%qD defined here"
 msgstr "nhãn %qD được định nghĩa ở đây"
 
-#: cp/name-lookup.c:7292
+#: cp/name-lookup.c:7300
 #, gcc-internal-format
 msgid "XXX entering pop_everything ()\n"
 msgstr "XXX vào pop_everything ()\n"
 
-#: cp/name-lookup.c:7301
+#: cp/name-lookup.c:7309
 #, gcc-internal-format
 msgid "XXX leaving pop_everything ()\n"
 msgstr "XXX rời bỏ pop_everything ()\n"
@@ -44772,7 +44817,7 @@
 msgid "LEXER_DEBUGGING_ENABLED_P is not set to true"
 msgstr ""
 
-#: cp/parser.c:1352 cp/parser.c:37254
+#: cp/parser.c:1352 cp/parser.c:37251
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -44797,7 +44842,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr ""
 
-#: cp/parser.c:2949 cp/parser.c:18221
+#: cp/parser.c:2949 cp/parser.c:18218
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "%<%T::%E%> chưa được khai báo"
@@ -44877,7 +44922,7 @@
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "cú gọi hàm không được xuất hiện trong biểu thức hằng"
 
-#: cp/parser.c:3143 cp/pt.c:17853
+#: cp/parser.c:3143 cp/pt.c:17890
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr ""
@@ -45100,7 +45145,7 @@
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr ""
 
-#: cp/parser.c:4587 cp/parser.c:12940
+#: cp/parser.c:4587 cp/parser.c:12937
 #, gcc-internal-format
 msgid "expected declaration"
 msgstr "cần khai báo"
@@ -45151,7 +45196,7 @@
 msgid "fold-expressions only available with -std=c++17 or -std=gnu++17"
 msgstr "fold-expressions chỉ sẵn sàng với -std=c++1z hay -std=gnu++1z"
 
-#: cp/parser.c:5275 cp/parser.c:5452 cp/parser.c:5630 cp/semantics.c:3612
+#: cp/parser.c:5275 cp/parser.c:5452 cp/parser.c:5633 cp/semantics.c:3615
 #, gcc-internal-format
 msgid "expected primary-expression"
 msgstr "cần biểu thức cơ bản"
@@ -45171,92 +45216,92 @@
 msgid "local variable %qD may not appear in this context"
 msgstr ""
 
-#: cp/parser.c:5787
+#: cp/parser.c:5790
 #, gcc-internal-format
 msgid "expected id-expression"
 msgstr "cần id-expression"
 
-#: cp/parser.c:5919
+#: cp/parser.c:5922
 #, gcc-internal-format
 msgid "scope %qT before %<~%> is not a class-name"
 msgstr ""
 
-#: cp/parser.c:5948 cp/parser.c:7860
+#: cp/parser.c:5951 cp/parser.c:7860
 #, gcc-internal-format
 msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgstr "%<~auto%> chỉ sẵn sàng trên -std=c++14 hay -std=gnu++14"
 
-#: cp/parser.c:6059
+#: cp/parser.c:6062
 #, gcc-internal-format
 msgid "declaration of %<~%T%> as member of %qT"
 msgstr "phần khai báo của %<~%T%> là thành viên của %qT"
 
-#: cp/parser.c:6074
+#: cp/parser.c:6077
 #, gcc-internal-format
 msgid "typedef-name %qD used as destructor declarator"
 msgstr ""
 
-#: cp/parser.c:6111 cp/parser.c:20249
+#: cp/parser.c:6114 cp/parser.c:20246
 #, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr "cần unqualified-id"
 
-#: cp/parser.c:6220
+#: cp/parser.c:6223
 #, gcc-internal-format
 msgid "found %<:%> in nested-name-specifier, expected %<::%>"
 msgstr ""
 
-#: cp/parser.c:6288
+#: cp/parser.c:6291
 #, gcc-internal-format
 msgid "decltype evaluates to %qT, which is not a class or enumeration type"
 msgstr ""
 
-#: cp/parser.c:6314
+#: cp/parser.c:6317
 #, gcc-internal-format
 msgid "function template-id %qD in nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:6322
+#: cp/parser.c:6325
 #, gcc-internal-format
 msgid "variable template-id %qD in nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:6426 cp/typeck.c:2684 cp/typeck.c:2687 cp/typeck.c:2704
+#: cp/parser.c:6429 cp/typeck.c:2684 cp/typeck.c:2687 cp/typeck.c:2704
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD không phải một mẫu"
 
-#: cp/parser.c:6504
+#: cp/parser.c:6507
 #, gcc-internal-format
 msgid "expected nested-name-specifier"
 msgstr "cần nested-name-specifier"
 
-#: cp/parser.c:6711 cp/parser.c:8950
+#: cp/parser.c:6714 cp/parser.c:8950
 #, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr "các kiểu có lẽ không nên được định nghĩa trong áp kiểu"
 
-#: cp/parser.c:6797
+#: cp/parser.c:6800
 #, gcc-internal-format
 msgid "types may not be defined in a %<typeid%> expression"
 msgstr ""
 
-#: cp/parser.c:6889
+#: cp/parser.c:6892
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "sai số tham số cho %<__builtin_addressof%>"
 
-#: cp/parser.c:6901 cp/pt.c:18416
+#: cp/parser.c:6904 cp/pt.c:18453
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "đối số sai số lượng cho %<__builtin_launder%>"
 
-#: cp/parser.c:6995
+#: cp/parser.c:6998
 #, gcc-internal-format
 msgid "ISO C++ forbids compound-literals"
 msgstr "ISO C++ cấm compound-literals"
 
-#: cp/parser.c:7054
+#: cp/parser.c:7057
 #, gcc-internal-format
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
@@ -45390,7 +45435,7 @@
 msgid "capture of non-variable %qE"
 msgstr "trùng biến minh dụ %q+D"
 
-#: cp/parser.c:10391 cp/parser.c:10401 cp/semantics.c:3453 cp/semantics.c:3465
+#: cp/parser.c:10391 cp/parser.c:10401 cp/semantics.c:3456 cp/semantics.c:3468
 #, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "%q#D được khai báo ở đây"
@@ -45476,7 +45521,7 @@
 msgid "init-statement in selection statements only available with -std=c++17 or -std=gnu++17"
 msgstr "định nghĩa namespaces lồng nhau chỉ sẵn sàng với -std=c++1z hay -std=gnu++1z"
 
-#: cp/parser.c:11546 cp/parser.c:28490
+#: cp/parser.c:11546 cp/parser.c:28487
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "cần selection-statement"
@@ -45496,563 +45541,563 @@
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:12250 cp/parser.c:28493
+#: cp/parser.c:12250 cp/parser.c:28490
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "cần iteration-statement"
 
-#: cp/parser.c:12298
+#: cp/parser.c:12297
 #, gcc-internal-format
 msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
 msgstr "vòng lặp range-based %<for%> chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/parser.c:12426
+#: cp/parser.c:12423
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr ""
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:12434
+#: cp/parser.c:12431
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ cấm tính toán gotos"
 
-#: cp/parser.c:12447 cp/parser.c:28496
+#: cp/parser.c:12444 cp/parser.c:28493
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "cần jump-statement"
 
-#: cp/parser.c:12620 cp/parser.c:23584
+#: cp/parser.c:12617 cp/parser.c:23581
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "%<;%> mở rộng"
 
-#: cp/parser.c:12863
+#: cp/parser.c:12860
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr "%<__label__%> không ở đầu của một khối"
 
-#: cp/parser.c:13083
+#: cp/parser.c:13080
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:13103
+#: cp/parser.c:13100
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr ""
 
-#: cp/parser.c:13124
+#: cp/parser.c:13121
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr ""
 
-#: cp/parser.c:13148
+#: cp/parser.c:13145
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr "các kiểu có lẽ không nên được định nghĩa trong áp kiểu"
 
-#: cp/parser.c:13203
+#: cp/parser.c:13200
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13206
+#: cp/parser.c:13203
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13257
+#: cp/parser.c:13254
 #, fuzzy, gcc-internal-format
 msgid "structured bindings only available with -std=c++17 or -std=gnu++17"
 msgstr "mẫu biến chỉ sẵn sàng với -std=c++14 hay -std=gnu++14"
 
-#: cp/parser.c:13306
+#: cp/parser.c:13303
 #, fuzzy, gcc-internal-format
 msgid "empty structured binding declaration"
 msgstr "khai báo trống rỗng"
 
-#: cp/parser.c:13324
+#: cp/parser.c:13321
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member function declaration"
 msgid "invalid initializer for structured binding declaration"
 msgstr "khai báo hàm thành viên không hợp lệ"
 
-#: cp/parser.c:13491
+#: cp/parser.c:13488
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr "%<friend%> được dùng bên ngoài lớp"
 
-#: cp/parser.c:13558
+#: cp/parser.c:13555
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr "%<auto%> thay đổi ý nghĩa trong C++11; hãy bỏ nó đi"
 
-#: cp/parser.c:13594
+#: cp/parser.c:13591
 #, gcc-internal-format
 msgid "decl-specifier invalid in condition"
 msgstr ""
 
-#: cp/parser.c:13600
+#: cp/parser.c:13597
 #, gcc-internal-format
 msgid "%qD invalid in lambda"
 msgstr "%qD không hợp lệ trong lambda"
 
-#: cp/parser.c:13693
+#: cp/parser.c:13690
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr ""
 
-#: cp/parser.c:13763 cp/parser.c:24064
+#: cp/parser.c:13760 cp/parser.c:24061
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr "các mẫu không thể là %<virtual%>"
 
-#: cp/parser.c:13805
+#: cp/parser.c:13802
 #, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr "đặc tả linkage không hợp lệ"
 
-#: cp/parser.c:13909
+#: cp/parser.c:13906
 #, fuzzy, gcc-internal-format
 #| msgid "static_assert without a message only available with -std=c++1z or -std=gnu++1z"
 msgid "static_assert without a message only available with -std=c++17 or -std=gnu++17"
 msgstr "static_assert không có lời nhắn chỉ sẵn sàng với -std=c++1z hay -std=gnu++1z"
 
-#: cp/parser.c:14111
+#: cp/parser.c:14108
 #, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr ""
 
-#: cp/parser.c:14264
+#: cp/parser.c:14261
 #, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr ""
 
-#: cp/parser.c:14291
+#: cp/parser.c:14288
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr ""
 
-#: cp/parser.c:14295
+#: cp/parser.c:14292
 #, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr ""
 
-#: cp/parser.c:14379
+#: cp/parser.c:14376
 #, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr ""
 
-#: cp/parser.c:14406
+#: cp/parser.c:14403
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "cannot expand initializer for member %qD"
 msgstr "thiếu bộ khởi tạo cho thành viên %qD"
 
-#: cp/parser.c:14418 cp/pt.c:24255
+#: cp/parser.c:14415 cp/pt.c:24333
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr ""
 
-#: cp/parser.c:14430 cp/pt.c:24267
+#: cp/parser.c:14427 cp/pt.c:24345
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
 
-#: cp/parser.c:14482
+#: cp/parser.c:14479
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr ""
 
-#: cp/parser.c:14552
+#: cp/parser.c:14549
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:14927
+#: cp/parser.c:14924
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr ""
 
-#: cp/parser.c:14933
+#: cp/parser.c:14930
 #, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr "cần định danh hậu tố"
 
-#: cp/parser.c:14942
+#: cp/parser.c:14939
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr ""
 
-#: cp/parser.c:14948
+#: cp/parser.c:14945
 #, gcc-internal-format
 msgid "invalid encoding prefix in literal operator"
 msgstr ""
 
-#: cp/parser.c:14975
+#: cp/parser.c:14972
 #, gcc-internal-format
 msgid "expected operator"
 msgstr "cần toán tử"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:15020
+#: cp/parser.c:15017
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr ""
 
-#: cp/parser.c:15190
+#: cp/parser.c:15187
 #, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr ""
 
-#: cp/parser.c:15198
+#: cp/parser.c:15195
 #, gcc-internal-format
 msgid "cv-qualified type parameter"
 msgstr ""
 
-#: cp/parser.c:15283
+#: cp/parser.c:15280
 #, gcc-internal-format
 msgid "variadic constraint introduced without %<...%>"
 msgstr ""
 
-#: cp/parser.c:15347
+#: cp/parser.c:15344
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "dùng %<auto%> không hợp lệ trong đối số mẫu mặc định"
 
-#: cp/parser.c:15582 cp/parser.c:15668 cp/parser.c:21694
+#: cp/parser.c:15579 cp/parser.c:15665 cp/parser.c:21691
 #, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:15586 cp/parser.c:15672
+#: cp/parser.c:15583 cp/parser.c:15669
 #, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr ""
 
-#: cp/parser.c:15738
+#: cp/parser.c:15735
 #, gcc-internal-format
 msgid "expected template-id"
 msgstr "cần template-id"
 
-#: cp/parser.c:15798
+#: cp/parser.c:15795
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr ""
 
-#: cp/parser.c:15802
+#: cp/parser.c:15799
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr ""
 
-#: cp/parser.c:15806
+#: cp/parser.c:15803
 #, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr ""
 
-#: cp/parser.c:15924
+#: cp/parser.c:15921
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr ""
 
 #. The name does not name a template.
-#: cp/parser.c:15992 cp/parser.c:16122 cp/parser.c:16337
+#: cp/parser.c:15989 cp/parser.c:16119 cp/parser.c:16334
 #, gcc-internal-format
 msgid "expected template-name"
 msgstr "cần template-name"
 
 #. Explain what went wrong.
-#: cp/parser.c:16038
+#: cp/parser.c:16035
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr ""
 
-#: cp/parser.c:16040
+#: cp/parser.c:16037
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr ""
 
-#: cp/parser.c:16189
+#: cp/parser.c:16186
 #, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr ""
 
-#: cp/parser.c:16298 cp/parser.c:16316 cp/parser.c:16483
+#: cp/parser.c:16295 cp/parser.c:16313 cp/parser.c:16480
 #, gcc-internal-format
 msgid "expected template-argument"
 msgstr "cần template-argument"
 
-#: cp/parser.c:16458
+#: cp/parser.c:16455
 #, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr ""
 
-#: cp/parser.c:16585
+#: cp/parser.c:16582
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr ""
 
-#: cp/parser.c:16589
+#: cp/parser.c:16586
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr ""
 
-#: cp/parser.c:16648
+#: cp/parser.c:16645
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr ""
 
-#: cp/parser.c:16869
+#: cp/parser.c:16866
 #, gcc-internal-format
 msgid "expected type specifier"
 msgstr "cần bộ chỉ định kiểu"
 
-#: cp/parser.c:17053
+#: cp/parser.c:17050
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:17059
+#: cp/parser.c:17056
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "việc dùng %<auto%> trong khai báo tham số chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/parser.c:17064
+#: cp/parser.c:17061
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgid "use of %<auto%> in parameter declaration only available with -fconcepts"
 msgstr "việc dùng %<auto%> trong khai báo tham số chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/parser.c:17209
+#: cp/parser.c:17206
 #, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "cần template-id cho kiểu"
 
-#: cp/parser.c:17278
+#: cp/parser.c:17275
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr "cần type-name (tên kiểu)"
 
-#: cp/parser.c:17631
+#: cp/parser.c:17628
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr ""
 
-#: cp/parser.c:17854
+#: cp/parser.c:17851
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr ""
 
-#: cp/parser.c:17942
+#: cp/parser.c:17939
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr ""
 
-#: cp/parser.c:17946
+#: cp/parser.c:17943
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr ""
 
-#: cp/parser.c:17951
+#: cp/parser.c:17948
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr ""
 
-#: cp/parser.c:18085
+#: cp/parser.c:18082
 #, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "%qD là một mẫu liệt kê"
 
-#: cp/parser.c:18096
+#: cp/parser.c:18093
 #, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr "%qD không phải tên một kiểu enumeration trong %qT"
 
-#: cp/parser.c:18111
+#: cp/parser.c:18108
 #, gcc-internal-format
 msgid "unnamed scoped enum is not allowed"
 msgstr ""
 
-#: cp/parser.c:18166
+#: cp/parser.c:18163
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "cần %<;%> hoặc %<{%>"
 
-#: cp/parser.c:18215
+#: cp/parser.c:18212
 #, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr ""
 
-#: cp/parser.c:18229
+#: cp/parser.c:18226
 #, gcc-internal-format
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr ""
 
-#: cp/parser.c:18241 cp/parser.c:23070
+#: cp/parser.c:18238 cp/parser.c:23067
 #, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr ""
 
-#: cp/parser.c:18246 cp/parser.c:23075
+#: cp/parser.c:18243 cp/parser.c:23072
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr ""
 
-#: cp/parser.c:18258 cp/parser.c:23089
+#: cp/parser.c:18255 cp/parser.c:23086
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr "không cho phép từ hạn định mở rộng"
 
-#: cp/parser.c:18282
+#: cp/parser.c:18279
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "nhiều định nghĩa cho %q#T"
 
-#: cp/parser.c:18295
+#: cp/parser.c:18292
 #, gcc-internal-format
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO C++ cấm kiểu liệt kê nặc danh không tên trống rỗng"
 
-#: cp/parser.c:18315
+#: cp/parser.c:18312
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:18318
+#: cp/parser.c:18315
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:18497
+#: cp/parser.c:18494
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD không là một namespace-name"
 
-#: cp/parser.c:18503
+#: cp/parser.c:18500
 #, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "cần namespace-name"
 
-#: cp/parser.c:18570
+#: cp/parser.c:18567
 #, fuzzy, gcc-internal-format
 #| msgid "nested namespace definitions only available with -std=c++1z or -std=gnu++1z"
 msgid "nested namespace definitions only available with -std=c++17 or -std=gnu++17"
 msgstr "định nghĩa namespaces lồng nhau chỉ sẵn sàng với -std=c++1z hay -std=gnu++1z"
 
-#: cp/parser.c:18578
+#: cp/parser.c:18575
 #, fuzzy, gcc-internal-format
 #| msgid "expected namespace-name"
 msgid "nested namespace name required"
 msgstr "cần namespace-name"
 
-#: cp/parser.c:18583
+#: cp/parser.c:18580
 #, gcc-internal-format
 msgid "namespace name required"
 msgstr ""
 
-#: cp/parser.c:18587
+#: cp/parser.c:18584
 #, gcc-internal-format
 msgid "a nested namespace definition cannot have attributes"
 msgstr ""
 
-#: cp/parser.c:18590
+#: cp/parser.c:18587
 #, gcc-internal-format
 msgid "a nested namespace definition cannot be inline"
 msgstr ""
 
-#: cp/parser.c:18597
+#: cp/parser.c:18594
 #, gcc-internal-format
 msgid "namespace %qD entered"
 msgstr ""
 
-#: cp/parser.c:18652
+#: cp/parser.c:18649
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "%<namespace%> không cho phép định nghĩa ở đây"
 
-#: cp/parser.c:18803
+#: cp/parser.c:18800
 #, fuzzy, gcc-internal-format
 msgid "pack expansion in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr "fold-expressions chỉ sẵn sàng với -std=c++1z hay -std=gnu++1z"
 
-#: cp/parser.c:18818
+#: cp/parser.c:18815
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr ""
 
-#: cp/parser.c:18865
+#: cp/parser.c:18862
 #, fuzzy, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr "fold-expressions chỉ sẵn sàng với -std=c++1z hay -std=gnu++1z"
 
-#: cp/parser.c:18875
+#: cp/parser.c:18872
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:18940
+#: cp/parser.c:18937
 #, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr ""
 
-#: cp/parser.c:19106
+#: cp/parser.c:19103
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:19493
+#: cp/parser.c:19490
 #, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "không cho phép định nghĩa hàm tại đây"
 
-#: cp/parser.c:19504
+#: cp/parser.c:19501
 #, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr ""
 
-#: cp/parser.c:19508
+#: cp/parser.c:19505
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr ""
 
-#: cp/parser.c:19559
+#: cp/parser.c:19556
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
 #. Anything else is an error.
-#: cp/parser.c:19598 cp/parser.c:21906
+#: cp/parser.c:19595 cp/parser.c:21903
 #, gcc-internal-format
 msgid "expected initializer"
 msgstr "cần bộ khởi tạo"
 
-#: cp/parser.c:19679
+#: cp/parser.c:19676
 #, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "bộ khởi tạo được cung cấp cho hàm"
 
-#: cp/parser.c:19713
+#: cp/parser.c:19710
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr ""
 
-#: cp/parser.c:19727
+#: cp/parser.c:19724
 #, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr ""
 
-#: cp/parser.c:20169
+#: cp/parser.c:20166
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr ""
 
-#: cp/parser.c:20295
+#: cp/parser.c:20292
 #, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr ""
 
-#: cp/parser.c:20299
+#: cp/parser.c:20296
 #, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "%<%T::%E%> không phải một kiểu"
@@ -46061,17 +46106,17 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:20328
+#: cp/parser.c:20325
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr "bộ khai báo không hợp lệ"
 
-#: cp/parser.c:20336
+#: cp/parser.c:20333
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "dùng cấu tử như là một mẫu là không hợp lệ"
 
-#: cp/parser.c:20338
+#: cp/parser.c:20335
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr "dùng %<%T::%D%> thay cho %<%T::%D%> cho tên của cấu tử trong tên hạn định"
@@ -46078,387 +46123,387 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:20410
+#: cp/parser.c:20407
 #, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr "mã hạn định trong khai báo"
 
-#: cp/parser.c:20435
+#: cp/parser.c:20432
 #, gcc-internal-format
 msgid "expected declarator"
 msgstr "cần câu khai báo"
 
-#: cp/parser.c:20554
+#: cp/parser.c:20551
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD là một namespace"
 
-#: cp/parser.c:20556
+#: cp/parser.c:20553
 #, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr ""
 
-#: cp/parser.c:20577
+#: cp/parser.c:20574
 #, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "cần ptr-operator"
 
-#: cp/parser.c:20638
+#: cp/parser.c:20635
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "trùng cv-qualifier"
 
-#: cp/parser.c:20692
+#: cp/parser.c:20689
 #, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr "đa ref-qualifiers"
 
-#: cp/parser.c:20729
+#: cp/parser.c:20726
 #, fuzzy, gcc-internal-format
 #| msgid "%E requires %<-fgnu-tm%>"
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr "%E cần %<-fgnu-tm%>"
 
-#: cp/parser.c:20787
+#: cp/parser.c:20784
 #, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "trùng virt-specifier"
 
-#: cp/parser.c:21025
+#: cp/parser.c:21022
 #, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr "thiếu đối số mẫu sau %qT"
 
-#: cp/parser.c:21031 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2090
+#: cp/parser.c:21028 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2093
 #, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr "cách dùng không hợp lệ %qT"
 
-#: cp/parser.c:21052
+#: cp/parser.c:21049
 #, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "các kiểu không nên được định nghĩa trong đối số mẫu"
 
-#: cp/parser.c:21057
+#: cp/parser.c:21054
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "dùng %<auto%> không hợp lệ trong đối số mẫu"
 
-#: cp/parser.c:21145
+#: cp/parser.c:21142
 #, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "cần type-specifier"
 
-#: cp/parser.c:21429
+#: cp/parser.c:21426
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "cần %<,%> hoặc %<…%>"
 
-#: cp/parser.c:21504
+#: cp/parser.c:21501
 #, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr ""
 
-#: cp/parser.c:21678
+#: cp/parser.c:21675
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr ""
 
-#: cp/parser.c:21696
+#: cp/parser.c:21693
 #, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:21702
+#: cp/parser.c:21699
 #, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:21704
+#: cp/parser.c:21701
 #, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:22131
+#: cp/parser.c:22128
 #, fuzzy, gcc-internal-format
 #| msgid "lambda capture initializers only available with -std=c++14 or -std=gnu++14"
 msgid "C++ designated initializers only available with -std=c++2a or -std=gnu++2a"
 msgstr "khởi tạo chụp lambda chỉ sẵn sàng với -std=c++14 hay -std=gnu++14"
 
-#: cp/parser.c:22151
+#: cp/parser.c:22148
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow ?: with omitted middle operand"
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr "ISO C++ không cho phép ?: với toán hạng ở giữa bị bỏ qua"
 
-#: cp/parser.c:22189
+#: cp/parser.c:22186
 #, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr ""
 
-#: cp/parser.c:22203
+#: cp/parser.c:22200
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr ""
 
-#: cp/parser.c:22228
+#: cp/parser.c:22225
 #, gcc-internal-format
 msgid "%<...%> not allowed in designated initializer list"
 msgstr ""
 
-#: cp/parser.c:22266
+#: cp/parser.c:22263
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr ""
 
-#: cp/parser.c:22322 cp/parser.c:22448
+#: cp/parser.c:22319 cp/parser.c:22445
 #, gcc-internal-format
 msgid "expected class-name"
 msgstr "cần class-name"
 
-#: cp/parser.c:22650
+#: cp/parser.c:22647
 #, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "cần %<;%> sau định nghĩa lớp"
 
-#: cp/parser.c:22653
+#: cp/parser.c:22650
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "cần %<;%> sau định nghĩa cấu trúc"
 
-#: cp/parser.c:22656
+#: cp/parser.c:22653
 #, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "cần %<;%> sau định nghĩa kiểu hỗn hợp"
 
-#: cp/parser.c:23012
+#: cp/parser.c:23009
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "cần %<{%> hoặc %<:%>"
 
-#: cp/parser.c:23023
+#: cp/parser.c:23020
 #, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "không thể chỉ định %<override%> cho lớp"
 
-#: cp/parser.c:23031
+#: cp/parser.c:23028
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:23038
+#: cp/parser.c:23035
 #, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr ""
 
-#: cp/parser.c:23050
+#: cp/parser.c:23047
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr ""
 
-#: cp/parser.c:23056
+#: cp/parser.c:23053
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr ""
 
-#: cp/parser.c:23114
+#: cp/parser.c:23111
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr ""
 
-#: cp/parser.c:23146
+#: cp/parser.c:23143
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr ""
 
-#: cp/parser.c:23182
+#: cp/parser.c:23179
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr ""
 
-#: cp/parser.c:23241
+#: cp/parser.c:23238
 #, fuzzy, gcc-internal-format
 msgid "previous definition of %q#T"
 msgstr "khai báo trước đây của %q+#T"
 
-#: cp/parser.c:23331 cp/parser.c:28499
+#: cp/parser.c:23328 cp/parser.c:28496
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr "cần class-key"
 
-#: cp/parser.c:23355
+#: cp/parser.c:23352
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:23359
+#: cp/parser.c:23356
 #, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "cần %<class%>, hoặc %<typename%>"
 
-#: cp/parser.c:23605
+#: cp/parser.c:23602
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr ""
 
-#: cp/parser.c:23623
+#: cp/parser.c:23620
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr ""
 
-#: cp/parser.c:23641
+#: cp/parser.c:23638
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:23738
+#: cp/parser.c:23735
 #, fuzzy, gcc-internal-format
 #| msgid "lambda capture initializers only available with -std=c++14 or -std=gnu++14"
 msgid "default member initializers for bit-fields only available with -std=c++2a or -std=gnu++2a"
 msgstr "khởi tạo chụp lambda chỉ sẵn sàng với -std=c++14 hay -std=gnu++14"
 
-#: cp/parser.c:23745
+#: cp/parser.c:23742
 #, fuzzy, gcc-internal-format
 msgid "default member initializer for unnamed bit-field"
 msgstr "đã khởi tạo một bộ phận mảng dẻo"
 
-#: cp/parser.c:23758
+#: cp/parser.c:23755
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr ""
 
-#: cp/parser.c:23903
+#: cp/parser.c:23900
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr ""
 
-#: cp/parser.c:23923
+#: cp/parser.c:23920
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%> after class definition"
 msgid "extra %<;%> after in-class function definition"
 msgstr "cần %<;%> sau định nghĩa lớp"
 
-#: cp/parser.c:23970
+#: cp/parser.c:23967
 #, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr ""
 
-#: cp/parser.c:23984
+#: cp/parser.c:23981
 #, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "cần %<;%> tại cuối khai báo thành viên"
 
-#: cp/parser.c:24058
+#: cp/parser.c:24055
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr ""
 
-#: cp/parser.c:24093
+#: cp/parser.c:24090
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr ""
 
-#: cp/parser.c:24223
+#: cp/parser.c:24220
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr ""
 
-#: cp/parser.c:24243
+#: cp/parser.c:24240
 #, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr ""
 
-#: cp/parser.c:24267
+#: cp/parser.c:24264
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr ""
 
-#: cp/parser.c:24270
+#: cp/parser.c:24267
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:24364 cp/parser.c:24442
+#: cp/parser.c:24361 cp/parser.c:24439
 #, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr ""
 
-#: cp/parser.c:24450
+#: cp/parser.c:24447
 #, fuzzy, gcc-internal-format
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "ISO C++ không cho phép %<alignof%> với một non-type"
 
-#: cp/parser.c:24456
+#: cp/parser.c:24453
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr ""
 
-#: cp/parser.c:24500
+#: cp/parser.c:24497
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "dùng %<auto%> không hợp lệ trong đặc tả ngoại lệ"
 
-#: cp/parser.c:24539
+#: cp/parser.c:24536
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:24650
+#: cp/parser.c:24647
 #, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr ""
 
-#: cp/parser.c:25203
+#: cp/parser.c:25200
 #, gcc-internal-format
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr ""
 
-#: cp/parser.c:25217
+#: cp/parser.c:25214
 #, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr ""
 
-#: cp/parser.c:25301
+#: cp/parser.c:25298
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:25305
+#: cp/parser.c:25302
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:25342
+#: cp/parser.c:25339
 #, fuzzy, gcc-internal-format
 msgid "expected attribute before %<...%>"
 msgstr "cần %<:%> hoặc %<…%>"
 
-#: cp/parser.c:25403
+#: cp/parser.c:25400
 #, fuzzy, gcc-internal-format
 msgid "attribute using prefix only available with -std=c++17 or -std=gnu++17"
 msgstr "mẫu biến chỉ sẵn sàng với -std=c++14 hay -std=gnu++14"
 
-#: cp/parser.c:25721
+#: cp/parser.c:25718
 #, gcc-internal-format
 msgid "%<requires%> only available with -fconcepts"
 msgstr "%<requires%> chỉ sẵn sàng với -fconcepts"
 
-#: cp/parser.c:25753
+#: cp/parser.c:25750
 #, gcc-internal-format
 msgid "a requires expression cannot appear outside a template"
 msgstr ""
 
-#: cp/parser.c:26467
+#: cp/parser.c:26464
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:26472
+#: cp/parser.c:26469
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "khai báo không hợp lệ của %<%T::%E%>"
 
-#: cp/parser.c:26476
+#: cp/parser.c:26473
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr ""
@@ -46467,454 +46512,454 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:26483
+#: cp/parser.c:26480
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr ""
 
-#: cp/parser.c:26832
+#: cp/parser.c:26829
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr ""
 
-#: cp/parser.c:26991
+#: cp/parser.c:26988
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr ""
 
-#: cp/parser.c:26996
+#: cp/parser.c:26993
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr ""
 
-#: cp/parser.c:27066
+#: cp/parser.c:27063
 #, gcc-internal-format
 msgid "empty introduction-list"
 msgstr ""
 
-#: cp/parser.c:27090
+#: cp/parser.c:27087
 #, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr ""
 
-#: cp/parser.c:27112
+#: cp/parser.c:27109
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr ""
 
-#: cp/parser.c:27121
+#: cp/parser.c:27118
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr ""
 
-#: cp/parser.c:27141
+#: cp/parser.c:27138
 #, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "đặc tả rõ ràng không hợp lệ"
 
-#: cp/parser.c:27245
+#: cp/parser.c:27242
 #, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr ""
 
-#: cp/parser.c:27296
+#: cp/parser.c:27293
 #, gcc-internal-format
 msgid "a class template declaration must not declare anything else"
 msgstr ""
 
-#: cp/parser.c:27342
+#: cp/parser.c:27339
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr ""
 
-#: cp/parser.c:27650
+#: cp/parser.c:27647
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr ""
 
-#: cp/parser.c:27663
+#: cp/parser.c:27660
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr ""
 
-#: cp/parser.c:27958
+#: cp/parser.c:27955
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr "đối số cho %<sizeof…%> phải được bao quanh bởi dấu ngoặc đơn"
 
-#: cp/parser.c:28118
+#: cp/parser.c:28115
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr ""
 
-#: cp/parser.c:28133
+#: cp/parser.c:28130
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> trước %qD"
 
-#: cp/parser.c:28267
+#: cp/parser.c:28264
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr ""
 
-#: cp/parser.c:28275
+#: cp/parser.c:28272
 #, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "đã chỉ ra cả hai %<__thread%> và %<thread_local%>"
 
-#: cp/parser.c:28280
+#: cp/parser.c:28277
 #, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "trùng %qD"
 
-#: cp/parser.c:28304
+#: cp/parser.c:28301
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "trùng %qs"
 
-#: cp/parser.c:28356
+#: cp/parser.c:28353
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "cần %<new%>"
 
-#: cp/parser.c:28359
+#: cp/parser.c:28356
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "cần %<delete%>"
 
-#: cp/parser.c:28362
+#: cp/parser.c:28359
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "cần %<return%>"
 
-#: cp/parser.c:28368
+#: cp/parser.c:28365
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "cần %<extern%>"
 
-#: cp/parser.c:28371
+#: cp/parser.c:28368
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "cần %<static_assert%>"
 
-#: cp/parser.c:28374
+#: cp/parser.c:28371
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "cần %<decltype%>"
 
-#: cp/parser.c:28377
+#: cp/parser.c:28374
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "cần %<operator%>"
 
-#: cp/parser.c:28380
+#: cp/parser.c:28377
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "cần %<class%>"
 
-#: cp/parser.c:28383
+#: cp/parser.c:28380
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "cần %<template%>"
 
-#: cp/parser.c:28386
+#: cp/parser.c:28383
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "cần %<namespace%>"
 
-#: cp/parser.c:28389
+#: cp/parser.c:28386
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "cần %<using%>"
 
-#: cp/parser.c:28392
+#: cp/parser.c:28389
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "cần %<asm%>"
 
-#: cp/parser.c:28395
+#: cp/parser.c:28392
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "cần %<try%>"
 
-#: cp/parser.c:28398
+#: cp/parser.c:28395
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "cần %<catch%>"
 
-#: cp/parser.c:28401
+#: cp/parser.c:28398
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "cần %<throw%>"
 
-#: cp/parser.c:28404
+#: cp/parser.c:28401
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "cần %<__label__%>"
 
-#: cp/parser.c:28407
+#: cp/parser.c:28404
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "cần %<@try%>"
 
-#: cp/parser.c:28410
+#: cp/parser.c:28407
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "cần %<@synchronized%>"
 
-#: cp/parser.c:28413
+#: cp/parser.c:28410
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "cần %<@throw%>"
 
-#: cp/parser.c:28416
+#: cp/parser.c:28413
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "cần %<__transaction_atomic%>"
 
-#: cp/parser.c:28419
+#: cp/parser.c:28416
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "cần %<__transaction_relaxed%>"
 
-#: cp/parser.c:28451
+#: cp/parser.c:28448
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "cần %<::%>"
 
-#: cp/parser.c:28463
+#: cp/parser.c:28460
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "cần %<…%>"
 
-#: cp/parser.c:28466
+#: cp/parser.c:28463
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "cần %<*%>"
 
-#: cp/parser.c:28469
+#: cp/parser.c:28466
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "cần %<~%>"
 
-#: cp/parser.c:28475
+#: cp/parser.c:28472
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "cần %<:%> hoặc %<::%>"
 
-#: cp/parser.c:28502
+#: cp/parser.c:28499
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "cần %<class%>, %<typename%>, hoặc %<template%>"
 
-#: cp/parser.c:28772
+#: cp/parser.c:28769
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr ""
 
-#: cp/parser.c:28777
+#: cp/parser.c:28774
 #, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "%q#T trước đã khai báo ở đây"
 
-#: cp/parser.c:28798
+#: cp/parser.c:28795
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr ""
 
-#: cp/parser.c:28819
+#: cp/parser.c:28816
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr ""
 
-#: cp/parser.c:29062
+#: cp/parser.c:29059
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr ""
 
-#: cp/parser.c:29303 cp/parser.c:30620 cp/parser.c:30808
+#: cp/parser.c:29300 cp/parser.c:30617 cp/parser.c:30805
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr ""
 
-#: cp/parser.c:29372
+#: cp/parser.c:29369
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr ""
 
-#: cp/parser.c:29442
+#: cp/parser.c:29439
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:29473
+#: cp/parser.c:29470
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr ""
 
-#: cp/parser.c:29883
+#: cp/parser.c:29880
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr ""
 
-#: cp/parser.c:29958 cp/parser.c:29976
+#: cp/parser.c:29955 cp/parser.c:29973
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr ""
 
-#: cp/parser.c:29970 cp/parser.c:30035
+#: cp/parser.c:29967 cp/parser.c:30032
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr ""
 
-#: cp/parser.c:30078
+#: cp/parser.c:30075
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:30284 cp/parser.c:30291 cp/parser.c:30298
+#: cp/parser.c:30281 cp/parser.c:30288 cp/parser.c:30295
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "kiểu không hợp lệ cho biến instance (minh dụ)"
 
-#: cp/parser.c:30413
+#: cp/parser.c:30410
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr ""
 
-#: cp/parser.c:30585
+#: cp/parser.c:30582
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:30592
+#: cp/parser.c:30589
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr ""
 
-#: cp/parser.c:30867 cp/parser.c:30874 cp/parser.c:30881
+#: cp/parser.c:30864 cp/parser.c:30871 cp/parser.c:30878
 #, gcc-internal-format
 msgid "invalid type for property"
 msgstr "kiểu không hợp lệ cho thuộc tính"
 
-#: cp/parser.c:32011
+#: cp/parser.c:32008
 #, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr "biểu thức %<wait%> phải là số nguyên"
 
-#: cp/parser.c:32724
+#: cp/parser.c:32721
 #, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr "bộ khởi tạo sai"
 
-#: cp/parser.c:34911
+#: cp/parser.c:34908
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:35231 cp/pt.c:16392
+#: cp/parser.c:35228 cp/pt.c:16414
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr ""
 
-#: cp/parser.c:35316
+#: cp/parser.c:35313
 #, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr ""
 
-#: cp/parser.c:37521
+#: cp/parser.c:37518
 #, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr "mệnh đề khởi tạo không hợp lệ"
 
-#: cp/parser.c:37549
+#: cp/parser.c:37546
 #, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "cần id-expression (các đối số)"
 
-#: cp/parser.c:37561
+#: cp/parser.c:37558
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:37662
+#: cp/parser.c:37659
 #, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr ""
 
-#: cp/parser.c:37682 cp/semantics.c:5405
+#: cp/parser.c:37679 cp/semantics.c:5408
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37687 cp/semantics.c:5414
+#: cp/parser.c:37684 cp/semantics.c:5417
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37690 cp/pt.c:12944 cp/semantics.c:5420
+#: cp/parser.c:37687 cp/pt.c:12966 cp/semantics.c:5423
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37693 cp/semantics.c:5426
+#: cp/parser.c:37690 cp/semantics.c:5429
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:38047
+#: cp/parser.c:38044
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:38057
+#: cp/parser.c:38054
 #, fuzzy, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr "%qD không phải là hàm thành viên mẫu"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:38392
+#: cp/parser.c:38389
 #, gcc-internal-format
 msgid "atomic_cancel"
 msgstr ""
 
-#: cp/parser.c:38435 cp/semantics.c:8575
+#: cp/parser.c:38432 cp/semantics.c:8578
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:38437 cp/semantics.c:8577
+#: cp/parser.c:38434 cp/semantics.c:8580
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:38631
+#: cp/parser.c:38628
 #, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr ""
 
-#: cp/parser.c:38927
+#: cp/parser.c:38924
 #, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr ""
 
-#: cp/parser.c:38959
+#: cp/parser.c:38956
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma grainsize%> must be inside a function"
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr "%<#pragma grainsize%> phải ở bên trong một hàm"
 
-#: cp/parser.c:39039
+#: cp/parser.c:39036
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr ""
 
-#: cp/parser.c:39295
+#: cp/parser.c:39292
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr "các mẫu ngầm không nên là %<virtual%>"
 
-#: cp/parser.c:39351
+#: cp/parser.c:39348
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
@@ -47001,7 +47046,7 @@
 msgid "specialization of %qD after instantiation"
 msgstr ""
 
-#: cp/pt.c:1954 cp/semantics.c:5274
+#: cp/pt.c:1954 cp/semantics.c:5277
 #, fuzzy, gcc-internal-format
 #| msgid "%s %#D"
 msgid "%s %#qD"
@@ -47171,123 +47216,123 @@
 msgid "argument to __integer_pack must be between 0 and %d"
 msgstr ""
 
-#: cp/pt.c:3942
+#: cp/pt.c:3955
 #, gcc-internal-format
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr ""
 
-#: cp/pt.c:4010
+#: cp/pt.c:4023
 #, gcc-internal-format
 msgid "expansion pattern %qT contains no argument packs"
 msgstr ""
 
-#: cp/pt.c:4012
+#: cp/pt.c:4025
 #, gcc-internal-format
 msgid "expansion pattern %qE contains no argument packs"
 msgstr ""
 
-#: cp/pt.c:4063
+#: cp/pt.c:4077
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr ""
 
-#: cp/pt.c:4080 cp/pt.c:4835
+#: cp/pt.c:4094 cp/pt.c:4849
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
 
-#: cp/pt.c:4082
+#: cp/pt.c:4096
 #, gcc-internal-format
 msgid "        <anonymous>"
 msgstr "        <nặc danh>"
 
-#: cp/pt.c:4208
+#: cp/pt.c:4222
 #, gcc-internal-format
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr ""
 
-#: cp/pt.c:4211
+#: cp/pt.c:4225
 #, gcc-internal-format
 msgid "declaration of %q+#D shadows template parameter"
 msgstr ""
 
-#: cp/pt.c:4213
+#: cp/pt.c:4227
 #, gcc-internal-format
 msgid "template parameter %qD declared here"
 msgstr ""
 
-#: cp/pt.c:4771
+#: cp/pt.c:4785
 #, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr ""
 
-#: cp/pt.c:4830
+#: cp/pt.c:4844
 #, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr ""
 
-#: cp/pt.c:4854
+#: cp/pt.c:4868
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:4858
+#: cp/pt.c:4872
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:4862 cp/pt.c:4873
+#: cp/pt.c:4876 cp/pt.c:4887
 #, gcc-internal-format
 msgid "primary template here"
 msgstr "mẫu nguyên gốc ở đây"
 
-#: cp/pt.c:4870
+#: cp/pt.c:4884
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:4885
+#: cp/pt.c:4899
 #, gcc-internal-format
 msgid "partial specialization %qD is not more specialized than"
 msgstr ""
 
-#: cp/pt.c:4887
+#: cp/pt.c:4901
 #, fuzzy, gcc-internal-format
 msgid "primary template %qD"
 msgstr "mẫu nguyên gốc ở đây"
 
-#: cp/pt.c:4934
+#: cp/pt.c:4948
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:4937
+#: cp/pt.c:4951
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:4958
+#: cp/pt.c:4972
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr ""
 
-#: cp/pt.c:5004
+#: cp/pt.c:5018
 #, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
 msgstr[0] ""
 
-#: cp/pt.c:5066
+#: cp/pt.c:5080
 #, gcc-internal-format
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr ""
 
-#: cp/pt.c:5070
+#: cp/pt.c:5084
 #, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr ""
 
-#: cp/pt.c:5247
+#: cp/pt.c:5261
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr ""
@@ -47295,47 +47340,47 @@
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5269
+#: cp/pt.c:5283
 #, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr ""
 
-#: cp/pt.c:5305
+#: cp/pt.c:5319
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr ""
 
-#: cp/pt.c:5308
+#: cp/pt.c:5322
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "các kiểu có lẽ không nên được định nghĩa trong áp kiểu"
 
-#: cp/pt.c:5311
+#: cp/pt.c:5325
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/pt.c:5314
+#: cp/pt.c:5328
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr ""
 
-#: cp/pt.c:5317 cp/pt.c:5375
+#: cp/pt.c:5331 cp/pt.c:5389
 #, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr ""
 
-#: cp/pt.c:5489
+#: cp/pt.c:5503
 #, gcc-internal-format
 msgid "template %qD declared"
 msgstr ""
 
-#: cp/pt.c:5496
+#: cp/pt.c:5510
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr ""
 
-#: cp/pt.c:5504
+#: cp/pt.c:5518
 #, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr ""
@@ -47345,75 +47390,75 @@
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5526
+#: cp/pt.c:5540
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "phần khai báo mẫu của %qD không hợp lệ"
 
-#: cp/pt.c:5669
+#: cp/pt.c:5683
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr ""
 
-#: cp/pt.c:5712
+#: cp/pt.c:5726
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr ""
 
-#: cp/pt.c:5726
+#: cp/pt.c:5740
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "nhận được %d đối số mẫu cho %q#D"
 
-#: cp/pt.c:5729
+#: cp/pt.c:5743
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "nhận được %d đối số mẫu cho %q#T"
 
-#: cp/pt.c:5731
+#: cp/pt.c:5745
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  nhưng cần %d"
 
-#: cp/pt.c:5752
+#: cp/pt.c:5766
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr ""
 
-#: cp/pt.c:5755
+#: cp/pt.c:5769
 #, fuzzy, gcc-internal-format
 #| msgid "invalid explicit specialization"
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "đặc tả rõ ràng không hợp lệ"
 
-#: cp/pt.c:5882
+#: cp/pt.c:5896
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT không phải là một kiểu mẫu"
 
-#: cp/pt.c:5895
+#: cp/pt.c:5909
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr ""
 
-#: cp/pt.c:5906
+#: cp/pt.c:5920
 #, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
 msgstr[0] ""
 
-#: cp/pt.c:5910
+#: cp/pt.c:5924
 #, gcc-internal-format
 msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
 msgstr[0] ""
 
-#: cp/pt.c:5947
+#: cp/pt.c:5961
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "đối số mẫu %q+#D"
 
-#: cp/pt.c:5948
+#: cp/pt.c:5962
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "khai báo lại ở đây như là %q#D"
@@ -47422,412 +47467,412 @@
 #.
 #. A template-parameter may not be given default arguments
 #. by two different declarations in the same scope.
-#: cp/pt.c:5958
+#: cp/pt.c:5972
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "định nghĩa lại của đối số mặc định của %q#D"
 
-#: cp/pt.c:5960
+#: cp/pt.c:5974
 #, gcc-internal-format
 msgid "original definition appeared here"
 msgstr "định nghĩa nguyên bản xuất hiện ở đây"
 
-#: cp/pt.c:5988
+#: cp/pt.c:6002
 #, gcc-internal-format
 msgid "redeclaration %q#D with different constraints"
 msgstr ""
 
-#: cp/pt.c:5991
+#: cp/pt.c:6005
 #, gcc-internal-format
 msgid "original declaration appeared here"
 msgstr ""
 
-#: cp/pt.c:6250 cp/pt.c:6318
+#: cp/pt.c:6264 cp/pt.c:6332
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr ""
 
-#: cp/pt.c:6253
+#: cp/pt.c:6267
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6256
+#: cp/pt.c:6270
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6268
+#: cp/pt.c:6282
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr ""
 
-#: cp/pt.c:6272
+#: cp/pt.c:6286
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr ""
 
-#: cp/pt.c:6321
+#: cp/pt.c:6335
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr ""
 
-#: cp/pt.c:6323
+#: cp/pt.c:6337
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qT"
 msgid "because it is a member of %qT"
 msgstr "%qD không phải là thành viên của %qT"
 
-#: cp/pt.c:6383
+#: cp/pt.c:6397
 #, gcc-internal-format
 msgid "  couldn't deduce template parameter %qD"
 msgstr ""
 
-#: cp/pt.c:6392
+#: cp/pt.c:6406
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.c:6401
+#: cp/pt.c:6415
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr "  kiểu không khớp %qT và %qT"
 
-#: cp/pt.c:6410
+#: cp/pt.c:6424
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr ""
 
-#: cp/pt.c:6421
+#: cp/pt.c:6435
 #, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr ""
 
-#: cp/pt.c:6431
+#: cp/pt.c:6445
 #, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr "  %qE không tương đương với %qE"
 
-#: cp/pt.c:6440
+#: cp/pt.c:6454
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:6452
+#: cp/pt.c:6466
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.c:6456
+#: cp/pt.c:6470
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.c:6467
+#: cp/pt.c:6481
 #, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6478
+#: cp/pt.c:6492
 #, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr "  kiểu hàm thành viên %qT không phải là một đối số mẫu hợp lệ"
 
-#: cp/pt.c:6490
+#: cp/pt.c:6504
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
 msgstr[0] "  ứng cử cần ít nhất %d đối số, nhưng cung cấp %d"
 
-#: cp/pt.c:6521
+#: cp/pt.c:6535
 #, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "  không thể chuyển đổi %qE (kiểu %qT) thành kiểu %qT"
 
-#: cp/pt.c:6534
+#: cp/pt.c:6548
 #, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "  %qT là lớp cơ sở chưa rõ ràng của %qT"
 
-#: cp/pt.c:6538
+#: cp/pt.c:6552
 #, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "  %qT không được dẫn xuất từ %qT"
 
-#: cp/pt.c:6549
+#: cp/pt.c:6563
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.c:6559
+#: cp/pt.c:6573
 #, gcc-internal-format
 msgid "  can't deduce a template for %qT from non-template type %qT"
 msgstr ""
 
-#: cp/pt.c:6569
+#: cp/pt.c:6583
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
 msgstr "quá nhiều đối số cho cho phương thức %qE"
 
-#: cp/pt.c:6609
+#: cp/pt.c:6623
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr ""
 
-#: cp/pt.c:6758
+#: cp/pt.c:6772
 #, fuzzy, gcc-internal-format
 #| msgid "missing template arguments after %qT"
 msgid "in template argument for type %qT"
 msgstr "thiếu đối số mẫu sau %qT"
 
-#: cp/pt.c:6772
+#: cp/pt.c:6786
 #, fuzzy, gcc-internal-format
 msgid "template argument %qE for type %qT not a constant integer"
 msgstr "%qE không phải là biểu thức hằng"
 
-#: cp/pt.c:6833
+#: cp/pt.c:6847
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr ""
 
-#: cp/pt.c:6841
+#: cp/pt.c:6855
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr ""
 
-#: cp/pt.c:6857
+#: cp/pt.c:6871
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr ""
 
-#: cp/pt.c:6864
+#: cp/pt.c:6878
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr ""
 
-#: cp/pt.c:6873
+#: cp/pt.c:6887
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr ""
 
-#: cp/pt.c:6888
+#: cp/pt.c:6902
 #, fuzzy, gcc-internal-format
 #| msgid "  member function type %qT is not a valid template argument"
 msgid "the address of %qD is not a valid template argument"
 msgstr "  kiểu hàm thành viên %qT không phải là một đối số mẫu hợp lệ"
 
-#: cp/pt.c:6897
+#: cp/pt.c:6911
 #, fuzzy, gcc-internal-format
 #| msgid "  member function type %qT is not a valid template argument"
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr "  kiểu hàm thành viên %qT không phải là một đối số mẫu hợp lệ"
 
-#: cp/pt.c:6904
+#: cp/pt.c:6918
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr ""
 
-#: cp/pt.c:6933
+#: cp/pt.c:6947
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr ""
 
-#: cp/pt.c:6941
+#: cp/pt.c:6955
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr ""
 
-#: cp/pt.c:6959
+#: cp/pt.c:6973
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr ""
 
-#: cp/pt.c:6975
+#: cp/pt.c:6989
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an object with linkage"
 msgstr ""
 
-#: cp/pt.c:6986
+#: cp/pt.c:7000
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because object %qD does not have linkage"
 msgstr ""
 
-#: cp/pt.c:7036
+#: cp/pt.c:7050
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr ""
 
-#: cp/pt.c:7038
+#: cp/pt.c:7052
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "dùng %qE để thay thế"
 
-#: cp/pt.c:7092
+#: cp/pt.c:7106
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr ""
 
-#: cp/pt.c:7654
+#: cp/pt.c:7668
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr ""
 
-#: cp/pt.c:7670
+#: cp/pt.c:7684
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr "dùng %<auto%> không hợp lệ trong đối số mẫu"
 
-#: cp/pt.c:7805
+#: cp/pt.c:7819
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr ""
 
-#: cp/pt.c:7834
+#: cp/pt.c:7848
 #, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr ""
 
-#: cp/pt.c:7839
+#: cp/pt.c:7853
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr ""
 
-#: cp/pt.c:7855 cp/pt.c:7877 cp/pt.c:7931
+#: cp/pt.c:7869 cp/pt.c:7891 cp/pt.c:7945
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.c:7860
+#: cp/pt.c:7874
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  cần hằng của kiểu %qT, nhưng lại nhận được %qT"
 
-#: cp/pt.c:7865
+#: cp/pt.c:7879
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  cần mẫu lớp, nhưng lại nhận được %qE"
 
-#: cp/pt.c:7868
+#: cp/pt.c:7882
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  cần kiểu, nhưng lại nhận %qE"
 
-#: cp/pt.c:7882
+#: cp/pt.c:7896
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  cần một kiểu, nhưng lại nhận được %qT"
 
-#: cp/pt.c:7885
+#: cp/pt.c:7899
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  cần mẫu lớp, nhưng lại nhận được %qT"
 
-#: cp/pt.c:7935
+#: cp/pt.c:7949
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  cần mẫu kiểu %qD, nhưng lại nhận được %qT"
 
-#: cp/pt.c:7949
+#: cp/pt.c:7963
 #, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.c:7952
+#: cp/pt.c:7966
 #, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr "  cần %qD nhưng lại nhận %qD"
 
-#: cp/pt.c:8012
+#: cp/pt.c:8026
 #, fuzzy, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "không thể chuyển đổi %qE từ %qT thành %qT"
 
-#: cp/pt.c:8149 cp/pt.c:8465
+#: cp/pt.c:8163 cp/pt.c:8479
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr ""
 
-#: cp/pt.c:8164 cp/pt.c:8298
+#: cp/pt.c:8178 cp/pt.c:8312
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "sai số lượng đối số hàm mẫu (%d, phải là %d)"
 
-#: cp/pt.c:8294
+#: cp/pt.c:8308
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "sai số lượng đối số mẫu (%d, cần ít nhất phải là %d)"
 
-#: cp/pt.c:8303
+#: cp/pt.c:8317
 #, gcc-internal-format
 msgid "provided for %qD"
 msgstr "được cung cấp cho %qD"
 
-#: cp/pt.c:8328
+#: cp/pt.c:8342
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:8332
+#: cp/pt.c:8346
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr ""
 
-#: cp/pt.c:8431
+#: cp/pt.c:8445
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:9054
+#: cp/pt.c:9068
 #, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%q#D không phải là hàm mẫu"
 
-#: cp/pt.c:9221
+#: cp/pt.c:9235
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr ""
 
-#: cp/pt.c:9223
+#: cp/pt.c:9237
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "cho khai báo hàm mẫu %q+D"
 
-#: cp/pt.c:9346
+#: cp/pt.c:9360
 #, gcc-internal-format
 msgid "template constraint failure"
 msgstr "ràng buộc mẫu gặp lỗi nghiêm trọng"
 
-#: cp/pt.c:9697
+#: cp/pt.c:9718
 #, fuzzy, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr "%qD không phải là một biến"
 
-#: cp/pt.c:10125
+#: cp/pt.c:10148
 #, gcc-internal-format, gfc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:11202
+#: cp/pt.c:11225
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD in union"
 msgstr "cấu có không thành viên đã đặt tên"
 
-#: cp/pt.c:11691
+#: cp/pt.c:11713
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:12160
+#: cp/pt.c:12182
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr ""
 
-#: cp/pt.c:12163
+#: cp/pt.c:12185
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr ""
 
-#: cp/pt.c:12747
+#: cp/pt.c:12769
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for %q#D"
 msgid "  when instantiating default argument for call to %qD"
@@ -47846,278 +47891,278 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:13708
+#: cp/pt.c:13730
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "biến %qD có kiểu hàm"
 
-#: cp/pt.c:13881
+#: cp/pt.c:13903
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "kiểu đối số không hợp lệ %qT"
 
-#: cp/pt.c:13883
+#: cp/pt.c:13905
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "trong khai báo %q+D"
 
-#: cp/pt.c:14001
+#: cp/pt.c:14023
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "hàm trả về một mảng"
 
-#: cp/pt.c:14003
+#: cp/pt.c:14025
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "hàm trả về hàm"
 
-#: cp/pt.c:14043
+#: cp/pt.c:14065
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr ""
 
-#: cp/pt.c:14637
+#: cp/pt.c:14659
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr ""
 
-#: cp/pt.c:14639
+#: cp/pt.c:14661
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr ""
 
-#: cp/pt.c:14641
+#: cp/pt.c:14663
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr ""
 
-#: cp/pt.c:14654
+#: cp/pt.c:14676
 #, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr ""
 
-#: cp/pt.c:14657
+#: cp/pt.c:14679
 #, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr ""
 
-#: cp/pt.c:14705
+#: cp/pt.c:14727
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr ""
 
-#: cp/pt.c:14711
+#: cp/pt.c:14733
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr ""
 
-#: cp/pt.c:14717
+#: cp/pt.c:14739
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "đang tạo con trỏ đến thành viên của kiểu void"
 
-#: cp/pt.c:14783
+#: cp/pt.c:14805
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "đang tạo mảng của %qT"
 
-#: cp/pt.c:14816
+#: cp/pt.c:14838
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT không phải có kiểu lớp, cấu trúc hay union"
 
-#: cp/pt.c:14853
+#: cp/pt.c:14875
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr ""
 
-#: cp/pt.c:14861
+#: cp/pt.c:14883
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr ""
 
-#: cp/pt.c:14925
+#: cp/pt.c:14947
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.c:15000
+#: cp/pt.c:15022
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "dùng %qs trong mẫu"
 
-#: cp/pt.c:15178
+#: cp/pt.c:15200
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/pt.c:15193
+#: cp/pt.c:15215
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr ""
 
-#: cp/pt.c:15195
+#: cp/pt.c:15217
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr ""
 
-#: cp/pt.c:15394
+#: cp/pt.c:15416
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "đang dùng trường không hợp lệ %qD"
 
-#: cp/pt.c:15883 cp/pt.c:17386
+#: cp/pt.c:15905 cp/pt.c:17408
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr ""
 
-#: cp/pt.c:15887 cp/pt.c:17390
+#: cp/pt.c:15909 cp/pt.c:17412
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr ""
 
-#: cp/pt.c:18334
+#: cp/pt.c:18371
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:18362
+#: cp/pt.c:18399
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:18367
+#: cp/pt.c:18404
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "dùng %<this->%D%> thay thế"
 
-#: cp/pt.c:18370
+#: cp/pt.c:18407
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "dùng %<%T::%D%> thay thế"
 
-#: cp/pt.c:18375
+#: cp/pt.c:18412
 #, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "%+D đã khai báo weakref sau khi được dùng"
 
-#: cp/pt.c:18712
+#: cp/pt.c:18752
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT không phải là một lớp hay namespace"
 
-#: cp/pt.c:18715
+#: cp/pt.c:18755
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD không phải là một lớp hay namespace"
 
-#: cp/pt.c:19026
+#: cp/pt.c:19066
 #, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr "%qT là/dùng kiểu nặc danh"
 
-#: cp/pt.c:19028
+#: cp/pt.c:19068
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr ""
 
-#: cp/pt.c:19038
+#: cp/pt.c:19078
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr ""
 
-#: cp/pt.c:19053
+#: cp/pt.c:19093
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "biểu thức nguyên %qE không là hằng"
 
-#: cp/pt.c:19071
+#: cp/pt.c:19111
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr ""
 
-#: cp/pt.c:22972
+#: cp/pt.c:23050
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr ""
 
-#: cp/pt.c:22974
+#: cp/pt.c:23052
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr ""
 
-#: cp/pt.c:22980
+#: cp/pt.c:23058
 #, fuzzy
 #| msgid "%s %#S"
 msgid "%s %#qS"
 msgstr "%s %#D"
 
-#: cp/pt.c:23004 cp/pt.c:23091
+#: cp/pt.c:23082 cp/pt.c:23169
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr ""
 
-#: cp/pt.c:23023
+#: cp/pt.c:23101
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD không phải là một thành viên dữ liệu tĩnh của một mẫu lớp"
 
-#: cp/pt.c:23029 cp/pt.c:23086
+#: cp/pt.c:23107 cp/pt.c:23164
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr ""
 
-#: cp/pt.c:23034
+#: cp/pt.c:23112
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr ""
 
-#: cp/pt.c:23042
+#: cp/pt.c:23120
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr ""
 
-#: cp/pt.c:23078
+#: cp/pt.c:23156
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr ""
 
-#: cp/pt.c:23101 cp/pt.c:23187
+#: cp/pt.c:23179 cp/pt.c:23265
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr ""
 
-#: cp/pt.c:23106 cp/pt.c:23204
+#: cp/pt.c:23184 cp/pt.c:23282
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr ""
 
-#: cp/pt.c:23163
+#: cp/pt.c:23241
 #, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr ""
 
-#: cp/pt.c:23165
+#: cp/pt.c:23243
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr ""
 
-#: cp/pt.c:23174
+#: cp/pt.c:23252
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr ""
 
-#: cp/pt.c:23192
+#: cp/pt.c:23270
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr ""
 
-#: cp/pt.c:23238
+#: cp/pt.c:23316
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr ""
 
-#: cp/pt.c:23536
+#: cp/pt.c:23614
 #, fuzzy, gcc-internal-format
 #| msgid "previous specification in %q#D here"
 msgid "exception specification of %qD depends on itself"
@@ -48130,108 +48175,108 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:23842
+#: cp/pt.c:23920
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr ""
 
-#: cp/pt.c:24043
+#: cp/pt.c:24121
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:24418
+#: cp/pt.c:24496
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr ""
 
-#: cp/pt.c:24420
+#: cp/pt.c:24498
 #, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr ""
 
-#: cp/pt.c:25723
+#: cp/pt.c:25802
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr ""
 
-#: cp/pt.c:25961
+#: cp/pt.c:26040
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/pt.c:26440
+#: cp/pt.c:26519
 #, gcc-internal-format
 msgid "non-class template %qT used without template arguments"
 msgstr "mẫu không phải lớp %qT được dùng mà không có đỗi số mẫu"
 
-#: cp/pt.c:26586
+#: cp/pt.c:26665
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:26593
+#: cp/pt.c:26672
 #, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr ""
 
-#: cp/pt.c:26607
+#: cp/pt.c:26686
 #, fuzzy, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "gặp yếu tố thừa trong bộ khởi tạo hợp"
 
-#: cp/pt.c:26614
+#: cp/pt.c:26693
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "hàm không phải được tính để chèn vào trực tiếp"
 
-#: cp/pt.c:26676
+#: cp/pt.c:26755
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:26679
+#: cp/pt.c:26758
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:26711
+#: cp/pt.c:26790
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/pt.c:26746
+#: cp/pt.c:26825
 #, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr ""
 
-#: cp/pt.c:26748
+#: cp/pt.c:26827
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr ""
 
-#: cp/pt.c:26781
+#: cp/pt.c:26860
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:26785
+#: cp/pt.c:26864
 #, gcc-internal-format
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.c:26789
+#: cp/pt.c:26868
 #, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.c:26793
+#: cp/pt.c:26872
 #, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.c:26912
+#: cp/pt.c:26991
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%> in template argument"
 msgid "invalid use of %qT in template argument"
@@ -48288,80 +48333,80 @@
 msgid "cannot dynamic_cast %qE (of type %q#T) to type %q#T (%s)"
 msgstr ""
 
-#: cp/search.c:240
+#: cp/search.c:243
 #, gcc-internal-format
 msgid "%qT is an ambiguous base of %qT"
 msgstr ""
 
-#: cp/search.c:256
+#: cp/search.c:259
 #, gcc-internal-format
 msgid "%qT is an inaccessible base of %qT"
 msgstr ""
 
-#: cp/search.c:1905
+#: cp/search.c:1908
 #, gcc-internal-format
 msgid "invalid covariant return type for %q#D"
 msgstr ""
 
-#: cp/search.c:1907 cp/search.c:1922 cp/search.c:1928 cp/search.c:1957
+#: cp/search.c:1910 cp/search.c:1925 cp/search.c:1931 cp/search.c:1960
 #, fuzzy, gcc-internal-format
 #| msgid "overriding final function %q+D"
 msgid "overridden function is %q#D"
 msgstr "đang dè lên hàm cuối %q+D"
 
-#: cp/search.c:1920
+#: cp/search.c:1923
 #, gcc-internal-format
 msgid "invalid covariant return type for %q+#D"
 msgstr ""
 
-#: cp/search.c:1926
+#: cp/search.c:1929
 #, gcc-internal-format
 msgid "conflicting return type specified for %q+#D"
 msgstr ""
 
-#: cp/search.c:1942
+#: cp/search.c:1945
 #, gcc-internal-format
 msgid "looser throw specifier for %q+#F"
 msgstr ""
 
-#: cp/search.c:1944
+#: cp/search.c:1947
 #, fuzzy, gcc-internal-format
 #| msgid "overriding final function %q+D"
 msgid "overridden function is %q#F"
 msgstr "đang dè lên hàm cuối %q+D"
 
-#: cp/search.c:1955
+#: cp/search.c:1958
 #, gcc-internal-format
 msgid "conflicting type attributes specified for %q+#D"
 msgstr ""
 
-#: cp/search.c:1972
+#: cp/search.c:1975
 #, gcc-internal-format
 msgid "%qD declared %<transaction_safe_dynamic%>"
 msgstr ""
 
-#: cp/search.c:1974
+#: cp/search.c:1977
 #, gcc-internal-format
 msgid "overriding %qD declared %<transaction_safe%>"
 msgstr ""
 
-#: cp/search.c:1981
+#: cp/search.c:1984
 #, gcc-internal-format
 msgid "deleted function %q+D overriding non-deleted function"
 msgstr ""
 
-#: cp/search.c:1984 cp/search.c:1992 cp/search.c:2000
+#: cp/search.c:1987 cp/search.c:1995 cp/search.c:2003
 #, fuzzy, gcc-internal-format
 #| msgid "overriding final function %q+D"
 msgid "overridden function is %qD"
 msgstr "đang dè lên hàm cuối %q+D"
 
-#: cp/search.c:1989
+#: cp/search.c:1992
 #, gcc-internal-format
 msgid "non-deleted function %q+D overriding deleted function"
 msgstr ""
 
-#: cp/search.c:1998
+#: cp/search.c:2001
 #, fuzzy, gcc-internal-format
 #| msgid "function returning a function"
 msgid "virtual function %q+D overriding final function"
@@ -48369,12 +48414,12 @@
 
 #. A static member function cannot match an inherited
 #. virtual member function.
-#: cp/search.c:2082
+#: cp/search.c:2085
 #, gcc-internal-format
 msgid "%q+#D cannot be declared"
 msgstr "%q+#D không thể được khai báo"
 
-#: cp/search.c:2083
+#: cp/search.c:2086
 #, gcc-internal-format
 msgid "  since %q+#D declared in base class"
 msgstr ""
@@ -48415,585 +48460,601 @@
 msgid "invalid use of member %qD in static member function"
 msgstr ""
 
-#: cp/semantics.c:2153
+#: cp/semantics.c:2156
 #, gcc-internal-format
 msgid "a statement expression is an insufficient context for overload resolution"
 msgstr ""
 
-#: cp/semantics.c:2540
+#: cp/semantics.c:2543
 #, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr ""
 
-#: cp/semantics.c:2622
+#: cp/semantics.c:2625
 #, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr ""
 
-#: cp/semantics.c:2624
+#: cp/semantics.c:2627
 #, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr ""
 
-#: cp/semantics.c:2626
+#: cp/semantics.c:2629
 #, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr ""
 
-#: cp/semantics.c:2648
+#: cp/semantics.c:2651
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr ""
 
-#: cp/semantics.c:2656 cp/typeck.c:2604
+#: cp/semantics.c:2659 cp/typeck.c:2604
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/semantics.c:2678
+#: cp/semantics.c:2681
 #, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr "%qE không là kiểu %qT"
 
-#: cp/semantics.c:2751
+#: cp/semantics.c:2754
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr ""
 
-#: cp/semantics.c:2892
+#: cp/semantics.c:2895
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr ""
 
-#: cp/semantics.c:2942
+#: cp/semantics.c:2945
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr ""
 
-#: cp/semantics.c:2945
+#: cp/semantics.c:2948
 #, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr ""
 
-#: cp/semantics.c:2962
+#: cp/semantics.c:2965
 #, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr ""
 
-#: cp/semantics.c:2993
+#: cp/semantics.c:2996
 #, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr "định nghĩa không hợp lệ của kiểu hạn định %qT"
 
-#: cp/semantics.c:3263
+#: cp/semantics.c:3266
 #, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "đặc tả lớp-cơ-sở không hợp lệ"
 
-#: cp/semantics.c:3423
+#: cp/semantics.c:3426
 #, gcc-internal-format
 msgid "cannot capture member %qD of anonymous union"
 msgstr "không thể chụp thành viên %qD trong hỗn hợp nặc danh"
 
-#: cp/semantics.c:3443 cp/semantics.c:9269
+#: cp/semantics.c:3446 cp/semantics.c:9272
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qD không bị bắt"
 
-#: cp/semantics.c:3448
+#: cp/semantics.c:3451
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.c:3450
+#: cp/semantics.c:3453
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.c:3462
+#: cp/semantics.c:3465
 #, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr ""
 
-#: cp/semantics.c:3464
+#: cp/semantics.c:3467
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr ""
 
-#: cp/semantics.c:3596
+#: cp/semantics.c:3599
 #, fuzzy, gcc-internal-format
 #| msgid "use of deleted function %qD"
 msgid "use of parameter outside function body"
 msgstr "dùng hàm bị xóa %qD"
 
-#: cp/semantics.c:3606
+#: cp/semantics.c:3609
 #, fuzzy, gcc-internal-format
 #| msgid "missing template arguments after %qT"
 msgid "missing template arguments"
 msgstr "thiếu đối số mẫu sau %qT"
 
-#: cp/semantics.c:3633
+#: cp/semantics.c:3636
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr ""
 
-#: cp/semantics.c:3664
+#: cp/semantics.c:3667
 #, gcc-internal-format
 msgid "use of namespace %qD as expression"
 msgstr ""
 
-#: cp/semantics.c:3669
+#: cp/semantics.c:3672
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr ""
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:3675
+#: cp/semantics.c:3678
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr ""
 
-#: cp/semantics.c:3702
+#: cp/semantics.c:3705
 #, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/semantics.c:3841
+#: cp/semantics.c:3844
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "không hiểu kiểu của %qE"
 
-#: cp/semantics.c:3870
+#: cp/semantics.c:3873
 #, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr "%qT không phải một kiểu enumeration"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4009
+#: cp/semantics.c:4012
 #, gcc-internal-format
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr ""
 
-#: cp/semantics.c:4038
+#: cp/semantics.c:4041
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr ""
 
-#: cp/semantics.c:4052
+#: cp/semantics.c:4055
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr ""
 
-#: cp/semantics.c:4056
+#: cp/semantics.c:4059
 #, fuzzy, gcc-internal-format
 #| msgid "a concept cannot be a member function"
 msgid "cannot apply %<offsetof%> to member function"
 msgstr "cấu tử không thể là hàm thành viên tĩnh"
 
-#: cp/semantics.c:4061
+#: cp/semantics.c:4064
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr ""
 
-#: cp/semantics.c:4072
+#: cp/semantics.c:4075
 #, gcc-internal-format
 msgid "offsetof within non-standard-layout type %qT is conditionally-supported"
 msgstr ""
 
-#: cp/semantics.c:4583 cp/semantics.c:6069 cp/semantics.c:6140
-#: cp/semantics.c:6183 cp/semantics.c:6533 cp/semantics.c:6632
-#: cp/semantics.c:6775
+#: cp/semantics.c:4586 cp/semantics.c:6072 cp/semantics.c:6143
+#: cp/semantics.c:6186 cp/semantics.c:6536 cp/semantics.c:6635
+#: cp/semantics.c:6778
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5271
+#: cp/semantics.c:5274
 #, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr ""
 
-#: cp/semantics.c:5544
+#: cp/semantics.c:5547
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: cp/semantics.c:5592
+#: cp/semantics.c:5595
 #, gcc-internal-format
 msgid "%qE has const type for %<reduction%>"
 msgstr ""
 
-#: cp/semantics.c:5707
+#: cp/semantics.c:5710
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:5941
+#: cp/semantics.c:5944
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5955
+#: cp/semantics.c:5958
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5977
+#: cp/semantics.c:5980
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr "biểu thức bước thẳng phải là số nguyên"
 
-#: cp/semantics.c:6080
+#: cp/semantics.c:6083
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD không phải một biến trong mệnh đề %qs"
 
-#: cp/semantics.c:6152
+#: cp/semantics.c:6155
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr ""
 
-#: cp/semantics.c:6195
+#: cp/semantics.c:6198
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "%qD không phải một biến trong mệnh đề %<lastprivate%>"
 
-#: cp/semantics.c:6240
+#: cp/semantics.c:6243
 #, gcc-internal-format
 msgid "%<gang%> static expression must be integral"
 msgstr "biểu thức tĩnh %<gang%> phải nguyên"
 
-#: cp/semantics.c:6254
+#: cp/semantics.c:6257
 #, fuzzy, gcc-internal-format
 #| msgid "%<gang%> static value must bepositive"
 msgid "%<gang%> static value must be positive"
 msgstr "giá trị tĩnh %<gang%> phải dương"
 
-#: cp/semantics.c:6288
+#: cp/semantics.c:6291
 #, gcc-internal-format
 msgid "%<gang%> num expression must be integral"
 msgstr "biểu thức số %<gang%> phải nguyên"
 
-#: cp/semantics.c:6291
+#: cp/semantics.c:6294
 #, gcc-internal-format
 msgid "%<vector%> length expression must be integral"
 msgstr "chiều dài %<vector%> phải là số nguyên"
 
-#: cp/semantics.c:6295
+#: cp/semantics.c:6298
 #, gcc-internal-format
 msgid "%<worker%> num expression must be integral"
 msgstr "biểu thức số %<worker%> phải là số nguyên"
 
-#: cp/semantics.c:6317
+#: cp/semantics.c:6320
 #, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr "%<gang%> giá trị phải dương"
 
-#: cp/semantics.c:6321
+#: cp/semantics.c:6324
 #, fuzzy, gcc-internal-format
 #| msgid "%<vector%> length value must bepositive"
 msgid "%<vector%> length value must be positive"
 msgstr "chiều dài %<vector%> giá trị phải dương"
 
-#: cp/semantics.c:6326
+#: cp/semantics.c:6329
 #, fuzzy, gcc-internal-format
 #| msgid "%<worker%> num value must bepositive"
 msgid "%<worker%> num value must be positive"
 msgstr "%<worker%> giá trị phải dương"
 
-#: cp/semantics.c:6376
+#: cp/semantics.c:6379
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6406
+#: cp/semantics.c:6409
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6419
+#: cp/semantics.c:6422
 #, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr ""
 
-#: cp/semantics.c:6438
+#: cp/semantics.c:6441
 #, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr "%<async%> biểu thức phải nguyên"
 
-#: cp/semantics.c:6466
+#: cp/semantics.c:6469
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr "%<thread_limit%> biểu thức phải nguyên"
 
-#: cp/semantics.c:6495
+#: cp/semantics.c:6498
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr "chỉ số %<device%> phải là số nguyên"
 
-#: cp/semantics.c:6516
+#: cp/semantics.c:6519
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6543
+#: cp/semantics.c:6546
 #, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qD không phải một biến trong mệnh đề  %<aligned%>"
 
-#: cp/semantics.c:6557
+#: cp/semantics.c:6560
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:6563
+#: cp/semantics.c:6566
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: cp/semantics.c:6576
+#: cp/semantics.c:6579
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6625
+#: cp/semantics.c:6628
 #, gcc-internal-format
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr "%qD không phải một biến trong mệnh đề %<depend%>"
 
-#: cp/semantics.c:6910
+#: cp/semantics.c:6913
 #, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6914
+#: cp/semantics.c:6917
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6979
+#: cp/semantics.c:6982
 #, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr "chỉ số %<device%> phải là số nguyên"
 
-#: cp/semantics.c:7008
+#: cp/semantics.c:7011
 #, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr "chỉ số %<device%> phải là số nguyên"
 
-#: cp/semantics.c:7037
+#: cp/semantics.c:7040
 #, gcc-internal-format
 msgid "%<num_tasks%> expression must be integral"
 msgstr "%<num_teams%> biểu thức phải nguyên"
 
-#: cp/semantics.c:7066
+#: cp/semantics.c:7069
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:7105
+#: cp/semantics.c:7108
 #, fuzzy, gcc-internal-format
 #| msgid "%<tile%> value must be integral"
 msgid "%<tile%> argument needs integral type"
 msgstr "giá trị %<tile%> phải là số nguyên"
 
-#: cp/semantics.c:7524
+#: cp/semantics.c:7527
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.c:7538
+#: cp/semantics.c:7541
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr ""
 
-#: cp/semantics.c:7743
+#: cp/semantics.c:7746
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.c:8171
+#: cp/semantics.c:8174
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.c:8398 cp/semantics.c:8408
+#: cp/semantics.c:8401 cp/semantics.c:8411
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.c:8702
+#: cp/semantics.c:8705
 #, gcc-internal-format
 msgid "static assertion failed"
 msgstr "thẩm tra tĩnh gặp lỗi"
 
-#: cp/semantics.c:8704
+#: cp/semantics.c:8707
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr "thẩm tra tĩnh gặp lỗi: %s"
 
-#: cp/semantics.c:8709
+#: cp/semantics.c:8712
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr ""
 
-#: cp/semantics.c:8739
+#: cp/semantics.c:8742
 #, gcc-internal-format
 msgid "argument to decltype must be an expression"
 msgstr ""
 
-#: cp/semantics.c:8767
+#: cp/semantics.c:8770
 #, gcc-internal-format
 msgid "decltype cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/semantics.c:9308
+#: cp/semantics.c:9311
 #, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.c:9361
+#: cp/semantics.c:9364
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.c:9363
+#: cp/semantics.c:9366
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:9381
+#: cp/semantics.c:9384
 #, fuzzy, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "đối số không được hỗ trợ cho %<__builtin_return_address%>"
 
-#: cp/tree.c:1276
+#: cp/tree.c:1295
 #, gcc-internal-format
 msgid "%qV qualifiers cannot be applied to %qT"
 msgstr ""
 
-#: cp/tree.c:1788
+#: cp/tree.c:1807
 #, gcc-internal-format
 msgid "lambda-expression in a constant expression"
 msgstr "Gặp biểu thức lambda trong biểu thức bất biến"
 
-#: cp/tree.c:1792
+#: cp/tree.c:1811
 #, fuzzy, gcc-internal-format
 #| msgid "lambda-expression in a constant expression"
 msgid "statement-expression in a constant expression"
 msgstr "Gặp biểu thức lambda trong biểu thức bất biến"
 
-#: cp/tree.c:4050
+#: cp/tree.c:4083
 #, gcc-internal-format
-msgid "the calling convention for %qT changes in -fabi-version=12 (GCC 8)"
+msgid "-fabi-version=13 (GCC 8.2) fixes the calling convention for %qT, which was accidentally changed in 8.1"
 msgstr ""
 
-#: cp/tree.c:4055
+#: cp/tree.c:4087
 #, gcc-internal-format
+msgid "-fabi-version=12 (GCC 8.1) accidentally changes the calling convention for %qT"
+msgstr ""
+
+#: cp/tree.c:4090
+#, fuzzy, gcc-internal-format
+#| msgid "  declared here"
+msgid " declared here"
+msgstr "  đã được khai báo ở đây"
+
+#: cp/tree.c:4094
+#, gcc-internal-format
+msgid "the calling convention for %qT changes in -fabi-version=13 (GCC 8.2)"
+msgstr ""
+
+#: cp/tree.c:4096
+#, gcc-internal-format
 msgid " because all of its copy and move constructors are deleted"
 msgstr ""
 
-#: cp/tree.c:4416
+#: cp/tree.c:4464
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to %qD with void return type"
 msgstr "Thuộc tính %qE cần kiểu trả về là void"
 
-#: cp/tree.c:4423
+#: cp/tree.c:4471
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr "thuộc tính %qE chỉ áp dụng cho các hàm"
 
-#: cp/tree.c:4475
+#: cp/tree.c:4523
 #, gcc-internal-format
 msgid "requested init_priority is not an integer constant"
 msgstr ""
 
-#: cp/tree.c:4497
+#: cp/tree.c:4545
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr ""
 
-#: cp/tree.c:4505
+#: cp/tree.c:4553
 #, gcc-internal-format
 msgid "requested init_priority is out of range"
 msgstr ""
 
-#: cp/tree.c:4515
+#: cp/tree.c:4563
 #, gcc-internal-format
 msgid "requested init_priority is reserved for internal use"
 msgstr ""
 
-#: cp/tree.c:4526
+#: cp/tree.c:4574
 #, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr ""
 
-#: cp/tree.c:4553
+#: cp/tree.c:4601
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as member of %qT"
 msgid "redeclaration of %qD adds abi tag %qE"
 msgstr "sự khai báo của %qD như là thành viên của %qT"
 
-#: cp/tree.c:4573
+#: cp/tree.c:4621
 #, gcc-internal-format
 msgid "the %qE attribute requires arguments"
 msgstr "thuộc tính %qE cần tham số"
 
-#: cp/tree.c:4584
+#: cp/tree.c:4632
 #, gcc-internal-format
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr ""
 
-#: cp/tree.c:4597 cp/tree.c:4610
+#: cp/tree.c:4645 cp/tree.c:4658
 #, gcc-internal-format
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr ""
 
-#: cp/tree.c:4599
+#: cp/tree.c:4647
 #, gcc-internal-format
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr ""
 
-#: cp/tree.c:4612
+#: cp/tree.c:4660
 #, gcc-internal-format
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr ""
 
-#: cp/tree.c:4636
+#: cp/tree.c:4684
 #, gcc-internal-format
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr ""
 
-#: cp/tree.c:4642
+#: cp/tree.c:4690
 #, gcc-internal-format
 msgid "%qE attribute applied to %qT after its definition"
 msgstr ""
 
-#: cp/tree.c:4649
+#: cp/tree.c:4697
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr ""
 
-#: cp/tree.c:4656
+#: cp/tree.c:4704
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr ""
 
-#: cp/tree.c:4678
+#: cp/tree.c:4726
 #, gcc-internal-format
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr ""
 
-#: cp/tree.c:4684
+#: cp/tree.c:4732
 #, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr ""
 
-#: cp/tree.c:5440
+#: cp/tree.c:5488
 #, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr ""
 
-#: cp/tree.c:5453
+#: cp/tree.c:5501
 #, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr "lang_* check: gặp lỗi trong %s, tại %s:%d"
@@ -50106,107 +50167,107 @@
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr ""
 
-#: cp/typeck2.c:1496 cp/typeck2.c:1523
+#: cp/typeck2.c:1499 cp/typeck2.c:1526
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "thiếu bộ khởi tạo cho thành viên %qD"
 
-#: cp/typeck2.c:1504
+#: cp/typeck2.c:1507
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr ""
 
-#: cp/typeck2.c:1511
+#: cp/typeck2.c:1514
 #, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr ""
 
-#: cp/typeck2.c:1587
+#: cp/typeck2.c:1590
 #, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr ""
 
-#: cp/typeck2.c:1660
+#: cp/typeck2.c:1663
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr ""
 
-#: cp/typeck2.c:1671
+#: cp/typeck2.c:1674
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr ""
 
-#: cp/typeck2.c:1858
+#: cp/typeck2.c:1861
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr ""
 
-#: cp/typeck2.c:1872
+#: cp/typeck2.c:1875
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr ""
 
-#: cp/typeck2.c:1898
+#: cp/typeck2.c:1901
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr ""
 
-#: cp/typeck2.c:1900
+#: cp/typeck2.c:1903
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "toán hạng cơ sở của %<->%> không phải là một con trỏ"
 
-#: cp/typeck2.c:1927
+#: cp/typeck2.c:1930
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr ""
 
-#: cp/typeck2.c:1936
+#: cp/typeck2.c:1939
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr ""
 
-#: cp/typeck2.c:1958
+#: cp/typeck2.c:1961
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2018
+#: cp/typeck2.c:2021
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr ""
 
-#: cp/typeck2.c:2029
+#: cp/typeck2.c:2032
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr ""
 
-#: cp/typeck2.c:2037
+#: cp/typeck2.c:2040
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++2a"
 msgstr ""
 
-#: cp/typeck2.c:2080
+#: cp/typeck2.c:2083
 #, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2096
+#: cp/typeck2.c:2099
 #, gcc-internal-format
 msgid "cannot deduce template arguments for %qT from ()"
 msgstr ""
 
-#: cp/typeck2.c:2114
+#: cp/typeck2.c:2117
 #, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr ""
 
-#: cp/typeck2.c:2341
+#: cp/typeck2.c:2344
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr ""
 
-#: cp/typeck2.c:2344
+#: cp/typeck2.c:2347
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr ""
@@ -50421,11 +50482,11 @@
 msgstr ""
 
 #: fortran/array.c:221 fortran/array.c:661 fortran/check.c:2849
-#: fortran/check.c:5222 fortran/check.c:5260 fortran/check.c:5302
-#: fortran/check.c:5329 fortran/check.c:5529 fortran/match.c:1821
+#: fortran/check.c:5225 fortran/check.c:5263 fortran/check.c:5305
+#: fortran/check.c:5332 fortran/check.c:5532 fortran/match.c:1821
 #: fortran/match.c:3174 fortran/match.c:3516 fortran/match.c:3712
-#: fortran/simplify.c:2909 fortran/simplify.c:2939 fortran/simplify.c:5764
-#: fortran/simplify.c:7658
+#: fortran/simplify.c:2909 fortran/simplify.c:2939 fortran/simplify.c:5769
+#: fortran/simplify.c:7663
 #, gcc-internal-format
 msgid "Coarrays disabled at %C, use %<-fcoarray=%> to enable"
 msgstr ""
@@ -50561,121 +50622,127 @@
 msgid "DO-iterator %qs at %L is inside iterator of the same name"
 msgstr ""
 
-#: fortran/array.c:1073 fortran/array.c:1255
+#: fortran/array.c:1073 fortran/array.c:1264
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in array constructor at %C"
 msgstr ""
 
-#: fortran/array.c:1129
+#: fortran/array.c:1105
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "%qs cannot appear in a constant-expression"
+msgid "NULL() at %C cannot appear in an array constructor"
+msgstr "%qs không thể xuất hiện trong biểu thức hằng"
+
+#: fortran/array.c:1138
 #, gcc-internal-format, gfc-internal-format
 msgid "[...] style array constructors at %C"
 msgstr ""
 
-#: fortran/array.c:1149
+#: fortran/array.c:1158
 #, gcc-internal-format, gfc-internal-format
 msgid "Array constructor including type specification at %C"
 msgstr ""
 
-#: fortran/array.c:1155 fortran/match.c:4148
+#: fortran/array.c:1164 fortran/match.c:4148
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-spec at %L cannot contain a deferred type parameter"
 msgstr ""
 
-#: fortran/array.c:1163
+#: fortran/array.c:1172
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-spec at %L cannot contain an asterisk for a type parameter"
 msgstr ""
 
-#: fortran/array.c:1181
+#: fortran/array.c:1190
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty array constructor at %C is not allowed"
 msgstr ""
 
-#: fortran/array.c:1218 fortran/array.c:1228
+#: fortran/array.c:1227 fortran/array.c:1237
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible typespec for array element at %L"
 msgstr "Đặc tả kiểu không tương thích cho phần tử mảng tại %L"
 
-#: fortran/array.c:1302
+#: fortran/array.c:1311
 #, gcc-internal-format, gfc-internal-format
 msgid "Element in %s array constructor at %L is %s"
 msgstr ""
 
-#: fortran/array.c:1633
+#: fortran/array.c:1642
 #, gcc-internal-format, gfc-internal-format
 msgid "Iterator step at %L cannot be zero"
 msgstr ""
 
-#: fortran/array.c:1770
+#: fortran/array.c:1779
 #, gcc-internal-format
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit.   See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/array.c:1940
+#: fortran/array.c:1949
 #, gcc-internal-format, gfc-internal-format
 msgid "AC-IMPLIED-DO initial expression references control variable at %L"
 msgstr ""
 
-#: fortran/array.c:1947
+#: fortran/array.c:1956
 #, gcc-internal-format, gfc-internal-format
 msgid "AC-IMPLIED-DO final expression references control variable at %L"
 msgstr ""
 
-#: fortran/array.c:1954
+#: fortran/array.c:1963
 #, gcc-internal-format, gfc-internal-format
 msgid "AC-IMPLIED-DO step expression references control variable at %L"
 msgstr ""
 
-#: fortran/array.c:1966
+#: fortran/array.c:1975
 #, gcc-internal-format, gfc-internal-format
 msgid "Array constructor value at %L shall not be unlimited polymorphic [F2008: C4106]"
 msgstr ""
 
-#: fortran/array.c:2055
+#: fortran/array.c:2067
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Different CHARACTER lengths (%ld/%ld) in array constructor"
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor at %L"
 msgstr "Bộ dựng mảng chứa các chiều dài KÝ_TỰ khác nhau (%ld/%ld)"
 
-#: fortran/array.c:2174
+#: fortran/array.c:2186
 #, gcc-internal-format
 msgid "spec_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2233
+#: fortran/array.c:2245
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2237
+#: fortran/array.c:2249
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Coarray declaration at %C"
 msgid "Bad array dimension at %L"
 msgstr "Khai báo Coarray tại %C"
 
-#: fortran/array.c:2264 fortran/data.c:552 fortran/data.c:571
-#: fortran/data.c:585 fortran/data.c:714
+#: fortran/array.c:2276 fortran/data.c:563 fortran/data.c:582
+#: fortran/data.c:596 fortran/data.c:725
 #, fuzzy, gcc-internal-format
 #| msgid "gimplification failed"
 msgid "Simplification error"
 msgstr "gimplification gặp lỗi"
 
-#: fortran/array.c:2376
+#: fortran/array.c:2388
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimen_type"
 msgstr ""
 
-#: fortran/array.c:2427
+#: fortran/array.c:2439
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2472
+#: fortran/array.c:2484
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad EXPR_ARRAY expr"
 msgstr ""
 
-#: fortran/array.c:2620
+#: fortran/array.c:2632
 #, gcc-internal-format
 msgid "gfc_find_array_ref(): No ref found"
 msgstr ""
@@ -50728,7 +50795,7 @@
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or PROCEDURE"
 msgstr "đối số %qs của %qs intrinsict tại %L phải là NGUYÊN hay THỦ TỤC"
 
-#: fortran/check.c:205 fortran/check.c:6658
+#: fortran/check.c:205 fortran/check.c:6661
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a constant"
 msgstr "đối số %qs của %qs intrinsict tại %L phải là hằng"
@@ -50844,7 +50911,7 @@
 msgid "Unequal character lengths (%ld/%ld) in %s at %L"
 msgstr ""
 
-#: fortran/check.c:946 fortran/check.c:6602
+#: fortran/check.c:946 fortran/check.c:6605
 #, gcc-internal-format
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have the same type"
 msgstr ""
@@ -51081,9 +51148,9 @@
 msgstr ""
 
 #: fortran/check.c:1939 fortran/check.c:2525 fortran/check.c:2628
-#: fortran/check.c:2835 fortran/check.c:2880 fortran/check.c:4256
-#: fortran/check.c:4390 fortran/check.c:4445 fortran/check.c:5515
-#: fortran/check.c:5644
+#: fortran/check.c:2835 fortran/check.c:2880 fortran/check.c:4259
+#: fortran/check.c:4393 fortran/check.c:4448 fortran/check.c:5518
+#: fortran/check.c:5647
 #, gcc-internal-format
 msgid "%qs intrinsic with KIND argument at %L"
 msgstr ""
@@ -51280,7 +51347,7 @@
 msgid "NULL intrinsic with allocatable MOLD at %L"
 msgstr ""
 
-#: fortran/check.c:3768 fortran/check.c:5591
+#: fortran/check.c:3768 fortran/check.c:5594
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must provide at least as many elements as there are .TRUE. values in %qs (%ld/%d)"
 msgstr ""
@@ -51300,372 +51367,372 @@
 msgid "%qs argument of %qs intrinsic at %L must not be a subobject of %qs"
 msgstr ""
 
-#: fortran/check.c:3901
+#: fortran/check.c:3904
 #, gcc-internal-format, gfc-internal-format
 msgid "The argument of the RANK intrinsic at %L must be a data object"
 msgstr ""
 
-#: fortran/check.c:4005
+#: fortran/check.c:4008
 #, gcc-internal-format
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L must be an array of constant size"
 msgstr ""
 
-#: fortran/check.c:4015
+#: fortran/check.c:4018
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L is empty"
 msgstr ""
 
-#: fortran/check.c:4022
+#: fortran/check.c:4025
 #, gcc-internal-format
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L has more than %d elements"
 msgstr ""
 
-#: fortran/check.c:4039
+#: fortran/check.c:4042
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has negative element (%d)"
 msgstr ""
 
-#: fortran/check.c:4071
+#: fortran/check.c:4074
 #, gcc-internal-format, gfc-internal-format
 msgid "Element %d of actual argument of RESHAPE at %L cannot be negative"
 msgstr ""
 
-#: fortran/check.c:4109
+#: fortran/check.c:4112
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has wrong number of elements (%d/%d)"
 msgstr ""
 
-#: fortran/check.c:4127
+#: fortran/check.c:4130
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has out-of-range dimension (%d)"
 msgstr ""
 
-#: fortran/check.c:4136
+#: fortran/check.c:4139
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has invalid permutation of dimensions (dimension %qd duplicated)"
 msgstr ""
 
-#: fortran/check.c:4172
+#: fortran/check.c:4175
 #, gcc-internal-format, gfc-internal-format
 msgid "Without padding, there are not enough elements in the intrinsic RESHAPE source at %L to match the shape"
 msgstr ""
 
-#: fortran/check.c:4189 fortran/check.c:4208
+#: fortran/check.c:4192 fortran/check.c:4211
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L cannot be of type %s"
 msgstr ""
 
-#: fortran/check.c:4199 fortran/check.c:4218
+#: fortran/check.c:4202 fortran/check.c:4221
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of an extensible type"
 msgstr ""
 
-#: fortran/check.c:4317
+#: fortran/check.c:4320
 #, gcc-internal-format
 msgid "SELECTED_REAL_KIND with neither %<P%> nor %<R%> argument at %L"
 msgstr ""
 
-#: fortran/check.c:4348
+#: fortran/check.c:4351
 #, gcc-internal-format
 msgid "%qs intrinsic with RADIX argument at %L"
 msgstr ""
 
-#: fortran/check.c:4383
+#: fortran/check.c:4386
 #, gcc-internal-format
 msgid "%<source%> argument of %<shape%> intrinsic at %L must not be an assumed size array"
 msgstr ""
 
-#: fortran/check.c:4460 fortran/check.c:6641
+#: fortran/check.c:4463 fortran/check.c:6644
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be a procedure"
 msgstr ""
 
-#: fortran/check.c:4473 fortran/check.c:4612 fortran/check.c:6633
+#: fortran/check.c:4476 fortran/check.c:4615 fortran/check.c:6636
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be TYPE(*)"
 msgstr ""
 
-#: fortran/check.c:4484 fortran/check.c:4624
+#: fortran/check.c:4487 fortran/check.c:4627
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be an assumed-size array"
 msgstr ""
 
-#: fortran/check.c:4554
+#: fortran/check.c:4557
 #, gcc-internal-format
 msgid "is_c_interoperable(): gfc_simplify_expr failed"
 msgstr ""
 
-#: fortran/check.c:4603
+#: fortran/check.c:4606
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be an interoperable data entity: %s"
 msgstr ""
 
-#: fortran/check.c:4642
+#: fortran/check.c:4645
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_1 at %L to C_ASSOCIATED shall have the type TYPE(C_PTR) or TYPE(C_FUNPTR)"
 msgstr ""
 
-#: fortran/check.c:4656
+#: fortran/check.c:4659
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_2 at %L to C_ASSOCIATED shall have the same type as C_PTR_1: %s instead of %s"
 msgstr ""
 
-#: fortran/check.c:4680
+#: fortran/check.c:4683
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_POINTER shall have the type TYPE(C_PTR)"
 msgstr ""
 
-#: fortran/check.c:4692
+#: fortran/check.c:4695
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER must be a pointer"
 msgstr ""
 
-#: fortran/check.c:4699
+#: fortran/check.c:4702
 #, gcc-internal-format, gfc-internal-format
 msgid "FPTR argument at %L to C_F_POINTER shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:4706
+#: fortran/check.c:4709
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:4713
+#: fortran/check.c:4716
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected SHAPE argument at %L to C_F_POINTER with scalar FPTR"
 msgstr ""
 
-#: fortran/check.c:4719
+#: fortran/check.c:4722
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected SHAPE argument to C_F_POINTER with array FPTR at %L"
 msgstr ""
 
-#: fortran/check.c:4738
+#: fortran/check.c:4741
 #, gcc-internal-format, gfc-internal-format
 msgid "SHAPE argument at %L to C_F_POINTER must have the same size as the RANK of FPTR"
 msgstr ""
 
-#: fortran/check.c:4748
+#: fortran/check.c:4751
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic FPTR at %L to C_F_POINTER"
 msgstr ""
 
-#: fortran/check.c:4753
+#: fortran/check.c:4756
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array FPTR at %L to C_F_POINTER: %s"
 msgstr ""
 
-#: fortran/check.c:4769
+#: fortran/check.c:4772
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_PROCPOINTER shall have the type TYPE(C_FUNPTR)"
 msgstr ""
 
-#: fortran/check.c:4781
+#: fortran/check.c:4784
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall be a procedure pointer"
 msgstr ""
 
-#: fortran/check.c:4788
+#: fortran/check.c:4791
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:4794
+#: fortran/check.c:4797
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure pointer at %L to C_F_PROCPOINTER"
 msgstr ""
 
-#: fortran/check.c:4808
+#: fortran/check.c:4811
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:4823
+#: fortran/check.c:4826
 #, gcc-internal-format
 msgid "Function result %qs at %L is invalid as X argument to C_FUNLOC"
 msgstr ""
 
-#: fortran/check.c:4831
+#: fortran/check.c:4834
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall be a procedure or a procedure pointer"
 msgstr ""
 
-#: fortran/check.c:4837
+#: fortran/check.c:4840
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure at %L to C_FUNLOC"
 msgstr ""
 
-#: fortran/check.c:4851
+#: fortran/check.c:4854
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:4857
+#: fortran/check.c:4860
 #, gcc-internal-format, gfc-internal-format
 msgid "X argument at %L to C_LOC shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:4868
+#: fortran/check.c:4871
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall have either the POINTER or the TARGET attribute"
 msgstr ""
 
-#: fortran/check.c:4876
+#: fortran/check.c:4879
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall be not be a zero-sized string"
 msgstr ""
 
-#: fortran/check.c:4885
+#: fortran/check.c:4888
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument at %L to C_LOC shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:4892
+#: fortran/check.c:4895
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array at %L as argument to C_LOC: %s"
 msgstr ""
 
-#: fortran/check.c:4903
+#: fortran/check.c:4906
 #, gcc-internal-format, gfc-internal-format
 msgid "Array of interoperable type at %L to C_LOC which is nonallocatable and neither assumed size nor explicit size"
 msgstr ""
 
-#: fortran/check.c:4908
+#: fortran/check.c:4911
 #, gcc-internal-format, gfc-internal-format
 msgid "Array section at %L to C_LOC"
 msgstr ""
 
-#: fortran/check.c:4936
+#: fortran/check.c:4939
 #, gcc-internal-format, gfc-internal-format
 msgid "non double precision REAL argument to %s intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:4949
+#: fortran/check.c:4952
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be less than rank %d"
 msgstr ""
 
-#: fortran/check.c:4968
+#: fortran/check.c:4971
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L is not a valid dimension index"
 msgstr ""
 
-#: fortran/check.c:5231
+#: fortran/check.c:5234
 #, gcc-internal-format, gfc-internal-format
 msgid "%s argument to IMAGE_INDEX must be a rank one array at %L"
 msgstr ""
 
-#: fortran/check.c:5242
+#: fortran/check.c:5245
 #, gcc-internal-format, gfc-internal-format
 msgid "The number of array elements of the SUB argument to IMAGE_INDEX at %L shall be %d (corank) not %d"
 msgstr ""
 
-#: fortran/check.c:5275
+#: fortran/check.c:5278
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to NUM_IMAGES at %L"
 msgstr ""
 
-#: fortran/check.c:5288
+#: fortran/check.c:5291
 #, gcc-internal-format, gfc-internal-format
 msgid "FAILED= argument to NUM_IMAGES at %L"
 msgstr ""
 
-#: fortran/check.c:5312
+#: fortran/check.c:5315
 #, gcc-internal-format, gfc-internal-format
 msgid "TEAM argument at %L to the intrinsic TEAM_NUMBER shall be of type TEAM_TYPE"
 msgstr ""
 
-#: fortran/check.c:5338
+#: fortran/check.c:5341
 #, gcc-internal-format, gfc-internal-format
 msgid "DIM argument without COARRAY argument not allowed for THIS_IMAGE intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:5345
+#: fortran/check.c:5348
 #, gcc-internal-format, gfc-internal-format
 msgid "The DISTANCE argument may not be specified together with the COARRAY or DIM argument in intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:5356
+#: fortran/check.c:5359
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected DIM argument with noncoarray argument at %L"
 msgstr ""
 
-#: fortran/check.c:5374
+#: fortran/check.c:5377
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to THIS_IMAGE at %L"
 msgstr ""
 
-#: fortran/check.c:5454
+#: fortran/check.c:5457
 #, gcc-internal-format
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L must not be %s"
 msgstr ""
 
-#: fortran/check.c:5483
+#: fortran/check.c:5486
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic TRANSFER at %L has partly undefined result: source size %ld < result size %ld"
 msgstr ""
 
-#: fortran/check.c:5605
+#: fortran/check.c:5608
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must have the same rank as %qs or be a scalar"
 msgstr ""
 
-#: fortran/check.c:5618
+#: fortran/check.c:5621
 #, gcc-internal-format
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have identical shape."
 msgstr ""
 
-#: fortran/check.c:5861 fortran/check.c:5893
+#: fortran/check.c:5864 fortran/check.c:5896
 #, gcc-internal-format
 msgid "Size of %qs argument of %qs intrinsic at %L too small (%i/%i)"
 msgstr ""
 
-#: fortran/check.c:5901
+#: fortran/check.c:5904
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many arguments to %s at %L"
 msgstr "Quá nhiều đối số cho %s tại %L"
 
-#: fortran/check.c:5919
+#: fortran/check.c:5922
 #, gcc-internal-format
 msgid "fe_runtime_error string must be null terminated"
 msgstr ""
 
-#: fortran/check.c:5931
+#: fortran/check.c:5934
 #, gcc-internal-format, gfc-internal-format
 msgid "fe_runtime_error: Wrong number of arguments (%d instead of %d)"
 msgstr ""
 
-#: fortran/check.c:5971
+#: fortran/check.c:5974
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:5990
+#: fortran/check.c:5993
 #, gcc-internal-format, gfc-internal-format
 msgid "Real COUNT_RATE argument to SYSTEM_CLOCK at %L"
 msgstr ""
 
-#: fortran/check.c:6000
+#: fortran/check.c:6003
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT_RATE argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:6017
+#: fortran/check.c:6020
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT_MAX argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:6234
+#: fortran/check.c:6237
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of a kind not wider than the default kind (%d)"
 msgstr ""
 
-#: fortran/check.c:6586 fortran/check.c:6594
+#: fortran/check.c:6589 fortran/check.c:6597
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or LOGICAL"
 msgstr ""
 
-#: fortran/check.c:6625
+#: fortran/check.c:6628
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic function NULL at %L cannot be an actual argument to STORAGE_SIZE, because it returns a disassociated pointer"
 msgstr ""
@@ -51677,7 +51744,7 @@
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:727 fortran/decl.c:3636 fortran/decl.c:10066
+#: fortran/class.c:727 fortran/decl.c:3655 fortran/decl.c:10091
 #, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr ""
@@ -51702,43 +51769,48 @@
 msgid "non-constant array in DATA statement %L"
 msgstr ""
 
-#: fortran/data.c:137
+#: fortran/data.c:140
 #, gcc-internal-format, gfc-internal-format
 msgid "failure to simplify substring reference in DATA statement at %L"
 msgstr ""
 
-#: fortran/data.c:170
+#: fortran/data.c:173
 #, gcc-internal-format, gfc-internal-format
 msgid "Unused initialization string at %L because variable has zero length"
 msgstr ""
 
-#: fortran/data.c:176
+#: fortran/data.c:179
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization string at %L was truncated to fit the variable (%ld/%ld)"
 msgstr ""
 
-#: fortran/data.c:265
+#: fortran/data.c:268
 #, gcc-internal-format
 msgid "%qs at %L already is initialized at %L"
 msgstr "“%qs” tại %L đã được khởi tạo tại %L rồi"
 
-#: fortran/data.c:289
+#: fortran/data.c:292
 #, gcc-internal-format, gfc-internal-format
 msgid "Data element below array lower bound at %L"
 msgstr ""
 
-#: fortran/data.c:306 fortran/data.c:395
+#: fortran/data.c:309 fortran/data.c:398
 #, gcc-internal-format, gfc-internal-format
 msgid "Data element above array upper bound at %L"
 msgstr ""
 
-#: fortran/data.c:336 fortran/data.c:505
+#: fortran/data.c:339 fortran/data.c:496
 #, gcc-internal-format
 msgid "re-initialization of %qs at %L"
 msgstr "khởi tạo lại của %qs tại %L"
 
-#: fortran/data.c:727
+#: fortran/data.c:515
 #, gcc-internal-format
+msgid "Nonpointer object %qs with default initialization shall not appear in a DATA statement at %L"
+msgstr ""
+
+#: fortran/data.c:738
+#, gcc-internal-format
 msgid "TODO: Vector sections in data statements"
 msgstr ""
 
@@ -51762,792 +51834,792 @@
 msgid "Invalid initializer %s in Data statement at %C"
 msgstr ""
 
-#: fortran/decl.c:536
+#: fortran/decl.c:537
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:573
+#: fortran/decl.c:574
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %C cannot appear within an INTERFACE"
 msgstr ""
 
-#: fortran/decl.c:597
+#: fortran/decl.c:598
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid substring in data-implied-do at %L in DATA statement"
 msgstr ""
 
-#: fortran/decl.c:619
+#: fortran/decl.c:620
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:664
+#: fortran/decl.c:662
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Empty old style initializer list at %C"
 msgstr "Sự khởi tạo kiểu cũ tại %C"
 
-#: fortran/decl.c:684
+#: fortran/decl.c:671
+#, gcc-internal-format, gfc-internal-format
+msgid "Array in initializer list at %L must have an explicit shape"
+msgstr ""
+
+#: fortran/decl.c:694
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Repeat spec invalid in scalar initializer at %C"
 msgstr "gặp yếu tố thừa trong bộ khởi tạo vô hướng"
 
-#: fortran/decl.c:689
+#: fortran/decl.c:699
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Repeat spec must be an integer at %C"
 msgstr "chiều dài véc-tơ phải là một hằng nguyên"
 
-#: fortran/decl.c:698
+#: fortran/decl.c:710
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected data constant after repeat spec at %C"
 msgstr "Cần tham chiếu thành phần tại %C"
 
-#: fortran/decl.c:729
+#: fortran/decl.c:742
 #, gcc-internal-format, gfc-internal-format
 msgid "End of scalar initializer expected at %C"
 msgstr ""
 
-#: fortran/decl.c:758
+#: fortran/decl.c:773
 #, fuzzy, gcc-internal-format, gfc-internal-format
-msgid "Expected constant array-spec in initializer list at %L"
-msgstr "Sự khởi tạo kiểu cũ tại %C"
-
-#: fortran/decl.c:767
-#, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Not enough elements in array initializer at %C"
 msgstr "gặp yếu tố thừa trong bộ khởi tạo mảng"
 
-#: fortran/decl.c:769
+#: fortran/decl.c:775
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Too many elements in array initializer at %C"
 msgstr "gặp yếu tố thừa trong bộ khởi tạo mảng"
 
-#: fortran/decl.c:790
+#: fortran/decl.c:795
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in old style initializer list at %C"
 msgstr "Lỗi trong khởi tạo con trỏ tại %C"
 
-#: fortran/decl.c:812
+#: fortran/decl.c:821
 #, gcc-internal-format, gfc-internal-format
 msgid "The assumed-rank array at %C shall not have a codimension"
 msgstr ""
 
-#: fortran/decl.c:876
+#: fortran/decl.c:885
 #, gcc-internal-format, gfc-internal-format
 msgid "Sum of array rank %d and corank %d at %C exceeds maximum allowed dimensions of %d"
 msgstr ""
 
-#: fortran/decl.c:900
+#: fortran/decl.c:909
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad INTENT specification at %C"
 msgstr ""
 
-#: fortran/decl.c:921
+#: fortran/decl.c:930
 #, gcc-internal-format, gfc-internal-format
 msgid "deferred type parameter at %C"
 msgstr ""
 
-#: fortran/decl.c:1004 fortran/resolve.c:11705
+#: fortran/decl.c:1013 fortran/resolve.c:11725
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
 
-#: fortran/decl.c:1030
+#: fortran/decl.c:1039
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style character length at %C"
 msgstr ""
 
-#: fortran/decl.c:1061
+#: fortran/decl.c:1070
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in character length specification at %C"
 msgstr ""
 
-#: fortran/decl.c:1212 fortran/decl.c:1217 fortran/decl.c:1266
+#: fortran/decl.c:1221 fortran/decl.c:1226 fortran/decl.c:1275
 #, gcc-internal-format
 msgid "Procedure %qs at %C is already defined at %L"
 msgstr "Thủ tục “%qs” tại %C đã được định nghĩa trước tại %L"
 
-#: fortran/decl.c:1222
+#: fortran/decl.c:1231
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure %qs at %C is already defined at %L"
 msgid "Contained procedure %qs at %C clashes with procedure defined at %L"
 msgstr "Thủ tục “%qs” tại %C đã được định nghĩa trước tại %L"
 
-#: fortran/decl.c:1231
+#: fortran/decl.c:1240
 #, gcc-internal-format
 msgid "Name %qs at %C is already defined as a generic interface at %L"
 msgstr "Tên “%qs” tại %C đã được định nghĩa trước tại %L"
 
-#: fortran/decl.c:1244
+#: fortran/decl.c:1253
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %C has an explicit interface from a previous declaration"
 msgstr "sự khai báo lại %q+D khác trong %<constexpr%>"
 
-#: fortran/decl.c:1257
+#: fortran/decl.c:1266
 #, gcc-internal-format
 msgid "Procedure %qs defined in interface body at %L clashes with internal procedure defined at %C"
 msgstr ""
 
-#: fortran/decl.c:1335
+#: fortran/decl.c:1344
 #, gcc-internal-format
 msgid "Procedure %qs at %L must have the BIND(C) attribute to be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:1362
+#: fortran/decl.c:1371
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because derived type %qs is not C interoperable"
 msgstr ""
 
-#: fortran/decl.c:1369
+#: fortran/decl.c:1378
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because it is polymorphic"
 msgstr ""
 
-#: fortran/decl.c:1376
+#: fortran/decl.c:1385
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument of the BIND(C) procedure %qs but may not be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:1391
+#: fortran/decl.c:1400
 #, gcc-internal-format
 msgid "Character argument %qs at %L must be length 1 because procedure %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1404
+#: fortran/decl.c:1413
 #, gcc-internal-format
 msgid "Variable %qs at %L with ALLOCATABLE attribute in procedure %qs with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1412
+#: fortran/decl.c:1421
 #, gcc-internal-format
 msgid "Variable %qs at %L with POINTER attribute in procedure %qs with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1421
+#: fortran/decl.c:1430
 #, gcc-internal-format
 msgid "Scalar variable %qs at %L with POINTER or ALLOCATABLE in procedure %qs with BIND(C) is not yet supported"
 msgstr ""
 
-#: fortran/decl.c:1430
+#: fortran/decl.c:1439
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the OPTIONAL and the VALUE attribute because procedure %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1437
+#: fortran/decl.c:1446
 #, gcc-internal-format
 msgid "Variable %qs at %L with OPTIONAL attribute in procedure %qs which is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1448
+#: fortran/decl.c:1457
 #, gcc-internal-format
 msgid "Assumed-shape array %qs at %L as dummy argument to the BIND(C) procedure %qs at %L"
 msgstr ""
 
-#: fortran/decl.c:1516
+#: fortran/decl.c:1525
 #, gcc-internal-format
 msgid "Symbol %qs at %C also declared as a type at %L"
 msgstr "Ký hiệu “%qs” tại %C đã sẵn được khai báo tại %L"
 
-#: fortran/decl.c:1575
+#: fortran/decl.c:1584
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %C must be declared with a C interoperable kind since common block %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1615
+#: fortran/decl.c:1624
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER length must be a constant at %L"
 msgstr "chiều dài véc-tơ phải là một hằng nguyên"
 
-#: fortran/decl.c:1630
+#: fortran/decl.c:1639
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression at %L is being truncated (%ld/%ld)"
 msgstr ""
 
-#: fortran/decl.c:1638
+#: fortran/decl.c:1647
 #, gcc-internal-format, gfc-internal-format
 msgid "The CHARACTER elements of the array constructor at %L must have the same length (%ld/%ld)"
 msgstr ""
 
-#: fortran/decl.c:1729
+#: fortran/decl.c:1738
 #, gcc-internal-format
 msgid "Initializer not allowed for PARAMETER %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:1739
+#: fortran/decl.c:1748
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER at %L is missing an initializer"
 msgstr ""
 
-#: fortran/decl.c:1749
+#: fortran/decl.c:1758
 #, gcc-internal-format
 msgid "Variable %qs at %C with an initializer already appears in a DATA statement"
 msgstr ""
 
-#: fortran/decl.c:1792
+#: fortran/decl.c:1801
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot initialize parameter array at %L with variable length elements"
 msgstr ""
 
-#: fortran/decl.c:1861
+#: fortran/decl.c:1870
 #, gcc-internal-format, gfc-internal-format
 msgid "Can't initialize implied-shape array at %L with scalar"
 msgstr ""
 
-#: fortran/decl.c:1896
+#: fortran/decl.c:1905
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-constant lower bound in implied-shape declaration at %L"
 msgstr ""
 
-#: fortran/decl.c:1982 fortran/decl.c:1989
+#: fortran/decl.c:1991 fortran/decl.c:1998
 #, gcc-internal-format, gfc-internal-format
 msgid "Component at %C must have the POINTER attribute"
 msgstr ""
 
-#: fortran/decl.c:1998
+#: fortran/decl.c:2007
 #, fuzzy, gcc-internal-format
 msgid "Component %qs with CLASS at %C must be allocatable or pointer"
 msgstr "Đối số %qs của %qs với PASS(%s) tại %L phải là vô hướng"
 
-#: fortran/decl.c:2007
+#: fortran/decl.c:2016
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr ""
 
-#: fortran/decl.c:2031 fortran/symbol.c:2230
+#: fortran/decl.c:2040 fortran/symbol.c:2244
 #, gcc-internal-format
 msgid "Component %qs at %C already declared at %L"
 msgstr "Thành phần “%qs” tại %C đã sẵn được khai báo tại %L"
 
-#: fortran/decl.c:2079
+#: fortran/decl.c:2088
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer array component of structure at %C must have a deferred shape"
 msgstr ""
 
-#: fortran/decl.c:2088
+#: fortran/decl.c:2097
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component of structure at %C must have a deferred shape"
 msgstr ""
 
-#: fortran/decl.c:2097
+#: fortran/decl.c:2106
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have an explicit shape"
 msgstr ""
 
-#: fortran/decl.c:2114
+#: fortran/decl.c:2123
 #, gcc-internal-format
 msgid "Type parameter %qs at %C has no corresponding entry in the type parameter name list at %L"
 msgstr ""
 
-#: fortran/decl.c:2171
+#: fortran/decl.c:2180
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C is ambiguous"
 msgstr ""
 
-#: fortran/decl.c:2188
+#: fortran/decl.c:2197
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C may not have MOLD"
 msgstr ""
 
-#: fortran/decl.c:2205
+#: fortran/decl.c:2214
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of pointer at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:2226
+#: fortran/decl.c:2235
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in pointer initialization at %C"
 msgstr "Lỗi trong khởi tạo con trỏ tại %C"
 
-#: fortran/decl.c:2233
+#: fortran/decl.c:2242
 #, gcc-internal-format, gfc-internal-format
 msgid "non-NULL pointer initialization at %C"
 msgstr "Khởi tạo con trỏ khác KHÔNG tại %C"
 
-#: fortran/decl.c:2256
+#: fortran/decl.c:2265
 #, gcc-internal-format
 msgid "RESULT variable %qs at %L prohibits FUNCTION name %qs at %C from appearing in a specification statement"
 msgstr ""
 
-#: fortran/decl.c:2318
+#: fortran/decl.c:2327
 #, gcc-internal-format
 msgid "%qs not allowed outside STRUCTURE at %C"
 msgstr ""
 
-#: fortran/decl.c:2320
+#: fortran/decl.c:2329
 #, fuzzy, gcc-internal-format
 #| msgid "%qs at %C is not a member of the %qs structure"
 msgid "%qs at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr "%qs tại %C không phải là thành viên của cấu trúc %qs"
 
-#: fortran/decl.c:2327
+#: fortran/decl.c:2336
 #, fuzzy, gcc-internal-format
 #| msgid "%qs function cannot have arguments"
 msgid "%qs entity cannot have attributes at %C"
 msgstr "%qs hàm không có đối số"
 
-#: fortran/decl.c:2367
+#: fortran/decl.c:2376
 #, gcc-internal-format
 msgid "Non-PARAMETER symbol %qs at %L can't be implied-shape"
 msgstr ""
 
-#: fortran/decl.c:2377
+#: fortran/decl.c:2386
 #, gcc-internal-format, gfc-internal-format
 msgid "Implied-shape array at %L"
 msgstr ""
 
-#: fortran/decl.c:2422
+#: fortran/decl.c:2431
 #, gcc-internal-format, gfc-internal-format
 msgid "Explicit shaped array with nonconstant bounds at %C"
 msgstr ""
 
-#: fortran/decl.c:2501
+#: fortran/decl.c:2510
 #, gcc-internal-format
 msgid "%qs at %C is a redefinition of the declaration in the corresponding interface for MODULE PROCEDURE %qs"
 msgstr ""
 
-#: fortran/decl.c:2512
+#: fortran/decl.c:2521
 #, fuzzy, gcc-internal-format
 #| msgid "Function %qs at %L cannot have an initializer"
 msgid "%qs entity cannot have an initializer at %C"
 msgstr "Hàm %qs tại %L không thể có bộ khởi tạo"
 
-#: fortran/decl.c:2538 fortran/decl.c:8369
+#: fortran/decl.c:2547 fortran/decl.c:8388
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr ""
 
-#: fortran/decl.c:2546
+#: fortran/decl.c:2555
 #, gcc-internal-format
 msgid "Couldn't set pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:2609
+#: fortran/decl.c:2618
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style initialization at %C"
 msgstr "Sự khởi tạo kiểu cũ tại %C"
 
-#: fortran/decl.c:2617
+#: fortran/decl.c:2626
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr ""
 
-#: fortran/decl.c:2630
+#: fortran/decl.c:2639
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in old style initialization of %s at %C"
 msgstr "Lỗi trong khởi tạo con trỏ tại %C"
 
-#: fortran/decl.c:2650 fortran/decl.c:6661
+#: fortran/decl.c:2659 fortran/decl.c:6680
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr ""
 
-#: fortran/decl.c:2663
+#: fortran/decl.c:2672
 #, gcc-internal-format
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr ""
 
-#: fortran/decl.c:2672 fortran/decl.c:10240
+#: fortran/decl.c:2681 fortran/decl.c:10265
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr ""
 
-#: fortran/decl.c:2679
+#: fortran/decl.c:2688
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:2696
+#: fortran/decl.c:2705
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr ""
 
-#: fortran/decl.c:2710
+#: fortran/decl.c:2719
 #, gcc-internal-format, gfc-internal-format
 msgid "The component with KIND or LEN attribute at %C does not not appear in the type parameter list at %L"
 msgstr ""
 
-#: fortran/decl.c:2718
+#: fortran/decl.c:2727
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C that appears in the type parameter list at %L has neither the KIND nor LEN attribute"
 msgstr ""
 
-#: fortran/decl.c:2726
+#: fortran/decl.c:2735
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C which is a type parameter must be a scalar"
 msgstr ""
 
-#: fortran/decl.c:2789 fortran/decl.c:2825
+#: fortran/decl.c:2798 fortran/decl.c:2834
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr ""
 
-#: fortran/decl.c:2831
+#: fortran/decl.c:2840
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr ""
 
-#: fortran/decl.c:2890 fortran/decl.c:2967
+#: fortran/decl.c:2899 fortran/decl.c:2976
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis at %C"
 msgstr ""
 
-#: fortran/decl.c:2903 fortran/decl.c:3038
+#: fortran/decl.c:2912 fortran/decl.c:3047
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr ""
 
-#: fortran/decl.c:2911 fortran/decl.c:3044
+#: fortran/decl.c:2920 fortran/decl.c:3053
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr ""
 
-#: fortran/decl.c:2941 fortran/decl.c:3657
+#: fortran/decl.c:2950 fortran/decl.c:3676
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr ""
 
-#: fortran/decl.c:2954
+#: fortran/decl.c:2963
 #, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr ""
 
-#: fortran/decl.c:2965
+#: fortran/decl.c:2974
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr ""
 
-#: fortran/decl.c:3070
+#: fortran/decl.c:3079
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr ""
 
-#: fortran/decl.c:3202
+#: fortran/decl.c:3211
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:3291
+#: fortran/decl.c:3310
 #, gcc-internal-format, gfc-internal-format
 msgid "RECORD at %C is an extension, enable it with -fdec-structure"
 msgstr ""
 
-#: fortran/decl.c:3304
+#: fortran/decl.c:3323
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected after RECORD at %C"
 msgstr ""
 
-#: fortran/decl.c:3417
+#: fortran/decl.c:3436
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C cannot contain both ASSUMED and DEFERRED parameters"
 msgstr ""
 
-#: fortran/decl.c:3441
+#: fortran/decl.c:3460
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C does not contain enough parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3465
+#: fortran/decl.c:3484
 #, gcc-internal-format
 msgid "The derived parameter %qs at %C does not have a default value"
 msgstr ""
 
-#: fortran/decl.c:3497
+#: fortran/decl.c:3516
 #, gcc-internal-format, gfc-internal-format
 msgid "The parameter expression at %C must be of INTEGER type and not %s type"
 msgstr ""
 
-#: fortran/decl.c:3525
+#: fortran/decl.c:3544
 #, gcc-internal-format
 msgid "The KIND parameter %qs at %C cannot either be ASSUMED or DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:3532
+#: fortran/decl.c:3551
 #, fuzzy, gcc-internal-format
 msgid "The value for the KIND parameter %qs at %C does not reduce to a constant expression"
 msgstr "%qE không phải là biểu thức hằng"
 
-#: fortran/decl.c:3547
+#: fortran/decl.c:3566
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C contains too many parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3556
+#: fortran/decl.c:3575
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "parametrized derived type argument"
 msgid "Parameterized derived type at %C is ambiguous"
 msgstr "đối số kiểu được dẫn suất tham số hóa"
 
-#: fortran/decl.c:3819
+#: fortran/decl.c:3838
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type at %C"
 msgstr "kiểu BYTE tại %C"
 
-#: fortran/decl.c:3824
+#: fortran/decl.c:3843
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr ""
 
-#: fortran/decl.c:3846
+#: fortran/decl.c:3865
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C is not allowed for components"
 msgstr ""
 
-#: fortran/decl.c:3849
+#: fortran/decl.c:3868
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr "Giả định kiểu tại %C"
 
-#: fortran/decl.c:3872 fortran/decl.c:3903 fortran/decl.c:3932
-#: fortran/decl.c:4216
+#: fortran/decl.c:3891 fortran/decl.c:3922 fortran/decl.c:3951
+#: fortran/decl.c:4235
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr ""
 
-#: fortran/decl.c:3928
+#: fortran/decl.c:3947
 #, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr ""
 
-#: fortran/decl.c:3971 fortran/decl.c:4107 fortran/decl.c:4119
-#: fortran/decl.c:4133 fortran/decl.c:4611 fortran/decl.c:4619
+#: fortran/decl.c:3990 fortran/decl.c:4126 fortran/decl.c:4138
+#: fortran/decl.c:4152 fortran/decl.c:4630 fortran/decl.c:4638
 #, gcc-internal-format
 msgid "Type name %qs at %C is ambiguous"
 msgstr ""
 
-#: fortran/decl.c:4066
+#: fortran/decl.c:4085
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS statement at %C"
 msgstr "câu lệnh CLASS tại %C"
 
-#: fortran/decl.c:4148
+#: fortran/decl.c:4167
 #, gcc-internal-format
 msgid "Type name %qs at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr ""
 
-#: fortran/decl.c:4287
+#: fortran/decl.c:4306
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4296
+#: fortran/decl.c:4315
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr ""
 
-#: fortran/decl.c:4355
+#: fortran/decl.c:4374
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr ""
 
-#: fortran/decl.c:4401
+#: fortran/decl.c:4420
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4454
+#: fortran/decl.c:4473
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr ""
 
-#: fortran/decl.c:4464
+#: fortran/decl.c:4483
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4570
+#: fortran/decl.c:4589
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr ""
 
-#: fortran/decl.c:4577
+#: fortran/decl.c:4596
 #, gcc-internal-format, gfc-internal-format
 msgid "F2008: C1210 IMPORT statement at %C is not permitted in a module procedure interface body"
 msgstr ""
 
-#: fortran/decl.c:4582
+#: fortran/decl.c:4601
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C"
 msgstr "câu lệnh IMPORT tại %C"
 
-#: fortran/decl.c:4596
+#: fortran/decl.c:4615
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr ""
 
-#: fortran/decl.c:4625
+#: fortran/decl.c:4644
 #, gcc-internal-format
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr ""
 
-#: fortran/decl.c:4632
+#: fortran/decl.c:4651
 #, gcc-internal-format
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr ""
 
-#: fortran/decl.c:4673
+#: fortran/decl.c:4692
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IMPORT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5010
+#: fortran/decl.c:5029
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing codimension specification at %C"
 msgstr ""
 
-#: fortran/decl.c:5012
+#: fortran/decl.c:5031
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr ""
 
-#: fortran/decl.c:5107
+#: fortran/decl.c:5126
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr "Trùng thuộc tính %s tại %L"
 
-#: fortran/decl.c:5124
+#: fortran/decl.c:5143
 #, gcc-internal-format
 msgid "%s at %L is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:5141
+#: fortran/decl.c:5160
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5150
+#: fortran/decl.c:5169
 #, gcc-internal-format, gfc-internal-format
 msgid "KIND attribute at %C in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5158
+#: fortran/decl.c:5177
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qs argument of %qs intrinsic at %L must be INTEGER"
 msgid "Component with KIND attribute at %C must be INTEGER"
 msgstr "Tham số %qs của hạn chế %qs tại %L phải là SỐ-NGUYÊN"
 
-#: fortran/decl.c:5165
+#: fortran/decl.c:5184
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be default integer kind (%d)"
 msgstr "Đối số %qs của %qs với PASS(%s) tại %L phải là vô hướng"
 
-#: fortran/decl.c:5174
+#: fortran/decl.c:5193
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected :: in TYPE definition at %C"
 msgid "LEN attribute at %C in a TYPE definition"
 msgstr "Cần :: trong định nghĩa KIỂU tại %C"
 
-#: fortran/decl.c:5182
+#: fortran/decl.c:5201
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qs argument of %qs intrinsic at %L must be INTEGER"
 msgid "Component with LEN attribute at %C must be INTEGER"
 msgstr "Tham số %qs của hạn chế %qs tại %L phải là SỐ-NGUYÊN"
 
-#: fortran/decl.c:5189
+#: fortran/decl.c:5208
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be default integer kind (%d)"
 msgstr "Đối số %qs của %qs với PASS(%s) tại %L phải là vô hướng"
 
-#: fortran/decl.c:5198
+#: fortran/decl.c:5217
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5216
+#: fortran/decl.c:5235
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5226
+#: fortran/decl.c:5245
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:5236
+#: fortran/decl.c:5255
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed outside a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5249
+#: fortran/decl.c:5268
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr "thuộc tính ASYNCHRONOUS tại%C"
 
-#: fortran/decl.c:5260
+#: fortran/decl.c:5279
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr "thuộc tính CONTIGUOUS tại %C"
 
-#: fortran/decl.c:5315 fortran/decl.c:8673
+#: fortran/decl.c:5334 fortran/decl.c:8692
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:5321
+#: fortran/decl.c:5340
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute at %C"
 msgstr "thuộc tính BẢO VỆ tại %C"
 
-#: fortran/decl.c:5355
+#: fortran/decl.c:5374
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE attribute at %C"
 msgstr "thuộc tính VALUE tại %C"
 
-#: fortran/decl.c:5362
+#: fortran/decl.c:5381
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
 msgstr "thuộc tính VOLATILE tại %C"
 
-#: fortran/decl.c:5369
+#: fortran/decl.c:5388
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr "match_attr_spec(): Thuộc tính sai"
 
-#: fortran/decl.c:5410
+#: fortran/decl.c:5429
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:5508
+#: fortran/decl.c:5527
 #, gcc-internal-format
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:5530
+#: fortran/decl.c:5549
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5539
+#: fortran/decl.c:5558
 #, gcc-internal-format
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5543
+#: fortran/decl.c:5562
 #, gcc-internal-format
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5555
+#: fortran/decl.c:5574
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr ""
 
-#: fortran/decl.c:5569
+#: fortran/decl.c:5588
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr ""
 
-#: fortran/decl.c:5577
+#: fortran/decl.c:5596
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr ""
 
-#: fortran/decl.c:5589
+#: fortran/decl.c:5608
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr ""
 
-#: fortran/decl.c:5597
+#: fortran/decl.c:5616
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be a character string"
 msgstr ""
@@ -52554,956 +52626,962 @@
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:5608
+#: fortran/decl.c:5627
 #, gcc-internal-format
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr ""
 
-#: fortran/decl.c:5682
+#: fortran/decl.c:5701
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5727
+#: fortran/decl.c:5746
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5734
+#: fortran/decl.c:5753
 #, gcc-internal-format
 msgid "Missing symbol"
 msgstr "Thiếu ký hiệu"
 
-#: fortran/decl.c:5763
+#: fortran/decl.c:5782
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) statement at %C"
 msgstr "BIND(C) tại %C"
 
-#: fortran/decl.c:5850
+#: fortran/decl.c:5869
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr ""
 
-#: fortran/decl.c:5892
+#: fortran/decl.c:5911
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in anonymous structure declaration at %C"
 msgstr "Gặp lỗi cú pháp trong biểu thức tại %C"
 
-#: fortran/decl.c:5901
+#: fortran/decl.c:5920
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:5951
+#: fortran/decl.c:5970
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C"
 msgstr "Tiền tố MODULE tại %C"
 
-#: fortran/decl.c:5996
+#: fortran/decl.c:6015
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPURE procedure at %C"
 msgstr "thủ tục IMPURE tại %C"
 
-#: fortran/decl.c:6008
+#: fortran/decl.c:6027
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr ""
 
-#: fortran/decl.c:6054
+#: fortran/decl.c:6073
 #, gcc-internal-format, gfc-internal-format
 msgid "ELEMENTAL prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6061
+#: fortran/decl.c:6080
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6068
+#: fortran/decl.c:6087
 #, gcc-internal-format, gfc-internal-format
 msgid "RECURSIVE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6134 fortran/primary.c:1820
+#: fortran/decl.c:6153 fortran/primary.c:1820
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate-return argument at %C"
 msgstr ""
 
-#: fortran/decl.c:6140 fortran/decl.c:6148
+#: fortran/decl.c:6159 fortran/decl.c:6167
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Left parenthesis required after %<*%>"
 msgid "A parameter name is required at %C"
 msgstr "Đẳng sau “%<*%>” thì yêu cầu một dấu ngoặc đơn mở"
 
-#: fortran/decl.c:6188
+#: fortran/decl.c:6207
 #, gcc-internal-format
 msgid "Name %qs at %C is the name of the procedure"
 msgstr ""
 
-#: fortran/decl.c:6201
+#: fortran/decl.c:6220
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected a nameless interface at %C"
 msgid "Expected parameter list in type declaration at %C"
 msgstr "Cần một giao diện không tên tại %C"
 
-#: fortran/decl.c:6204
+#: fortran/decl.c:6223
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr ""
 
-#: fortran/decl.c:6222
+#: fortran/decl.c:6241
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate symbol %qs in formal argument list at %C"
 msgid "Duplicate name %qs in parameter list at %C"
 msgstr "Trùng ký hiệu %qs trong danh sách đối số hình thức tại %C"
 
-#: fortran/decl.c:6225
+#: fortran/decl.c:6244
 #, gcc-internal-format
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr "Trùng ký hiệu %qs trong danh sách đối số hình thức tại %C"
 
-#: fortran/decl.c:6264
+#: fortran/decl.c:6283
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in MODULE PROCEDURE formal argument names (%s/%s) at %C"
 msgstr ""
 
-#: fortran/decl.c:6270
+#: fortran/decl.c:6289
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in number of MODULE PROCEDURE formal arguments at %C"
 msgstr ""
 
-#: fortran/decl.c:6309
+#: fortran/decl.c:6328
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr ""
 
-#: fortran/decl.c:6386
+#: fortran/decl.c:6405
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:6396 fortran/decl.c:7494
+#: fortran/decl.c:6415 fortran/decl.c:7513
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr ""
 
-#: fortran/decl.c:6600
+#: fortran/decl.c:6619
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:6607
+#: fortran/decl.c:6626
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:6613
+#: fortran/decl.c:6632
 #, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr ""
 
-#: fortran/decl.c:6636
+#: fortran/decl.c:6655
 #, gcc-internal-format
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr "Thủ tục “%qs” tại %L đã sẵn có kiểu cơ bản của %s"
 
-#: fortran/decl.c:6682 fortran/decl.c:6870 fortran/decl.c:10723
+#: fortran/decl.c:6701 fortran/decl.c:6889 fortran/decl.c:10748
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6731 fortran/decl.c:10623
+#: fortran/decl.c:6750 fortran/decl.c:10648
 #, gcc-internal-format
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr ""
 
-#: fortran/decl.c:6738
+#: fortran/decl.c:6757
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr ""
 
-#: fortran/decl.c:6742
+#: fortran/decl.c:6761
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:6814
+#: fortran/decl.c:6833
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:6832
+#: fortran/decl.c:6851
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr ""
 
-#: fortran/decl.c:6841 fortran/decl.c:9392
+#: fortran/decl.c:6860 fortran/decl.c:9411
 #, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr ""
 
-#: fortran/decl.c:6911
+#: fortran/decl.c:6930
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6983
+#: fortran/decl.c:7002
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr ""
 
-#: fortran/decl.c:7007 fortran/decl.c:7011 fortran/decl.c:7266
-#: fortran/decl.c:7270 fortran/decl.c:7462 fortran/decl.c:7466
-#: fortran/symbol.c:1875
+#: fortran/decl.c:7026 fortran/decl.c:7030 fortran/decl.c:7285
+#: fortran/decl.c:7289 fortran/decl.c:7481 fortran/decl.c:7485
+#: fortran/symbol.c:1889
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr ""
 
-#: fortran/decl.c:7164
+#: fortran/decl.c:7183
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C"
 msgstr "câu lệnh ENTRY tại %C"
 
-#: fortran/decl.c:7173
+#: fortran/decl.c:7192
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr ""
 
-#: fortran/decl.c:7176
+#: fortran/decl.c:7195
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr ""
 
-#: fortran/decl.c:7179
+#: fortran/decl.c:7198
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SUBMODULE"
 msgstr ""
 
-#: fortran/decl.c:7182
+#: fortran/decl.c:7201
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr ""
 
-#: fortran/decl.c:7186 fortran/decl.c:7231
+#: fortran/decl.c:7205 fortran/decl.c:7250
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr ""
 
-#: fortran/decl.c:7190
+#: fortran/decl.c:7209
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a STRUCTURE block"
 msgstr "Hàm khai báo tại %L không phải xuất hiện trong một GIAO DIỆN"
 
-#: fortran/decl.c:7194
+#: fortran/decl.c:7213
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr ""
 
-#: fortran/decl.c:7198
+#: fortran/decl.c:7217
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr ""
 
-#: fortran/decl.c:7203
+#: fortran/decl.c:7222
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr ""
 
-#: fortran/decl.c:7207
+#: fortran/decl.c:7226
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr ""
 
-#: fortran/decl.c:7211
+#: fortran/decl.c:7230
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr ""
 
-#: fortran/decl.c:7215
+#: fortran/decl.c:7234
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr ""
 
-#: fortran/decl.c:7219
+#: fortran/decl.c:7238
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr ""
 
-#: fortran/decl.c:7223
+#: fortran/decl.c:7242
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected ENTRY statement at %C"
 msgstr "Không cần câu lệnh ENTRY tại %C"
 
-#: fortran/decl.c:7244
+#: fortran/decl.c:7263
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr ""
 
-#: fortran/decl.c:7295 fortran/decl.c:7501
+#: fortran/decl.c:7314 fortran/decl.c:7520
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7563 fortran/decl.c:7570
+#: fortran/decl.c:7582 fortran/decl.c:7589
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:7610
+#: fortran/decl.c:7629
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr ""
 
-#: fortran/decl.c:7626
+#: fortran/decl.c:7645
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr ""
 
-#: fortran/decl.c:7634
+#: fortran/decl.c:7653
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr ""
 
-#: fortran/decl.c:7653
+#: fortran/decl.c:7672
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing closing paren for binding label at %C"
 msgstr ""
 
-#: fortran/decl.c:7659
+#: fortran/decl.c:7678
 #, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7665
+#: fortran/decl.c:7684
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7694
+#: fortran/decl.c:7713
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr ""
 
-#: fortran/decl.c:7939
+#: fortran/decl.c:7958
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr "Không cần câu lệnh END tại %C"
 
-#: fortran/decl.c:7948
+#: fortran/decl.c:7967
 #, gcc-internal-format, gfc-internal-format
 msgid "END statement instead of %s statement at %L"
 msgstr ""
 
 #. We would have required END [something].
-#: fortran/decl.c:7957
+#: fortran/decl.c:7976
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr "cần lệnh %s tại %L"
 
-#: fortran/decl.c:7968
+#: fortran/decl.c:7987
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s statement at %L"
 msgstr "Cần câu lệnh %s tại %L"
 
-#: fortran/decl.c:7988
+#: fortran/decl.c:8007
 #, gcc-internal-format
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr ""
 
-#: fortran/decl.c:8005
+#: fortran/decl.c:8024
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr "Cần tên chấm dứt tại %C"
 
-#: fortran/decl.c:8019 fortran/decl.c:8027
+#: fortran/decl.c:8038 fortran/decl.c:8046
 #, gcc-internal-format
 msgid "Expected label %qs for %s statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8126
+#: fortran/decl.c:8145
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr ""
 
-#: fortran/decl.c:8134
+#: fortran/decl.c:8153
 #, gcc-internal-format, gfc-internal-format
 msgid "Dimensions specified for %s at %L after its initialization"
 msgstr ""
 
-#: fortran/decl.c:8142
+#: fortran/decl.c:8161
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr ""
 
-#: fortran/decl.c:8151
+#: fortran/decl.c:8170
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr ""
 
-#: fortran/decl.c:8249
+#: fortran/decl.c:8268
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr ""
 
-#: fortran/decl.c:8286
+#: fortran/decl.c:8305
 #, gcc-internal-format
 msgid "Expected %<(%> at %C"
 msgstr "Cần %<(%> tại %C"
 
-#: fortran/decl.c:8300 fortran/decl.c:8340
+#: fortran/decl.c:8319 fortran/decl.c:8359
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr "Cần tên biến tại %C"
 
-#: fortran/decl.c:8316
+#: fortran/decl.c:8335
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C must be an integer"
 msgstr ""
 
-#: fortran/decl.c:8320
+#: fortran/decl.c:8339
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr ""
 
-#: fortran/decl.c:8326
+#: fortran/decl.c:8345
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr "Cần \",\" tại %C"
 
-#: fortran/decl.c:8365
+#: fortran/decl.c:8384
 #, gcc-internal-format
 msgid "Couldn't set Cray pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:8389
+#: fortran/decl.c:8408
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr "Cần \")\" tại %C"
 
-#: fortran/decl.c:8401
+#: fortran/decl.c:8420
 #, gcc-internal-format
 msgid "Expected %<,%> or end of statement at %C"
 msgstr "cần %<,%> hoặc kết thúc câu lệnh tại %C"
 
-#: fortran/decl.c:8427
+#: fortran/decl.c:8446
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:8459
+#: fortran/decl.c:8478
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:8478
+#: fortran/decl.c:8497
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer declaration at %C requires -fcray-pointer flag"
 msgstr ""
 
-#: fortran/decl.c:8517
+#: fortran/decl.c:8536
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS statement at %C"
 msgstr "câu lệnh CONTIGUOUS tại %C"
 
-#: fortran/decl.c:8623
+#: fortran/decl.c:8642
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:8640
+#: fortran/decl.c:8659
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:8679
+#: fortran/decl.c:8698
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8717
+#: fortran/decl.c:8736
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8741
+#: fortran/decl.c:8760
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:8778
+#: fortran/decl.c:8797
 #, gcc-internal-format, gfc-internal-format
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:8806
+#: fortran/decl.c:8825
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr ""
 
-#: fortran/decl.c:8813
+#: fortran/decl.c:8832
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8819
+#: fortran/decl.c:8838
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr ""
 
-#: fortran/decl.c:8839
+#: fortran/decl.c:8858
 #, gcc-internal-format, gfc-internal-format
 msgid "Initializing already initialized variable at %C"
 msgstr ""
 
 #. With legacy PARAMETER statements, don't expect a terminating ')'.
-#: fortran/decl.c:8864
+#: fortran/decl.c:8883
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER without '()' at %C"
 msgstr ""
 
-#: fortran/decl.c:8880
+#: fortran/decl.c:8899
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8899 fortran/decl.c:8955
+#: fortran/decl.c:8918 fortran/decl.c:8974
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:8934
+#: fortran/decl.c:8953
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in AUTOMATIC statement at %C"
 msgstr "Không cần câu lệnh %s tại %C"
 
-#: fortran/decl.c:8941
+#: fortran/decl.c:8960
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in AUTOMATIC statement at %C"
 msgstr "Gặp lỗi cú pháp trong biểu thức tại %C"
 
-#: fortran/decl.c:8990
+#: fortran/decl.c:9009
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in STATIC statement at %C"
 msgstr "Không cần câu lệnh %s tại %C"
 
-#: fortran/decl.c:8997
+#: fortran/decl.c:9016
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in STATIC statement at %C"
 msgstr "Gặp lỗi cú pháp trong biểu thức tại %C"
 
-#: fortran/decl.c:9016
+#: fortran/decl.c:9035
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:9027
+#: fortran/decl.c:9046
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:9073
+#: fortran/decl.c:9092
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9087
+#: fortran/decl.c:9106
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:9091
+#: fortran/decl.c:9110
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE statement at %C"
 msgstr "câu lệnh VALUE tại %C"
 
-#: fortran/decl.c:9129
+#: fortran/decl.c:9148
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VALUE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9141
+#: fortran/decl.c:9160
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE statement at %C"
 msgstr "câu lệnh VOLATILE tại %C"
 
-#: fortran/decl.c:9168
+#: fortran/decl.c:9187
 #, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr ""
 
-#: fortran/decl.c:9193
+#: fortran/decl.c:9212
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9205
+#: fortran/decl.c:9224
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS statement at %C"
 msgstr "câu lệnh ASYNCHRONOUS tại %C"
 
-#: fortran/decl.c:9249
+#: fortran/decl.c:9268
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9274
+#: fortran/decl.c:9293
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:9367
+#: fortran/decl.c:9386
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr ""
 
-#: fortran/decl.c:9425
+#: fortran/decl.c:9444
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr ""
 
-#: fortran/decl.c:9474
+#: fortran/decl.c:9493
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr ""
 
-#: fortran/decl.c:9483
+#: fortran/decl.c:9502
 #, gcc-internal-format
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr ""
 
-#: fortran/decl.c:9489
+#: fortran/decl.c:9508
 #, gcc-internal-format
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr ""
 
-#: fortran/decl.c:9496
+#: fortran/decl.c:9515
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:9503
+#: fortran/decl.c:9522
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr ""
 
-#: fortran/decl.c:9526
+#: fortran/decl.c:9545
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:9538
+#: fortran/decl.c:9557
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:9559
+#: fortran/decl.c:9578
 #, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
 msgstr "Kiểu TRỪU TƯỢNG tại %C"
 
-#: fortran/decl.c:9605
+#: fortran/decl.c:9624
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Failed to create structure type '%s' at %C"
 msgstr "gặp lỗi khi đóng tập tin thống kê %s [%s]"
 
-#: fortran/decl.c:9611
+#: fortran/decl.c:9630
 #, fuzzy, gcc-internal-format
 msgid "Type definition of %qs at %C was already defined at %L"
 msgstr "Thủ tục “%qs” tại %C đã được định nghĩa trước tại %L"
 
-#: fortran/decl.c:9658
+#: fortran/decl.c:9677
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Junk after MAP statement at %C"
 msgstr "câu lệnh IMPORT tại %C"
 
-#: fortran/decl.c:9691
+#: fortran/decl.c:9710
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Junk after UNION statement at %C"
 msgstr "Không cần câu lệnh END tại %C"
 
-#: fortran/decl.c:9726
+#: fortran/decl.c:9745
 #, fuzzy, gcc-internal-format
 #| msgid "%qs at %C is not a member of the %qs structure"
 msgid "%s at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr "%qs tại %C không phải là thành viên của cấu trúc %qs"
 
-#: fortran/decl.c:9740
+#: fortran/decl.c:9759
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected in non-nested structure declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:9758
+#: fortran/decl.c:9777
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Junk after non-nested STRUCTURE statement at %C"
 msgstr "Không cần câu lệnh CASE tại %C"
 
-#: fortran/decl.c:9765
+#: fortran/decl.c:9784
 #, fuzzy, gcc-internal-format
 msgid "Structure name %qs at %C cannot be the same as an intrinsic type"
 msgstr "Hàm %qs tại %L không thể có bộ khởi tạo"
 
-#: fortran/decl.c:9926
+#: fortran/decl.c:9947
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr "Cần :: trong định nghĩa KIỂU tại %C"
 
-#: fortran/decl.c:9954
+#: fortran/decl.c:9975
 #, gcc-internal-format
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr ""
 
-#: fortran/decl.c:9964
+#: fortran/decl.c:9986
 #, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr ""
 
-#: fortran/decl.c:9981
+#: fortran/decl.c:9989
+#, fuzzy, gcc-internal-format
+#| msgid "Procedure %qs at %L already has basic type of %s"
+msgid "Derived type name %qs at %C already has a basic type"
+msgstr "Thủ tục “%qs” tại %L đã sẵn có kiểu cơ bản của %s"
+
+#: fortran/decl.c:10006
 #, gcc-internal-format
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr ""
 
-#: fortran/decl.c:10042
+#: fortran/decl.c:10067
 #, gcc-internal-format, gfc-internal-format
 msgid "Garbage after PARAMETERIZED TYPE declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:10126
+#: fortran/decl.c:10151
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr ""
 
-#: fortran/decl.c:10146
+#: fortran/decl.c:10171
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM and ENUMERATOR at %C"
 msgstr "ENUM và ENUMERATOR tại %C"
 
-#: fortran/decl.c:10178
+#: fortran/decl.c:10203
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr ""
 
-#: fortran/decl.c:10257
+#: fortran/decl.c:10282
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr ""
 
-#: fortran/decl.c:10305
+#: fortran/decl.c:10330
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr ""
 
-#: fortran/decl.c:10341
+#: fortran/decl.c:10366
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr ""
 
-#: fortran/decl.c:10388 fortran/decl.c:10403
+#: fortran/decl.c:10413 fortran/decl.c:10428
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate access-specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:10423
+#: fortran/decl.c:10448
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10443
+#: fortran/decl.c:10468
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10470
+#: fortran/decl.c:10495
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:10488
+#: fortran/decl.c:10513
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr ""
 
-#: fortran/decl.c:10504
+#: fortran/decl.c:10529
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DEFERRED at %C"
 msgstr "Trùng DEFERRED tại %C"
 
-#: fortran/decl.c:10517
+#: fortran/decl.c:10542
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected access-specifier at %C"
 msgstr "Cần access-specifier tại %C"
 
-#: fortran/decl.c:10519
+#: fortran/decl.c:10544
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr "Cần thuộc tính ràng buộc tại %C"
 
-#: fortran/decl.c:10527
+#: fortran/decl.c:10552
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED can't both appear at %C"
 msgstr ""
 
-#: fortran/decl.c:10539
+#: fortran/decl.c:10564
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:10581
+#: fortran/decl.c:10606
 #, gcc-internal-format
 msgid "Interface-name expected after %<(%> at %C"
 msgstr ""
 
-#: fortran/decl.c:10587
+#: fortran/decl.c:10612
 #, gcc-internal-format
 msgid "%<)%> expected at %C"
 msgstr "cần %<)%> tại %C"
 
-#: fortran/decl.c:10607
+#: fortran/decl.c:10632
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:10612
+#: fortran/decl.c:10637
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:10635
+#: fortran/decl.c:10660
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr "Cần tên ràng buộc tại %C"
 
-#: fortran/decl.c:10639
+#: fortran/decl.c:10664
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
 msgstr "danh sách PROCEDURE tại %C"
 
-#: fortran/decl.c:10651
+#: fortran/decl.c:10676
 #, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:10657
+#: fortran/decl.c:10682
 #, gcc-internal-format
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr ""
 
-#: fortran/decl.c:10667
+#: fortran/decl.c:10692
 #, gcc-internal-format
 msgid "Expected binding target after %<=>%> at %C"
 msgstr ""
 
-#: fortran/decl.c:10684
+#: fortran/decl.c:10709
 #, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr ""
 
-#: fortran/decl.c:10695
+#: fortran/decl.c:10720
 #, gcc-internal-format
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:10746
+#: fortran/decl.c:10771
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr ""
 
-#: fortran/decl.c:10766
+#: fortran/decl.c:10791
 #, gcc-internal-format
 msgid "Expected %<::%> at %C"
 msgstr "Cần %<::%> tại %C"
 
-#: fortran/decl.c:10778
+#: fortran/decl.c:10803
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected generic name or operator descriptor at %C"
 msgstr ""
 
-#: fortran/decl.c:10799
+#: fortran/decl.c:10824
 #, gcc-internal-format, gfc-internal-format
 msgid "Malformed GENERIC statement at %C"
 msgstr ""
 
-#: fortran/decl.c:10810
+#: fortran/decl.c:10835
 #, gcc-internal-format
 msgid "Expected %<=>%> at %C"
 msgstr "Cần %<=>%> tại %C"
 
-#: fortran/decl.c:10846
+#: fortran/decl.c:10871
 #, gcc-internal-format
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:10854
+#: fortran/decl.c:10879
 #, gcc-internal-format
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr ""
 
-#: fortran/decl.c:10902
+#: fortran/decl.c:10927
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr ""
 
-#: fortran/decl.c:10912
+#: fortran/decl.c:10937
 #, gcc-internal-format
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:10930
+#: fortran/decl.c:10955
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr ""
 
-#: fortran/decl.c:10965
+#: fortran/decl.c:10990
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr ""
 
-#: fortran/decl.c:10976
+#: fortran/decl.c:11001
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr ""
 
-#: fortran/decl.c:10998
+#: fortran/decl.c:11023
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr "FINAL trống rỗng tại %C"
 
-#: fortran/decl.c:11005
+#: fortran/decl.c:11030
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr ""
 
-#: fortran/decl.c:11015
+#: fortran/decl.c:11040
 #, gcc-internal-format
 msgid "Expected %<,%> at %C"
 msgstr "Cần %<,%> tại %C"
 
-#: fortran/decl.c:11021
+#: fortran/decl.c:11046
 #, gcc-internal-format
 msgid "Unknown procedure name %qs at %C"
 msgstr "Không rõ tên thủ tục “%qs” tại %C"
 
-#: fortran/decl.c:11034
+#: fortran/decl.c:11059
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure %qs at %C is already defined at %L"
 msgid "%qs at %C is already defined as FINAL procedure"
 msgstr "Thủ tục “%qs” tại %C đã được định nghĩa trước tại %L"
 
-#: fortran/decl.c:11104
+#: fortran/decl.c:11129
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr ""
 
-#: fortran/decl.c:11150
+#: fortran/decl.c:11175
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr ""
 
-#: fortran/decl.c:11170
+#: fortran/decl.c:11195
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive requires a non-negative integral constant less than or equal to %u at %C"
 msgstr ""
 
-#: fortran/decl.c:11184
+#: fortran/decl.c:11209
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in expression at %C"
 msgid "Syntax error in !GCC$ UNROLL directive at %C"
@@ -53842,27 +53920,27 @@
 msgid "BOZ literal at %L used to initialize non-integer variable %qs"
 msgstr ""
 
-#: fortran/expr.c:3369 fortran/resolve.c:10197
+#: fortran/expr.c:3369 fortran/resolve.c:10210
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal at %L outside a DATA statement and outside INT/REAL/DBLE/CMPLX"
 msgstr ""
 
-#: fortran/expr.c:3380 fortran/resolve.c:10208
+#: fortran/expr.c:3380 fortran/resolve.c:10221
 #, gcc-internal-format
 msgid "BOZ literal at %L is bitwise transferred non-integer symbol %qs"
 msgstr ""
 
-#: fortran/expr.c:3388 fortran/resolve.c:10217
+#: fortran/expr.c:3388 fortran/resolve.c:10230
 #, gcc-internal-format
 msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3392 fortran/resolve.c:10221
+#: fortran/expr.c:3392 fortran/resolve.c:10234
 #, gcc-internal-format
 msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3396 fortran/resolve.c:10225
+#: fortran/expr.c:3396 fortran/resolve.c:10238
 #, gcc-internal-format
 msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
@@ -53872,148 +53950,148 @@
 msgid "The assignment to a KIND or LEN component of a parameterized type at %L is not allowed"
 msgstr ""
 
-#: fortran/expr.c:3426
+#: fortran/expr.c:3429
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible types in DATA statement at %L; attempted conversion of %s to %s"
 msgstr ""
 
-#: fortran/expr.c:3465
+#: fortran/expr.c:3468
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is not a POINTER at %L"
 msgstr ""
 
-#: fortran/expr.c:3473
+#: fortran/expr.c:3476
 #, gcc-internal-format
 msgid "%qs in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgstr ""
 
-#: fortran/expr.c:3496
+#: fortran/expr.c:3499
 #, gcc-internal-format
 msgid "Expected bounds specification for %qs at %L"
 msgstr ""
 
-#: fortran/expr.c:3501
+#: fortran/expr.c:3504
 #, gcc-internal-format
 msgid "Bounds specification for %qs in pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3514
+#: fortran/expr.c:3517
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower bound has to be present at %L"
 msgstr ""
 
-#: fortran/expr.c:3520
+#: fortran/expr.c:3523
 #, gcc-internal-format, gfc-internal-format
 msgid "Stride must not be present at %L"
 msgstr ""
 
-#: fortran/expr.c:3532
+#: fortran/expr.c:3535
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the upper bounds must be specified at %L"
 msgstr ""
 
-#: fortran/expr.c:3558
+#: fortran/expr.c:3561
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %L shall not have a coindex"
 msgstr ""
 
-#: fortran/expr.c:3579
+#: fortran/expr.c:3582
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3603
+#: fortran/expr.c:3606
 #, gcc-internal-format
 msgid "Function result %qs is invalid as proc-target in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3612
+#: fortran/expr.c:3615
 #, gcc-internal-format
 msgid "Abstract interface %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3622
+#: fortran/expr.c:3625
 #, gcc-internal-format
 msgid "Statement function %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3628
+#: fortran/expr.c:3631
 #, gcc-internal-format
 msgid "Internal procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3635
+#: fortran/expr.c:3638
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L is invalid in procedure pointer assignment"
 msgstr ""
 
-#: fortran/expr.c:3643
+#: fortran/expr.c:3646
 #, gcc-internal-format
 msgid "Nonintrinsic elemental procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3666
+#: fortran/expr.c:3669
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in the procedure pointer assignment at %L: mismatch in the calling convention"
 msgstr ""
 
-#: fortran/expr.c:3719
+#: fortran/expr.c:3722
 #, gcc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %qs is not a subroutine"
 msgstr ""
 
-#: fortran/expr.c:3729 fortran/expr.c:3744
+#: fortran/expr.c:3732 fortran/expr.c:3747
 #, fuzzy, gcc-internal-format
 #| msgid "Expected a procedure for argument %qs at %L"
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr "Cần một thủ tục cho đối số %qs tại %L"
 
-#: fortran/expr.c:3735 fortran/expr.c:3750 fortran/resolve.c:2566
+#: fortran/expr.c:3738 fortran/expr.c:3753 fortran/resolve.c:2566
 #, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr ""
 
-#: fortran/expr.c:3762
+#: fortran/expr.c:3765
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %s"
 msgstr ""
 
-#: fortran/expr.c:3771
+#: fortran/expr.c:3774
 #, gcc-internal-format
 msgid "Procedure pointer target %qs at %L must be either an intrinsic, host or use associated, referenced or have the EXTERNAL attribute"
 msgstr ""
 
-#: fortran/expr.c:3788
+#: fortran/expr.c:3791
 #, gcc-internal-format, gfc-internal-format
 msgid "Data-pointer-object at %L must be unlimited polymorphic, or of a type with the BIND or SEQUENCE attribute, to be compatible with an unlimited polymorphic target"
 msgstr ""
 
-#: fortran/expr.c:3793
+#: fortran/expr.c:3796
 #, gcc-internal-format, gfc-internal-format
 msgid "Different types in pointer assignment at %L; attempted assignment of %s to %s"
 msgstr ""
 
-#: fortran/expr.c:3802
+#: fortran/expr.c:3805
 #, gcc-internal-format, gfc-internal-format
 msgid "Different kind type parameters in pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3809
+#: fortran/expr.c:3812
 #, gcc-internal-format, gfc-internal-format
 msgid "Different ranks in pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3828
+#: fortran/expr.c:3831
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is smaller than size of the pointer (%ld < %ld) at %L"
 msgstr ""
 
-#: fortran/expr.c:3841
+#: fortran/expr.c:3844
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target must be rank 1 or simply contiguous at %L"
 msgstr ""
 
-#: fortran/expr.c:3845
+#: fortran/expr.c:3848
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is not rank 1 at %L"
 msgstr ""
@@ -54021,147 +54099,152 @@
 #. The test above might need to be extend when F08, Note 5.4 has to be
 #. interpreted in the way that target and pointer with the same coindex
 #. are allowed.
-#: fortran/expr.c:3877 fortran/expr.c:3925
+#: fortran/expr.c:3880 fortran/expr.c:3928
 #, gcc-internal-format, gfc-internal-format
 msgid "Data target at %L shall not have a coindex"
 msgstr ""
 
-#: fortran/expr.c:3880
+#: fortran/expr.c:3883
 #, gcc-internal-format, gfc-internal-format
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr ""
 
-#: fortran/expr.c:3888
+#: fortran/expr.c:3891
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr ""
 
-#: fortran/expr.c:3895
+#: fortran/expr.c:3898
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr ""
 
-#: fortran/expr.c:3904
+#: fortran/expr.c:3907
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr ""
 
-#: fortran/expr.c:3912
+#: fortran/expr.c:3915
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/expr.c:3936
+#: fortran/expr.c:3939
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to contiguous pointer from non-contiguous target at %L"
 msgstr ""
 
-#: fortran/expr.c:3975
+#: fortran/expr.c:3978
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr ""
 
-#: fortran/expr.c:4051 fortran/resolve.c:1452
+#: fortran/expr.c:4054 fortran/resolve.c:1452
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/expr.c:4057
+#: fortran/expr.c:4060
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr ""
 
-#: fortran/expr.c:4072 fortran/resolve.c:1458
+#: fortran/expr.c:4075 fortran/resolve.c:1458
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr ""
 
-#: fortran/expr.c:4084
+#: fortran/expr.c:4087
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr ""
 
-#: fortran/expr.c:5512
+#: fortran/expr.c:4557
+#, gcc-internal-format
+msgid "generate_isocbinding_initializer(): bad iso_c_binding type, expected %<c_ptr%> or %<c_funptr%>"
+msgstr ""
+
+#: fortran/expr.c:5568
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5520
+#: fortran/expr.c:5576
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5528
+#: fortran/expr.c:5584
 #, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5537
+#: fortran/expr.c:5593
 #, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr ""
 
-#: fortran/expr.c:5548
+#: fortran/expr.c:5604
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5557
+#: fortran/expr.c:5613
 #, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5570
+#: fortran/expr.c:5626
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5583
+#: fortran/expr.c:5639
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5613
+#: fortran/expr.c:5669
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5621
+#: fortran/expr.c:5677
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5634
+#: fortran/expr.c:5690
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5642
+#: fortran/expr.c:5698
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5654
+#: fortran/expr.c:5710
 #, gcc-internal-format
 msgid "Variable %qs can not appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr ""
 
-#: fortran/expr.c:5713
+#: fortran/expr.c:5769
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:5717
+#: fortran/expr.c:5773
 #, gcc-internal-format
 msgid "%qs at %L associated to expression can not be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:5728
+#: fortran/expr.c:5784
 #, gcc-internal-format
 msgid "Associate-name %qs can not appear in a variable definition context (%s) at %L because its target at %L can not, either"
 msgstr ""
 
-#: fortran/expr.c:5770
+#: fortran/expr.c:5826
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr ""
@@ -54171,22 +54254,22 @@
 msgid "can't open input file: %s"
 msgstr "không thể mở tập tin đầu vào: %s"
 
-#: fortran/frontend-passes.c:190
+#: fortran/frontend-passes.c:192
 #, fuzzy, gcc-internal-format
 msgid "No location in statement"
 msgstr "tại câu lệnh"
 
-#: fortran/frontend-passes.c:205
+#: fortran/frontend-passes.c:207
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "No location in expression near %L"
 msgstr "Gặp lỗi cú pháp trong biểu thức tại %C"
 
-#: fortran/frontend-passes.c:409
+#: fortran/frontend-passes.c:414
 #, gcc-internal-format
 msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
-#: fortran/frontend-passes.c:817 fortran/trans-array.c:1182
+#: fortran/frontend-passes.c:822 fortran/trans-array.c:1182
 #: fortran/trans-array.c:6440 fortran/trans-array.c:7864
 #: fortran/trans-intrinsic.c:7307
 #, gcc-internal-format, gfc-internal-format
@@ -54193,69 +54276,69 @@
 msgid "Creating array temporary at %L"
 msgstr "Đang tạo mảng tạm tại %L"
 
-#: fortran/frontend-passes.c:842 fortran/frontend-passes.c:846
+#: fortran/frontend-passes.c:847 fortran/frontend-passes.c:851
 #, gcc-internal-format
 msgid "Removing call to function %qs at %L"
 msgstr ""
 
-#: fortran/frontend-passes.c:1273 fortran/frontend-passes.c:1312
+#: fortran/frontend-passes.c:1278 fortran/frontend-passes.c:1317
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "bad expression"
 msgstr "cần biểu thức"
 
-#: fortran/frontend-passes.c:1308
+#: fortran/frontend-passes.c:1313
 #, fuzzy, gcc-internal-format
 #| msgid "bad move"
 msgid "bad op"
 msgstr "sai di chuyển"
 
-#: fortran/frontend-passes.c:2161
+#: fortran/frontend-passes.c:2166
 #, gcc-internal-format
 msgid "illegal OP in optimize_comparison"
 msgstr ""
 
-#: fortran/frontend-passes.c:2407
+#: fortran/frontend-passes.c:2412
 #, gcc-internal-format
 msgid "Variable %qs at %L set to undefined value inside loop  beginning at %L as INTENT(OUT) argument to subroutine %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:2414
+#: fortran/frontend-passes.c:2419
 #, gcc-internal-format
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to subroutine %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:2637 fortran/frontend-passes.c:2661
+#: fortran/frontend-passes.c:2642 fortran/frontend-passes.c:2666
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L out of bounds (%ld < %ld) in loop beginning at %L"
 msgstr ""
 
-#: fortran/frontend-passes.c:2646 fortran/frontend-passes.c:2670
+#: fortran/frontend-passes.c:2651 fortran/frontend-passes.c:2675
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L out of bounds (%ld > %ld) in loop beginning at %L"
 msgstr ""
 
-#: fortran/frontend-passes.c:2730
+#: fortran/frontend-passes.c:2735
 #, gcc-internal-format
 msgid "Variable %qs at %L set to undefined value inside loop beginning at %L as INTENT(OUT) argument to function %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:2736
+#: fortran/frontend-passes.c:2741
 #, gcc-internal-format
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:3128 fortran/trans-expr.c:1581
+#: fortran/frontend-passes.c:3133 fortran/trans-expr.c:1581
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr ""
 
-#: fortran/frontend-passes.c:3637
+#: fortran/frontend-passes.c:3642
 #, gcc-internal-format
 msgid "Scalarization using DIMEN_RANGE unimplemented"
 msgstr ""
 
-#: fortran/frontend-passes.c:4429
+#: fortran/frontend-passes.c:4434
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "containing loop"
 msgid "Interchanging loops at %L"
@@ -54378,12 +54461,12 @@
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:970 fortran/resolve.c:16351
+#: fortran/interface.c:970 fortran/resolve.c:16378
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:977 fortran/resolve.c:16369
+#: fortran/interface.c:977 fortran/resolve.c:16396
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
@@ -55577,7 +55660,7 @@
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.c:3369 fortran/resolve.c:14263
+#: fortran/io.c:3369 fortran/resolve.c:14283
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -55743,7 +55826,7 @@
 msgid "Integer too large at %C"
 msgstr "Số nguyên quá lớn tại %C"
 
-#: fortran/match.c:580 fortran/parse.c:1132
+#: fortran/match.c:580 fortran/parse.c:1136
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many digits in statement label at %C"
 msgstr ""
@@ -56513,57 +56596,57 @@
 msgid "Expected block name %qs of SELECT construct at %C"
 msgstr ""
 
-#: fortran/match.c:6186
+#: fortran/match.c:6201
 #, gcc-internal-format, gfc-internal-format
 msgid "parse error in SELECT TYPE statement at %C"
 msgstr ""
 
-#: fortran/match.c:6211
+#: fortran/match.c:6226
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr ""
 
-#: fortran/match.c:6249
+#: fortran/match.c:6264
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr "Không cần câu lệnh CASE tại %C"
 
-#: fortran/match.c:6301
+#: fortran/match.c:6316
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CASE specification at %C"
 msgstr ""
 
-#: fortran/match.c:6319
+#: fortran/match.c:6334
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected TYPE IS statement at %C"
 msgstr ""
 
-#: fortran/match.c:6351
+#: fortran/match.c:6366
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr ""
 
-#: fortran/match.c:6362
+#: fortran/match.c:6377
 #, gcc-internal-format, gfc-internal-format
 msgid "All the LEN type parameters in the TYPE IS statement at %C must be ASSUMED"
 msgstr ""
 
-#: fortran/match.c:6373
+#: fortran/match.c:6388
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr ""
 
-#: fortran/match.c:6449
+#: fortran/match.c:6464
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr ""
 
-#: fortran/match.c:6572
+#: fortran/match.c:6587
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr ""
 
-#: fortran/match.c:6610
+#: fortran/match.c:6625
 #, gcc-internal-format
 msgid "Label %qs at %C doesn't match WHERE label %qs"
 msgstr ""
@@ -56715,188 +56798,188 @@
 msgid "mio_array_ref(): Unknown array ref"
 msgstr ""
 
-#: fortran/module.c:3716
+#: fortran/module.c:3718
 #, gcc-internal-format, gfc-internal-format
 msgid "Namelist %s cannot be renamed by USE association to %s"
 msgstr ""
 
-#: fortran/module.c:4832
+#: fortran/module.c:4834
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4835
+#: fortran/module.c:4837
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:5029
+#: fortran/module.c:5031
 #, gcc-internal-format
 msgid "%qs of module %qs, imported at %C, is also the name of the current program unit"
 msgstr ""
 
-#: fortran/module.c:5381
+#: fortran/module.c:5383
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5388
+#: fortran/module.c:5390
 #, gcc-internal-format
 msgid "User operator %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5393
+#: fortran/module.c:5395
 #, gcc-internal-format
 msgid "Intrinsic operator %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5628
+#: fortran/module.c:5630
 #, gcc-internal-format
 msgid "write_symbol(): bad module symbol %qs"
 msgstr ""
 
-#: fortran/module.c:5961
+#: fortran/module.c:5963
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr ""
 
-#: fortran/module.c:6148
+#: fortran/module.c:6150
 #, gcc-internal-format
 msgid "Can't open module file %qs for writing at %C: %s"
 msgstr ""
 
-#: fortran/module.c:6169
+#: fortran/module.c:6171
 #, gcc-internal-format
 msgid "Error writing module file %qs for writing: %s"
 msgstr ""
 
-#: fortran/module.c:6180
+#: fortran/module.c:6182
 #, gcc-internal-format
 msgid "Can't delete module file %qs: %s"
 msgstr ""
 
-#: fortran/module.c:6183
+#: fortran/module.c:6185
 #, gcc-internal-format
 msgid "Can't rename module file %qs to %qs: %s"
 msgstr ""
 
-#: fortran/module.c:6189
+#: fortran/module.c:6191
 #, gcc-internal-format
 msgid "Can't delete temporary module file %qs: %s"
 msgstr ""
 
-#: fortran/module.c:6246
+#: fortran/module.c:6248
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C already declared"
 msgstr "Ký hiệu %qs đã sẵn được khai báo"
 
-#: fortran/module.c:6317
+#: fortran/module.c:6319
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr ""
 
-#: fortran/module.c:6425 fortran/module.c:6769
+#: fortran/module.c:6427 fortran/module.c:6771
 #, gcc-internal-format
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr ""
 
-#: fortran/module.c:6553
+#: fortran/module.c:6555
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr ""
 
-#: fortran/module.c:6574 fortran/module.c:6607 fortran/module.c:6649
+#: fortran/module.c:6576 fortran/module.c:6609 fortran/module.c:6651
 #, gcc-internal-format
 msgid "Symbol %qs already declared"
 msgstr "Ký hiệu %qs đã sẵn được khai báo"
 
-#: fortran/module.c:6754
+#: fortran/module.c:6756
 #, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:6776
+#: fortran/module.c:6778
 #, gcc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr ""
 
-#: fortran/module.c:6844
+#: fortran/module.c:6846
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr ""
 
-#: fortran/module.c:6898
+#: fortran/module.c:6900
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr ""
 
-#: fortran/module.c:6924
+#: fortran/module.c:6926
 #, gcc-internal-format, gfc-internal-format
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr ""
 
-#: fortran/module.c:6953
+#: fortran/module.c:6955
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr ""
 
-#: fortran/module.c:6965
+#: fortran/module.c:6967
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
 msgstr "mô đun ISO_C_BINDING tại %C"
 
-#: fortran/module.c:6978
+#: fortran/module.c:6980
 #, gcc-internal-format
 msgid "Can't find an intrinsic module named %qs at %C"
 msgstr ""
 
-#: fortran/module.c:6984
+#: fortran/module.c:6986
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr ""
 
-#: fortran/module.c:6990
+#: fortran/module.c:6992
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr ""
 
-#: fortran/module.c:6996
+#: fortran/module.c:6998
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr ""
 
-#: fortran/module.c:7006
+#: fortran/module.c:7008
 #, gcc-internal-format
 msgid "Can't open module file %qs for reading at %C: %s"
 msgstr ""
 
-#: fortran/module.c:7009
+#: fortran/module.c:7011
 #, gcc-internal-format
 msgid "Module file %qs has not been generated, either because the module does not contain a MODULE PROCEDURE or there is an error in the module."
 msgstr ""
 
-#: fortran/module.c:7020
+#: fortran/module.c:7022
 #, gcc-internal-format
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:7043
+#: fortran/module.c:7045
 #, gcc-internal-format
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr ""
 
-#: fortran/module.c:7051
+#: fortran/module.c:7053
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr ""
 
-#: fortran/module.c:7066
+#: fortran/module.c:7068
 #, gcc-internal-format, gfc-internal-format
 msgid "Can't USE the same %smodule we're building"
 msgstr ""
 
 #: fortran/openmp.c:296 fortran/openmp.c:397 fortran/openmp.c:692
-#: fortran/openmp.c:3167
+#: fortran/openmp.c:3166
 #, gcc-internal-format, gfc-internal-format
 msgid "COMMON block /%s/ not found at %C"
 msgstr ""
@@ -56975,864 +57058,864 @@
 #: fortran/openmp.c:2180
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid argument to $!ACC WAIT at %L"
-msgid "Invalid argument to !$ACC WAIT at %L"
+msgid "Invalid argument to !$ACC WAIT at %C"
 msgstr "Đối số hợp lệ cho $!ACC WAIT tại %L"
 
-#: fortran/openmp.c:2188
+#: fortran/openmp.c:2187
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT clause at %L requires a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/openmp.c:2221
+#: fortran/openmp.c:2220
 #, gcc-internal-format, gfc-internal-format
 msgid "ACC CACHE directive must be inside of loop %C"
 msgstr ""
 
-#: fortran/openmp.c:2252
+#: fortran/openmp.c:2251
 #, gcc-internal-format
 msgid "Multiple loop axes specified for routine"
 msgstr ""
 
-#: fortran/openmp.c:2278
+#: fortran/openmp.c:2277
 #, gcc-internal-format, gfc-internal-format
 msgid "Only the !$ACC ROUTINE form without list is allowed in interface block at %C"
 msgstr ""
 
-#: fortran/openmp.c:2306
+#: fortran/openmp.c:2305
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$ACC ROUTINE ( NAME ) at %C, invalid function name %s"
 msgstr ""
 
-#: fortran/openmp.c:2315
+#: fortran/openmp.c:2314
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$ACC ROUTINE ( NAME ) at %C"
 msgstr ""
 
-#: fortran/openmp.c:2322
+#: fortran/openmp.c:2321
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$ACC ROUTINE ( NAME ) at %C, expecting ')' after NAME"
 msgstr ""
 
-#: fortran/openmp.c:2457 fortran/openmp.c:2481
+#: fortran/openmp.c:2456 fortran/openmp.c:2480
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP CRITICAL statement at %C"
 msgstr ""
 
-#: fortran/openmp.c:2548
+#: fortran/openmp.c:2547
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP FLUSH statement at %C"
 msgstr ""
 
-#: fortran/openmp.c:2942 fortran/openmp.c:6225
+#: fortran/openmp.c:2941 fortran/openmp.c:6230
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined %s !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2946 fortran/openmp.c:6229
+#: fortran/openmp.c:2945 fortran/openmp.c:6234
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2951
+#: fortran/openmp.c:2950
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2953
+#: fortran/openmp.c:2952
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2973
+#: fortran/openmp.c:2972
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after !$OMP DECLARE REDUCTION at %C"
 msgstr ""
 
-#: fortran/openmp.c:3010
+#: fortran/openmp.c:3009
 #, gcc-internal-format, gfc-internal-format
 msgid "Only the !$OMP DECLARE TARGET form without clauses is allowed in interface block at %C"
 msgstr ""
 
-#: fortran/openmp.c:3025
+#: fortran/openmp.c:3024
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after !$OMP DECLARE TARGET at %C"
 msgstr ""
 
-#: fortran/openmp.c:3048
+#: fortran/openmp.c:3047
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET variable at %L is an element of a COMMON block"
 msgstr ""
 
-#: fortran/openmp.c:3053
+#: fortran/openmp.c:3052
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET variable at %L previously mentioned in LINK clause and later in TO clause"
 msgstr ""
 
-#: fortran/openmp.c:3059
+#: fortran/openmp.c:3058
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET variable at %L previously mentioned in TO clause and later in LINK clause"
 msgstr ""
 
-#: fortran/openmp.c:3063
+#: fortran/openmp.c:3062
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable at %L mentioned multiple times in clauses of the same OMP DECLARE TARGET directive"
 msgstr ""
 
-#: fortran/openmp.c:3078
+#: fortran/openmp.c:3077
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET COMMON at %L previously mentioned in LINK clause and later in TO clause"
 msgstr ""
 
-#: fortran/openmp.c:3084
+#: fortran/openmp.c:3083
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET COMMON at %L previously mentioned in TO clause and later in LINK clause"
 msgstr ""
 
-#: fortran/openmp.c:3088
+#: fortran/openmp.c:3087
 #, gcc-internal-format, gfc-internal-format
 msgid "COMMON at %L mentioned multiple times in clauses of the same OMP DECLARE TARGET directive"
 msgstr ""
 
-#: fortran/openmp.c:3115
+#: fortran/openmp.c:3114
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$OMP DECLARE TARGET list at %C"
 msgstr ""
 
-#: fortran/openmp.c:3147
+#: fortran/openmp.c:3146
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate variable at %C is an element of a COMMON block"
 msgstr ""
 
-#: fortran/openmp.c:3184
+#: fortran/openmp.c:3183
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after OMP THREADPRIVATE at %C"
 msgstr ""
 
-#: fortran/openmp.c:3191
+#: fortran/openmp.c:3190
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$OMP THREADPRIVATE list at %C"
 msgstr ""
 
-#: fortran/openmp.c:3405
+#: fortran/openmp.c:3404
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after TASKWAIT clause at %C"
 msgstr ""
 
-#: fortran/openmp.c:3419
+#: fortran/openmp.c:3418
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after TASKYIELD clause at %C"
 msgstr ""
 
-#: fortran/openmp.c:3478
+#: fortran/openmp.c:3477
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP WORKSHARE statement at %C"
 msgstr ""
 
-#: fortran/openmp.c:3492
+#: fortran/openmp.c:3491
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP MASTER statement at %C"
 msgstr ""
 
-#: fortran/openmp.c:3551
+#: fortran/openmp.c:3550
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP ATOMIC statement at %C"
 msgstr ""
 
-#: fortran/openmp.c:3578
+#: fortran/openmp.c:3577
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP BARRIER statement at %C"
 msgstr ""
 
-#: fortran/openmp.c:3592
+#: fortran/openmp.c:3591
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP TASKGROUP statement at %C"
 msgstr ""
 
-#: fortran/openmp.c:3642
+#: fortran/openmp.c:3641
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP CANCELLATION POINT statement at %C"
 msgstr ""
 
-#: fortran/openmp.c:3662
+#: fortran/openmp.c:3661
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after NOWAIT clause at %C"
 msgstr ""
 
-#: fortran/openmp.c:3704
+#: fortran/openmp.c:3703
 #, gcc-internal-format, gfc-internal-format
 msgid "%s clause at %L requires a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/openmp.c:3715
+#: fortran/openmp.c:3714
 #, gcc-internal-format, gfc-internal-format
 msgid "INTEGER expression of %s clause at %L must be positive"
 msgstr ""
 
-#: fortran/openmp.c:3726
+#: fortran/openmp.c:3725
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "INTEGER expression of %s clause at %L must be non-negative"
 msgstr "%s tại %L phải là số nguyên"
 
-#: fortran/openmp.c:3737
+#: fortran/openmp.c:3736
 #, gcc-internal-format
 msgid "POINTER object %qs of derived type in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3740
+#: fortran/openmp.c:3739
 #, fuzzy, gcc-internal-format
 #| msgid "Cray pointer %qs in %s clause at %L"
 msgid "Cray pointer object %qs of derived type in %s clause at %L"
 msgstr "Con trỏ Cray %qs trong mệnh đề %s tại %L"
 
-#: fortran/openmp.c:3743
+#: fortran/openmp.c:3742
 #, fuzzy, gcc-internal-format
 #| msgid "Cray pointer %qs in %s clause at %L"
 msgid "Cray pointee object %qs of derived type in %s clause at %L"
 msgstr "Con trỏ Cray %qs trong mệnh đề %s tại %L"
 
-#: fortran/openmp.c:3749 fortran/openmp.c:4687
+#: fortran/openmp.c:3748 fortran/openmp.c:4686
 #, gcc-internal-format
 msgid "POINTER object %qs of polymorphic type in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3754
+#: fortran/openmp.c:3753
 #, fuzzy, gcc-internal-format
 #| msgid "Cray pointer %qs in %s clause at %L"
 msgid "Cray pointer object %qs of polymorphic type in %s clause at %L"
 msgstr "Con trỏ Cray %qs trong mệnh đề %s tại %L"
 
-#: fortran/openmp.c:3759
+#: fortran/openmp.c:3758
 #, fuzzy, gcc-internal-format
 #| msgid "Cray pointer %qs in %s clause at %L"
 msgid "Cray pointee object %qs of polymorphic type in %s clause at %L"
 msgstr "Con trỏ Cray %qs trong mệnh đề %s tại %L"
 
-#: fortran/openmp.c:3769 fortran/openmp.c:4385 fortran/openmp.c:4490
+#: fortran/openmp.c:3768 fortran/openmp.c:4384 fortran/openmp.c:4489
 #, gcc-internal-format
 msgid "Assumed size array %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3772
+#: fortran/openmp.c:3771
 #, gcc-internal-format
 msgid "Assumed rank array %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3776
+#: fortran/openmp.c:3775
 #, gcc-internal-format
 msgid "Noncontiguous deferred shape array %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3784
+#: fortran/openmp.c:3783
 #, gcc-internal-format
 msgid "ALLOCATABLE object %qs of derived type in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3789
+#: fortran/openmp.c:3788
 #, gcc-internal-format
 msgid "ALLOCATABLE object %qs of polymorphic type in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3801 fortran/openmp.c:4480
+#: fortran/openmp.c:3800 fortran/openmp.c:4479
 #, gcc-internal-format
 msgid "POINTER object %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3806 fortran/openmp.c:4691
+#: fortran/openmp.c:3805 fortran/openmp.c:4690
 #, gcc-internal-format
 msgid "Cray pointer object %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3811 fortran/openmp.c:4694
+#: fortran/openmp.c:3810 fortran/openmp.c:4693
 #, gcc-internal-format
 msgid "Cray pointee object %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3816 fortran/openmp.c:4682
+#: fortran/openmp.c:3815 fortran/openmp.c:4681
 #, gcc-internal-format
 msgid "ALLOCATABLE object %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3819
+#: fortran/openmp.c:3818
 #, gcc-internal-format
 msgid "VALUE object %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3862
+#: fortran/openmp.c:3861
 #, gcc-internal-format, gfc-internal-format
 msgid "Implicitly declared function %s used in !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:3911
+#: fortran/openmp.c:3910
 #, gcc-internal-format, gfc-internal-format
 msgid "Implicitly declared subroutine %s used in !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:3944
+#: fortran/openmp.c:3943
 #, gcc-internal-format, gfc-internal-format
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:3952 fortran/openmp.c:3963 fortran/resolve.c:10028
-#: fortran/resolve.c:11295
+#: fortran/openmp.c:3951 fortran/openmp.c:3962 fortran/resolve.c:10041
+#: fortran/resolve.c:11315
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/openmp.c:3967
+#: fortran/openmp.c:3966
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause without modifier at %L used together with IF clauses with modifiers"
 msgstr ""
 
-#: fortran/openmp.c:4044
+#: fortran/openmp.c:4043
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause modifier %s at %L not appropriate for the current OpenMP construct"
 msgstr ""
 
-#: fortran/openmp.c:4054
+#: fortran/openmp.c:4053
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/openmp.c:4064
+#: fortran/openmp.c:4063
 #, gcc-internal-format, gfc-internal-format
 msgid "SCHEDULE clause's chunk_size at %L requires a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/openmp.c:4069
+#: fortran/openmp.c:4068
 #, gcc-internal-format, gfc-internal-format
 msgid "INTEGER expression of SCHEDULE clause's chunk_size at %L must be positive"
 msgstr ""
 
-#: fortran/openmp.c:4084
+#: fortran/openmp.c:4083
 #, gcc-internal-format
 msgid "Variable %qs is not a dummy argument at %L"
 msgstr "Biến %qs không phải là đối số hàm giả tại %L"
 
-#: fortran/openmp.c:4116
+#: fortran/openmp.c:4115 fortran/openmp.c:5998
 #, gcc-internal-format
 msgid "Object %qs is not a variable at %L"
 msgstr "Đối tượng %qs không phải là một biến tại %L"
 
-#: fortran/openmp.c:4132 fortran/openmp.c:4143 fortran/openmp.c:4151
-#: fortran/openmp.c:4162 fortran/openmp.c:4174 fortran/openmp.c:4189
-#: fortran/openmp.c:6023
+#: fortran/openmp.c:4131 fortran/openmp.c:4142 fortran/openmp.c:4150
+#: fortran/openmp.c:4161 fortran/openmp.c:4173 fortran/openmp.c:4188
+#: fortran/openmp.c:6028
 #, gcc-internal-format
 msgid "Symbol %qs present on multiple clauses at %L"
 msgstr ""
 
-#: fortran/openmp.c:4196
+#: fortran/openmp.c:4195
 #, gcc-internal-format
 msgid "Array %qs is not permitted in reduction at %L"
 msgstr ""
 
-#: fortran/openmp.c:4209
+#: fortran/openmp.c:4208
 #, gcc-internal-format
 msgid "Symbol %qs present on both FROM and TO clauses at %L"
 msgstr ""
 
-#: fortran/openmp.c:4231
+#: fortran/openmp.c:4230
 #, gcc-internal-format
 msgid "Non-THREADPRIVATE object %qs in COPYIN clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4239
+#: fortran/openmp.c:4238
 #, gcc-internal-format
 msgid "Assumed size array %qs in COPYPRIVATE clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4242
+#: fortran/openmp.c:4241
 #, gcc-internal-format
 msgid "INTENT(IN) POINTER %qs in COPYPRIVATE clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4250
+#: fortran/openmp.c:4249
 #, gcc-internal-format
 msgid "THREADPRIVATE object %qs in SHARED clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4253
+#: fortran/openmp.c:4252
 #, gcc-internal-format
 msgid "Cray pointee %qs in SHARED clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4256
+#: fortran/openmp.c:4255
 #, gcc-internal-format
 msgid "ASSOCIATE name %qs in SHARED clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4271
+#: fortran/openmp.c:4270
 #, gcc-internal-format
 msgid "%qs in ALIGNED clause must be POINTER, ALLOCATABLE, Cray pointer or C_PTR at %L"
 msgstr ""
 
-#: fortran/openmp.c:4283
+#: fortran/openmp.c:4282
 #, gcc-internal-format
 msgid "%qs in ALIGNED clause at %L requires a scalar positive constant integer alignment expression"
 msgstr ""
 
-#: fortran/openmp.c:4302
+#: fortran/openmp.c:4301
 #, gcc-internal-format, gfc-internal-format
 msgid "SINK dependence type only allowed on ORDERED directive at %L"
 msgstr ""
 
-#: fortran/openmp.c:4306
+#: fortran/openmp.c:4305
 #, gcc-internal-format, gfc-internal-format
 msgid "DEPEND SINK used together with DEPEND SOURCE on the same construct at %L"
 msgstr ""
 
-#: fortran/openmp.c:4316
+#: fortran/openmp.c:4315
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SINK addend not a constant integer at %L"
 msgstr "thanh ghi tổng không phải là số nguyên hằng"
 
-#: fortran/openmp.c:4322
+#: fortran/openmp.c:4321
 #, gcc-internal-format, gfc-internal-format
 msgid "Only SOURCE or SINK dependence types are allowed on ORDERED directive at %L"
 msgstr ""
 
-#: fortran/openmp.c:4333 fortran/openmp.c:4354
+#: fortran/openmp.c:4332 fortran/openmp.c:4353
 #, gcc-internal-format
 msgid "%qs in %s clause at %L is not a proper array section"
 msgstr ""
 
-#: fortran/openmp.c:4337
+#: fortran/openmp.c:4336
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarrays not supported in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4346
+#: fortran/openmp.c:4345
 #, gcc-internal-format, gfc-internal-format
 msgid "Stride should not be specified for array section in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4367
+#: fortran/openmp.c:4366
 #, gcc-internal-format
 msgid "%qs in DEPEND clause at %L is a zero size array section"
 msgstr ""
 
-#: fortran/openmp.c:4403
+#: fortran/openmp.c:4402
 #, gcc-internal-format, gfc-internal-format
 msgid "TARGET%s with map-type other than TO, FROM, TOFROM, or ALLOC on MAP clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4419
+#: fortran/openmp.c:4418
 #, gcc-internal-format, gfc-internal-format
 msgid "TARGET ENTER DATA with map-type other than TO, or ALLOC on MAP clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4434
+#: fortran/openmp.c:4433
 #, gcc-internal-format, gfc-internal-format
 msgid "TARGET EXIT DATA with map-type other than FROM, RELEASE, or DELETE on MAP clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4450 fortran/openmp.c:4466
+#: fortran/openmp.c:4449 fortran/openmp.c:4465
 #, gcc-internal-format
 msgid "THREADPRIVATE object %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4453 fortran/openmp.c:4469
+#: fortran/openmp.c:4452 fortran/openmp.c:4468
 #, gcc-internal-format
 msgid "Cray pointee %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4472
+#: fortran/openmp.c:4471
 #, gcc-internal-format
 msgid "ASSOCIATE name %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4477
+#: fortran/openmp.c:4476
 #, gcc-internal-format
 msgid "Procedure pointer %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4483
+#: fortran/openmp.c:4482
 #, gcc-internal-format
 msgid "Cray pointer %qs in %s clause at %L"
 msgstr "Con trỏ Cray %qs trong mệnh đề %s tại %L"
 
-#: fortran/openmp.c:4493
+#: fortran/openmp.c:4492
 #, gcc-internal-format
 msgid "Variable %qs in %s clause is used in NAMELIST statement at %L"
 msgstr ""
 
 #. case OMP_LIST_REDUCTION:
-#: fortran/openmp.c:4503
+#: fortran/openmp.c:4502
 #, gcc-internal-format
 msgid "INTENT(IN) POINTER %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4596
+#: fortran/openmp.c:4595
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP DECLARE REDUCTION %s not found for type %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:4622
+#: fortran/openmp.c:4621
 #, gcc-internal-format, gfc-internal-format
 msgid "LINEAR clause modifier used on DO or SIMD construct at %L"
 msgstr ""
 
-#: fortran/openmp.c:4627
+#: fortran/openmp.c:4626
 #, gcc-internal-format, gfc-internal-format
 msgid "LINEAR clause specified together with ORDERED clause with argument at %L"
 msgstr ""
 
-#: fortran/openmp.c:4632
+#: fortran/openmp.c:4631
 #, gcc-internal-format
 msgid "LINEAR variable %qs must be INTEGER at %L"
 msgstr "biến LINEAR %qs tại %L phải là SỐ-NGUYÊN"
 
-#: fortran/openmp.c:4637
+#: fortran/openmp.c:4636
 #, gcc-internal-format
 msgid "LINEAR dummy argument %qs with VALUE attribute with %s modifier at %L"
 msgstr ""
 
-#: fortran/openmp.c:4648
+#: fortran/openmp.c:4647
 #, gcc-internal-format
 msgid "%qs in LINEAR clause at %L requires a scalar integer linear-step expression"
 msgstr ""
 
-#: fortran/openmp.c:4665
+#: fortran/openmp.c:4664
 #, gcc-internal-format
 msgid "%qs in LINEAR clause at %L requires a constant integer linear-step expression or dummy argument specified in UNIFORM clause"
 msgstr ""
 
-#: fortran/openmp.c:4699
+#: fortran/openmp.c:4698
 #, gcc-internal-format
 msgid "%s clause variable %qs at %L is neither a POINTER nor an array"
 msgstr ""
 
-#: fortran/openmp.c:4731
+#: fortran/openmp.c:4730
 #, gcc-internal-format, gfc-internal-format
 msgid "DIST_SCHEDULE clause's chunk_size at %L requires a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/openmp.c:4763
+#: fortran/openmp.c:4762
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Incompatible ranks in %s (%d and %d) at %L"
 msgid "Incompatible use of TILE and COLLAPSE at %L"
 msgstr "Vùng không tương thích nhau trong %s (%d và %d) tại %L"
 
-#: fortran/openmp.c:4765
+#: fortran/openmp.c:4764
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE dependence type only allowed on ORDERED directive at %L"
 msgstr ""
 
-#: fortran/openmp.c:4778
+#: fortran/openmp.c:4777
 #, gcc-internal-format, gfc-internal-format
 msgid "%s must contain at least one MAP clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4875
+#: fortran/openmp.c:4874
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unexpected !$OMP ATOMIC expression at %L"
 msgstr "cần biểu thức"
 
-#: fortran/openmp.c:4904
+#: fortran/openmp.c:4903
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC statement must set a scalar variable of intrinsic type at %L"
 msgstr ""
 
-#: fortran/openmp.c:4929
+#: fortran/openmp.c:4928
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC READ statement must read from a scalar variable of intrinsic type at %L"
 msgstr ""
 
-#: fortran/openmp.c:4934
+#: fortran/openmp.c:4933
 #, gcc-internal-format, gfc-internal-format
 msgid "expr in !$OMP ATOMIC WRITE assignment var = expr must be scalar and cannot reference var at %L"
 msgstr ""
 
-#: fortran/openmp.c:4956 fortran/openmp.c:5247
+#: fortran/openmp.c:4955 fortran/openmp.c:5246
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE capture statement must read from a scalar variable of intrinsic type at %L"
 msgstr ""
 
-#: fortran/openmp.c:4971
+#: fortran/openmp.c:4970
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE update statement must set a scalar variable of intrinsic type at %L"
 msgstr ""
 
-#: fortran/openmp.c:4978 fortran/openmp.c:5254
+#: fortran/openmp.c:4977 fortran/openmp.c:5253
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE capture statement reads from different variable than update statement writes into at %L"
 msgstr ""
 
-#: fortran/openmp.c:4994
+#: fortran/openmp.c:4993
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC with ALLOCATABLE variable at %L"
 msgstr ""
 
-#: fortran/openmp.c:5036
+#: fortran/openmp.c:5035
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment operator must be binary +, *, -, /, .AND., .OR., .EQV. or .NEQV. at %L"
 msgstr ""
 
-#: fortran/openmp.c:5084
+#: fortran/openmp.c:5083
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment must be var = var op expr or var = expr op var at %L"
 msgstr ""
 
-#: fortran/openmp.c:5098
+#: fortran/openmp.c:5097
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC var = var op expr not mathematically equivalent to var = var op (expr) at %L"
 msgstr ""
 
-#: fortran/openmp.c:5130
+#: fortran/openmp.c:5129
 #, gcc-internal-format, gfc-internal-format
 msgid "expr in !$OMP ATOMIC assignment var = var op expr must be scalar and cannot reference var at %L"
 msgstr ""
 
-#: fortran/openmp.c:5154
+#: fortran/openmp.c:5153
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment intrinsic IAND, IOR or IEOR must have two arguments at %L"
 msgstr ""
 
-#: fortran/openmp.c:5161
+#: fortran/openmp.c:5160
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment intrinsic must be MIN, MAX, IAND, IOR or IEOR at %L"
 msgstr "!$OMP ATOMIC phân bổ bên trong phải là MIN, MAX, IAND, IOR hay IEOR tại %L"
 
-#: fortran/openmp.c:5178
+#: fortran/openmp.c:5177
 #, gcc-internal-format
 msgid "!$OMP ATOMIC intrinsic arguments except one must not reference %qs at %L"
 msgstr ""
 
-#: fortran/openmp.c:5185
+#: fortran/openmp.c:5184
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC intrinsic arguments must be scalar at %L"
 msgstr ""
 
-#: fortran/openmp.c:5193
+#: fortran/openmp.c:5192
 #, gcc-internal-format
 msgid "First or last !$OMP ATOMIC intrinsic argument must be %qs at %L"
 msgstr ""
 
-#: fortran/openmp.c:5211
+#: fortran/openmp.c:5210
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment must have an operator or intrinsic on right hand side at %L"
 msgstr ""
 
-#: fortran/openmp.c:5225
+#: fortran/openmp.c:5224
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE capture statement must set a scalar variable of intrinsic type at %L"
 msgstr ""
 
-#: fortran/openmp.c:5544
+#: fortran/openmp.c:5543
 #, gcc-internal-format, gfc-internal-format
 msgid "%s cannot be a DO WHILE or DO without loop control at %L"
 msgstr ""
 
-#: fortran/openmp.c:5550
+#: fortran/openmp.c:5549
 #, gcc-internal-format, gfc-internal-format
 msgid "%s cannot be a DO CONCURRENT loop at %L"
 msgstr ""
 
-#: fortran/openmp.c:5556
+#: fortran/openmp.c:5555
 #, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable must be of type integer at %L"
 msgstr ""
 
-#: fortran/openmp.c:5560
+#: fortran/openmp.c:5559
 #, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable must not be THREADPRIVATE at %L"
 msgstr ""
 
-#: fortran/openmp.c:5573
+#: fortran/openmp.c:5572
 #, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable present on clause other than PRIVATE or LASTPRIVATE at %L"
 msgstr ""
 
-#: fortran/openmp.c:5577
+#: fortran/openmp.c:5576
 #, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable present on clause other than LASTPRIVATE at %L"
 msgstr ""
 
-#: fortran/openmp.c:5581
+#: fortran/openmp.c:5580
 #, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable present on clause other than LINEAR at %L"
 msgstr ""
 
-#: fortran/openmp.c:5599
+#: fortran/openmp.c:5598
 #, gcc-internal-format, gfc-internal-format
 msgid "%s collapsed loops don't form rectangular iteration space at %L"
 msgstr ""
 
-#: fortran/openmp.c:5611
+#: fortran/openmp.c:5610
 #, gcc-internal-format, gfc-internal-format
 msgid "collapsed %s loops not perfectly nested at %L"
 msgstr ""
 
-#: fortran/openmp.c:5620 fortran/openmp.c:5628
+#: fortran/openmp.c:5619 fortran/openmp.c:5627
 #, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for collapsed %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:5712 fortran/openmp.c:5725
+#: fortran/openmp.c:5711 fortran/openmp.c:5724
 #, gcc-internal-format, gfc-internal-format
 msgid "The %s directive cannot be specified within a %s region at %L"
 msgstr ""
 
-#: fortran/openmp.c:5744
+#: fortran/openmp.c:5743
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP cannot be a DO WHILE or DO without loop control at %L"
 msgstr ""
 
-#: fortran/openmp.c:5750
+#: fortran/openmp.c:5749
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP iteration variable must be of type integer at %L"
 msgstr ""
 
-#: fortran/openmp.c:5766
+#: fortran/openmp.c:5765
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s loops don't form rectangular iteration space at %L"
 msgstr ""
 
-#: fortran/openmp.c:5778
+#: fortran/openmp.c:5777
 #, gcc-internal-format, gfc-internal-format
 msgid "%s !$ACC LOOP loops not perfectly nested at %L"
 msgstr ""
 
-#: fortran/openmp.c:5788 fortran/openmp.c:5797
+#: fortran/openmp.c:5787 fortran/openmp.c:5796
 #, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for %s !$ACC LOOP at %L"
 msgstr ""
 
-#: fortran/openmp.c:5812 fortran/openmp.c:5819
+#: fortran/openmp.c:5811 fortran/openmp.c:5818
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s in PARALLEL region doesn't allow %s arguments at %L"
 msgstr ""
 
-#: fortran/openmp.c:5841
+#: fortran/openmp.c:5840
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside another loop parallelized across gangs at %L"
 msgstr ""
 
-#: fortran/openmp.c:5845 fortran/openmp.c:5849
+#: fortran/openmp.c:5844 fortran/openmp.c:5848
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside loop parallelized across workers at %L"
 msgstr ""
 
-#: fortran/openmp.c:5856
+#: fortran/openmp.c:5855
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across workers at %L"
 msgstr ""
 
-#: fortran/openmp.c:5860
+#: fortran/openmp.c:5859
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across vectors at %L"
 msgstr ""
 
-#: fortran/openmp.c:5866
+#: fortran/openmp.c:5865
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across vectors is not allowed inside another loop parallelized across vectors at %L"
 msgstr ""
 
-#: fortran/openmp.c:5878
+#: fortran/openmp.c:5877
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with INDEPENDENT at %L"
 msgstr ""
 
-#: fortran/openmp.c:5880
+#: fortran/openmp.c:5879
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with GANG at %L"
 msgstr ""
 
-#: fortran/openmp.c:5882
+#: fortran/openmp.c:5881
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with WORKER at %L"
 msgstr ""
 
-#: fortran/openmp.c:5884
+#: fortran/openmp.c:5883
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with VECTOR at %L"
 msgstr ""
 
-#: fortran/openmp.c:5886
+#: fortran/openmp.c:5885
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with AUTO at %L"
 msgstr ""
 
-#: fortran/openmp.c:5891
+#: fortran/openmp.c:5890
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with GANG at %L"
 msgstr ""
 
-#: fortran/openmp.c:5893
+#: fortran/openmp.c:5892
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with WORKER at %L"
 msgstr ""
 
-#: fortran/openmp.c:5895
+#: fortran/openmp.c:5894
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with VECTOR at %L"
 msgstr ""
 
-#: fortran/openmp.c:5899
+#: fortran/openmp.c:5898
 #, gcc-internal-format, gfc-internal-format
 msgid "Tiled loop cannot be parallelized across gangs, workers and vectors at the same time at %L"
 msgstr ""
 
-#: fortran/openmp.c:5934
+#: fortran/openmp.c:5933
 #, gcc-internal-format, gfc-internal-format
 msgid "TILE requires constant expression at %L"
 msgstr "TILE cần biểu thức hằng tại %L"
 
-#: fortran/openmp.c:5999
+#: fortran/openmp.c:6004
 #, gcc-internal-format
 msgid "PARAMETER object %qs is not allowed at %L"
 msgstr ""
 
-#: fortran/openmp.c:6006
+#: fortran/openmp.c:6011
 #, gcc-internal-format
 msgid "Array sections: %qs not allowed in !$ACC DECLARE at %L"
 msgstr ""
 
-#: fortran/openmp.c:6133
+#: fortran/openmp.c:6138
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP TARGET UPDATE at %L requires at least one TO or FROM clause"
 msgstr ""
 
-#: fortran/openmp.c:6155
+#: fortran/openmp.c:6160
 #, gcc-internal-format
 msgid "!$OMP DECLARE SIMD should refer to containing procedure %qs at %L"
 msgstr ""
 
-#: fortran/openmp.c:6179
+#: fortran/openmp.c:6184
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_PRIV or OMP_ORIG used in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6187
+#: fortran/openmp.c:6192
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_OUT or OMP_IN used in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6216
+#: fortran/openmp.c:6221
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid operator for !$OMP DECLARE REDUCTION %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:6238
+#: fortran/openmp.c:6243
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER length in !$OMP DECLARE REDUCTION %s not constant at %L"
 msgstr ""
 
-#: fortran/openmp.c:6254
+#: fortran/openmp.c:6259
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6269
+#: fortran/openmp.c:6274
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6279
+#: fortran/openmp.c:6284
 #, gcc-internal-format, gfc-internal-format
 msgid "One of actual subroutine arguments in INITIALIZER clause of !$OMP DECLARE REDUCTION must be OMP_PRIV at %L"
 msgstr ""
 
-#: fortran/openmp.c:6287
+#: fortran/openmp.c:6292
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing INITIALIZER clause for !$OMP DECLARE REDUCTION of derived type without default initializer at %L"
 msgstr ""
@@ -57942,494 +58025,494 @@
 msgid "Unclassifiable statement at %C"
 msgstr ""
 
-#: fortran/parse.c:629
+#: fortran/parse.c:631
 #, gcc-internal-format, gfc-internal-format
 msgid "OpenACC directives at %C may not appear in PURE procedures"
 msgstr ""
 
-#: fortran/parse.c:705
+#: fortran/parse.c:707
 #, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable OpenACC directive at %C"
 msgstr ""
 
-#: fortran/parse.c:831 fortran/parse.c:1040
+#: fortran/parse.c:835 fortran/parse.c:1044
 #, gcc-internal-format, gfc-internal-format
 msgid "OpenMP directives other than SIMD or DECLARE TARGET at %C may not appear in PURE or ELEMENTAL procedures"
 msgstr ""
 
-#: fortran/parse.c:1024
+#: fortran/parse.c:1028
 #, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable OpenMP directive at %C"
 msgstr ""
 
-#: fortran/parse.c:1076
+#: fortran/parse.c:1080
 #, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable GCC directive at %C"
 msgstr ""
 
-#: fortran/parse.c:1135 fortran/parse.c:1362
+#: fortran/parse.c:1139 fortran/parse.c:1366
 #, gcc-internal-format, gfc-internal-format
 msgid "Zero is not a valid statement label at %C"
 msgstr ""
 
-#: fortran/parse.c:1142 fortran/parse.c:1354
+#: fortran/parse.c:1146 fortran/parse.c:1358
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-numeric character in statement label at %C"
 msgstr ""
 
-#: fortran/parse.c:1154 fortran/parse.c:1403
+#: fortran/parse.c:1158 fortran/parse.c:1407
 #, gcc-internal-format, gfc-internal-format
 msgid "Semicolon at %C needs to be preceded by statement"
 msgstr ""
 
-#: fortran/parse.c:1161 fortran/parse.c:1418
+#: fortran/parse.c:1165 fortran/parse.c:1422
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label without statement at %L"
 msgstr ""
 
-#: fortran/parse.c:1224 fortran/parse.c:1405
+#: fortran/parse.c:1228 fortran/parse.c:1409
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Semicolon at %C without preceding statement"
 msgstr ""
 
-#: fortran/parse.c:1247 fortran/parse.c:1381
+#: fortran/parse.c:1251 fortran/parse.c:1385
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad continuation line at %C"
 msgstr ""
 
-#: fortran/parse.c:1679
+#: fortran/parse.c:1683
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT statement at %L does not have a statement label"
 msgstr ""
 
-#: fortran/parse.c:2435
+#: fortran/parse.c:2439
 #, gcc-internal-format
 msgid "gfc_ascii_statement(): Bad statement code"
 msgstr ""
 
-#: fortran/parse.c:2577
+#: fortran/parse.c:2581
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement at %C"
 msgstr "Không cần câu lệnh %s tại %C"
 
-#: fortran/parse.c:2732
+#: fortran/parse.c:2736
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot follow %s statement at %L"
 msgstr ""
 
-#: fortran/parse.c:2749
+#: fortran/parse.c:2753
 #, gcc-internal-format
 msgid "Unexpected end of file in %qs"
 msgstr "Gặp kết thúc tập tin bất thường tại %qs"
 
-#: fortran/parse.c:2784
+#: fortran/parse.c:2788
 #, gcc-internal-format
 msgid "Derived-type %qs with SEQUENCE must not have a CONTAINS section at %C"
 msgstr ""
 
-#: fortran/parse.c:2787
+#: fortran/parse.c:2791
 #, gcc-internal-format
 msgid "Derived-type %qs with BIND(C) must not have a CONTAINS section at %C"
 msgstr ""
 
-#: fortran/parse.c:2807
+#: fortran/parse.c:2811
 #, gcc-internal-format, gfc-internal-format
 msgid "Components in TYPE at %C must precede CONTAINS"
 msgstr ""
 
-#: fortran/parse.c:2811
+#: fortran/parse.c:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound procedure at %C"
 msgstr ""
 
-#: fortran/parse.c:2819
+#: fortran/parse.c:2823
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC binding at %C"
 msgstr "GENERIC ràng buộc tại %C"
 
-#: fortran/parse.c:2827
+#: fortran/parse.c:2831
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure declaration at %C"
 msgstr ""
 
-#: fortran/parse.c:2839
+#: fortran/parse.c:2843
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type definition at %C with empty CONTAINS section"
 msgstr ""
 
-#: fortran/parse.c:2849 fortran/parse.c:3304
+#: fortran/parse.c:2853 fortran/parse.c:3308
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement in TYPE at %C must be inside a MODULE"
 msgstr ""
 
-#: fortran/parse.c:2856
+#: fortran/parse.c:2860
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede procedure bindings"
 msgstr ""
 
-#: fortran/parse.c:2863 fortran/parse.c:3317
+#: fortran/parse.c:2867 fortran/parse.c:3321
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PRIVATE statement at %C"
 msgstr ""
 
-#: fortran/parse.c:2873
+#: fortran/parse.c:2877
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede CONTAINS"
 msgstr ""
 
-#: fortran/parse.c:2877
+#: fortran/parse.c:2881
 #, gcc-internal-format, gfc-internal-format
 msgid "Already inside a CONTAINS block at %C"
 msgstr ""
 
-#: fortran/parse.c:2996
+#: fortran/parse.c:3000
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s at %L of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray, which is not possible as the component has the pointer attribute"
 msgstr ""
 
-#: fortran/parse.c:3002
+#: fortran/parse.c:3006
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer component %s at %L has a noncoarray subcomponent of type LOCK_TYPE, which must have a codimension or be a subcomponent of a coarray"
 msgstr ""
 
-#: fortran/parse.c:3007
+#: fortran/parse.c:3011
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L of type LOCK_TYPE must have a codimension"
 msgstr ""
 
-#: fortran/parse.c:3011
+#: fortran/parse.c:3015
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L must have a codimension as it has a noncoarray subcomponent of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/parse.c:3016
+#: fortran/parse.c:3020
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as already a coarray subcomponent exists)"
 msgstr ""
 
-#: fortran/parse.c:3023
+#: fortran/parse.c:3027
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as %s at %L has a codimension or a coarray subcomponent)"
 msgstr ""
 
-#: fortran/parse.c:3033
+#: fortran/parse.c:3037
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s at %L of type EVENT_TYPE must have a codimension or be a subcomponent of a coarray, which is not possible as the component has the pointer attribute"
 msgstr ""
 
-#: fortran/parse.c:3039
+#: fortran/parse.c:3043
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer component %s at %L has a noncoarray subcomponent of type EVENT_TYPE, which must have a codimension or be a subcomponent of a coarray"
 msgstr ""
 
-#: fortran/parse.c:3044
+#: fortran/parse.c:3048
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L of type EVENT_TYPE must have a codimension"
 msgstr ""
 
-#: fortran/parse.c:3048
+#: fortran/parse.c:3052
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L must have a codimension as it has a noncoarray subcomponent of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/parse.c:3053
+#: fortran/parse.c:3057
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as already a coarray subcomponent exists)"
 msgstr ""
 
-#: fortran/parse.c:3060
+#: fortran/parse.c:3064
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as %s at %L has a codimension or a coarray subcomponent)"
 msgstr ""
 
-#: fortran/parse.c:3112
+#: fortran/parse.c:3116
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to create map component '%s'"
 msgstr ""
 
-#: fortran/parse.c:3145
+#: fortran/parse.c:3149
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "failed to create union component '%s'"
 msgstr "không tìm thấy lớp “%s”"
 
-#: fortran/parse.c:3200
+#: fortran/parse.c:3204
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in nested structure declaration at %C"
 msgstr "Gặp lỗi cú pháp trong biểu thức tại %C"
 
-#: fortran/parse.c:3287
+#: fortran/parse.c:3291
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside CONTAINS"
 msgstr ""
 
-#: fortran/parse.c:3295
+#: fortran/parse.c:3299
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type definition at %C without components"
 msgstr ""
 
-#: fortran/parse.c:3311
+#: fortran/parse.c:3315
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede structure components"
 msgstr ""
 
-#: fortran/parse.c:3328
+#: fortran/parse.c:3332
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede structure components"
 msgstr ""
 
-#: fortran/parse.c:3334
+#: fortran/parse.c:3338
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE attribute at %C already specified in TYPE statement"
 msgstr ""
 
-#: fortran/parse.c:3339
+#: fortran/parse.c:3343
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SEQUENCE statement at %C"
 msgstr ""
 
-#: fortran/parse.c:3349
+#: fortran/parse.c:3353
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS block in derived type definition at %C"
 msgstr ""
 
-#: fortran/parse.c:3407
+#: fortran/parse.c:3411
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM declaration at %C has no ENUMERATORS"
 msgstr ""
 
-#: fortran/parse.c:3494
+#: fortran/parse.c:3498
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in INTERFACE block at %C"
 msgstr ""
 
-#: fortran/parse.c:3518
+#: fortran/parse.c:3522
 #, gcc-internal-format
 msgid "Name %qs of ABSTRACT INTERFACE at %C cannot be the same as an intrinsic type"
 msgstr ""
 
-#: fortran/parse.c:3552
+#: fortran/parse.c:3556
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement at %C in INTERFACE body"
 msgstr ""
 
-#: fortran/parse.c:3570
+#: fortran/parse.c:3574
 #, gcc-internal-format
 msgid "INTERFACE procedure %qs at %L has the same name as the enclosing procedure"
 msgstr ""
 
-#: fortran/parse.c:3700
+#: fortran/parse.c:3704
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/parse.c:3732
+#: fortran/parse.c:3736
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement is not allowed inside of BLOCK DATA at %C"
 msgstr ""
 
-#: fortran/parse.c:3822
+#: fortran/parse.c:3826
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement must appear in a MODULE"
 msgstr ""
 
-#: fortran/parse.c:3830
+#: fortran/parse.c:3834
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C follows another accessibility specification"
 msgstr ""
 
-#: fortran/parse.c:3882
+#: fortran/parse.c:3886
 #, gcc-internal-format
 msgid "Bad kind expression for function %qs at %L"
 msgstr ""
 
-#: fortran/parse.c:3886
+#: fortran/parse.c:3890
 #, gcc-internal-format
 msgid "The type for function %qs at %L is not accessible"
 msgstr "Kiểu của hàm %qs tại %L là không thể truy cập"
 
-#: fortran/parse.c:3946
+#: fortran/parse.c:3950
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C follows previous unmasked ELSEWHERE"
 msgstr ""
 
-#: fortran/parse.c:3968
+#: fortran/parse.c:3972
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in WHERE block at %C"
 msgstr ""
 
-#: fortran/parse.c:4027
+#: fortran/parse.c:4031
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in FORALL block at %C"
 msgstr ""
 
-#: fortran/parse.c:4078
+#: fortran/parse.c:4082
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSE IF statement at %C cannot follow ELSE statement at %L"
 msgstr ""
 
-#: fortran/parse.c:4096
+#: fortran/parse.c:4100
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ELSE statements at %L and %C"
 msgstr ""
 
-#: fortran/parse.c:4157
+#: fortran/parse.c:4161
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected a CASE or END SELECT statement following SELECT CASE at %C"
 msgstr ""
 
-#: fortran/parse.c:4241
+#: fortran/parse.c:4245
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected TYPE IS, CLASS IS or END SELECT statement following SELECT TYPE at %C"
 msgstr ""
 
-#: fortran/parse.c:4303
+#: fortran/parse.c:4307
 #, gcc-internal-format
 msgid "Variable %qs at %C cannot be redefined inside loop beginning at %L"
 msgstr ""
 
-#: fortran/parse.c:4336
+#: fortran/parse.c:4340
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is within another block"
 msgstr ""
 
-#: fortran/parse.c:4346
+#: fortran/parse.c:4350
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is interwoven with another DO loop"
 msgstr ""
 
-#: fortran/parse.c:4372
+#: fortran/parse.c:4376
 #, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL block inside of OpenACC region at %C"
 msgstr ""
 
-#: fortran/parse.c:4373
+#: fortran/parse.c:4377
 #, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL block inside of OpenMP region at %C"
 msgstr ""
 
-#: fortran/parse.c:4399
+#: fortran/parse.c:4403
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label in END CRITICAL at %C does not match CRITICAL label"
 msgstr ""
 
-#: fortran/parse.c:4468
+#: fortran/parse.c:4472
 #, gcc-internal-format, gfc-internal-format
 msgid "BLOCK construct at %C"
 msgstr "cấu trúc BLOCK tại %C"
 
-#: fortran/parse.c:4502
+#: fortran/parse.c:4506
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSOCIATE construct at %C"
 msgstr "cấu trúc ASSOCIATE tại %C"
 
-#: fortran/parse.c:4690
+#: fortran/parse.c:4694
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label in ENDDO at %C doesn't match DO label"
 msgstr ""
 
-#: fortran/parse.c:4706
+#: fortran/parse.c:4710
 #, gcc-internal-format, gfc-internal-format
 msgid "Named block DO at %L requires matching ENDDO name"
 msgstr ""
 
-#: fortran/parse.c:4897
+#: fortran/parse.c:4901
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing !$OMP END ATOMIC after !$OMP ATOMIC CAPTURE at %C"
 msgstr ""
 
-#: fortran/parse.c:4913 fortran/parse.c:4972
+#: fortran/parse.c:4917 fortran/parse.c:4976
 #, gcc-internal-format, gfc-internal-format
 msgid "OpenACC directive inside of CRITICAL block at %C"
 msgstr ""
 
-#: fortran/parse.c:4947
+#: fortran/parse.c:4951
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s at %C"
 msgstr "Cần %s tại %C"
 
-#: fortran/parse.c:4991
+#: fortran/parse.c:4995
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected DO loop at %C"
 msgstr "Cần vòng lặp DO tại %C"
 
-#: fortran/parse.c:5011
+#: fortran/parse.c:5015
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant !$ACC END LOOP at %C"
 msgstr ""
 
-#: fortran/parse.c:5225
+#: fortran/parse.c:5229
 #, gcc-internal-format, gfc-internal-format
 msgid "Name after !$omp critical and !$omp end critical does not match at %C"
 msgstr ""
 
-#: fortran/parse.c:5283
+#: fortran/parse.c:5287
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot terminate a non-block DO loop"
 msgstr ""
 
-#: fortran/parse.c:5297
+#: fortran/parse.c:5301
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %C after the first executable statement"
 msgstr ""
 
-#: fortran/parse.c:5423
+#: fortran/parse.c:5427
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive does not commence a loop at %C"
 msgstr ""
 
-#: fortran/parse.c:5538
+#: fortran/parse.c:5542
 #, gcc-internal-format
 msgid "Contained procedure %qs at %C is already ambiguous"
 msgstr ""
 
-#: fortran/parse.c:5595
+#: fortran/parse.c:5599
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in CONTAINS section at %C"
 msgstr ""
 
-#: fortran/parse.c:5620
+#: fortran/parse.c:5624
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS statement without FUNCTION or SUBROUTINE statement at %L"
 msgstr ""
 
-#: fortran/parse.c:5732
+#: fortran/parse.c:5736
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS statement at %C is already in a contained program unit"
 msgstr ""
 
-#: fortran/parse.c:5784
+#: fortran/parse.c:5788
 #, gcc-internal-format
 msgid "Global binding name %qs at %L is already being used as a %s at %L"
 msgstr ""
 
-#: fortran/parse.c:5788
+#: fortran/parse.c:5792
 #, gcc-internal-format
 msgid "Global name %qs at %L is already being used as a %s at %L"
 msgstr ""
 
-#: fortran/parse.c:5794
+#: fortran/parse.c:5798
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure %qs at %C is already defined at %L"
 msgid "Global binding name %qs at %L is already being used at %L"
 msgstr "Thủ tục “%qs” tại %C đã được định nghĩa trước tại %L"
 
-#: fortran/parse.c:5797
+#: fortran/parse.c:5801
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure %qs at %C is already defined at %L"
 msgid "Global name %qs at %L is already being used at %L"
 msgstr "Thủ tục “%qs” tại %C đã được định nghĩa trước tại %L"
 
-#: fortran/parse.c:5819
+#: fortran/parse.c:5823
 #, gcc-internal-format, gfc-internal-format
 msgid "Blank BLOCK DATA at %C conflicts with prior BLOCK DATA at %L"
 msgstr ""
 
-#: fortran/parse.c:5845
+#: fortran/parse.c:5849
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in BLOCK DATA at %C"
 msgstr ""
 
-#: fortran/parse.c:5949
+#: fortran/parse.c:5953
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in MODULE at %C"
 msgstr ""
@@ -58437,7 +58520,7 @@
 #. If we see a duplicate main program, shut down.  If the second
 #. instance is an implied main program, i.e. data decls or executable
 #. statements, we're in for lots of errors.
-#: fortran/parse.c:6333
+#: fortran/parse.c:6337
 #, gcc-internal-format, gfc-internal-format
 msgid "Two main PROGRAMs at %L and %C"
 msgstr ""
@@ -59189,7 +59272,7 @@
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.c:1893 fortran/resolve.c:9560 fortran/resolve.c:11225
+#: fortran/resolve.c:1893 fortran/resolve.c:9573 fortran/resolve.c:11245
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr ""
@@ -59299,7 +59382,7 @@
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "%qE không phải tên một kiểu"
 
-#: fortran/resolve.c:2905 fortran/resolve.c:16283
+#: fortran/resolve.c:2905 fortran/resolve.c:16310
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr ""
@@ -59420,197 +59503,197 @@
 msgid "logical_to_bitwise(): Bad intrinsic"
 msgstr "resolve_operator(): intrinsic sai"
 
-#: fortran/resolve.c:4059
+#: fortran/resolve.c:4065
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr "resolve_operator(): intrinsic sai"
 
-#: fortran/resolve.c:4229 fortran/resolve.c:4252
+#: fortran/resolve.c:4235 fortran/resolve.c:4258
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:4347
+#: fortran/resolve.c:4353
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4352
+#: fortran/resolve.c:4358
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4362
+#: fortran/resolve.c:4368
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4367
+#: fortran/resolve.c:4373
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4387
+#: fortran/resolve.c:4393
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr ""
 
-#: fortran/resolve.c:4404
+#: fortran/resolve.c:4410
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4412
+#: fortran/resolve.c:4418
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4428
+#: fortran/resolve.c:4434
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4437
+#: fortran/resolve.c:4443
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4453
+#: fortran/resolve.c:4459
 #, gcc-internal-format
 msgid "check_dimension(): Bad array reference"
 msgstr ""
 
-#: fortran/resolve.c:4476
+#: fortran/resolve.c:4482
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:4486
+#: fortran/resolve.c:4492
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.c:4494
+#: fortran/resolve.c:4500
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.c:4510
+#: fortran/resolve.c:4516
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr ""
 
-#: fortran/resolve.c:4538
+#: fortran/resolve.c:4544
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4544
+#: fortran/resolve.c:4550
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr ""
 
-#: fortran/resolve.c:4550
+#: fortran/resolve.c:4556
 #, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr ""
 
-#: fortran/resolve.c:4589
+#: fortran/resolve.c:4595
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4596
+#: fortran/resolve.c:4602
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr ""
 
-#: fortran/resolve.c:4641
+#: fortran/resolve.c:4647
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr ""
 
-#: fortran/resolve.c:4652
+#: fortran/resolve.c:4658
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.c:4663
+#: fortran/resolve.c:4669
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.c:4706
+#: fortran/resolve.c:4712
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr ""
 
-#: fortran/resolve.c:4804
+#: fortran/resolve.c:4810
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:4811
+#: fortran/resolve.c:4817
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4820
+#: fortran/resolve.c:4826
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr ""
 
-#: fortran/resolve.c:4833
+#: fortran/resolve.c:4839
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:4840
+#: fortran/resolve.c:4846
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4850
+#: fortran/resolve.c:4856
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr ""
 
-#: fortran/resolve.c:4860
+#: fortran/resolve.c:4866
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr ""
 
-#: fortran/resolve.c:5013
+#: fortran/resolve.c:5019
 #, gcc-internal-format
 msgid "resolve_ref(): Bad array reference"
 msgstr ""
 
-#: fortran/resolve.c:5027
+#: fortran/resolve.c:5033
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:5037
+#: fortran/resolve.c:5043
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:5056
+#: fortran/resolve.c:5062
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:5154
+#: fortran/resolve.c:5160
 #, gcc-internal-format
 msgid "expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.c:5236
+#: fortran/resolve.c:5242
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr ""
 
-#: fortran/resolve.c:5246
+#: fortran/resolve.c:5252
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -59619,12 +59702,12 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5256
+#: fortran/resolve.c:5262
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5271
+#: fortran/resolve.c:5277
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -59633,268 +59716,268 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5281
+#: fortran/resolve.c:5287
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5292
+#: fortran/resolve.c:5298
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5301
+#: fortran/resolve.c:5307
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5316
+#: fortran/resolve.c:5322
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5478
+#: fortran/resolve.c:5484
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5483
+#: fortran/resolve.c:5489
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5553
+#: fortran/resolve.c:5559
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.c:5566
+#: fortran/resolve.c:5572
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.c:5919
+#: fortran/resolve.c:5925
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:5926
+#: fortran/resolve.c:5932
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5961
+#: fortran/resolve.c:5967
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5970
+#: fortran/resolve.c:5976
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr ""
 
 #. Nothing matching found!
-#: fortran/resolve.c:6158
+#: fortran/resolve.c:6164
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:6185
+#: fortran/resolve.c:6191
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "%qs tại %L phải là THỦ TỤC CON"
 
-#: fortran/resolve.c:6236
+#: fortran/resolve.c:6242
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr "%qs tại %L phải là HÀM"
 
-#: fortran/resolve.c:6786
+#: fortran/resolve.c:6792
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "gfc_resolve_expr(): sai kiểu biểu thức"
 
-#: fortran/resolve.c:6812
+#: fortran/resolve.c:6818
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s tại %L phải là một scalar"
 
-#: fortran/resolve.c:6822
+#: fortran/resolve.c:6828
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "%s tại %L phải là số nguyên"
 
-#: fortran/resolve.c:6826 fortran/resolve.c:6833
+#: fortran/resolve.c:6832 fortran/resolve.c:6839
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s tại %L phải là SỐ-NGUYÊN"
 
-#: fortran/resolve.c:6875
+#: fortran/resolve.c:6881
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:6911
+#: fortran/resolve.c:6917
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.c:6928
+#: fortran/resolve.c:6934
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.c:6934
+#: fortran/resolve.c:6940
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.c:6995
+#: fortran/resolve.c:7001
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7000
+#: fortran/resolve.c:7006
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7007
+#: fortran/resolve.c:7013
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7015
+#: fortran/resolve.c:7021
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr ""
 
-#: fortran/resolve.c:7020
+#: fortran/resolve.c:7026
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:7033
+#: fortran/resolve.c:7039
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr ""
 
-#: fortran/resolve.c:7136 fortran/resolve.c:7428
+#: fortran/resolve.c:7142 fortran/resolve.c:7434
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:7144 fortran/resolve.c:7393
+#: fortran/resolve.c:7150 fortran/resolve.c:7399
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7250
+#: fortran/resolve.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7281
+#: fortran/resolve.c:7287
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.c:7439
+#: fortran/resolve.c:7445
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.c:7451
+#: fortran/resolve.c:7457
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.c:7465
+#: fortran/resolve.c:7471
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7480
+#: fortran/resolve.c:7486
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7493
+#: fortran/resolve.c:7499
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.c:7511
+#: fortran/resolve.c:7517
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.c:7592 fortran/resolve.c:7607
+#: fortran/resolve.c:7598 fortran/resolve.c:7613
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7599
+#: fortran/resolve.c:7605
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7622
+#: fortran/resolve.c:7628
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7649
+#: fortran/resolve.c:7655
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7668
+#: fortran/resolve.c:7674
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.c:7683
+#: fortran/resolve.c:7689
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7694
+#: fortran/resolve.c:7700
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7726
+#: fortran/resolve.c:7732
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:7749
+#: fortran/resolve.c:7755
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:7760
+#: fortran/resolve.c:7766
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.c:7771
+#: fortran/resolve.c:7782
 #, gcc-internal-format, gfc-internal-format
-msgid "Errmsg-variable at %L must be a scalar CHARACTER variable"
+msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:7794
+#: fortran/resolve.c:7805
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:7824
+#: fortran/resolve.c:7835
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.c:7830 fortran/resolve.c:7836
+#: fortran/resolve.c:7841 fortran/resolve.c:7847
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -59903,233 +59986,233 @@
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8064
+#: fortran/resolve.c:8075
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr ""
 
-#: fortran/resolve.c:8115
+#: fortran/resolve.c:8126
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr ""
 
-#: fortran/resolve.c:8126
+#: fortran/resolve.c:8137
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr ""
 
-#: fortran/resolve.c:8139
+#: fortran/resolve.c:8150
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:8185
+#: fortran/resolve.c:8196
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr ""
 
-#: fortran/resolve.c:8204
+#: fortran/resolve.c:8215
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr ""
 
-#: fortran/resolve.c:8214
+#: fortran/resolve.c:8225
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr ""
 
-#: fortran/resolve.c:8232 fortran/resolve.c:8240
+#: fortran/resolve.c:8243 fortran/resolve.c:8251
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr ""
 
-#: fortran/resolve.c:8302 fortran/resolve.c:8873
+#: fortran/resolve.c:8313 fortran/resolve.c:8884
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr ""
 
-#: fortran/resolve.c:8328
+#: fortran/resolve.c:8339
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:8340
+#: fortran/resolve.c:8351
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:8355
+#: fortran/resolve.c:8366
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr ""
 
-#: fortran/resolve.c:8458
+#: fortran/resolve.c:8469
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr ""
 
-#: fortran/resolve.c:8518
+#: fortran/resolve.c:8529
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr ""
 
-#: fortran/resolve.c:8523
+#: fortran/resolve.c:8534
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "parameter %u has void type"
 msgid "Selector at %L has no type"
 msgstr "tham số %u có kiểu void"
 
-#: fortran/resolve.c:8545
+#: fortran/resolve.c:8556
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.c:8556
+#: fortran/resolve.c:8567
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:8763
+#: fortran/resolve.c:8774
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8783 fortran/resolve.c:8795
+#: fortran/resolve.c:8794 fortran/resolve.c:8806
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.c:8824
+#: fortran/resolve.c:8835
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr ""
 
-#: fortran/resolve.c:8836
+#: fortran/resolve.c:8847
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr ""
 
-#: fortran/resolve.c:8848
+#: fortran/resolve.c:8859
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr ""
 
-#: fortran/resolve.c:8851
+#: fortran/resolve.c:8862
 #, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "Gặp kiểu hạn chế không cần %qs tại %L"
 
-#: fortran/resolve.c:8861
+#: fortran/resolve.c:8872
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.c:9108
+#: fortran/resolve.c:9119
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9204
+#: fortran/resolve.c:9215
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "Ngữ cảnh sai cho hạn chế NULL() tại %L"
 
-#: fortran/resolve.c:9257
+#: fortran/resolve.c:9268
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "Tham số %qs của thủ tục cơ bản tại %L phải là vô hướng"
 
-#: fortran/resolve.c:9267
+#: fortran/resolve.c:9278
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9280
+#: fortran/resolve.c:9291
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9289
+#: fortran/resolve.c:9300
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr ""
 
-#: fortran/resolve.c:9296
+#: fortran/resolve.c:9307
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9307
+#: fortran/resolve.c:9318
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr ""
 
-#: fortran/resolve.c:9313
+#: fortran/resolve.c:9324
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9328
+#: fortran/resolve.c:9339
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:9388
+#: fortran/resolve.c:9399
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:9398
+#: fortran/resolve.c:9409
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:9402
+#: fortran/resolve.c:9413
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr ""
 
-#: fortran/resolve.c:9405
+#: fortran/resolve.c:9416
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr ""
 
-#: fortran/resolve.c:9412 fortran/resolve.c:9533
+#: fortran/resolve.c:9423 fortran/resolve.c:9545
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:9424 fortran/resolve.c:9540
+#: fortran/resolve.c:9435 fortran/resolve.c:9553
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:9436
+#: fortran/resolve.c:9447
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr ""
 
-#: fortran/resolve.c:9449
+#: fortran/resolve.c:9460
 #, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:9510
+#: fortran/resolve.c:9521
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:9514 fortran/resolve.c:9524
+#: fortran/resolve.c:9525 fortran/resolve.c:9535
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr ""
 
-#: fortran/resolve.c:9567
+#: fortran/resolve.c:9580
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9577
+#: fortran/resolve.c:9590
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr ""
@@ -60136,12 +60219,12 @@
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:9594 fortran/resolve.c:9617
+#: fortran/resolve.c:9607 fortran/resolve.c:9630
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.c:9598 fortran/resolve.c:9623
+#: fortran/resolve.c:9611 fortran/resolve.c:9636
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -60149,107 +60232,107 @@
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:9638
+#: fortran/resolve.c:9651
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9710
+#: fortran/resolve.c:9723
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:9726
+#: fortran/resolve.c:9739
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:9734 fortran/resolve.c:9821
+#: fortran/resolve.c:9747 fortran/resolve.c:9834
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:9744 fortran/resolve.c:9831
+#: fortran/resolve.c:9757 fortran/resolve.c:9844
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:9775
+#: fortran/resolve.c:9788
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:9784
+#: fortran/resolve.c:9797
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr ""
 
-#: fortran/resolve.c:9949
+#: fortran/resolve.c:9962
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr ""
 
-#: fortran/resolve.c:9959
+#: fortran/resolve.c:9972
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr ""
 
-#: fortran/resolve.c:10036
+#: fortran/resolve.c:10049
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr ""
 
-#: fortran/resolve.c:10138
+#: fortran/resolve.c:10151
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr "gfc_resolve_blocks(): Kiểu khối sai"
 
-#: fortran/resolve.c:10251
+#: fortran/resolve.c:10264
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr ""
 
-#: fortran/resolve.c:10283
+#: fortran/resolve.c:10296
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:10288
+#: fortran/resolve.c:10301
 #, gcc-internal-format, gfc-internal-format
 msgid "The impure variable at %L is assigned to a derived type variable with a POINTER component in a PURE procedure (12.6)"
 msgstr ""
 
-#: fortran/resolve.c:10298
+#: fortran/resolve.c:10311
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:10330
+#: fortran/resolve.c:10343
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:10334
+#: fortran/resolve.c:10347
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:10339
+#: fortran/resolve.c:10352
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.c:10346
+#: fortran/resolve.c:10359
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr ""
 
-#: fortran/resolve.c:10357
+#: fortran/resolve.c:10370
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:10663
+#: fortran/resolve.c:10683
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
@@ -60256,67 +60339,67 @@
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:10905
+#: fortran/resolve.c:10925
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:10917
+#: fortran/resolve.c:10937
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr ""
 
-#: fortran/resolve.c:11157
+#: fortran/resolve.c:11177
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:11160
+#: fortran/resolve.c:11180
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr ""
 
-#: fortran/resolve.c:11171
+#: fortran/resolve.c:11191
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr ""
 
-#: fortran/resolve.c:11233
+#: fortran/resolve.c:11253
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:11278
+#: fortran/resolve.c:11298
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid NULL at %L"
 msgstr "NULL không hợp lệ %L"
 
-#: fortran/resolve.c:11282
+#: fortran/resolve.c:11302
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:11339
+#: fortran/resolve.c:11359
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr "gfc_resolve_code(): Không có biểu thức trên DO WHILE"
 
-#: fortran/resolve.c:11344
+#: fortran/resolve.c:11364
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:11428
+#: fortran/resolve.c:11448
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:11507
+#: fortran/resolve.c:11527
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_resolve_code(): Mã câu lệnh sai"
 
-#: fortran/resolve.c:11617
+#: fortran/resolve.c:11637
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
@@ -60323,7 +60406,7 @@
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:11630
+#: fortran/resolve.c:11650
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr ""
@@ -60331,57 +60414,57 @@
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:11647
+#: fortran/resolve.c:11667
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.c:11732
+#: fortran/resolve.c:11752
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "Chiều dài chuỗi tại %L là quá lớn"
 
-#: fortran/resolve.c:11961
+#: fortran/resolve.c:11981
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:11965
+#: fortran/resolve.c:11985
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:11973
+#: fortran/resolve.c:11993
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:11983
+#: fortran/resolve.c:12003
 #, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:11998
+#: fortran/resolve.c:12018
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.c:12010
+#: fortran/resolve.c:12030
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.c:12041
+#: fortran/resolve.c:12061
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.c:12063
+#: fortran/resolve.c:12083
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
 
-#: fortran/resolve.c:12090
+#: fortran/resolve.c:12110
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
@@ -60388,890 +60471,895 @@
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12131
+#: fortran/resolve.c:12151
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr ""
 
-#: fortran/resolve.c:12150
+#: fortran/resolve.c:12170
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr ""
 
-#: fortran/resolve.c:12171
+#: fortran/resolve.c:12191
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr ""
 
-#: fortran/resolve.c:12178
+#: fortran/resolve.c:12198
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr ""
 
-#: fortran/resolve.c:12225
+#: fortran/resolve.c:12245
 #, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12228
+#: fortran/resolve.c:12248
 #, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12232
+#: fortran/resolve.c:12252
 #, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12235
+#: fortran/resolve.c:12255
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12238
+#: fortran/resolve.c:12258
 #, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12241
+#: fortran/resolve.c:12261
 #, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12283
+#: fortran/resolve.c:12303
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L"
 msgstr "%s tại %L"
 
-#: fortran/resolve.c:12310
+#: fortran/resolve.c:12330
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:12332
+#: fortran/resolve.c:12352
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:12354
+#: fortran/resolve.c:12374
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.c:12372
+#: fortran/resolve.c:12392
 #, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "Hàm %qs tại %L không thể có bộ khởi tạo"
 
-#: fortran/resolve.c:12381
+#: fortran/resolve.c:12401
 #, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12389
+#: fortran/resolve.c:12409
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr ""
 
-#: fortran/resolve.c:12399
+#: fortran/resolve.c:12419
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr ""
 
-#: fortran/resolve.c:12418
+#: fortran/resolve.c:12438
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr ""
 
-#: fortran/resolve.c:12422
+#: fortran/resolve.c:12442
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr ""
 
-#: fortran/resolve.c:12426
+#: fortran/resolve.c:12446
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr ""
 
-#: fortran/resolve.c:12430
+#: fortran/resolve.c:12450
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr ""
 
-#: fortran/resolve.c:12443
+#: fortran/resolve.c:12463
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12452
+#: fortran/resolve.c:12472
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:12458
+#: fortran/resolve.c:12478
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:12470
+#: fortran/resolve.c:12490
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:12527
+#: fortran/resolve.c:12547
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12533
+#: fortran/resolve.c:12553
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12539
+#: fortran/resolve.c:12559
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12547
+#: fortran/resolve.c:12567
 #, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12553
+#: fortran/resolve.c:12573
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.c:12596
+#: fortran/resolve.c:12616
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12604
+#: fortran/resolve.c:12624
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12612
+#: fortran/resolve.c:12632
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12621
+#: fortran/resolve.c:12641
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.c:12705
+#: fortran/resolve.c:12725
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:12714
+#: fortran/resolve.c:12734
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr ""
 
-#: fortran/resolve.c:12723
+#: fortran/resolve.c:12743
 #, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "Đối số của thủ tục FINAL tại %L phải là kiểu %qs"
 
-#: fortran/resolve.c:12731
+#: fortran/resolve.c:12751
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:12737
+#: fortran/resolve.c:12757
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:12743
+#: fortran/resolve.c:12763
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr ""
 
-#: fortran/resolve.c:12751
+#: fortran/resolve.c:12771
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:12760
+#: fortran/resolve.c:12780
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr ""
 
-#: fortran/resolve.c:12782
+#: fortran/resolve.c:12802
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr ""
 
-#: fortran/resolve.c:12819
+#: fortran/resolve.c:12839
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr ""
 
-#: fortran/resolve.c:12859
+#: fortran/resolve.c:12879
 #, gcc-internal-format
 msgid "%qs and %qs can't be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12895
+#: fortran/resolve.c:12915
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.c:12954
+#: fortran/resolve.c:12974
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12966
+#: fortran/resolve.c:12986
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.c:12994
+#: fortran/resolve.c:13014
 #, gcc-internal-format
 msgid "GENERIC %qs at %L can't overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.c:13050
+#: fortran/resolve.c:13070
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L can't be NOPASS"
 msgstr ""
 
-#: fortran/resolve.c:13242
+#: fortran/resolve.c:13262
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr ""
 
-#: fortran/resolve.c:13284
+#: fortran/resolve.c:13304
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:13298
+#: fortran/resolve.c:13318
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:13312 fortran/resolve.c:13778
+#: fortran/resolve.c:13332 fortran/resolve.c:13798
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13320
+#: fortran/resolve.c:13340
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "Đối số %qs của %qs với PASS(%s) tại %L phải là kiểu dẫn xuất %qs"
 
-#: fortran/resolve.c:13329
+#: fortran/resolve.c:13349
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:13335
+#: fortran/resolve.c:13355
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13341
+#: fortran/resolve.c:13361
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr ""
 
-#: fortran/resolve.c:13370
+#: fortran/resolve.c:13390
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:13380
+#: fortran/resolve.c:13400
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:13472
+#: fortran/resolve.c:13492
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.c:13574
+#: fortran/resolve.c:13594
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:13583
+#: fortran/resolve.c:13603
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13593
+#: fortran/resolve.c:13613
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.c:13602
+#: fortran/resolve.c:13622
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.c:13613
+#: fortran/resolve.c:13633
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "Đối số của %s tại %L phải là của một độ dài"
 
-#: fortran/resolve.c:13711
+#: fortran/resolve.c:13731
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:13725
+#: fortran/resolve.c:13745
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:13741
+#: fortran/resolve.c:13761
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "Đối số %qs của %qs với PASS(%s) tại %L phải là dẫn xuất kiểu %qs"
 
-#: fortran/resolve.c:13751
+#: fortran/resolve.c:13771
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "Đối số %qs của %qs với PASS(%s) tại %L phải là vô hướng"
 
-#: fortran/resolve.c:13760
+#: fortran/resolve.c:13780
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:13769
+#: fortran/resolve.c:13789
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13811
+#: fortran/resolve.c:13831
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr ""
 
-#: fortran/resolve.c:13824
+#: fortran/resolve.c:13844
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr ""
 
-#: fortran/resolve.c:13835
+#: fortran/resolve.c:13855
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13868
+#: fortran/resolve.c:13888
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:13876
+#: fortran/resolve.c:13896
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.c:13885
+#: fortran/resolve.c:13905
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr ""
 
-#: fortran/resolve.c:13903 fortran/resolve.c:13915
+#: fortran/resolve.c:13923 fortran/resolve.c:13935
 #, gcc-internal-format
 msgid "The pointer component %qs of %qs at %L is a type that has not been declared"
 msgstr ""
 
-#: fortran/resolve.c:13989
+#: fortran/resolve.c:14009
 #, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr ""
 
-#: fortran/resolve.c:14034
+#: fortran/resolve.c:14054
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.c:14047
+#: fortran/resolve.c:14067
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr ""
 
-#: fortran/resolve.c:14111
+#: fortran/resolve.c:14131
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14144
+#: fortran/resolve.c:14164
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.c:14216
+#: fortran/resolve.c:14236
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:14222
+#: fortran/resolve.c:14242
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14228
+#: fortran/resolve.c:14248
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14236
+#: fortran/resolve.c:14256
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14253
+#: fortran/resolve.c:14273
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14275
+#: fortran/resolve.c:14295
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14286
+#: fortran/resolve.c:14306
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14313
+#: fortran/resolve.c:14333
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14337
+#: fortran/resolve.c:14357
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:14353
+#: fortran/resolve.c:14373
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:14364
+#: fortran/resolve.c:14384
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr ""
 
-#: fortran/resolve.c:14372
+#: fortran/resolve.c:14392
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr ""
 
-#: fortran/resolve.c:14423
+#: fortran/resolve.c:14443
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr ""
 
-#: fortran/resolve.c:14434
+#: fortran/resolve.c:14454
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.c:14441
+#: fortran/resolve.c:14461
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.c:14480
+#: fortran/resolve.c:14500
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:14544
+#: fortran/resolve.c:14564
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:14547
+#: fortran/resolve.c:14567
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:14643
+#: fortran/resolve.c:14663
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:14664
+#: fortran/resolve.c:14684
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr ""
 
-#: fortran/resolve.c:14677
+#: fortran/resolve.c:14697
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14680
+#: fortran/resolve.c:14700
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14688
+#: fortran/resolve.c:14708
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14695
+#: fortran/resolve.c:14715
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:14708
+#: fortran/resolve.c:14728
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr ""
 
-#: fortran/resolve.c:14714
+#: fortran/resolve.c:14734
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14724
+#: fortran/resolve.c:14744
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:14733
+#: fortran/resolve.c:14753
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.c:14746 fortran/resolve.c:14923
+#: fortran/resolve.c:14766 fortran/resolve.c:14943
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.c:14760
+#: fortran/resolve.c:14780
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14769
+#: fortran/resolve.c:14789
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:14778
+#: fortran/resolve.c:14798
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14786
+#: fortran/resolve.c:14806
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:14793
+#: fortran/resolve.c:14813
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:14813
+#: fortran/resolve.c:14833
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.c:14820
+#: fortran/resolve.c:14840
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14827
+#: fortran/resolve.c:14847
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:14834
+#: fortran/resolve.c:14854
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:14860
+#: fortran/resolve.c:14880
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:14870
+#: fortran/resolve.c:14890
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "Đối số của %s tại %L phải là của một độ dài"
 
-#: fortran/resolve.c:14949
+#: fortran/resolve.c:14969
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:14964
+#: fortran/resolve.c:14984
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14977
+#: fortran/resolve.c:14997
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14995
+#: fortran/resolve.c:15015
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.c:15007
+#: fortran/resolve.c:15027
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:15016
+#: fortran/resolve.c:15036
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:15028
+#: fortran/resolve.c:15048
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr ""
 
-#: fortran/resolve.c:15037
+#: fortran/resolve.c:15057
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15049
+#: fortran/resolve.c:15069
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15065
+#: fortran/resolve.c:15085
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15073
+#: fortran/resolve.c:15093
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15080
+#: fortran/resolve.c:15100
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15092
+#: fortran/resolve.c:15112
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.c:15101
+#: fortran/resolve.c:15121
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15117
+#: fortran/resolve.c:15137
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15123
+#: fortran/resolve.c:15143
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15148
+#: fortran/resolve.c:15168
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist '%s' can not be an argument at %L"
 msgid "Namelist %qs can not be an argument to subroutine or function at %L"
 msgstr "Danh sách tên “%s” không thể là đối số tại %L"
 
-#: fortran/resolve.c:15218
+#: fortran/resolve.c:15238
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:15229
+#: fortran/resolve.c:15249
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:15333
+#: fortran/resolve.c:15353
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:15339
+#: fortran/resolve.c:15359
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:15345
+#: fortran/resolve.c:15365
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.c:15354
+#: fortran/resolve.c:15374
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr ""
 
-#: fortran/resolve.c:15368
+#: fortran/resolve.c:15388
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:15414
+#: fortran/resolve.c:15434
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.c:15427
+#: fortran/resolve.c:15447
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.c:15526
+#: fortran/resolve.c:15546
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15534
+#: fortran/resolve.c:15554
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15542
+#: fortran/resolve.c:15562
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15667
+#: fortran/resolve.c:15687
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.c:15832
+#: fortran/resolve.c:15852
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "Nhãn %d tại %L đã định nghĩa nhưng chưa được dùng"
 
-#: fortran/resolve.c:15838
+#: fortran/resolve.c:15858
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr ""
 
-#: fortran/resolve.c:15922
+#: fortran/resolve.c:15942
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15931
+#: fortran/resolve.c:15951
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15939
+#: fortran/resolve.c:15959
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:15955
+#: fortran/resolve.c:15975
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16058
+#: fortran/resolve.c:16078
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:16073
+#: fortran/resolve.c:16093
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:16098
+#: fortran/resolve.c:16118
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:16107
+#: fortran/resolve.c:16127
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16180
+#: fortran/resolve.c:16200
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16191
+#: fortran/resolve.c:16211
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16202
+#: fortran/resolve.c:16222
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "Chuỗi con tại %L có độ dài là không"
 
-#: fortran/resolve.c:16293
+#: fortran/resolve.c:16253
 #, gcc-internal-format
+msgid "Self reference in character length expression for %qs at %L"
+msgstr ""
+
+#: fortran/resolve.c:16320
+#, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.c:16306
+#: fortran/resolve.c:16333
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:16326
+#: fortran/resolve.c:16353
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:16336
+#: fortran/resolve.c:16363
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr ""
 
-#: fortran/resolve.c:16344
+#: fortran/resolve.c:16371
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:16358
+#: fortran/resolve.c:16385
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:16376
+#: fortran/resolve.c:16403
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:16383
+#: fortran/resolve.c:16410
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr ""
 
-#: fortran/resolve.c:16461
+#: fortran/resolve.c:16488
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -61598,19 +61686,13 @@
 msgid "simplify_min_max(): Bad type in arglist"
 msgstr ""
 
-#. Result is processor-dependent.
-#: fortran/simplify.c:5472
-#, gcc-internal-format, gfc-internal-format
-msgid "Second argument MOD at %L is zero"
-msgstr ""
+#: fortran/simplify.c:5470 fortran/simplify.c:5478
+#, fuzzy, gcc-internal-format
+#| msgid "Argument of %s at %L must be of length one"
+msgid "Argument %qs of MOD at %L shall not be zero"
+msgstr "Đối số của %s tại %L phải là của một độ dài"
 
-#. Result is processor-dependent.
-#: fortran/simplify.c:5483
-#, gcc-internal-format, gfc-internal-format
-msgid "Second argument of MOD at %L is zero"
-msgstr ""
-
-#: fortran/simplify.c:5494
+#: fortran/simplify.c:5484
 #, gcc-internal-format
 msgid "gfc_simplify_mod(): Bad arguments"
 msgstr ""
@@ -61618,97 +61700,97 @@
 #. Result is processor-dependent. This processor just opts
 #. to not handle it at all.
 #. Result is processor-dependent.
-#: fortran/simplify.c:5520 fortran/simplify.c:5532
+#: fortran/simplify.c:5525 fortran/simplify.c:5537
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of MODULO at %L is zero"
 msgstr ""
 
-#: fortran/simplify.c:5552
+#: fortran/simplify.c:5557
 #, gcc-internal-format
 msgid "gfc_simplify_modulo(): Bad arguments"
 msgstr ""
 
-#: fortran/simplify.c:5600
+#: fortran/simplify.c:5605
 #, gcc-internal-format, gfc-internal-format
 msgid "Result of NEAREST is NaN at %L"
 msgstr ""
 
-#: fortran/simplify.c:6081
+#: fortran/simplify.c:6086
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative at %L"
 msgstr ""
 
-#: fortran/simplify.c:6137
+#: fortran/simplify.c:6142
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument NCOPIES of REPEAT intrinsic is too large at %L"
 msgstr ""
 
-#: fortran/simplify.c:6174
+#: fortran/simplify.c:6179
 #, gcc-internal-format, gfc-internal-format
 msgid "Evaluation of string longer than 2**28 at %L deferred to runtime, expect bugs"
 msgstr ""
 
-#: fortran/simplify.c:6302
+#: fortran/simplify.c:6307
 #, gcc-internal-format, gfc-internal-format
 msgid "Reshaped array too large at %C"
 msgstr ""
 
-#: fortran/simplify.c:6416
+#: fortran/simplify.c:6421
 #, gcc-internal-format, gfc-internal-format
 msgid "Result of SCALE overflows its kind at %L"
 msgstr ""
 
-#: fortran/simplify.c:6995
+#: fortran/simplify.c:7000
 #, gcc-internal-format
 msgid "Bad type in gfc_simplify_sign"
 msgstr ""
 
-#: fortran/simplify.c:7024
+#: fortran/simplify.c:7029
 #, gcc-internal-format
 msgid "in gfc_simplify_sin(): Bad type"
 msgstr "in gfc_simplify_sin(): Kiểu sai"
 
-#: fortran/simplify.c:7151 fortran/simplify.c:7431
+#: fortran/simplify.c:7156 fortran/simplify.c:7436
 #, gcc-internal-format
 msgid "Failure getting length of a constant array."
 msgstr ""
 
-#: fortran/simplify.c:7161
+#: fortran/simplify.c:7166
 #, gcc-internal-format
 msgid "The number of elements (%d) in the array constructor at %L requires an increase of the allowed %d upper limit.  See %<-fmax-array-constructor%> option."
 msgstr ""
 
-#: fortran/simplify.c:7227
+#: fortran/simplify.c:7232
 #, gcc-internal-format, gfc-internal-format
 msgid "Simplification of SPREAD at %C not yet implemented"
 msgstr ""
 
-#: fortran/simplify.c:7251
+#: fortran/simplify.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SQRT at %L has a negative value"
 msgstr ""
 
-#: fortran/simplify.c:7267
+#: fortran/simplify.c:7272
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid argument of SQRT at %L"
 msgstr "đối số của SQRT tại %L không hợp lệ"
 
-#: fortran/simplify.c:7598
+#: fortran/simplify.c:7603
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY lower bound is %ld)"
 msgstr ""
 
-#: fortran/simplify.c:7621
+#: fortran/simplify.c:7626
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY upper bound is %ld)"
 msgstr ""
 
-#: fortran/simplify.c:7993
+#: fortran/simplify.c:7998
 #, gcc-internal-format
 msgid "gfc_convert_constant(): Unexpected type"
 msgstr ""
 
-#: fortran/simplify.c:8078
+#: fortran/simplify.c:8083
 #, gcc-internal-format
 msgid "Character %qs in string at %L cannot be converted into character kind %d"
 msgstr ""
@@ -61811,7 +61893,7 @@
 msgid "BIND(C) applied to %s %s at %L"
 msgstr "BIND(C) được áp dụng với %s %s tại %L"
 
-#: fortran/symbol.c:901 fortran/symbol.c:912 fortran/symbol.c:1762
+#: fortran/symbol.c:901 fortran/symbol.c:912 fortran/symbol.c:1776
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute conflicts with %s attribute at %L"
 msgstr ""
@@ -61886,17 +61968,22 @@
 msgid "Duplicate VOLATILE attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1367
+#: fortran/symbol.c:1360
 #, gcc-internal-format, gfc-internal-format
+msgid "VOLATILE attribute at %L cannot be specified in a PURE procedure"
+msgstr ""
+
+#: fortran/symbol.c:1381
+#, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ASYNCHRONOUS attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1758
+#: fortran/symbol.c:1772
 #, gcc-internal-format
 msgid "%s attribute of %qs conflicts with %s attribute at %L"
 msgstr "thuộc tính %s của %qs xung đột với thuộc tính %s tại %L"
 
-#: fortran/symbol.c:1794
+#: fortran/symbol.c:1808
 #, gcc-internal-format, gfc-internal-format
 msgid ""
 "%s procedure at %L is already declared as %s procedure. \n"
@@ -61903,209 +61990,209 @@
 "F2008: A pointer function assignment is ambiguous if it is the first executable statement after the specification block. Please add any other kind of executable statement before it. FIXME"
 msgstr ""
 
-#: fortran/symbol.c:1802
+#: fortran/symbol.c:1816
 #, gcc-internal-format, gfc-internal-format
 msgid "%s procedure at %L is already declared as %s procedure"
 msgstr ""
 
-#: fortran/symbol.c:1837
+#: fortran/symbol.c:1851
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgstr ""
 
-#: fortran/symbol.c:1861
+#: fortran/symbol.c:1875
 #, gcc-internal-format, gfc-internal-format
 msgid "ACCESS specification at %L was already specified"
 msgstr ""
 
-#: fortran/symbol.c:1878
+#: fortran/symbol.c:1892
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate BIND attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1885
+#: fortran/symbol.c:1899
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) at %L"
 msgstr "BIND(C) tại %L"
 
-#: fortran/symbol.c:1901
+#: fortran/symbol.c:1915
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate EXTENDS attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1905
+#: fortran/symbol.c:1919
 #, gcc-internal-format, gfc-internal-format
 msgid "EXTENDS at %L"
 msgstr "EXTENDS tại %L"
 
-#: fortran/symbol.c:1931
+#: fortran/symbol.c:1945
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has an explicit interface"
 msgstr ""
 
-#: fortran/symbol.c:1938
+#: fortran/symbol.c:1952
 #, gcc-internal-format
 msgid "%qs at %L has attributes specified outside its INTERFACE body"
 msgstr ""
 
-#: fortran/symbol.c:1976
+#: fortran/symbol.c:1990
 #, gcc-internal-format
 msgid "Symbol %qs at %L conflicts with symbol from module %qs, use-associated at %L"
 msgstr ""
 
-#: fortran/symbol.c:1980
+#: fortran/symbol.c:1994
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr ""
 
-#: fortran/symbol.c:1987
+#: fortran/symbol.c:2001
 #, gcc-internal-format
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr ""
 
-#: fortran/symbol.c:1999
+#: fortran/symbol.c:2013
 #, gcc-internal-format
 msgid "Symbol %qs at %L cannot have a type"
 msgstr ""
 
-#: fortran/symbol.c:2242
+#: fortran/symbol.c:2256
 #, gcc-internal-format
 msgid "Component %qs at %C already in the parent type at %L"
 msgstr "Thành phần “%qs” tại %C đã sẵn trong kiểu cha mẹ %L"
 
-#: fortran/symbol.c:2327
+#: fortran/symbol.c:2341
 #, gcc-internal-format
 msgid "Symbol %qs at %C is ambiguous"
 msgstr ""
 
-#: fortran/symbol.c:2359
+#: fortran/symbol.c:2373
 #, gcc-internal-format
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr ""
 
-#: fortran/symbol.c:2508
+#: fortran/symbol.c:2522
 #, gcc-internal-format
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr ""
 
-#: fortran/symbol.c:2529
+#: fortran/symbol.c:2543
 #, fuzzy, gcc-internal-format
 #| msgid "%qs at %C is not a member of the %qs structure"
 msgid "%qs at %C is not a member of the %qs structure; did you mean %qs?"
 msgstr "%qs tại %C không phải là thành viên của cấu trúc %qs"
 
-#: fortran/symbol.c:2533
+#: fortran/symbol.c:2547
 #, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr "%qs tại %C không phải là thành viên của cấu trúc %qs"
 
-#: fortran/symbol.c:2697
+#: fortran/symbol.c:2711
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr ""
 
-#: fortran/symbol.c:2708
+#: fortran/symbol.c:2722
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr ""
 
-#: fortran/symbol.c:2718
+#: fortran/symbol.c:2732
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr ""
 
-#: fortran/symbol.c:2724
+#: fortran/symbol.c:2738
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:2766
+#: fortran/symbol.c:2780
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr ""
 
-#: fortran/symbol.c:2775
+#: fortran/symbol.c:2789
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr ""
 
-#: fortran/symbol.c:2781
+#: fortran/symbol.c:2795
 #, gcc-internal-format, gfc-internal-format
 msgid "Shared DO termination label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:3110
+#: fortran/symbol.c:3124
 #, gcc-internal-format
 msgid "new_symbol(): Symbol name too long"
 msgstr "new_symbol(): Tên ký hiệu quá dài"
 
-#: fortran/symbol.c:3135
+#: fortran/symbol.c:3149
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr ""
 
-#: fortran/symbol.c:3138
+#: fortran/symbol.c:3152
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
 msgstr ""
 
 #. Symbol is from another namespace.
-#: fortran/symbol.c:3381
+#: fortran/symbol.c:3395
 #, gcc-internal-format
 msgid "Symbol %qs at %C has already been host associated"
 msgstr ""
 
-#: fortran/symbol.c:4397
+#: fortran/symbol.c:4411
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr ""
 
-#: fortran/symbol.c:4410
+#: fortran/symbol.c:4424
 #, gcc-internal-format
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr ""
 
-#: fortran/symbol.c:4428
+#: fortran/symbol.c:4442
 #, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr ""
 
-#: fortran/symbol.c:4449
+#: fortran/symbol.c:4463
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:4459
+#: fortran/symbol.c:4473
 #, gcc-internal-format
 msgid "Procedure pointer component %qs at %L cannot be a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:4470
+#: fortran/symbol.c:4484
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:4509
+#: fortran/symbol.c:4523
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.c:4519
+#: fortran/symbol.c:4533
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/symbol.c:4533
+#: fortran/symbol.c:4547
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot be declared with both PRIVATE and BIND(C) attributes"
 msgstr ""
 
-#: fortran/symbol.c:4541
+#: fortran/symbol.c:4555
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.c:5018 fortran/symbol.c:5023
+#: fortran/symbol.c:5032 fortran/symbol.c:5037
 #, gcc-internal-format
 msgid "Symbol %qs is used before it is typed at %L"
 msgstr ""
@@ -62152,7 +62239,7 @@
 msgid "Creating array temporary at %L for argument %qs"
 msgstr ""
 
-#: fortran/trans-array.c:10693
+#: fortran/trans-array.c:10724
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr ""
@@ -62354,12 +62441,12 @@
 msgid "%<dim%> argument of %s intrinsic at %L is not a valid dimension index"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:10572 fortran/trans-stmt.c:1050
+#: fortran/trans-intrinsic.c:10574 fortran/trans-stmt.c:1050
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, the event component of derived type at %L is not yet supported"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:10579
+#: fortran/trans-intrinsic.c:10581
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The event variable at %L shall not be coindexed "
 msgid "The event variable at %L shall not be coindexed"
@@ -62400,7 +62487,7 @@
 msgid "Sorry, only support for integer kind %d implemented for image-set at %L"
 msgstr ""
 
-#: fortran/trans-stmt.c:3346
+#: fortran/trans-stmt.c:3343
 #, gcc-internal-format
 msgid "gfc_trans_select(): Bad type for case expr."
 msgstr "gfc_trans_select(): Kiểu cho biểu thức case sai."
@@ -62528,7 +62615,7 @@
 msgid "two or more sections for %s"
 msgstr "cần thiết ít nhất hai phần cho %s"
 
-#: lto/lto-partition.c:516
+#: lto/lto-partition.c:570
 #, gcc-internal-format
 msgid "min partition size cannot be greater than max partition size"
 msgstr ""
@@ -62663,58 +62750,58 @@
 msgid "Cannot read %s"
 msgstr "Không thể đọc %s"
 
-#: lto/lto.c:2369
+#: lto/lto.c:2337
 #, gcc-internal-format
 msgid "lto_obj_file_open() failed"
 msgstr "lto_obj_file_open() gặp lỗi"
 
-#: lto/lto.c:2394
+#: lto/lto.c:2362
 #, gcc-internal-format
 msgid "waitpid failed"
 msgstr "waitpid bị lỗi"
 
-#: lto/lto.c:2397
+#: lto/lto.c:2365
 #, gcc-internal-format
 msgid "streaming subprocess failed"
 msgstr ""
 
-#: lto/lto.c:2400
+#: lto/lto.c:2368
 #, gcc-internal-format
 msgid "streaming subprocess was killed by signal"
 msgstr ""
 
-#: lto/lto.c:2476
+#: lto/lto.c:2445
 #, gcc-internal-format
 msgid "no LTRANS output list filename provided"
 msgstr ""
 
-#: lto/lto.c:2564
+#: lto/lto.c:2525
 #, gcc-internal-format
 msgid "opening LTRANS output list %s: %m"
 msgstr ""
 
-#: lto/lto.c:2570
+#: lto/lto.c:2532
 #, gcc-internal-format
 msgid "writing to LTRANS output list %s: %m"
 msgstr ""
 
-#: lto/lto.c:2581
+#: lto/lto.c:2542
 #, gcc-internal-format
 msgid "closing LTRANS output list %s: %m"
 msgstr ""
 
-#: lto/lto.c:2833
+#: lto/lto.c:2794
 #, gcc-internal-format
 msgid "could not open symbol resolution file: %m"
 msgstr ""
 
-#: lto/lto.c:2954
+#: lto/lto.c:2915
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing argument to %qs"
 msgid "missing resolution data for %s"
 msgstr "thiếu đối số đối cho %qs"
 
-#: lto/lto.c:2986
+#: lto/lto.c:2947
 #, gcc-internal-format
 msgid "errors during merging of translation units"
 msgstr ""
@@ -63855,9 +63942,6 @@
 #~ msgid "previous declaration of namespace %qD here"
 #~ msgstr "khai báo trước đây của không gian tên %qD ở đây"
 
-#~ msgid "  declared here"
-#~ msgstr "  đã được khai báo ở đây"
-
 #~ msgid "%qD must take %<void%>"
 #~ msgstr "%qD phải nhận %<void%>"
 
Index: gcc/po/uk.po
===================================================================
--- gcc/po/uk.po	(.../tags/gcc_8_2_0_release)
+++ gcc/po/uk.po	(.../branches/gcc-8-branch)
@@ -5,10 +5,10 @@
 # Yuri Chornoivan <yurchor@ukr.net>, 2015, 2016, 2017, 2018.
 msgid ""
 msgstr ""
-"Project-Id-Version: gcc 8.1.0\n"
+"Project-Id-Version: gcc 8.2.0\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2018-05-01 20:30+0000\n"
-"PO-Revision-Date: 2018-05-04 16:12+0200\n"
+"POT-Creation-Date: 2018-07-25 14:25+0000\n"
+"PO-Revision-Date: 2018-07-27 22:28+0200\n"
 "Last-Translator: Yuri Chornoivan <yurchor@ukr.net>\n"
 "Language-Team: Ukrainian <translation-team-uk@lists.sourceforge.net>\n"
 "Language: uk\n"
@@ -40,12 +40,12 @@
 msgid "[cannot find %s]"
 msgstr "[не вдалося знайти %s]"
 
-#: collect2.c:1557
+#: collect2.c:1585
 #, c-format
 msgid "collect2 version %s\n"
 msgstr "collect2 версії %s\n"
 
-#: collect2.c:1664
+#: collect2.c:1692
 #, c-format
 msgid "%d constructor found\n"
 msgid_plural "%d constructors found\n"
@@ -53,7 +53,7 @@
 msgstr[1] "знайдено %d конструктори\n"
 msgstr[2] "знайдено %d конструкторів\n"
 
-#: collect2.c:1668
+#: collect2.c:1696
 #, c-format
 msgid "%d destructor found\n"
 msgid_plural "%d destructors found\n"
@@ -61,7 +61,7 @@
 msgstr[1] "знайдено %d деструктори\n"
 msgstr[2] "знайдено %d деструкторів\n"
 
-#: collect2.c:1672
+#: collect2.c:1700
 #, c-format
 msgid "%d frame table found\n"
 msgid_plural "%d frame tables found\n"
@@ -69,12 +69,12 @@
 msgstr[1] "знайдено %d таблиці кадрів\n"
 msgstr[2] "знайдено %d таблиць кадрів\n"
 
-#: collect2.c:1836
+#: collect2.c:1864
 #, c-format
 msgid "[Leaving %s]\n"
 msgstr "[Полишаємо %s]\n"
 
-#: collect2.c:2068
+#: collect2.c:2094
 #, c-format
 msgid ""
 "\n"
@@ -83,7 +83,7 @@
 "\n"
 "write_c_file - назвою результату є %s, префіксом є %s\n"
 
-#: collect2.c:2584
+#: collect2.c:2610
 #, c-format
 msgid ""
 "\n"
@@ -106,7 +106,7 @@
 msgid "%s: some warnings being treated as errors"
 msgstr "%s: деякі попередження вважаються помилками"
 
-#: diagnostic.c:324 input.c:222 input.c:1834 c-family/c-opts.c:1377
+#: diagnostic.c:324 input.c:222 input.c:1834 c-family/c-opts.c:1392
 #: fortran/cpp.c:576 fortran/error.c:1008 fortran/error.c:1028
 msgid "<built-in>"
 msgstr "<вбудоване>"
@@ -198,13 +198,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:4164 config/arc/arc.c:5784 config/i386/i386.c:17302
+#: final.c:4164 config/arc/arc.c:5775 config/i386/i386.c:17305
 #: config/pdp11/pdp11.c:1715
 #, c-format
 msgid "floating constant misused"
 msgstr "помилкове використання сталої із рухомою крапкою"
 
-#: final.c:4222 config/arc/arc.c:5881 config/i386/i386.c:17393
+#: final.c:4222 config/arc/arc.c:5872 config/i386/i386.c:17396
 #: config/pdp11/pdp11.c:1756
 #, c-format
 msgid "invalid expression as operand"
@@ -1101,7 +1101,7 @@
 msgid "GCSE disabled"
 msgstr ""
 
-#: gimple-ssa-isolate-paths.c:542 c/c-typeck.c:10240
+#: gimple-ssa-isolate-paths.c:542 c/c-typeck.c:10245
 #, gcc-internal-format
 msgid "function returns address of local variable"
 msgstr ""
@@ -1399,7 +1399,7 @@
 msgid "options enabled: "
 msgstr ""
 
-#: tree-diagnostic.c:299 c/c-decl.c:5419 c/c-typeck.c:7259 cp/error.c:1042
+#: tree-diagnostic.c:299 c/c-decl.c:5439 c/c-typeck.c:7264 cp/error.c:1042
 #: c-family/c-pretty-print.c:413
 #, gcc-internal-format
 msgid "<anonymous>"
@@ -2853,64 +2853,64 @@
 msgstr ""
 
 #. Handle deferred options from command-line.
-#: c-family/c-opts.c:1402 fortran/cpp.c:590
+#: c-family/c-opts.c:1417 fortran/cpp.c:590
 msgid "<command-line>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6613
+#: config/aarch64/aarch64.c:6629
 #, c-format
 msgid "unsupported operand for code '%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6624 config/aarch64/aarch64.c:6640
-#: config/aarch64/aarch64.c:6652 config/aarch64/aarch64.c:6663
-#: config/aarch64/aarch64.c:6673 config/aarch64/aarch64.c:6694
-#: config/aarch64/aarch64.c:6764 config/aarch64/aarch64.c:6775
-#: config/aarch64/aarch64.c:6789 config/aarch64/aarch64.c:7011
-#: config/aarch64/aarch64.c:7029
+#: config/aarch64/aarch64.c:6640 config/aarch64/aarch64.c:6656
+#: config/aarch64/aarch64.c:6668 config/aarch64/aarch64.c:6679
+#: config/aarch64/aarch64.c:6689 config/aarch64/aarch64.c:6710
+#: config/aarch64/aarch64.c:6780 config/aarch64/aarch64.c:6791
+#: config/aarch64/aarch64.c:6805 config/aarch64/aarch64.c:7027
+#: config/aarch64/aarch64.c:7045
 #, c-format
 msgid "invalid operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6709 config/aarch64/aarch64.c:6720
-#: config/aarch64/aarch64.c:6871 config/aarch64/aarch64.c:6882
+#: config/aarch64/aarch64.c:6725 config/aarch64/aarch64.c:6736
+#: config/aarch64/aarch64.c:6887 config/aarch64/aarch64.c:6898
 #, c-format
 msgid "invalid vector constant"
 msgstr "некоректна векторна константа"
 
-#: config/aarch64/aarch64.c:6732 config/aarch64/aarch64.c:6744
-#: config/aarch64/aarch64.c:6755
+#: config/aarch64/aarch64.c:6748 config/aarch64/aarch64.c:6760
+#: config/aarch64/aarch64.c:6771
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6823 config/arm/arm.c:22704
+#: config/aarch64/aarch64.c:6839 config/arm/arm.c:22704
 #, c-format
 msgid "missing operand"
 msgstr "пропущено операнд"
 
-#: config/aarch64/aarch64.c:6908
+#: config/aarch64/aarch64.c:6924
 #, c-format
 msgid "invalid constant"
 msgstr "некоректна константа"
 
-#: config/aarch64/aarch64.c:6911
+#: config/aarch64/aarch64.c:6927
 #, c-format
 msgid "invalid operand"
 msgstr "некоректний операнд"
 
-#: config/aarch64/aarch64.c:7040 config/aarch64/aarch64.c:7045
+#: config/aarch64/aarch64.c:7056 config/aarch64/aarch64.c:7061
 #, c-format
 msgid "invalid operand prefix '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:7062
+#: config/aarch64/aarch64.c:7078
 #, c-format
 msgid "invalid address mode"
 msgstr "некоректний режим адресування"
 
-#: config/alpha/alpha.c:5125 config/i386/i386.c:18558
-#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21798
+#: config/alpha/alpha.c:5125 config/i386/i386.c:18561
+#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21875
 #: config/sparc/sparc.c:9290
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
@@ -2927,7 +2927,7 @@
 msgstr "некоректне значення %%r"
 
 #: config/alpha/alpha.c:5223 config/ia64/ia64.c:5534
-#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21506
+#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21583
 #: config/xtensa/xtensa.c:2429
 #, c-format
 msgid "invalid %%R value"
@@ -2934,13 +2934,13 @@
 msgstr "некоректне значення %%R"
 
 #: config/alpha/alpha.c:5229 config/powerpcspe/powerpcspe.c:23933
-#: config/rs6000/rs6000.c:21426 config/xtensa/xtensa.c:2396
+#: config/rs6000/rs6000.c:21503 config/xtensa/xtensa.c:2396
 #, c-format
 msgid "invalid %%N value"
 msgstr "некоректне значення %%N"
 
 #: config/alpha/alpha.c:5237 config/powerpcspe/powerpcspe.c:23961
-#: config/rs6000/rs6000.c:21454
+#: config/rs6000/rs6000.c:21531
 #, c-format
 msgid "invalid %%P value"
 msgstr "некоректне значення %%P"
@@ -2971,7 +2971,7 @@
 msgstr "некоректне значення %%U"
 
 #: config/alpha/alpha.c:5323 config/powerpcspe/powerpcspe.c:24021
-#: config/rs6000/rs6000.c:21514
+#: config/rs6000/rs6000.c:21591
 #, c-format
 msgid "invalid %%s value"
 msgstr "некоректне значення %%s"
@@ -2982,7 +2982,7 @@
 msgstr "некоректне значення %%C"
 
 #: config/alpha/alpha.c:5371 config/powerpcspe/powerpcspe.c:23797
-#: config/rs6000/rs6000.c:21290
+#: config/rs6000/rs6000.c:21367
 #, c-format
 msgid "invalid %%E value"
 msgstr "некоректне значення %%E"
@@ -2993,7 +2993,7 @@
 msgstr ""
 
 #: config/alpha/alpha.c:5405 config/cr16/cr16.c:1569
-#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21803
+#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21880
 #: config/spu/spu.c:1458
 #, c-format
 msgid "invalid %%xn code"
@@ -3004,57 +3004,57 @@
 msgid "invalid operand address"
 msgstr ""
 
-#: config/arc/arc.c:3810
+#: config/arc/arc.c:3808
 #, c-format
 msgid "invalid operand to %%Z code"
 msgstr ""
 
-#: config/arc/arc.c:3818
+#: config/arc/arc.c:3816
 #, c-format
 msgid "invalid operand to %%z code"
 msgstr ""
 
-#: config/arc/arc.c:3826
+#: config/arc/arc.c:3824
 #, c-format
 msgid "invalid operands to %%c code"
 msgstr "некоректні операнди для коду %%c"
 
-#: config/arc/arc.c:3834
+#: config/arc/arc.c:3832
 #, c-format
 msgid "invalid operand to %%M code"
 msgstr ""
 
-#: config/arc/arc.c:3842 config/m32r/m32r.c:2100
+#: config/arc/arc.c:3840 config/m32r/m32r.c:2100
 #, c-format
 msgid "invalid operand to %%p code"
 msgstr ""
 
-#: config/arc/arc.c:3853 config/m32r/m32r.c:2093
+#: config/arc/arc.c:3851 config/m32r/m32r.c:2093
 #, c-format
 msgid "invalid operand to %%s code"
 msgstr ""
 
-#: config/arc/arc.c:4001 config/m32r/m32r.c:2126
+#: config/arc/arc.c:3999 config/m32r/m32r.c:2126
 #, c-format
 msgid "invalid operand to %%R code"
 msgstr ""
 
-#: config/arc/arc.c:4077 config/m32r/m32r.c:2149
+#: config/arc/arc.c:4075 config/m32r/m32r.c:2149
 #, c-format
 msgid "invalid operand to %%H/%%L code"
 msgstr ""
 
-#: config/arc/arc.c:4145 config/m32r/m32r.c:2220
+#: config/arc/arc.c:4143 config/m32r/m32r.c:2220
 #, c-format
 msgid "invalid operand to %%U code"
 msgstr ""
 
-#: config/arc/arc.c:4157
+#: config/arc/arc.c:4155
 #, c-format
 msgid "invalid operand to %%V code"
 msgstr ""
 
-#: config/arc/arc.c:4214
+#: config/arc/arc.c:4212
 #, c-format
 msgid "invalid operand to %%O code"
 msgstr ""
@@ -3061,18 +3061,18 @@
 
 #. Unknown flag.
 #. Undocumented flag.
-#: config/arc/arc.c:4240 config/epiphany/epiphany.c:1305
-#: config/m32r/m32r.c:2247 config/nds32/nds32.c:3079 config/sparc/sparc.c:9569
+#: config/arc/arc.c:4238 config/epiphany/epiphany.c:1305
+#: config/m32r/m32r.c:2247 config/nds32/nds32.c:3080 config/sparc/sparc.c:9569
 #, c-format
 msgid "invalid operand output code"
 msgstr ""
 
-#: config/arc/arc.c:5869
+#: config/arc/arc.c:5860
 #, c-format
 msgid "invalid UNSPEC as operand: %d"
 msgstr ""
 
-#: config/arc/arc.c:6158 config/cris/cris.c:2568
+#: config/arc/arc.c:6149 config/cris/cris.c:2568
 msgid "unrecognized supposed constant"
 msgstr ""
 
@@ -3107,7 +3107,7 @@
 #: config/arm/arm.c:22685 config/arm/arm.c:22692 config/bfin/bfin.c:1441
 #: config/bfin/bfin.c:1448 config/bfin/bfin.c:1455 config/bfin/bfin.c:1462
 #: config/bfin/bfin.c:1471 config/bfin/bfin.c:1478 config/bfin/bfin.c:1485
-#: config/bfin/bfin.c:1492 config/nds32/nds32.c:3098
+#: config/bfin/bfin.c:1492 config/nds32/nds32.c:3099
 #, c-format
 msgid "invalid operand for code '%c'"
 msgstr ""
@@ -3446,97 +3446,97 @@
 msgid "bad output_condmove_single operand"
 msgstr ""
 
-#: config/i386/i386.c:17387
+#: config/i386/i386.c:17390
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr ""
 
-#: config/i386/i386.c:17925
+#: config/i386/i386.c:17928
 #, c-format
 msgid "invalid use of register '%s'"
 msgstr "некоректне використання регістру «%s»"
 
-#: config/i386/i386.c:17930
+#: config/i386/i386.c:17933
 #, c-format
 msgid "invalid use of asm flag output"
 msgstr ""
 
-#: config/i386/i386.c:18160
+#: config/i386/i386.c:18163
 #, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr ""
 
-#: config/i386/i386.c:18195
+#: config/i386/i386.c:18198
 #, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr ""
 
-#: config/i386/i386.c:18264
+#: config/i386/i386.c:18267
 #, c-format
 msgid "invalid operand type used with operand code 'Z'"
 msgstr ""
 
-#: config/i386/i386.c:18269
+#: config/i386/i386.c:18272
 #, c-format
 msgid "invalid operand size for operand code 'Z'"
 msgstr ""
 
-#: config/i386/i386.c:18346
+#: config/i386/i386.c:18349
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr ""
 
-#: config/i386/i386.c:18425
+#: config/i386/i386.c:18428
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr ""
 
-#: config/i386/i386.c:18443
+#: config/i386/i386.c:18446
 #, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr ""
 
-#: config/i386/i386.c:18456
+#: config/i386/i386.c:18459
 #, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr ""
 
-#: config/i386/i386.c:18471
+#: config/i386/i386.c:18474
 #, c-format
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr ""
 
-#: config/i386/i386.c:18499
+#: config/i386/i386.c:18502
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr ""
 
-#: config/i386/i386.c:18517
+#: config/i386/i386.c:18520
 #, c-format
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr ""
 
-#: config/i386/i386.c:18540
+#: config/i386/i386.c:18543
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr ""
 
-#: config/i386/i386.c:18626
+#: config/i386/i386.c:18629
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr ""
 
-#: config/i386/i386.c:18688
+#: config/i386/i386.c:18691
 #, c-format
 msgid "invalid constraints for operand"
 msgstr ""
 
-#: config/i386/i386.c:18738
+#: config/i386/i386.c:18741
 #, c-format
 msgid "invalid vector immediate"
 msgstr "некоректна векторна константа"
 
-#: config/i386/i386.c:29572
+#: config/i386/i386.c:29575
 msgid "unknown insn mode"
 msgstr ""
 
@@ -3574,7 +3574,7 @@
 msgstr ""
 
 #: config/iq2000/iq2000.c:3185 config/powerpcspe/powerpcspe.c:23951
-#: config/rs6000/rs6000.c:21444
+#: config/rs6000/rs6000.c:21521
 #, c-format
 msgid "invalid %%p value"
 msgstr "некоректне значення %%p"
@@ -3628,7 +3628,7 @@
 msgstr ""
 
 #: config/m32r/m32r.c:2350 config/m32r/m32r.c:2365
-#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33292
+#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33348
 msgid "bad address"
 msgstr "помилкова адреса"
 
@@ -3747,185 +3747,185 @@
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4411 config/rs6000/rs6000.c:4258
+#: config/powerpcspe/powerpcspe.c:4411 config/rs6000/rs6000.c:4278
 msgid "-maltivec=le not allowed for big-endian targets"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4423 config/rs6000/rs6000.c:4273
+#: config/powerpcspe/powerpcspe.c:4423 config/rs6000/rs6000.c:4293
 msgid "-mvsx requires hardware floating point"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4431 config/rs6000/rs6000.c:4281
+#: config/powerpcspe/powerpcspe.c:4431 config/rs6000/rs6000.c:4301
 msgid "-mvsx and -mpaired are incompatible"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4433 config/rs6000/rs6000.c:4283
+#: config/powerpcspe/powerpcspe.c:4433 config/rs6000/rs6000.c:4303
 msgid "-mvsx needs indexed addressing"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4438 config/rs6000/rs6000.c:4288
+#: config/powerpcspe/powerpcspe.c:4438 config/rs6000/rs6000.c:4308
 msgid "-mvsx and -mno-altivec are incompatible"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4440 config/rs6000/rs6000.c:4290
+#: config/powerpcspe/powerpcspe.c:4440 config/rs6000/rs6000.c:4310
 msgid "-mno-altivec disables vsx"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4648 config/rs6000/rs6000.c:4416
+#: config/powerpcspe/powerpcspe.c:4648 config/rs6000/rs6000.c:4436
 msgid "-mquad-memory requires 64-bit mode"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4651 config/rs6000/rs6000.c:4419
+#: config/powerpcspe/powerpcspe.c:4651 config/rs6000/rs6000.c:4439
 msgid "-mquad-memory-atomic requires 64-bit mode"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4663 config/rs6000/rs6000.c:4431
+#: config/powerpcspe/powerpcspe.c:4663 config/rs6000/rs6000.c:4451
 msgid "-mquad-memory is not available in little endian mode"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4735 config/rs6000/rs6000.c:4512
+#: config/powerpcspe/powerpcspe.c:4735 config/rs6000/rs6000.c:4532
 msgid "-mtoc-fusion requires 64-bit"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4742 config/rs6000/rs6000.c:4519
+#: config/powerpcspe/powerpcspe.c:4742 config/rs6000/rs6000.c:4539
 msgid "-mtoc-fusion requires medium/large code model"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10915
+#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10947
 msgid "bad move"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21087
+#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21164
 msgid "Bad 128-bit move"
 msgstr "Помилкове 128-бітове пересування"
 
-#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21278
+#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21355
 #, c-format
 msgid "invalid %%e value"
 msgstr "некоректне значення %%e"
 
-#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21299
+#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21376
 #, c-format
 msgid "invalid %%f value"
 msgstr "некоректне значення %%f"
 
-#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21308
+#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21385
 #, c-format
 msgid "invalid %%F value"
 msgstr "некоректне значення %%F"
 
-#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21317
+#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21394
 #, c-format
 msgid "invalid %%G value"
 msgstr "некоректне значення %%G"
 
-#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21352
+#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21429
 #, c-format
 msgid "invalid %%j code"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21362
+#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21439
 #, c-format
 msgid "invalid %%J code"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21372
+#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21449
 #, c-format
 msgid "invalid %%k value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21387
+#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21464
 #: config/xtensa/xtensa.c:2415
 #, c-format
 msgid "invalid %%K value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21434
+#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21511
 #, c-format
 msgid "invalid %%O value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21481
+#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21558
 #, c-format
 msgid "invalid %%q value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21534
+#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21611
 #, c-format
 msgid "invalid %%T value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21546
+#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21623
 #, c-format
 msgid "invalid %%u value"
 msgstr "некоректне значення %%u"
 
-#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21560
+#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21637
 #: config/xtensa/xtensa.c:2384
 #, c-format
 msgid "invalid %%v value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21627
+#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21704
 #: config/xtensa/xtensa.c:2436
 #, c-format
 msgid "invalid %%x value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21747
+#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21824
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22282
+#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22359
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22288
+#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22365
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22294
+#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22371
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36572
+#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36628
 msgid "AltiVec argument passed to unprototyped function"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38739
+#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38795
 msgid "Could not generate addis value for fusion"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38809
+#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38865
 msgid "Unable to generate load/store offset for fusion"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38908
+#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38964
 msgid "Bad GPR fusion"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39126
+#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39182
 msgid "emit_fusion_p9_load, bad reg #1"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39172
+#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39228
 msgid "emit_fusion_p9_load, bad reg #2"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39175
+#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39231
 msgid "emit_fusion_p9_load not MEM"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39213
+#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39269
 msgid "emit_fusion_p9_store, bad reg #1"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39259
+#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39315
 msgid "emit_fusion_p9_store, bad reg #2"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39262
+#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39318
 msgid "emit_fusion_p9_store not MEM"
 msgstr ""
 
@@ -4302,14 +4302,14 @@
 #: c/gimple-parser.c:188 c/gimple-parser.c:197 c/gimple-parser.c:226
 #: c/gimple-parser.c:1375 c/gimple-parser.c:1404 c/gimple-parser.c:1484
 #: c/gimple-parser.c:1511 c/c-parser.c:3204 c/c-parser.c:9967
-#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27841
-#: cp/parser.c:28430
+#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27838
+#: cp/parser.c:28427
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "мало бути %<;%>"
 
 #: c/c-parser.c:2431 c/c-parser.c:7573 c/c-parser.c:8015 c/c-parser.c:8058
-#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27839 cp/parser.c:28448
+#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27836 cp/parser.c:28445
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "мало бути %<,%>"
@@ -4324,7 +4324,7 @@
 #: c/gimple-parser.c:821 c/gimple-parser.c:837 c/gimple-parser.c:853
 #: c/gimple-parser.c:880 c/gimple-parser.c:915 c/gimple-parser.c:1038
 #: c/gimple-parser.c:1209 c/gimple-parser.c:1220 c/gimple-parser.c:1342
-#: c/gimple-parser.c:1441 cp/parser.c:28478
+#: c/gimple-parser.c:1441 cp/parser.c:28475
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "мало бути %<)%>"
@@ -4332,7 +4332,7 @@
 #: c/c-parser.c:3824 c/c-parser.c:4733 c/c-parser.c:4769 c/c-parser.c:6441
 #: c/c-parser.c:8125 c/c-parser.c:8983 c/c-parser.c:9127 c/c-parser.c:11588
 #: c/c-parser.c:18220 c/c-parser.c:18222 c/gimple-parser.c:1015
-#: cp/parser.c:28442
+#: cp/parser.c:28439
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "мало бути %<]%>"
@@ -4346,7 +4346,7 @@
 #: c/c-parser.c:17792 c/gimple-parser.c:363 c/gimple-parser.c:811
 #: c/gimple-parser.c:873 c/gimple-parser.c:911 c/gimple-parser.c:1198
 #: c/gimple-parser.c:1339 c/gimple-parser.c:1438 c/c-parser.c:11911
-#: cp/parser.c:28433
+#: cp/parser.c:28430
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "мало бути %<(%>"
@@ -4353,7 +4353,7 @@
 
 #: c/c-parser.c:4903 c/c-parser.c:10310 c/c-parser.c:16212 c/c-parser.c:18449
 #: c/gimple-parser.c:141 c/gimple-parser.c:1444 c/c-parser.c:3018
-#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18155 cp/parser.c:28439
+#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18152 cp/parser.c:28436
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "мало бути %<{%>"
@@ -4363,13 +4363,13 @@
 #: c/c-parser.c:12351 c/c-parser.c:12493 c/c-parser.c:12864 c/c-parser.c:12957
 #: c/c-parser.c:13566 c/c-parser.c:17636 c/c-parser.c:17695
 #: c/gimple-parser.c:431 c/gimple-parser.c:1492 c/gimple-parser.c:1519
-#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28472 cp/parser.c:29597
-#: cp/parser.c:32279
+#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28469 cp/parser.c:29594
+#: cp/parser.c:32276
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "мало бути %<:%>"
 
-#: c/c-parser.c:5974 cp/parser.c:28365
+#: c/c-parser.c:5974 cp/parser.c:28362
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "мало бути %<while%>"
@@ -4378,18 +4378,18 @@
 msgid "expected %<.%>"
 msgstr "мало бути %<.%>"
 
-#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30172
-#: cp/parser.c:30246
+#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30169
+#: cp/parser.c:30243
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "мало бути %<@end%>"
 
-#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28457
+#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28454
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "мало бути %<>%>"
 
-#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28481
+#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28478
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "мало бути %<,%> або %<)%>"
@@ -4397,32 +4397,32 @@
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15190 c/c-parser.c:15234 c/c-parser.c:15466 c/c-parser.c:15701
 #: c/c-parser.c:17833 c/gimple-parser.c:286 c/c-parser.c:4792
-#: cp/parser.c:28460
+#: cp/parser.c:28457
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "мало бути %<=%>"
 
-#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28436
-#: cp/parser.c:30389
+#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28433
+#: cp/parser.c:30386
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "мало бути %<}%>"
 
-#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35674
+#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35671
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "мало бути %<#pragma omp section%> або %<}%>"
 
-#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28445 cp/parser.c:31535
+#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28442 cp/parser.c:31532
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "мало бути %<[%>"
 
-#: c/c-typeck.c:7847
+#: c/c-typeck.c:7852
 msgid "(anonymous)"
 msgstr "(анонімний)"
 
-#: c/gimple-parser.c:795 cp/parser.c:15791 cp/parser.c:28454
+#: c/gimple-parser.c:795 cp/parser.c:15788 cp/parser.c:28451
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "мало бути %<<%>"
@@ -4676,11 +4676,11 @@
 msgid "%r%s:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr ""
 
-#: cp/pt.c:1949 cp/semantics.c:5268
+#: cp/pt.c:1949 cp/semantics.c:5271
 msgid "candidates are:"
 msgstr ""
 
-#: cp/pt.c:1951 cp/pt.c:22975
+#: cp/pt.c:1951 cp/pt.c:23053
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] ""
@@ -4727,27 +4727,27 @@
 msgid "source type is not polymorphic"
 msgstr ""
 
-#: cp/typeck.c:6083 c/c-typeck.c:4261
+#: cp/typeck.c:6083 c/c-typeck.c:4266
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr ""
 
-#: cp/typeck.c:6084 c/c-typeck.c:4248
+#: cp/typeck.c:6084 c/c-typeck.c:4253
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr ""
 
-#: cp/typeck.c:6111 c/c-typeck.c:4302
+#: cp/typeck.c:6111 c/c-typeck.c:4307
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr ""
 
-#: cp/typeck.c:6128 c/c-typeck.c:4310
+#: cp/typeck.c:6128 c/c-typeck.c:4315
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr ""
 
-#: cp/typeck.c:6140 c/c-typeck.c:4322
+#: cp/typeck.c:6140 c/c-typeck.c:4327
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr ""
@@ -4987,67 +4987,67 @@
 msgid "Expected attribute bit name"
 msgstr ""
 
-#: fortran/module.c:3223
+#: fortran/module.c:3225
 msgid "Expected integer string"
 msgstr ""
 
-#: fortran/module.c:3227
+#: fortran/module.c:3229
 msgid "Error converting integer"
 msgstr ""
 
-#: fortran/module.c:3249
+#: fortran/module.c:3251
 msgid "Expected real string"
 msgstr ""
 
-#: fortran/module.c:3474
+#: fortran/module.c:3476
 msgid "Expected expression type"
 msgstr ""
 
-#: fortran/module.c:3554
+#: fortran/module.c:3556
 msgid "Bad operator"
 msgstr ""
 
-#: fortran/module.c:3671
+#: fortran/module.c:3673
 msgid "Bad type in constant expression"
 msgstr ""
 
-#: fortran/module.c:7038
+#: fortran/module.c:7040
 msgid "Unexpected end of module"
 msgstr ""
 
-#: fortran/parse.c:1757
+#: fortran/parse.c:1761
 msgid "arithmetic IF"
 msgstr ""
 
-#: fortran/parse.c:1766
+#: fortran/parse.c:1770
 msgid "attribute declaration"
 msgstr ""
 
-#: fortran/parse.c:1802
+#: fortran/parse.c:1806
 msgid "data declaration"
 msgstr ""
 
-#: fortran/parse.c:1820
+#: fortran/parse.c:1824
 msgid "derived type declaration"
 msgstr ""
 
-#: fortran/parse.c:1947
+#: fortran/parse.c:1951
 msgid "block IF"
 msgstr ""
 
-#: fortran/parse.c:1956
+#: fortran/parse.c:1960
 msgid "implied END DO"
 msgstr ""
 
-#: fortran/parse.c:2050 fortran/resolve.c:11199
+#: fortran/parse.c:2054 fortran/resolve.c:11219
 msgid "assignment"
 msgstr "присвоювання"
 
-#: fortran/parse.c:2053 fortran/resolve.c:11250 fortran/resolve.c:11253
+#: fortran/parse.c:2057 fortran/resolve.c:11270 fortran/resolve.c:11273
 msgid "pointer assignment"
 msgstr ""
 
-#: fortran/parse.c:2071
+#: fortran/parse.c:2075
 msgid "simple IF"
 msgstr ""
 
@@ -5139,106 +5139,111 @@
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:3878
+#: fortran/resolve.c:3879
 #, c-format
+msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
+msgstr ""
+
+#: fortran/resolve.c:3884
+#, c-format
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3893
+#: fortran/resolve.c:3899
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3926
+#: fortran/resolve.c:3932
 #, c-format
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3949
+#: fortran/resolve.c:3955
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:3963
+#: fortran/resolve.c:3969
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr ""
 
-#: fortran/resolve.c:4015
+#: fortran/resolve.c:4021
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr ""
 
-#: fortran/resolve.c:4021
+#: fortran/resolve.c:4027
 #, c-format
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4034
+#: fortran/resolve.c:4040
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L; did you mean '%s'?"
 msgstr "Невідомий оператор %%<%s%%> у %%L; хотіли написати «%s»?"
 
-#: fortran/resolve.c:4037
+#: fortran/resolve.c:4043
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr "Невідомий оператор %%<%s%%> у %%L"
 
-#: fortran/resolve.c:4040
+#: fortran/resolve.c:4046
 #, c-format
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:4044
+#: fortran/resolve.c:4050
 #, c-format
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4132
+#: fortran/resolve.c:4138
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr ""
 
-#: fortran/resolve.c:6849
+#: fortran/resolve.c:6855
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.c:6853
+#: fortran/resolve.c:6859
 msgid "iterator variable"
 msgstr ""
 
-#: fortran/resolve.c:6857
+#: fortran/resolve.c:6863
 msgid "Start expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:6861
+#: fortran/resolve.c:6867
 msgid "End expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:6865
+#: fortran/resolve.c:6871
 msgid "Step expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:7150 fortran/resolve.c:7153
+#: fortran/resolve.c:7156 fortran/resolve.c:7159
 msgid "DEALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.c:7525 fortran/resolve.c:7528
+#: fortran/resolve.c:7531 fortran/resolve.c:7534
 msgid "ALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.c:7720 fortran/resolve.c:9417
+#: fortran/resolve.c:7726 fortran/resolve.c:9428
 msgid "STAT variable"
 msgstr ""
 
-#: fortran/resolve.c:7764 fortran/resolve.c:9429
+#: fortran/resolve.c:7770 fortran/resolve.c:9440
 msgid "ERRMSG variable"
 msgstr ""
 
-#: fortran/resolve.c:9219
+#: fortran/resolve.c:9230
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.c:9441
+#: fortran/resolve.c:9452
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
@@ -5271,7 +5276,7 @@
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:10154
+#: fortran/trans-expr.c:10157
 msgid "Assignment of scalar to unallocated array"
 msgstr ""
 
@@ -5280,12 +5285,12 @@
 msgid "Unequal character lengths (%ld/%ld) in %s"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:8088
+#: fortran/trans-intrinsic.c:8090
 #, c-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative (its value is %ld)"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:8120
+#: fortran/trans-intrinsic.c:8122
 msgid "Argument NCOPIES of REPEAT intrinsic is too large"
 msgstr ""
 
@@ -5306,15 +5311,15 @@
 msgid "Invalid image number %d in SYNC IMAGES"
 msgstr ""
 
-#: fortran/trans-stmt.c:2180
+#: fortran/trans-stmt.c:2177
 msgid "Loop iterates infinitely"
 msgstr ""
 
-#: fortran/trans-stmt.c:2200 fortran/trans-stmt.c:2456
+#: fortran/trans-stmt.c:2197 fortran/trans-stmt.c:2453
 msgid "Loop variable has been modified"
 msgstr ""
 
-#: fortran/trans-stmt.c:2309
+#: fortran/trans-stmt.c:2306
 msgid "DO step value is zero"
 msgstr ""
 
@@ -5887,10 +5892,10 @@
 msgid "Allow dollar signs in entity names."
 msgstr ""
 
-#: fortran/lang.opt:485 config/alpha/alpha.opt:31 common.opt:783
-#: common.opt:985 common.opt:989 common.opt:993 common.opt:997 common.opt:1532
-#: common.opt:1588 common.opt:1712 common.opt:1716 common.opt:1946
-#: common.opt:2116 common.opt:2792
+#: fortran/lang.opt:485 config/alpha/alpha.opt:31 common.opt:649
+#: common.opt:783 common.opt:989 common.opt:993 common.opt:997 common.opt:1001
+#: common.opt:1536 common.opt:1592 common.opt:1716 common.opt:1720
+#: common.opt:1950 common.opt:2120 common.opt:2796
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr ""
 
@@ -6109,12 +6114,12 @@
 msgstr ""
 
 #: fortran/lang.opt:751 c-family/c.opt:1356 c-family/c.opt:1384
-#: c-family/c.opt:1634 config/pa/pa.opt:42 config/pa/pa.opt:70 common.opt:1154
-#: common.opt:1333 common.opt:1408 common.opt:1676 common.opt:1799
-#: common.opt:2169 common.opt:2205 common.opt:2298 common.opt:2302
-#: common.opt:2407 common.opt:2498 common.opt:2506 common.opt:2514
-#: common.opt:2522 common.opt:2623 common.opt:2675 common.opt:2755
-#: common.opt:2893 common.opt:2897 common.opt:2901 common.opt:2905
+#: c-family/c.opt:1634 config/pa/pa.opt:42 config/pa/pa.opt:70 common.opt:1158
+#: common.opt:1337 common.opt:1412 common.opt:1680 common.opt:1803
+#: common.opt:2173 common.opt:2209 common.opt:2302 common.opt:2306
+#: common.opt:2411 common.opt:2502 common.opt:2510 common.opt:2518
+#: common.opt:2526 common.opt:2627 common.opt:2679 common.opt:2759
+#: common.opt:2897 common.opt:2901 common.opt:2905 common.opt:2909
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr ""
 
@@ -6164,7 +6169,7 @@
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:220 c-family/c.opt:224
 #: c-family/c.opt:236 c-family/c.opt:1855 c-family/c.opt:1863 brig/lang.opt:39
-#: config/darwin.opt:56 common.opt:338 common.opt:341 common.opt:3046
+#: config/darwin.opt:56 common.opt:338 common.opt:341 common.opt:3050
 #, c-format
 msgid "missing filename after %qs"
 msgstr ""
@@ -6740,7 +6745,7 @@
 #: c-family/c.opt:1525 c-family/c.opt:1528 c-family/c.opt:1569
 #: c-family/c.opt:1704 c-family/c.opt:1731 c-family/c.opt:1771
 #: c-family/c.opt:1802 c-family/c.opt:1806 c-family/c.opt:1822
-#: config/ia64/ia64.opt:167 config/ia64/ia64.opt:170 c-family/c-opts.c:434
+#: config/ia64/ia64.opt:167 config/ia64/ia64.opt:170 c-family/c-opts.c:432
 #, gcc-internal-format
 msgid "switch %qs is no longer supported"
 msgstr ""
@@ -13783,10 +13788,6 @@
 msgid "Warn if dereferencing a NULL pointer may lead to erroneous or undefined behavior."
 msgstr ""
 
-#: common.opt:649
-msgid "Warn if the loop cannot be optimized due to nontrivial assumptions."
-msgstr ""
-
 #: common.opt:656
 msgid "Warn about some C++ One Definition Rule violations during link time optimization."
 msgstr ""
@@ -13955,1676 +13956,1676 @@
 msgid "-dumpdir <dir>\tSet the directory name to be used for dumps."
 msgstr ""
 
-#: common.opt:946
+#: common.opt:950
 msgid "The version of the C++ ABI in use."
 msgstr ""
 
-#: common.opt:950
+#: common.opt:954
 msgid "Aggressively optimize loops using language constraints."
 msgstr ""
 
-#: common.opt:954
+#: common.opt:958
 msgid "Align the start of functions."
 msgstr ""
 
-#: common.opt:964
+#: common.opt:968
 msgid "Align labels which are only reached by jumping."
 msgstr ""
 
-#: common.opt:971
+#: common.opt:975
 msgid "Align all labels."
 msgstr ""
 
-#: common.opt:978
+#: common.opt:982
 msgid "Align the start of loops."
 msgstr ""
 
-#: common.opt:1001
+#: common.opt:1005
 msgid "Select what to sanitize."
 msgstr ""
 
-#: common.opt:1005
+#: common.opt:1009
 msgid "Select type of coverage sanitization."
 msgstr ""
 
-#: common.opt:1009
+#: common.opt:1013
 msgid "-fasan-shadow-offset=<number>\tUse custom shadow memory offset."
 msgstr ""
 
-#: common.opt:1013
+#: common.opt:1017
 msgid "-fsanitize-sections=<sec1,sec2,...>\tSanitize global variables in user-defined sections."
 msgstr ""
 
-#: common.opt:1018
+#: common.opt:1022
 msgid "After diagnosing undefined behavior attempt to continue execution."
 msgstr ""
 
-#: common.opt:1022
+#: common.opt:1026
 msgid "This switch is deprecated; use -fsanitize-recover= instead."
 msgstr ""
 
-#: common.opt:1029
+#: common.opt:1033
 msgid "Use trap instead of a library function for undefined behavior sanitization."
 msgstr ""
 
-#: common.opt:1033
+#: common.opt:1037
 msgid "Generate unwind tables that are exact at each instruction boundary."
 msgstr ""
 
-#: common.opt:1037
+#: common.opt:1041
 msgid "Generate auto-inc/dec instructions."
 msgstr ""
 
-#: common.opt:1041
+#: common.opt:1045
 msgid "Use sample profile information for call graph node weights. The default profile file is fbdata.afdo in 'pwd'."
 msgstr ""
 
-#: common.opt:1046
+#: common.opt:1050
 msgid "Use sample profile information for call graph node weights. The profile file is specified in the argument."
 msgstr ""
 
-#: common.opt:1055
+#: common.opt:1059
 msgid "Generate code to check bounds before indexing arrays."
 msgstr ""
 
-#: common.opt:1059
+#: common.opt:1063
 msgid "Replace add, compare, branch with branch on count register."
 msgstr ""
 
-#: common.opt:1063
+#: common.opt:1067
 msgid "Use profiling information for branch probabilities."
 msgstr ""
 
-#: common.opt:1067
+#: common.opt:1071
 msgid "Perform branch target load optimization before prologue / epilogue threading."
 msgstr ""
 
-#: common.opt:1071
+#: common.opt:1075
 msgid "Perform branch target load optimization after prologue / epilogue threading."
 msgstr ""
 
-#: common.opt:1075
+#: common.opt:1079
 msgid "Restrict target load migration not to re-use registers in any basic block."
 msgstr ""
 
-#: common.opt:1079
+#: common.opt:1083
 msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions."
 msgstr ""
 
-#: common.opt:1083
+#: common.opt:1087
 msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls."
 msgstr ""
 
-#: common.opt:1090
+#: common.opt:1094
 msgid "Save registers around function calls."
 msgstr ""
 
-#: common.opt:1094
+#: common.opt:1098
 msgid "This switch is deprecated; do not use."
 msgstr ""
 
-#: common.opt:1098
+#: common.opt:1102
 msgid "Check the return value of new in C++."
 msgstr "Перевіряти повернуте значення new у C++."
 
-#: common.opt:1102 common.opt:1106
+#: common.opt:1106 common.opt:1110
 msgid "Perform internal consistency checkings."
 msgstr "Виконувати внутрішні перевірки сумісності."
 
-#: common.opt:1110
+#: common.opt:1114
 msgid "Enable code hoisting."
 msgstr "Увімкнути підняття коду."
 
-#: common.opt:1114
+#: common.opt:1118
 msgid "Looks for opportunities to reduce stack adjustments and stack references."
 msgstr ""
 
-#: common.opt:1118
+#: common.opt:1122
 msgid "Do not put uninitialized globals in the common section."
 msgstr ""
 
-#: common.opt:1126
+#: common.opt:1130
 msgid "-fcompare-debug[=<opts>]\tCompile with and without e.g. -gtoggle, and compare the final-insns dump."
 msgstr ""
 
-#: common.opt:1130
+#: common.opt:1134
 msgid "Run only the second compilation of -fcompare-debug."
 msgstr ""
 
-#: common.opt:1134
+#: common.opt:1138
 msgid "Perform comparison elimination after register allocation has finished."
 msgstr ""
 
-#: common.opt:1138
+#: common.opt:1142
 msgid "Do not perform optimizations increasing noticeably stack usage."
 msgstr ""
 
-#: common.opt:1142
+#: common.opt:1146
 msgid "Perform a register copy-propagation optimization pass."
 msgstr ""
 
-#: common.opt:1146
+#: common.opt:1150
 msgid "Perform cross-jumping optimization."
 msgstr ""
 
-#: common.opt:1150
+#: common.opt:1154
 msgid "When running CSE, follow jumps to their targets."
 msgstr ""
 
-#: common.opt:1158
+#: common.opt:1162
 msgid "Omit range reduction step when performing complex division."
 msgstr ""
 
-#: common.opt:1162
+#: common.opt:1166
 msgid "Complex multiplication and division follow Fortran rules."
 msgstr ""
 
-#: common.opt:1166
+#: common.opt:1170
 msgid "Place data items into their own section."
 msgstr ""
 
-#: common.opt:1170
+#: common.opt:1174
 msgid "List all available debugging counters with their limits and counts."
 msgstr ""
 
-#: common.opt:1174
+#: common.opt:1178
 msgid "-fdbg-cnt=<counter>:<limit>[,<counter>:<limit>,...]\tSet the debug counter limit."
 msgstr ""
 
-#: common.opt:1178
+#: common.opt:1182
 msgid "-fdebug-prefix-map=<old>=<new> Map one directory name to another in debug information."
 msgstr ""
 
-#: common.opt:1182
+#: common.opt:1186
 msgid "-ffile-prefix-map=<old>=<new> Map one directory name to another in compilation result."
 msgstr ""
 
-#: common.opt:1186
+#: common.opt:1190
 msgid "Output .debug_types section when using DWARF v4 debuginfo."
 msgstr ""
 
-#: common.opt:1192
+#: common.opt:1196
 msgid "Defer popping functions args from stack until later."
 msgstr ""
 
-#: common.opt:1196
+#: common.opt:1200
 msgid "Attempt to fill delay slots of branch instructions."
 msgstr ""
 
-#: common.opt:1200
+#: common.opt:1204
 msgid "Delete dead instructions that may throw exceptions."
 msgstr ""
 
-#: common.opt:1204
+#: common.opt:1208
 msgid "Delete useless null pointer checks."
 msgstr ""
 
-#: common.opt:1208
+#: common.opt:1212
 msgid "Stream extra data to support more aggressive devirtualization in LTO local transformation mode."
 msgstr ""
 
-#: common.opt:1212
+#: common.opt:1216
 msgid "Perform speculative devirtualization."
 msgstr ""
 
-#: common.opt:1216
+#: common.opt:1220
 msgid "Try to convert virtual calls to direct ones."
 msgstr ""
 
-#: common.opt:1220
+#: common.opt:1224
 msgid "-fdiagnostics-show-location=[once|every-line]\tHow often to emit source location at the beginning of line-wrapped diagnostics."
 msgstr ""
 
-#: common.opt:1237
+#: common.opt:1241
 msgid "Show the source line with a caret indicating the column."
 msgstr ""
 
-#: common.opt:1245
+#: common.opt:1249
 msgid "-fdiagnostics-color=[never|always|auto]\tColorize diagnostics."
 msgstr ""
 
-#: common.opt:1265
+#: common.opt:1269
 msgid "Print fix-it hints in machine-readable form."
 msgstr ""
 
-#: common.opt:1269
+#: common.opt:1273
 msgid "Print fix-it hints to stderr in unified diff format."
 msgstr ""
 
-#: common.opt:1273
+#: common.opt:1277
 msgid "Amend appropriate diagnostic messages with the command line option that controls them."
 msgstr ""
 
-#: common.opt:1277
+#: common.opt:1281
 msgid "-fdisable-[tree|rtl|ipa]-<pass>=range1+range2 disables an optimization pass."
 msgstr ""
 
-#: common.opt:1281
+#: common.opt:1285
 msgid "-fenable-[tree|rtl|ipa]-<pass>=range1+range2 enables an optimization pass."
 msgstr ""
 
-#: common.opt:1285
+#: common.opt:1289
 msgid "-fdump-<type>\tDump various compiler internals to a file."
 msgstr ""
 
-#: common.opt:1292
+#: common.opt:1296
 msgid "-fdump-final-insns=filename\tDump to filename the insns at the end of translation."
 msgstr ""
 
-#: common.opt:1296
+#: common.opt:1300
 msgid "-fdump-go-spec=filename\tWrite all declarations to file as Go code."
 msgstr ""
 
-#: common.opt:1300
+#: common.opt:1304
 msgid "Suppress output of addresses in debugging dumps."
 msgstr ""
 
-#: common.opt:1304
+#: common.opt:1308
 msgid "Collect and dump debug information into temporary file if ICE in C/C++ compiler occurred."
 msgstr ""
 
-#: common.opt:1309
+#: common.opt:1313
 msgid "Dump detailed information on GCC's internal representation of source code locations."
 msgstr ""
 
-#: common.opt:1313
+#: common.opt:1317
 msgid "Dump optimization passes."
 msgstr ""
 
-#: common.opt:1317
+#: common.opt:1321
 msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps."
 msgstr ""
 
-#: common.opt:1321
+#: common.opt:1325
 msgid "Suppress output of previous and next insn numbers in debugging dumps."
 msgstr ""
 
-#: common.opt:1325
+#: common.opt:1329
 msgid "Enable CFI tables via GAS assembler directives."
 msgstr ""
 
-#: common.opt:1329
+#: common.opt:1333
 msgid "Perform early inlining."
 msgstr ""
 
-#: common.opt:1337
+#: common.opt:1341
 msgid "Perform interprocedural reduction of aggregates."
 msgstr ""
 
-#: common.opt:1341
+#: common.opt:1345
 msgid "Perform unused symbol elimination in debug info."
 msgstr ""
 
-#: common.opt:1345
+#: common.opt:1349
 msgid "Perform unused type elimination in debug info."
 msgstr ""
 
-#: common.opt:1349
+#: common.opt:1353
 msgid "Do not suppress C++ class debug information."
 msgstr ""
 
-#: common.opt:1353
+#: common.opt:1357
 msgid "Enable exception handling."
 msgstr ""
 
-#: common.opt:1357
+#: common.opt:1361
 msgid "Perform a number of minor, expensive optimizations."
 msgstr ""
 
-#: common.opt:1361
+#: common.opt:1365
 msgid "-fexcess-precision=[fast|standard]\tSpecify handling of excess floating-point precision."
 msgstr ""
 
-#: common.opt:1364
+#: common.opt:1368
 #, c-format
 msgid "unknown excess precision style %qs"
 msgstr ""
 
-#: common.opt:1376
+#: common.opt:1380
 msgid "-fpermitted-flt-eval-methods=[c11|ts-18661]\tSpecify which values of FLT_EVAL_METHOD are permitted."
 msgstr ""
 
-#: common.opt:1379
+#: common.opt:1383
 #, c-format
 msgid "unknown specification for the set of FLT_EVAL_METHOD values to permit %qs"
 msgstr ""
 
-#: common.opt:1392
+#: common.opt:1396
 msgid "Output lto objects containing both the intermediate language and binary output."
 msgstr ""
 
-#: common.opt:1396
+#: common.opt:1400
 msgid "Assume no NaNs or infinities are generated."
 msgstr ""
 
-#: common.opt:1400
+#: common.opt:1404
 msgid "-ffixed-<register>\tMark <register> as being unavailable to the compiler."
 msgstr ""
 
-#: common.opt:1404
+#: common.opt:1408
 msgid "Don't allocate floats and doubles in extended-precision registers."
 msgstr ""
 
-#: common.opt:1412
+#: common.opt:1416
 msgid "Perform a forward propagation pass on RTL."
 msgstr ""
 
-#: common.opt:1416
+#: common.opt:1420
 msgid "-ffp-contract=[off|on|fast]\tPerform floating-point expression contraction."
 msgstr ""
 
-#: common.opt:1419
+#: common.opt:1423
 #, c-format
 msgid "unknown floating point contraction style %qs"
 msgstr ""
 
-#: common.opt:1433
+#: common.opt:1437
 msgid "Allow built-in functions ceil, floor, round, trunc to raise \"inexact\" exceptions."
 msgstr ""
 
-#: common.opt:1440
+#: common.opt:1444
 msgid "Allow function addresses to be held in registers."
 msgstr ""
 
-#: common.opt:1444
+#: common.opt:1448
 msgid "Place each function into its own section."
 msgstr ""
 
-#: common.opt:1448
+#: common.opt:1452
 msgid "Perform global common subexpression elimination."
 msgstr ""
 
-#: common.opt:1452
+#: common.opt:1456
 msgid "Perform enhanced load motion during global common subexpression elimination."
 msgstr ""
 
-#: common.opt:1456
+#: common.opt:1460
 msgid "Perform store motion after global common subexpression elimination."
 msgstr ""
 
-#: common.opt:1460
+#: common.opt:1464
 msgid "Perform redundant load after store elimination in global common subexpression elimination."
 msgstr ""
 
-#: common.opt:1465
+#: common.opt:1469
 msgid "Perform global common subexpression elimination after register allocation has finished."
 msgstr ""
 
-#: common.opt:1482
+#: common.opt:1486
 msgid "-fgnat-encodings=[all|gdb|minimal]\tSelect the balance between GNAT encodings and standard DWARF emitted in the debug information"
 msgstr ""
 
-#: common.opt:1487
+#: common.opt:1491
 msgid "Enable in and out of Graphite representation."
 msgstr ""
 
-#: common.opt:1491
+#: common.opt:1495
 msgid "Enable Graphite Identity transformation."
 msgstr ""
 
-#: common.opt:1495
+#: common.opt:1499
 msgid "Enable hoisting adjacent loads to encourage generating conditional move instructions."
 msgstr ""
 
-#: common.opt:1504
+#: common.opt:1508
 msgid "Mark all loops as parallel."
 msgstr ""
 
-#: common.opt:1508 common.opt:1516 common.opt:2587
+#: common.opt:1512 common.opt:1520 common.opt:2591
 msgid "Enable loop nest transforms.  Same as -floop-nest-optimize."
 msgstr ""
 
-#: common.opt:1512
+#: common.opt:1516
 msgid "Enable loop interchange on trees."
 msgstr ""
 
-#: common.opt:1520
+#: common.opt:1524
 msgid "Perform unroll-and-jam on loops."
 msgstr ""
 
-#: common.opt:1524
+#: common.opt:1528
 msgid "Enable support for GNU transactional memory."
 msgstr ""
 
-#: common.opt:1528
+#: common.opt:1532
 msgid "Use STB_GNU_UNIQUE if supported by the assembler."
 msgstr ""
 
-#: common.opt:1536
+#: common.opt:1540
 msgid "Enable the loop nest optimizer."
 msgstr ""
 
-#: common.opt:1540
+#: common.opt:1544
 msgid "Force bitfield accesses to match their type width."
 msgstr ""
 
-#: common.opt:1544
+#: common.opt:1548
 msgid "Merge adjacent stores."
 msgstr ""
 
-#: common.opt:1548
+#: common.opt:1552
 msgid "Enable guessing of branch probabilities."
 msgstr ""
 
-#: common.opt:1556
+#: common.opt:1560
 msgid "Process #ident directives."
 msgstr ""
 
-#: common.opt:1560
+#: common.opt:1564
 msgid "Perform conversion of conditional jumps to branchless equivalents."
 msgstr ""
 
-#: common.opt:1564
+#: common.opt:1568
 msgid "Perform conversion of conditional jumps to conditional execution."
 msgstr ""
 
-#: common.opt:1568
+#: common.opt:1572
 msgid "-fstack-reuse=[all|named_vars|none]\tSet stack reuse level for local variables."
 msgstr ""
 
-#: common.opt:1571
+#: common.opt:1575
 #, c-format
 msgid "unknown Stack Reuse Level %qs"
 msgstr ""
 
-#: common.opt:1584
+#: common.opt:1588
 msgid "Convert conditional jumps in innermost loops to branchless equivalents."
 msgstr ""
 
-#: common.opt:1596
+#: common.opt:1600
 msgid "Do not generate .size directives."
 msgstr ""
 
-#: common.opt:1600
+#: common.opt:1604
 msgid "Perform indirect inlining."
 msgstr ""
 
-#: common.opt:1606
+#: common.opt:1610
 msgid "Enable inlining of function declared \"inline\", disabling disables all inlining."
 msgstr ""
 
-#: common.opt:1610
+#: common.opt:1614
 msgid "Integrate functions into their callers when code size is known not to grow."
 msgstr ""
 
-#: common.opt:1614
+#: common.opt:1618
 msgid "Integrate functions not declared \"inline\" into their callers when profitable."
 msgstr ""
 
-#: common.opt:1618
+#: common.opt:1622
 msgid "Integrate functions only required by their single caller."
 msgstr ""
 
-#: common.opt:1625
+#: common.opt:1629
 msgid "-finline-limit=<number>\tLimit the size of inlined functions to <number>."
 msgstr ""
 
-#: common.opt:1629
+#: common.opt:1633
 msgid "Inline __atomic operations when a lock free instruction sequence is available."
 msgstr ""
 
-#: common.opt:1636
+#: common.opt:1640
 msgid "-fcf-protection=[full|branch|return|none]\tInstrument functions with checks to verify jump/call/return control-flow transfer instructions have valid targets."
 msgstr ""
 
-#: common.opt:1640
+#: common.opt:1644
 #, c-format
 msgid "unknown Control-Flow Protection Level %qs"
 msgstr ""
 
-#: common.opt:1656
+#: common.opt:1660
 msgid "Instrument function entry and exit with profiling calls."
 msgstr ""
 
-#: common.opt:1660
+#: common.opt:1664
 msgid "-finstrument-functions-exclude-function-list=name,...  Do not instrument listed functions."
 msgstr ""
 
-#: common.opt:1664
+#: common.opt:1668
 msgid "-finstrument-functions-exclude-file-list=filename,...  Do not instrument functions listed in files."
 msgstr ""
 
-#: common.opt:1668
+#: common.opt:1672
 msgid "Perform interprocedural constant propagation."
 msgstr ""
 
-#: common.opt:1672
+#: common.opt:1676
 msgid "Perform cloning to make Interprocedural constant propagation stronger."
 msgstr ""
 
-#: common.opt:1680
+#: common.opt:1684
 msgid "Perform interprocedural bitwise constant propagation."
 msgstr ""
 
-#: common.opt:1684
+#: common.opt:1688
 msgid "Perform interprocedural profile propagation."
 msgstr ""
 
-#: common.opt:1688
+#: common.opt:1692
 msgid "Perform interprocedural points-to analysis."
 msgstr ""
 
-#: common.opt:1692
+#: common.opt:1696
 msgid "Discover pure and const functions."
 msgstr ""
 
-#: common.opt:1696
+#: common.opt:1700
 msgid "Perform Identical Code Folding for functions and read-only variables."
 msgstr ""
 
-#: common.opt:1700
+#: common.opt:1704
 msgid "Perform Identical Code Folding for functions."
 msgstr ""
 
-#: common.opt:1704
+#: common.opt:1708
 msgid "Perform Identical Code Folding for variables."
 msgstr ""
 
-#: common.opt:1708
+#: common.opt:1712
 msgid "Discover readonly and non addressable static variables."
 msgstr ""
 
-#: common.opt:1720
+#: common.opt:1724
 msgid "Perform IPA Value Range Propagation."
 msgstr ""
 
-#: common.opt:1724
+#: common.opt:1728
 msgid "-fira-algorithm=[CB|priority]\tSet the used IRA algorithm."
 msgstr ""
 
-#: common.opt:1727
+#: common.opt:1731
 #, c-format
 msgid "unknown IRA algorithm %qs"
 msgstr ""
 
-#: common.opt:1737
+#: common.opt:1741
 msgid "-fira-region=[one|all|mixed]\tSet regions for IRA."
 msgstr ""
 
-#: common.opt:1740
+#: common.opt:1744
 #, c-format
 msgid "unknown IRA region %qs"
 msgstr ""
 
-#: common.opt:1753
+#: common.opt:1757
 msgid "Use IRA based register pressure calculation in RTL hoist optimizations."
 msgstr ""
 
-#: common.opt:1758
+#: common.opt:1762
 msgid "Use IRA based register pressure calculation in RTL loop optimizations."
 msgstr ""
 
-#: common.opt:1763
+#: common.opt:1767
 msgid "Share slots for saving different hard registers."
 msgstr ""
 
-#: common.opt:1767
+#: common.opt:1771
 msgid "Share stack slots for spilled pseudo-registers."
 msgstr ""
 
-#: common.opt:1771
+#: common.opt:1775
 msgid "-fira-verbose=<number>\tControl IRA's level of diagnostic messages."
 msgstr ""
 
-#: common.opt:1775
+#: common.opt:1779
 msgid "Optimize induction variables on trees."
 msgstr ""
 
-#: common.opt:1779
+#: common.opt:1783
 msgid "Use jump tables for sufficiently large switch statements."
 msgstr ""
 
-#: common.opt:1783
+#: common.opt:1787
 msgid "Generate code for functions even if they are fully inlined."
 msgstr ""
 
-#: common.opt:1787
+#: common.opt:1791
 msgid "Generate code for static functions even if they are never called."
 msgstr ""
 
-#: common.opt:1791
+#: common.opt:1795
 msgid "Emit static const variables even if they are not used."
 msgstr ""
 
-#: common.opt:1795
+#: common.opt:1799
 msgid "Give external symbols a leading underscore."
 msgstr ""
 
-#: common.opt:1803
+#: common.opt:1807
 msgid "Do CFG-sensitive rematerialization in LRA."
 msgstr ""
 
-#: common.opt:1807
+#: common.opt:1811
 msgid "Enable link-time optimization."
 msgstr ""
 
-#: common.opt:1811
+#: common.opt:1815
 msgid "Link-time optimization with number of parallel jobs or jobserver."
 msgstr ""
 
-#: common.opt:1814
+#: common.opt:1818
 #, c-format
 msgid "unknown LTO partitioning model %qs"
 msgstr ""
 
-#: common.opt:1833
+#: common.opt:1837
 msgid "Specify the algorithm to partition symbols and vars at linktime."
 msgstr ""
 
-#: common.opt:1838
+#: common.opt:1842
 msgid "-flto-compression-level=<number>\tUse zlib compression level <number> for IL."
 msgstr ""
 
-#: common.opt:1842
+#: common.opt:1846
 msgid "Merge C++ types using One Definition Rule."
 msgstr ""
 
-#: common.opt:1846
+#: common.opt:1850
 msgid "Report various link-time optimization statistics."
 msgstr ""
 
-#: common.opt:1850
+#: common.opt:1854
 msgid "Report various link-time optimization statistics for WPA only."
 msgstr ""
 
-#: common.opt:1854
+#: common.opt:1858
 msgid "Set errno after built-in math functions."
 msgstr ""
 
-#: common.opt:1858
+#: common.opt:1862
 msgid "-fmax-errors=<number>\tMaximum number of errors to report."
 msgstr ""
 
-#: common.opt:1862
+#: common.opt:1866
 msgid "Report on permanent memory allocation."
 msgstr ""
 
-#: common.opt:1866
+#: common.opt:1870
 msgid "Report on permanent memory allocation in WPA only."
 msgstr ""
 
-#: common.opt:1873
+#: common.opt:1877
 msgid "Attempt to merge identical constants and constant variables."
 msgstr ""
 
-#: common.opt:1877
+#: common.opt:1881
 msgid "Attempt to merge identical constants across compilation units."
 msgstr ""
 
-#: common.opt:1881
+#: common.opt:1885
 msgid "Attempt to merge identical debug strings across compilation units."
 msgstr ""
 
-#: common.opt:1885
+#: common.opt:1889
 msgid "-fmessage-length=<number>\tLimit diagnostics to <number> characters per line.  0 suppresses line-wrapping."
 msgstr ""
 
-#: common.opt:1889
+#: common.opt:1893
 msgid "Perform SMS based modulo scheduling before the first scheduling pass."
 msgstr ""
 
-#: common.opt:1893
+#: common.opt:1897
 msgid "Perform SMS based modulo scheduling with register moves allowed."
 msgstr ""
 
-#: common.opt:1897
+#: common.opt:1901
 msgid "Move loop invariant computations out of loops."
 msgstr ""
 
-#: common.opt:1901
+#: common.opt:1905
 msgid "Use the RTL dead code elimination pass."
 msgstr ""
 
-#: common.opt:1905
+#: common.opt:1909
 msgid "Use the RTL dead store elimination pass."
 msgstr ""
 
-#: common.opt:1909
+#: common.opt:1913
 msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling."
 msgstr ""
 
-#: common.opt:1913
+#: common.opt:1917
 msgid "Support synchronous non-call exceptions."
 msgstr ""
 
-#: common.opt:1916
+#: common.opt:1920
 #, c-format
 msgid "options or targets missing after %qs"
 msgstr ""
 
-#: common.opt:1917
+#: common.opt:1921
 msgid "-foffload=<targets>=<options>  Specify offloading targets and options for them."
 msgstr ""
 
-#: common.opt:1921
+#: common.opt:1925
 msgid "-foffload-abi=[lp64|ilp32]     Set the ABI to use in an offload compiler."
 msgstr ""
 
-#: common.opt:1924
+#: common.opt:1928
 #, c-format
 msgid "unknown offload ABI %qs"
 msgstr ""
 
-#: common.opt:1934
+#: common.opt:1938
 msgid "When possible do not generate stack frames."
 msgstr ""
 
-#: common.opt:1938
+#: common.opt:1942
 msgid "Enable all optimization info dumps on stderr."
 msgstr ""
 
-#: common.opt:1942
+#: common.opt:1946
 msgid "-fopt-info[-<type>=filename]\tDump compiler optimization details."
 msgstr ""
 
-#: common.opt:1950
+#: common.opt:1954
 msgid "Optimize sibling and tail recursive calls."
 msgstr ""
 
-#: common.opt:1954
+#: common.opt:1958
 msgid "Perform partial inlining."
 msgstr ""
 
-#: common.opt:1958 common.opt:1962
+#: common.opt:1962 common.opt:1966
 msgid "Report on memory allocation before interprocedural optimization."
 msgstr ""
 
-#: common.opt:1966
+#: common.opt:1970
 msgid "Pack structure members together without holes."
 msgstr ""
 
-#: common.opt:1970
+#: common.opt:1974
 msgid "-fpack-struct=<number>\tSet initial maximum structure member alignment."
 msgstr ""
 
-#: common.opt:1974
+#: common.opt:1978
 msgid "Return small aggregates in memory, not registers."
 msgstr ""
 
-#: common.opt:1978
+#: common.opt:1982
 msgid "Perform loop peeling."
 msgstr ""
 
-#: common.opt:1982
+#: common.opt:1986
 msgid "Enable machine specific peephole optimizations."
 msgstr ""
 
-#: common.opt:1986
+#: common.opt:1990
 msgid "Enable an RTL peephole pass before sched2."
 msgstr ""
 
-#: common.opt:1990
+#: common.opt:1994
 msgid "Generate position-independent code if possible (large mode)."
 msgstr ""
 
-#: common.opt:1994
+#: common.opt:1998
 msgid "Generate position-independent code for executables if possible (large mode)."
 msgstr ""
 
-#: common.opt:1998
+#: common.opt:2002
 msgid "Generate position-independent code if possible (small mode)."
 msgstr "Створити виконуваний файл з незалежним позиціюванням, якщо можливо (малий режим)"
 
-#: common.opt:2002
+#: common.opt:2006
 msgid "Generate position-independent code for executables if possible (small mode)."
 msgstr ""
 
-#: common.opt:2006
+#: common.opt:2010
 msgid "Use PLT for PIC calls (-fno-plt: load the address from GOT at call site)."
 msgstr ""
 
-#: common.opt:2010
+#: common.opt:2014
 msgid "Specify a plugin to load."
 msgstr ""
 
-#: common.opt:2014
+#: common.opt:2018
 msgid "-fplugin-arg-<name>-<key>[=<value>]\tSpecify argument <key>=<value> for plugin <name>."
 msgstr ""
 
-#: common.opt:2018
+#: common.opt:2022
 msgid "Run predictive commoning optimization."
 msgstr ""
 
-#: common.opt:2022
+#: common.opt:2026
 msgid "Generate prefetch instructions, if available, for arrays in loops."
 msgstr ""
 
-#: common.opt:2026
+#: common.opt:2030
 msgid "Enable basic program profiling code."
 msgstr ""
 
-#: common.opt:2030
+#: common.opt:2034
 msgid "Generate absolute source path names for gcov."
 msgstr ""
 
-#: common.opt:2034
+#: common.opt:2038
 msgid "Insert arc-based program profiling code."
 msgstr ""
 
-#: common.opt:2038
+#: common.opt:2042
 msgid "Set the top-level directory for storing the profile data. The default is 'pwd'."
 msgstr ""
 
-#: common.opt:2043
+#: common.opt:2047
 msgid "Enable correction of flow inconsistent profile data input."
 msgstr ""
 
-#: common.opt:2047
+#: common.opt:2051
 msgid "-fprofile-update=[single|atomic|prefer-atomic]\tSet the profile update method."
 msgstr ""
 
-#: common.opt:2050
+#: common.opt:2054
 #, c-format
 msgid "unknown profile update method %qs"
 msgstr ""
 
-#: common.opt:2063
+#: common.opt:2067
 msgid "Enable common options for generating profile info for profile feedback directed optimizations."
 msgstr ""
 
-#: common.opt:2067
+#: common.opt:2071
 msgid "Enable common options for generating profile info for profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr ""
 
-#: common.opt:2071
+#: common.opt:2075
 msgid "Enable common options for performing profile feedback directed optimizations."
 msgstr ""
 
-#: common.opt:2075
+#: common.opt:2079
 msgid "Enable common options for performing profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr ""
 
-#: common.opt:2079
+#: common.opt:2083
 msgid "Insert code to profile values of expressions."
 msgstr ""
 
-#: common.opt:2083
+#: common.opt:2087
 msgid "Report on consistency of profile."
 msgstr ""
 
-#: common.opt:2087
+#: common.opt:2091
 msgid "Enable function reordering that improves code placement."
 msgstr ""
 
-#: common.opt:2091
+#: common.opt:2095
 msgid "Insert NOP instructions at each function entry."
 msgstr ""
 
-#: common.opt:2098
+#: common.opt:2102
 msgid "-frandom-seed=<string>\tMake compile reproducible using <string>."
 msgstr ""
 
-#: common.opt:2108
+#: common.opt:2112
 msgid "Record gcc command line switches in the object file."
 msgstr ""
 
-#: common.opt:2112
+#: common.opt:2116
 msgid "Return small aggregates in registers."
 msgstr ""
 
-#: common.opt:2120
+#: common.opt:2124
 msgid "Tell DSE that the storage for a C++ object is dead when the constructor starts and when the destructor finishes."
 msgstr ""
 
-#: common.opt:2128
+#: common.opt:2132
 msgid "Relief of register pressure through live range shrinkage."
 msgstr ""
 
-#: common.opt:2132
+#: common.opt:2136
 msgid "Perform a register renaming optimization pass."
 msgstr ""
 
-#: common.opt:2136
+#: common.opt:2140
 msgid "Perform a target dependent instruction fusion optimization pass."
 msgstr ""
 
-#: common.opt:2140
+#: common.opt:2144
 msgid "Reorder basic blocks to improve code placement."
 msgstr ""
 
-#: common.opt:2144
+#: common.opt:2148
 msgid "-freorder-blocks-algorithm=[simple|stc]\tSet the used basic block reordering algorithm."
 msgstr ""
 
-#: common.opt:2147
+#: common.opt:2151
 #, c-format
 msgid "unknown basic block reordering algorithm %qs"
 msgstr ""
 
-#: common.opt:2157
+#: common.opt:2161
 msgid "Reorder basic blocks and partition into hot and cold sections."
 msgstr ""
 
-#: common.opt:2161
+#: common.opt:2165
 msgid "Reorder functions to improve code placement."
 msgstr ""
 
-#: common.opt:2165
+#: common.opt:2169
 msgid "Add a common subexpression elimination pass after loop optimizations."
 msgstr ""
 
-#: common.opt:2173
+#: common.opt:2177
 msgid "Disable optimizations that assume default FP rounding behavior."
 msgstr ""
 
-#: common.opt:2177
+#: common.opt:2181
 msgid "Enable scheduling across basic blocks."
 msgstr ""
 
-#: common.opt:2181
+#: common.opt:2185
 msgid "Enable register pressure sensitive insn scheduling."
 msgstr ""
 
-#: common.opt:2185
+#: common.opt:2189
 msgid "Allow speculative motion of non-loads."
 msgstr ""
 
-#: common.opt:2189
+#: common.opt:2193
 msgid "Allow speculative motion of some loads."
 msgstr ""
 
-#: common.opt:2193
+#: common.opt:2197
 msgid "Allow speculative motion of more loads."
 msgstr ""
 
-#: common.opt:2197
+#: common.opt:2201
 msgid "-fsched-verbose=<number>\tSet the verbosity level of the scheduler."
 msgstr ""
 
-#: common.opt:2201
+#: common.opt:2205
 msgid "If scheduling post reload, do superblock scheduling."
 msgstr ""
 
-#: common.opt:2209
+#: common.opt:2213
 msgid "Reschedule instructions before register allocation."
 msgstr ""
 
-#: common.opt:2213
+#: common.opt:2217
 msgid "Reschedule instructions after register allocation."
 msgstr ""
 
-#: common.opt:2220
+#: common.opt:2224
 msgid "Schedule instructions using selective scheduling algorithm."
 msgstr ""
 
-#: common.opt:2224
+#: common.opt:2228
 msgid "Run selective scheduling after reload."
 msgstr ""
 
-#: common.opt:2228
+#: common.opt:2232
 msgid "Run self-tests, using the given path to locate test files."
 msgstr ""
 
-#: common.opt:2232
+#: common.opt:2236
 msgid "Perform software pipelining of inner loops during selective scheduling."
 msgstr ""
 
-#: common.opt:2236
+#: common.opt:2240
 msgid "Perform software pipelining of outer loops during selective scheduling."
 msgstr ""
 
-#: common.opt:2240
+#: common.opt:2244
 msgid "Reschedule pipelined regions without pipelining."
 msgstr ""
 
-#: common.opt:2244
+#: common.opt:2248
 msgid "Allow interposing function (or variables) by ones with different semantics (or initializer) respectively by dynamic linker."
 msgstr ""
 
-#: common.opt:2250
+#: common.opt:2254
 msgid "Allow premature scheduling of queued insns."
 msgstr ""
 
-#: common.opt:2254
+#: common.opt:2258
 msgid "-fsched-stalled-insns=<number>\tSet number of queued insns that can be prematurely scheduled."
 msgstr ""
 
-#: common.opt:2262
+#: common.opt:2266
 msgid "Set dependence distance checking in premature scheduling of queued insns."
 msgstr ""
 
-#: common.opt:2266
+#: common.opt:2270
 msgid "-fsched-stalled-insns-dep=<number>\tSet dependence distance checking in premature scheduling of queued insns."
 msgstr ""
 
-#: common.opt:2270
+#: common.opt:2274
 msgid "Enable the group heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2274
+#: common.opt:2278
 msgid "Enable the critical path heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2278
+#: common.opt:2282
 msgid "Enable the speculative instruction heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2282
+#: common.opt:2286
 msgid "Enable the rank heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2286
+#: common.opt:2290
 msgid "Enable the last instruction heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2290
+#: common.opt:2294
 msgid "Enable the dependent count heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2294
+#: common.opt:2298
 msgid "Access data in the same section from shared anchor points."
 msgstr ""
 
-#: common.opt:2306
+#: common.opt:2310
 msgid "Turn on Redundant Extensions Elimination pass."
 msgstr ""
 
-#: common.opt:2310
+#: common.opt:2314
 msgid "Show column numbers in diagnostics, when available.  Default on."
 msgstr ""
 
-#: common.opt:2314
+#: common.opt:2318
 msgid "Emit function prologues only before parts of the function that need it, rather than at the top of the function."
 msgstr ""
 
-#: common.opt:2319
+#: common.opt:2323
 msgid "Shrink-wrap parts of the prologue and epilogue separately."
 msgstr ""
 
-#: common.opt:2323
+#: common.opt:2327
 msgid "Disable optimizations observable by IEEE signaling NaNs."
 msgstr ""
 
-#: common.opt:2327
+#: common.opt:2331
 msgid "Disable floating point optimizations that ignore the IEEE signedness of zero."
 msgstr ""
 
-#: common.opt:2331
+#: common.opt:2335
 msgid "Convert floating point constants to single precision constants."
 msgstr ""
 
-#: common.opt:2335
+#: common.opt:2339
 msgid "Split lifetimes of induction variables when loops are unrolled."
 msgstr ""
 
-#: common.opt:2339
+#: common.opt:2343
 msgid "Generate discontiguous stack frames."
 msgstr ""
 
-#: common.opt:2343
+#: common.opt:2347
 msgid "Split wide types into independent registers."
 msgstr ""
 
-#: common.opt:2347
+#: common.opt:2351
 msgid "Enable backward propagation of use properties at the SSA level."
 msgstr ""
 
-#: common.opt:2351
+#: common.opt:2355
 msgid "Optimize conditional patterns using SSA PHI nodes."
 msgstr ""
 
-#: common.opt:2355
+#: common.opt:2359
 msgid "Optimize amount of stdarg registers saved to stack at start of function."
 msgstr ""
 
-#: common.opt:2359
+#: common.opt:2363
 msgid "Apply variable expansion when loops are unrolled."
 msgstr ""
 
-#: common.opt:2363
+#: common.opt:2367
 msgid "-fstack-check=[no|generic|specific]\tInsert stack checking code into the program."
 msgstr ""
 
-#: common.opt:2367
+#: common.opt:2371
 msgid "Insert stack checking code into the program.  Same as -fstack-check=specific."
 msgstr ""
 
-#: common.opt:2371
+#: common.opt:2375
 msgid "Insert code to probe each page of stack space as it is allocated to protect from stack-clash style attacks."
 msgstr ""
 
-#: common.opt:2379
+#: common.opt:2383
 msgid "-fstack-limit-register=<register>\tTrap if the stack goes past <register>."
 msgstr ""
 
-#: common.opt:2383
+#: common.opt:2387
 msgid "-fstack-limit-symbol=<name>\tTrap if the stack goes past symbol <name>."
 msgstr ""
 
-#: common.opt:2387
+#: common.opt:2391
 msgid "Use propolice as a stack protection method."
 msgstr ""
 
-#: common.opt:2391
+#: common.opt:2395
 msgid "Use a stack protection method for every function."
 msgstr ""
 
-#: common.opt:2395
+#: common.opt:2399
 msgid "Use a smart stack protection method for certain functions."
 msgstr ""
 
-#: common.opt:2399
+#: common.opt:2403
 msgid "Use stack protection method only for functions with the stack_protect attribute."
 msgstr ""
 
-#: common.opt:2403
+#: common.opt:2407
 msgid "Output stack usage information on a per-function basis."
 msgstr ""
 
-#: common.opt:2415
+#: common.opt:2419
 msgid "Assume strict aliasing rules apply."
 msgstr ""
 
-#: common.opt:2419
+#: common.opt:2423
 msgid "Treat signed overflow as undefined.  Negated as -fwrapv -fwrapv-pointer."
 msgstr ""
 
-#: common.opt:2423
+#: common.opt:2427
 msgid "Implement __atomic operations via libcalls to legacy __sync functions."
 msgstr ""
 
-#: common.opt:2427
+#: common.opt:2431
 msgid "Check for syntax errors, then stop."
 msgstr ""
 
-#: common.opt:2431
+#: common.opt:2435
 msgid "Create data files needed by \"gcov\"."
 msgstr ""
 
-#: common.opt:2435
+#: common.opt:2439
 msgid "Perform jump threading optimizations."
 msgstr ""
 
-#: common.opt:2439
+#: common.opt:2443
 msgid "Report the time taken by each compiler pass."
 msgstr ""
 
-#: common.opt:2443
+#: common.opt:2447
 msgid "Record times taken by sub-phases separately."
 msgstr ""
 
-#: common.opt:2447
+#: common.opt:2451
 msgid "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tSet the default thread-local storage code generation model."
 msgstr ""
 
-#: common.opt:2450
+#: common.opt:2454
 #, c-format
 msgid "unknown TLS model %qs"
 msgstr ""
 
-#: common.opt:2466
+#: common.opt:2470
 msgid "Reorder top level functions, variables, and asms."
 msgstr ""
 
-#: common.opt:2470
+#: common.opt:2474
 msgid "Perform superblock formation via tail duplication."
 msgstr ""
 
-#: common.opt:2474
+#: common.opt:2478
 msgid "For targets that normally need trampolines for nested functions, always generate them instead of using descriptors."
 msgstr ""
 
-#: common.opt:2482
+#: common.opt:2486
 msgid "Assume floating-point operations can trap."
 msgstr ""
 
-#: common.opt:2486
+#: common.opt:2490
 msgid "Trap for signed overflow in addition, subtraction and multiplication."
 msgstr ""
 
-#: common.opt:2490
+#: common.opt:2494
 msgid "Enable SSA-CCP optimization on trees."
 msgstr ""
 
-#: common.opt:2494
+#: common.opt:2498
 msgid "Enable SSA-BIT-CCP optimization on trees."
 msgstr ""
 
-#: common.opt:2502
+#: common.opt:2506
 msgid "Enable loop header copying on trees."
 msgstr ""
 
-#: common.opt:2510
+#: common.opt:2514
 msgid "Enable SSA coalescing of user variables."
 msgstr ""
 
-#: common.opt:2518
+#: common.opt:2522
 msgid "Enable copy propagation on trees."
 msgstr ""
 
-#: common.opt:2526
+#: common.opt:2530
 msgid "Transform condition stores into unconditional ones."
 msgstr ""
 
-#: common.opt:2530
+#: common.opt:2534
 msgid "Perform conversions of switch initializations."
 msgstr ""
 
-#: common.opt:2534
+#: common.opt:2538
 msgid "Enable SSA dead code elimination optimization on trees."
 msgstr ""
 
-#: common.opt:2538
+#: common.opt:2542
 msgid "Enable dominator optimizations."
 msgstr ""
 
-#: common.opt:2542
+#: common.opt:2546
 msgid "Enable tail merging on trees."
 msgstr ""
 
-#: common.opt:2546
+#: common.opt:2550
 msgid "Enable dead store elimination."
 msgstr ""
 
-#: common.opt:2550
+#: common.opt:2554
 msgid "Enable forward propagation on trees."
 msgstr ""
 
-#: common.opt:2554
+#: common.opt:2558
 msgid "Enable Full Redundancy Elimination (FRE) on trees."
 msgstr ""
 
-#: common.opt:2558
+#: common.opt:2562
 msgid "Enable string length optimizations on trees."
 msgstr ""
 
-#: common.opt:2562
+#: common.opt:2566
 msgid "Detect paths that trigger erroneous or undefined behavior due to dereferencing a null pointer.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
-#: common.opt:2568
+#: common.opt:2572
 msgid "Detect paths that trigger erroneous or undefined behavior due to a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
-#: common.opt:2575
+#: common.opt:2579
 msgid "Enable loop distribution on trees."
 msgstr ""
 
-#: common.opt:2579
+#: common.opt:2583
 msgid "Enable loop distribution for patterns transformed into a library call."
 msgstr ""
 
-#: common.opt:2583
+#: common.opt:2587
 msgid "Enable loop invariant motion on trees."
 msgstr ""
 
-#: common.opt:2591
+#: common.opt:2595
 msgid "Create canonical induction variables in loops."
 msgstr ""
 
-#: common.opt:2595
+#: common.opt:2599
 msgid "Enable loop optimizations on tree level."
 msgstr ""
 
-#: common.opt:2599
+#: common.opt:2603
 msgid "-ftree-parallelize-loops=<number>\tEnable automatic parallelization of loops."
 msgstr ""
 
-#: common.opt:2603
+#: common.opt:2607
 msgid "Enable hoisting loads from conditional pointers."
 msgstr ""
 
-#: common.opt:2607
+#: common.opt:2611
 msgid "Enable SSA-PRE optimization on trees."
 msgstr ""
 
-#: common.opt:2611
+#: common.opt:2615
 msgid "In SSA-PRE optimization on trees, enable partial-partial redundancy elimination."
 msgstr ""
 
-#: common.opt:2615
+#: common.opt:2619
 msgid "Perform function-local points-to analysis on trees."
 msgstr ""
 
-#: common.opt:2619
+#: common.opt:2623
 msgid "Enable reassociation on tree level."
 msgstr ""
 
-#: common.opt:2627
+#: common.opt:2631
 msgid "Enable SSA code sinking on trees."
 msgstr ""
 
-#: common.opt:2631
+#: common.opt:2635
 msgid "Perform straight-line strength reduction."
 msgstr ""
 
-#: common.opt:2635
+#: common.opt:2639
 msgid "Perform scalar replacement of aggregates."
 msgstr ""
 
-#: common.opt:2639
+#: common.opt:2643
 msgid "Replace temporary expressions in the SSA->normal pass."
 msgstr ""
 
-#: common.opt:2643
+#: common.opt:2647
 msgid "Perform live range splitting during the SSA->normal pass."
 msgstr ""
 
-#: common.opt:2647
+#: common.opt:2651
 msgid "Perform Value Range Propagation on trees."
 msgstr ""
 
-#: common.opt:2651
+#: common.opt:2655
 msgid "Split paths leading to loop backedges."
 msgstr ""
 
-#: common.opt:2655
+#: common.opt:2659
 msgid "Assume common declarations may be overridden with ones with a larger trailing array."
 msgstr ""
 
-#: common.opt:2660
+#: common.opt:2664
 msgid "Compile whole compilation unit at a time."
 msgstr ""
 
-#: common.opt:2664
+#: common.opt:2668
 msgid "Perform loop unrolling when iteration count is known."
 msgstr ""
 
-#: common.opt:2668
+#: common.opt:2672
 msgid "Perform loop unrolling for all loops."
 msgstr ""
 
-#: common.opt:2679
+#: common.opt:2683
 msgid "Allow optimization for floating-point arithmetic which may change the result of the operation due to rounding."
 msgstr ""
 
-#: common.opt:2684
+#: common.opt:2688
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr ""
 
-#: common.opt:2692
+#: common.opt:2696
 msgid "Allow math optimizations that may violate IEEE or ISO standards."
 msgstr ""
 
-#: common.opt:2696
+#: common.opt:2700
 msgid "Perform loop unswitching."
 msgstr ""
 
-#: common.opt:2700
+#: common.opt:2704
 msgid "Perform loop splitting."
 msgstr ""
 
-#: common.opt:2704
+#: common.opt:2708
 msgid "Just generate unwind tables for exception handling."
 msgstr ""
 
-#: common.opt:2708
+#: common.opt:2712
 msgid "Use the bfd linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2712
+#: common.opt:2716
 msgid "Use the gold linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2724
+#: common.opt:2728
 msgid "Perform variable tracking."
 msgstr ""
 
-#: common.opt:2732
+#: common.opt:2736
 msgid "Perform variable tracking by annotating assignments."
 msgstr ""
 
-#: common.opt:2738
+#: common.opt:2742
 msgid "Toggle -fvar-tracking-assignments."
 msgstr ""
 
-#: common.opt:2746
+#: common.opt:2750
 msgid "Perform variable tracking and also tag variables that are uninitialized."
 msgstr ""
 
-#: common.opt:2751
+#: common.opt:2755
 msgid "Enable vectorization on trees."
 msgstr ""
 
-#: common.opt:2759
+#: common.opt:2763
 msgid "Enable loop vectorization on trees."
 msgstr ""
 
-#: common.opt:2763
+#: common.opt:2767
 msgid "Enable basic block vectorization (SLP) on trees."
 msgstr ""
 
-#: common.opt:2767
+#: common.opt:2771
 msgid "Specifies the cost model for vectorization. -fvect-cost-model=[unlimited|dynamic|cheap]\tSpecifies the cost model for vectorization."
 msgstr ""
 
-#: common.opt:2772
+#: common.opt:2776
 msgid "-fsimd-cost-model=[unlimited|dynamic|cheap]\tSpecifies the vectorization cost model for code marked with a simd directive."
 msgstr ""
 
-#: common.opt:2775
+#: common.opt:2779
 #, c-format
 msgid "unknown vectorizer cost model %qs"
 msgstr ""
 
-#: common.opt:2788
+#: common.opt:2792
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr ""
 
-#: common.opt:2796
+#: common.opt:2800
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr ""
 
-#: common.opt:2806
+#: common.opt:2810
 msgid "Add extra commentary to assembler output."
 msgstr ""
 
-#: common.opt:2810
+#: common.opt:2814
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility."
 msgstr ""
 
-#: common.opt:2813
+#: common.opt:2817
 #, c-format
 msgid "unrecognized visibility value %qs"
 msgstr ""
 
-#: common.opt:2829
+#: common.opt:2833
 msgid "Validate vtable pointers before using them."
 msgstr ""
 
-#: common.opt:2832
+#: common.opt:2836
 #, c-format
 msgid "unknown vtable verify initialization priority %qs"
 msgstr ""
 
-#: common.opt:2845
+#: common.opt:2849
 msgid "Output vtable verification counters."
 msgstr ""
 
-#: common.opt:2849
+#: common.opt:2853
 msgid "Output vtable verification pointer sets information."
 msgstr ""
 
-#: common.opt:2853
+#: common.opt:2857
 msgid "Use expression value profiles in optimizations."
 msgstr ""
 
-#: common.opt:2857
+#: common.opt:2861
 msgid "Construct webs and split unrelated uses of single variable."
 msgstr ""
 
-#: common.opt:2861
+#: common.opt:2865
 msgid "Enable conditional dead code elimination for builtin calls."
 msgstr ""
 
-#: common.opt:2865
+#: common.opt:2869
 msgid "Perform whole program optimizations."
 msgstr ""
 
-#: common.opt:2869
+#: common.opt:2873
 msgid "Assume pointer overflow wraps around."
 msgstr ""
 
-#: common.opt:2873
+#: common.opt:2877
 msgid "Assume signed arithmetic overflow wraps around."
 msgstr ""
 
-#: common.opt:2877
+#: common.opt:2881
 msgid "Put zero initialized data in the bss section."
 msgstr "Розташувати ініціалізовані нулями дані у розділі bss."
 
-#: common.opt:2881
+#: common.opt:2885
 msgid "Generate debug information in default format."
 msgstr "Створити діагностичні дані у типовому форматі."
 
-#: common.opt:2885
+#: common.opt:2889
 msgid "Assume assembler support for (DWARF2+) .loc directives"
 msgstr ""
 
-#: common.opt:2889
+#: common.opt:2893
 msgid "Assume assembler support for view in (DWARF2+) .loc directives"
 msgstr ""
 
-#: common.opt:2892 common.opt:2896 common.opt:2900 common.opt:2904
+#: common.opt:2896 common.opt:2900 common.opt:2904 common.opt:2908
 #, c-format
 msgid "switch %qs no longer supported"
 msgstr "підтримку перемикача %qs припинено"
 
-#: common.opt:2909
+#: common.opt:2913
 msgid "Record DW_AT_decl_column and DW_AT_call_column in DWARF."
 msgstr ""
 
-#: common.opt:2913
+#: common.opt:2917
 msgid "Generate debug information in default version of DWARF format."
 msgstr ""
 
-#: common.opt:2917
+#: common.opt:2921
 msgid "Generate debug information in DWARF v2 (or later) format."
 msgstr ""
 
-#: common.opt:2921
+#: common.opt:2925
 msgid "Generate debug information in default extended format."
 msgstr ""
 
-#: common.opt:2925
+#: common.opt:2929
 msgid "Generate extended entry point information for inlined functions"
 msgstr ""
 
-#: common.opt:2929
+#: common.opt:2933
 msgid "Compute locview reset points based on insn length estimates"
 msgstr ""
 
-#: common.opt:2937
+#: common.opt:2941
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:2941
+#: common.opt:2945
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:2945
+#: common.opt:2949
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr ""
 
-#: common.opt:2949
+#: common.opt:2953
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr ""
 
-#: common.opt:2953
+#: common.opt:2957
 msgid "Generate debug information in separate .dwo files."
 msgstr ""
 
-#: common.opt:2957
+#: common.opt:2961
 msgid "Generate debug information in STABS format."
 msgstr ""
 
-#: common.opt:2961
+#: common.opt:2965
 msgid "Generate debug information in extended STABS format."
 msgstr ""
 
-#: common.opt:2965
+#: common.opt:2969
 msgid "Emit progressive recommended breakpoint locations."
 msgstr ""
 
-#: common.opt:2969
+#: common.opt:2973
 msgid "Don't emit DWARF additions beyond selected version."
 msgstr ""
 
-#: common.opt:2973
+#: common.opt:2977
 msgid "Toggle debug information generation."
 msgstr ""
 
-#: common.opt:2977
+#: common.opt:2981
 msgid "Augment variable location lists with progressive views."
 msgstr ""
 
-#: common.opt:2984
+#: common.opt:2988
 msgid "Generate debug information in VMS format."
 msgstr ""
 
-#: common.opt:2988
+#: common.opt:2992
 msgid "Generate debug information in XCOFF format."
 msgstr ""
 
-#: common.opt:2992
+#: common.opt:2996
 msgid "Generate debug information in extended XCOFF format."
 msgstr ""
 
-#: common.opt:3010
+#: common.opt:3014
 msgid "Generate compressed debug sections."
 msgstr ""
 
-#: common.opt:3014
+#: common.opt:3018
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>."
 msgstr ""
 
-#: common.opt:3021
+#: common.opt:3025
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory."
 msgstr ""
 
-#: common.opt:3025
+#: common.opt:3029
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory."
 msgstr ""
 
-#: common.opt:3047
+#: common.opt:3051
 msgid "-o <file>\tPlace output into <file>."
 msgstr ""
 
-#: common.opt:3051
+#: common.opt:3055
 msgid "Enable function profiling."
 msgstr ""
 
-#: common.opt:3061
+#: common.opt:3065
 msgid "Like -pedantic but issue them as errors."
 msgstr ""
 
-#: common.opt:3101
+#: common.opt:3105
 msgid "Do not display functions compiled or elapsed time."
 msgstr ""
 
-#: common.opt:3133
+#: common.opt:3137
 msgid "Enable verbose output."
 msgstr "Увімкнути докладне виведення."
 
-#: common.opt:3137
+#: common.opt:3141
 msgid "Display the compiler's version."
 msgstr ""
 
-#: common.opt:3141
+#: common.opt:3145
 msgid "Suppress warnings."
 msgstr "Придушити попередження."
 
-#: common.opt:3151
+#: common.opt:3155
 msgid "Create a shared library."
 msgstr "Створити бібліотеку спільного використання."
 
-#: common.opt:3196
+#: common.opt:3200
 msgid "Don't create a dynamically linked position independent executable."
 msgstr "Не створювати динамічно скомпонований виконуваний файл з незалежним позиціюванням."
 
-#: common.opt:3200
+#: common.opt:3204
 msgid "Create a dynamically linked position independent executable."
 msgstr "Створити динамічно скомпонований виконуваний файл з незалежним позиціюванням."
 
-#: common.opt:3204
+#: common.opt:3208
 msgid "Create a static position independent executable."
 msgstr "Створити статичний виконуваний файл з незалежним позиціюванням."
 
-#: common.opt:3211
+#: common.opt:3215
 msgid "Use caller save register across calls if possible."
 msgstr ""
 
-#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:598 cp/cvt.c:1308
+#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:599 cp/cvt.c:1308
 #: cp/cvt.c:1561
 #, gcc-internal-format
 msgid "value computed is not used"
@@ -15651,7 +15652,7 @@
 msgstr ""
 
 #: go/gofrontend/expressions.cc:4331 c/c-parser.c:13477 c/c-parser.c:13484
-#: cp/parser.c:33264 cp/parser.c:33271
+#: cp/parser.c:33261 cp/parser.c:33268
 #, gcc-internal-format
 msgid "expected integer"
 msgstr "мало бути ціле число"
@@ -16066,14 +16067,14 @@
 msgid "ignoring attribute %qE because it conflicts with attribute %qs"
 msgstr ""
 
-#: attribs.c:449 c-family/c-attribs.c:1894 cp/decl.c:13690 cp/friend.c:302
-#: cp/tree.c:4559
+#: attribs.c:449 c-family/c-attribs.c:1905 cp/decl.c:13714 cp/friend.c:302
+#: cp/tree.c:4607
 #, gcc-internal-format
 msgid "previous declaration here"
 msgstr ""
 
 #. Warn about and ignore all others for now, but store them.
-#: attribs.c:564 c-family/c-attribs.c:2717 objc/objc-act.c:4963
+#: attribs.c:564 c-family/c-attribs.c:2728 objc/objc-act.c:4963
 #: objc/objc-act.c:6932 objc/objc-act.c:8119 objc/objc-act.c:8170
 #, gcc-internal-format
 msgid "%qE attribute directive ignored"
@@ -16092,17 +16093,17 @@
 #. This is a c++11 attribute that appertains to a
 #. type-specifier, outside of the definition of, a class
 #. type.  Ignore it.
-#: attribs.c:590 cp/decl.c:10999
+#: attribs.c:590 cp/decl.c:11023
 #, gcc-internal-format
 msgid "attribute ignored"
 msgstr ""
 
-#: attribs.c:592 cp/decl.c:11000
+#: attribs.c:592 cp/decl.c:11024
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
 
-#: attribs.c:610 c-family/c-attribs.c:3219
+#: attribs.c:610 c-family/c-attribs.c:3230
 #, gcc-internal-format
 msgid "%qE attribute does not apply to types"
 msgstr ""
@@ -16118,40 +16119,40 @@
 msgstr ""
 
 #: attribs.c:691 attribs.c:1622 attribs.c:1632 attribs.c:1642
-#: c-family/c-attribs.c:540 c-family/c-attribs.c:559 c-family/c-attribs.c:577
-#: c-family/c-attribs.c:607 c-family/c-attribs.c:628 c-family/c-attribs.c:649
-#: c-family/c-attribs.c:690 c-family/c-attribs.c:717 c-family/c-attribs.c:733
-#: c-family/c-attribs.c:750 c-family/c-attribs.c:766 c-family/c-attribs.c:792
-#: c-family/c-attribs.c:807 c-family/c-attribs.c:835 c-family/c-attribs.c:852
-#: c-family/c-attribs.c:870 c-family/c-attribs.c:893 c-family/c-attribs.c:931
-#: c-family/c-attribs.c:954 c-family/c-attribs.c:971 c-family/c-attribs.c:1000
-#: c-family/c-attribs.c:1021 c-family/c-attribs.c:1042
-#: c-family/c-attribs.c:1069 c-family/c-attribs.c:1099
-#: c-family/c-attribs.c:1136 c-family/c-attribs.c:1189
-#: c-family/c-attribs.c:1255 c-family/c-attribs.c:1313
-#: c-family/c-attribs.c:1402 c-family/c-attribs.c:1432
-#: c-family/c-attribs.c:1483 c-family/c-attribs.c:1998
-#: c-family/c-attribs.c:2035 c-family/c-attribs.c:2096
-#: c-family/c-attribs.c:2152 c-family/c-attribs.c:2230
-#: c-family/c-attribs.c:2312 c-family/c-attribs.c:2371
-#: c-family/c-attribs.c:2390 c-family/c-attribs.c:2498
-#: c-family/c-attribs.c:2514 c-family/c-attribs.c:2530
-#: c-family/c-attribs.c:2551 c-family/c-attribs.c:2608
-#: c-family/c-attribs.c:2635 c-family/c-attribs.c:2690
-#: c-family/c-attribs.c:2870 c-family/c-attribs.c:2891
-#: c-family/c-attribs.c:3004 c-family/c-attribs.c:3031
-#: c-family/c-attribs.c:3221 c-family/c-attribs.c:3239
-#: c-family/c-attribs.c:3262 c-family/c-attribs.c:3301
-#: c-family/c-attribs.c:3383 c-family/c-attribs.c:3439
-#: c-family/c-attribs.c:3455 c-family/c-attribs.c:3549
-#: c-family/c-common.c:5600 config/darwin.c:2072 config/arm/arm.c:6868
+#: c-family/c-attribs.c:547 c-family/c-attribs.c:566 c-family/c-attribs.c:584
+#: c-family/c-attribs.c:614 c-family/c-attribs.c:635 c-family/c-attribs.c:656
+#: c-family/c-attribs.c:697 c-family/c-attribs.c:728 c-family/c-attribs.c:744
+#: c-family/c-attribs.c:761 c-family/c-attribs.c:777 c-family/c-attribs.c:803
+#: c-family/c-attribs.c:818 c-family/c-attribs.c:846 c-family/c-attribs.c:863
+#: c-family/c-attribs.c:881 c-family/c-attribs.c:904 c-family/c-attribs.c:942
+#: c-family/c-attribs.c:965 c-family/c-attribs.c:982 c-family/c-attribs.c:1011
+#: c-family/c-attribs.c:1032 c-family/c-attribs.c:1053
+#: c-family/c-attribs.c:1080 c-family/c-attribs.c:1110
+#: c-family/c-attribs.c:1147 c-family/c-attribs.c:1200
+#: c-family/c-attribs.c:1266 c-family/c-attribs.c:1324
+#: c-family/c-attribs.c:1413 c-family/c-attribs.c:1443
+#: c-family/c-attribs.c:1494 c-family/c-attribs.c:2009
+#: c-family/c-attribs.c:2046 c-family/c-attribs.c:2107
+#: c-family/c-attribs.c:2163 c-family/c-attribs.c:2241
+#: c-family/c-attribs.c:2323 c-family/c-attribs.c:2382
+#: c-family/c-attribs.c:2401 c-family/c-attribs.c:2509
+#: c-family/c-attribs.c:2525 c-family/c-attribs.c:2541
+#: c-family/c-attribs.c:2562 c-family/c-attribs.c:2619
+#: c-family/c-attribs.c:2646 c-family/c-attribs.c:2701
+#: c-family/c-attribs.c:2881 c-family/c-attribs.c:2902
+#: c-family/c-attribs.c:3015 c-family/c-attribs.c:3042
+#: c-family/c-attribs.c:3232 c-family/c-attribs.c:3250
+#: c-family/c-attribs.c:3273 c-family/c-attribs.c:3312
+#: c-family/c-attribs.c:3394 c-family/c-attribs.c:3450
+#: c-family/c-attribs.c:3466 c-family/c-attribs.c:3560
+#: c-family/c-common.c:5598 config/darwin.c:2072 config/arm/arm.c:6868
 #: config/arm/arm.c:6896 config/arm/arm.c:6913 config/avr/avr.c:9698
-#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6497
-#: config/i386/i386.c:41520 config/ia64/ia64.c:788
-#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33056
-#: config/spu/spu.c:3743 ada/gcc-interface/utils.c:6244
-#: ada/gcc-interface/utils.c:6261 ada/gcc-interface/utils.c:6277
-#: ada/gcc-interface/utils.c:6303 brig/brig-lang.c:476 lto/lto-lang.c:283
+#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6500
+#: config/i386/i386.c:41514 config/ia64/ia64.c:788
+#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33112
+#: config/spu/spu.c:3743 ada/gcc-interface/utils.c:6249
+#: ada/gcc-interface/utils.c:6266 ada/gcc-interface/utils.c:6282
+#: ada/gcc-interface/utils.c:6308 brig/brig-lang.c:476 lto/lto-lang.c:283
 #, gcc-internal-format
 msgid "%qE attribute ignored"
 msgstr ""
@@ -16521,87 +16522,102 @@
 msgid "%Kattempt to free a non-heap object"
 msgstr ""
 
-#: calls.c:1434
+#: calls.c:1291 file-prefix-map.c:50
 #, gcc-internal-format
+msgid "invalid argument %qs to %qs"
+msgstr "некоректний аргумент %qs %qs"
+
+#: calls.c:1452
+#, gcc-internal-format
 msgid "%Kargument %i value %qE is negative"
 msgstr ""
 
-#: calls.c:1452
+#: calls.c:1470
 #, gcc-internal-format
 msgid "%Kargument %i value is zero"
 msgstr ""
 
-#: calls.c:1469
+#: calls.c:1487
 #, gcc-internal-format
 msgid "%Kargument %i value %qE exceeds maximum object size %E"
 msgstr ""
 
-#: calls.c:1483
+#: calls.c:1501
 #, gcc-internal-format
 msgid "%Kargument %i range [%E, %E] is negative"
 msgstr ""
 
-#: calls.c:1490
+#: calls.c:1508
 #, gcc-internal-format
 msgid "%Kargument %i range [%E, %E] exceeds maximum object size %E"
 msgstr ""
 
-#: calls.c:1520
+#: calls.c:1538
 #, gcc-internal-format
 msgid "%Kproduct %<%E * %E%> of arguments %i and %i exceeds %<SIZE_MAX%>"
 msgstr ""
 
-#: calls.c:1526
+#: calls.c:1544
 #, gcc-internal-format
 msgid "%Kproduct %<%E * %E%> of arguments %i and %i exceeds maximum object size %E"
 msgstr ""
 
-#: calls.c:1537 calls.c:1540
+#: calls.c:1555 calls.c:1558
 #, gcc-internal-format
 msgid "argument %i in the range [%E, %E]"
 msgstr ""
 
-#: calls.c:1551
+#: calls.c:1569
 #, gcc-internal-format
 msgid "in a call to built-in allocation function %qD"
 msgstr "у виклику до вбудованої функції розподілу пам'яті %qD"
 
-#: calls.c:1554
+#: calls.c:1572
 #, gcc-internal-format
 msgid "in a call to allocation function %qD declared here"
 msgstr "у виклику до функції отримання області пам'яті %qD оголошено тут"
 
-#: calls.c:1711
+#: calls.c:1835
 #, gcc-internal-format
-msgid "%qD argument %i declared attribute %<nonstring%> is smaller than the specified bound %E"
+msgid "%qD argument %i declared attribute %<nonstring%> is smaller than the specified bound %wu"
 msgstr ""
 
-#: calls.c:1716
+#: calls.c:1841
 #, gcc-internal-format
+msgid "%qD argument %i declared attribute %<nonstring%> is smaller than the specified bound [%E, %E]"
+msgstr ""
+
+#: calls.c:1847
+#, gcc-internal-format
+msgid "%qD argument %i declared attribute %<nonstring%> may be smaller than the specified bound [%E, %E]"
+msgstr ""
+
+#: calls.c:1857
+#, gcc-internal-format
 msgid "%qD argument %i declared attribute %<nonstring%>"
 msgstr ""
 
-#: calls.c:1721
+#: calls.c:1862
 #, gcc-internal-format
 msgid "argument %qD declared here"
 msgstr "аргумент %qD оголошено тут:"
 
-#: calls.c:1735
+#: calls.c:1876
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot tail-call: %s"
 msgstr "хвостовий виклик неможливий: %s"
 
-#: calls.c:3365
+#: calls.c:3506
 #, gcc-internal-format
 msgid "function call has aggregate value"
 msgstr ""
 
-#: calls.c:4059
+#: calls.c:4200
 #, gcc-internal-format
 msgid "passing too large argument on stack"
 msgstr ""
 
-#: cfgexpand.c:1665 function.c:1002 varasm.c:2231
+#: cfgexpand.c:1665 function.c:1002 varasm.c:2242
 #, gcc-internal-format
 msgid "size of variable %q+D is too large"
 msgstr ""
@@ -17173,237 +17189,237 @@
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr ""
 
-#: cgraph.c:3051
+#: cgraph.c:3056
 #, gcc-internal-format
 msgid "caller edge count invalid"
 msgstr ""
 
-#: cgraph.c:3135
+#: cgraph.c:3140
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr ""
 
-#: cgraph.c:3142
+#: cgraph.c:3147
 #, gcc-internal-format
 msgid "cgraph count invalid"
 msgstr ""
 
-#: cgraph.c:3147
+#: cgraph.c:3152
 #, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr ""
 
-#: cgraph.c:3152
+#: cgraph.c:3157
 #, gcc-internal-format
 msgid "local symbols must be defined"
 msgstr ""
 
-#: cgraph.c:3157
+#: cgraph.c:3162
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr ""
 
-#: cgraph.c:3162
+#: cgraph.c:3167
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr ""
 
-#: cgraph.c:3167
+#: cgraph.c:3172
 #, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr ""
 
-#: cgraph.c:3174
+#: cgraph.c:3179
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for indirect edge from %s"
 msgstr ""
 
-#: cgraph.c:3181
+#: cgraph.c:3186
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr ""
 
-#: cgraph.c:3196
+#: cgraph.c:3201
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr ""
 
-#: cgraph.c:3206
+#: cgraph.c:3211
 #, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr ""
 
-#: cgraph.c:3211
+#: cgraph.c:3216
 #, gcc-internal-format
 msgid "multiple inline callers"
 msgstr ""
 
-#: cgraph.c:3218
+#: cgraph.c:3223
 #, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr ""
 
-#: cgraph.c:3239
+#: cgraph.c:3244
 #, gcc-internal-format
 msgid "caller edge count does not match BB count"
 msgstr ""
 
-#: cgraph.c:3261
+#: cgraph.c:3266
 #, gcc-internal-format
 msgid "indirect call count does not match BB count"
 msgstr ""
 
-#: cgraph.c:3272
+#: cgraph.c:3277
 #, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr ""
 
-#: cgraph.c:3277
+#: cgraph.c:3282
 #, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr ""
 
-#: cgraph.c:3289
+#: cgraph.c:3294
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr ""
 
-#: cgraph.c:3301
+#: cgraph.c:3306
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr ""
 
-#: cgraph.c:3307
+#: cgraph.c:3312
 #, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr ""
 
-#: cgraph.c:3312
+#: cgraph.c:3317
 #, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr ""
 
-#: cgraph.c:3317
+#: cgraph.c:3322
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr ""
 
-#: cgraph.c:3329
+#: cgraph.c:3334
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr ""
 
-#: cgraph.c:3337
+#: cgraph.c:3342
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr ""
 
-#: cgraph.c:3342
+#: cgraph.c:3347
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr ""
 
-#: cgraph.c:3349
+#: cgraph.c:3354
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr ""
 
-#: cgraph.c:3358
+#: cgraph.c:3363
 #, gcc-internal-format
 msgid "Instrumentation clone does not reference original node"
 msgstr ""
 
-#: cgraph.c:3365
+#: cgraph.c:3370
 #, gcc-internal-format
 msgid "Not instrumented node has non-NULL original declaration"
 msgstr ""
 
-#: cgraph.c:3375
+#: cgraph.c:3380
 #, gcc-internal-format
 msgid "Instrumented node has wrong original declaration"
 msgstr ""
 
-#: cgraph.c:3393
+#: cgraph.c:3398
 #, gcc-internal-format
 msgid "Node has more than one chkp reference"
 msgstr ""
 
-#: cgraph.c:3398
+#: cgraph.c:3403
 #, gcc-internal-format
 msgid "Wrong node is referenced with chkp reference"
 msgstr ""
 
-#: cgraph.c:3406
+#: cgraph.c:3411
 #, gcc-internal-format
 msgid "Analyzed node has no reference to instrumented version"
 msgstr ""
 
-#: cgraph.c:3420
+#: cgraph.c:3425
 #, gcc-internal-format
 msgid "Alias chain for instrumented node is broken"
 msgstr ""
 
-#: cgraph.c:3429
+#: cgraph.c:3434
 #, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3434
+#: cgraph.c:3439
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3439
+#: cgraph.c:3444
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr ""
 
-#: cgraph.c:3445
+#: cgraph.c:3450
 #, gcc-internal-format
 msgid "Instrumentation thunk has wrong edge callee"
 msgstr ""
 
-#: cgraph.c:3481
+#: cgraph.c:3486
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr ""
 
-#: cgraph.c:3489
+#: cgraph.c:3494
 #, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr ""
 
-#: cgraph.c:3498
+#: cgraph.c:3503
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr ""
 
-#: cgraph.c:3508
+#: cgraph.c:3513
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr ""
 
-#: cgraph.c:3518
+#: cgraph.c:3523
 #, gcc-internal-format
 msgid "reference to dead statement"
 msgstr ""
 
-#: cgraph.c:3531
+#: cgraph.c:3536
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3543
+#: cgraph.c:3548
 #, gcc-internal-format, gfc-internal-format
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3554
+#: cgraph.c:3559
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr ""
 
-#: cgraph.c:3661 varpool.c:306
+#: cgraph.c:3666 varpool.c:306
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: section %s is missing"
 msgstr ""
@@ -17434,12 +17450,12 @@
 msgstr ""
 
 #. include_self=
-#: cgraphunit.c:981 c/c-decl.c:11282
+#: cgraphunit.c:981 c/c-decl.c:11302
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr ""
 
-#: cgraphunit.c:983 c/c-decl.c:11291
+#: cgraphunit.c:983 c/c-decl.c:11311
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr ""
@@ -17554,12 +17570,12 @@
 msgid "cannot find '%s'"
 msgstr "не вдалося знайти «%s»"
 
-#: collect-utils.c:183 collect2.c:2361 collect2.c:2560 gcc.c:3080 gcc.c:6856
+#: collect-utils.c:183 collect2.c:2387 collect2.c:2586 gcc.c:3080 gcc.c:6856
 #, gcc-internal-format
 msgid "pex_init failed: %m"
 msgstr ""
 
-#: collect-utils.c:192 collect2.c:2370 collect2.c:2568 gcc.c:8498
+#: collect-utils.c:192 collect2.c:2396 collect2.c:2594 gcc.c:8498
 #, gcc-internal-format
 msgid "%s: %m"
 msgstr ""
@@ -17569,93 +17585,93 @@
 msgid "COLLECT_LTO_WRAPPER must be set"
 msgstr ""
 
-#: collect2.c:966 gcc.c:7382 lto-wrapper.c:1666
+#: collect2.c:969 gcc.c:7382 lto-wrapper.c:1692
 #: config/i386/intelmic-mkoffload.c:556 config/nvptx/mkoffload.c:405
 #, gcc-internal-format
 msgid "atexit failed"
 msgstr ""
 
-#: collect2.c:1064
+#: collect2.c:1067
 #, gcc-internal-format
 msgid "no arguments"
 msgstr "немає аргументів"
 
-#: collect2.c:1303 opts.c:904
+#: collect2.c:1311 opts.c:904
 #, gcc-internal-format
 msgid "LTO support has not been enabled in this configuration"
 msgstr ""
 
-#: collect2.c:1344
+#: collect2.c:1352
 #, gcc-internal-format
 msgid "can't open %s: %m"
 msgstr ""
 
-#: collect2.c:1450
+#: collect2.c:1472
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown demangling style '%s'"
 msgstr "невідомий стиль декодування '%s'"
 
-#: collect2.c:1546 collect2.c:1729 collect2.c:1769
+#: collect2.c:1574 collect2.c:1757 collect2.c:1797
 #, gcc-internal-format
 msgid "fopen %s: %m"
 msgstr ""
 
-#: collect2.c:1549 collect2.c:1734 collect2.c:1772
+#: collect2.c:1577 collect2.c:1762 collect2.c:1800
 #, gcc-internal-format
 msgid "fclose %s: %m"
 msgstr ""
 
-#: collect2.c:2335
+#: collect2.c:2361
 #, gcc-internal-format
 msgid "cannot find 'nm'"
 msgstr ""
 
-#: collect2.c:2383
+#: collect2.c:2409
 #, gcc-internal-format
 msgid "can't open nm output: %m"
 msgstr ""
 
-#: collect2.c:2467
+#: collect2.c:2493
 #, gcc-internal-format, gfc-internal-format
 msgid "init function found in object %s"
 msgstr ""
 
-#: collect2.c:2478
+#: collect2.c:2504
 #, gcc-internal-format, gfc-internal-format
 msgid "fini function found in object %s"
 msgstr ""
 
-#: collect2.c:2535
+#: collect2.c:2561
 #, gcc-internal-format
 msgid "cannot find 'ldd'"
 msgstr ""
 
-#: collect2.c:2581
+#: collect2.c:2607
 #, gcc-internal-format
 msgid "can't open ldd output: %m"
 msgstr ""
 
-#: collect2.c:2599
+#: collect2.c:2625
 #, gcc-internal-format, gfc-internal-format
 msgid "dynamic dependency %s not found"
 msgstr ""
 
-#: collect2.c:2611
+#: collect2.c:2637
 #, gcc-internal-format, gfc-internal-format
 msgid "unable to open dynamic dependency '%s'"
 msgstr ""
 
-#: collect2.c:2765
+#: collect2.c:2791
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: not a COFF file"
 msgstr ""
 
-#: collect2.c:2930
+#: collect2.c:2961
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: cannot open as COFF file"
 msgstr ""
 
-#: collect2.c:2989
+#: collect2.c:3020
 #, gcc-internal-format, gfc-internal-format
 msgid "library lib%s not found"
 msgstr ""
@@ -17865,12 +17881,12 @@
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr ""
 
-#: dwarf2out.c:10901
+#: dwarf2out.c:10909
 #, gcc-internal-format
 msgid "-gdwarf-6 is output as version 5 with incompatibilities"
 msgstr ""
 
-#: dwarf2out.c:14415
+#: dwarf2out.c:14423
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
@@ -17990,11 +18006,6 @@
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr ""
 
-#: file-prefix-map.c:50
-#, gcc-internal-format
-msgid "invalid argument %qs to %qs"
-msgstr "некоректний аргумент %qs %qs"
-
 #: final.c:1868
 #, gcc-internal-format
 msgid "the frame size of %wd bytes is larger than %wd bytes"
@@ -18015,42 +18026,42 @@
 msgid "large fixed-point constant implicitly truncated to fixed-point type"
 msgstr ""
 
-#: fold-const.c:4151 fold-const.c:4161
+#: fold-const.c:4157 fold-const.c:4167
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d due to width of bit-field"
 msgstr ""
 
-#: fold-const.c:5478 tree-ssa-reassoc.c:2374 tree-ssa-reassoc.c:3214
+#: fold-const.c:5484 tree-ssa-reassoc.c:2379 tree-ssa-reassoc.c:3219
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
 
-#: fold-const.c:5928 fold-const.c:5942
+#: fold-const.c:5934 fold-const.c:5948
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr ""
 
-#: fold-const.c:6085
+#: fold-const.c:6091
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr ""
 
-#: fold-const.c:6090
+#: fold-const.c:6096
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr ""
 
-#: fold-const.c:8310
+#: fold-const.c:8316
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr ""
 
-#: fold-const.c:8710
+#: fold-const.c:8716
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr ""
 
-#: fold-const.c:12063
+#: fold-const.c:12069
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr ""
@@ -18060,7 +18071,7 @@
 msgid "total size of local objects too large"
 msgstr ""
 
-#: function.c:1776 gimplify.c:6270
+#: function.c:1776 gimplify.c:6273
 #, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr ""
@@ -18365,7 +18376,7 @@
 msgid "%s: linker input file unused because linking not done"
 msgstr ""
 
-#: gcc.c:8420 c-family/c-opts.c:770
+#: gcc.c:8420 c-family/c-opts.c:768
 #, gcc-internal-format
 msgid "cannot use %<-%> as input filename for a precompiled header"
 msgstr ""
@@ -18600,7 +18611,7 @@
 msgid "%G%qD destination unchanged after copying no bytes"
 msgstr ""
 
-#: gimple-fold.c:2052 tree-ssa-strlen.c:2050
+#: gimple-fold.c:2052 tree-ssa-strlen.c:2074
 msgid "%G%qD specified bound %E equals destination size"
 msgstr ""
 
@@ -18622,12 +18633,12 @@
 msgid "null pointer dereference"
 msgstr "розіменування нульового вказівника"
 
-#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12451
-#: tree.c:12488 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10147
-#: c/c-typeck.c:10164 c/gimple-parser.c:1616 c/gimple-parser.c:1624
+#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12455
+#: tree.c:12492 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10152
+#: c/c-typeck.c:10169 c/gimple-parser.c:1616 c/gimple-parser.c:1624
 #: cp/call.c:6493 cp/call.c:8098 cp/constexpr.c:820 cp/constexpr.c:2309
-#: cp/cvt.c:1015 cp/cvt.c:1042 cp/decl.c:7334 cp/decl2.c:5256 cp/pt.c:8334
-#: cp/semantics.c:1836 cp/semantics.c:4053 cp/typeck.c:1700 cp/typeck.c:1895
+#: cp/cvt.c:1015 cp/cvt.c:1042 cp/decl.c:7355 cp/decl2.c:5246 cp/pt.c:8348
+#: cp/semantics.c:1836 cp/semantics.c:4056 cp/typeck.c:1700 cp/typeck.c:1895
 #: cp/typeck.c:3837
 #, gcc-internal-format
 msgid "declared here"
@@ -18638,27 +18649,27 @@
 msgid "nonnull argument %qD compared to NULL"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2517 gimple-ssa-sprintf.c:2637
+#: gimple-ssa-sprintf.c:2555 gimple-ssa-sprintf.c:2675
 #, gcc-internal-format
 msgid "%qE output may be truncated before the last format character"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2519 gimple-ssa-sprintf.c:2639
+#: gimple-ssa-sprintf.c:2557 gimple-ssa-sprintf.c:2677
 #, gcc-internal-format
 msgid "%qE output truncated before the last format character"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2522 gimple-ssa-sprintf.c:2642
+#: gimple-ssa-sprintf.c:2560 gimple-ssa-sprintf.c:2680
 #, gcc-internal-format
 msgid "%qE may write a terminating nul past the end of the destination"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2524 gimple-ssa-sprintf.c:2644
+#: gimple-ssa-sprintf.c:2562 gimple-ssa-sprintf.c:2682
 #, gcc-internal-format
 msgid "%qE writing a terminating nul past the end of the destination"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2534
+#: gimple-ssa-sprintf.c:2572
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size %wu"
@@ -18666,7 +18677,7 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: gimple-ssa-sprintf.c:2541
+#: gimple-ssa-sprintf.c:2579
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size %wu"
@@ -18674,7 +18685,7 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: gimple-ssa-sprintf.c:2548
+#: gimple-ssa-sprintf.c:2586
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size %wu"
@@ -18682,67 +18693,67 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: gimple-ssa-sprintf.c:2559
+#: gimple-ssa-sprintf.c:2597
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2562
+#: gimple-ssa-sprintf.c:2600
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2564
+#: gimple-ssa-sprintf.c:2602
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2576
+#: gimple-ssa-sprintf.c:2614
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2579
+#: gimple-ssa-sprintf.c:2617
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2582
+#: gimple-ssa-sprintf.c:2620
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2591
+#: gimple-ssa-sprintf.c:2629
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2594
+#: gimple-ssa-sprintf.c:2632
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2597
+#: gimple-ssa-sprintf.c:2635
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2606
+#: gimple-ssa-sprintf.c:2644
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2609
+#: gimple-ssa-sprintf.c:2647
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2611
+#: gimple-ssa-sprintf.c:2649
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2653
+#: gimple-ssa-sprintf.c:2691
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size between %wu and %wu"
@@ -18750,7 +18761,7 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: gimple-ssa-sprintf.c:2660
+#: gimple-ssa-sprintf.c:2698
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size between %wu and %wu"
@@ -18758,7 +18769,7 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: gimple-ssa-sprintf.c:2668
+#: gimple-ssa-sprintf.c:2706
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size between %wu and %wu"
@@ -18766,102 +18777,102 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: gimple-ssa-sprintf.c:2680
+#: gimple-ssa-sprintf.c:2718
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2683
+#: gimple-ssa-sprintf.c:2721
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2686
+#: gimple-ssa-sprintf.c:2724
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2699
+#: gimple-ssa-sprintf.c:2737
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2702
+#: gimple-ssa-sprintf.c:2740
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2705
+#: gimple-ssa-sprintf.c:2743
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2715
+#: gimple-ssa-sprintf.c:2753
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2718
+#: gimple-ssa-sprintf.c:2756
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2721
+#: gimple-ssa-sprintf.c:2759
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2730
+#: gimple-ssa-sprintf.c:2768
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2733
+#: gimple-ssa-sprintf.c:2771
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2736
+#: gimple-ssa-sprintf.c:2774
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2825
+#: gimple-ssa-sprintf.c:2863
 #, gcc-internal-format
 msgid "%<%.*s%> directive argument is null"
 msgstr "аргумент директиви %<%.*s%> є порожнім"
 
-#: gimple-ssa-sprintf.c:2890
+#: gimple-ssa-sprintf.c:2928
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes exceeds minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2897
+#: gimple-ssa-sprintf.c:2935
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may exceed minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2900
+#: gimple-ssa-sprintf.c:2938
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes exceeds minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2929
+#: gimple-ssa-sprintf.c:2967
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2936
+#: gimple-ssa-sprintf.c:2974
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2939
+#: gimple-ssa-sprintf.c:2977
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may cause result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2949
+#: gimple-ssa-sprintf.c:2987
 #, gcc-internal-format
 msgid "assuming directive output of %wu byte"
 msgid_plural "assuming directive output of %wu bytes"
@@ -18869,77 +18880,77 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: gimple-ssa-sprintf.c:2956
+#: gimple-ssa-sprintf.c:2994
 #, gcc-internal-format
 msgid "directive argument %qE"
 msgstr "аргумент директиви %qE"
 
-#: gimple-ssa-sprintf.c:2958
+#: gimple-ssa-sprintf.c:2996
 #, gcc-internal-format
 msgid "directive argument in the range [%E, %E]"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2962
+#: gimple-ssa-sprintf.c:3000
 #, gcc-internal-format
 msgid "using the range [%E, %E] for directive argument"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2982
+#: gimple-ssa-sprintf.c:3020
 #, gcc-internal-format
 msgid "%qE output %wu byte into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2983
+#: gimple-ssa-sprintf.c:3021
 #, gcc-internal-format
 msgid "%qE output %wu bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2987
+#: gimple-ssa-sprintf.c:3025
 #, gcc-internal-format
 msgid "%qE output between %wu and %wu bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2992
+#: gimple-ssa-sprintf.c:3030
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes (assuming %wu) into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2997
+#: gimple-ssa-sprintf.c:3035
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3368
+#: gimple-ssa-sprintf.c:3406
 #, gcc-internal-format
 msgid "%<%.*s%> directive width out of range"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3402
+#: gimple-ssa-sprintf.c:3440
 #, gcc-internal-format
 msgid "%<%.*s%> directive precision out of range"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3893
+#: gimple-ssa-sprintf.c:3931
 #, gcc-internal-format
 msgid "specified bound %wu exceeds maximum object size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3899
+#: gimple-ssa-sprintf.c:3937
 #, gcc-internal-format
 msgid "specified bound %wu exceeds %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3949
+#: gimple-ssa-sprintf.c:3987
 #, gcc-internal-format
 msgid "null destination pointer"
 msgstr "нульовий вказівник призначення"
 
-#: gimple-ssa-sprintf.c:3966
+#: gimple-ssa-sprintf.c:4004
 #, gcc-internal-format
 msgid "specified bound %wu exceeds the size %wu of the destination object"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3978
+#: gimple-ssa-sprintf.c:4016
 #, gcc-internal-format
 msgid "null format string"
 msgstr ""
@@ -19163,10 +19174,10 @@
 msgstr ""
 
 #: gimple-ssa-warn-restrict.c:1678 c/c-decl.c:3603 c/c-decl.c:3874
-#: c/c-typeck.c:8345 cp/class.c:1346 cp/class.c:3098 cp/decl.c:3979
-#: cp/decl.c:10753 cp/decl.c:11151 cp/decl.c:11160 cp/friend.c:384
+#: c/c-typeck.c:8350 cp/class.c:1346 cp/class.c:3102 cp/decl.c:3979
+#: cp/decl.c:10777 cp/decl.c:11175 cp/decl.c:11184 cp/friend.c:384
 #: cp/friend.c:393 cp/parser.c:3275 cp/parser.c:3372 cp/parser.c:3422
-#: cp/parser.c:6327 cp/parser.c:21027
+#: cp/parser.c:6330 cp/parser.c:21024
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr ""
@@ -19234,217 +19245,217 @@
 msgid "using result of function returning %<void%>"
 msgstr ""
 
-#: gimplify.c:6128
+#: gimplify.c:6131
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid lvalue in asm output %d"
 msgstr ""
 
-#: gimplify.c:6271
+#: gimplify.c:6274
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr ""
 
-#: gimplify.c:6311 gimplify.c:6320
+#: gimplify.c:6314 gimplify.c:6323
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr ""
 
-#: gimplify.c:6928
+#: gimplify.c:6931
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in target region"
 msgstr ""
 
-#: gimplify.c:6930
+#: gimplify.c:6933
 #, gcc-internal-format
 msgid "enclosing target region"
 msgstr ""
 
-#: gimplify.c:6942
+#: gimplify.c:6945
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in untied task"
 msgstr ""
 
-#: gimplify.c:6944
+#: gimplify.c:6947
 #, gcc-internal-format
 msgid "enclosing task"
 msgstr ""
 
-#: gimplify.c:7016
+#: gimplify.c:7019
 #, gcc-internal-format
 msgid "%qE not specified in enclosing %qs"
 msgstr "%qE не задано у замиканні %qs"
 
-#: gimplify.c:7018
+#: gimplify.c:7021
 #, gcc-internal-format
 msgid "enclosing %qs"
 msgstr ""
 
-#: gimplify.c:7143
+#: gimplify.c:7146
 #, gcc-internal-format
 msgid "%qE not specified in enclosing OpenACC %qs construct"
 msgstr ""
 
-#: gimplify.c:7145
+#: gimplify.c:7148
 #, gcc-internal-format
 msgid "enclosing OpenACC %qs construct"
 msgstr ""
 
-#: gimplify.c:7198
+#: gimplify.c:7201
 #, gcc-internal-format
 msgid "%qE with %<link%> clause used in %<routine%> function"
 msgstr ""
 
-#: gimplify.c:7206
+#: gimplify.c:7209
 #, gcc-internal-format
 msgid "%qE requires a %<declare%> directive for use in a %<routine%> function"
 msgstr ""
 
-#: gimplify.c:7272 gimplify.c:7872
+#: gimplify.c:7275 gimplify.c:7875
 #, gcc-internal-format
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr ""
 
-#: gimplify.c:7293
+#: gimplify.c:7296
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr ""
 
-#: gimplify.c:7411 gimplify.c:7443
+#: gimplify.c:7414 gimplify.c:7446
 #, gcc-internal-format
 msgid "iteration variable %qE is predetermined linear"
 msgstr ""
 
-#: gimplify.c:7414
+#: gimplify.c:7417
 #, gcc-internal-format
 msgid "iteration variable %qE should be private"
 msgstr ""
 
-#: gimplify.c:7428
+#: gimplify.c:7431
 #, gcc-internal-format
 msgid "iteration variable %qE should not be firstprivate"
 msgstr ""
 
-#: gimplify.c:7431
+#: gimplify.c:7434
 #, gcc-internal-format
 msgid "iteration variable %qE should not be reduction"
 msgstr ""
 
-#: gimplify.c:7434
+#: gimplify.c:7437
 #, gcc-internal-format
 msgid "iteration variable %qE should not be linear"
 msgstr ""
 
-#: gimplify.c:7437
+#: gimplify.c:7440
 #, gcc-internal-format
 msgid "iteration variable %qE should not be lastprivate"
 msgstr ""
 
-#: gimplify.c:7440
+#: gimplify.c:7443
 #, gcc-internal-format
 msgid "iteration variable %qE should not be private"
 msgstr ""
 
-#: gimplify.c:7742
+#: gimplify.c:7745
 #, gcc-internal-format
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr ""
 
-#: gimplify.c:7949
+#: gimplify.c:7952
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr ""
 
-#: gimplify.c:8160
+#: gimplify.c:8163
 #, gcc-internal-format
 msgid "%qE appears more than once in map clauses"
 msgstr ""
 
-#: gimplify.c:8464
+#: gimplify.c:8467
 #, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr ""
 
-#: gimplify.c:8484
+#: gimplify.c:8487
 #, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr ""
 
-#: gimplify.c:8510
+#: gimplify.c:8513
 #, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr ""
 
-#: gimplify.c:8775
+#: gimplify.c:8778
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr ""
 
-#: gimplify.c:8808
+#: gimplify.c:8811
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:9000
+#: gimplify.c:9003
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:9051
+#: gimplify.c:9054
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr ""
 
-#: gimplify.c:9133
+#: gimplify.c:9136
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to present_or_copy"
 msgstr ""
 
-#: gimplify.c:9278
+#: gimplify.c:9281
 #, gcc-internal-format
 msgid "invalid private reduction on %qE"
 msgstr "некоректне приватне спрощення %qE"
 
-#: gimplify.c:11103 omp-low.c:2791
+#: gimplify.c:11106 omp-low.c:2791
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: gimplify.c:11121
+#: gimplify.c:11124
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr ""
 
-#: gimplify.c:11134
+#: gimplify.c:11137
 #, gcc-internal-format
 msgid "number of variables in %<depend(sink)%> clause does not match number of iteration variables"
 msgstr ""
 
-#: gimplify.c:11147
+#: gimplify.c:11150
 #, gcc-internal-format
 msgid "more than one %<depend(source)%> clause on an %<ordered%> construct"
 msgstr ""
 
-#: gimplify.c:11158
+#: gimplify.c:11161
 #, gcc-internal-format
 msgid "%<depend(source)%> clause specified together with %<depend(sink:)%> clauses on the same construct"
 msgstr ""
 
-#: gimplify.c:12393
+#: gimplify.c:12396
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr ""
 
-#: gimplify.c:12936
+#: gimplify.c:12939
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr ""
 
-#: gimplify.c:12941
+#: gimplify.c:12944
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr ""
 
-#: gimplify.c:12948
+#: gimplify.c:12951
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr ""
@@ -19923,47 +19934,47 @@
 msgid "Max. number of generated reload insns per insn is achieved (%d)\n"
 msgstr ""
 
-#: lto-cgraph.c:1294
+#: lto-cgraph.c:1296
 #, gcc-internal-format, gfc-internal-format
 msgid "bytecode stream: found multiple instances of cgraph node with uid %d"
 msgstr ""
 
-#: lto-cgraph.c:1472
+#: lto-cgraph.c:1474
 #, gcc-internal-format
 msgid "bytecode stream: no caller found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1478
+#: lto-cgraph.c:1480
 #, gcc-internal-format
 msgid "bytecode stream: no callee found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1552
+#: lto-cgraph.c:1554
 #, gcc-internal-format
 msgid "bytecode stream: found empty cgraph node"
 msgstr ""
 
-#: lto-cgraph.c:1730
+#: lto-cgraph.c:1732
 #, gcc-internal-format, gfc-internal-format
 msgid "At most %i profile runs is supported. Perhaps corrupted profile?"
 msgstr ""
 
-#: lto-cgraph.c:1817
+#: lto-cgraph.c:1819
 #, gcc-internal-format, gfc-internal-format
 msgid "Profile information in %s corrupted"
 msgstr ""
 
-#: lto-cgraph.c:1855
+#: lto-cgraph.c:1857
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO cgraph in %s"
 msgstr ""
 
-#: lto-cgraph.c:1865
+#: lto-cgraph.c:1867
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO section refs in %s"
 msgstr ""
 
-#: lto-cgraph.c:1946
+#: lto-cgraph.c:1948
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid offload table in %s"
 msgstr ""
@@ -20034,81 +20045,86 @@
 msgid "bytecode stream in file %qs generated with LTO version %d.%d instead of the expected %d.%d"
 msgstr ""
 
-#: lto-wrapper.c:117
+#: lto-wrapper.c:118
 #, gcc-internal-format
 msgid "deleting LTRANS file %s: %m"
 msgstr ""
 
-#: lto-wrapper.c:154
+#: lto-wrapper.c:155
 #, gcc-internal-format
 msgid "malformed COLLECT_GCC_OPTIONS"
 msgstr ""
 
-#: lto-wrapper.c:308
+#: lto-wrapper.c:309
 #, gcc-internal-format, gfc-internal-format
 msgid "Option %s with different values"
 msgstr ""
 
-#: lto-wrapper.c:392
+#: lto-wrapper.c:393
 #, gcc-internal-format, gfc-internal-format
 msgid "Option %s not used consistently in all LTO input files"
 msgstr ""
 
-#: lto-wrapper.c:832
+#: lto-wrapper.c:833
 #, gcc-internal-format, gfc-internal-format
 msgid "problem with building target image for %s\n"
 msgstr ""
 
-#: lto-wrapper.c:852
+#: lto-wrapper.c:853
 #, gcc-internal-format
 msgid "reading input file"
 msgstr ""
 
-#: lto-wrapper.c:857
+#: lto-wrapper.c:858
 #, gcc-internal-format
 msgid "writing output file"
 msgstr ""
 
-#: lto-wrapper.c:889
+#: lto-wrapper.c:890
 #, gcc-internal-format
 msgid "installation error, can't find crtoffloadtable.o"
 msgstr ""
 
-#: lto-wrapper.c:1000 lto-wrapper.c:1012
+#: lto-wrapper.c:1001 lto-wrapper.c:1013
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: %s\n"
 msgstr "%s: %s\n"
 
-#: lto-wrapper.c:1056
+#: lto-wrapper.c:1064
 #, gcc-internal-format
 msgid "environment variable COLLECT_GCC must be set"
 msgstr ""
 
-#: lto-wrapper.c:1060 config/nvptx/mkoffload.c:363
+#: lto-wrapper.c:1068 config/nvptx/mkoffload.c:363
 #, gcc-internal-format
 msgid "environment variable COLLECT_GCC_OPTIONS must be set"
 msgstr ""
 
-#: lto-wrapper.c:1229 lto-wrapper.c:1285
+#: lto-wrapper.c:1237 lto-wrapper.c:1293
 #, gcc-internal-format
 msgid "cannot open %s: %m"
 msgstr "не вдалося відкрити %s: %m"
 
-#: lto-wrapper.c:1232 lto-wrapper.c:1291
+#: lto-wrapper.c:1240 lto-wrapper.c:1299
 #, gcc-internal-format
 msgid "cannot read %s: %m"
 msgstr "не вдалося прочитати %s: %m"
 
-#: lto-wrapper.c:1259
+#: lto-wrapper.c:1267
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid format of %s"
 msgstr "некоректний формат %s"
 
-#: lto-wrapper.c:1482
+#: lto-wrapper.c:1491
 #, gcc-internal-format
 msgid "fopen: %s: %m"
 msgstr ""
 
+#: lto-wrapper.c:1508
+#, gcc-internal-format, gfc-internal-format
+msgid "Corrupted ltrans output file %s"
+msgstr "Пошкоджений файл виведення ltrans %s"
+
 #: multiple_target.c:76
 #, gcc-internal-format
 msgid "the call requires ifunc, which is not supported by this target"
@@ -20460,12 +20476,12 @@
 msgid "unrecognized argument in option %qs"
 msgstr ""
 
-#: opts-common.c:1198 config/i386/i386.c:3206
+#: opts-common.c:1198 config/i386/i386.c:3209
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr ""
 
-#: opts-common.c:1201 config/i386/i386.c:3209
+#: opts-common.c:1201 config/i386/i386.c:3212
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr ""
@@ -21051,22 +21067,22 @@
 msgid "output operand %d must use %<&%> constraint"
 msgstr ""
 
-#: regcprop.c:1187
+#: regcprop.c:1193
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad next_regno for empty chain (%u)"
 msgstr ""
 
-#: regcprop.c:1199
+#: regcprop.c:1205
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: Loop in regno chain (%u)"
 msgstr ""
 
-#: regcprop.c:1202
+#: regcprop.c:1208
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad oldest_regno (%u)"
 msgstr ""
 
-#: regcprop.c:1214
+#: regcprop.c:1220
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Non-empty reg in chain (%s %u %i)"
 msgstr ""
@@ -21110,7 +21126,7 @@
 msgstr ""
 
 #: reginfo.c:789 config/powerpcspe/powerpcspe.c:32259
-#: config/rs6000/rs6000.c:29453
+#: config/rs6000/rs6000.c:29530
 #, gcc-internal-format
 msgid "conflicts with %qD"
 msgstr ""
@@ -21355,152 +21371,157 @@
 msgid "function symbol is not function"
 msgstr ""
 
-#: symtab.c:1006
+#: symtab.c:1005
 #, gcc-internal-format
+msgid "inconsistent `ifunc' attribute"
+msgstr ""
+
+#: symtab.c:1013
+#, gcc-internal-format
 msgid "variable symbol is not variable"
 msgstr ""
 
-#: symtab.c:1012
+#: symtab.c:1019
 #, gcc-internal-format
 msgid "node has unknown type"
 msgstr ""
 
-#: symtab.c:1021
+#: symtab.c:1028
 #, gcc-internal-format
 msgid "node not found node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.c:1029
+#: symtab.c:1036
 #, gcc-internal-format
 msgid "node differs from node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.c:1038
+#: symtab.c:1045
 #, gcc-internal-format
 msgid "assembler name hash list corrupted"
 msgstr ""
 
-#: symtab.c:1051
+#: symtab.c:1058
 #, gcc-internal-format
 msgid "node not found in symtab assembler name hash"
 msgstr ""
 
-#: symtab.c:1058
+#: symtab.c:1065
 #, gcc-internal-format
 msgid "double linked list of assembler names corrupted"
 msgstr ""
 
-#: symtab.c:1063
+#: symtab.c:1070
 #, gcc-internal-format
 msgid "node has body_removed but is definition"
 msgstr ""
 
-#: symtab.c:1068
+#: symtab.c:1075
 #, gcc-internal-format
 msgid "node is analyzed but it is not a definition"
 msgstr ""
 
-#: symtab.c:1073
+#: symtab.c:1080
 #, gcc-internal-format
 msgid "node is alias but not implicit alias"
 msgstr ""
 
-#: symtab.c:1078
+#: symtab.c:1085
 #, gcc-internal-format
 msgid "node is alias but not definition"
 msgstr ""
 
-#: symtab.c:1083
+#: symtab.c:1090
 #, gcc-internal-format
 msgid "node is weakref but not an transparent_alias"
 msgstr ""
 
-#: symtab.c:1088
+#: symtab.c:1095
 #, gcc-internal-format
 msgid "node is transparent_alias but not an alias"
 msgstr ""
 
-#: symtab.c:1097
+#: symtab.c:1104
 #, gcc-internal-format
 msgid "node is in same_comdat_group list but has no comdat_group"
 msgstr ""
 
-#: symtab.c:1102
+#: symtab.c:1109
 #, gcc-internal-format
 msgid "same_comdat_group list across different groups"
 msgstr ""
 
-#: symtab.c:1107
+#: symtab.c:1114
 #, gcc-internal-format
 msgid "mixing different types of symbol in same comdat groups is not supported"
 msgstr ""
 
-#: symtab.c:1112
+#: symtab.c:1119
 #, gcc-internal-format
 msgid "node is alone in a comdat group"
 msgstr ""
 
-#: symtab.c:1119
+#: symtab.c:1126
 #, gcc-internal-format
 msgid "same_comdat_group is not a circular list"
 msgstr ""
 
-#: symtab.c:1134
+#: symtab.c:1141
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local symbol referred to by %s outside its comdat"
 msgstr ""
 
-#: symtab.c:1144
+#: symtab.c:1151
 #, gcc-internal-format
 msgid "implicit_section flag is set but section isn't"
 msgstr ""
 
-#: symtab.c:1151
+#: symtab.c:1158
 #, gcc-internal-format
 msgid "Both section and comdat group is set"
 msgstr ""
 
-#: symtab.c:1163
+#: symtab.c:1170
 #, gcc-internal-format
 msgid "Alias and target's section differs"
 msgstr ""
 
-#: symtab.c:1170
+#: symtab.c:1177
 #, gcc-internal-format
 msgid "Alias and target's comdat groups differs"
 msgstr ""
 
-#: symtab.c:1185
+#: symtab.c:1192
 #, gcc-internal-format
 msgid "Transparent alias and target's assembler names differs"
 msgstr ""
 
-#: symtab.c:1193
+#: symtab.c:1200
 #, gcc-internal-format
 msgid "Chained transparent aliases"
 msgstr ""
 
-#: symtab.c:1216 symtab.c:1253
+#: symtab.c:1223 symtab.c:1260
 #, gcc-internal-format
 msgid "symtab_node::verify failed"
 msgstr ""
 
-#: symtab.c:1249
+#: symtab.c:1256
 #, gcc-internal-format
 msgid "Two symbols with same comdat_group are not linked by the same_comdat_group list."
 msgstr ""
 
-#: symtab.c:1658
+#: symtab.c:1665
 #, gcc-internal-format
 msgid "function %q+D part of alias cycle"
 msgstr ""
 
-#: symtab.c:1660
+#: symtab.c:1667
 #, gcc-internal-format
 msgid "variable %q+D part of alias cycle"
 msgstr ""
 
-#: symtab.c:1688
+#: symtab.c:1695
 #, gcc-internal-format
 msgid "section of alias %q+D must match section of its target"
 msgstr ""
@@ -22301,7 +22322,7 @@
 msgid "the first argument of a VEC_COND_EXPR must be of a boolean vector type of the same number of elements as the result"
 msgstr ""
 
-#: tree-cfg.c:4395 c/c-typeck.c:5212
+#: tree-cfg.c:4395 c/c-typeck.c:5217
 #, gcc-internal-format
 msgid "type mismatch in conditional expression"
 msgstr ""
@@ -22651,22 +22672,22 @@
 msgid "missing edge %i->%i"
 msgstr ""
 
-#: tree-cfg.c:9379
+#: tree-cfg.c:9388
 #, gcc-internal-format
 msgid "%<noreturn%> function does return"
 msgstr ""
 
-#: tree-cfg.c:9400 tree-cfg.c:9432
+#: tree-cfg.c:9409 tree-cfg.c:9441
 #, gcc-internal-format
 msgid "control reaches end of non-void function"
 msgstr ""
 
-#: tree-cfg.c:9498 cp/cvt.c:1039
+#: tree-cfg.c:9507 cp/cvt.c:1039
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgstr ""
 
-#: tree-cfg.c:9503 cp/cvt.c:1046
+#: tree-cfg.c:9512 cp/cvt.c:1046
 #, gcc-internal-format
 msgid "ignoring return value of function declared with attribute warn_unused_result"
 msgstr ""
@@ -22931,7 +22952,7 @@
 msgid "stmt volatile flag not up-to-date"
 msgstr ""
 
-#: tree-ssa-strlen.c:1975
+#: tree-ssa-strlen.c:1999
 msgid "%G%qD output truncated before terminating nul copying %E byte from a string of the same length"
 msgid_plural "%G%qD output truncated before terminating nul copying %E bytes from a string of the same length"
 msgstr[0] ""
@@ -22938,7 +22959,7 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: tree-ssa-strlen.c:1989
+#: tree-ssa-strlen.c:2013
 msgid "%G%qD output truncated copying %E byte from a string of length %wu"
 msgid_plural "%G%qD output truncated copying %E bytes from a string of length %wu"
 msgstr[0] ""
@@ -22945,11 +22966,11 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: tree-ssa-strlen.c:1996
+#: tree-ssa-strlen.c:2020
 msgid "%G%qD output truncated copying between %wu and %wu bytes from a string of length %wu"
 msgstr ""
 
-#: tree-ssa-strlen.c:2008
+#: tree-ssa-strlen.c:2032
 msgid "%G%qD output may be truncated copying %E byte from a string of length %wu"
 msgid_plural "%G%qD output may be truncated copying %E bytes from a string of length %wu"
 msgstr[0] ""
@@ -22956,24 +22977,24 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: tree-ssa-strlen.c:2015 tree-ssa-strlen.c:2029
+#: tree-ssa-strlen.c:2039 tree-ssa-strlen.c:2053
 msgid "%G%qD output may be truncated copying between %wu and %wu bytes from a string of length %wu"
 msgstr ""
 
-#: tree-ssa-strlen.c:2150
+#: tree-ssa-strlen.c:2174
 msgid "%G%qD output truncated before terminating nul copying as many bytes from a string as its length"
 msgstr ""
 
-#: tree-ssa-strlen.c:2156
+#: tree-ssa-strlen.c:2180
 msgid "%G%qD specified bound depends on the length of the source argument"
 msgstr ""
 
-#: tree-ssa-strlen.c:2163
+#: tree-ssa-strlen.c:2187
 #, gcc-internal-format
 msgid "length computed here"
 msgstr "довжину обчислено тут:"
 
-#: tree-ssa-uninit.c:191 varasm.c:331
+#: tree-ssa-uninit.c:191 varasm.c:342
 #, gcc-internal-format
 msgid "%qD was declared here"
 msgstr "%qD було оголошено тут:"
@@ -23148,27 +23169,27 @@
 msgid "target specific builtin not available"
 msgstr ""
 
-#: tree-vect-generic.c:287
+#: tree-vect-generic.c:283
 #, gcc-internal-format
 msgid "vector operation will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-generic.c:290
+#: tree-vect-generic.c:286
 #, gcc-internal-format
 msgid "vector operation will be expanded in parallel"
 msgstr ""
 
-#: tree-vect-generic.c:341
+#: tree-vect-generic.c:337
 #, gcc-internal-format
 msgid "vector operation will be expanded with a single scalar operation"
 msgstr ""
 
-#: tree-vect-generic.c:941
+#: tree-vect-generic.c:937
 #, gcc-internal-format
 msgid "vector condition will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-generic.c:1373
+#: tree-vect-generic.c:1369
 #, gcc-internal-format
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr ""
@@ -23178,27 +23199,27 @@
 msgid "vectorization did not happen for a simd loop"
 msgstr ""
 
-#: tree-vrp.c:4930 tree-vrp.c:4974
+#: tree-vrp.c:4931 tree-vrp.c:4975
 #, gcc-internal-format
 msgid "array subscript %E is above array bounds of %qT"
 msgstr ""
 
-#: tree-vrp.c:4956
+#: tree-vrp.c:4957
 #, gcc-internal-format
 msgid "array subscript [%E, %E] is outside array bounds of %qT"
 msgstr ""
 
-#: tree-vrp.c:4988
+#: tree-vrp.c:4989
 #, gcc-internal-format
 msgid "array subscript %E is below array bounds of %qT"
 msgstr ""
 
-#: tree-vrp.c:5046
+#: tree-vrp.c:5047
 #, gcc-internal-format
 msgid "array subscript %wi is below array bounds of %qT"
 msgstr ""
 
-#: tree-vrp.c:5060
+#: tree-vrp.c:5061
 #, gcc-internal-format
 msgid "array subscript %wu is above array bounds of %qT"
 msgstr ""
@@ -23213,92 +23234,92 @@
 msgid "side-effects element in no-side-effects CONSTRUCTOR"
 msgstr ""
 
-#: tree.c:7852
+#: tree.c:7856
 #, gcc-internal-format
 msgid "arrays of functions are not meaningful"
 msgstr ""
 
-#: tree.c:8019
+#: tree.c:8023
 #, gcc-internal-format
 msgid "function return type cannot be function"
 msgstr ""
 
-#: tree.c:9327 tree.c:9412 tree.c:9473
+#: tree.c:9331 tree.c:9416 tree.c:9477
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: %s, have %s in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9364
+#: tree.c:9368
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected none of %s, have %s in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9377
+#: tree.c:9381
 #, gcc-internal-format
 msgid "tree check: expected class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9426
+#: tree.c:9430
 #, gcc-internal-format
 msgid "tree check: did not expect class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9439
+#: tree.c:9443
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected omp_clause %s, have %s in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9499
+#: tree.c:9503
 #, gcc-internal-format
 msgid "tree check: expected tree that contains %qs structure, have %qs in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9513
+#: tree.c:9517
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_int_cst with %d elts in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9525
+#: tree.c:9529
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_vec with %d elts in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9538
+#: tree.c:9542
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of %s with %d operands in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9551
+#: tree.c:9555
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of omp_clause %s with %d operands in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:12446
+#: tree.c:12450
 #, gcc-internal-format
 msgid "%qD is deprecated: %s"
 msgstr "%qD вважається застарілим: %s"
 
-#: tree.c:12449
+#: tree.c:12453
 #, gcc-internal-format
 msgid "%qD is deprecated"
 msgstr "%qD вважається застарілим"
 
-#: tree.c:12473 tree.c:12495
+#: tree.c:12477 tree.c:12499
 #, gcc-internal-format
 msgid "%qE is deprecated: %s"
 msgstr "%qE вважається застарілим: %s"
 
-#: tree.c:12476 tree.c:12498
+#: tree.c:12480 tree.c:12502
 #, gcc-internal-format
 msgid "%qE is deprecated"
 msgstr "%qE вважається застарілим"
 
-#: tree.c:12482 tree.c:12503
+#: tree.c:12486 tree.c:12507
 #, gcc-internal-format, gfc-internal-format
 msgid "type is deprecated: %s"
 msgstr "тип вважається застарілим: %s"
 
-#: tree.c:12485 tree.c:12506
+#: tree.c:12489 tree.c:12510
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr "тип вважається застарілим"
@@ -23323,242 +23344,242 @@
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.c:13043
+#: tree.c:13047
 #, gcc-internal-format, gfc-internal-format
 msgid "type variant differs by %s"
 msgstr ""
 
-#: tree.c:13084
+#: tree.c:13088
 #, gcc-internal-format
 msgid "type variant has different TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13086
+#: tree.c:13090
 #, gcc-internal-format
 msgid "type variant's TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13088
+#: tree.c:13092
 #, gcc-internal-format
 msgid "type's TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13108
+#: tree.c:13112
 #, gcc-internal-format
 msgid "type variant with TYPE_ALIAS_SET_KNOWN_P"
 msgstr ""
 
-#: tree.c:13121
+#: tree.c:13125
 #, gcc-internal-format
 msgid "type variant has different TYPE_VFIELD"
 msgstr ""
 
-#: tree.c:13157
+#: tree.c:13161
 #, gcc-internal-format
 msgid "type variant has different TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13159
+#: tree.c:13163
 #, gcc-internal-format
 msgid "type variant's TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13161
+#: tree.c:13165
 #, gcc-internal-format
 msgid "type's TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13199
+#: tree.c:13203
 #, gcc-internal-format
 msgid "type variant has different TYPE_FIELDS"
 msgstr ""
 
-#: tree.c:13201
+#: tree.c:13205
 #, gcc-internal-format
 msgid "first mismatch is field"
 msgstr ""
 
-#: tree.c:13203
+#: tree.c:13207
 #, gcc-internal-format
 msgid "and field"
 msgstr ""
 
-#: tree.c:13220
+#: tree.c:13224
 #, gcc-internal-format
 msgid "type variant has different TREE_TYPE"
 msgstr ""
 
-#: tree.c:13222 tree.c:13233
+#: tree.c:13226 tree.c:13237
 #, gcc-internal-format
 msgid "type variant's TREE_TYPE"
 msgstr ""
 
-#: tree.c:13224 tree.c:13235
+#: tree.c:13228 tree.c:13239
 #, gcc-internal-format
 msgid "type's TREE_TYPE"
 msgstr ""
 
-#: tree.c:13231
+#: tree.c:13235
 #, gcc-internal-format
 msgid "type is not compatible with its variant"
 msgstr ""
 
-#: tree.c:13534
+#: tree.c:13538
 #, gcc-internal-format
 msgid "Main variant is not defined"
 msgstr ""
 
-#: tree.c:13539
+#: tree.c:13543
 #, gcc-internal-format
 msgid "TYPE_MAIN_VARIANT has different TYPE_MAIN_VARIANT"
 msgstr ""
 
-#: tree.c:13551
+#: tree.c:13555
 #, gcc-internal-format
 msgid "TYPE_CANONICAL has different TYPE_CANONICAL"
 msgstr ""
 
-#: tree.c:13569
+#: tree.c:13573
 #, gcc-internal-format
 msgid "TYPE_CANONICAL is not compatible"
 msgstr ""
 
-#: tree.c:13577
+#: tree.c:13581
 #, gcc-internal-format
 msgid "TYPE_MODE of TYPE_CANONICAL is not compatible"
 msgstr ""
 
-#: tree.c:13583
+#: tree.c:13587
 #, gcc-internal-format
 msgid "TYPE_CANONICAL of main variant is not main variant"
 msgstr ""
 
-#: tree.c:13599
+#: tree.c:13603
 #, gcc-internal-format
 msgid "TYPE_VFIELD is not FIELD_DECL nor TREE_LIST"
 msgstr ""
 
-#: tree.c:13609
+#: tree.c:13613
 #, gcc-internal-format
 msgid "TYPE_NEXT_PTR_TO is not POINTER_TYPE"
 msgstr ""
 
-#: tree.c:13619
+#: tree.c:13623
 #, gcc-internal-format
 msgid "TYPE_NEXT_REF_TO is not REFERENCE_TYPE"
 msgstr ""
 
-#: tree.c:13640
+#: tree.c:13644
 #, gcc-internal-format
 msgid "TYPE_BINFO is not TREE_BINFO"
 msgstr ""
 
-#: tree.c:13646
+#: tree.c:13650
 #, gcc-internal-format
 msgid "TYPE_BINFO type is not TYPE_MAIN_VARIANT"
 msgstr ""
 
-#: tree.c:13657
+#: tree.c:13661
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not record nor union"
 msgstr ""
 
-#: tree.c:13668
+#: tree.c:13672
 #, gcc-internal-format
 msgid "TYPE_OFFSET_BASETYPE is not record nor union"
 msgstr ""
 
-#: tree.c:13686
+#: tree.c:13690
 #, gcc-internal-format
 msgid "TYPE_ARRAY_MAX_SIZE not INTEGER_CST"
 msgstr ""
 
-#: tree.c:13693
+#: tree.c:13697
 #, gcc-internal-format
 msgid "TYPE_MAX_VALUE_RAW non-NULL"
 msgstr ""
 
-#: tree.c:13700
+#: tree.c:13704
 #, gcc-internal-format
 msgid "TYPE_LANG_SLOT_1 (binfo) field is non-NULL"
 msgstr ""
 
-#: tree.c:13716
+#: tree.c:13720
 #, gcc-internal-format
 msgid "Enum value is not CONST_DECL or INTEGER_CST"
 msgstr ""
 
-#: tree.c:13724
+#: tree.c:13728
 #, gcc-internal-format
 msgid "Enum value type is not INTEGER_TYPE nor convertible to the enum"
 msgstr ""
 
-#: tree.c:13731
+#: tree.c:13735
 #, gcc-internal-format
 msgid "Enum value name is not IDENTIFIER_NODE"
 msgstr ""
 
-#: tree.c:13741
+#: tree.c:13745
 #, gcc-internal-format
 msgid "Array TYPE_DOMAIN is not integer type"
 msgstr ""
 
-#: tree.c:13750
+#: tree.c:13754
 #, gcc-internal-format
 msgid "TYPE_FIELDS defined in incomplete type"
 msgstr ""
 
-#: tree.c:13772
+#: tree.c:13776
 #, gcc-internal-format
 msgid "Wrong tree in TYPE_FIELDS list"
 msgstr ""
 
-#: tree.c:13787
+#: tree.c:13791
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is %i while TYPE_CACHED_VALUES is %p"
 msgstr ""
 
-#: tree.c:13793
+#: tree.c:13797
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES is not TREE_VEC"
 msgstr ""
 
-#: tree.c:13806
+#: tree.c:13810
 #, gcc-internal-format
 msgid "wrong TYPE_CACHED_VALUES entry"
 msgstr ""
 
-#: tree.c:13819
+#: tree.c:13823
 #, gcc-internal-format
 msgid "TREE_PURPOSE is non-NULL in TYPE_ARG_TYPES list"
 msgstr ""
 
-#: tree.c:13825
+#: tree.c:13829
 #, gcc-internal-format
 msgid "Wrong entry in TYPE_ARG_TYPES list"
 msgstr ""
 
-#: tree.c:13832
+#: tree.c:13836
 #, gcc-internal-format
 msgid "TYPE_VALUES_RAW field is non-NULL"
 msgstr ""
 
-#: tree.c:13844
+#: tree.c:13848
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is set while it should not"
 msgstr ""
 
-#: tree.c:13850
+#: tree.c:13854
 #, gcc-internal-format
 msgid "TYPE_STRING_FLAG is set on wrong type code"
 msgstr ""
 
-#: tree.c:13860
+#: tree.c:13864
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not main variant"
 msgstr ""
 
-#: tree.c:13867
+#: tree.c:13871
 #, gcc-internal-format
 msgid "verify_type failed"
 msgstr "помилка verify_type"
@@ -23583,182 +23604,182 @@
 msgid "corrupted value profile: %s profile counter (%d out of %d) inconsistent with basic-block count (%d)"
 msgstr ""
 
-#: var-tracking.c:7166
+#: var-tracking.c:7184
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded with -fvar-tracking-assignments, retrying without"
 msgstr ""
 
-#: var-tracking.c:7170
+#: var-tracking.c:7188
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded"
 msgstr ""
 
-#: varasm.c:326
+#: varasm.c:337
 #, gcc-internal-format
 msgid "%+qD causes a section type conflict with %qD"
 msgstr ""
 
-#: varasm.c:329
+#: varasm.c:340
 #, gcc-internal-format
 msgid "section type conflict with %qD"
 msgstr ""
 
-#: varasm.c:334
+#: varasm.c:345
 #, gcc-internal-format
 msgid "%+qD causes a section type conflict"
 msgstr ""
 
-#: varasm.c:336
+#: varasm.c:347
 #, gcc-internal-format
 msgid "section type conflict"
 msgstr ""
 
-#: varasm.c:1019
+#: varasm.c:1030
 #, gcc-internal-format
 msgid "alignment of %q+D is greater than maximum object file alignment %d"
 msgstr ""
 
-#: varasm.c:1172
+#: varasm.c:1183
 #, gcc-internal-format
 msgid "only zero initializers are allowed in section %qs"
 msgstr ""
 
-#: varasm.c:1378 varasm.c:1387
+#: varasm.c:1389 varasm.c:1398
 #, gcc-internal-format
 msgid "register name not specified for %q+D"
 msgstr ""
 
-#: varasm.c:1389
+#: varasm.c:1400
 #, gcc-internal-format
 msgid "invalid register name for %q+D"
 msgstr ""
 
-#: varasm.c:1391
+#: varasm.c:1402
 #, gcc-internal-format
 msgid "data type of %q+D isn%'t suitable for a register"
 msgstr ""
 
-#: varasm.c:1394
+#: varasm.c:1405
 #, gcc-internal-format
 msgid "the register specified for %q+D cannot be accessed by the current target"
 msgstr ""
 
-#: varasm.c:1397
+#: varasm.c:1408
 #, gcc-internal-format
 msgid "the register specified for %q+D is not general enough to be used as a register variable"
 msgstr ""
 
-#: varasm.c:1400
+#: varasm.c:1411
 #, gcc-internal-format
 msgid "register specified for %q+D isn%'t suitable for data type"
 msgstr ""
 
-#: varasm.c:1410
+#: varasm.c:1421
 #, gcc-internal-format
 msgid "global register variable has initial value"
 msgstr ""
 
-#: varasm.c:1414
+#: varasm.c:1425
 #, gcc-internal-format
 msgid "optimization may eliminate reads and/or writes to register variables"
 msgstr ""
 
-#: varasm.c:1460
+#: varasm.c:1471
 #, gcc-internal-format
 msgid "register name given for non-register variable %q+D"
 msgstr ""
 
-#: varasm.c:1870
+#: varasm.c:1881
 #, gcc-internal-format
 msgid "Patchable function entry > size"
 msgstr ""
 
-#: varasm.c:2069
+#: varasm.c:2080
 #, gcc-internal-format
 msgid "thread-local COMMON data not implemented"
 msgstr ""
 
-#: varasm.c:2102
+#: varasm.c:2113
 #, gcc-internal-format
 msgid "requested alignment for %q+D is greater than implemented alignment of %wu"
 msgstr ""
 
-#: varasm.c:2205 c/c-decl.c:5027 c/c-parser.c:1534
+#: varasm.c:2216 c/c-decl.c:5027 c/c-parser.c:1534
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t known"
 msgstr ""
 
-#: varasm.c:4910
+#: varasm.c:4921
 #, gcc-internal-format
 msgid "initializer for integer/fixed-point value is too complicated"
 msgstr ""
 
-#: varasm.c:4915
+#: varasm.c:4926
 #, gcc-internal-format
 msgid "initializer for floating value is not a floating constant"
 msgstr ""
 
-#: varasm.c:5227
+#: varasm.c:5238
 #, gcc-internal-format
 msgid "invalid initial value for member %qE"
 msgstr ""
 
-#: varasm.c:5487
+#: varasm.c:5498
 #, gcc-internal-format
 msgid "%+qD declared weak after being used"
 msgstr ""
 
-#: varasm.c:5539
+#: varasm.c:5550
 #, gcc-internal-format
 msgid "weak declaration of %q+D being applied to a already existing, static definition"
 msgstr ""
 
-#: varasm.c:5575
+#: varasm.c:5586
 #, gcc-internal-format
 msgid "weak declaration of %q+D must be public"
 msgstr ""
 
-#: varasm.c:5579
+#: varasm.c:5590
 #, gcc-internal-format
 msgid "weak declaration of %q+D not supported"
 msgstr ""
 
-#: varasm.c:5608 varasm.c:5912
+#: varasm.c:5619 varasm.c:5926
 #, gcc-internal-format
 msgid "only weak aliases are supported in this configuration"
 msgstr ""
 
-#: varasm.c:5802
+#: varasm.c:5813
 #, gcc-internal-format
 msgid "weakref is not supported in this configuration"
 msgstr ""
 
-#: varasm.c:5834
+#: varasm.c:5846
 #, gcc-internal-format
 msgid "ifunc is not supported on this target"
 msgstr ""
 
-#: varasm.c:5892
+#: varasm.c:5904
 #, gcc-internal-format
 msgid "weakref %q+D ultimately targets itself"
 msgstr ""
 
-#: varasm.c:5894
+#: varasm.c:5906
 #, gcc-internal-format
 msgid "weakref %q+D must have static linkage"
 msgstr ""
 
-#: varasm.c:5901
+#: varasm.c:5913
 #, gcc-internal-format
 msgid "alias definitions not supported in this configuration"
 msgstr ""
 
-#: varasm.c:5909
+#: varasm.c:5923
 #, gcc-internal-format
 msgid "ifunc is not supported in this configuration"
 msgstr ""
 
-#: varasm.c:6127 config/sol2.c:159 config/i386/winnt.c:265
+#: varasm.c:6141 config/sol2.c:159 config/i386/winnt.c:265
 #, gcc-internal-format
 msgid "visibility attribute not supported in this configuration; ignored"
 msgstr ""
@@ -23834,466 +23855,471 @@
 msgid "bytecode stream: tag %s is not in the expected range [%s, %s]"
 msgstr ""
 
-#: c-family/c-attribs.c:529
+#: c-family/c-attribs.c:524
 #, gcc-internal-format
+msgid "%qE attribute ignored for type %qT"
+msgstr "Атрибут %qE для типу %qT проігноровано"
+
+#: c-family/c-attribs.c:536
+#, gcc-internal-format
 msgid "%qE attribute ignored for field of type %qT"
 msgstr ""
 
-#: c-family/c-attribs.c:696
+#: c-family/c-attribs.c:706
 #, gcc-internal-format
 msgid "no_sanitize argument not a string"
 msgstr ""
 
-#: c-family/c-attribs.c:826 ada/gcc-interface/utils.c:6235
+#: c-family/c-attribs.c:837 ada/gcc-interface/utils.c:6240
 #, gcc-internal-format
 msgid "%qE attribute ignored due to conflict with attribute %qs"
 msgstr ""
 
-#: c-family/c-attribs.c:875
+#: c-family/c-attribs.c:886
 #, gcc-internal-format
 msgid "%qE attribute ignored. Use -fcf-protection option to enable it"
 msgstr ""
 
-#: c-family/c-attribs.c:914 c-family/c-attribs.c:920 c-family/c-attribs.c:3388
-#: c-family/c-attribs.c:3423 c-family/c-attribs.c:3429
+#: c-family/c-attribs.c:925 c-family/c-attribs.c:931 c-family/c-attribs.c:3399
+#: c-family/c-attribs.c:3434 c-family/c-attribs.c:3440
 #, gcc-internal-format
 msgid "%qE attribute ignored due to conflict with %qs attribute"
 msgstr ""
 
-#: c-family/c-attribs.c:976 brig/brig-lang.c:482 lto/lto-lang.c:288
+#: c-family/c-attribs.c:987 brig/brig-lang.c:482 lto/lto-lang.c:288
 #, gcc-internal-format
 msgid "%qE attribute has no effect on unit local functions"
 msgstr ""
 
-#: c-family/c-attribs.c:1130
+#: c-family/c-attribs.c:1141
 #, gcc-internal-format
 msgid "%qE attribute have effect only on public objects"
 msgstr ""
 
-#: c-family/c-attribs.c:1159
+#: c-family/c-attribs.c:1170
 #, gcc-internal-format
 msgid "%qE attribute only affects top level objects"
 msgstr ""
 
-#: c-family/c-attribs.c:1198 c-family/c-attribs.c:2682
+#: c-family/c-attribs.c:1209 c-family/c-attribs.c:2693
 #, gcc-internal-format
 msgid "%qE attribute on function returning %<void%>"
 msgstr "атрибут %qE на функції, яка повертає %<void%>"
 
-#: c-family/c-attribs.c:1221 c-family/c-pragma.c:419
+#: c-family/c-attribs.c:1232 c-family/c-pragma.c:419
 #, gcc-internal-format
 msgid "scalar_storage_order is not supported because endianness is not uniform"
 msgstr ""
 
-#: c-family/c-attribs.c:1238
+#: c-family/c-attribs.c:1249
 #, gcc-internal-format
 msgid "scalar_storage_order argument must be one of \"big-endian\" or \"little-endian\""
 msgstr ""
 
-#: c-family/c-attribs.c:1334
+#: c-family/c-attribs.c:1345
 #, gcc-internal-format
 msgid "destructor priorities are not supported"
 msgstr ""
 
-#: c-family/c-attribs.c:1336
+#: c-family/c-attribs.c:1347
 #, gcc-internal-format
 msgid "constructor priorities are not supported"
 msgstr ""
 
-#: c-family/c-attribs.c:1358
+#: c-family/c-attribs.c:1369
 #, gcc-internal-format, gfc-internal-format
 msgid "destructor priorities from 0 to %d are reserved for the implementation"
 msgstr ""
 
-#: c-family/c-attribs.c:1363
+#: c-family/c-attribs.c:1374
 #, gcc-internal-format, gfc-internal-format
 msgid "constructor priorities from 0 to %d are reserved for the implementation"
 msgstr ""
 
-#: c-family/c-attribs.c:1371
+#: c-family/c-attribs.c:1382
 #, gcc-internal-format, gfc-internal-format
 msgid "destructor priorities must be integers from 0 to %d inclusive"
 msgstr ""
 
-#: c-family/c-attribs.c:1374
+#: c-family/c-attribs.c:1385
 #, gcc-internal-format, gfc-internal-format
 msgid "constructor priorities must be integers from 0 to %d inclusive"
 msgstr ""
 
-#: c-family/c-attribs.c:1527
+#: c-family/c-attribs.c:1538
 #, gcc-internal-format
 msgid "unknown machine mode %qE"
 msgstr ""
 
-#: c-family/c-attribs.c:1557
+#: c-family/c-attribs.c:1568
 #, gcc-internal-format
 msgid "specifying vector types with __attribute__ ((mode)) is deprecated"
 msgstr ""
 
-#: c-family/c-attribs.c:1560
+#: c-family/c-attribs.c:1571
 #, gcc-internal-format
 msgid "use __attribute__ ((vector_size)) instead"
 msgstr ""
 
-#: c-family/c-attribs.c:1569
+#: c-family/c-attribs.c:1580
 #, gcc-internal-format
 msgid "unable to emulate %qs"
 msgstr ""
 
-#: c-family/c-attribs.c:1582
+#: c-family/c-attribs.c:1593
 #, gcc-internal-format
 msgid "invalid pointer mode %qs"
 msgstr ""
 
-#: c-family/c-attribs.c:1599
+#: c-family/c-attribs.c:1610
 #, gcc-internal-format
 msgid "signedness of type and machine mode %qs don%'t match"
 msgstr ""
 
-#: c-family/c-attribs.c:1610
+#: c-family/c-attribs.c:1621
 #, gcc-internal-format
 msgid "no data type for mode %qs"
 msgstr ""
 
-#: c-family/c-attribs.c:1620
+#: c-family/c-attribs.c:1631
 #, gcc-internal-format
 msgid "cannot use mode %qs for enumeral types"
 msgstr ""
 
-#: c-family/c-attribs.c:1647
+#: c-family/c-attribs.c:1658
 #, gcc-internal-format
 msgid "mode %qs applied to inappropriate type"
 msgstr ""
 
-#: c-family/c-attribs.c:1669
+#: c-family/c-attribs.c:1680
 #, gcc-internal-format
 msgid "section attributes are not supported for this target"
 msgstr ""
 
-#: c-family/c-attribs.c:1675
+#: c-family/c-attribs.c:1686
 #, gcc-internal-format
 msgid "section attribute not allowed for %q+D"
 msgstr ""
 
-#: c-family/c-attribs.c:1681
+#: c-family/c-attribs.c:1692
 #, gcc-internal-format
 msgid "section attribute argument not a string constant"
 msgstr ""
 
-#: c-family/c-attribs.c:1690
+#: c-family/c-attribs.c:1701
 #, gcc-internal-format
 msgid "section attribute cannot be specified for local variables"
 msgstr ""
 
-#: c-family/c-attribs.c:1700 config/bfin/bfin.c:4806 config/bfin/bfin.c:4857
+#: c-family/c-attribs.c:1711 config/bfin/bfin.c:4806 config/bfin/bfin.c:4857
 #: config/bfin/bfin.c:4883 config/bfin/bfin.c:4896
 #, gcc-internal-format
 msgid "section of %q+D conflicts with previous declaration"
 msgstr ""
 
-#: c-family/c-attribs.c:1708
+#: c-family/c-attribs.c:1719
 #, gcc-internal-format
 msgid "section of %q+D cannot be overridden"
 msgstr ""
 
-#: c-family/c-attribs.c:1773
+#: c-family/c-attribs.c:1784
 #, gcc-internal-format, gfc-internal-format
 msgid "requested alignment %d is larger than %d"
 msgstr ""
 
-#: c-family/c-attribs.c:1866
+#: c-family/c-attribs.c:1877
 #, gcc-internal-format
 msgid "alignment may not be specified for %q+D"
 msgstr ""
 
-#: c-family/c-attribs.c:1886
+#: c-family/c-attribs.c:1897
 #, gcc-internal-format
 msgid "ignoring attribute %<%E (%u)%> because it conflicts with attribute %<%E (%u)%>"
 msgstr ""
 
 #. Do not error out for attribute warn_if_not_aligned.
-#: c-family/c-attribs.c:1891 c-family/c-attribs.c:1920
+#: c-family/c-attribs.c:1902 c-family/c-attribs.c:1931
 #, gcc-internal-format
 msgid "alignment for %q+D must be at least %d"
 msgstr ""
 
-#: c-family/c-attribs.c:1916
+#: c-family/c-attribs.c:1927
 #, gcc-internal-format
 msgid "alignment for %q+D was previously specified as %d and may not be decreased"
 msgstr ""
 
-#: c-family/c-attribs.c:1943
+#: c-family/c-attribs.c:1954
 #, gcc-internal-format
 msgid "%<warn_if_not_aligned%> may not be specified for %q+D"
 msgstr ""
 
-#: c-family/c-attribs.c:1986
+#: c-family/c-attribs.c:1997
 #, gcc-internal-format
 msgid "inline function %q+D declared weak"
 msgstr ""
 
-#: c-family/c-attribs.c:1991
+#: c-family/c-attribs.c:2002
 #, gcc-internal-format
 msgid "indirect function %q+D cannot be declared weak"
 msgstr ""
 
-#: c-family/c-attribs.c:2015
+#: c-family/c-attribs.c:2026
 #, gcc-internal-format
 msgid "%qE attribute is only applicable on functions"
 msgstr ""
 
-#: c-family/c-attribs.c:2046
+#: c-family/c-attribs.c:2057
 #, gcc-internal-format
 msgid "%q+D defined both normally and as %qE attribute"
 msgstr ""
 
-#: c-family/c-attribs.c:2054
+#: c-family/c-attribs.c:2065
 #, gcc-internal-format
 msgid "weak %q+D cannot be defined %qE"
 msgstr ""
 
-#: c-family/c-attribs.c:2071 c-family/c-attribs.c:2582
+#: c-family/c-attribs.c:2082 c-family/c-attribs.c:2593
 #, gcc-internal-format
 msgid "attribute %qE argument not a string"
 msgstr ""
 
-#: c-family/c-attribs.c:2106
+#: c-family/c-attribs.c:2117
 #, gcc-internal-format
 msgid "%+qD declared alias after being used"
 msgstr ""
 
-#: c-family/c-attribs.c:2108
+#: c-family/c-attribs.c:2119
 #, gcc-internal-format
 msgid "%+qD declared ifunc after being used"
 msgstr ""
 
-#: c-family/c-attribs.c:2159
+#: c-family/c-attribs.c:2170
 #, gcc-internal-format
 msgid "indirect function %q+D cannot be declared weakref"
 msgstr ""
 
-#: c-family/c-attribs.c:2181
+#: c-family/c-attribs.c:2192
 #, gcc-internal-format
 msgid "weakref attribute must appear before alias attribute"
 msgstr ""
 
-#: c-family/c-attribs.c:2193
+#: c-family/c-attribs.c:2204
 #, gcc-internal-format
 msgid "%+qD declared weakref after being used"
 msgstr ""
 
-#: c-family/c-attribs.c:2217
+#: c-family/c-attribs.c:2228
 #, gcc-internal-format
 msgid "%qE attribute ignored on non-class types"
 msgstr ""
 
-#: c-family/c-attribs.c:2223
+#: c-family/c-attribs.c:2234
 #, gcc-internal-format
 msgid "%qE attribute ignored because %qT is already defined"
 msgstr ""
 
-#: c-family/c-attribs.c:2236
+#: c-family/c-attribs.c:2247
 #, gcc-internal-format
 msgid "visibility argument not a string"
 msgstr ""
 
-#: c-family/c-attribs.c:2248
+#: c-family/c-attribs.c:2259
 #, gcc-internal-format
 msgid "%qE attribute ignored on types"
 msgstr ""
 
-#: c-family/c-attribs.c:2264
+#: c-family/c-attribs.c:2275
 #, gcc-internal-format
 msgid "visibility argument must be one of \"default\", \"hidden\", \"protected\" or \"internal\""
 msgstr ""
 
-#: c-family/c-attribs.c:2275
+#: c-family/c-attribs.c:2286
 #, gcc-internal-format
 msgid "%qD redeclared with different visibility"
 msgstr ""
 
-#: c-family/c-attribs.c:2278 c-family/c-attribs.c:2282
+#: c-family/c-attribs.c:2289 c-family/c-attribs.c:2293
 #, gcc-internal-format
 msgid "%qD was declared %qs which implies default visibility"
 msgstr ""
 
-#: c-family/c-attribs.c:2320
+#: c-family/c-attribs.c:2331
 #, gcc-internal-format
 msgid "tls_model argument not a string"
 msgstr ""
 
-#: c-family/c-attribs.c:2333
+#: c-family/c-attribs.c:2344
 #, gcc-internal-format
 msgid "tls_model argument must be one of \"local-exec\", \"initial-exec\", \"local-dynamic\" or \"global-dynamic\""
 msgstr ""
 
-#: c-family/c-attribs.c:2353 c-family/c-attribs.c:2656
-#: c-family/c-attribs.c:3497 config/m32c/m32c.c:2944
+#: c-family/c-attribs.c:2364 c-family/c-attribs.c:2667
+#: c-family/c-attribs.c:3508 config/m32c/m32c.c:2944
 #, gcc-internal-format
 msgid "%qE attribute applies only to functions"
 msgstr ""
 
-#: c-family/c-attribs.c:2417
+#: c-family/c-attribs.c:2428
 #, gcc-internal-format
 msgid "alloc_size parameter outside range"
 msgstr ""
 
-#: c-family/c-attribs.c:2443
+#: c-family/c-attribs.c:2454
 #, gcc-internal-format
 msgid "alloc_align parameter outside range"
 msgstr ""
 
-#: c-family/c-attribs.c:2467
+#: c-family/c-attribs.c:2478
 #, gcc-internal-format
 msgid "assume_aligned parameter not integer constant"
 msgstr ""
 
-#: c-family/c-attribs.c:2595
+#: c-family/c-attribs.c:2606
 #, gcc-internal-format
 msgid "only %<inbranch%> and %<notinbranch%> flags are allowed for %<__simd__%> attribute"
 msgstr ""
 
-#: c-family/c-attribs.c:2662 c-family/c-attribs.c:3503
+#: c-family/c-attribs.c:2673 c-family/c-attribs.c:3514
 #, gcc-internal-format
 msgid "can%'t set %qE attribute after definition"
 msgstr ""
 
-#: c-family/c-attribs.c:2727
+#: c-family/c-attribs.c:2738
 #, gcc-internal-format
 msgid "%qE attribute duplicated"
 msgstr ""
 
-#: c-family/c-attribs.c:2729
+#: c-family/c-attribs.c:2740
 #, gcc-internal-format
 msgid "%qE attribute follows %qE"
 msgstr ""
 
-#: c-family/c-attribs.c:2828
+#: c-family/c-attribs.c:2839
 #, gcc-internal-format
 msgid "type was previously declared %qE"
 msgstr ""
 
-#: c-family/c-attribs.c:2841 cp/class.c:4397
+#: c-family/c-attribs.c:2852 cp/class.c:4401
 #, gcc-internal-format
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
 msgstr ""
 
-#: c-family/c-attribs.c:2899
+#: c-family/c-attribs.c:2910
 #, gcc-internal-format
 msgid "%qE argument not an identifier"
 msgstr ""
 
-#: c-family/c-attribs.c:2910
+#: c-family/c-attribs.c:2921
 #, gcc-internal-format
 msgid "%qD is not compatible with %qD"
 msgstr ""
 
-#: c-family/c-attribs.c:2913
+#: c-family/c-attribs.c:2924
 #, gcc-internal-format
 msgid "%qE argument is not a function"
 msgstr ""
 
-#: c-family/c-attribs.c:2961
+#: c-family/c-attribs.c:2972
 #, gcc-internal-format
 msgid "deprecated message is not a string"
 msgstr ""
 
-#: c-family/c-attribs.c:3002
+#: c-family/c-attribs.c:3013
 #, gcc-internal-format
 msgid "%qE attribute ignored for %qE"
 msgstr ""
 
-#: c-family/c-attribs.c:3065
+#: c-family/c-attribs.c:3076
 #, gcc-internal-format
 msgid "invalid vector type for attribute %qE"
 msgstr ""
 
-#: c-family/c-attribs.c:3071 ada/gcc-interface/utils.c:3896
+#: c-family/c-attribs.c:3082 ada/gcc-interface/utils.c:3899
 #, gcc-internal-format
 msgid "vector size not an integral multiple of component size"
 msgstr ""
 
-#: c-family/c-attribs.c:3077 ada/gcc-interface/utils.c:3903
+#: c-family/c-attribs.c:3088 ada/gcc-interface/utils.c:3906
 #, gcc-internal-format
 msgid "zero vector size"
 msgstr ""
 
-#: c-family/c-attribs.c:3085
+#: c-family/c-attribs.c:3096
 #, gcc-internal-format
 msgid "number of components of the vector not a power of two"
 msgstr ""
 
-#: c-family/c-attribs.c:3118 ada/gcc-interface/utils.c:6092
+#: c-family/c-attribs.c:3129 ada/gcc-interface/utils.c:6098
 #, gcc-internal-format
 msgid "nonnull attribute without arguments on a non-prototype"
 msgstr ""
 
-#: c-family/c-attribs.c:3137 ada/gcc-interface/utils.c:6106
+#: c-family/c-attribs.c:3148 ada/gcc-interface/utils.c:6112
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument has invalid operand number (argument %lu)"
 msgstr ""
 
-#: c-family/c-attribs.c:3159 ada/gcc-interface/utils.c:6128
+#: c-family/c-attribs.c:3170 ada/gcc-interface/utils.c:6134
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument with out-of-range operand number (argument %lu, operand %lu)"
 msgstr ""
 
-#: c-family/c-attribs.c:3168 ada/gcc-interface/utils.c:6137
+#: c-family/c-attribs.c:3179 ada/gcc-interface/utils.c:6143
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument references non-pointer operand (argument %lu, operand %lu)"
 msgstr ""
 
-#: c-family/c-attribs.c:3208
+#: c-family/c-attribs.c:3219
 #, gcc-internal-format
 msgid "%qE attribute ignored on objects of type %qT"
 msgstr ""
 
-#: c-family/c-attribs.c:3216
+#: c-family/c-attribs.c:3227
 #, gcc-internal-format
 msgid "%qE attribute does not apply to functions"
 msgstr ""
 
-#: c-family/c-attribs.c:3273
+#: c-family/c-attribs.c:3284
 #, gcc-internal-format
 msgid "cleanup argument not an identifier"
 msgstr ""
 
-#: c-family/c-attribs.c:3280
+#: c-family/c-attribs.c:3291
 #, gcc-internal-format
 msgid "cleanup argument not a function"
 msgstr ""
 
-#: c-family/c-attribs.c:3317
+#: c-family/c-attribs.c:3328
 #, gcc-internal-format
 msgid "%qE attribute requires prototypes with named arguments"
 msgstr ""
 
-#: c-family/c-attribs.c:3325
+#: c-family/c-attribs.c:3336
 #, gcc-internal-format
 msgid "%qE attribute only applies to variadic functions"
 msgstr ""
 
-#: c-family/c-attribs.c:3341 ada/gcc-interface/utils.c:6179
+#: c-family/c-attribs.c:3352 ada/gcc-interface/utils.c:6185
 #, gcc-internal-format
 msgid "requested position is not an integer constant"
 msgstr ""
 
-#: c-family/c-attribs.c:3349 ada/gcc-interface/utils.c:6186
+#: c-family/c-attribs.c:3360 ada/gcc-interface/utils.c:6192
 #, gcc-internal-format
 msgid "requested position is less than zero"
 msgstr ""
 
-#: c-family/c-attribs.c:3404
+#: c-family/c-attribs.c:3415
 #, gcc-internal-format
 msgid "empty string in attribute %<target%>"
 msgstr ""
 
-#: c-family/c-attribs.c:3520
+#: c-family/c-attribs.c:3531
 #, gcc-internal-format
 msgid "returns_nonnull attribute on a function not returning a pointer"
 msgstr ""
 
-#: c-family/c-attribs.c:3535
+#: c-family/c-attribs.c:3546
 #, gcc-internal-format
 msgid "%qE attribute is only valid on %<struct%> type"
 msgstr ""
@@ -24338,12 +24364,12 @@
 msgid "__builtin_shuffle argument vector(s) inner type must have the same size as inner type of the mask"
 msgstr ""
 
-#: c-family/c-common.c:1262 c-family/c-warn.c:1194
+#: c-family/c-common.c:1262 c-family/c-warn.c:1202
 #, gcc-internal-format
 msgid "unsigned conversion from %qT to %qT changes value from %qE to %qE"
 msgstr ""
 
-#: c-family/c-common.c:1267 c-family/c-warn.c:1202
+#: c-family/c-common.c:1267 c-family/c-warn.c:1210
 #, gcc-internal-format
 msgid "unsigned conversion from %qT to %qT changes the value of %qE"
 msgstr ""
@@ -24473,7 +24499,7 @@
 msgid "suggest parentheses around assignment used as truth value"
 msgstr ""
 
-#: c-family/c-common.c:3518 c/c-decl.c:4325 c/c-decl.c:6430 c/c-typeck.c:14177
+#: c-family/c-common.c:3518 c/c-decl.c:4325 c/c-decl.c:6450 c/c-typeck.c:14182
 #, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr ""
@@ -24553,7 +24579,7 @@
 msgid "duplicate case value"
 msgstr "дублювання значення випадку"
 
-#: c-family/c-common.c:4867 c-family/c-warn.c:2216
+#: c-family/c-common.c:4867 c-family/c-warn.c:2225
 #, gcc-internal-format
 msgid "previously used here"
 msgstr ""
@@ -24598,193 +24624,193 @@
 msgid "missing sentinel in function call"
 msgstr ""
 
-#: c-family/c-common.c:5411
+#: c-family/c-common.c:5409
 #, gcc-internal-format, gfc-internal-format
 msgid "null argument where non-null required (argument %lu)"
 msgstr ""
 
-#: c-family/c-common.c:5506 c-family/c-common.c:5553
+#: c-family/c-common.c:5504 c-family/c-common.c:5551
 #, gcc-internal-format
 msgid "bad option %qs to attribute %<optimize%>"
 msgstr ""
 
-#: c-family/c-common.c:5509 c-family/c-common.c:5557
+#: c-family/c-common.c:5507 c-family/c-common.c:5555
 #, gcc-internal-format
 msgid "bad option %qs to pragma %<optimize%>"
 msgstr ""
 
-#: c-family/c-common.c:5589
+#: c-family/c-common.c:5587
 #, gcc-internal-format
 msgid "%<fallthrough%> attribute specified multiple times"
 msgstr ""
 
-#: c-family/c-common.c:5593
+#: c-family/c-common.c:5591
 #, gcc-internal-format
 msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr ""
 
-#: c-family/c-common.c:5733 c-family/c-common.c:6485 c-family/c-common.c:6558
+#: c-family/c-common.c:5731 c-family/c-common.c:6477 c-family/c-common.c:6550
 #: c/c-typeck.c:3555
 #, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr ""
 
-#: c-family/c-common.c:5738 c-family/c-common.c:6584 c/c-typeck.c:3284
+#: c-family/c-common.c:5736 c-family/c-common.c:6576 c/c-typeck.c:3284
 #, gcc-internal-format
 msgid "too many arguments to function %qE"
 msgstr ""
 
-#: c-family/c-common.c:5769
+#: c-family/c-common.c:5767
 #, gcc-internal-format
 msgid "third argument to function %qE must be a constant integer"
 msgstr ""
 
-#: c-family/c-common.c:5794
+#: c-family/c-common.c:5792
 #, gcc-internal-format
 msgid "second argument to function %qE must be a constant integer power of 2 between %qi and %qu bits"
 msgstr ""
 
-#: c-family/c-common.c:5815 c-family/c-common.c:5859
+#: c-family/c-common.c:5813 c-family/c-common.c:5857
 #, gcc-internal-format
 msgid "non-floating-point argument in call to function %qE"
 msgstr ""
 
-#: c-family/c-common.c:5838
+#: c-family/c-common.c:5836
 #, gcc-internal-format
 msgid "non-floating-point arguments in call to function %qE"
 msgstr ""
 
-#: c-family/c-common.c:5852
+#: c-family/c-common.c:5850
 #, gcc-internal-format
 msgid "non-const integer argument %u in call to function %qE"
 msgstr ""
 
-#: c-family/c-common.c:5872
+#: c-family/c-common.c:5870
 #, gcc-internal-format
 msgid "non-integer argument 3 in call to function %qE"
 msgstr ""
 
-#: c-family/c-common.c:5889 c-family/c-common.c:5925
+#: c-family/c-common.c:5887 c-family/c-common.c:5923
 #, gcc-internal-format
 msgid "argument %u in call to function %qE does not have integral type"
 msgstr ""
 
-#: c-family/c-common.c:5896
+#: c-family/c-common.c:5894
 #, gcc-internal-format
 msgid "argument 3 in call to function %qE does not have pointer to integral type"
 msgstr ""
 
-#: c-family/c-common.c:5902
+#: c-family/c-common.c:5900
 #, gcc-internal-format
 msgid "argument 3 in call to function %qE has pointer to enumerated type"
 msgstr ""
 
-#: c-family/c-common.c:5908
+#: c-family/c-common.c:5906
 #, gcc-internal-format
 msgid "argument 3 in call to function %qE has pointer to boolean type"
 msgstr ""
 
-#: c-family/c-common.c:5931
+#: c-family/c-common.c:5929
 #, gcc-internal-format
 msgid "argument 3 in call to function %qE has enumerated type"
 msgstr ""
 
-#: c-family/c-common.c:5937
+#: c-family/c-common.c:5935
 #, gcc-internal-format
 msgid "argument 3 in call to function %qE has boolean type"
 msgstr ""
 
-#: c-family/c-common.c:6184
+#: c-family/c-common.c:6183
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to static data member %qD"
 msgstr ""
 
-#: c-family/c-common.c:6189
+#: c-family/c-common.c:6188
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> when %<operator[]%> is overloaded"
 msgstr ""
 
-#: c-family/c-common.c:6196
+#: c-family/c-common.c:6195
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to a non constant address"
 msgstr ""
 
-#: c-family/c-common.c:6209
+#: c-family/c-common.c:6208
 #, gcc-internal-format
 msgid "attempt to take address of bit-field structure member %qD"
 msgstr ""
 
-#: c-family/c-common.c:6261
+#: c-family/c-common.c:6260
 #, gcc-internal-format
 msgid "index %E denotes an offset greater than size of %qT"
 msgstr ""
 
-#: c-family/c-common.c:6427 cp/init.c:3004 cp/init.c:3023
+#: c-family/c-common.c:6419 cp/init.c:3020 cp/init.c:3039
 #, gcc-internal-format
 msgid "size of array is too large"
 msgstr ""
 
-#: c-family/c-common.c:6517
+#: c-family/c-common.c:6509
 #, gcc-internal-format
 msgid "operand type %qT is incompatible with argument %d of %qE"
 msgstr ""
 
-#: c-family/c-common.c:6651
+#: c-family/c-common.c:6643
 #, gcc-internal-format
 msgid "incorrect number of arguments to function %qE"
 msgstr ""
 
-#: c-family/c-common.c:6665
+#: c-family/c-common.c:6657
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a non-void pointer type"
 msgstr ""
 
-#: c-family/c-common.c:6674
+#: c-family/c-common.c:6666
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a constant size type"
 msgstr ""
 
-#: c-family/c-common.c:6685
+#: c-family/c-common.c:6677
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a nonzero size object"
 msgstr ""
 
-#: c-family/c-common.c:6706
+#: c-family/c-common.c:6698
 #, gcc-internal-format
 msgid "argument %d of %qE must be a pointer type"
 msgstr ""
 
-#: c-family/c-common.c:6714
+#: c-family/c-common.c:6706
 #, gcc-internal-format
 msgid "argument %d of %qE must be a pointer to a constant size type"
 msgstr ""
 
-#: c-family/c-common.c:6720
+#: c-family/c-common.c:6712
 #, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a function"
 msgstr ""
 
-#: c-family/c-common.c:6728
+#: c-family/c-common.c:6720
 #, gcc-internal-format
 msgid "size mismatch in argument %d of %qE"
 msgstr ""
 
-#: c-family/c-common.c:6740
+#: c-family/c-common.c:6732
 #, gcc-internal-format
 msgid "non-integer memory model argument %d of %qE"
 msgstr ""
 
-#: c-family/c-common.c:6753
+#: c-family/c-common.c:6745
 #, gcc-internal-format
 msgid "invalid memory model argument %d of %qE"
 msgstr ""
 
-#: c-family/c-common.c:7672
+#: c-family/c-common.c:7664
 #, gcc-internal-format
 msgid "index value is out of bound"
 msgstr ""
 
-#: c-family/c-common.c:7714 c-family/c-common.c:7763 c-family/c-common.c:7779
+#: c-family/c-common.c:7706 c-family/c-common.c:7755 c-family/c-common.c:7771
 #, gcc-internal-format
 msgid "conversion of scalar %qT to vector %qT involves truncation"
 msgstr ""
@@ -24791,22 +24817,22 @@
 
 #. Reject arguments that are built-in functions with
 #. no library fallback.
-#: c-family/c-common.c:7867
+#: c-family/c-common.c:7859
 #, gcc-internal-format
 msgid "built-in function %qE must be directly called"
 msgstr ""
 
-#: c-family/c-common.c:7889 c/c-decl.c:6177
+#: c-family/c-common.c:7881 c/c-decl.c:6197
 #, gcc-internal-format
 msgid "size of array %qE is too large"
 msgstr ""
 
-#: c-family/c-common.c:7891 c/c-decl.c:6180
+#: c-family/c-common.c:7883 c/c-decl.c:6200
 #, gcc-internal-format
 msgid "size of unnamed array is too large"
 msgstr ""
 
-#: c-family/c-common.c:7921
+#: c-family/c-common.c:7913
 #, gcc-internal-format
 msgid "environment variable SOURCE_DATE_EPOCH must expand to a non-negative integer less than or equal to %wd"
 msgstr ""
@@ -25327,7 +25353,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr ""
 
-#: c-family/c-omp.c:557 cp/semantics.c:8186
+#: c-family/c-omp.c:557 cp/semantics.c:8189
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr ""
@@ -25342,22 +25368,22 @@
 msgid "%qE is not initialized"
 msgstr ""
 
-#: c-family/c-omp.c:599 cp/semantics.c:8076
+#: c-family/c-omp.c:599 cp/semantics.c:8079
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.c:704 cp/semantics.c:7732
+#: c-family/c-omp.c:704 cp/semantics.c:7735
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.c:711 cp/semantics.c:8082
+#: c-family/c-omp.c:711 cp/semantics.c:8085
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr ""
 
-#: c-family/c-omp.c:775 cp/semantics.c:7847
+#: c-family/c-omp.c:775 cp/semantics.c:7850
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr ""
@@ -25412,112 +25438,127 @@
 msgid "%<-Wabi=1%> is not supported, using =2"
 msgstr "Підтримки %<-Wabi=1%> не передбачено, використовуємо =2"
 
-#: c-family/c-opts.c:612 fortran/cpp.c:350
+#: c-family/c-opts.c:610 fortran/cpp.c:350
 #, gcc-internal-format
 msgid "output filename specified twice"
 msgstr ""
 
-#: c-family/c-opts.c:799
+#: c-family/c-opts.c:797
 #, gcc-internal-format
 msgid "-fexcess-precision=standard for C++"
 msgstr ""
 
-#: c-family/c-opts.c:834
+#: c-family/c-opts.c:832
 #, gcc-internal-format
 msgid "-fno-gnu89-inline is only supported in GNU99 or C99 mode"
 msgstr ""
 
-#: c-family/c-opts.c:880
+#: c-family/c-opts.c:878
 #, gcc-internal-format
 msgid "-Wformat-y2k ignored without -Wformat"
 msgstr ""
 
-#: c-family/c-opts.c:882
+#: c-family/c-opts.c:880
 #, gcc-internal-format
 msgid "-Wformat-extra-args ignored without -Wformat"
 msgstr ""
 
-#: c-family/c-opts.c:884
+#: c-family/c-opts.c:882
 #, gcc-internal-format
 msgid "-Wformat-zero-length ignored without -Wformat"
 msgstr ""
 
-#: c-family/c-opts.c:886
+#: c-family/c-opts.c:884
 #, gcc-internal-format
 msgid "-Wformat-nonliteral ignored without -Wformat"
 msgstr ""
 
-#: c-family/c-opts.c:888
+#: c-family/c-opts.c:886
 #, gcc-internal-format
 msgid "-Wformat-contains-nul ignored without -Wformat"
 msgstr ""
 
-#: c-family/c-opts.c:890
+#: c-family/c-opts.c:888
 #, gcc-internal-format
 msgid "-Wformat-security ignored without -Wformat"
 msgstr ""
 
-#: c-family/c-opts.c:928
+#: c-family/c-opts.c:918
 #, gcc-internal-format
 msgid "%<-fabi-compat-version=1%> is not supported, using =2"
 msgstr "Підтримки %<-fabi-compat-version=1%> не передбачено, використовуємо =2"
 
-#: c-family/c-opts.c:988
+#: c-family/c-opts.c:944
 #, gcc-internal-format
+msgid "-Wabi won't warn about anything"
+msgstr ""
+
+#: c-family/c-opts.c:946
+#, gcc-internal-format
+msgid "-Wabi warns about differences from the most up-to-date ABI, which is also used by default"
+msgstr ""
+
+#: c-family/c-opts.c:949
+#, gcc-internal-format
+msgid "use e.g. -Wabi=11 to warn about changes from GCC 7"
+msgstr ""
+
+#: c-family/c-opts.c:1003
+#, gcc-internal-format
 msgid "external TLS initialization functions not supported on this target"
 msgstr ""
 
-#: c-family/c-opts.c:1001
+#: c-family/c-opts.c:1016
 #, gcc-internal-format, gfc-internal-format
 msgid "too many filenames given.  Type %s --help for usage"
 msgstr ""
 
-#: c-family/c-opts.c:1016
+#: c-family/c-opts.c:1031
 #, gcc-internal-format
 msgid "opening output file %s: %m"
 msgstr ""
 
-#: c-family/c-opts.c:1036
+#: c-family/c-opts.c:1051
 #, gcc-internal-format, gfc-internal-format
 msgid "the \"%s\" debug format cannot be used with pre-compiled headers"
 msgstr ""
 
-#: c-family/c-opts.c:1190
+#: c-family/c-opts.c:1205
 #, gcc-internal-format
 msgid "opening dependency file %s: %m"
 msgstr ""
 
-#: c-family/c-opts.c:1201
+#: c-family/c-opts.c:1216
 #, gcc-internal-format
 msgid "closing dependency file %s: %m"
 msgstr ""
 
-#: c-family/c-opts.c:1204
+#: c-family/c-opts.c:1219
 #, gcc-internal-format
 msgid "when writing output to %s: %m"
 msgstr ""
 
-#: c-family/c-opts.c:1284
+#: c-family/c-opts.c:1299
 #, gcc-internal-format
 msgid "to generate dependencies you must specify either -M or -MM"
 msgstr ""
 
-#: c-family/c-opts.c:1307
+#: c-family/c-opts.c:1322
 #, gcc-internal-format
 msgid "-MG may only be used with -M or -MM"
 msgstr ""
 
-#: c-family/c-opts.c:1340
+#: c-family/c-opts.c:1355
 #, gcc-internal-format
 msgid "-fdirectives-only is incompatible with -Wunused_macros"
 msgstr ""
 
-#: c-family/c-opts.c:1342
+#: c-family/c-opts.c:1357
 #, gcc-internal-format
 msgid "-fdirectives-only is incompatible with -traditional"
 msgstr ""
 
-#: c-family/c-opts.c:1534
+#: c-family/c-opts.c:1549
 #, gcc-internal-format
 msgid "too late for # directive to set debug directory"
 msgstr ""
@@ -25902,709 +25943,709 @@
 msgid "wrong type argument to %s"
 msgstr ""
 
-#: c-family/c-warn.c:53 c-family/c-warn.c:66 cp/constexpr.c:1847
+#: c-family/c-warn.c:54 c-family/c-warn.c:67 cp/constexpr.c:1847
 #: cp/constexpr.c:4099
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr ""
 
-#: c-family/c-warn.c:93
+#: c-family/c-warn.c:94
 #, gcc-internal-format
 msgid "integer overflow in expression %qE of type %qT results in %qE"
 msgstr ""
 
-#: c-family/c-warn.c:95
+#: c-family/c-warn.c:96
 #, gcc-internal-format
 msgid "integer overflow in expression of type %qT results in %qE"
 msgstr ""
 
-#: c-family/c-warn.c:101
+#: c-family/c-warn.c:102
 #, gcc-internal-format
 msgid "floating point overflow in expression %qE of type %qT results in %qE"
 msgstr ""
 
-#: c-family/c-warn.c:103
+#: c-family/c-warn.c:104
 #, gcc-internal-format
 msgid "floating point overflow in expression of type %qT results in %qE"
 msgstr ""
 
-#: c-family/c-warn.c:109
+#: c-family/c-warn.c:110
 #, gcc-internal-format
 msgid "fixed-point overflow in expression %qE of type %qT results in %qE"
 msgstr ""
 
-#: c-family/c-warn.c:111
+#: c-family/c-warn.c:112
 #, gcc-internal-format
 msgid "fixed-point overflow in expression of type %qT results in %qE"
 msgstr ""
 
-#: c-family/c-warn.c:117
+#: c-family/c-warn.c:118
 #, gcc-internal-format
 msgid "vector overflow in expression %qE of type %qT results in %qE"
 msgstr ""
 
-#: c-family/c-warn.c:119
+#: c-family/c-warn.c:120
 #, gcc-internal-format
 msgid "vector overflow in expression of type %qT results in %qE"
 msgstr ""
 
-#: c-family/c-warn.c:126
+#: c-family/c-warn.c:127
 #, gcc-internal-format
 msgid "complex integer overflow in expression %qE of type %qT results in %qE"
 msgstr ""
 
-#: c-family/c-warn.c:128
+#: c-family/c-warn.c:129
 #, gcc-internal-format
 msgid "complex integer overflow in expression of type %qT results in %qE"
 msgstr ""
 
-#: c-family/c-warn.c:132
+#: c-family/c-warn.c:133
 #, gcc-internal-format
 msgid "complex floating point overflow in expression %qE of type %qT results in %qE"
 msgstr ""
 
-#: c-family/c-warn.c:134
+#: c-family/c-warn.c:135
 #, gcc-internal-format
 msgid "complex floating point overflow in expression of type %qT results in %qE"
 msgstr ""
 
-#: c-family/c-warn.c:216
+#: c-family/c-warn.c:217
 #, gcc-internal-format
 msgid "logical %<or%> applied to non-boolean constant"
 msgstr ""
 
-#: c-family/c-warn.c:219
+#: c-family/c-warn.c:220
 #, gcc-internal-format
 msgid "logical %<and%> applied to non-boolean constant"
 msgstr ""
 
-#: c-family/c-warn.c:289
+#: c-family/c-warn.c:290
 #, gcc-internal-format
 msgid "logical %<or%> of collectively exhaustive tests is always true"
 msgstr ""
 
-#: c-family/c-warn.c:293
+#: c-family/c-warn.c:294
 #, gcc-internal-format
 msgid "logical %<and%> of mutually exclusive tests is always false"
 msgstr ""
 
-#: c-family/c-warn.c:303
+#: c-family/c-warn.c:304
 #, gcc-internal-format
 msgid "logical %<or%> of equal expressions"
 msgstr ""
 
-#: c-family/c-warn.c:306
+#: c-family/c-warn.c:307
 #, gcc-internal-format
 msgid "logical %<and%> of equal expressions"
 msgstr ""
 
-#: c-family/c-warn.c:384
+#: c-family/c-warn.c:385
 #, gcc-internal-format
 msgid "bitwise comparison always evaluates to false"
 msgstr ""
 
-#: c-family/c-warn.c:387
+#: c-family/c-warn.c:388
 #, gcc-internal-format
 msgid "bitwise comparison always evaluates to true"
 msgstr ""
 
-#: c-family/c-warn.c:441
+#: c-family/c-warn.c:442
 #, gcc-internal-format
 msgid "self-comparison always evaluates to true"
 msgstr ""
 
-#: c-family/c-warn.c:444
+#: c-family/c-warn.c:445
 #, gcc-internal-format
 msgid "self-comparison always evaluates to false"
 msgstr ""
 
-#: c-family/c-warn.c:494
+#: c-family/c-warn.c:495
 #, gcc-internal-format
 msgid "logical not is only applied to the left hand side of comparison"
 msgstr ""
 
-#: c-family/c-warn.c:502
+#: c-family/c-warn.c:503
 #, gcc-internal-format
 msgid "add parentheses around left hand side expression to silence this warning"
 msgstr ""
 
-#: c-family/c-warn.c:636
+#: c-family/c-warn.c:637
 #, gcc-internal-format
 msgid "type-punning to incomplete type might break strict-aliasing rules"
 msgstr ""
 
-#: c-family/c-warn.c:654
+#: c-family/c-warn.c:655
 #, gcc-internal-format
 msgid "dereferencing type-punned pointer will break strict-aliasing rules"
 msgstr "розіменовування вказівника із каламбуром типізації порушить правила строгого злиття"
 
-#: c-family/c-warn.c:662 c-family/c-warn.c:680
+#: c-family/c-warn.c:663 c-family/c-warn.c:681
 #, gcc-internal-format
 msgid "dereferencing type-punned pointer might break strict-aliasing rules"
 msgstr "розіменовування вказівника із каламбуром типізації може порушити правила строгого злиття"
 
-#: c-family/c-warn.c:803
+#: c-family/c-warn.c:811
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to use the size of the destination?"
 msgstr ""
 
-#: c-family/c-warn.c:834
+#: c-family/c-warn.c:842
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the destination; did you mean to remove the addressof?"
 msgstr ""
 
-#: c-family/c-warn.c:841
+#: c-family/c-warn.c:849
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the destination; did you mean to provide an explicit length?"
 msgstr ""
 
-#: c-family/c-warn.c:846
+#: c-family/c-warn.c:854
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the destination; did you mean to dereference it?"
 msgstr ""
 
-#: c-family/c-warn.c:858
+#: c-family/c-warn.c:866
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the destination; expected %qT or an explicit length"
 msgstr ""
 
-#: c-family/c-warn.c:874
+#: c-family/c-warn.c:882
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to remove the addressof?"
 msgstr ""
 
-#: c-family/c-warn.c:881
+#: c-family/c-warn.c:889
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to provide an explicit length?"
 msgstr ""
 
-#: c-family/c-warn.c:886
+#: c-family/c-warn.c:894
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to dereference it?"
 msgstr ""
 
-#: c-family/c-warn.c:898
+#: c-family/c-warn.c:906
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the source; expected %qT or an explicit length"
 msgstr ""
 
-#: c-family/c-warn.c:914
+#: c-family/c-warn.c:922
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the first source; did you mean to remove the addressof?"
 msgstr ""
 
-#: c-family/c-warn.c:921
+#: c-family/c-warn.c:929
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the first source; did you mean to provide an explicit length?"
 msgstr ""
 
-#: c-family/c-warn.c:926
+#: c-family/c-warn.c:934
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the first source; did you mean to dereference it?"
 msgstr ""
 
-#: c-family/c-warn.c:938
+#: c-family/c-warn.c:946
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the first source; expected %qT or an explicit length"
 msgstr ""
 
-#: c-family/c-warn.c:954
+#: c-family/c-warn.c:962
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the second source; did you mean to remove the addressof?"
 msgstr ""
 
-#: c-family/c-warn.c:961
+#: c-family/c-warn.c:969
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the second source; did you mean to provide an explicit length?"
 msgstr ""
 
-#: c-family/c-warn.c:966
+#: c-family/c-warn.c:974
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the second source; did you mean to dereference it?"
 msgstr ""
 
-#: c-family/c-warn.c:978
+#: c-family/c-warn.c:986
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the second source; expected %qT or an explicit length"
 msgstr ""
 
-#: c-family/c-warn.c:1007 c-family/c-warn.c:1014
+#: c-family/c-warn.c:1015 c-family/c-warn.c:1022
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified parameter type %qT of %q+D"
 msgstr ""
 
-#: c-family/c-warn.c:1024
+#: c-family/c-warn.c:1032
 #, gcc-internal-format
 msgid "first argument of %q+D should be %<int%>"
 msgstr ""
 
-#: c-family/c-warn.c:1033
+#: c-family/c-warn.c:1041
 #, gcc-internal-format
 msgid "second argument of %q+D should be %<char **%>"
 msgstr ""
 
-#: c-family/c-warn.c:1042
+#: c-family/c-warn.c:1050
 #, gcc-internal-format
 msgid "third argument of %q+D should probably be %<char **%>"
 msgstr ""
 
-#: c-family/c-warn.c:1053
+#: c-family/c-warn.c:1061
 #, gcc-internal-format
 msgid "%q+D takes only zero or two arguments"
 msgstr ""
 
-#: c-family/c-warn.c:1057
+#: c-family/c-warn.c:1065
 #, gcc-internal-format
 msgid "%q+D declared as variadic function"
 msgstr ""
 
-#: c-family/c-warn.c:1099
+#: c-family/c-warn.c:1107
 #, gcc-internal-format
 msgid "conversion to %qT from boolean expression"
 msgstr ""
 
-#: c-family/c-warn.c:1117 c-family/c-warn.c:1192
+#: c-family/c-warn.c:1125 c-family/c-warn.c:1200
 #, gcc-internal-format
 msgid "conversion from %qT to %qT changes value from %qE to %qE"
 msgstr ""
 
-#: c-family/c-warn.c:1121 c-family/c-warn.c:1200
+#: c-family/c-warn.c:1129 c-family/c-warn.c:1208
 #, gcc-internal-format
 msgid "conversion from %qT to %qT changes the value of %qE"
 msgstr ""
 
-#: c-family/c-warn.c:1141
+#: c-family/c-warn.c:1149
 #, gcc-internal-format
 msgid "conversion from %qT to %qT discards imaginary component"
 msgstr ""
 
-#: c-family/c-warn.c:1153
+#: c-family/c-warn.c:1161
 #, gcc-internal-format
 msgid "conversion from %qT to %qT may change value"
 msgstr ""
 
-#: c-family/c-warn.c:1213 c-family/c-warn.c:1230 c-family/c-warn.c:1247
+#: c-family/c-warn.c:1221 c-family/c-warn.c:1238 c-family/c-warn.c:1255
 #, gcc-internal-format
 msgid "overflow in conversion from %qT to %qT changes value from %qE to %qE"
 msgstr ""
 
-#: c-family/c-warn.c:1218 c-family/c-warn.c:1235 c-family/c-warn.c:1252
+#: c-family/c-warn.c:1226 c-family/c-warn.c:1243 c-family/c-warn.c:1260
 #, gcc-internal-format
 msgid "overflow in conversion from %qT to %qT changes the value of %qE"
 msgstr ""
 
-#: c-family/c-warn.c:1282
+#: c-family/c-warn.c:1290
 #, gcc-internal-format
 msgid "case value %qs not in enumerated type"
 msgstr "значення випадку %qs не належить до перераховного типу"
 
-#: c-family/c-warn.c:1287
+#: c-family/c-warn.c:1295
 #, gcc-internal-format
 msgid "case value %qs not in enumerated type %qT"
 msgstr "значення випадку %qs не належить до перераховного типу %qT"
 
-#: c-family/c-warn.c:1348
+#: c-family/c-warn.c:1356
 #, gcc-internal-format
 msgid "switch missing default case"
 msgstr ""
 
-#: c-family/c-warn.c:1393
+#: c-family/c-warn.c:1401
 #, gcc-internal-format
 msgid "switch condition has boolean value"
 msgstr ""
 
-#: c-family/c-warn.c:1466
+#: c-family/c-warn.c:1474
 #, gcc-internal-format
 msgid "enumeration value %qE not handled in switch"
 msgstr ""
 
-#: c-family/c-warn.c:1494
+#: c-family/c-warn.c:1502
 #, gcc-internal-format
 msgid "the omitted middle operand in ?: will always be %<true%>, suggest explicit middle operand"
 msgstr ""
 
-#: c-family/c-warn.c:1515
+#: c-family/c-warn.c:1523
 #, gcc-internal-format
 msgid "assignment of member %qD in read-only object"
 msgstr ""
 
-#: c-family/c-warn.c:1517
+#: c-family/c-warn.c:1525
 #, gcc-internal-format
 msgid "increment of member %qD in read-only object"
 msgstr ""
 
-#: c-family/c-warn.c:1519
+#: c-family/c-warn.c:1527
 #, gcc-internal-format
 msgid "decrement of member %qD in read-only object"
 msgstr ""
 
-#: c-family/c-warn.c:1521
+#: c-family/c-warn.c:1529
 #, gcc-internal-format
 msgid "member %qD in read-only object used as %<asm%> output"
 msgstr ""
 
-#: c-family/c-warn.c:1525
+#: c-family/c-warn.c:1533
 #, gcc-internal-format
 msgid "assignment of read-only member %qD"
 msgstr ""
 
-#: c-family/c-warn.c:1526
+#: c-family/c-warn.c:1534
 #, gcc-internal-format
 msgid "increment of read-only member %qD"
 msgstr ""
 
-#: c-family/c-warn.c:1527
+#: c-family/c-warn.c:1535
 #, gcc-internal-format
 msgid "decrement of read-only member %qD"
 msgstr ""
 
-#: c-family/c-warn.c:1528
+#: c-family/c-warn.c:1536
 #, gcc-internal-format
 msgid "read-only member %qD used as %<asm%> output"
 msgstr ""
 
-#: c-family/c-warn.c:1532
+#: c-family/c-warn.c:1540
 #, gcc-internal-format
 msgid "assignment of read-only variable %qD"
 msgstr ""
 
-#: c-family/c-warn.c:1533
+#: c-family/c-warn.c:1541
 #, gcc-internal-format
 msgid "increment of read-only variable %qD"
 msgstr ""
 
-#: c-family/c-warn.c:1534
+#: c-family/c-warn.c:1542
 #, gcc-internal-format
 msgid "decrement of read-only variable %qD"
 msgstr ""
 
-#: c-family/c-warn.c:1535
+#: c-family/c-warn.c:1543
 #, gcc-internal-format
 msgid "read-only variable %qD used as %<asm%> output"
 msgstr ""
 
-#: c-family/c-warn.c:1538
+#: c-family/c-warn.c:1546
 #, gcc-internal-format
 msgid "assignment of read-only parameter %qD"
 msgstr ""
 
-#: c-family/c-warn.c:1539
+#: c-family/c-warn.c:1547
 #, gcc-internal-format
 msgid "increment of read-only parameter %qD"
 msgstr ""
 
-#: c-family/c-warn.c:1540
+#: c-family/c-warn.c:1548
 #, gcc-internal-format
 msgid "decrement of read-only parameter %qD"
 msgstr ""
 
-#: c-family/c-warn.c:1541
+#: c-family/c-warn.c:1549
 #, gcc-internal-format
 msgid "read-only parameter %qD use as %<asm%> output"
 msgstr ""
 
-#: c-family/c-warn.c:1546
+#: c-family/c-warn.c:1554
 #, gcc-internal-format
 msgid "assignment of read-only named return value %qD"
 msgstr ""
 
-#: c-family/c-warn.c:1548
+#: c-family/c-warn.c:1556
 #, gcc-internal-format
 msgid "increment of read-only named return value %qD"
 msgstr ""
 
-#: c-family/c-warn.c:1550
+#: c-family/c-warn.c:1558
 #, gcc-internal-format
 msgid "decrement of read-only named return value %qD"
 msgstr ""
 
-#: c-family/c-warn.c:1552
+#: c-family/c-warn.c:1560
 #, gcc-internal-format
 msgid "read-only named return value %qD used as %<asm%>output"
 msgstr ""
 
-#: c-family/c-warn.c:1557
+#: c-family/c-warn.c:1565
 #, gcc-internal-format
 msgid "assignment of function %qD"
 msgstr ""
 
-#: c-family/c-warn.c:1558
+#: c-family/c-warn.c:1566
 #, gcc-internal-format
 msgid "increment of function %qD"
 msgstr ""
 
-#: c-family/c-warn.c:1559
+#: c-family/c-warn.c:1567
 #, gcc-internal-format
 msgid "decrement of function %qD"
 msgstr ""
 
-#: c-family/c-warn.c:1560
+#: c-family/c-warn.c:1568
 #, gcc-internal-format
 msgid "function %qD used as %<asm%> output"
 msgstr ""
 
-#: c-family/c-warn.c:1563 c/c-typeck.c:4762
+#: c-family/c-warn.c:1571 c/c-typeck.c:4767
 #, gcc-internal-format
 msgid "assignment of read-only location %qE"
 msgstr ""
 
-#: c-family/c-warn.c:1564 c/c-typeck.c:4765
+#: c-family/c-warn.c:1572 c/c-typeck.c:4770
 #, gcc-internal-format
 msgid "increment of read-only location %qE"
 msgstr ""
 
-#: c-family/c-warn.c:1565 c/c-typeck.c:4768
+#: c-family/c-warn.c:1573 c/c-typeck.c:4773
 #, gcc-internal-format
 msgid "decrement of read-only location %qE"
 msgstr ""
 
-#: c-family/c-warn.c:1566
+#: c-family/c-warn.c:1574
 #, gcc-internal-format
 msgid "read-only location %qE used as %<asm%> output"
 msgstr ""
 
-#: c-family/c-warn.c:1580
+#: c-family/c-warn.c:1588
 #, gcc-internal-format
 msgid "lvalue required as left operand of assignment"
 msgstr ""
 
-#: c-family/c-warn.c:1583
+#: c-family/c-warn.c:1591
 #, gcc-internal-format
 msgid "lvalue required as increment operand"
 msgstr ""
 
-#: c-family/c-warn.c:1586
+#: c-family/c-warn.c:1594
 #, gcc-internal-format
 msgid "lvalue required as decrement operand"
 msgstr ""
 
-#: c-family/c-warn.c:1589
+#: c-family/c-warn.c:1597
 #, gcc-internal-format
 msgid "lvalue required as unary %<&%> operand"
 msgstr ""
 
-#: c-family/c-warn.c:1592
+#: c-family/c-warn.c:1600
 #, gcc-internal-format
 msgid "lvalue required in asm statement"
 msgstr ""
 
-#: c-family/c-warn.c:1609
+#: c-family/c-warn.c:1617
 #, gcc-internal-format
 msgid "invalid type argument (have %qT)"
 msgstr ""
 
-#: c-family/c-warn.c:1613
+#: c-family/c-warn.c:1621
 #, gcc-internal-format
 msgid "invalid type argument of array indexing (have %qT)"
 msgstr ""
 
-#: c-family/c-warn.c:1618
+#: c-family/c-warn.c:1626
 #, gcc-internal-format
 msgid "invalid type argument of unary %<*%> (have %qT)"
 msgstr ""
 
-#: c-family/c-warn.c:1623
+#: c-family/c-warn.c:1631
 #, gcc-internal-format
 msgid "invalid type argument of %<->%> (have %qT)"
 msgstr ""
 
-#: c-family/c-warn.c:1628
+#: c-family/c-warn.c:1636
 #, gcc-internal-format
 msgid "invalid type argument of %<->*%> (have %qT)"
 msgstr ""
 
-#: c-family/c-warn.c:1633
+#: c-family/c-warn.c:1641
 #, gcc-internal-format
 msgid "invalid type argument of implicit conversion (have %qT)"
 msgstr ""
 
-#: c-family/c-warn.c:1654
+#: c-family/c-warn.c:1662
 #, gcc-internal-format
 msgid "array subscript has type %<char%>"
 msgstr ""
 
-#: c-family/c-warn.c:1689 c-family/c-warn.c:1692
+#: c-family/c-warn.c:1697 c-family/c-warn.c:1700
 #, gcc-internal-format
 msgid "suggest parentheses around %<+%> inside %<<<%>"
 msgstr ""
 
-#: c-family/c-warn.c:1695 c-family/c-warn.c:1698
+#: c-family/c-warn.c:1703 c-family/c-warn.c:1706
 #, gcc-internal-format
 msgid "suggest parentheses around %<-%> inside %<<<%>"
 msgstr ""
 
-#: c-family/c-warn.c:1704 c-family/c-warn.c:1707
+#: c-family/c-warn.c:1712 c-family/c-warn.c:1715
 #, gcc-internal-format
 msgid "suggest parentheses around %<+%> inside %<>>%>"
 msgstr ""
 
-#: c-family/c-warn.c:1710 c-family/c-warn.c:1713
+#: c-family/c-warn.c:1718 c-family/c-warn.c:1721
 #, gcc-internal-format
 msgid "suggest parentheses around %<-%> inside %<>>%>"
 msgstr ""
 
-#: c-family/c-warn.c:1719 c-family/c-warn.c:1722
+#: c-family/c-warn.c:1727 c-family/c-warn.c:1730
 #, gcc-internal-format
 msgid "suggest parentheses around %<&&%> within %<||%>"
 msgstr ""
 
-#: c-family/c-warn.c:1729 c-family/c-warn.c:1733
+#: c-family/c-warn.c:1737 c-family/c-warn.c:1741
 #, gcc-internal-format
 msgid "suggest parentheses around arithmetic in operand of %<|%>"
 msgstr ""
 
-#: c-family/c-warn.c:1737 c-family/c-warn.c:1740
+#: c-family/c-warn.c:1745 c-family/c-warn.c:1748
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<|%>"
 msgstr ""
 
-#: c-family/c-warn.c:1745
+#: c-family/c-warn.c:1753
 #, gcc-internal-format
 msgid "suggest parentheses around operand of %<!%> or change %<|%> to %<||%> or %<!%> to %<~%>"
 msgstr ""
 
-#: c-family/c-warn.c:1753 c-family/c-warn.c:1757
+#: c-family/c-warn.c:1761 c-family/c-warn.c:1765
 #, gcc-internal-format
 msgid "suggest parentheses around arithmetic in operand of %<^%>"
 msgstr ""
 
-#: c-family/c-warn.c:1761 c-family/c-warn.c:1764
+#: c-family/c-warn.c:1769 c-family/c-warn.c:1772
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<^%>"
 msgstr ""
 
-#: c-family/c-warn.c:1770 c-family/c-warn.c:1773
+#: c-family/c-warn.c:1778 c-family/c-warn.c:1781
 #, gcc-internal-format
 msgid "suggest parentheses around %<+%> in operand of %<&%>"
 msgstr ""
 
-#: c-family/c-warn.c:1776 c-family/c-warn.c:1779
+#: c-family/c-warn.c:1784 c-family/c-warn.c:1787
 #, gcc-internal-format
 msgid "suggest parentheses around %<-%> in operand of %<&%>"
 msgstr ""
 
-#: c-family/c-warn.c:1783 c-family/c-warn.c:1786
+#: c-family/c-warn.c:1791 c-family/c-warn.c:1794
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<&%>"
 msgstr ""
 
-#: c-family/c-warn.c:1791
+#: c-family/c-warn.c:1799
 #, gcc-internal-format
 msgid "suggest parentheses around operand of %<!%> or change %<&%> to %<&&%> or %<!%> to %<~%>"
 msgstr ""
 
-#: c-family/c-warn.c:1798 c-family/c-warn.c:1801
+#: c-family/c-warn.c:1806 c-family/c-warn.c:1809
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<==%>"
 msgstr ""
 
-#: c-family/c-warn.c:1806 c-family/c-warn.c:1809
+#: c-family/c-warn.c:1814 c-family/c-warn.c:1817
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<!=%>"
 msgstr ""
 
-#: c-family/c-warn.c:1819 c-family/c-warn.c:1825
+#: c-family/c-warn.c:1827 c-family/c-warn.c:1833
 #, gcc-internal-format
 msgid "comparisons like %<X<=Y<=Z%> do not have their mathematical meaning"
 msgstr ""
 
-#: c-family/c-warn.c:1841
+#: c-family/c-warn.c:1849
 #, gcc-internal-format
 msgid "label %q+D defined but not used"
 msgstr ""
 
-#: c-family/c-warn.c:1843
+#: c-family/c-warn.c:1851
 #, gcc-internal-format
 msgid "label %q+D declared but not defined"
 msgstr ""
 
-#: c-family/c-warn.c:1866
+#: c-family/c-warn.c:1874
 #, gcc-internal-format
 msgid "division by zero"
 msgstr "ділення на нуль"
 
-#: c-family/c-warn.c:1886
+#: c-family/c-warn.c:1894
 #, gcc-internal-format
 msgid "%<memset%> used with constant zero length parameter; this could be due to transposed parameters"
 msgstr ""
 
-#: c-family/c-warn.c:1909
+#: c-family/c-warn.c:1918
 #, gcc-internal-format
 msgid "%<memset%> used with length equal to number of elements without multiplication by element size"
 msgstr ""
 
-#: c-family/c-warn.c:1948 c/c-typeck.c:11499 c/c-typeck.c:11667
+#: c-family/c-warn.c:1957 c/c-typeck.c:11504 c/c-typeck.c:11672
 #: cp/typeck.c:5048
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr ""
 
-#: c-family/c-warn.c:1998
+#: c-family/c-warn.c:2007
 #, gcc-internal-format
 msgid "comparison of integer expressions of different signedness: %qT and %qT"
 msgstr ""
 
-#: c-family/c-warn.c:2051
+#: c-family/c-warn.c:2060
 #, gcc-internal-format
 msgid "promoted ~unsigned is always non-zero"
 msgstr ""
 
-#: c-family/c-warn.c:2054
+#: c-family/c-warn.c:2063
 #, gcc-internal-format
 msgid "comparison of promoted ~unsigned with constant"
 msgstr ""
 
-#: c-family/c-warn.c:2064
+#: c-family/c-warn.c:2073
 #, gcc-internal-format
 msgid "comparison of promoted ~unsigned with unsigned"
 msgstr ""
 
-#: c-family/c-warn.c:2118
+#: c-family/c-warn.c:2127
 #, gcc-internal-format
 msgid "unused parameter %qD"
 msgstr "невикористаний параметр %qD"
 
-#: c-family/c-warn.c:2180
+#: c-family/c-warn.c:2189
 #, gcc-internal-format
 msgid "typedef %qD locally defined but not used"
 msgstr ""
 
-#: c-family/c-warn.c:2215
+#: c-family/c-warn.c:2224
 #, gcc-internal-format
 msgid "duplicated %<if%> condition"
 msgstr "дублювання умови %<if%>"
 
-#: c-family/c-warn.c:2244
+#: c-family/c-warn.c:2253
 #, gcc-internal-format
 msgid "optimization attribute on %qD follows definition but the attribute doesn%'t match"
 msgstr ""
 
-#: c-family/c-warn.c:2254
+#: c-family/c-warn.c:2261
 #, gcc-internal-format
 msgid "inline declaration of %qD follows declaration with attribute %qs"
 msgstr ""
 
-#: c-family/c-warn.c:2259
+#: c-family/c-warn.c:2266
 #, gcc-internal-format
 msgid "declaration of %q+D with attribute %qs follows inline declaration"
 msgstr ""
 
-#: c-family/c-warn.c:2306
+#: c-family/c-warn.c:2313
 #, gcc-internal-format
 msgid "result of %qE requires %u bits to represent, but %qT only has %u bits"
 msgstr ""
 
-#: c-family/c-warn.c:2344 c-family/c-warn.c:2368
+#: c-family/c-warn.c:2351 c-family/c-warn.c:2375
 #, gcc-internal-format
 msgid "comparison of constant %qE with boolean expression is always false"
 msgstr ""
 
-#: c-family/c-warn.c:2347 c-family/c-warn.c:2365
+#: c-family/c-warn.c:2354 c-family/c-warn.c:2372
 #, gcc-internal-format
 msgid "comparison of constant %qE with boolean expression is always true"
 msgstr ""
 
-#: c-family/c-warn.c:2415
+#: c-family/c-warn.c:2422
 msgid "passing argument %i to restrict-qualified parameter aliases with argument %Z"
 msgid_plural "passing argument %i to restrict-qualified parameter aliases with arguments %Z"
 msgstr[0] ""
@@ -26611,17 +26652,17 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: c-family/c-warn.c:2480 c/c-typeck.c:5288 cp/call.c:5365
+#: c-family/c-warn.c:2487 c/c-typeck.c:5293 cp/call.c:5365
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr ""
 
-#: c-family/c-warn.c:2586
+#: c-family/c-warn.c:2593
 #, gcc-internal-format
 msgid "macro expands to multiple statements"
 msgstr ""
 
-#: c-family/c-warn.c:2587
+#: c-family/c-warn.c:2594
 #, gcc-internal-format
 msgid "some parts of macro expansion are not guarded by this %qs clause"
 msgstr ""
@@ -26636,7 +26677,7 @@
 msgid "too many input files"
 msgstr ""
 
-#: common/config/aarch64/aarch64-common.c:319 config/aarch64/aarch64.c:10686
+#: common/config/aarch64/aarch64-common.c:319 config/aarch64/aarch64.c:10702
 #, gcc-internal-format
 msgid "unknown value %qs for -mcpu"
 msgstr ""
@@ -26667,13 +26708,13 @@
 msgstr ""
 
 #: common/config/arm/arm-common.c:322 common/config/arm/arm-common.c:376
-#: common/config/arm/arm-common.c:423 config/aarch64/aarch64.c:10639
+#: common/config/arm/arm-common.c:423 config/aarch64/aarch64.c:10655
 #, gcc-internal-format
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr "коректними аргументами є такі: %s; ви мали на увазі %qs?"
 
 #: common/config/arm/arm-common.c:325 common/config/arm/arm-common.c:379
-#: common/config/arm/arm-common.c:426 config/aarch64/aarch64.c:10642
+#: common/config/arm/arm-common.c:426 config/aarch64/aarch64.c:10658
 #, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s"
 msgstr "коректні аргументи: %s"
@@ -27146,12 +27187,12 @@
 msgid "profiler support for VxWorks"
 msgstr ""
 
-#: config/aarch64/aarch64-builtins.c:1109 config/arm/arm-builtins.c:2262
+#: config/aarch64/aarch64-builtins.c:1109 config/arm/arm-builtins.c:2272
 #, gcc-internal-format
 msgid "%Kargument %d must be a constant immediate"
 msgstr ""
 
-#: config/aarch64/aarch64-builtins.c:1180 config/arm/arm-builtins.c:2492
+#: config/aarch64/aarch64-builtins.c:1180 config/arm/arm-builtins.c:2502
 #, gcc-internal-format
 msgid "%Klane index must be a constant immediate"
 msgstr ""
@@ -27161,175 +27202,175 @@
 msgid "%Ktotal size and element size must be a non-zero constant immediate"
 msgstr ""
 
-#: config/aarch64/aarch64.c:1053
+#: config/aarch64/aarch64.c:1069
 #, gcc-internal-format
 msgid "%qs is incompatible with %s %s"
 msgstr ""
 
-#: config/aarch64/aarch64.c:1055
+#: config/aarch64/aarch64.c:1071
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with %s %s"
 msgstr ""
 
-#: config/aarch64/aarch64.c:3772
+#: config/aarch64/aarch64.c:3788
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10287
+#: config/aarch64/aarch64.c:10303
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown flag passed in -moverride=%s (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10331
+#: config/aarch64/aarch64.c:10347
 #, gcc-internal-format, gfc-internal-format
 msgid "%s string ill-formed\n"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10388
+#: config/aarch64/aarch64.c:10404
 #, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10406
+#: config/aarch64/aarch64.c:10422
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown tuning option (%s)"
 msgstr "невідомий параметр регулювання (%s)"
 
-#: config/aarch64/aarch64.c:10683
+#: config/aarch64/aarch64.c:10699
 #, gcc-internal-format
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10690
+#: config/aarch64/aarch64.c:10706
 #, gcc-internal-format
 msgid "invalid feature modifier in %<-mcpu=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10717
+#: config/aarch64/aarch64.c:10733
 #, gcc-internal-format
 msgid "missing arch name in %<-march=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10720
+#: config/aarch64/aarch64.c:10736
 #, gcc-internal-format
 msgid "unknown value %qs for -march"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10724
+#: config/aarch64/aarch64.c:10740
 #, gcc-internal-format
 msgid "invalid feature modifier in %<-march=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10750
+#: config/aarch64/aarch64.c:10766
 #, gcc-internal-format
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10753
+#: config/aarch64/aarch64.c:10769
 #, gcc-internal-format
 msgid "unknown value %qs for -mtune"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10871 config/arm/arm.c:3173
+#: config/aarch64/aarch64.c:10887 config/arm/arm.c:3173
 #, gcc-internal-format, gfc-internal-format
 msgid "switch -mcpu=%s conflicts with -march=%s switch"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10906
+#: config/aarch64/aarch64.c:10922
 #, gcc-internal-format
 msgid "assembler does not support -mabi=ilp32"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10913
+#: config/aarch64/aarch64.c:10929
 #, gcc-internal-format
 msgid "return address signing is only supported for -mabi=lp64"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10975
+#: config/aarch64/aarch64.c:10991
 #, gcc-internal-format
 msgid "code model %qs with -f%s"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11138
+#: config/aarch64/aarch64.c:11154
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11141
+#: config/aarch64/aarch64.c:11157
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11145 config/aarch64/aarch64.c:11184
-#: config/aarch64/aarch64.c:11257
+#: config/aarch64/aarch64.c:11161 config/aarch64/aarch64.c:11200
+#: config/aarch64/aarch64.c:11273
 #, gcc-internal-format
 msgid "invalid value (\"%s\") in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11177
+#: config/aarch64/aarch64.c:11193
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11180
+#: config/aarch64/aarch64.c:11196
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11213
+#: config/aarch64/aarch64.c:11229
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"tune=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11253
+#: config/aarch64/aarch64.c:11269
 #, gcc-internal-format
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11306 config/aarch64/aarch64.c:11483
+#: config/aarch64/aarch64.c:11322 config/aarch64/aarch64.c:11499
 #, gcc-internal-format
 msgid "malformed %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11354
+#: config/aarch64/aarch64.c:11370
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11362
+#: config/aarch64/aarch64.c:11378
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11416
+#: config/aarch64/aarch64.c:11432
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11473 config/arm/arm.c:30742
-#: config/i386/i386.c:5440 config/powerpcspe/powerpcspe.c:39760
-#: config/rs6000/rs6000.c:36904 config/s390/s390.c:15746
+#: config/aarch64/aarch64.c:11489 config/arm/arm.c:30742
+#: config/i386/i386.c:5443 config/powerpcspe/powerpcspe.c:39760
+#: config/rs6000/rs6000.c:36960 config/s390/s390.c:15746
 #, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11500
+#: config/aarch64/aarch64.c:11516
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11509
+#: config/aarch64/aarch64.c:11525
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13571
+#: config/aarch64/aarch64.c:13587
 #, gcc-internal-format
 msgid "%Klane %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13573
+#: config/aarch64/aarch64.c:13589
 #, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr ""
@@ -27389,8 +27430,8 @@
 msgid "bad value %qs for -mmemory-latency"
 msgstr ""
 
-#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6526
-#: config/arc/arc.c:6800 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
+#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6517
+#: config/arc/arc.c:6791 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
 #: config/tilepro/tilepro.c:3108
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -27499,11 +27540,11 @@
 #: config/arm/arm.c:7029 config/avr/avr.c:9718 config/avr/avr.c:9734
 #: config/bfin/bfin.c:4705 config/bfin/bfin.c:4766 config/bfin/bfin.c:4795
 #: config/epiphany/epiphany.c:491 config/h8300/h8300.c:5459
-#: config/i386/i386.c:6452 config/i386/i386.c:12479 config/i386/i386.c:41424
-#: config/i386/i386.c:41474 config/i386/i386.c:41544 config/m68k/m68k.c:780
+#: config/i386/i386.c:6455 config/i386/i386.c:12482 config/i386/i386.c:41418
+#: config/i386/i386.c:41468 config/i386/i386.c:41538 config/m68k/m68k.c:780
 #: config/mcore/mcore.c:3070 config/nvptx/nvptx.c:4611
 #: config/powerpcspe/powerpcspe.c:35785 config/riscv/riscv.c:2698
-#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:32982
+#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:33038
 #: config/rx/rx.c:2719 config/rx/rx.c:2745 config/s390/s390.c:1056
 #: config/s390/s390.c:1143 config/sh/sh.c:8428 config/sh/sh.c:8446
 #: config/sh/sh.c:8470 config/sh/sh.c:8541 config/sh/sh.c:8564
@@ -27513,133 +27554,133 @@
 msgid "%qE attribute only applies to functions"
 msgstr ""
 
-#: config/arc/arc.c:6425
+#: config/arc/arc.c:6416
 #, gcc-internal-format
 msgid "__builtin_arc_aligned with non-constant alignment"
 msgstr ""
 
-#: config/arc/arc.c:6433
+#: config/arc/arc.c:6424
 #, gcc-internal-format
 msgid "invalid alignment value for __builtin_arc_aligned"
 msgstr ""
 
-#: config/arc/arc.c:6596
+#: config/arc/arc.c:6587
 #, gcc-internal-format
 msgid "operand 1 should be an unsigned 3-bit immediate"
 msgstr ""
 
-#: config/arc/arc.c:6637 config/arc/arc.c:6734
+#: config/arc/arc.c:6628 config/arc/arc.c:6725
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6670 config/arc/arc.c:6702
+#: config/arc/arc.c:6661 config/arc/arc.c:6693
 #, gcc-internal-format
 msgid "operand 1 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6674 config/arc/arc.c:6706
+#: config/arc/arc.c:6665 config/arc/arc.c:6697
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 8-bit value"
 msgstr ""
 
-#: config/arc/arc.c:6738
+#: config/arc/arc.c:6729
 #, gcc-internal-format
 msgid "operand 3 should be an unsigned 8-bit value"
 msgstr ""
 
-#: config/arc/arc.c:6771
+#: config/arc/arc.c:6762
 #, gcc-internal-format
 msgid "operand 4 should be an unsigned 8-bit value (0-255)"
 msgstr ""
 
-#: config/arc/arc.c:6775
+#: config/arc/arc.c:6766
 #, gcc-internal-format
 msgid "operand 3 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6782
+#: config/arc/arc.c:6773
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (subreg 0-7)"
 msgstr ""
 
-#: config/arc/arc.c:6785
+#: config/arc/arc.c:6776
 #, gcc-internal-format
 msgid "operand 2 should be an even 3-bit value (subreg 0,2,4,6)"
 msgstr ""
 
-#: config/arc/arc.c:6832
+#: config/arc/arc.c:6823
 #, gcc-internal-format, gfc-internal-format
 msgid "builtin requires an immediate for operand %d"
 msgstr ""
 
-#: config/arc/arc.c:6837
+#: config/arc/arc.c:6828
 #, gcc-internal-format, gfc-internal-format
 msgid "operand %d should be a 6 bit unsigned immediate"
 msgstr ""
 
-#: config/arc/arc.c:6841
+#: config/arc/arc.c:6832
 #, gcc-internal-format, gfc-internal-format
 msgid "operand %d should be a 8 bit unsigned immediate"
 msgstr ""
 
-#: config/arc/arc.c:6845
+#: config/arc/arc.c:6836
 #, gcc-internal-format, gfc-internal-format
 msgid "operand %d should be a 3 bit unsigned immediate"
 msgstr ""
 
-#: config/arc/arc.c:6848
+#: config/arc/arc.c:6839
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown builtin immediate operand type for operand %d"
 msgstr ""
 
-#: config/arc/arc.c:6899
+#: config/arc/arc.c:6890
 #, gcc-internal-format
 msgid "register number must be a compile-time constant. Try giving higher optimization levels"
 msgstr ""
 
-#: config/arc/arc.c:7685
+#: config/arc/arc.c:7747
 #, gcc-internal-format
 msgid "Insn addresses not set after shorten_branches"
 msgstr ""
 
-#: config/arc/arc.c:7894
+#: config/arc/arc.c:7956
 #, gcc-internal-format
 msgid "insn addresses not freed"
 msgstr ""
 
-#: config/arc/arc.c:10682
+#: config/arc/arc.c:10670
 #, gcc-internal-format
 msgid "%qE attribute only valid for ARCv2 architecture"
 msgstr ""
 
-#: config/arc/arc.c:10690 config/arc/arc.c:10729
+#: config/arc/arc.c:10678 config/arc/arc.c:10717
 #, gcc-internal-format
 msgid "argument of %qE attribute is missing"
 msgstr ""
 
-#: config/arc/arc.c:10701 config/arc/arc.c:10740 config/arc/arc.c:10842
+#: config/arc/arc.c:10689 config/arc/arc.c:10728 config/arc/arc.c:10830
 #: config/avr/avr.c:9790
 #, gcc-internal-format
 msgid "%qE attribute allows only an integer constant argument"
 msgstr ""
 
-#: config/arc/arc.c:10721
+#: config/arc/arc.c:10709
 #, gcc-internal-format
 msgid "%qE attribute only valid for ARC EM architecture"
 msgstr ""
 
-#: config/arc/arc.c:10776
+#: config/arc/arc.c:10764
 #, gcc-internal-format
 msgid "%qE attribute only applies to types"
 msgstr ""
 
-#: config/arc/arc.c:10782
+#: config/arc/arc.c:10770
 #, gcc-internal-format
 msgid "argument of %qE attribute ignored"
 msgstr "аргумент атрибута %qE проігноровано"
 
-#: config/arc/arc.c:10832 config/avr/avr.c:9777 config/bfin/bfin.c:4827
+#: config/arc/arc.c:10820 config/avr/avr.c:9777 config/bfin/bfin.c:4827
 #: config/i386/winnt.c:63 config/msp430/msp430.c:2018
 #: config/nvptx/nvptx.c:4634
 #, gcc-internal-format
@@ -27646,174 +27687,174 @@
 msgid "%qE attribute only applies to variables"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2370
+#: config/arm/arm-builtins.c:2380
 #, gcc-internal-format
 msgid "this builtin is not supported for this target"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2475
+#: config/arm/arm-builtins.c:2485
 #, gcc-internal-format
 msgid "You must enable NEON instructions (e.g. -mfloat-abi=softfp -mfpu=neon) to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2513
+#: config/arm/arm-builtins.c:2523
 #, gcc-internal-format
 msgid "You must enable VFP instructions to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2573
+#: config/arm/arm-builtins.c:2583
 #, gcc-internal-format
 msgid "You must enable crypto instructions (e.g. include -mfloat-abi=softfp -mfpu=crypto-neon...) to use these intrinsics."
 msgstr ""
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:2633 config/arm/arm-builtins.c:2737
+#: config/arm/arm-builtins.c:2643 config/arm/arm-builtins.c:2747
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2641 config/arm/arm-builtins.c:2686
-#: config/arm/arm-builtins.c:2744 config/arm/arm-builtins.c:2753
+#: config/arm/arm-builtins.c:2651 config/arm/arm-builtins.c:2696
+#: config/arm/arm-builtins.c:2754 config/arm/arm-builtins.c:2763
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2646 config/arm/arm-builtins.c:2755
+#: config/arm/arm-builtins.c:2656 config/arm/arm-builtins.c:2765
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2651 config/arm/arm-builtins.c:2757
+#: config/arm/arm-builtins.c:2661 config/arm/arm-builtins.c:2767
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2823
+#: config/arm/arm-builtins.c:2833
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2828
+#: config/arm/arm-builtins.c:2838
 #, gcc-internal-format
 msgid "the range of mask should be in 0 to 255"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3016
+#: config/arm/arm-builtins.c:3026
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3018
+#: config/arm/arm-builtins.c:3028
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3020
+#: config/arm/arm-builtins.c:3030
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3022
+#: config/arm/arm-builtins.c:3032
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3028
+#: config/arm/arm-builtins.c:3038
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3030
+#: config/arm/arm-builtins.c:3040
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3035
+#: config/arm/arm-builtins.c:3045
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3037
+#: config/arm/arm-builtins.c:3047
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3039
+#: config/arm/arm-builtins.c:3049
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3041
+#: config/arm/arm-builtins.c:3051
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3043
+#: config/arm/arm-builtins.c:3053
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3045
+#: config/arm/arm-builtins.c:3055
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3047
+#: config/arm/arm-builtins.c:3057
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3049
+#: config/arm/arm-builtins.c:3059
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3051
+#: config/arm/arm-builtins.c:3061
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3053
+#: config/arm/arm-builtins.c:3063
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3055
+#: config/arm/arm-builtins.c:3065
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3057
+#: config/arm/arm-builtins.c:3067
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3059
+#: config/arm/arm-builtins.c:3069
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3061
+#: config/arm/arm-builtins.c:3071
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3063
+#: config/arm/arm-builtins.c:3073
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3065
+#: config/arm/arm-builtins.c:3075
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3067
+#: config/arm/arm-builtins.c:3077
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3069
+#: config/arm/arm-builtins.c:3079
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr ""
@@ -28720,551 +28761,551 @@
 msgid "can%'t set position in PCH file: %m"
 msgstr ""
 
-#: config/i386/i386.c:3177
+#: config/i386/i386.c:3180
 #, gcc-internal-format
 msgid "wrong argument %qs to option %qs"
 msgstr "помилковий аргумент %qs параметра %qs"
 
-#: config/i386/i386.c:3183
+#: config/i386/i386.c:3186
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr ""
 
-#: config/i386/i386.c:3193
+#: config/i386/i386.c:3196
 #, gcc-internal-format
 msgid "wrong strategy name %qs specified for option %qs"
 msgstr ""
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3219
+#: config/i386/i386.c:3222
 #, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386.c:3232
+#: config/i386/i386.c:3235
 #, gcc-internal-format
 msgid "unknown alignment %qs specified for option %qs"
 msgstr ""
 
-#: config/i386/i386.c:3242
+#: config/i386/i386.c:3245
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr ""
 
-#: config/i386/i386.c:3249
+#: config/i386/i386.c:3252
 #, gcc-internal-format
 msgid "too many size ranges specified in option %qs"
 msgstr ""
 
-#: config/i386/i386.c:3302
+#: config/i386/i386.c:3305
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown parameter to option -mtune-ctrl: %s"
 msgstr ""
 
-#: config/i386/i386.c:3726
+#: config/i386/i386.c:3729
 #, gcc-internal-format
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr ""
 
-#: config/i386/i386.c:3775
+#: config/i386/i386.c:3778
 #, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "%<-mtune=x86-64%> вважається застарілим; скористайтеся одним із відповідників: %<-mtune=k8%> або %<-mtune=generic%>"
 
-#: config/i386/i386.c:3777
+#: config/i386/i386.c:3780
 #, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr "%<target(\"tune=x86-64\")%> вважається застарілим; скористайтеся одним із відповідників: %<target(\"tune=k8\")%> або %<target(\"tune=generic\")%>"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3804
+#: config/i386/i386.c:3807
 #, gcc-internal-format
 msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386.c:3821
+#: config/i386/i386.c:3824
 #, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr ""
 
-#: config/i386/i386.c:3833
+#: config/i386/i386.c:3836
 #, gcc-internal-format
 msgid "-mabi=ms not supported with X32 ABI"
 msgstr "підтримки -mabi=ms для ABI X32 не передбачено"
 
-#: config/i386/i386.c:3851 config/i386/i386.c:3860 config/i386/i386.c:3872
-#: config/i386/i386.c:3883 config/i386/i386.c:3894
+#: config/i386/i386.c:3854 config/i386/i386.c:3863 config/i386/i386.c:3875
+#: config/i386/i386.c:3886 config/i386/i386.c:3897
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr ""
 
-#: config/i386/i386.c:3863 config/i386/i386.c:3875
+#: config/i386/i386.c:3866 config/i386/i386.c:3878
 #, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr ""
 
-#: config/i386/i386.c:3881 config/i386/i386.c:3890 config/i386/i386.c:5213
+#: config/i386/i386.c:3884 config/i386/i386.c:3893 config/i386/i386.c:5216
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr ""
 
-#: config/i386/i386.c:3918
+#: config/i386/i386.c:3921
 #, gcc-internal-format
 msgid "-masm=intel not supported in this configuration"
 msgstr ""
 
-#: config/i386/i386.c:3923
+#: config/i386/i386.c:3926
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr ""
 
-#: config/i386/i386.c:3932
+#: config/i386/i386.c:3935
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386.c:3934
+#: config/i386/i386.c:3937
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386.c:3941
+#: config/i386/i386.c:3944
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386.c:3943
+#: config/i386/i386.c:3946
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386.c:3951 config/i386/i386.c:4265
+#: config/i386/i386.c:3954 config/i386/i386.c:4268
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr ""
 
-#: config/i386/i386.c:4197 config/i386/i386.c:4200
+#: config/i386/i386.c:4200 config/i386/i386.c:4203
 #, gcc-internal-format
 msgid "Intel MPX does not support x32"
 msgstr ""
 
-#: config/i386/i386.c:4205
+#: config/i386/i386.c:4208
 #, gcc-internal-format
 msgid "bad value (%qs) for %<-march=%> switch"
 msgstr ""
 
-#: config/i386/i386.c:4206
+#: config/i386/i386.c:4209
 #, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"arch=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386.c:4228
+#: config/i386/i386.c:4231
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4230
+#: config/i386/i386.c:4233
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4235
+#: config/i386/i386.c:4238
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "коректними аргументами перемикача %<-march=%> є такі: %s"
 
-#: config/i386/i386.c:4236
+#: config/i386/i386.c:4239
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr ""
 
-#: config/i386/i386.c:4284
+#: config/i386/i386.c:4287
 #, gcc-internal-format
 msgid "bad value (%qs) for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386.c:4285
+#: config/i386/i386.c:4288
 #, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386.c:4305
+#: config/i386/i386.c:4308
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4307
+#: config/i386/i386.c:4310
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4312
+#: config/i386/i386.c:4315
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "коректними аргументами перемикача %<-mtune=%> є такі: %s"
 
-#: config/i386/i386.c:4313
+#: config/i386/i386.c:4316
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr ""
 
-#: config/i386/i386.c:4379
+#: config/i386/i386.c:4382
 #, gcc-internal-format
 msgid "-mregparm is ignored in 64-bit mode"
 msgstr ""
 
-#: config/i386/i386.c:4381
+#: config/i386/i386.c:4384
 #, gcc-internal-format
 msgid "-mregparm is ignored for Intel MCU psABI"
 msgstr ""
 
-#: config/i386/i386.c:4384
+#: config/i386/i386.c:4387
 #, gcc-internal-format, gfc-internal-format
 msgid "-mregparm=%d is not between 0 and %d"
 msgstr ""
 
-#: config/i386/i386.c:4417
+#: config/i386/i386.c:4420
 #, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr ""
 
-#: config/i386/i386.c:4418
+#: config/i386/i386.c:4421
 #, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr ""
 
-#: config/i386/i386.c:4497
+#: config/i386/i386.c:4500
 #, gcc-internal-format
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr ""
 
-#: config/i386/i386.c:4500
+#: config/i386/i386.c:4503
 #, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr ""
 
-#: config/i386/i386.c:4523
+#: config/i386/i386.c:4526
 #, gcc-internal-format, gfc-internal-format
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr ""
 
-#: config/i386/i386.c:4536
+#: config/i386/i386.c:4539
 #, gcc-internal-format
 msgid "-mnop-mcount is not compatible with this target"
 msgstr ""
 
-#: config/i386/i386.c:4539
+#: config/i386/i386.c:4542
 #, gcc-internal-format
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr ""
 
-#: config/i386/i386.c:4545
+#: config/i386/i386.c:4548
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386.c:4546
+#: config/i386/i386.c:4549
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386.c:4556
+#: config/i386/i386.c:4559
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr ""
 
-#: config/i386/i386.c:4563
+#: config/i386/i386.c:4566
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr ""
 
-#: config/i386/i386.c:4613
+#: config/i386/i386.c:4616
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr ""
 
-#: config/i386/i386.c:4615
+#: config/i386/i386.c:4618
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr ""
 
-#: config/i386/i386.c:4629
+#: config/i386/i386.c:4632
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr ""
 
-#: config/i386/i386.c:4631
+#: config/i386/i386.c:4634
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr ""
 
-#: config/i386/i386.c:4741
+#: config/i386/i386.c:4744
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr ""
 
-#: config/i386/i386.c:4744
+#: config/i386/i386.c:4747
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr ""
 
-#: config/i386/i386.c:4748
+#: config/i386/i386.c:4751
 #, gcc-internal-format
 msgid "-mcall-ms2sysv-xlogues isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386.c:4813 config/powerpcspe/powerpcspe.c:5663
+#: config/i386/i386.c:4816 config/powerpcspe/powerpcspe.c:5663
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown option for -mrecip=%s"
 msgstr ""
 
-#: config/i386/i386.c:4870 config/powerpcspe/powerpcspe.c:5339
+#: config/i386/i386.c:4873 config/powerpcspe/powerpcspe.c:5339
 #, gcc-internal-format
 msgid "%qs is not a valid number in -mstack-protector-guard-offset="
 msgstr ""
 
-#: config/i386/i386.c:4875 config/powerpcspe/powerpcspe.c:5344
+#: config/i386/i386.c:4878 config/powerpcspe/powerpcspe.c:5344
 #, gcc-internal-format
 msgid "%qs is not a valid offset in -mstack-protector-guard-offset="
 msgstr ""
 
-#: config/i386/i386.c:4907 config/powerpcspe/powerpcspe.c:5356
+#: config/i386/i386.c:4910 config/powerpcspe/powerpcspe.c:5356
 #, gcc-internal-format
 msgid "%qs is not a valid base register in -mstack-protector-guard-reg="
 msgstr ""
 
-#: config/i386/i386.c:5506 config/i386/i386.c:5553 config/s390/s390.c:15812
+#: config/i386/i386.c:5509 config/i386/i386.c:5556 config/s390/s390.c:15812
 #: config/s390/s390.c:15862 config/s390/s390.c:15879
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr ""
 
-#: config/i386/i386.c:5534
+#: config/i386/i386.c:5537
 #, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr ""
 
-#: config/i386/i386.c:5837
+#: config/i386/i386.c:5840
 #, gcc-internal-format
 msgid "interrupt and naked attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5852
+#: config/i386/i386.c:5855
 #, gcc-internal-format
 msgid "Only DWARF debug format is supported for interrupt service routine."
 msgstr ""
 
-#: config/i386/i386.c:5901
+#: config/i386/i386.c:5904
 #, gcc-internal-format
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5913
+#: config/i386/i386.c:5916
 #, gcc-internal-format
 msgid "%<-mindirect-branch=thunk-extern%>, %<-fcf-protection=branch%> and %<-fcheck-pointer-bounds%> are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5949
+#: config/i386/i386.c:5952
 #, gcc-internal-format
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6047
+#: config/i386/i386.c:6050
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in %s service routine"
 msgstr ""
 
-#: config/i386/i386.c:6051
+#: config/i386/i386.c:6054
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in function with no_caller_saved_registers attribute"
 msgstr ""
 
-#: config/i386/i386.c:6465 config/i386/i386.c:6516
+#: config/i386/i386.c:6468 config/i386/i386.c:6519
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6470
+#: config/i386/i386.c:6473
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6477 config/i386/i386.c:41444
+#: config/i386/i386.c:6480 config/i386/i386.c:41438
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr ""
 
-#: config/i386/i386.c:6483
+#: config/i386/i386.c:6486
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr ""
 
-#: config/i386/i386.c:6508 config/i386/i386.c:6551
+#: config/i386/i386.c:6511 config/i386/i386.c:6554
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6512
+#: config/i386/i386.c:6515
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6520 config/i386/i386.c:6569
+#: config/i386/i386.c:6523 config/i386/i386.c:6572
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6530 config/i386/i386.c:6547
+#: config/i386/i386.c:6533 config/i386/i386.c:6550
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6534
+#: config/i386/i386.c:6537
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6538 config/i386/i386.c:6565
+#: config/i386/i386.c:6541 config/i386/i386.c:6568
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6555 config/i386/i386.c:6573
+#: config/i386/i386.c:6558 config/i386/i386.c:6576
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6561
+#: config/i386/i386.c:6564
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr ""
 
-#: config/i386/i386.c:6805
+#: config/i386/i386.c:6808
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:6808
+#: config/i386/i386.c:6811
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:7126
+#: config/i386/i386.c:7129
 #, gcc-internal-format
 msgid "X32 does not support ms_abi attribute"
 msgstr ""
 
-#: config/i386/i386.c:7160
+#: config/i386/i386.c:7163
 #, gcc-internal-format
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr ""
 
-#: config/i386/i386.c:7502
+#: config/i386/i386.c:7505
 #, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7508
+#: config/i386/i386.c:7511
 #, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7522
+#: config/i386/i386.c:7525
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7528
+#: config/i386/i386.c:7531
 #, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7544
+#: config/i386/i386.c:7547
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7550
+#: config/i386/i386.c:7553
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7566
+#: config/i386/i386.c:7569
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7572
+#: config/i386/i386.c:7575
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7754
+#: config/i386/i386.c:7757
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:7871
+#: config/i386/i386.c:7874
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:7989
+#: config/i386/i386.c:7992
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:8152
+#: config/i386/i386.c:8155
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.c:8158
+#: config/i386/i386.c:8161
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.c:8174
+#: config/i386/i386.c:8177
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr ""
 
-#: config/i386/i386.c:8471 config/i386/i386.c:8750 config/i386/i386.c:9276
+#: config/i386/i386.c:8474 config/i386/i386.c:8753 config/i386/i386.c:9279
 #, gcc-internal-format
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:8473 config/i386/i386.c:8752 config/i386/i386.c:9278
+#: config/i386/i386.c:8476 config/i386/i386.c:8755 config/i386/i386.c:9281
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr ""
 
-#: config/i386/i386.c:9178
+#: config/i386/i386.c:9181
 #, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr ""
 
-#: config/i386/i386.c:11601
+#: config/i386/i386.c:11604
 #, gcc-internal-format, gfc-internal-format
 msgid "-mcall-ms2sysv-xlogues is not compatible with %s"
 msgstr ""
 
-#: config/i386/i386.c:13593
+#: config/i386/i386.c:13596
 #, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr ""
 
-#: config/i386/i386.c:13683
+#: config/i386/i386.c:13686
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr ""
 
-#: config/i386/i386.c:14970
+#: config/i386/i386.c:14973
 #, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr ""
 
-#: config/i386/i386.c:14990
+#: config/i386/i386.c:14993
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
 msgstr ""
@@ -29271,311 +29312,311 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:15001
+#: config/i386/i386.c:15004
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr ""
 
-#: config/i386/i386.c:17939
+#: config/i386/i386.c:17942
 #, gcc-internal-format
 msgid "'V' modifier on non-integer register"
 msgstr ""
 
-#: config/i386/i386.c:17950 config/i386/i386.c:17964
+#: config/i386/i386.c:17953 config/i386/i386.c:17967
 #, gcc-internal-format
 msgid "unsupported size for integer register"
 msgstr ""
 
-#: config/i386/i386.c:17996
+#: config/i386/i386.c:17999
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr ""
 
-#: config/i386/i386.c:18011
+#: config/i386/i386.c:18014
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr ""
 
-#: config/i386/i386.c:18202
+#: config/i386/i386.c:18205
 #, gcc-internal-format
 msgid "non-integer operand used with operand code 'z'"
 msgstr ""
 
-#: config/i386/i386.c:28467
+#: config/i386/i386.c:28470
 #, gcc-internal-format
 msgid "interrupt service routine can't be called directly"
 msgstr ""
 
-#: config/i386/i386.c:29995
+#: config/i386/i386.c:29998
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in -fabi-version=12 (GCC 8)"
 msgstr ""
 
-#: config/i386/i386.c:32435
+#: config/i386/i386.c:32438
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr ""
 
-#: config/i386/i386.c:32485
+#: config/i386/i386.c:32488
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for %s"
 msgstr ""
 
-#: config/i386/i386.c:32495
+#: config/i386/i386.c:32498
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr ""
 
-#: config/i386/i386.c:32657
+#: config/i386/i386.c:32660
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386.c:32662 config/i386/i386.c:32938
-#: config/rs6000/rs6000.c:37850
+#: config/i386/i386.c:32665 config/i386/i386.c:32941
+#: config/rs6000/rs6000.c:37906
 #, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr ""
 
-#: config/i386/i386.c:32795 config/rs6000/rs6000.c:37607
+#: config/i386/i386.c:32798 config/rs6000/rs6000.c:37663
 #, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr ""
 
-#: config/i386/i386.c:33207
+#: config/i386/i386.c:33210
 #, gcc-internal-format
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr ""
 
-#: config/i386/i386.c:33232 config/i386/i386.c:33282
+#: config/i386/i386.c:33235 config/i386/i386.c:33285
 #, gcc-internal-format, gfc-internal-format
 msgid "Parameter to builtin not valid: %s"
 msgstr ""
 
-#: config/i386/i386.c:33975 config/i386/i386.c:35415
+#: config/i386/i386.c:33978 config/i386/i386.c:35418
 #, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:34370
+#: config/i386/i386.c:34373
 #, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:34465
+#: config/i386/i386.c:34468
 #, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:35346
+#: config/i386/i386.c:35349
 #, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:35361
+#: config/i386/i386.c:35364
 #, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:35394
+#: config/i386/i386.c:35397
 #, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:35434
+#: config/i386/i386.c:35437
 #, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:35447
+#: config/i386/i386.c:35450
 #, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:35457
+#: config/i386/i386.c:35460
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:35462 config/i386/i386.c:36249
+#: config/i386/i386.c:35465 config/i386/i386.c:36252
 #, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:35596
+#: config/i386/i386.c:35599
 #, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr ""
 
-#: config/i386/i386.c:35601
+#: config/i386/i386.c:35604
 #, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr ""
 
-#: config/i386/i386.c:35607 config/i386/i386.c:35814
+#: config/i386/i386.c:35610 config/i386/i386.c:35817
 #, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr ""
 
-#: config/i386/i386.c:35796
+#: config/i386/i386.c:35799
 #, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:35802
+#: config/i386/i386.c:35805
 #, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:35805
+#: config/i386/i386.c:35808
 #, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:36247
+#: config/i386/i386.c:36250
 #, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:36329 config/powerpcspe/powerpcspe.c:16219
-#: config/rs6000/rs6000.c:15304
+#: config/i386/i386.c:36332 config/powerpcspe/powerpcspe.c:16219
+#: config/rs6000/rs6000.c:15348
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr ""
 
-#: config/i386/i386.c:36539
+#: config/i386/i386.c:36542
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr ""
 
-#: config/i386/i386.c:36543
+#: config/i386/i386.c:36546
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr ""
 
-#: config/i386/i386.c:37381
+#: config/i386/i386.c:37375
 #, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr ""
 
-#: config/i386/i386.c:38108 config/i386/i386.c:38290
+#: config/i386/i386.c:38102 config/i386/i386.c:38284
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386.c:38343
+#: config/i386/i386.c:38337
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386.c:38349
+#: config/i386/i386.c:38343
 #, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr ""
 
-#: config/i386/i386.c:38368
+#: config/i386/i386.c:38362
 #, gcc-internal-format
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:41431
+#: config/i386/i386.c:41425
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr ""
 
-#: config/i386/i386.c:41452
+#: config/i386/i386.c:41446
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr ""
 
-#: config/i386/i386.c:41485 config/i386/i386.c:41494
+#: config/i386/i386.c:41479 config/i386/i386.c:41488
 #, gcc-internal-format
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:41530 config/powerpcspe/powerpcspe.c:35868
-#: config/rs6000/rs6000.c:33065
+#: config/i386/i386.c:41524 config/powerpcspe/powerpcspe.c:35868
+#: config/rs6000/rs6000.c:33121
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr ""
 
-#: config/i386/i386.c:41555 config/i386/i386.c:41577 config/ia64/ia64.c:815
+#: config/i386/i386.c:41549 config/i386/i386.c:41571 config/ia64/ia64.c:815
 #: config/s390/s390.c:1153
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr ""
 
-#: config/i386/i386.c:41565 config/i386/i386.c:41587 config/s390/s390.c:1182
+#: config/i386/i386.c:41559 config/i386/i386.c:41581 config/s390/s390.c:1182
 #, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr ""
 
-#: config/i386/i386.c:41619
+#: config/i386/i386.c:41613
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386.c:41626
+#: config/i386/i386.c:41620
 #, gcc-internal-format, gfc-internal-format
 msgid "interrupt service routine should have unsigned %sint as the second argument"
 msgstr ""
 
-#: config/i386/i386.c:41636
+#: config/i386/i386.c:41630
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386.c:41639
+#: config/i386/i386.c:41633
 #, gcc-internal-format
 msgid "interrupt service routine can't have non-void return value"
 msgstr ""
 
-#: config/i386/i386.c:44676
+#: config/i386/i386.c:44670
 #, gcc-internal-format
 msgid "alternatives not allowed in asm flag output"
 msgstr ""
 
-#: config/i386/i386.c:44740
+#: config/i386/i386.c:44734
 #, gcc-internal-format
 msgid "unknown asm flag output %qs"
 msgstr ""
 
-#: config/i386/i386.c:44769
+#: config/i386/i386.c:44763
 #, gcc-internal-format
 msgid "invalid type for asm flag output"
 msgstr ""
 
-#: config/i386/i386.c:50634
+#: config/i386/i386.c:50628
 #, gcc-internal-format
 msgid "unknown architecture specific memory model"
 msgstr ""
 
-#: config/i386/i386.c:50641
+#: config/i386/i386.c:50635
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50647
+#: config/i386/i386.c:50641
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50671 config/i386/i386.c:50787
+#: config/i386/i386.c:50665 config/i386/i386.c:50781
 #, gcc-internal-format, gfc-internal-format
 msgid "unsupported simdlen %d"
 msgstr ""
 
-#: config/i386/i386.c:50690
+#: config/i386/i386.c:50684
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd"
 msgstr ""
 
-#: config/i386/i386.c:50712
+#: config/i386/i386.c:50706
 #, gcc-internal-format
 msgid "unsupported argument type %qT for simd"
 msgstr ""
 
-#: config/i386/i386.c:51033
+#: config/i386/i386.c:51027
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr ""
@@ -29796,7 +29837,7 @@
 msgstr ""
 
 #: config/m68k/m68k.c:1128 config/powerpcspe/powerpcspe.c:28512
-#: config/rs6000/rs6000.c:25791
+#: config/rs6000/rs6000.c:25868
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr ""
@@ -30369,58 +30410,58 @@
 
 #. Trampoline is not supported on reduced-set registers yet.
 #: config/nds32/nds32.c:2327 config/nds32/nds32.c:2381
-#: config/nds32/nds32.c:3127 config/nds32/nds32.c:3201
-#: config/nds32/nds32.c:3216 config/nds32/nds32.c:3222
-#: config/nds32/nds32.c:3284 config/nds32/nds32.c:3290
-#: config/nds32/nds32.c:3322
+#: config/nds32/nds32.c:3128 config/nds32/nds32.c:3202
+#: config/nds32/nds32.c:3217 config/nds32/nds32.c:3223
+#: config/nds32/nds32.c:3285 config/nds32/nds32.c:3291
+#: config/nds32/nds32.c:3323
 #, gcc-internal-format
 msgid "a nested function is not supported for reduced registers"
 msgstr ""
 
 #. The enum index value for array size is out of range.
-#: config/nds32/nds32.c:3025
+#: config/nds32/nds32.c:3026
 #, gcc-internal-format
 msgid "intrinsic register index is out of range"
 msgstr ""
 
-#: config/nds32/nds32.c:3041 config/nds32/nds32.c:3048
-#: config/nds32/nds32.c:3055 config/nds32/nds32.c:3062
-#: config/nds32/nds32.c:3069
+#: config/nds32/nds32.c:3042 config/nds32/nds32.c:3049
+#: config/nds32/nds32.c:3056 config/nds32/nds32.c:3063
+#: config/nds32/nds32.c:3070
 #, gcc-internal-format
 msgid "CCTL intrinsic function subtype out of range!"
 msgstr ""
 
-#: config/nds32/nds32.c:3508
+#: config/nds32/nds32.c:3509
 #, gcc-internal-format
 msgid "invalid id value for interrupt/exception attribute"
 msgstr ""
 
-#: config/nds32/nds32.c:3536
+#: config/nds32/nds32.c:3537
 #, gcc-internal-format
 msgid "invalid id value for reset attribute"
 msgstr ""
 
-#: config/nds32/nds32.c:3552
+#: config/nds32/nds32.c:3553
 #, gcc-internal-format
 msgid "invalid nmi function for reset attribute"
 msgstr ""
 
-#: config/nds32/nds32.c:3565
+#: config/nds32/nds32.c:3566
 #, gcc-internal-format
 msgid "invalid warm function for reset attribute"
 msgstr ""
 
-#: config/nds32/nds32.c:3638
+#: config/nds32/nds32.c:3639
 #, gcc-internal-format
 msgid "Disable FPU ISA, the ABI option must be enable '-mfloat-abi=soft'"
 msgstr ""
 
-#: config/nds32/nds32.c:3641
+#: config/nds32/nds32.c:3642
 #, gcc-internal-format
 msgid "'-mabi=2fp+' option only support when FPU available, must be enable '-mext-fpu-sp' or '-mext-fpu-dp'"
 msgstr ""
 
-#: config/nds32/nds32.c:3647
+#: config/nds32/nds32.c:3648
 #, gcc-internal-format
 msgid "position-independent code not supported"
 msgstr "підтримки коду із незалежним позиціюванням не передбачено"
@@ -30754,12 +30795,12 @@
 msgid "junk at end of #pragma longcall"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6154
+#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6152
 #, gcc-internal-format
 msgid "vec_lvsl is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6158
+#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6156
 #, gcc-internal-format
 msgid "vec_lvsr is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
@@ -30809,7 +30850,7 @@
 msgid "vec_insert only accepts 3 arguments"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6868
+#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6866
 #, gcc-internal-format
 msgid "passing arg %d of %qE discards qualifiers from pointer target type"
 msgstr ""
@@ -30894,7 +30935,7 @@
 msgid "target attribute or pragma changes SPE ABI"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4351 config/rs6000/rs6000.c:4223
+#: config/powerpcspe/powerpcspe.c:4351 config/rs6000/rs6000.c:4243
 #, gcc-internal-format
 msgid "AltiVec not supported in this target"
 msgstr ""
@@ -31040,7 +31081,7 @@
 msgid "-mvsx-small-integer requires -mpower8-vector, -mupper-regs-di, and -mdirect-move"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4959 config/rs6000/rs6000.c:4601
+#: config/powerpcspe/powerpcspe.c:4959 config/rs6000/rs6000.c:4628
 #, gcc-internal-format
 msgid "target attribute or pragma changes long double size"
 msgstr ""
@@ -31081,22 +31122,22 @@
 msgstr ""
 
 #: config/powerpcspe/powerpcspe.c:5140 config/powerpcspe/powerpcspe.c:5155
-#: config/rs6000/rs6000.c:4766 config/rs6000/rs6000.c:4781
+#: config/rs6000/rs6000.c:4791 config/rs6000/rs6000.c:4806
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:5168 config/rs6000/rs6000.c:4794
+#: config/powerpcspe/powerpcspe.c:5168 config/rs6000/rs6000.c:4819
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:5234 config/rs6000/rs6000.c:4828
+#: config/powerpcspe/powerpcspe.c:5234 config/rs6000/rs6000.c:4853
 #, gcc-internal-format
 msgid "target attribute or pragma changes single precision floating point"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:5237 config/rs6000/rs6000.c:4831
+#: config/powerpcspe/powerpcspe.c:5237 config/rs6000/rs6000.c:4856
 #, gcc-internal-format
 msgid "target attribute or pragma changes double precision floating point"
 msgstr ""
@@ -31106,12 +31147,12 @@
 msgid "-mstack-protector-guard=tls needs a valid base register"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:8415 config/rs6000/rs6000.c:7925
+#: config/powerpcspe/powerpcspe.c:8415 config/rs6000/rs6000.c:7950
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11237
+#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11269
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
@@ -31121,7 +31162,7 @@
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11595
+#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11633
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr ""
@@ -31131,12 +31172,12 @@
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12604
+#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12648
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12779
+#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12823
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
@@ -31146,28 +31187,28 @@
 msgid "internal error: builtin function %s already processed"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:13971
+#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:14015
 #, gcc-internal-format
 msgid "argument 1 must be an 8-bit field value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14015
+#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14059
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr ""
 
 #: config/powerpcspe/powerpcspe.c:14934 config/powerpcspe/powerpcspe.c:16803
-#: config/rs6000/rs6000.c:14101
+#: config/rs6000/rs6000.c:14145
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14119
+#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14163
 #, gcc-internal-format
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14135
+#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14179
 #, gcc-internal-format
 msgid "argument 2 must be a 7-bit unsigned literal"
 msgstr ""
@@ -31187,12 +31228,12 @@
 msgid "builtin %s is only valid in 64-bit mode"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14791
+#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14835
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %d must be an unsigned literal"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14793
+#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14837
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr ""
@@ -31214,53 +31255,53 @@
 msgid "hwcap %s is an invalid argument to builtin %s"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15065
+#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15109
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15090
+#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15134
 #, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15110
+#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15154
 #, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15122
+#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15166
 #, gcc-internal-format
 msgid "argument 1 must be 0 or 2"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15134
+#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15178
 #, gcc-internal-format
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15148
+#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15192
 #, gcc-internal-format
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15160
+#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15204
 #, gcc-internal-format
 msgid "argument 2 must be 0 or 1"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15168
+#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15212
 #, gcc-internal-format
 msgid "argument 3 must be in the range 0..15"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15237
-#: config/rs6000/rs6000.c:15569
+#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15281
+#: config/rs6000/rs6000.c:15613
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15394
+#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15438
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr ""
@@ -31385,7 +31426,7 @@
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25758
+#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25835
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr ""
@@ -31395,12 +31436,12 @@
 msgid "-fsplit-stack uses register r29"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29459
+#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29536
 #, gcc-internal-format
 msgid "Stack frame larger than 2G is not supported for -fsplit-stack"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30447
+#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30524
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr ""
@@ -31410,22 +31451,22 @@
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32830
+#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32907
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32832
+#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32909
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32834
+#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32911
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32836
+#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32913
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr ""
@@ -31435,7 +31476,7 @@
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32845
+#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32922
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr ""
@@ -31977,71 +32018,71 @@
 "Please use an explicit cpu name.  Valid cpu names are: %s"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6168 config/rs6000/rs6000-c.c:6219
-#: config/rs6000/rs6000-c.c:6489 config/rs6000/rs6000-c.c:6555
-#: config/rs6000/rs6000-c.c:6916 config/rs6000/rs6000-c.c:6963
+#: config/rs6000/rs6000-c.c:6166 config/rs6000/rs6000-c.c:6217
+#: config/rs6000/rs6000-c.c:6487 config/rs6000/rs6000-c.c:6553
+#: config/rs6000/rs6000-c.c:6914 config/rs6000/rs6000-c.c:6961
 #, gcc-internal-format
 msgid "builtin %qs only accepts 2 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6292 config/rs6000/rs6000-c.c:6375
-#: config/rs6000/rs6000-c.c:6736
+#: config/rs6000/rs6000-c.c:6290 config/rs6000/rs6000-c.c:6373
+#: config/rs6000/rs6000-c.c:6734
 #, gcc-internal-format
 msgid "builtin %qs only accepts 3 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6484
+#: config/rs6000/rs6000-c.c:6482
 #, gcc-internal-format
 msgid "builtin %qs only accepts 1 argument"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:7054
+#: config/rs6000/rs6000-c.c:7052
 #, gcc-internal-format
 msgid "builtin %qs requires builtin %qs"
 msgstr "вбудований код %qs потребує вбудованого коду %qs"
 
-#: config/rs6000/rs6000-c.c:7058
+#: config/rs6000/rs6000-c.c:7056
 #, gcc-internal-format
 msgid "builtin function %qs not supported in this compiler configuration"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:7068
+#: config/rs6000/rs6000-c.c:7066
 #, gcc-internal-format
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3754 config/rs6000/rs6000.c:3757
-#: config/rs6000/rs6000.c:3760
+#: config/rs6000/rs6000.c:3772 config/rs6000/rs6000.c:3775
+#: config/rs6000/rs6000.c:3778
 #, gcc-internal-format
 msgid "%qs requires %qs or %qs"
 msgstr "%qs потребує %qs або %qs"
 
-#: config/rs6000/rs6000.c:3861
+#: config/rs6000/rs6000.c:3879
 #, gcc-internal-format
 msgid "%qs requires PowerPC64 architecture, enabling"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4037
+#: config/rs6000/rs6000.c:4057
 #, gcc-internal-format
 msgid "%qs command-line option is deprecated"
 msgstr "параметр командного рядка %qs є застарілим"
 
-#: config/rs6000/rs6000.c:4048
+#: config/rs6000/rs6000.c:4068
 #, gcc-internal-format
 msgid "%qs is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4147
+#: config/rs6000/rs6000.c:4167
 #, gcc-internal-format
 msgid "will not generate %qs instructions because assembler lacks %qs support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4240
+#: config/rs6000/rs6000.c:4260
 #, gcc-internal-format
 msgid "%qs is not supported on little endian systems"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4333
+#: config/rs6000/rs6000.c:4353
 #, gcc-internal-format
 msgid "power9 target option is incompatible with %<%s=<xxx>%> for <xxx> less than power9"
 msgstr ""
@@ -32048,7 +32089,7 @@
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:4341
+#: config/rs6000/rs6000.c:4361
 #, gcc-internal-format
 msgid "%qs incompatible with explicitly disabled options"
 msgstr ""
@@ -32057,240 +32098,241 @@
 #. error messages.  However, if users have managed to select
 #. power9-fusion without selecting power8-fusion, they
 #. already know about undocumented flags.
-#: config/rs6000/rs6000.c:4366 config/rs6000/rs6000.c:4373
-#: config/rs6000/rs6000.c:4380 config/rs6000/rs6000.c:4388
-#: config/rs6000/rs6000.c:4407 config/rs6000/rs6000.c:4464
-#: config/rs6000/rs6000.c:4468 config/rs6000/rs6000.c:4485
-#: config/rs6000/rs6000.c:4538 config/rs6000/rs6000.c:4565
-#: config/rs6000/rs6000.c:4580 config/rs6000/rs6000.c:4588
-#: config/rs6000/rs6000.c:4684
+#: config/rs6000/rs6000.c:4386 config/rs6000/rs6000.c:4393
+#: config/rs6000/rs6000.c:4400 config/rs6000/rs6000.c:4408
+#: config/rs6000/rs6000.c:4427 config/rs6000/rs6000.c:4484
+#: config/rs6000/rs6000.c:4488 config/rs6000/rs6000.c:4505
+#: config/rs6000/rs6000.c:4558 config/rs6000/rs6000.c:4585
+#: config/rs6000/rs6000.c:4600 config/rs6000/rs6000.c:4608
+#: config/rs6000/rs6000.c:4709
 #, gcc-internal-format
 msgid "%qs requires %qs"
 msgstr "%qs потребує %qs"
 
-#: config/rs6000/rs6000.c:4625
+#: config/rs6000/rs6000.c:4650
 #, gcc-internal-format
 msgid "Using IEEE extended precision long double"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4627
+#: config/rs6000/rs6000.c:4652
 #, gcc-internal-format
 msgid "Using IBM extended precision long double"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4644
+#: config/rs6000/rs6000.c:4669
 #, gcc-internal-format
 msgid "%qs requires VSX support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4653
+#: config/rs6000/rs6000.c:4678
 #, gcc-internal-format
 msgid "The -mfloat128 option may not be fully supported"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4676
+#: config/rs6000/rs6000.c:4701
 #, gcc-internal-format
 msgid "%qs requires full ISA 3.0 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4743
+#: config/rs6000/rs6000.c:4768
 #, gcc-internal-format
 msgid "unknown vectorization library ABI type (%qs) for %qs switch"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4930
+#: config/rs6000/rs6000.c:4955
 #, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4935
+#: config/rs6000/rs6000.c:4960
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr "%qs не є коректним зсувом у %qs"
 
-#: config/rs6000/rs6000.c:4947
+#: config/rs6000/rs6000.c:4972
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4955
+#: config/rs6000/rs6000.c:4980
 #, gcc-internal-format
 msgid "%qs needs a valid base register"
 msgstr ""
 
-#: config/rs6000/rs6000.c:5253
+#: config/rs6000/rs6000.c:5278
 #, gcc-internal-format
 msgid "unknown option for %<%s=%s%>"
 msgstr "невідомий параметр для %<%s=%s%>"
 
-#: config/rs6000/rs6000.c:5290
+#: config/rs6000/rs6000.c:5315
 #, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11401
+#: config/rs6000/rs6000.c:11439
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11862
+#: config/rs6000/rs6000.c:11906
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13572
+#: config/rs6000/rs6000.c:13616
 #, gcc-internal-format
 msgid "internal error: builtin function %qs already processed"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14150
+#: config/rs6000/rs6000.c:14194
 #, gcc-internal-format
 msgid "argument 2 must be a 1-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14189
+#: config/rs6000/rs6000.c:14233
 #, gcc-internal-format
 msgid "argument 1 of %qs must be a constant"
 msgstr "аргумент 1 %qs має бути сталою"
 
-#: config/rs6000/rs6000.c:14247 config/rs6000/rs6000.c:15898
+#: config/rs6000/rs6000.c:14291 config/rs6000/rs6000.c:15942
 #, gcc-internal-format
 msgid "argument 1 of %qs is out of range"
 msgstr "аргумент 1 %qs лежить поза припустимим діапазоном"
 
-#: config/rs6000/rs6000.c:14742
+#: config/rs6000/rs6000.c:14786
 #, gcc-internal-format
 msgid "builtin %qs is only valid in 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14939
+#: config/rs6000/rs6000.c:14983
 #, gcc-internal-format
 msgid "builtin %qs only accepts a string argument"
 msgstr ""
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000.c:14958
+#: config/rs6000/rs6000.c:15002
 #, gcc-internal-format
 msgid "cpu %qs is an invalid argument to builtin %qs"
 msgstr ""
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000.c:14986
+#: config/rs6000/rs6000.c:15030
 #, gcc-internal-format
 msgid "%s %qs is an invalid argument to builtin %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15012
+#: config/rs6000/rs6000.c:15056
 #, gcc-internal-format
 msgid "builtin %qs needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15616
+#: config/rs6000/rs6000.c:15660
 #, gcc-internal-format
 msgid "second argument to %qs must be 0..12"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15631
+#: config/rs6000/rs6000.c:15675
 #, gcc-internal-format
 msgid "third argument to %qs must be 0..12"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15850
+#: config/rs6000/rs6000.c:15894
 #, gcc-internal-format, gfc-internal-format
 msgid "argument 1 of %s must be a constant"
 msgstr "аргумент 1 %s має бути сталим"
 
-#: config/rs6000/rs6000.c:15932
+#: config/rs6000/rs6000.c:15976
 #, gcc-internal-format
 msgid "builtin function %qs is only valid for the cell processor"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15934 config/rs6000/rs6000.c:15936
-#: config/rs6000/rs6000.c:15938 config/rs6000/rs6000.c:15940
-#: config/rs6000/rs6000.c:15946 config/rs6000/rs6000.c:15948
-#: config/rs6000/rs6000.c:15955 config/rs6000/rs6000.c:15962
-#: config/rs6000/rs6000.c:15969 config/rs6000/rs6000.c:15975
+#: config/rs6000/rs6000.c:15978 config/rs6000/rs6000.c:15980
+#: config/rs6000/rs6000.c:15982 config/rs6000/rs6000.c:15984
+#: config/rs6000/rs6000.c:15990 config/rs6000/rs6000.c:15992
+#: config/rs6000/rs6000.c:15999 config/rs6000/rs6000.c:16006
+#: config/rs6000/rs6000.c:16011 config/rs6000/rs6000.c:16014
+#: config/rs6000/rs6000.c:16018 config/rs6000/rs6000.c:16024
 #, gcc-internal-format
 msgid "builtin function %qs requires the %qs option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15943 config/rs6000/rs6000.c:15952
-#: config/rs6000/rs6000.c:15959 config/rs6000/rs6000.c:15966
+#: config/rs6000/rs6000.c:15987 config/rs6000/rs6000.c:15996
+#: config/rs6000/rs6000.c:16003
 #, gcc-internal-format
 msgid "builtin function %qs requires the %qs and %qs options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15972
+#: config/rs6000/rs6000.c:16021
 #, gcc-internal-format
 msgid "builtin function %qs requires ISA 3.0 IEEE 128-bit floating point"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15978
+#: config/rs6000/rs6000.c:16027
 #, gcc-internal-format
 msgid "builtin function %qs requires the %qs (or newer), and %qs or %qs options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15982
+#: config/rs6000/rs6000.c:16031
 #, gcc-internal-format
 msgid "builtin function %qs is not supported with the current options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18218
+#: config/rs6000/rs6000.c:18290
 #, gcc-internal-format
 msgid "internal error: builtin function %qs had an unexpected return type %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18235
+#: config/rs6000/rs6000.c:18307
 #, gcc-internal-format
 msgid "internal error: builtin function %qs, argument %d had unexpected argument type %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:29451
+#: config/rs6000/rs6000.c:29528
 #, gcc-internal-format
 msgid "%qs uses register r29"
 msgstr "%qs використовує регістр r29"
 
-#: config/rs6000/rs6000.c:32748
+#: config/rs6000/rs6000.c:32825
 #, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32842
+#: config/rs6000/rs6000.c:32919
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32850
+#: config/rs6000/rs6000.c:32927
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32853
+#: config/rs6000/rs6000.c:32930
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:36876
+#: config/rs6000/rs6000.c:36932
 #, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "некоректний процесор %qs для %s%qs%s"
 
-#: config/rs6000/rs6000.c:36879
+#: config/rs6000/rs6000.c:36935
 #, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr ""
 
-#: config/rs6000/rs6000.c:36881
+#: config/rs6000/rs6000.c:36937
 #, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:37416
+#: config/rs6000/rs6000.c:37472
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr "%<-mno-%s%> вимикає %<-m%s%>"
 
-#: config/rs6000/rs6000.c:37575
+#: config/rs6000/rs6000.c:37631
 #, gcc-internal-format
 msgid "target_clones attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
@@ -33027,48 +33069,48 @@
 msgid "subprogram %q+F not marked Inline"
 msgstr ""
 
-#: ada/gcc-interface/trans.c:6404
+#: ada/gcc-interface/trans.c:6401
 #, gcc-internal-format
 msgid "out-of-bounds access may be optimized away"
 msgstr ""
 
-#: ada/gcc-interface/trans.c:6406
+#: ada/gcc-interface/trans.c:6403
 #, gcc-internal-format
 msgid "containing loop"
 msgstr ""
 
-#: ada/gcc-interface/utils.c:3887
+#: ada/gcc-interface/utils.c:3890
 #, gcc-internal-format
 msgid "invalid element type for attribute %qs"
 msgstr ""
 
-#: ada/gcc-interface/utils.c:3911
+#: ada/gcc-interface/utils.c:3914
 #, gcc-internal-format
 msgid "number of components of vector not a power of two"
 msgstr ""
 
-#: ada/gcc-interface/utils.c:6037 ada/gcc-interface/utils.c:6215
-#: ada/gcc-interface/utils.c:6322
+#: ada/gcc-interface/utils.c:6043 ada/gcc-interface/utils.c:6220
+#: ada/gcc-interface/utils.c:6327
 #, gcc-internal-format
 msgid "%qs attribute ignored"
 msgstr ""
 
-#: ada/gcc-interface/utils.c:6158
+#: ada/gcc-interface/utils.c:6164
 #, gcc-internal-format
 msgid "%qs attribute requires prototypes with named arguments"
 msgstr ""
 
-#: ada/gcc-interface/utils.c:6167
+#: ada/gcc-interface/utils.c:6173
 #, gcc-internal-format
 msgid "%qs attribute only applies to variadic functions"
 msgstr ""
 
-#: ada/gcc-interface/utils.c:6282
+#: ada/gcc-interface/utils.c:6287
 #, gcc-internal-format
 msgid "%qE attribute has no effect"
 msgstr ""
 
-#: ada/gcc-interface/utils.c:6406
+#: ada/gcc-interface/utils.c:6411
 #, gcc-internal-format
 msgid "attribute %qs applies to array types only"
 msgstr ""
@@ -33083,7 +33125,7 @@
 #. an unprototyped function, it is compile-time undefined;
 #. making it a constraint in that case was rejected in
 #. DR#252.
-#: c/c-convert.c:101 c/c-typeck.c:2175 c/c-typeck.c:6507 c/c-typeck.c:12138
+#: c/c-convert.c:101 c/c-typeck.c:2175 c/c-typeck.c:6512 c/c-typeck.c:12143
 #: cp/typeck.c:2027 cp/typeck.c:7977 cp/typeck.c:8742
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
@@ -33144,7 +33186,7 @@
 msgid "type of array %q+D completed incompatibly with implicit initialization"
 msgstr ""
 
-#: c/c-decl.c:1567 c/c-decl.c:6701 c/c-decl.c:7574 c/c-decl.c:8381
+#: c/c-decl.c:1567 c/c-decl.c:6721 c/c-decl.c:7594 c/c-decl.c:8401
 #, gcc-internal-format
 msgid "originally defined here"
 msgstr ""
@@ -33549,16 +33591,11 @@
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.c:4548 c/c-decl.c:7147
+#: c/c-decl.c:4548 c/c-decl.c:7167
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr ""
 
-#: c/c-decl.c:4635 cp/decl2.c:1520
-#, gcc-internal-format
-msgid "%q+D in declare target directive does not have mappable type"
-msgstr ""
-
 #: c/c-decl.c:4693
 #, gcc-internal-format
 msgid "%q+D is usually a function"
@@ -33584,7 +33621,7 @@
 #. of VLAs themselves count as VLAs, it does not make
 #. sense to permit them to be initialized given that
 #. ordinary VLAs may not be initialized.
-#: c/c-decl.c:4732 c/c-decl.c:4747 c/c-typeck.c:7630
+#: c/c-decl.c:4732 c/c-decl.c:4747 c/c-typeck.c:7635
 #, gcc-internal-format
 msgid "variable-sized object may not be initialized"
 msgstr ""
@@ -33644,202 +33681,207 @@
 msgid "uninitialized const %qD is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:5268
+#: c/c-decl.c:5224 cp/decl.c:7318
 #, gcc-internal-format
+msgid "%q+D in declare target directive does not have mappable type"
+msgstr ""
+
+#: c/c-decl.c:5288
+#, gcc-internal-format
 msgid "ISO C forbids forward parameter declarations"
 msgstr ""
 
-#: c/c-decl.c:5371
+#: c/c-decl.c:5391
 #, gcc-internal-format
 msgid "defining a type in a compound literal is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:5425 c/c-decl.c:5440
+#: c/c-decl.c:5445 c/c-decl.c:5460
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant"
 msgstr ""
 
-#: c/c-decl.c:5435
+#: c/c-decl.c:5455
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant expression"
 msgstr ""
 
-#: c/c-decl.c:5446
+#: c/c-decl.c:5466
 #, gcc-internal-format
 msgid "negative width in bit-field %qs"
 msgstr ""
 
-#: c/c-decl.c:5451
+#: c/c-decl.c:5471
 #, gcc-internal-format
 msgid "zero width for bit-field %qs"
 msgstr ""
 
-#: c/c-decl.c:5461
+#: c/c-decl.c:5481
 #, gcc-internal-format
 msgid "bit-field %qs has invalid type"
 msgstr ""
 
-#: c/c-decl.c:5467
+#: c/c-decl.c:5487
 #, gcc-internal-format
 msgid "cannot declare bit-field %qs with %<warn_if_not_aligned%> type"
 msgstr ""
 
-#: c/c-decl.c:5478
+#: c/c-decl.c:5498
 #, gcc-internal-format
 msgid "type of bit-field %qs is a GCC extension"
 msgstr ""
 
-#: c/c-decl.c:5484
+#: c/c-decl.c:5504
 #, gcc-internal-format
 msgid "width of %qs exceeds its type"
 msgstr ""
 
-#: c/c-decl.c:5497
+#: c/c-decl.c:5517
 #, gcc-internal-format
 msgid "%qs is narrower than values of its type"
 msgstr ""
 
-#: c/c-decl.c:5512
+#: c/c-decl.c:5532
 #, gcc-internal-format
 msgid "ISO C90 forbids array %qE whose size can%'t be evaluated"
 msgstr ""
 
-#: c/c-decl.c:5515
+#: c/c-decl.c:5535
 #, gcc-internal-format
 msgid "ISO C90 forbids array whose size can%'t be evaluated"
 msgstr ""
 
-#: c/c-decl.c:5522
+#: c/c-decl.c:5542
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array %qE"
 msgstr ""
 
-#: c/c-decl.c:5524
+#: c/c-decl.c:5544
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array"
 msgstr ""
 
-#: c/c-decl.c:5733 c/c-decl.c:6107 c/c-decl.c:6117
+#: c/c-decl.c:5753 c/c-decl.c:6127 c/c-decl.c:6137
 #, gcc-internal-format
 msgid "variably modified %qE at file scope"
 msgstr ""
 
-#: c/c-decl.c:5735
+#: c/c-decl.c:5755
 #, gcc-internal-format
 msgid "variably modified field at file scope"
 msgstr ""
 
-#: c/c-decl.c:5755
+#: c/c-decl.c:5775
 #, gcc-internal-format
 msgid "type defaults to %<int%> in declaration of %qE"
 msgstr ""
 
-#: c/c-decl.c:5759
+#: c/c-decl.c:5779
 #, gcc-internal-format
 msgid "type defaults to %<int%> in type name"
 msgstr ""
 
-#: c/c-decl.c:5791
+#: c/c-decl.c:5811
 #, gcc-internal-format
 msgid "duplicate %<const%>"
 msgstr "дублювання %<const%>"
 
-#: c/c-decl.c:5793
+#: c/c-decl.c:5813
 #, gcc-internal-format
 msgid "duplicate %<restrict%>"
 msgstr "дублювання %<restrict%>"
 
-#: c/c-decl.c:5795
+#: c/c-decl.c:5815
 #, gcc-internal-format
 msgid "duplicate %<volatile%>"
 msgstr "дублювання %<volatile%>"
 
-#: c/c-decl.c:5797
+#: c/c-decl.c:5817
 #, gcc-internal-format
 msgid "duplicate %<_Atomic%>"
 msgstr "дублювання %<_Atomic%>"
 
-#: c/c-decl.c:5800
+#: c/c-decl.c:5820
 #, gcc-internal-format, gfc-internal-format
 msgid "conflicting named address spaces (%s vs %s)"
 msgstr ""
 
-#: c/c-decl.c:5823 c/c-parser.c:2821
+#: c/c-decl.c:5843 c/c-parser.c:2821
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified array type"
 msgstr ""
 
-#: c/c-decl.c:5837
+#: c/c-decl.c:5857
 #, gcc-internal-format
 msgid "function definition declared %<auto%>"
 msgstr ""
 
-#: c/c-decl.c:5839
+#: c/c-decl.c:5859
 #, gcc-internal-format
 msgid "function definition declared %<register%>"
 msgstr ""
 
-#: c/c-decl.c:5841
+#: c/c-decl.c:5861
 #, gcc-internal-format
 msgid "function definition declared %<typedef%>"
 msgstr ""
 
-#: c/c-decl.c:5843
+#: c/c-decl.c:5863
 #, gcc-internal-format
 msgid "function definition declared %qs"
 msgstr ""
 
-#: c/c-decl.c:5861
+#: c/c-decl.c:5881
 #, gcc-internal-format
 msgid "storage class specified for structure field %qE"
 msgstr ""
 
-#: c/c-decl.c:5864
+#: c/c-decl.c:5884
 #, gcc-internal-format
 msgid "storage class specified for structure field"
 msgstr ""
 
-#: c/c-decl.c:5868
+#: c/c-decl.c:5888
 #, gcc-internal-format
 msgid "storage class specified for parameter %qE"
 msgstr ""
 
-#: c/c-decl.c:5871
+#: c/c-decl.c:5891
 #, gcc-internal-format
 msgid "storage class specified for unnamed parameter"
 msgstr ""
 
-#: c/c-decl.c:5874 cp/decl.c:10935
+#: c/c-decl.c:5894 cp/decl.c:10959
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr ""
 
-#: c/c-decl.c:5891
+#: c/c-decl.c:5911
 #, gcc-internal-format
 msgid "%qE initialized and declared %<extern%>"
 msgstr ""
 
-#: c/c-decl.c:5895
+#: c/c-decl.c:5915
 #, gcc-internal-format
 msgid "%qE has both %<extern%> and initializer"
 msgstr ""
 
-#: c/c-decl.c:5900
+#: c/c-decl.c:5920
 #, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<auto%>"
 msgstr ""
 
-#: c/c-decl.c:5904
+#: c/c-decl.c:5924
 #, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<register%>"
 msgstr ""
 
-#: c/c-decl.c:5909
+#: c/c-decl.c:5929
 #, gcc-internal-format
 msgid "nested function %qE declared %<extern%>"
 msgstr ""
 
-#: c/c-decl.c:5912
+#: c/c-decl.c:5932
 #, gcc-internal-format
 msgid "function-scope %qE implicitly auto and declared %qs"
 msgstr ""
@@ -33847,701 +33889,701 @@
 #. Only the innermost declarator (making a parameter be of
 #. array type which is converted to pointer type)
 #. may have static or type qualifiers.
-#: c/c-decl.c:5959 c/c-decl.c:6328
+#: c/c-decl.c:5979 c/c-decl.c:6348
 #, gcc-internal-format
 msgid "static or type qualifiers in non-parameter array declarator"
 msgstr ""
 
-#: c/c-decl.c:6007
+#: c/c-decl.c:6027
 #, gcc-internal-format
 msgid "declaration of %qE as array of voids"
 msgstr ""
 
-#: c/c-decl.c:6009
+#: c/c-decl.c:6029
 #, gcc-internal-format
 msgid "declaration of type name as array of voids"
 msgstr ""
 
-#: c/c-decl.c:6016
+#: c/c-decl.c:6036
 #, gcc-internal-format
 msgid "declaration of %qE as array of functions"
 msgstr ""
 
-#: c/c-decl.c:6019
+#: c/c-decl.c:6039
 #, gcc-internal-format
 msgid "declaration of type name as array of functions"
 msgstr ""
 
-#: c/c-decl.c:6027 c/c-decl.c:8085
+#: c/c-decl.c:6047 c/c-decl.c:8105
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr ""
 
-#: c/c-decl.c:6053
+#: c/c-decl.c:6073
 #, gcc-internal-format
 msgid "size of array %qE has non-integer type"
 msgstr ""
 
-#: c/c-decl.c:6057
+#: c/c-decl.c:6077
 #, gcc-internal-format
 msgid "size of unnamed array has non-integer type"
 msgstr ""
 
-#: c/c-decl.c:6064
+#: c/c-decl.c:6084
 #, gcc-internal-format
 msgid "size of array %qE has incomplete type"
 msgstr ""
 
-#: c/c-decl.c:6067
+#: c/c-decl.c:6087
 #, gcc-internal-format
 msgid "size of unnamed array has incomplete type"
 msgstr ""
 
-#: c/c-decl.c:6078
+#: c/c-decl.c:6098
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array %qE"
 msgstr ""
 
-#: c/c-decl.c:6081
+#: c/c-decl.c:6101
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array"
 msgstr ""
 
-#: c/c-decl.c:6090
+#: c/c-decl.c:6110
 #, gcc-internal-format
 msgid "size of array %qE is negative"
 msgstr ""
 
-#: c/c-decl.c:6092
+#: c/c-decl.c:6112
 #, gcc-internal-format
 msgid "size of unnamed array is negative"
 msgstr ""
 
-#: c/c-decl.c:6216 c/c-decl.c:6871
+#: c/c-decl.c:6236 c/c-decl.c:6891
 #, gcc-internal-format
 msgid "ISO C90 does not support flexible array members"
 msgstr ""
 
 #. C99 6.7.5.2p4
-#: c/c-decl.c:6238
+#: c/c-decl.c:6258
 #, gcc-internal-format
 msgid "%<[*]%> not in a declaration"
 msgstr ""
 
-#: c/c-decl.c:6251
+#: c/c-decl.c:6271
 #, gcc-internal-format
 msgid "array type has incomplete element type %qT"
 msgstr ""
 
-#: c/c-decl.c:6257
+#: c/c-decl.c:6277
 #, gcc-internal-format
 msgid "declaration of %qE as multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: c/c-decl.c:6261
+#: c/c-decl.c:6281
 #, gcc-internal-format
 msgid "declaration of multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: c/c-decl.c:6364
+#: c/c-decl.c:6384
 #, gcc-internal-format
 msgid "%qE declared as function returning a function"
 msgstr ""
 
-#: c/c-decl.c:6367
+#: c/c-decl.c:6387
 #, gcc-internal-format
 msgid "type name declared as function returning a function"
 msgstr ""
 
-#: c/c-decl.c:6374
+#: c/c-decl.c:6394
 #, gcc-internal-format
 msgid "%qE declared as function returning an array"
 msgstr ""
 
-#: c/c-decl.c:6377
+#: c/c-decl.c:6397
 #, gcc-internal-format
 msgid "type name declared as function returning an array"
 msgstr ""
 
-#: c/c-decl.c:6418
+#: c/c-decl.c:6438
 #, gcc-internal-format
 msgid "function definition has qualified void return type"
 msgstr ""
 
-#: c/c-decl.c:6421 cp/decl.c:11201
+#: c/c-decl.c:6441 cp/decl.c:11225
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr ""
 
-#: c/c-decl.c:6459 c/c-decl.c:6668 c/c-decl.c:6721 c/c-decl.c:6805
-#: c/c-decl.c:6926 c/c-parser.c:2823
+#: c/c-decl.c:6479 c/c-decl.c:6688 c/c-decl.c:6741 c/c-decl.c:6825
+#: c/c-decl.c:6946 c/c-parser.c:2823
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified function type"
 msgstr ""
 
-#: c/c-decl.c:6465 c/c-decl.c:6674 c/c-decl.c:6810 c/c-decl.c:6931
+#: c/c-decl.c:6485 c/c-decl.c:6694 c/c-decl.c:6830 c/c-decl.c:6951
 #, gcc-internal-format
 msgid "ISO C forbids qualified function types"
 msgstr ""
 
-#: c/c-decl.c:6559
+#: c/c-decl.c:6579
 #, gcc-internal-format
 msgid "%qs combined with %<auto%> qualifier for %qE"
 msgstr ""
 
-#: c/c-decl.c:6563
+#: c/c-decl.c:6583
 #, gcc-internal-format
 msgid "%qs combined with %<register%> qualifier for %qE"
 msgstr ""
 
-#: c/c-decl.c:6569
+#: c/c-decl.c:6589
 #, gcc-internal-format
 msgid "%qs specified for auto variable %qE"
 msgstr ""
 
-#: c/c-decl.c:6585
+#: c/c-decl.c:6605
 #, gcc-internal-format
 msgid "%qs specified for parameter %qE"
 msgstr ""
 
-#: c/c-decl.c:6588
+#: c/c-decl.c:6608
 #, gcc-internal-format
 msgid "%qs specified for unnamed parameter"
 msgstr ""
 
-#: c/c-decl.c:6594
+#: c/c-decl.c:6614
 #, gcc-internal-format
 msgid "%qs specified for structure field %qE"
 msgstr ""
 
-#: c/c-decl.c:6597
+#: c/c-decl.c:6617
 #, gcc-internal-format
 msgid "%qs specified for structure field"
 msgstr ""
 
-#: c/c-decl.c:6612
+#: c/c-decl.c:6632
 #, gcc-internal-format
 msgid "bit-field %qE has atomic type"
 msgstr ""
 
-#: c/c-decl.c:6614
+#: c/c-decl.c:6634
 #, gcc-internal-format
 msgid "bit-field has atomic type"
 msgstr ""
 
-#: c/c-decl.c:6623
+#: c/c-decl.c:6643
 #, gcc-internal-format
 msgid "alignment specified for typedef %qE"
 msgstr ""
 
-#: c/c-decl.c:6625
+#: c/c-decl.c:6645
 #, gcc-internal-format
 msgid "alignment specified for %<register%> object %qE"
 msgstr ""
 
-#: c/c-decl.c:6630
+#: c/c-decl.c:6650
 #, gcc-internal-format
 msgid "alignment specified for parameter %qE"
 msgstr ""
 
-#: c/c-decl.c:6632
+#: c/c-decl.c:6652
 #, gcc-internal-format
 msgid "alignment specified for unnamed parameter"
 msgstr ""
 
-#: c/c-decl.c:6637
+#: c/c-decl.c:6657
 #, gcc-internal-format
 msgid "alignment specified for bit-field %qE"
 msgstr ""
 
-#: c/c-decl.c:6639
+#: c/c-decl.c:6659
 #, gcc-internal-format
 msgid "alignment specified for unnamed bit-field"
 msgstr ""
 
-#: c/c-decl.c:6642
+#: c/c-decl.c:6662
 #, gcc-internal-format
 msgid "alignment specified for function %qE"
 msgstr ""
 
-#: c/c-decl.c:6649
+#: c/c-decl.c:6669
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of %qE"
 msgstr ""
 
-#: c/c-decl.c:6652
+#: c/c-decl.c:6672
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of unnamed field"
 msgstr ""
 
-#: c/c-decl.c:6683
+#: c/c-decl.c:6703
 #, gcc-internal-format
 msgid "typedef %q+D declared %<inline%>"
 msgstr ""
 
-#: c/c-decl.c:6685
+#: c/c-decl.c:6705
 #, gcc-internal-format
 msgid "typedef %q+D declared %<_Noreturn%>"
 msgstr ""
 
-#: c/c-decl.c:6727
+#: c/c-decl.c:6747
 #, gcc-internal-format
 msgid "ISO C forbids const or volatile function types"
 msgstr ""
 
 #. C99 6.7.2.1p8
-#: c/c-decl.c:6738
+#: c/c-decl.c:6758
 #, gcc-internal-format
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr ""
 
-#: c/c-decl.c:6755 cp/decl.c:9989
+#: c/c-decl.c:6775 cp/decl.c:10010
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr ""
 
-#: c/c-decl.c:6795
+#: c/c-decl.c:6815
 #, gcc-internal-format
 msgid "attributes in parameter array declarator ignored"
 msgstr ""
 
-#: c/c-decl.c:6837
+#: c/c-decl.c:6857
 #, gcc-internal-format
 msgid "parameter %q+D declared %<inline%>"
 msgstr ""
 
-#: c/c-decl.c:6839
+#: c/c-decl.c:6859
 #, gcc-internal-format
 msgid "parameter %q+D declared %<_Noreturn%>"
 msgstr ""
 
-#: c/c-decl.c:6852
+#: c/c-decl.c:6872
 #, gcc-internal-format
 msgid "field %qE declared as a function"
 msgstr ""
 
-#: c/c-decl.c:6859
+#: c/c-decl.c:6879
 #, gcc-internal-format
 msgid "field %qE has incomplete type"
 msgstr ""
 
-#: c/c-decl.c:6861
+#: c/c-decl.c:6881
 #, gcc-internal-format
 msgid "unnamed field has incomplete type"
 msgstr ""
 
-#: c/c-decl.c:6897 c/c-decl.c:6908 c/c-decl.c:6911
+#: c/c-decl.c:6917 c/c-decl.c:6928 c/c-decl.c:6931
 #, gcc-internal-format
 msgid "invalid storage class for function %qE"
 msgstr ""
 
-#: c/c-decl.c:6968
+#: c/c-decl.c:6988
 #, gcc-internal-format
 msgid "cannot inline function %<main%>"
 msgstr ""
 
-#: c/c-decl.c:6970
+#: c/c-decl.c:6990
 #, gcc-internal-format
 msgid "%<main%> declared %<_Noreturn%>"
 msgstr ""
 
-#: c/c-decl.c:6981
+#: c/c-decl.c:7001
 #, gcc-internal-format
 msgid "ISO C99 does not support %<_Noreturn%>"
 msgstr "У ISO C99 не передбачено підтримки %<_Noreturn%>"
 
-#: c/c-decl.c:6984
+#: c/c-decl.c:7004
 #, gcc-internal-format
 msgid "ISO C90 does not support %<_Noreturn%>"
 msgstr "У ISO C90 не передбачено підтримки %<_Noreturn%>"
 
-#: c/c-decl.c:7013
+#: c/c-decl.c:7033
 #, gcc-internal-format
 msgid "variable previously declared %<static%> redeclared %<extern%>"
 msgstr ""
 
-#: c/c-decl.c:7023
+#: c/c-decl.c:7043
 #, gcc-internal-format
 msgid "variable %q+D declared %<inline%>"
 msgstr ""
 
-#: c/c-decl.c:7025
+#: c/c-decl.c:7045
 #, gcc-internal-format
 msgid "variable %q+D declared %<_Noreturn%>"
 msgstr ""
 
-#: c/c-decl.c:7060
+#: c/c-decl.c:7080
 #, gcc-internal-format
 msgid "non-nested function with variably modified type"
 msgstr ""
 
-#: c/c-decl.c:7062
+#: c/c-decl.c:7082
 #, gcc-internal-format
 msgid "object with variably modified type must have no linkage"
 msgstr ""
 
-#: c/c-decl.c:7153 c/c-decl.c:8821
+#: c/c-decl.c:7173 c/c-decl.c:8841
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr ""
 
-#: c/c-decl.c:7163
+#: c/c-decl.c:7183
 #, gcc-internal-format
 msgid "parameter names (without types) in function declaration"
 msgstr ""
 
-#: c/c-decl.c:7201
+#: c/c-decl.c:7221
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has incomplete type"
 msgstr ""
 
-#: c/c-decl.c:7205
+#: c/c-decl.c:7225
 #, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has incomplete type"
 msgstr ""
 
-#: c/c-decl.c:7216
+#: c/c-decl.c:7236
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has void type"
 msgstr ""
 
-#: c/c-decl.c:7220
+#: c/c-decl.c:7240
 #, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has void type"
 msgstr ""
 
-#: c/c-decl.c:7294
+#: c/c-decl.c:7314
 #, gcc-internal-format
 msgid "%<void%> as only parameter may not be qualified"
 msgstr ""
 
-#: c/c-decl.c:7298 c/c-decl.c:7334
+#: c/c-decl.c:7318 c/c-decl.c:7354
 #, gcc-internal-format
 msgid "%<void%> must be the only parameter"
 msgstr ""
 
-#: c/c-decl.c:7328
+#: c/c-decl.c:7348
 #, gcc-internal-format
 msgid "parameter %q+D has just a forward declaration"
 msgstr ""
 
-#: c/c-decl.c:7374
+#: c/c-decl.c:7394
 #, gcc-internal-format
 msgid "%<%s %E%> declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr ""
 
-#: c/c-decl.c:7380
+#: c/c-decl.c:7400
 #, gcc-internal-format, gfc-internal-format
 msgid "anonymous %s declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr ""
 
-#: c/c-decl.c:7482
+#: c/c-decl.c:7502
 #, gcc-internal-format
 msgid "enum type defined here"
 msgstr ""
 
-#: c/c-decl.c:7488
+#: c/c-decl.c:7508
 #, gcc-internal-format
 msgid "struct defined here"
 msgstr ""
 
-#: c/c-decl.c:7494
+#: c/c-decl.c:7514
 #, gcc-internal-format
 msgid "union defined here"
 msgstr ""
 
-#: c/c-decl.c:7570
+#: c/c-decl.c:7590
 #, gcc-internal-format
 msgid "redefinition of %<union %E%>"
 msgstr ""
 
-#: c/c-decl.c:7572
+#: c/c-decl.c:7592
 #, gcc-internal-format
 msgid "redefinition of %<struct %E%>"
 msgstr ""
 
-#: c/c-decl.c:7581
+#: c/c-decl.c:7601
 #, gcc-internal-format
 msgid "nested redefinition of %<union %E%>"
 msgstr ""
 
-#: c/c-decl.c:7583
+#: c/c-decl.c:7603
 #, gcc-internal-format
 msgid "nested redefinition of %<struct %E%>"
 msgstr ""
 
-#: c/c-decl.c:7613 c/c-decl.c:8400
+#: c/c-decl.c:7633 c/c-decl.c:8420
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:7680 cp/decl.c:4802
+#: c/c-decl.c:7700 cp/decl.c:4802
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr ""
 
-#: c/c-decl.c:7685
+#: c/c-decl.c:7705
 #, gcc-internal-format
 msgid "ISO C99 doesn%'t support unnamed structs/unions"
 msgstr ""
 
-#: c/c-decl.c:7688
+#: c/c-decl.c:7708
 #, gcc-internal-format
 msgid "ISO C90 doesn%'t support unnamed structs/unions"
 msgstr ""
 
-#: c/c-decl.c:7781 c/c-decl.c:7799 c/c-decl.c:7860
+#: c/c-decl.c:7801 c/c-decl.c:7819 c/c-decl.c:7880
 #, gcc-internal-format
 msgid "duplicate member %q+D"
 msgstr ""
 
-#: c/c-decl.c:7886
+#: c/c-decl.c:7906
 #, gcc-internal-format
 msgid "empty struct has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.c:7889
+#: c/c-decl.c:7909
 #, gcc-internal-format
 msgid "empty union has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.c:7994
+#: c/c-decl.c:8014
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr ""
 
-#: c/c-decl.c:7996
+#: c/c-decl.c:8016
 #, gcc-internal-format
 msgid "union has no members"
 msgstr ""
 
-#: c/c-decl.c:8001
+#: c/c-decl.c:8021
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr ""
 
-#: c/c-decl.c:8003
+#: c/c-decl.c:8023
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr ""
 
-#: c/c-decl.c:8064 cp/decl.c:12069
+#: c/c-decl.c:8084 cp/decl.c:12093
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr ""
 
-#: c/c-decl.c:8070
+#: c/c-decl.c:8090
 #, gcc-internal-format
 msgid "flexible array member not at end of struct"
 msgstr ""
 
-#: c/c-decl.c:8076
+#: c/c-decl.c:8096
 #, gcc-internal-format
 msgid "flexible array member in a struct with no named members"
 msgstr ""
 
-#: c/c-decl.c:8107
+#: c/c-decl.c:8127
 #, gcc-internal-format
 msgid "type %qT is too large"
 msgstr ""
 
-#: c/c-decl.c:8230
+#: c/c-decl.c:8250
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr ""
 
-#: c/c-decl.c:8372
+#: c/c-decl.c:8392
 #, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr ""
 
 #. This enum is a named one that has been declared already.
-#: c/c-decl.c:8379
+#: c/c-decl.c:8399
 #, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr ""
 
-#: c/c-decl.c:8458 cp/decl.c:14423
+#: c/c-decl.c:8478 cp/decl.c:14447
 #, gcc-internal-format
 msgid "specified mode too small for enumeral values"
 msgstr ""
 
-#: c/c-decl.c:8473
+#: c/c-decl.c:8493
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr ""
 
-#: c/c-decl.c:8587 c/c-decl.c:8603
+#: c/c-decl.c:8607 c/c-decl.c:8623
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr ""
 
-#: c/c-decl.c:8598
+#: c/c-decl.c:8618
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr ""
 
-#: c/c-decl.c:8622
+#: c/c-decl.c:8642
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr ""
 
-#: c/c-decl.c:8630
+#: c/c-decl.c:8650
 #, gcc-internal-format
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr ""
 
-#: c/c-decl.c:8715 cp/decl.c:5104 cp/decl.c:14955
+#: c/c-decl.c:8735 cp/decl.c:5104 cp/decl.c:14979
 #, gcc-internal-format
 msgid "inline function %qD given attribute noinline"
 msgstr ""
 
-#: c/c-decl.c:8733
+#: c/c-decl.c:8753
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr ""
 
-#: c/c-decl.c:8744
+#: c/c-decl.c:8764
 #, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr ""
 
-#: c/c-decl.c:8771
+#: c/c-decl.c:8791
 #, gcc-internal-format
 msgid "%q+D defined as variadic function without prototype"
 msgstr ""
 
-#: c/c-decl.c:8830
+#: c/c-decl.c:8850
 #, gcc-internal-format
 msgid "no previous prototype for %qD"
 msgstr ""
 
-#: c/c-decl.c:8839
+#: c/c-decl.c:8859
 #, gcc-internal-format
 msgid "%qD was used with no prototype before its definition"
 msgstr ""
 
-#: c/c-decl.c:8847 cp/decl.c:15090
+#: c/c-decl.c:8867 cp/decl.c:15114
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr ""
 
-#: c/c-decl.c:8857
+#: c/c-decl.c:8877
 #, gcc-internal-format
 msgid "%qD was used with no declaration before its definition"
 msgstr ""
 
-#: c/c-decl.c:8876
+#: c/c-decl.c:8896
 #, gcc-internal-format
 msgid "return type of %qD is not %<int%>"
 msgstr ""
 
-#: c/c-decl.c:8878
+#: c/c-decl.c:8898
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr ""
 
-#: c/c-decl.c:8885
+#: c/c-decl.c:8905
 #, gcc-internal-format
 msgid "%qD is normally a non-static function"
 msgstr ""
 
-#: c/c-decl.c:8922
+#: c/c-decl.c:8942
 #, gcc-internal-format
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr ""
 
-#: c/c-decl.c:8937
+#: c/c-decl.c:8957
 #, gcc-internal-format
 msgid "traditional C rejects ISO C style function definitions"
 msgstr ""
 
-#: c/c-decl.c:8953
+#: c/c-decl.c:8973
 #, gcc-internal-format
 msgid "parameter name omitted"
 msgstr ""
 
-#: c/c-decl.c:8990
+#: c/c-decl.c:9010
 #, gcc-internal-format
 msgid "old-style function definition"
 msgstr ""
 
-#: c/c-decl.c:8999
+#: c/c-decl.c:9019
 #, gcc-internal-format
 msgid "parameter name missing from parameter list"
 msgstr ""
 
-#: c/c-decl.c:9015
+#: c/c-decl.c:9035
 #, gcc-internal-format
 msgid "%qD declared as a non-parameter"
 msgstr ""
 
-#: c/c-decl.c:9023
+#: c/c-decl.c:9043
 #, gcc-internal-format
 msgid "multiple parameters named %qD"
 msgstr ""
 
-#: c/c-decl.c:9032
+#: c/c-decl.c:9052
 #, gcc-internal-format
 msgid "parameter %qD declared with void type"
 msgstr ""
 
-#: c/c-decl.c:9061 c/c-decl.c:9066
+#: c/c-decl.c:9081 c/c-decl.c:9086
 #, gcc-internal-format
 msgid "type of %qD defaults to %<int%>"
 msgstr ""
 
-#: c/c-decl.c:9086
+#: c/c-decl.c:9106
 #, gcc-internal-format
 msgid "parameter %qD has incomplete type"
 msgstr ""
 
-#: c/c-decl.c:9093
+#: c/c-decl.c:9113
 #, gcc-internal-format
 msgid "declaration for parameter %qD but no such parameter"
 msgstr ""
 
-#: c/c-decl.c:9146
+#: c/c-decl.c:9166
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr ""
 
-#: c/c-decl.c:9157
+#: c/c-decl.c:9177
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr ""
 
-#: c/c-decl.c:9160 c/c-decl.c:9207 c/c-decl.c:9221
+#: c/c-decl.c:9180 c/c-decl.c:9227 c/c-decl.c:9241
 #, gcc-internal-format
 msgid "prototype declaration"
 msgstr ""
 
-#: c/c-decl.c:9199
+#: c/c-decl.c:9219
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr ""
 
-#: c/c-decl.c:9204
+#: c/c-decl.c:9224
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr ""
 
-#: c/c-decl.c:9214
+#: c/c-decl.c:9234
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr ""
 
-#: c/c-decl.c:9219
+#: c/c-decl.c:9239
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr ""
 
-#: c/c-decl.c:9470 cp/decl.c:15873
+#: c/c-decl.c:9490 cp/decl.c:15897
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr ""
 
-#: c/c-decl.c:9490 cp/decl.c:15905
+#: c/c-decl.c:9510 cp/decl.c:15929
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr ""
@@ -34549,247 +34591,247 @@
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:9586
+#: c/c-decl.c:9606
 #, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr ""
 
-#: c/c-decl.c:9591
+#: c/c-decl.c:9611
 #, gcc-internal-format
 msgid "use option -std=c99, -std=gnu99, -std=c11 or -std=gnu11 to compile your code"
 msgstr ""
 
-#: c/c-decl.c:9626
+#: c/c-decl.c:9646
 #, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:9630
+#: c/c-decl.c:9650
 #, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:9637
+#: c/c-decl.c:9657
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:9642
+#: c/c-decl.c:9662
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:9646
+#: c/c-decl.c:9666
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:9650
+#: c/c-decl.c:9670
 #, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:9900
+#: c/c-decl.c:9920
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr ""
 
-#: c/c-decl.c:9958 c/c-decl.c:9965
+#: c/c-decl.c:9978 c/c-decl.c:9985
 #, gcc-internal-format
 msgid "duplicate %qE declaration specifier"
 msgstr ""
 
-#: c/c-decl.c:9992 c/c-decl.c:10376 c/c-decl.c:10766
+#: c/c-decl.c:10012 c/c-decl.c:10396 c/c-decl.c:10786
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr ""
 
-#: c/c-decl.c:10004 cp/parser.c:28261
+#: c/c-decl.c:10024 cp/parser.c:28258
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr ""
 
-#: c/c-decl.c:10017
+#: c/c-decl.c:10037
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "У ISO C90 не передбачено підтримки %<long long%>"
 
-#: c/c-decl.c:10246 c/c-parser.c:8848
+#: c/c-decl.c:10266 c/c-parser.c:8848
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr ""
 
-#: c/c-decl.c:10292
+#: c/c-decl.c:10312
 #, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr ""
 
-#: c/c-decl.c:10363 c/c-decl.c:10923
+#: c/c-decl.c:10383 c/c-decl.c:10943
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr ""
 
-#: c/c-decl.c:10419
+#: c/c-decl.c:10439
 #, gcc-internal-format
 msgid "ISO C does not support %<__int%d%> types"
 msgstr ""
 
-#: c/c-decl.c:10441
+#: c/c-decl.c:10461
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr ""
 
-#: c/c-decl.c:10484
+#: c/c-decl.c:10504
 #, gcc-internal-format
 msgid "ISO C90 does not support boolean types"
 msgstr ""
 
-#: c/c-decl.c:10603
+#: c/c-decl.c:10623
 #, gcc-internal-format
 msgid "ISO C does not support the %<_Float%d%s%> type"
 msgstr "У ISO C не передбачено підтримки типу %<_Float%d%s%>"
 
-#: c/c-decl.c:10653
+#: c/c-decl.c:10673
 #, gcc-internal-format
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr ""
 
-#: c/c-decl.c:10724
+#: c/c-decl.c:10744
 #, gcc-internal-format
 msgid "ISO C does not support decimal floating point"
 msgstr ""
 
-#: c/c-decl.c:10747 c/c-decl.c:11013 c/c-parser.c:7842
+#: c/c-decl.c:10767 c/c-decl.c:11033 c/c-parser.c:7842
 #, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr ""
 
-#: c/c-decl.c:10749
+#: c/c-decl.c:10769
 #, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr ""
 
-#: c/c-decl.c:10784
+#: c/c-decl.c:10804
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr ""
 
-#: c/c-decl.c:10797
+#: c/c-decl.c:10817
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr ""
 
-#: c/c-decl.c:10845
+#: c/c-decl.c:10865
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr ""
 
-#: c/c-decl.c:10866
+#: c/c-decl.c:10886
 #, gcc-internal-format
 msgid "%qE used with %<auto%>"
 msgstr ""
 
-#: c/c-decl.c:10868
+#: c/c-decl.c:10888
 #, gcc-internal-format
 msgid "%qE used with %<register%>"
 msgstr ""
 
-#: c/c-decl.c:10870
+#: c/c-decl.c:10890
 #, gcc-internal-format
 msgid "%qE used with %<typedef%>"
 msgstr ""
 
-#: c/c-decl.c:10884 c/c-parser.c:7360
+#: c/c-decl.c:10904 c/c-parser.c:7360
 #, gcc-internal-format
 msgid "ISO C99 does not support %qE"
 msgstr ""
 
-#: c/c-decl.c:10887 c/c-parser.c:7363
+#: c/c-decl.c:10907 c/c-parser.c:7363
 #, gcc-internal-format
 msgid "ISO C90 does not support %qE"
 msgstr ""
 
-#: c/c-decl.c:10899
+#: c/c-decl.c:10919
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<__thread%> до %<extern%>"
 
-#: c/c-decl.c:10908
+#: c/c-decl.c:10928
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<__thread%> до %<static%>"
 
-#: c/c-decl.c:10921
+#: c/c-decl.c:10941
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr ""
 
-#: c/c-decl.c:10929
+#: c/c-decl.c:10949
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr ""
 
-#: c/c-decl.c:10937
+#: c/c-decl.c:10957
 #, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr ""
 
-#: c/c-decl.c:11010
+#: c/c-decl.c:11030
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr ""
 
-#: c/c-decl.c:11025
+#: c/c-decl.c:11045
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr ""
 
-#: c/c-decl.c:11076 c/c-decl.c:11092 c/c-decl.c:11118
+#: c/c-decl.c:11096 c/c-decl.c:11112 c/c-decl.c:11138
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr ""
 
-#: c/c-decl.c:11514 cp/semantics.c:5348
+#: c/c-decl.c:11534 cp/semantics.c:5351
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:11518 cp/semantics.c:5352
+#: c/c-decl.c:11538 cp/semantics.c:5355
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.c:385 c/c-typeck.c:11426 cp/typeck.c:4680
+#: c/c-fold.c:385 c/c-typeck.c:11431 cp/typeck.c:4680
 #, gcc-internal-format
 msgid "left shift of negative value"
 msgstr ""
 
-#: c/c-fold.c:395 c/c-typeck.c:11435 cp/typeck.c:4688
+#: c/c-fold.c:395 c/c-typeck.c:11440 cp/typeck.c:4688
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr ""
 
-#: c/c-fold.c:396 c/c-typeck.c:11365 cp/typeck.c:4633
+#: c/c-fold.c:396 c/c-typeck.c:11370 cp/typeck.c:4633
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr ""
 
-#: c/c-fold.c:404 c/c-typeck.c:11454 cp/typeck.c:4696
+#: c/c-fold.c:404 c/c-typeck.c:11459 cp/typeck.c:4696
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr ""
 
-#: c/c-fold.c:405 c/c-typeck.c:11389 cp/typeck.c:4641
+#: c/c-fold.c:405 c/c-typeck.c:11394 cp/typeck.c:4641
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr ""
 
-#: c/c-fold.c:412 c/c-typeck.c:11446
+#: c/c-fold.c:412 c/c-typeck.c:11451
 #, gcc-internal-format
 msgid "left shift count >= width of vector element"
 msgstr ""
 
-#: c/c-fold.c:413 c/c-typeck.c:11376
+#: c/c-fold.c:413 c/c-typeck.c:11381
 #, gcc-internal-format
 msgid "right shift count >= width of vector element"
 msgstr ""
@@ -34809,7 +34851,7 @@
 msgid "to match this %qs"
 msgstr "для відповідності цьому %qs"
 
-#: c/c-parser.c:1216 cp/parser.c:28484
+#: c/c-parser.c:1216 cp/parser.c:28481
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr ""
@@ -34850,7 +34892,7 @@
 msgstr ""
 
 #: c/c-parser.c:1848 c/c-parser.c:11129 c/c-parser.c:16147 c/c-parser.c:16585
-#: c/c-parser.c:17061 cp/parser.c:36007 cp/parser.c:38993
+#: c/c-parser.c:17061 cp/parser.c:36004 cp/parser.c:38990
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr ""
@@ -34865,7 +34907,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr ""
 
-#: c/c-parser.c:1906 cp/parser.c:30161 cp/parser.c:30235
+#: c/c-parser.c:1906 cp/parser.c:30158 cp/parser.c:30232
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr ""
@@ -34919,7 +34961,7 @@
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr ""
 
-#: c/c-parser.c:2220 cp/parser.c:13002 cp/parser.c:13159
+#: c/c-parser.c:2220 cp/parser.c:12999 cp/parser.c:13156
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "мало бути %<,%> або %<;%>"
@@ -34947,7 +34989,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "У ISO C90 не передбачено підтримки %<_Static_assert%>"
 
-#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38634
+#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38631
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr ""
@@ -35011,13 +35053,13 @@
 #: c/c-parser.c:10745 c/c-parser.c:10798 c/c-parser.c:10814 c/c-parser.c:10860
 #: c/c-parser.c:11496 c/c-parser.c:11537 c/c-parser.c:13445 c/c-parser.c:13681
 #: c/c-parser.c:15544 c/c-parser.c:18218 c/gimple-parser.c:1058
-#: c/gimple-parser.c:1096 cp/parser.c:28487 cp/parser.c:31013
-#: cp/parser.c:31043 cp/parser.c:31113 cp/parser.c:33230 cp/parser.c:38350
+#: c/gimple-parser.c:1096 cp/parser.c:28484 cp/parser.c:31010
+#: cp/parser.c:31040 cp/parser.c:31110 cp/parser.c:33227 cp/parser.c:38347
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr ""
 
-#: c/c-parser.c:2995 cp/parser.c:18384
+#: c/c-parser.c:2995 cp/parser.c:18381
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr ""
@@ -35186,12 +35228,12 @@
 msgid "expected statement"
 msgstr ""
 
-#: c/c-parser.c:5639 cp/parser.c:12516
+#: c/c-parser.c:5639 cp/parser.c:12513
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr ""
 
-#: c/c-parser.c:5681 cp/parser.c:12519
+#: c/c-parser.c:5681 cp/parser.c:12516
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr ""
@@ -35529,7 +35571,7 @@
 msgid "%<__builtin_complex%> operands of different types"
 msgstr ""
 
-#: c/c-parser.c:8891 cp/parser.c:6918
+#: c/c-parser.c:8891 cp/parser.c:6921
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_shuffle%>"
 msgstr "помилкова кількість аргументів %<__builtin_shuffle%>"
@@ -35589,76 +35631,76 @@
 msgid "no type or storage class may be specified here,"
 msgstr ""
 
-#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31073
+#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31070
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr ""
 
-#: c/c-parser.c:10682 cp/parser.c:31033
+#: c/c-parser.c:10682 cp/parser.c:31030
 #, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr ""
 
-#: c/c-parser.c:10685 cp/parser.c:31036
+#: c/c-parser.c:10685 cp/parser.c:31033
 #, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr ""
 
-#: c/c-parser.c:10699 cp/parser.c:31051
+#: c/c-parser.c:10699 cp/parser.c:31048
 #, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr ""
 
-#: c/c-parser.c:10704 cp/parser.c:31057
+#: c/c-parser.c:10704 cp/parser.c:31054
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.c:10711 cp/parser.c:31065
+#: c/c-parser.c:10711 cp/parser.c:31062
 #, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr ""
 
-#: c/c-parser.c:10905 cp/parser.c:38674
+#: c/c-parser.c:10905 cp/parser.c:38671
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
 #: c/c-parser.c:10949 c/c-parser.c:16582 c/c-parser.c:16840 c/c-parser.c:16899
-#: c/c-parser.c:16983 cp/parser.c:36004 cp/parser.c:36298 cp/parser.c:36386
-#: cp/parser.c:36457 cp/parser.c:38721 cp/parser.c:38736 cp/parser.c:38752
-#: cp/parser.c:38768 cp/parser.c:38784 cp/parser.c:38811 cp/parser.c:38824
-#: cp/parser.c:38847 cp/parser.c:38860
+#: c/c-parser.c:16983 cp/parser.c:36001 cp/parser.c:36295 cp/parser.c:36383
+#: cp/parser.c:36454 cp/parser.c:38718 cp/parser.c:38733 cp/parser.c:38749
+#: cp/parser.c:38765 cp/parser.c:38781 cp/parser.c:38808 cp/parser.c:38821
+#: cp/parser.c:38844 cp/parser.c:38857
 #, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:10972 cp/parser.c:38837
+#: c/c-parser.c:10972 cp/parser.c:38834
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<#pragma acc routine%> має перебувати у області видимості файла"
 
-#: c/c-parser.c:11050 cp/parser.c:38918
+#: c/c-parser.c:11050 cp/parser.c:38915
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr ""
 
-#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38947 cp/parser.c:38980
+#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38944 cp/parser.c:38977
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr ""
 
-#: c/c-parser.c:11111 cp/parser.c:38711
+#: c/c-parser.c:11111 cp/parser.c:38708
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr ""
 
-#: c/c-parser.c:11421 cp/parser.c:31457
+#: c/c-parser.c:11421 cp/parser.c:31454
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr ""
 
-#: c/c-parser.c:11443 cp/parser.c:31994
+#: c/c-parser.c:11443 cp/parser.c:31991
 #, gcc-internal-format
 msgid "expected integer expression before ')'"
 msgstr ""
@@ -35673,53 +35715,53 @@
 msgid "%qD is not a variable"
 msgstr ""
 
-#: c/c-parser.c:11746 cp/semantics.c:6808
+#: c/c-parser.c:11746 cp/semantics.c:6811
 #, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr ""
 
-#: c/c-parser.c:11788 cp/parser.c:32073
+#: c/c-parser.c:11788 cp/parser.c:32070
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:11865 cp/parser.c:32137
+#: c/c-parser.c:11865 cp/parser.c:32134
 #, gcc-internal-format
 msgid "expected %<none%> or %<present%>"
 msgstr "мало бути %<none%> або %<present%>"
 
-#: c/c-parser.c:11867 cp/parser.c:32139
+#: c/c-parser.c:11867 cp/parser.c:32136
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "мало бути %<none%> або %<shared%>"
 
-#: c/c-parser.c:11968 cp/parser.c:32242
+#: c/c-parser.c:11968 cp/parser.c:32239
 #, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "мало бути %<data%>, %<update%>, %<enter%> або %<exit%>"
 
-#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32260
-#: cp/parser.c:36290 cp/parser.c:36378
+#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32257
+#: cp/parser.c:36287 cp/parser.c:36375
 #, gcc-internal-format
 msgid "expected %<data%>"
 msgstr "мало бути %<data%>"
 
-#: c/c-parser.c:12035 cp/parser.c:32313
+#: c/c-parser.c:12035 cp/parser.c:32310
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:12042 cp/parser.c:32320
+#: c/c-parser.c:12042 cp/parser.c:32317
 #, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr ""
 
-#: c/c-parser.c:12044 cp/parser.c:32322
+#: c/c-parser.c:12044 cp/parser.c:32319
 #, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr ""
 
-#: c/c-parser.c:12050 cp/parser.c:32328
+#: c/c-parser.c:12050 cp/parser.c:32325
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -35741,82 +35783,82 @@
 msgid "%<num_tasks%> value must be positive"
 msgstr "значення %<num_tasks%> має бути додатним"
 
-#: c/c-parser.c:12229 cp/semantics.c:6992
+#: c/c-parser.c:12229 cp/semantics.c:6995
 #, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr "значення %<grainsize%> має бути додатним"
 
-#: c/c-parser.c:12276 cp/semantics.c:7021
+#: c/c-parser.c:12276 cp/semantics.c:7024
 #, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr "значення %<priority%> має бути невід’ємним"
 
-#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32545 cp/parser.c:32552
+#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32542 cp/parser.c:32549
 #, gcc-internal-format
 msgid "expected %<tofrom%>"
 msgstr "мало бути %<tofrom%>"
 
-#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32561 cp/parser.c:32568
+#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32558 cp/parser.c:32565
 #, gcc-internal-format
 msgid "expected %<scalar%>"
 msgstr "мало бути %<scalar%>"
 
-#: c/c-parser.c:12425 cp/semantics.c:6299
+#: c/c-parser.c:12425 cp/semantics.c:6302
 #, gcc-internal-format
 msgid "%qs expression must be integral"
 msgstr ""
 
-#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6331
+#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6334
 #, gcc-internal-format
 msgid "%qs value must be positive"
 msgstr "значення %qs має бути додатним"
 
-#: c/c-parser.c:12499 cp/parser.c:31853
+#: c/c-parser.c:12499 cp/parser.c:31850
 #, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "забагато аргументів %<static%>"
 
-#: c/c-parser.c:12533 cp/parser.c:31886
+#: c/c-parser.c:12533 cp/parser.c:31883
 #, gcc-internal-format
 msgid "unexpected argument"
 msgstr "несподіваний аргумент"
 
-#: c/c-parser.c:12699 cp/semantics.c:7120
+#: c/c-parser.c:12699 cp/semantics.c:7123
 #, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr ""
 
-#: c/c-parser.c:12765 cp/parser.c:32626
+#: c/c-parser.c:12765 cp/parser.c:32623
 #, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37643
+#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37640
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr ""
 
-#: c/c-parser.c:12967 cp/parser.c:32840
+#: c/c-parser.c:12967 cp/parser.c:32837
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr ""
 
-#: c/c-parser.c:13021 cp/parser.c:32856
+#: c/c-parser.c:13021 cp/parser.c:32853
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:13025 cp/parser.c:32859
+#: c/c-parser.c:13025 cp/parser.c:32856
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:13037 cp/semantics.c:6389
+#: c/c-parser.c:13037 cp/semantics.c:6392
 #, gcc-internal-format
 msgid "chunk size value must be positive"
 msgstr "значення розміру фрагмента має бути додатним"
 
-#: c/c-parser.c:13060 cp/parser.c:32879
+#: c/c-parser.c:13060 cp/parser.c:32876
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr ""
@@ -35826,12 +35868,12 @@
 msgid "%<num_teams%> value must be positive"
 msgstr "значення %<num_teams%> має бути додатним"
 
-#: c/c-parser.c:13226 cp/semantics.c:6479
+#: c/c-parser.c:13226 cp/semantics.c:6482
 #, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr "значення %<thread_limit%> має бути додатним"
 
-#: c/c-parser.c:13271 cp/semantics.c:6589
+#: c/c-parser.c:13271 cp/semantics.c:6592
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr ""
@@ -35851,17 +35893,17 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:13584 cp/parser.c:33374 cp/parser.c:33599
+#: c/c-parser.c:13584 cp/parser.c:33371 cp/parser.c:33596
 #, gcc-internal-format
 msgid "invalid depend kind"
 msgstr ""
 
-#: c/c-parser.c:13669 cp/parser.c:33447
+#: c/c-parser.c:13669 cp/parser.c:33444
 #, gcc-internal-format
 msgid "invalid map kind"
 msgstr ""
 
-#: c/c-parser.c:13767 cp/parser.c:33546
+#: c/c-parser.c:13767 cp/parser.c:33543
 #, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr ""
@@ -35871,67 +35913,67 @@
 msgid "invalid proc_bind kind"
 msgstr ""
 
-#: c/c-parser.c:14059 cp/parser.c:33825
+#: c/c-parser.c:14059 cp/parser.c:33822
 #, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr ""
 
-#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33836 cp/parser.c:34143
+#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33833 cp/parser.c:34140
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr ""
 
-#: c/c-parser.c:14214 cp/parser.c:34010
+#: c/c-parser.c:14214 cp/parser.c:34007
 #, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr ""
 
-#: c/c-parser.c:14334 cp/parser.c:34132
+#: c/c-parser.c:14334 cp/parser.c:34129
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr ""
 
-#: c/c-parser.c:14472 cp/parser.c:36803
+#: c/c-parser.c:14472 cp/parser.c:36800
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14482 cp/parser.c:36813
+#: c/c-parser.c:14482 cp/parser.c:36810
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14502 cp/parser.c:36833
+#: c/c-parser.c:14502 cp/parser.c:36830
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr ""
 
-#: c/c-parser.c:14513 cp/parser.c:36844
+#: c/c-parser.c:14513 cp/parser.c:36841
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr ""
 
-#: c/c-parser.c:14520 cp/parser.c:36851
+#: c/c-parser.c:14520 cp/parser.c:36848
 #, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14528 cp/parser.c:36859
+#: c/c-parser.c:14528 cp/parser.c:36856
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14540 cp/parser.c:36871
+#: c/c-parser.c:14540 cp/parser.c:36868
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14632 cp/parser.c:36957
+#: c/c-parser.c:14632 cp/parser.c:36954
 #, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "мало бути %<data%> після %<#pragma acc %s%>"
 
-#: c/c-parser.c:14648 cp/parser.c:36974
+#: c/c-parser.c:14648 cp/parser.c:36971
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr ""
@@ -35946,7 +35988,7 @@
 msgid "expected function name"
 msgstr "мало бути вказано назву функції"
 
-#: c/c-parser.c:14893 cp/parser.c:38064
+#: c/c-parser.c:14893 cp/parser.c:38061
 #, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr ""
@@ -35956,42 +35998,42 @@
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14953 cp/parser.c:38118 cp/parser.c:38160
+#: c/c-parser.c:14953 cp/parser.c:38115 cp/parser.c:38157
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14970 cp/parser.c:38174
+#: c/c-parser.c:14970 cp/parser.c:38171
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> already applied to %qD"
 msgstr "%<#pragma acc routine%> вже застосовано до %qD"
 
-#: c/c-parser.c:14979 cp/parser.c:38183
+#: c/c-parser.c:14979 cp/parser.c:38180
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr "%<#pragma acc routine%> має бути застосовано до використання"
 
-#: c/c-parser.c:14980 cp/parser.c:38184
+#: c/c-parser.c:14980 cp/parser.c:38181
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<#pragma acc routine%> має бути застосовано до визначення"
 
-#: c/c-parser.c:15023 cp/parser.c:37152
+#: c/c-parser.c:15023 cp/parser.c:37149
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
 
-#: c/c-parser.c:15435 cp/parser.c:34511 cp/parser.c:34537
+#: c/c-parser.c:15435 cp/parser.c:34508 cp/parser.c:34534
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr ""
 
-#: c/c-parser.c:15439 cp/parser.c:34568 cp/parser.c:34584
+#: c/c-parser.c:15439 cp/parser.c:34565 cp/parser.c:34581
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr ""
 
-#: c/c-parser.c:15488 cp/semantics.c:8401 cp/semantics.c:8411
+#: c/c-parser.c:15488 cp/semantics.c:8404 cp/semantics.c:8414
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
@@ -36001,22 +36043,22 @@
 msgid "expected %<(%> or end of line"
 msgstr ""
 
-#: c/c-parser.c:15619 cp/parser.c:35103
+#: c/c-parser.c:15619 cp/parser.c:35100
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:15630 cp/parser.c:35114
+#: c/c-parser.c:15630 cp/parser.c:35111
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:15648 cp/parser.c:35141
+#: c/c-parser.c:15648 cp/parser.c:35138
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr ""
 
-#: c/c-parser.c:15718 cp/semantics.c:8066 cp/semantics.c:8153
+#: c/c-parser.c:15718 cp/semantics.c:8069 cp/semantics.c:8156
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr ""
@@ -36026,72 +36068,72 @@
 msgid "not enough perfectly nested loops"
 msgstr ""
 
-#: c/c-parser.c:15862 cp/parser.c:35364
+#: c/c-parser.c:15862 cp/parser.c:35361
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.c:15909 cp/parser.c:35184 cp/parser.c:35226 cp/pt.c:16385
+#: c/c-parser.c:15909 cp/parser.c:35181 cp/parser.c:35223 cp/pt.c:16407
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr ""
 
-#: c/c-parser.c:16000 cp/parser.c:35437
+#: c/c-parser.c:16000 cp/parser.c:35434
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr ""
 
-#: c/c-parser.c:16166 cp/parser.c:35600
+#: c/c-parser.c:16166 cp/parser.c:35597
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:16374 cp/parser.c:35799
+#: c/c-parser.c:16374 cp/parser.c:35796
 #, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "мало бути %<for%> після %qs"
 
-#: c/c-parser.c:16573 cp/parser.c:35995
+#: c/c-parser.c:16573 cp/parser.c:35992
 #, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "мало бути %<point%>"
 
-#: c/c-parser.c:16793 cp/parser.c:36232
+#: c/c-parser.c:16793 cp/parser.c:36229
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16806 cp/parser.c:36245
+#: c/c-parser.c:16806 cp/parser.c:36242
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16853 cp/parser.c:36470
+#: c/c-parser.c:16853 cp/parser.c:36467
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:16925 cp/parser.c:36325
+#: c/c-parser.c:16925 cp/parser.c:36322
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16937 cp/parser.c:36337
+#: c/c-parser.c:16937 cp/parser.c:36334
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17011 cp/parser.c:36414
+#: c/c-parser.c:17011 cp/parser.c:36411
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17024 cp/parser.c:36427
+#: c/c-parser.c:17024 cp/parser.c:36424
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17238 cp/parser.c:36680
+#: c/c-parser.c:17238 cp/parser.c:36677
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -36111,32 +36153,32 @@
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17395 cp/parser.c:37273
+#: c/c-parser.c:17395 cp/parser.c:37270
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17474 cp/parser.c:37343
+#: c/c-parser.c:17474 cp/parser.c:37340
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> with clauses in between %<#pragma omp declare target%> without clauses and %<#pragma omp end declare target%>"
 msgstr ""
 
-#: c/c-parser.c:17493 cp/parser.c:37362
+#: c/c-parser.c:17493 cp/parser.c:37359
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17534 cp/parser.c:37409
+#: c/c-parser.c:17534 cp/parser.c:37406
 #, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "мало бути %<target%>"
 
-#: c/c-parser.c:17541 cp/parser.c:37416
+#: c/c-parser.c:17541 cp/parser.c:37413
 #, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "мало бути %<declare%>"
 
-#: c/c-parser.c:17547 cp/parser.c:37423
+#: c/c-parser.c:17547 cp/parser.c:37420
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr ""
@@ -36191,47 +36233,47 @@
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:17947 cp/parser.c:37868
+#: c/c-parser.c:17947 cp/parser.c:37865
 #, gcc-internal-format
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr ""
 
-#: c/c-parser.c:18162 cp/semantics.c:7531
+#: c/c-parser.c:18162 cp/semantics.c:7534
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr ""
 
-#: c/c-parser.c:18164 cp/semantics.c:7533
+#: c/c-parser.c:18164 cp/semantics.c:7536
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr ""
 
-#: c/c-parser.c:18168 cp/semantics.c:7535
+#: c/c-parser.c:18168 cp/semantics.c:7538
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr ""
 
-#: c/c-parser.c:18368 cp/parser.c:38565
+#: c/c-parser.c:18368 cp/parser.c:38562
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:18374 cp/parser.c:38571
+#: c/c-parser.c:18374 cp/parser.c:38568
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
 
-#: c/c-parser.c:18383 cp/parser.c:38580
+#: c/c-parser.c:18383 cp/parser.c:38577
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.c:18385 cp/parser.c:38583
+#: c/c-parser.c:18385 cp/parser.c:38580
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.c:18391 cp/parser.c:38589
+#: c/c-parser.c:18391 cp/parser.c:38586
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
@@ -36246,7 +36288,7 @@
 msgid "%qD has an incomplete type %qT"
 msgstr ""
 
-#: c/c-typeck.c:237 c/c-typeck.c:9994 c/c-typeck.c:10036 cp/call.c:4147
+#: c/c-typeck.c:237 c/c-typeck.c:9999 c/c-typeck.c:10041 cp/call.c:4147
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr ""
@@ -36322,12 +36364,12 @@
 msgid "converting an array compound literal to a pointer is ill-formed in C++"
 msgstr ""
 
-#: c/c-typeck.c:2417 c/c-typeck.c:8641
+#: c/c-typeck.c:2417 c/c-typeck.c:8646
 #, gcc-internal-format
 msgid "%qT has no member named %qE; did you mean %qE?"
 msgstr ""
 
-#: c/c-typeck.c:2421 c/c-typeck.c:8645
+#: c/c-typeck.c:2421 c/c-typeck.c:8650
 #, gcc-internal-format
 msgid "%qT has no member named %qE"
 msgstr ""
@@ -36525,457 +36567,457 @@
 msgid "pointer to a function used in subtraction"
 msgstr ""
 
-#: c/c-typeck.c:3847
+#: c/c-typeck.c:3852
 #, gcc-internal-format
 msgid "arithmetic on pointer to an incomplete type"
 msgstr ""
 
-#: c/c-typeck.c:3852 cp/typeck.c:5562
+#: c/c-typeck.c:3857 cp/typeck.c:5562
 #, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr ""
 
-#: c/c-typeck.c:4283
+#: c/c-typeck.c:4288
 #, gcc-internal-format
 msgid "%<~%> on a boolean expression"
 msgstr "%<~%> над булевим виразом"
 
-#: c/c-typeck.c:4287
+#: c/c-typeck.c:4292
 #, gcc-internal-format
 msgid "did you mean to use logical not?"
 msgstr ""
 
-#: c/c-typeck.c:4296
+#: c/c-typeck.c:4301
 #, gcc-internal-format
 msgid "ISO C does not support %<~%> for complex conjugation"
 msgstr ""
 
-#: c/c-typeck.c:4335
+#: c/c-typeck.c:4340
 #, gcc-internal-format
 msgid "wrong type argument to unary exclamation mark"
 msgstr ""
 
-#: c/c-typeck.c:4393
+#: c/c-typeck.c:4398
 #, gcc-internal-format
 msgid "increment of enumeration value is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:4396
+#: c/c-typeck.c:4401
 #, gcc-internal-format
 msgid "decrement of enumeration value is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:4403
+#: c/c-typeck.c:4408
 #, gcc-internal-format
 msgid "increment of a boolean expression"
 msgstr ""
 
-#: c/c-typeck.c:4406
+#: c/c-typeck.c:4411
 #, gcc-internal-format
 msgid "decrement of a boolean expression"
 msgstr ""
 
-#: c/c-typeck.c:4422
+#: c/c-typeck.c:4427
 #, gcc-internal-format
 msgid "ISO C does not support %<++%> and %<--%> on complex types"
 msgstr ""
 
-#: c/c-typeck.c:4447 c/c-typeck.c:4481
+#: c/c-typeck.c:4452 c/c-typeck.c:4486
 #, gcc-internal-format
 msgid "wrong type argument to increment"
 msgstr ""
 
-#: c/c-typeck.c:4449 c/c-typeck.c:4484
+#: c/c-typeck.c:4454 c/c-typeck.c:4489
 #, gcc-internal-format
 msgid "wrong type argument to decrement"
 msgstr ""
 
-#: c/c-typeck.c:4469
+#: c/c-typeck.c:4474
 #, gcc-internal-format
 msgid "increment of pointer to an incomplete type %qT"
 msgstr ""
 
-#: c/c-typeck.c:4473
+#: c/c-typeck.c:4478
 #, gcc-internal-format
 msgid "decrement of pointer to an incomplete type %qT"
 msgstr ""
 
-#: c/c-typeck.c:4577
+#: c/c-typeck.c:4582
 #, gcc-internal-format
 msgid "taking address of expression of type %<void%>"
 msgstr ""
 
-#: c/c-typeck.c:4636
+#: c/c-typeck.c:4641
 #, gcc-internal-format
 msgid "cannot take address of bit-field %qD"
 msgstr ""
 
-#: c/c-typeck.c:4649
+#: c/c-typeck.c:4654
 #, gcc-internal-format
 msgid "cannot take address of scalar with reverse storage order"
 msgstr ""
 
-#: c/c-typeck.c:4657
+#: c/c-typeck.c:4662
 #, gcc-internal-format
 msgid "address of array with reverse scalar storage order requested"
 msgstr ""
 
-#: c/c-typeck.c:4838
+#: c/c-typeck.c:4843
 #, gcc-internal-format
 msgid "global register variable %qD used in nested function"
 msgstr ""
 
-#: c/c-typeck.c:4841
+#: c/c-typeck.c:4846
 #, gcc-internal-format
 msgid "register variable %qD used in nested function"
 msgstr ""
 
-#: c/c-typeck.c:4846
+#: c/c-typeck.c:4851
 #, gcc-internal-format
 msgid "address of global register variable %qD requested"
 msgstr ""
 
-#: c/c-typeck.c:4848
+#: c/c-typeck.c:4853
 #, gcc-internal-format
 msgid "address of register variable %qD requested"
 msgstr ""
 
-#: c/c-typeck.c:4951
+#: c/c-typeck.c:4956
 #, gcc-internal-format
 msgid "non-lvalue array in conditional expression"
 msgstr ""
 
-#: c/c-typeck.c:5033
+#: c/c-typeck.c:5038
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other result of conditional"
 msgstr ""
 
-#: c/c-typeck.c:5092 c/c-typeck.c:5098
+#: c/c-typeck.c:5097 c/c-typeck.c:5103
 #, gcc-internal-format
 msgid "operand of ?: changes signedness from %qT to %qT due to unsignedness of other operand"
 msgstr ""
 
-#: c/c-typeck.c:5115
+#: c/c-typeck.c:5120
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr with only one void side"
 msgstr ""
 
-#: c/c-typeck.c:5132
+#: c/c-typeck.c:5137
 #, gcc-internal-format
 msgid "pointers to disjoint address spaces used in conditional expression"
 msgstr ""
 
-#: c/c-typeck.c:5143 c/c-typeck.c:5160
+#: c/c-typeck.c:5148 c/c-typeck.c:5165
 #, gcc-internal-format
 msgid "pointer to array loses qualifier in conditional expression"
 msgstr ""
 
-#: c/c-typeck.c:5148 c/c-typeck.c:5165
+#: c/c-typeck.c:5153 c/c-typeck.c:5170
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr between %<void *%> and function pointer"
 msgstr ""
 
-#: c/c-typeck.c:5178
+#: c/c-typeck.c:5183
 #, gcc-internal-format
 msgid "pointer type mismatch in conditional expression"
 msgstr ""
 
-#: c/c-typeck.c:5187 c/c-typeck.c:5198
+#: c/c-typeck.c:5192 c/c-typeck.c:5203
 #, gcc-internal-format
 msgid "pointer/integer type mismatch in conditional expression"
 msgstr ""
 
-#: c/c-typeck.c:5336
+#: c/c-typeck.c:5341
 #, gcc-internal-format
 msgid "left-hand operand of comma expression has no effect"
 msgstr ""
 
-#: c/c-typeck.c:5354 c/c-typeck.c:10636
+#: c/c-typeck.c:5359 c/c-typeck.c:10641
 #, gcc-internal-format
 msgid "right-hand operand of comma expression has no effect"
 msgstr ""
 
-#: c/c-typeck.c:5423
+#: c/c-typeck.c:5428
 msgid "cast adds %q#v qualifier to function type"
 msgstr ""
 
-#: c/c-typeck.c:5429
+#: c/c-typeck.c:5434
 msgid "cast discards %qv qualifier from pointer target type"
 msgstr ""
 
-#: c/c-typeck.c:5464
+#: c/c-typeck.c:5469
 #, gcc-internal-format
 msgid "to be safe all intermediate pointers in cast from %qT to %qT must be %<const%> qualified"
 msgstr ""
 
-#: c/c-typeck.c:5554
+#: c/c-typeck.c:5559
 #, gcc-internal-format
 msgid "cast specifies array type"
 msgstr ""
 
-#: c/c-typeck.c:5560
+#: c/c-typeck.c:5565
 #, gcc-internal-format
 msgid "cast specifies function type"
 msgstr ""
 
-#: c/c-typeck.c:5575
+#: c/c-typeck.c:5580
 #, gcc-internal-format
 msgid "ISO C forbids casting nonscalar to the same type"
 msgstr ""
 
-#: c/c-typeck.c:5595
+#: c/c-typeck.c:5600
 #, gcc-internal-format
 msgid "ISO C forbids casts to union type"
 msgstr ""
 
-#: c/c-typeck.c:5605
+#: c/c-typeck.c:5610
 #, gcc-internal-format
 msgid "cast to union type from type not present in union"
 msgstr ""
 
-#: c/c-typeck.c:5640
+#: c/c-typeck.c:5645
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint generic address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5645
+#: c/c-typeck.c:5650
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to generic address space pointer from disjoint %s address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5650
+#: c/c-typeck.c:5655
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint %s address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5670
+#: c/c-typeck.c:5675
 #, gcc-internal-format
 msgid "cast increases required alignment of target type"
 msgstr ""
 
-#: c/c-typeck.c:5681
+#: c/c-typeck.c:5686
 #, gcc-internal-format
 msgid "cast from pointer to integer of different size"
 msgstr ""
 
-#: c/c-typeck.c:5686
+#: c/c-typeck.c:5691
 #, gcc-internal-format
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr ""
 
-#: c/c-typeck.c:5695 cp/typeck.c:7811
+#: c/c-typeck.c:5700 cp/typeck.c:7811
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr ""
 
-#: c/c-typeck.c:5709
+#: c/c-typeck.c:5714
 #, gcc-internal-format
 msgid "ISO C forbids conversion of function pointer to object pointer type"
 msgstr ""
 
-#: c/c-typeck.c:5718
+#: c/c-typeck.c:5723
 #, gcc-internal-format
 msgid "ISO C forbids conversion of object pointer to function pointer type"
 msgstr ""
 
-#: c/c-typeck.c:5728
+#: c/c-typeck.c:5733
 #, gcc-internal-format
 msgid "cast between incompatible function types from %qT to %qT"
 msgstr ""
 
-#: c/c-typeck.c:5815
+#: c/c-typeck.c:5820
 #, gcc-internal-format
 msgid "defining a type in a cast is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:5856
+#: c/c-typeck.c:5861
 #, gcc-internal-format
 msgid "assignment to expression with array type"
 msgstr ""
 
-#: c/c-typeck.c:5982
+#: c/c-typeck.c:5987
 #, gcc-internal-format
 msgid "enum conversion in assignment is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:6180 c/c-typeck.c:6202 c/c-typeck.c:6226
+#: c/c-typeck.c:6185 c/c-typeck.c:6207 c/c-typeck.c:6231
 #, gcc-internal-format
 msgid "(near initialization for %qs)"
 msgstr ""
 
-#: c/c-typeck.c:6241
+#: c/c-typeck.c:6246
 #, gcc-internal-format
 msgid "array initialized from parenthesized string constant"
 msgstr ""
 
-#: c/c-typeck.c:6284 c/c-typeck.c:6476 c/c-typeck.c:6908
+#: c/c-typeck.c:6289 c/c-typeck.c:6481 c/c-typeck.c:6913
 #, gcc-internal-format
 msgid "expected %qT but argument is of type %qT"
 msgstr ""
 
-#: c/c-typeck.c:6471
+#: c/c-typeck.c:6476
 #, gcc-internal-format
 msgid "enum conversion when passing argument %d of %qE is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:6480
+#: c/c-typeck.c:6485
 #, gcc-internal-format
 msgid "enum conversion from %qT to %qT in assignment is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:6484
+#: c/c-typeck.c:6489
 #, gcc-internal-format
 msgid "enum conversion from %qT to %qT in initialization is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:6489
+#: c/c-typeck.c:6494
 #, gcc-internal-format
 msgid "enum conversion from %qT to %qT in return is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:6523
+#: c/c-typeck.c:6528
 #, gcc-internal-format
 msgid "cannot pass rvalue to reference parameter"
 msgstr ""
 
-#: c/c-typeck.c:6656 c/c-typeck.c:6942
+#: c/c-typeck.c:6661 c/c-typeck.c:6947
 msgid "passing argument %d of %qE makes %q#v qualified function pointer from unqualified"
 msgstr ""
 
-#: c/c-typeck.c:6659 c/c-typeck.c:6945
+#: c/c-typeck.c:6664 c/c-typeck.c:6950
 msgid "assignment makes %q#v qualified function pointer from unqualified"
 msgstr ""
 
-#: c/c-typeck.c:6662 c/c-typeck.c:6947
+#: c/c-typeck.c:6667 c/c-typeck.c:6952
 msgid "initialization makes %q#v qualified function pointer from unqualified"
 msgstr ""
 
-#: c/c-typeck.c:6665 c/c-typeck.c:6949
+#: c/c-typeck.c:6670 c/c-typeck.c:6954
 msgid "return makes %q#v qualified function pointer from unqualified"
 msgstr ""
 
-#: c/c-typeck.c:6673 c/c-typeck.c:6840 c/c-typeck.c:6883
+#: c/c-typeck.c:6678 c/c-typeck.c:6845 c/c-typeck.c:6888
 msgid "passing argument %d of %qE discards %qv qualifier from pointer target type"
 msgstr ""
 
-#: c/c-typeck.c:6675 c/c-typeck.c:6842 c/c-typeck.c:6885
+#: c/c-typeck.c:6680 c/c-typeck.c:6847 c/c-typeck.c:6890
 msgid "assignment discards %qv qualifier from pointer target type"
 msgstr ""
 
-#: c/c-typeck.c:6677 c/c-typeck.c:6844 c/c-typeck.c:6887
+#: c/c-typeck.c:6682 c/c-typeck.c:6849 c/c-typeck.c:6892
 msgid "initialization discards %qv qualifier from pointer target type"
 msgstr ""
 
-#: c/c-typeck.c:6679 c/c-typeck.c:6846 c/c-typeck.c:6889
+#: c/c-typeck.c:6684 c/c-typeck.c:6851 c/c-typeck.c:6894
 msgid "return discards %qv qualifier from pointer target type"
 msgstr ""
 
-#: c/c-typeck.c:6688
+#: c/c-typeck.c:6693
 #, gcc-internal-format
 msgid "ISO C prohibits argument conversion to union type"
 msgstr ""
 
-#: c/c-typeck.c:6750
+#: c/c-typeck.c:6755
 #, gcc-internal-format
 msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgstr ""
 
-#: c/c-typeck.c:6762
+#: c/c-typeck.c:6767
 #, gcc-internal-format
 msgid "passing argument %d of %qE from pointer to non-enclosed address space"
 msgstr ""
 
-#: c/c-typeck.c:6766
+#: c/c-typeck.c:6771
 #, gcc-internal-format
 msgid "assignment from pointer to non-enclosed address space"
 msgstr ""
 
-#: c/c-typeck.c:6770
+#: c/c-typeck.c:6775
 #, gcc-internal-format
 msgid "initialization from pointer to non-enclosed address space"
 msgstr ""
 
-#: c/c-typeck.c:6774
+#: c/c-typeck.c:6779
 #, gcc-internal-format
 msgid "return from pointer to non-enclosed address space"
 msgstr ""
 
-#: c/c-typeck.c:6792
+#: c/c-typeck.c:6797
 #, gcc-internal-format
 msgid "argument %d of %qE might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:6798
+#: c/c-typeck.c:6803
 #, gcc-internal-format
 msgid "assignment left-hand side might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:6803
+#: c/c-typeck.c:6808
 #, gcc-internal-format
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:6808 cp/typeck.c:8891
+#: c/c-typeck.c:6813 cp/typeck.c:8891
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:6857
+#: c/c-typeck.c:6862
 #, gcc-internal-format
 msgid "ISO C forbids passing argument %d of %qE between function pointer and %<void *%>"
 msgstr ""
 
-#: c/c-typeck.c:6860
+#: c/c-typeck.c:6865
 #, gcc-internal-format
 msgid "ISO C forbids assignment between function pointer and %<void *%>"
 msgstr ""
 
-#: c/c-typeck.c:6862
+#: c/c-typeck.c:6867
 #, gcc-internal-format
 msgid "ISO C forbids initialization between function pointer and %<void *%>"
 msgstr ""
 
-#: c/c-typeck.c:6864
+#: c/c-typeck.c:6869
 #, gcc-internal-format
 msgid "ISO C forbids return between function pointer and %<void *%>"
 msgstr ""
 
-#: c/c-typeck.c:6904
+#: c/c-typeck.c:6909
 #, gcc-internal-format
 msgid "pointer targets in passing argument %d of %qE differ in signedness"
 msgstr ""
 
-#: c/c-typeck.c:6913
+#: c/c-typeck.c:6918
 #, gcc-internal-format
 msgid "pointer targets in assignment from %qT to %qT differ in signedness"
 msgstr ""
 
-#: c/c-typeck.c:6918
+#: c/c-typeck.c:6923
 #, gcc-internal-format
 msgid "pointer targets in initialization of %qT from %qT differ in signedness"
 msgstr ""
 
-#: c/c-typeck.c:6923
+#: c/c-typeck.c:6928
 #, gcc-internal-format
 msgid "pointer targets in returning %qT from a function with return type %qT differ in signedness"
 msgstr ""
 
-#: c/c-typeck.c:6961
+#: c/c-typeck.c:6966
 #, gcc-internal-format
 msgid "passing argument %d of %qE from incompatible pointer type"
 msgstr ""
 
-#: c/c-typeck.c:6967
+#: c/c-typeck.c:6972
 #, gcc-internal-format
 msgid "assignment to %qT from incompatible pointer type %qT"
 msgstr ""
 
-#: c/c-typeck.c:6972
+#: c/c-typeck.c:6977
 #, gcc-internal-format
 msgid "initialization of %qT from incompatible pointer type %qT"
 msgstr ""
 
-#: c/c-typeck.c:6977
+#: c/c-typeck.c:6982
 #, gcc-internal-format
 msgid "returning %qT from a function with incompatible return type %qT"
 msgstr "повертає %qT з функції із несумісним типом повернення %qT"
@@ -36982,782 +37024,782 @@
 
 #. ??? This should not be an error when inlining calls to
 #. unprototyped functions.
-#: c/c-typeck.c:6991 c/c-typeck.c:7514 cp/typeck.c:2063
+#: c/c-typeck.c:6996 c/c-typeck.c:7519 cp/typeck.c:2063
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr ""
 
-#: c/c-typeck.c:7004
+#: c/c-typeck.c:7009
 #, gcc-internal-format
 msgid "passing argument %d of %qE makes pointer from integer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7010
+#: c/c-typeck.c:7015
 #, gcc-internal-format
 msgid "assignment to %qT from %qT makes pointer from integer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7015
+#: c/c-typeck.c:7020
 #, gcc-internal-format
 msgid "initialization of %qT from %qT makes pointer from integer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7019
+#: c/c-typeck.c:7024
 #, gcc-internal-format
 msgid "returning %qT from a function with return type %qT makes pointer from integer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7035
+#: c/c-typeck.c:7040
 #, gcc-internal-format
 msgid "passing argument %d of %qE makes integer from pointer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7041
+#: c/c-typeck.c:7046
 #, gcc-internal-format
 msgid "assignment to %qT from %qT makes integer from pointer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7046
+#: c/c-typeck.c:7051
 #, gcc-internal-format
 msgid "initialization of %qT from %qT makes integer from pointer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7050
+#: c/c-typeck.c:7055
 #, gcc-internal-format
 msgid "returning %qT from a function with return type %qT makes integer from pointer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7073
+#: c/c-typeck.c:7078
 #, gcc-internal-format
 msgid "incompatible type for argument %d of %qE"
 msgstr ""
 
-#: c/c-typeck.c:7078
+#: c/c-typeck.c:7083
 #, gcc-internal-format
 msgid "incompatible types when assigning to type %qT from type %qT"
 msgstr ""
 
-#: c/c-typeck.c:7083
+#: c/c-typeck.c:7088
 #, gcc-internal-format
 msgid "incompatible types when initializing type %qT using type %qT"
 msgstr ""
 
-#: c/c-typeck.c:7088
+#: c/c-typeck.c:7093
 #, gcc-internal-format
 msgid "incompatible types when returning type %qT but %qT was expected"
 msgstr ""
 
-#: c/c-typeck.c:7152
+#: c/c-typeck.c:7157
 #, gcc-internal-format
 msgid "traditional C rejects automatic aggregate initialization"
 msgstr ""
 
-#: c/c-typeck.c:7388 c/c-typeck.c:8284 cp/typeck2.c:1045
+#: c/c-typeck.c:7393 c/c-typeck.c:8289 cp/typeck2.c:1045
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr ""
 
-#: c/c-typeck.c:7398 cp/typeck2.c:1059
+#: c/c-typeck.c:7403 cp/typeck2.c:1059
 #, gcc-internal-format
 msgid "char-array initialized from wide string"
 msgstr ""
 
-#: c/c-typeck.c:7407
+#: c/c-typeck.c:7412
 #, gcc-internal-format
 msgid "wide character array initialized from non-wide string"
 msgstr ""
 
-#: c/c-typeck.c:7413
+#: c/c-typeck.c:7418
 #, gcc-internal-format
 msgid "wide character array initialized from incompatible wide string"
 msgstr ""
 
-#: c/c-typeck.c:7446
+#: c/c-typeck.c:7451
 #, gcc-internal-format
 msgid "array of inappropriate type initialized from string constant"
 msgstr ""
 
-#: c/c-typeck.c:7533 c/c-typeck.c:7557 c/c-typeck.c:7560 c/c-typeck.c:7568
-#: c/c-typeck.c:7608 c/c-typeck.c:9131 c/c-typeck.c:9181
+#: c/c-typeck.c:7538 c/c-typeck.c:7562 c/c-typeck.c:7565 c/c-typeck.c:7573
+#: c/c-typeck.c:7613 c/c-typeck.c:9136 c/c-typeck.c:9186
 #, gcc-internal-format
 msgid "initializer element is not constant"
 msgstr ""
 
-#: c/c-typeck.c:7542
+#: c/c-typeck.c:7547
 #, gcc-internal-format
 msgid "array initialized from non-constant array expression"
 msgstr ""
 
-#: c/c-typeck.c:7573 c/c-typeck.c:7621 c/c-typeck.c:9191
+#: c/c-typeck.c:7578 c/c-typeck.c:7626 c/c-typeck.c:9196
 #, gcc-internal-format
 msgid "initializer element is not a constant expression"
 msgstr ""
 
-#: c/c-typeck.c:7615 c/c-typeck.c:9186
+#: c/c-typeck.c:7620 c/c-typeck.c:9191
 #, gcc-internal-format
 msgid "initializer element is not computable at load time"
 msgstr ""
 
-#: c/c-typeck.c:7634
+#: c/c-typeck.c:7639
 #, gcc-internal-format
 msgid "invalid initializer"
 msgstr ""
 
-#: c/c-typeck.c:7912 cp/decl.c:6396
+#: c/c-typeck.c:7917 cp/decl.c:6396
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr ""
 
-#: c/c-typeck.c:8132
+#: c/c-typeck.c:8137
 #, gcc-internal-format
 msgid "extra brace group at end of initializer"
 msgstr ""
 
-#: c/c-typeck.c:8215
+#: c/c-typeck.c:8220
 #, gcc-internal-format
 msgid "braces around scalar initializer"
 msgstr ""
 
-#: c/c-typeck.c:8281 c/c-typeck.c:9615 cp/typeck2.c:1084 cp/typeck2.c:1297
+#: c/c-typeck.c:8286 c/c-typeck.c:9620 cp/typeck2.c:1084 cp/typeck2.c:1297
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr ""
 
-#: c/c-typeck.c:8318
+#: c/c-typeck.c:8323
 #, gcc-internal-format
 msgid "missing braces around initializer"
 msgstr ""
 
-#: c/c-typeck.c:8341
+#: c/c-typeck.c:8346
 #, gcc-internal-format
 msgid "missing initializer for field %qD of %qT"
 msgstr ""
 
-#: c/c-typeck.c:8365
+#: c/c-typeck.c:8370
 #, gcc-internal-format
 msgid "empty scalar initializer"
 msgstr ""
 
-#: c/c-typeck.c:8370
+#: c/c-typeck.c:8375
 #, gcc-internal-format
 msgid "extra elements in scalar initializer"
 msgstr ""
 
-#: c/c-typeck.c:8483 c/c-typeck.c:8565
+#: c/c-typeck.c:8488 c/c-typeck.c:8570
 #, gcc-internal-format
 msgid "array index in non-array initializer"
 msgstr ""
 
-#: c/c-typeck.c:8488 c/c-typeck.c:8627
+#: c/c-typeck.c:8493 c/c-typeck.c:8632
 #, gcc-internal-format
 msgid "field name not in record or union initializer"
 msgstr ""
 
-#: c/c-typeck.c:8538
+#: c/c-typeck.c:8543
 #, gcc-internal-format
 msgid "array index in initializer not of integer type"
 msgstr ""
 
-#: c/c-typeck.c:8547 c/c-typeck.c:8556
+#: c/c-typeck.c:8552 c/c-typeck.c:8561
 #, gcc-internal-format
 msgid "array index in initializer is not an integer constant expression"
 msgstr ""
 
-#: c/c-typeck.c:8561 c/c-typeck.c:8563
+#: c/c-typeck.c:8566 c/c-typeck.c:8568
 #, gcc-internal-format
 msgid "nonconstant array index in initializer"
 msgstr ""
 
-#: c/c-typeck.c:8567 c/c-typeck.c:8570
+#: c/c-typeck.c:8572 c/c-typeck.c:8575
 #, gcc-internal-format
 msgid "array index in initializer exceeds array bounds"
 msgstr ""
 
-#: c/c-typeck.c:8589
+#: c/c-typeck.c:8594
 #, gcc-internal-format
 msgid "empty index range in initializer"
 msgstr ""
 
-#: c/c-typeck.c:8598
+#: c/c-typeck.c:8603
 #, gcc-internal-format
 msgid "array index range in initializer exceeds array bounds"
 msgstr ""
 
-#: c/c-typeck.c:8700 c/c-typeck.c:8730 c/c-typeck.c:9274
+#: c/c-typeck.c:8705 c/c-typeck.c:8735 c/c-typeck.c:9279
 #, gcc-internal-format
 msgid "initialized field with side-effects overwritten"
 msgstr ""
 
-#: c/c-typeck.c:8704 c/c-typeck.c:8734 c/c-typeck.c:9277
+#: c/c-typeck.c:8709 c/c-typeck.c:8739 c/c-typeck.c:9282
 #, gcc-internal-format
 msgid "initialized field overwritten"
 msgstr ""
 
-#: c/c-typeck.c:9208
+#: c/c-typeck.c:9213
 #, gcc-internal-format
 msgid "enum conversion in initialization is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:9496
+#: c/c-typeck.c:9501
 #, gcc-internal-format
 msgid "excess elements in char array initializer"
 msgstr ""
 
-#: c/c-typeck.c:9503 c/c-typeck.c:9574
+#: c/c-typeck.c:9508 c/c-typeck.c:9579
 #, gcc-internal-format
 msgid "excess elements in struct initializer"
 msgstr ""
 
-#: c/c-typeck.c:9518
+#: c/c-typeck.c:9523
 #, gcc-internal-format
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr ""
 
-#: c/c-typeck.c:9589
+#: c/c-typeck.c:9594
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr ""
 
-#: c/c-typeck.c:9687
+#: c/c-typeck.c:9692
 #, gcc-internal-format
 msgid "excess elements in union initializer"
 msgstr ""
 
-#: c/c-typeck.c:9709
+#: c/c-typeck.c:9714
 #, gcc-internal-format
 msgid "traditional C rejects initialization of unions"
 msgstr ""
 
-#: c/c-typeck.c:9777
+#: c/c-typeck.c:9782
 #, gcc-internal-format
 msgid "excess elements in array initializer"
 msgstr ""
 
-#: c/c-typeck.c:9811
+#: c/c-typeck.c:9816
 #, gcc-internal-format
 msgid "excess elements in vector initializer"
 msgstr ""
 
-#: c/c-typeck.c:9843
+#: c/c-typeck.c:9848
 #, gcc-internal-format
 msgid "excess elements in scalar initializer"
 msgstr ""
 
-#: c/c-typeck.c:10086
+#: c/c-typeck.c:10091
 #, gcc-internal-format
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr ""
 
-#: c/c-typeck.c:10113 c/gimple-parser.c:1604 cp/typeck.c:9113
+#: c/c-typeck.c:10118 c/gimple-parser.c:1604 cp/typeck.c:9113
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr ""
 
-#: c/c-typeck.c:10139 c/c-typeck.c:10143
+#: c/c-typeck.c:10144 c/c-typeck.c:10148
 #, gcc-internal-format
 msgid "%<return%> with no value, in function returning non-void"
 msgstr ""
 
-#: c/c-typeck.c:10157 c/gimple-parser.c:1614
+#: c/c-typeck.c:10162 c/gimple-parser.c:1614
 #, gcc-internal-format
 msgid "%<return%> with a value, in function returning void"
 msgstr ""
 
-#: c/c-typeck.c:10160
+#: c/c-typeck.c:10165
 #, gcc-internal-format
 msgid "ISO C forbids %<return%> with expression, in function returning void"
 msgstr ""
 
-#: c/c-typeck.c:10236
+#: c/c-typeck.c:10241
 #, gcc-internal-format
 msgid "function returns address of label"
 msgstr ""
 
-#: c/c-typeck.c:10327 cp/semantics.c:1171
+#: c/c-typeck.c:10332 cp/semantics.c:1171
 #, gcc-internal-format
 msgid "switch quantity not an integer"
 msgstr ""
 
-#: c/c-typeck.c:10352
+#: c/c-typeck.c:10357
 #, gcc-internal-format
 msgid "%<long%> switch expression not converted to %<int%> in ISO C"
 msgstr ""
 
-#: c/c-typeck.c:10390 c/c-typeck.c:10398
+#: c/c-typeck.c:10395 c/c-typeck.c:10403
 #, gcc-internal-format
 msgid "case label is not an integer constant expression"
 msgstr ""
 
-#: c/c-typeck.c:10404 cp/parser.c:11067
+#: c/c-typeck.c:10409 cp/parser.c:11067
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr ""
 
-#: c/c-typeck.c:10406
+#: c/c-typeck.c:10411
 #, gcc-internal-format
 msgid "%<default%> label not within a switch statement"
 msgstr ""
 
-#: c/c-typeck.c:10578 cp/parser.c:12356
+#: c/c-typeck.c:10583 cp/parser.c:12353
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr ""
 
-#: c/c-typeck.c:10580 cp/parser.c:12379
+#: c/c-typeck.c:10585 cp/parser.c:12376
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr ""
 
-#: c/c-typeck.c:10585 cp/parser.c:12369
+#: c/c-typeck.c:10590 cp/parser.c:12366
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr ""
 
-#: c/c-typeck.c:10590
+#: c/c-typeck.c:10595
 #, gcc-internal-format
 msgid "break statement within %<#pragma simd%> loop body"
 msgstr ""
 
-#: c/c-typeck.c:10592
+#: c/c-typeck.c:10597
 #, gcc-internal-format
 msgid "continue statement within %<#pragma simd%> loop body"
 msgstr ""
 
-#: c/c-typeck.c:10618 cp/cp-gimplify.c:432
+#: c/c-typeck.c:10623 cp/cp-gimplify.c:432
 #, gcc-internal-format
 msgid "statement with no effect"
 msgstr ""
 
-#: c/c-typeck.c:10662
+#: c/c-typeck.c:10667
 #, gcc-internal-format
 msgid "expression statement has incomplete type"
 msgstr ""
 
-#: c/c-typeck.c:11476 c/c-typeck.c:11644 cp/typeck.c:5017
+#: c/c-typeck.c:11481 c/c-typeck.c:11649 cp/typeck.c:5017
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr ""
 
-#: c/c-typeck.c:11484 c/c-typeck.c:11652 cp/typeck.c:5030
+#: c/c-typeck.c:11489 c/c-typeck.c:11657 cp/typeck.c:5030
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr ""
 
-#: c/c-typeck.c:11509 c/c-typeck.c:11677 cp/typeck.c:5058
+#: c/c-typeck.c:11514 c/c-typeck.c:11682 cp/typeck.c:5058
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr ""
 
-#: c/c-typeck.c:11523 cp/typeck.c:4743
+#: c/c-typeck.c:11528 cp/typeck.c:4743
 #, gcc-internal-format
 msgid "comparing floating point with == or != is unsafe"
 msgstr ""
 
-#: c/c-typeck.c:11541 c/c-typeck.c:11562
+#: c/c-typeck.c:11546 c/c-typeck.c:11567
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<false%> for the address of %qD will never be NULL"
 msgstr ""
 
-#: c/c-typeck.c:11547 c/c-typeck.c:11568
+#: c/c-typeck.c:11552 c/c-typeck.c:11573
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<true%> for the address of %qD will never be NULL"
 msgstr ""
 
-#: c/c-typeck.c:11589 c/c-typeck.c:11718
+#: c/c-typeck.c:11594 c/c-typeck.c:11723
 #, gcc-internal-format
 msgid "comparison of pointers to disjoint address spaces"
 msgstr ""
 
-#: c/c-typeck.c:11596 c/c-typeck.c:11602
+#: c/c-typeck.c:11601 c/c-typeck.c:11607
 #, gcc-internal-format
 msgid "ISO C forbids comparison of %<void *%> with function pointer"
 msgstr ""
 
-#: c/c-typeck.c:11609 c/c-typeck.c:11728
+#: c/c-typeck.c:11614 c/c-typeck.c:11733
 #, gcc-internal-format
 msgid "comparison of distinct pointer types lacks a cast"
 msgstr ""
 
-#: c/c-typeck.c:11621 c/c-typeck.c:11626 c/c-typeck.c:11754 c/c-typeck.c:11759
+#: c/c-typeck.c:11626 c/c-typeck.c:11631 c/c-typeck.c:11759 c/c-typeck.c:11764
 #, gcc-internal-format
 msgid "comparison between pointer and integer"
 msgstr ""
 
-#: c/c-typeck.c:11706
+#: c/c-typeck.c:11711
 #, gcc-internal-format
 msgid "comparison of complete and incomplete pointers"
 msgstr ""
 
-#: c/c-typeck.c:11708
+#: c/c-typeck.c:11713
 #, gcc-internal-format
 msgid "ISO C forbids ordered comparisons of pointers to functions"
 msgstr ""
 
-#: c/c-typeck.c:11713
+#: c/c-typeck.c:11718
 #, gcc-internal-format
 msgid "ordered comparison of pointer with null pointer"
 msgstr ""
 
-#: c/c-typeck.c:11736 c/c-typeck.c:11739 c/c-typeck.c:11746 c/c-typeck.c:11749
+#: c/c-typeck.c:11741 c/c-typeck.c:11744 c/c-typeck.c:11751 c/c-typeck.c:11754
 #: cp/typeck.c:5081 cp/typeck.c:5088
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr ""
 
-#: c/c-typeck.c:11811
+#: c/c-typeck.c:11816
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
 msgstr ""
 
-#: c/c-typeck.c:12126
+#: c/c-typeck.c:12131
 #, gcc-internal-format
 msgid "used array that cannot be converted to pointer where scalar is required"
 msgstr ""
 
-#: c/c-typeck.c:12130
+#: c/c-typeck.c:12135
 #, gcc-internal-format
 msgid "used struct type value where scalar is required"
 msgstr ""
 
-#: c/c-typeck.c:12134
+#: c/c-typeck.c:12139
 #, gcc-internal-format
 msgid "used union type value where scalar is required"
 msgstr ""
 
-#: c/c-typeck.c:12150
+#: c/c-typeck.c:12155
 #, gcc-internal-format
 msgid "used vector type where scalar is required"
 msgstr ""
 
-#: c/c-typeck.c:12340 cp/semantics.c:8508
+#: c/c-typeck.c:12345 cp/semantics.c:8511
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12379 cp/semantics.c:8545
+#: c/c-typeck.c:12384 cp/semantics.c:8548
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12423 c/c-typeck.c:13581 c/c-typeck.c:13642 c/c-typeck.c:13704
+#: c/c-typeck.c:12428 c/c-typeck.c:13586 c/c-typeck.c:13647 c/c-typeck.c:13709
 #, gcc-internal-format
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12436 c/c-typeck.c:13628 cp/semantics.c:4546
-#: cp/semantics.c:6717
+#: c/c-typeck.c:12441 c/c-typeck.c:13633 cp/semantics.c:4549
+#: cp/semantics.c:6720
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12445 c/c-typeck.c:13652 cp/semantics.c:4556
-#: cp/semantics.c:6735
+#: c/c-typeck.c:12450 c/c-typeck.c:13657 cp/semantics.c:4559
+#: cp/semantics.c:6738
 #, gcc-internal-format
 msgid "%qE is a member of a union"
 msgstr ""
 
-#: c/c-typeck.c:12455 cp/semantics.c:4570 cp/semantics.c:6760
+#: c/c-typeck.c:12460 cp/semantics.c:4573 cp/semantics.c:6763
 #, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12459 c/c-typeck.c:13669 cp/semantics.c:4574
-#: cp/semantics.c:6763
+#: c/c-typeck.c:12464 c/c-typeck.c:13674 cp/semantics.c:4577
+#: cp/semantics.c:6766
 #, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12466
+#: c/c-typeck.c:12471
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12475 c/c-typeck.c:13676 c/c-typeck.c:13778
-#: cp/semantics.c:4591 cp/semantics.c:6769 cp/semantics.c:6931
+#: c/c-typeck.c:12480 c/c-typeck.c:13681 c/c-typeck.c:13783
+#: cp/semantics.c:4594 cp/semantics.c:6772 cp/semantics.c:6934
 #, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12511 cp/semantics.c:4623
+#: c/c-typeck.c:12516 cp/semantics.c:4626
 #, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr ""
 
-#: c/c-typeck.c:12518 cp/semantics.c:4630
+#: c/c-typeck.c:12523 cp/semantics.c:4633
 #, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr ""
 
-#: c/c-typeck.c:12545 c/c-typeck.c:12609 c/c-typeck.c:12867
-#: cp/semantics.c:4666 cp/semantics.c:4730
+#: c/c-typeck.c:12550 c/c-typeck.c:12614 c/c-typeck.c:12872
+#: cp/semantics.c:4669 cp/semantics.c:4733
 #, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12564 cp/semantics.c:4685
+#: c/c-typeck.c:12569 cp/semantics.c:4688
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12572 cp/semantics.c:4693
+#: c/c-typeck.c:12577 cp/semantics.c:4696
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12581 c/c-typeck.c:12691 cp/semantics.c:4702
-#: cp/semantics.c:4812
+#: c/c-typeck.c:12586 c/c-typeck.c:12696 cp/semantics.c:4705
+#: cp/semantics.c:4815
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12598 cp/semantics.c:4719
+#: c/c-typeck.c:12603 cp/semantics.c:4722
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12635 cp/semantics.c:4756
+#: c/c-typeck.c:12640 cp/semantics.c:4759
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12650 cp/semantics.c:4771
+#: c/c-typeck.c:12655 cp/semantics.c:4774
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12683 cp/semantics.c:4804
+#: c/c-typeck.c:12688 cp/semantics.c:4807
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12701 c/c-typeck.c:12810 cp/semantics.c:4822
-#: cp/semantics.c:4934
+#: c/c-typeck.c:12706 c/c-typeck.c:12815 cp/semantics.c:4825
+#: cp/semantics.c:4937
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12709 cp/semantics.c:4830
+#: c/c-typeck.c:12714 cp/semantics.c:4833
 #, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr ""
 
-#: c/c-typeck.c:13103 c/c-typeck.c:13113
+#: c/c-typeck.c:13108 c/c-typeck.c:13118
 #, gcc-internal-format
 msgid "%qD in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: c/c-typeck.c:13130
+#: c/c-typeck.c:13135
 #, gcc-internal-format
 msgid "%<_Atomic%> %qE in %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13178
+#: c/c-typeck.c:13183
 #, gcc-internal-format
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr ""
 
-#: c/c-typeck.c:13187 cp/semantics.c:5755
+#: c/c-typeck.c:13192 cp/semantics.c:5758
 #, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr ""
 
-#: c/c-typeck.c:13275
+#: c/c-typeck.c:13280
 #, gcc-internal-format
 msgid "variable length element type in array %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13293 c/c-typeck.c:13836 cp/semantics.c:7249
+#: c/c-typeck.c:13298 c/c-typeck.c:13841 cp/semantics.c:7252
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13305 cp/semantics.c:7289
+#: c/c-typeck.c:13310 cp/semantics.c:7292
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr ""
 
-#: c/c-typeck.c:13319 cp/semantics.c:5929
+#: c/c-typeck.c:13324 cp/semantics.c:5932
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr ""
 
-#: c/c-typeck.c:13327
+#: c/c-typeck.c:13332
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with type %qT"
 msgstr ""
 
-#: c/c-typeck.c:13335
+#: c/c-typeck.c:13340
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13354 cp/semantics.c:5999
+#: c/c-typeck.c:13359 cp/semantics.c:6002
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
-#: c/c-typeck.c:13384 c/c-typeck.c:13771 cp/semantics.c:6083
-#: cp/semantics.c:6924
+#: c/c-typeck.c:13389 c/c-typeck.c:13776 cp/semantics.c:6086
+#: cp/semantics.c:6927
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr ""
 
-#: c/c-typeck.c:13393 cp/semantics.c:6092
+#: c/c-typeck.c:13398 cp/semantics.c:6095
 #, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr ""
 
-#: c/c-typeck.c:13404 c/c-typeck.c:13434 c/c-typeck.c:13463
+#: c/c-typeck.c:13409 c/c-typeck.c:13439 c/c-typeck.c:13468
 #, gcc-internal-format
 msgid "%qE appears more than once in data clauses"
 msgstr ""
 
-#: c/c-typeck.c:13411 c/c-typeck.c:13440 c/c-typeck.c:13600 c/c-typeck.c:13714
-#: c/c-typeck.c:13720 c/c-typeck.c:13733 c/c-typeck.c:13742
-#: cp/semantics.c:6102 cp/semantics.c:6109 cp/semantics.c:6160
-#: cp/semantics.c:6166 cp/semantics.c:6203 cp/semantics.c:6680
-#: cp/semantics.c:6817 cp/semantics.c:6823 cp/semantics.c:6836
-#: cp/semantics.c:6845
+#: c/c-typeck.c:13416 c/c-typeck.c:13445 c/c-typeck.c:13605 c/c-typeck.c:13719
+#: c/c-typeck.c:13725 c/c-typeck.c:13738 c/c-typeck.c:13747
+#: cp/semantics.c:6105 cp/semantics.c:6112 cp/semantics.c:6163
+#: cp/semantics.c:6169 cp/semantics.c:6206 cp/semantics.c:6683
+#: cp/semantics.c:6820 cp/semantics.c:6826 cp/semantics.c:6839
+#: cp/semantics.c:6848
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
-#: c/c-typeck.c:13413 c/c-typeck.c:13442 c/c-typeck.c:13722 c/c-typeck.c:13744
-#: cp/semantics.c:6111 cp/semantics.c:6168 cp/semantics.c:6825
-#: cp/semantics.c:6847
+#: c/c-typeck.c:13418 c/c-typeck.c:13447 c/c-typeck.c:13727 c/c-typeck.c:13749
+#: cp/semantics.c:6114 cp/semantics.c:6171 cp/semantics.c:6828
+#: cp/semantics.c:6850
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr ""
 
-#: c/c-typeck.c:13427 cp/semantics.c:6154
+#: c/c-typeck.c:13432 cp/semantics.c:6157
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13456 cp/semantics.c:6197
+#: c/c-typeck.c:13461 cp/semantics.c:6200
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13475 cp/semantics.c:6545
+#: c/c-typeck.c:13480 cp/semantics.c:6548
 #, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13482
+#: c/c-typeck.c:13487
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array"
 msgstr ""
 
-#: c/c-typeck.c:13489
+#: c/c-typeck.c:13494
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<aligned%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13496
+#: c/c-typeck.c:13501
 #, gcc-internal-format
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:13551 cp/semantics.c:6627
+#: c/c-typeck.c:13556 cp/semantics.c:6630
 #, gcc-internal-format
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13573 cp/semantics.c:6658
+#: c/c-typeck.c:13578 cp/semantics.c:6661
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13597 c/c-typeck.c:13731 cp/semantics.c:6677
-#: cp/semantics.c:6834
+#: c/c-typeck.c:13602 c/c-typeck.c:13736 cp/semantics.c:6680
+#: cp/semantics.c:6837
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr ""
 
-#: c/c-typeck.c:13603 c/c-typeck.c:13735 cp/semantics.c:6683
-#: cp/semantics.c:6838
+#: c/c-typeck.c:13608 c/c-typeck.c:13740 cp/semantics.c:6686
+#: cp/semantics.c:6841
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr ""
 
-#: c/c-typeck.c:13635 cp/semantics.c:6724
+#: c/c-typeck.c:13640 cp/semantics.c:6727
 #, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13695 c/c-typeck.c:13785 cp/semantics.c:6799
-#: cp/semantics.c:6938
+#: c/c-typeck.c:13700 c/c-typeck.c:13790 cp/semantics.c:6802
+#: cp/semantics.c:6941
 #, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13766 cp/semantics.c:6918
+#: c/c-typeck.c:13771 cp/semantics.c:6921
 #, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr ""
 
-#: c/c-typeck.c:13794 cp/semantics.c:6947
+#: c/c-typeck.c:13799 cp/semantics.c:6950
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr ""
 
-#: c/c-typeck.c:13808 cp/semantics.c:6962
+#: c/c-typeck.c:13813 cp/semantics.c:6965
 #, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13811 cp/semantics.c:6964
+#: c/c-typeck.c:13816 cp/semantics.c:6967
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13826
+#: c/c-typeck.c:13831
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer nor an array"
 msgstr ""
 
-#: c/c-typeck.c:13900 cp/semantics.c:6359
+#: c/c-typeck.c:13905 cp/semantics.c:6362
 #, gcc-internal-format
 msgid "%<nonmonotonic%> modifier specified for %qs schedule kind"
 msgstr ""
 
-#: c/c-typeck.c:13931 cp/semantics.c:7141
+#: c/c-typeck.c:13936 cp/semantics.c:7144
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:13981 cp/semantics.c:7332
+#: c/c-typeck.c:13986 cp/semantics.c:7335
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr ""
 
-#: c/c-typeck.c:14001 cp/semantics.c:7223
+#: c/c-typeck.c:14006 cp/semantics.c:7226
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:14013 cp/semantics.c:7236
+#: c/c-typeck.c:14018 cp/semantics.c:7239
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14031 cp/semantics.c:7203
+#: c/c-typeck.c:14036 cp/semantics.c:7206
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14204
+#: c/c-typeck.c:14209
 #, gcc-internal-format
 msgid "cannot use %<va_arg%> with reverse storage order"
 msgstr ""
 
-#: c/c-typeck.c:14209
+#: c/c-typeck.c:14214
 #, gcc-internal-format
 msgid "second argument to %<va_arg%> is of incomplete type %qT"
 msgstr ""
 
-#: c/c-typeck.c:14215
+#: c/c-typeck.c:14220
 #, gcc-internal-format
 msgid "C++ requires promoted type, not enum type, in %<va_arg%>"
 msgstr ""
@@ -37871,7 +37913,7 @@
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr ""
 
-#: cp/call.c:3441 cp/pt.c:6495
+#: cp/call.c:3441 cp/pt.c:6509
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -38162,7 +38204,7 @@
 msgid "%q#D is private within this context"
 msgstr ""
 
-#: cp/call.c:6478 cp/decl.c:7343
+#: cp/call.c:6478 cp/decl.c:7364
 #, gcc-internal-format
 msgid "declared private here"
 msgstr ""
@@ -38172,7 +38214,7 @@
 msgid "%q#D is protected within this context"
 msgstr ""
 
-#: cp/call.c:6486 cp/decl.c:7344
+#: cp/call.c:6486 cp/decl.c:7365
 #, gcc-internal-format
 msgid "declared protected here"
 msgstr ""
@@ -38471,7 +38513,7 @@
 msgid "call to non-function %qD"
 msgstr ""
 
-#: cp/call.c:9119 cp/pt.c:15053 cp/typeck.c:2901
+#: cp/call.c:9119 cp/pt.c:15075 cp/typeck.c:2901
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
@@ -38679,262 +38721,262 @@
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr ""
 
-#: cp/class.c:2098
+#: cp/class.c:2103
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr ""
 
-#: cp/class.c:2110
+#: cp/class.c:2115
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr ""
 
-#: cp/class.c:2152
+#: cp/class.c:2156
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr ""
 
-#: cp/class.c:2156
+#: cp/class.c:2160
 #, gcc-internal-format
 msgid "%q#D is public, but requires an existing %q#T object"
 msgstr ""
 
-#: cp/class.c:2430
+#: cp/class.c:2434
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr ""
 
-#: cp/class.c:2785
+#: cp/class.c:2789
 #, gcc-internal-format
 msgid "%qD can be marked override"
 msgstr ""
 
-#: cp/class.c:2797
+#: cp/class.c:2801
 #, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr ""
 
-#: cp/class.c:2799
+#: cp/class.c:2803
 #, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr ""
 
-#: cp/class.c:2861
+#: cp/class.c:2865
 #, gcc-internal-format
 msgid "%qD was hidden"
 msgstr ""
 
-#: cp/class.c:2863
+#: cp/class.c:2867
 #, gcc-internal-format
 msgid "  by %qD"
 msgstr ""
 
-#: cp/class.c:2896
+#: cp/class.c:2900
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr ""
 
-#: cp/class.c:2906 cp/name-lookup.c:3293 cp/parser.c:19720
+#: cp/class.c:2910 cp/name-lookup.c:3293 cp/parser.c:19717
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
 
-#: cp/class.c:3097
+#: cp/class.c:3101
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr ""
 
-#: cp/class.c:3213
+#: cp/class.c:3217
 #, gcc-internal-format
 msgid "bit-field %q+#D with non-integral type"
 msgstr ""
 
-#: cp/class.c:3229
+#: cp/class.c:3233
 #, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr ""
 
-#: cp/class.c:3234
+#: cp/class.c:3238
 #, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr ""
 
-#: cp/class.c:3239
+#: cp/class.c:3243
 #, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr ""
 
-#: cp/class.c:3249
+#: cp/class.c:3253
 #, gcc-internal-format
 msgid "width of %qD exceeds its type"
 msgstr ""
 
-#: cp/class.c:3255
+#: cp/class.c:3259
 #, gcc-internal-format
 msgid "%qD is too small to hold all values of %q#T"
 msgstr ""
 
-#: cp/class.c:3316
+#: cp/class.c:3320
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr ""
 
-#: cp/class.c:3319
+#: cp/class.c:3323
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr ""
 
-#: cp/class.c:3321
+#: cp/class.c:3325
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr ""
 
-#: cp/class.c:3325
+#: cp/class.c:3329
 #, gcc-internal-format
 msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/class.c:3453
+#: cp/class.c:3457
 #, gcc-internal-format
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr ""
 
-#: cp/class.c:3460
+#: cp/class.c:3464
 #, gcc-internal-format
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr ""
 
-#: cp/class.c:3470
+#: cp/class.c:3474
 #, gcc-internal-format
 msgid "field %q+D invalidly declared function type"
 msgstr ""
 
-#: cp/class.c:3476
+#: cp/class.c:3480
 #, gcc-internal-format
 msgid "field %q+D invalidly declared method type"
 msgstr ""
 
-#: cp/class.c:3536
+#: cp/class.c:3540
 #, gcc-internal-format
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr ""
 
-#: cp/class.c:3585
+#: cp/class.c:3589
 #, gcc-internal-format
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr ""
 
-#: cp/class.c:3591
+#: cp/class.c:3595
 #, gcc-internal-format
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr ""
 
-#: cp/class.c:3617
+#: cp/class.c:3621
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr ""
 
-#: cp/class.c:3658
+#: cp/class.c:3662
 #, gcc-internal-format
 msgid "field %q#D with same name as class"
 msgstr ""
 
-#: cp/class.c:3681
+#: cp/class.c:3685
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr ""
 
-#: cp/class.c:3686
+#: cp/class.c:3690
 #, gcc-internal-format
 msgid "  but does not override %<%T(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:3688
+#: cp/class.c:3692
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr "  або %<operator=(const %T&)%>"
 
-#: cp/class.c:3692
+#: cp/class.c:3696
 #, gcc-internal-format
 msgid "  but does not override %<operator=(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:4097
+#: cp/class.c:4101
 #, gcc-internal-format
 msgid "alignment of %qD increased in -fabi-version=9 (GCC 5.2)"
 msgstr ""
 
-#: cp/class.c:4100
+#: cp/class.c:4104
 #, gcc-internal-format
 msgid "alignment of %qD will increase in -fabi-version=9"
 msgstr ""
 
-#: cp/class.c:4378
+#: cp/class.c:4382
 #, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr ""
 
-#: cp/class.c:4813
+#: cp/class.c:4817
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr ""
 
-#: cp/class.c:4834
+#: cp/class.c:4838
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr ""
 
-#: cp/class.c:5350 cp/constexpr.c:237
+#: cp/class.c:5367 cp/constexpr.c:237
 #, gcc-internal-format
 msgid "enclosing class of %<constexpr%> non-static member function %q+#D is not a literal type"
 msgstr ""
 
-#: cp/class.c:5374
+#: cp/class.c:5391
 #, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr ""
 
-#: cp/class.c:5377
+#: cp/class.c:5394
 #, gcc-internal-format
 msgid "  %qT is a closure type, which is only literal in C++17 and later"
 msgstr ""
 
-#: cp/class.c:5380
+#: cp/class.c:5397
 #, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr ""
 
-#: cp/class.c:5387
+#: cp/class.c:5404
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no %<constexpr%> constructor that is not a copy or move constructor"
 msgstr ""
 
-#: cp/class.c:5420
+#: cp/class.c:5437
 #, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr ""
 
-#: cp/class.c:5435
+#: cp/class.c:5452
 #, gcc-internal-format
 msgid "  non-static data member %qD has non-literal type"
 msgstr ""
 
-#: cp/class.c:5442
+#: cp/class.c:5459
 #, gcc-internal-format
 msgid "  non-static data member %qD has volatile type"
 msgstr ""
 
-#: cp/class.c:5561
+#: cp/class.c:5578
 #, gcc-internal-format
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr ""
 
-#: cp/class.c:5590
+#: cp/class.c:5607
 #, gcc-internal-format
 msgid "non-static reference %q#D in class without a constructor"
 msgstr ""
 
-#: cp/class.c:5596
+#: cp/class.c:5613
 #, gcc-internal-format
 msgid "non-static const member %q#D in class without a constructor"
 msgstr ""
@@ -38941,152 +38983,152 @@
 
 #. If the function is defaulted outside the class, we just
 #. give the synthesis error.
-#: cp/class.c:5624
+#: cp/class.c:5641
 #, gcc-internal-format
 msgid "%q+D declared to take const reference, but implicit declaration would take non-const"
 msgstr ""
 
-#: cp/class.c:5898
+#: cp/class.c:5915
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:5910
+#: cp/class.c:5927
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:6133
+#: cp/class.c:6150
 #, gcc-internal-format
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr ""
 
-#: cp/class.c:6291
+#: cp/class.c:6308
 #, gcc-internal-format
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr ""
 
-#: cp/class.c:6576
+#: cp/class.c:6593
 #, gcc-internal-format
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr ""
 
-#: cp/class.c:6578
+#: cp/class.c:6595
 #, gcc-internal-format
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr ""
 
-#: cp/class.c:6583
+#: cp/class.c:6600
 #, gcc-internal-format
 msgid "array member %q#D declared here"
 msgstr "член масиву %q#D оголошено тут"
 
-#: cp/class.c:6610
+#: cp/class.c:6627
 #, gcc-internal-format
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr ""
 
-#: cp/class.c:6612
+#: cp/class.c:6629
 #, gcc-internal-format
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr ""
 
-#: cp/class.c:6620 cp/class.c:6650
+#: cp/class.c:6637 cp/class.c:6667
 #, gcc-internal-format
 msgid "in the definition of %q#T"
 msgstr "у оголошенні %q#T"
 
-#: cp/class.c:6628
+#: cp/class.c:6645
 #, gcc-internal-format
 msgid "flexible array member %qD not at end of %q#T"
 msgstr ""
 
-#: cp/class.c:6630
+#: cp/class.c:6647
 #, gcc-internal-format
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr ""
 
-#: cp/class.c:6648
+#: cp/class.c:6665
 #, gcc-internal-format
 msgid "next member %q#D declared here"
 msgstr ""
 
-#: cp/class.c:6760 cp/parser.c:23239
+#: cp/class.c:6777 cp/parser.c:23236
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr ""
 
-#: cp/class.c:6897
+#: cp/class.c:6914
 #, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr ""
 
-#: cp/class.c:6925
+#: cp/class.c:6942
 #, gcc-internal-format
 msgid "type transparent %q#T does not have any fields"
 msgstr ""
 
-#: cp/class.c:6931
+#: cp/class.c:6948
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr ""
 
-#: cp/class.c:6935
+#: cp/class.c:6952
 #, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr ""
 
-#: cp/class.c:6941
+#: cp/class.c:6958
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:7071
+#: cp/class.c:7088
 #, gcc-internal-format
 msgid "definition of %qD does not match %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/class.c:7082
+#: cp/class.c:7099
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr ""
 
-#: cp/class.c:7582
+#: cp/class.c:7599
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr ""
 
-#: cp/class.c:7672
+#: cp/class.c:7689
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr ""
 
-#: cp/class.c:7817
+#: cp/class.c:7834
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr ""
 
-#: cp/class.c:7844
+#: cp/class.c:7861
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr ""
 
-#: cp/class.c:7870
+#: cp/class.c:7887
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr ""
 
-#: cp/class.c:7873
+#: cp/class.c:7890
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr ""
 
-#: cp/class.c:7948 cp/class.c:7990
+#: cp/class.c:7965 cp/class.c:8007
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr ""
 
-#: cp/class.c:7968
+#: cp/class.c:7985
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr ""
@@ -39096,12 +39138,12 @@
 #. A name N used in a class S shall refer to the same declaration
 #. in its context and when re-evaluated in the completed scope of
 #. S.
-#: cp/class.c:8235
+#: cp/class.c:8252
 #, gcc-internal-format
 msgid "declaration of %q#D"
 msgstr ""
 
-#: cp/class.c:8237
+#: cp/class.c:8254
 #, gcc-internal-format
 msgid "changes meaning of %qD from %q#D"
 msgstr ""
@@ -39492,17 +39534,17 @@
 msgid "unexpected AST of kind %s"
 msgstr ""
 
-#: cp/cp-gimplify.c:1415
+#: cp/cp-gimplify.c:1416
 #, gcc-internal-format
 msgid "throw will always call terminate()"
 msgstr ""
 
-#: cp/cp-gimplify.c:1418
+#: cp/cp-gimplify.c:1419
 #, gcc-internal-format
 msgid "in C++11 destructors default to noexcept"
 msgstr ""
 
-#: cp/cp-gimplify.c:1429
+#: cp/cp-gimplify.c:1430
 #, gcc-internal-format
 msgid "in C++11 this throw will terminate because destructors default to noexcept"
 msgstr ""
@@ -39906,7 +39948,7 @@
 msgid "redeclaration %qD differs in %<constexpr%> from previous declaration"
 msgstr "повторне оголошення %qD відрізняється у %<constexpr%> від попереднього оголошення"
 
-#: cp/decl.c:1304 cp/decl.c:13843
+#: cp/decl.c:1304 cp/decl.c:13867
 #, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr "попереднє оголошення %qD"
@@ -40230,7 +40272,7 @@
 msgid "  enters OpenMP structured block"
 msgstr ""
 
-#: cp/decl.c:3434 cp/parser.c:12366 cp/parser.c:12387
+#: cp/decl.c:3434 cp/parser.c:12363 cp/parser.c:12384
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr ""
@@ -40240,7 +40282,7 @@
 msgid "%qD is not a type"
 msgstr ""
 
-#: cp/decl.c:3838 cp/parser.c:6366
+#: cp/decl.c:3838 cp/parser.c:6369
 #, gcc-internal-format
 msgid "%qD used without template parameters"
 msgstr ""
@@ -40616,8 +40658,8 @@
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.c:6011 cp/decl.c:6234 cp/typeck2.c:1310 cp/typeck2.c:1590
-#: cp/typeck2.c:1638 cp/typeck2.c:1685
+#: cp/decl.c:6011 cp/decl.c:6234 cp/typeck2.c:1310 cp/typeck2.c:1593
+#: cp/typeck2.c:1641 cp/typeck2.c:1688
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr ""
@@ -40692,12 +40734,12 @@
 msgid "assignment (not initialization) in declaration"
 msgstr ""
 
-#: cp/decl.c:6873 cp/decl.c:12605
+#: cp/decl.c:6873 cp/decl.c:12629
 #, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr ""
 
-#: cp/decl.c:6877 cp/decl.c:12609
+#: cp/decl.c:6877 cp/decl.c:12633
 #, gcc-internal-format
 msgid "%<register%> storage class specifier used"
 msgstr ""
@@ -40722,42 +40764,42 @@
 msgid "function %q#D is initialized like a variable"
 msgstr ""
 
-#: cp/decl.c:7329
+#: cp/decl.c:7350
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr ""
 
-#: cp/decl.c:7332
+#: cp/decl.c:7353
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.c:7339
+#: cp/decl.c:7360
 #, gcc-internal-format
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "неможливо розкласти недоступний член %qD %qT"
 
-#: cp/decl.c:7365
+#: cp/decl.c:7386
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:7374
+#: cp/decl.c:7395
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:7592
+#: cp/decl.c:7613
 #, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr ""
 
-#: cp/decl.c:7608
+#: cp/decl.c:7629
 #, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr ""
 
-#: cp/decl.c:7617 cp/decl.c:7702
+#: cp/decl.c:7638 cp/decl.c:7723
 #, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
@@ -40765,7 +40807,7 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/decl.c:7621
+#: cp/decl.c:7642
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
@@ -40773,7 +40815,7 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/decl.c:7624
+#: cp/decl.c:7645
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
@@ -40781,878 +40823,878 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/decl.c:7669
+#: cp/decl.c:7690
 #, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr ""
 
-#: cp/decl.c:7695
+#: cp/decl.c:7716
 #, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "%<std::tuple_size<%T>::value%> не є інтегральним сталим виразом"
 
-#: cp/decl.c:7704
+#: cp/decl.c:7725
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.c:7725
+#: cp/decl.c:7746
 #, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr ""
 
-#: cp/decl.c:7751
+#: cp/decl.c:7772
 #, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr "не вдалося розкласти тип об'єднання %qT"
 
-#: cp/decl.c:7756
+#: cp/decl.c:7777
 #, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr ""
 
-#: cp/decl.c:7761
+#: cp/decl.c:7782
 #, gcc-internal-format
 msgid "cannot decompose lambda closure type %qT"
 msgstr ""
 
-#: cp/decl.c:7765
+#: cp/decl.c:7786
 #, gcc-internal-format
 msgid "structured binding refers to incomplete class type %qT"
 msgstr ""
 
-#: cp/decl.c:7774
+#: cp/decl.c:7795
 #, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr ""
 
-#: cp/decl.c:8213
+#: cp/decl.c:8234
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:8216
+#: cp/decl.c:8237
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:8222
+#: cp/decl.c:8243
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:8450
+#: cp/decl.c:8471
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr ""
 
-#: cp/decl.c:8454
+#: cp/decl.c:8475
 #, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr ""
 
-#: cp/decl.c:8457
+#: cp/decl.c:8478
 #, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr ""
 
-#: cp/decl.c:8473
+#: cp/decl.c:8494
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.c:8475
+#: cp/decl.c:8496
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.c:8499
+#: cp/decl.c:8520
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr ""
 
-#: cp/decl.c:8501
+#: cp/decl.c:8522
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr ""
 
-#: cp/decl.c:8506
+#: cp/decl.c:8527
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr ""
 
-#: cp/decl.c:8508
+#: cp/decl.c:8529
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr ""
 
-#: cp/decl.c:8510
+#: cp/decl.c:8531
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:8515
+#: cp/decl.c:8536
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr ""
 
-#: cp/decl.c:8517
+#: cp/decl.c:8538
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr ""
 
-#: cp/decl.c:8519
+#: cp/decl.c:8540
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr ""
 
-#: cp/decl.c:8524
+#: cp/decl.c:8545
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr ""
 
-#: cp/decl.c:8526
+#: cp/decl.c:8547
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr ""
 
-#: cp/decl.c:8528
+#: cp/decl.c:8549
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr ""
 
-#: cp/decl.c:8535
+#: cp/decl.c:8556
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr ""
 
-#: cp/decl.c:8542
+#: cp/decl.c:8563
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr ""
 
-#: cp/decl.c:8574
+#: cp/decl.c:8595
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr ""
 
-#: cp/decl.c:8614
+#: cp/decl.c:8635
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr ""
 
-#: cp/decl.c:8624
+#: cp/decl.c:8645
 #, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr ""
 
-#: cp/decl.c:8630
+#: cp/decl.c:8651
 #, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr ""
 
-#: cp/decl.c:8632
+#: cp/decl.c:8653
 #, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr ""
 
-#: cp/decl.c:8703
+#: cp/decl.c:8724
 #, gcc-internal-format
 msgid "concept %qD has no definition"
 msgstr ""
 
-#: cp/decl.c:8772
+#: cp/decl.c:8793
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr ""
 
 #. Something like `template <class T> friend void f<T>()'.
-#: cp/decl.c:8782
+#: cp/decl.c:8803
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr ""
 
-#: cp/decl.c:8800
+#: cp/decl.c:8821
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:8808
+#: cp/decl.c:8829
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:8857
+#: cp/decl.c:8878
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr ""
 
-#: cp/decl.c:8859
+#: cp/decl.c:8880
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr ""
 
-#: cp/decl.c:8861
+#: cp/decl.c:8882
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be %<constexpr%>"
 msgstr ""
 
-#: cp/decl.c:8863
+#: cp/decl.c:8884
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr ""
 
-#: cp/decl.c:8920
+#: cp/decl.c:8941
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.c:8921
+#: cp/decl.c:8942
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.c:8929
+#: cp/decl.c:8950
 #, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr ""
 
-#: cp/decl.c:8930
+#: cp/decl.c:8951
 #, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr ""
 
-#: cp/decl.c:8940
+#: cp/decl.c:8961
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared at namespace scope"
 msgstr ""
 
-#: cp/decl.c:8946
+#: cp/decl.c:8967
 #, gcc-internal-format
 msgid "deduction guide %qD must not have a function body"
 msgstr ""
 
-#: cp/decl.c:8959
+#: cp/decl.c:8980
 #, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr ""
 
-#: cp/decl.c:8969
+#: cp/decl.c:8990
 #, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr ""
 
-#: cp/decl.c:8977
+#: cp/decl.c:8998
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:8983
+#: cp/decl.c:9004
 #, gcc-internal-format
 msgid "floating point suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:8991
+#: cp/decl.c:9012
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/decl.c:8996
+#: cp/decl.c:9017
 #, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr ""
 
-#: cp/decl.c:9076
+#: cp/decl.c:9097
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr ""
 
-#: cp/decl.c:9116
+#: cp/decl.c:9137
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr ""
 
-#: cp/decl.c:9121
+#: cp/decl.c:9142
 #, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr ""
 
-#: cp/decl.c:9123
+#: cp/decl.c:9144
 #, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr "%q#D явним чином типово визначено тут"
 
-#: cp/decl.c:9140
+#: cp/decl.c:9161
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr ""
 
-#: cp/decl.c:9329
+#: cp/decl.c:9350
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr ""
 
-#: cp/decl.c:9337
+#: cp/decl.c:9358
 #, gcc-internal-format
 msgid "a non-template variable cannot be %<concept%>"
 msgstr ""
 
-#: cp/decl.c:9344
+#: cp/decl.c:9365
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.c:9464
+#: cp/decl.c:9485
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr ""
 
-#: cp/decl.c:9468
+#: cp/decl.c:9489
 #, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr ""
 
-#: cp/decl.c:9472
+#: cp/decl.c:9493
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr ""
 
-#: cp/decl.c:9486
+#: cp/decl.c:9507
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:9493
+#: cp/decl.c:9514
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr ""
 
-#: cp/decl.c:9498
+#: cp/decl.c:9519
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:9598
+#: cp/decl.c:9619
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:9600
+#: cp/decl.c:9621
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:9630 cp/decl.c:9680
+#: cp/decl.c:9651 cp/decl.c:9701
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr ""
 
-#: cp/decl.c:9646
+#: cp/decl.c:9667
 #, gcc-internal-format
 msgid "size of array %qD is negative"
 msgstr ""
 
-#: cp/decl.c:9648 cp/init.c:3651
+#: cp/decl.c:9669 cp/init.c:3667
 #, gcc-internal-format
 msgid "size of array is negative"
 msgstr ""
 
-#: cp/decl.c:9662
+#: cp/decl.c:9683
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr ""
 
-#: cp/decl.c:9664
+#: cp/decl.c:9685
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr ""
 
-#: cp/decl.c:9677
+#: cp/decl.c:9698
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr ""
 
-#: cp/decl.c:9686
+#: cp/decl.c:9707
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr ""
 
-#: cp/decl.c:9688
+#: cp/decl.c:9709
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr ""
 
-#: cp/decl.c:9694
+#: cp/decl.c:9715
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr ""
 
-#: cp/decl.c:9697
+#: cp/decl.c:9718
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr ""
 
-#: cp/decl.c:9746
+#: cp/decl.c:9767
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr ""
 
-#: cp/decl.c:9799
+#: cp/decl.c:9820
 #, gcc-internal-format
 msgid "%qD declared as array of %qT"
 msgstr ""
 
-#: cp/decl.c:9809
+#: cp/decl.c:9830
 #, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr ""
 
-#: cp/decl.c:9811
+#: cp/decl.c:9832
 #, gcc-internal-format
 msgid "creating array of void"
 msgstr ""
 
-#: cp/decl.c:9816
+#: cp/decl.c:9837
 #, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr ""
 
-#: cp/decl.c:9818
+#: cp/decl.c:9839
 #, gcc-internal-format
 msgid "creating array of functions"
 msgstr ""
 
-#: cp/decl.c:9823
+#: cp/decl.c:9844
 #, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr ""
 
-#: cp/decl.c:9825
+#: cp/decl.c:9846
 #, gcc-internal-format
 msgid "creating array of references"
 msgstr ""
 
-#: cp/decl.c:9830
+#: cp/decl.c:9851
 #, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr ""
 
-#: cp/decl.c:9832
+#: cp/decl.c:9853
 #, gcc-internal-format
 msgid "creating array of function members"
 msgstr ""
 
-#: cp/decl.c:9846
+#: cp/decl.c:9867
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.c:9850
+#: cp/decl.c:9871
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.c:9909
+#: cp/decl.c:9930
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr ""
 
-#: cp/decl.c:9912
+#: cp/decl.c:9933
 #, gcc-internal-format
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr ""
 
-#: cp/decl.c:9922
+#: cp/decl.c:9943
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr ""
 
-#: cp/decl.c:9925
+#: cp/decl.c:9946
 #, gcc-internal-format
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr ""
 
-#: cp/decl.c:9937
+#: cp/decl.c:9958
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr ""
 
-#: cp/decl.c:9940
+#: cp/decl.c:9961
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr ""
 
-#: cp/decl.c:9948
+#: cp/decl.c:9969
 #, gcc-internal-format
 msgid "return type specified for deduction guide"
 msgstr ""
 
-#: cp/decl.c:9951
+#: cp/decl.c:9972
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.c:9955
+#: cp/decl.c:9976
 #, gcc-internal-format
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.c:9964
+#: cp/decl.c:9985
 #, gcc-internal-format
 msgid "decl-specifier in declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.c:9985
+#: cp/decl.c:10006
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr ""
 
-#: cp/decl.c:9992
+#: cp/decl.c:10013
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr ""
 
-#: cp/decl.c:10007
+#: cp/decl.c:10028
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr ""
 
-#: cp/decl.c:10013
+#: cp/decl.c:10034
 #, gcc-internal-format
 msgid "inline variables are only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/decl.c:10268
+#: cp/decl.c:10292
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr ""
 
-#: cp/decl.c:10271 cp/decl.c:10291
+#: cp/decl.c:10295 cp/decl.c:10315
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr ""
 
-#: cp/decl.c:10274
+#: cp/decl.c:10298
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr ""
 
-#: cp/decl.c:10283
+#: cp/decl.c:10307
 #, gcc-internal-format
 msgid "%q#T is not a class or a namespace"
 msgstr ""
 
-#: cp/decl.c:10305 cp/decl.c:10398 cp/decl.c:10407 cp/decl.c:11970
+#: cp/decl.c:10329 cp/decl.c:10422 cp/decl.c:10431 cp/decl.c:11994
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr ""
 
-#: cp/decl.c:10311
+#: cp/decl.c:10335
 #, gcc-internal-format
 msgid "declaration of %qD as non-member"
 msgstr ""
 
-#: cp/decl.c:10339
+#: cp/decl.c:10363
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr ""
 
-#: cp/decl.c:10390
+#: cp/decl.c:10414
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr ""
 
-#: cp/decl.c:10415
+#: cp/decl.c:10439
 #, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr ""
 
-#: cp/decl.c:10420
+#: cp/decl.c:10444
 #, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr ""
 
-#: cp/decl.c:10454
+#: cp/decl.c:10478
 #, gcc-internal-format
 msgid "%<concept%> cannot appear in a typedef declaration"
 msgstr ""
 
-#: cp/decl.c:10460
+#: cp/decl.c:10484
 #, gcc-internal-format
 msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgstr ""
 
-#: cp/decl.c:10468
+#: cp/decl.c:10492
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr ""
 
-#: cp/decl.c:10474
+#: cp/decl.c:10498
 #, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr ""
 
-#: cp/decl.c:10515
+#: cp/decl.c:10539
 #, gcc-internal-format
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr ""
 
-#: cp/decl.c:10564 cp/decl.c:10567 cp/decl.c:10570
+#: cp/decl.c:10588 cp/decl.c:10591 cp/decl.c:10594
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr ""
 
-#: cp/decl.c:10586
+#: cp/decl.c:10610
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr ""
 
-#: cp/decl.c:10592
+#: cp/decl.c:10616
 #, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr ""
 
-#: cp/decl.c:10614 cp/decl.c:10634
+#: cp/decl.c:10638 cp/decl.c:10658
 #, gcc-internal-format
 msgid "%<signed%> or %<unsigned%> invalid for %qs"
 msgstr ""
 
-#: cp/decl.c:10616
+#: cp/decl.c:10640
 #, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgstr ""
 
-#: cp/decl.c:10618
+#: cp/decl.c:10642
 #, gcc-internal-format
 msgid "%<long long%> invalid for %qs"
 msgstr ""
 
-#: cp/decl.c:10620
+#: cp/decl.c:10644
 #, gcc-internal-format
 msgid "%<long%> invalid for %qs"
 msgstr ""
 
-#: cp/decl.c:10622
+#: cp/decl.c:10646
 #, gcc-internal-format
 msgid "%<short%> invalid for %qs"
 msgstr ""
 
-#: cp/decl.c:10624
+#: cp/decl.c:10648
 #, gcc-internal-format
 msgid "%<long%> or %<short%> invalid for %qs"
 msgstr ""
 
-#: cp/decl.c:10626
+#: cp/decl.c:10650
 #, gcc-internal-format
 msgid "%<long%>, %<int%>, %<short%>, or %<char%> invalid for %qs"
 msgstr ""
 
-#: cp/decl.c:10628
+#: cp/decl.c:10652
 #, gcc-internal-format
 msgid "%<long%> or %<short%> specified with char for %qs"
 msgstr ""
 
-#: cp/decl.c:10630
+#: cp/decl.c:10654
 #, gcc-internal-format
 msgid "%<long%> and %<short%> specified together for %qs"
 msgstr ""
 
-#: cp/decl.c:10636
+#: cp/decl.c:10660
 #, gcc-internal-format
 msgid "%<short%> or %<long%> invalid for %qs"
 msgstr ""
 
-#: cp/decl.c:10644
+#: cp/decl.c:10668
 #, gcc-internal-format
 msgid "long, short, signed or unsigned used invalidly for %qs"
 msgstr ""
 
-#: cp/decl.c:10712
+#: cp/decl.c:10736
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr ""
 
-#: cp/decl.c:10751
+#: cp/decl.c:10775
 #, gcc-internal-format
 msgid "template placeholder type %qT must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.c:10769
+#: cp/decl.c:10793
 #, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr ""
 
-#: cp/decl.c:10775
+#: cp/decl.c:10799
 #, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<constexpr%>"
 msgstr ""
 
-#: cp/decl.c:10785
+#: cp/decl.c:10809
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:10790
+#: cp/decl.c:10814
 #, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr ""
 
-#: cp/decl.c:10796
+#: cp/decl.c:10820
 #, gcc-internal-format
 msgid "storage class specifiers invalid in parameter declarations"
 msgstr ""
 
-#: cp/decl.c:10800
+#: cp/decl.c:10824
 #, gcc-internal-format
 msgid "a parameter cannot be declared %<concept%>"
 msgstr ""
 
-#: cp/decl.c:10805
+#: cp/decl.c:10829
 #, gcc-internal-format
 msgid "a parameter cannot be declared %<constexpr%>"
 msgstr ""
 
-#: cp/decl.c:10815
+#: cp/decl.c:10839
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr ""
 
-#: cp/decl.c:10825
+#: cp/decl.c:10849
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<inline%>"
 msgstr ""
 
-#: cp/decl.c:10828
+#: cp/decl.c:10852
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<typedef%>"
 msgstr ""
 
-#: cp/decl.c:10830
+#: cp/decl.c:10854
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<constexpr%>"
 msgstr ""
 
-#: cp/decl.c:10834
+#: cp/decl.c:10858
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr ""
 
-#: cp/decl.c:10839
+#: cp/decl.c:10863
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<concept%>"
 msgstr ""
 
-#: cp/decl.c:10845
+#: cp/decl.c:10869
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<register%>"
 msgstr ""
 
-#: cp/decl.c:10849
+#: cp/decl.c:10873
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<static%>"
 msgstr ""
 
-#: cp/decl.c:10853
+#: cp/decl.c:10877
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<extern%>"
 msgstr ""
 
-#: cp/decl.c:10857
+#: cp/decl.c:10881
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:10861
+#: cp/decl.c:10885
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10872
+#: cp/decl.c:10896
 #, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr ""
 
-#: cp/decl.c:10875
+#: cp/decl.c:10899
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10906
+#: cp/decl.c:10930
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr ""
 
-#: cp/decl.c:10929
+#: cp/decl.c:10953
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr ""
 
-#: cp/decl.c:10933
+#: cp/decl.c:10957
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr ""
 
-#: cp/decl.c:10946
+#: cp/decl.c:10970
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr ""
 
-#: cp/decl.c:10950
+#: cp/decl.c:10974
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10957
+#: cp/decl.c:10981
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr ""
 
-#: cp/decl.c:10969
+#: cp/decl.c:10993
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr ""
 
-#: cp/decl.c:11050
+#: cp/decl.c:11074
 #, gcc-internal-format
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr ""
 
-#: cp/decl.c:11098
+#: cp/decl.c:11122
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.c:11118
+#: cp/decl.c:11142
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.c:11121
+#: cp/decl.c:11145
 #, gcc-internal-format
 msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/decl.c:11127
+#: cp/decl.c:11151
 #, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr ""
 
-#: cp/decl.c:11134
+#: cp/decl.c:11158
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:11147
+#: cp/decl.c:11171
 #, gcc-internal-format
 msgid "deduced class type %qD in function return type"
 msgstr ""
 
-#: cp/decl.c:11156
+#: cp/decl.c:11180
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr ""
 
-#: cp/decl.c:11169
+#: cp/decl.c:11193
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
@@ -41659,459 +41701,459 @@
 
 #. Not using maybe_warn_cpp0x because this should
 #. always be an error.
-#: cp/decl.c:11180
+#: cp/decl.c:11204
 #, gcc-internal-format
 msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/decl.c:11183
+#: cp/decl.c:11207
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.c:11212
+#: cp/decl.c:11236
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr ""
 
-#: cp/decl.c:11218
+#: cp/decl.c:11242
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr ""
 
-#: cp/decl.c:11247
+#: cp/decl.c:11271
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.c:11248
+#: cp/decl.c:11272
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.c:11252
+#: cp/decl.c:11276
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.c:11253
+#: cp/decl.c:11277
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.c:11261
+#: cp/decl.c:11285
 #, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr ""
 
-#: cp/decl.c:11262
+#: cp/decl.c:11286
 #, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr ""
 
-#: cp/decl.c:11280
+#: cp/decl.c:11304
 #, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
 msgstr ""
 
 #. Cannot be both friend and virtual.
-#: cp/decl.c:11295
+#: cp/decl.c:11319
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr ""
 
-#: cp/decl.c:11299
+#: cp/decl.c:11323
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr ""
 
-#: cp/decl.c:11301
+#: cp/decl.c:11325
 #, gcc-internal-format
 msgid "can%'t define friend function %qs in a local class definition"
 msgstr ""
 
-#: cp/decl.c:11313
+#: cp/decl.c:11337
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr ""
 
-#: cp/decl.c:11339
+#: cp/decl.c:11363
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr ""
 
-#: cp/decl.c:11379
+#: cp/decl.c:11403
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr ""
 
-#: cp/decl.c:11392 cp/decl.c:11399
+#: cp/decl.c:11416 cp/decl.c:11423
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr ""
 
-#: cp/decl.c:11401
+#: cp/decl.c:11425
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr ""
 
-#: cp/decl.c:11430
+#: cp/decl.c:11454
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr ""
 
-#: cp/decl.c:11431
+#: cp/decl.c:11455
 #, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr ""
 
-#: cp/decl.c:11504
+#: cp/decl.c:11528
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.c:11574
+#: cp/decl.c:11598
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr ""
 
-#: cp/decl.c:11599
+#: cp/decl.c:11623
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr ""
 
-#: cp/decl.c:11605
+#: cp/decl.c:11629
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr ""
 
-#: cp/decl.c:11635
+#: cp/decl.c:11659
 #, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.c:11637
+#: cp/decl.c:11661
 #, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.c:11645
+#: cp/decl.c:11669
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.c:11685
+#: cp/decl.c:11709
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr ""
 
-#: cp/decl.c:11693
+#: cp/decl.c:11717
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.c:11695
+#: cp/decl.c:11719
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.c:11706
+#: cp/decl.c:11730
 #, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr ""
 
-#: cp/decl.c:11709
+#: cp/decl.c:11733
 #, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr ""
 
-#: cp/decl.c:11712
+#: cp/decl.c:11736
 #, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr ""
 
-#: cp/decl.c:11721
+#: cp/decl.c:11745
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:11726
+#: cp/decl.c:11750
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:11732
+#: cp/decl.c:11756
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:11737
+#: cp/decl.c:11761
 #, gcc-internal-format
 msgid "static %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:11742
+#: cp/decl.c:11766
 #, gcc-internal-format
 msgid "const %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:11747
+#: cp/decl.c:11771
 #, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:11778
+#: cp/decl.c:11802
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr ""
 
-#: cp/decl.c:11783
+#: cp/decl.c:11807
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.c:11787
+#: cp/decl.c:11811
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr ""
 
-#: cp/decl.c:11813
+#: cp/decl.c:11837
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr ""
 
-#: cp/decl.c:11900
+#: cp/decl.c:11924
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr ""
 
-#: cp/decl.c:11908
+#: cp/decl.c:11932
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr ""
 
-#: cp/decl.c:11910
+#: cp/decl.c:11934
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr ""
 
-#: cp/decl.c:11914
+#: cp/decl.c:11938
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr ""
 
-#: cp/decl.c:11927
+#: cp/decl.c:11951
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr ""
 
-#: cp/decl.c:11947
+#: cp/decl.c:11971
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr ""
 
-#: cp/decl.c:11951
+#: cp/decl.c:11975
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.c:11961
+#: cp/decl.c:11985
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr ""
 
-#: cp/decl.c:11976
+#: cp/decl.c:12000
 #, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr ""
 
-#: cp/decl.c:11995
+#: cp/decl.c:12019
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:12001
+#: cp/decl.c:12025
 #, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr ""
 
-#: cp/decl.c:12003
+#: cp/decl.c:12027
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr ""
 
-#: cp/decl.c:12052 cp/parser.c:3270
+#: cp/decl.c:12076 cp/parser.c:3270
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr ""
 
-#: cp/decl.c:12056
+#: cp/decl.c:12080
 #, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr ""
 
-#: cp/decl.c:12080
+#: cp/decl.c:12104
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr ""
 
-#: cp/decl.c:12083
+#: cp/decl.c:12107
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array members"
 msgstr ""
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:12099
+#: cp/decl.c:12123
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr ""
 
-#: cp/decl.c:12121
+#: cp/decl.c:12145
 #, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr ""
 
-#: cp/decl.c:12130
+#: cp/decl.c:12154
 #, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr ""
 
-#: cp/decl.c:12139
+#: cp/decl.c:12163
 #, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr ""
 
-#: cp/decl.c:12153
+#: cp/decl.c:12177
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr ""
 
-#: cp/decl.c:12160
+#: cp/decl.c:12184
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr ""
 
-#: cp/decl.c:12166
+#: cp/decl.c:12190
 #, gcc-internal-format
 msgid "a destructor cannot be %<concept%>"
 msgstr ""
 
-#: cp/decl.c:12171
+#: cp/decl.c:12195
 #, gcc-internal-format
 msgid "a destructor cannot be %<constexpr%>"
 msgstr ""
 
-#: cp/decl.c:12177
+#: cp/decl.c:12201
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr ""
 
-#: cp/decl.c:12185
+#: cp/decl.c:12209
 #, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr ""
 
-#: cp/decl.c:12190
+#: cp/decl.c:12214
 #, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr ""
 
-#: cp/decl.c:12199
+#: cp/decl.c:12223
 #, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr ""
 
-#: cp/decl.c:12202
+#: cp/decl.c:12226
 #, gcc-internal-format
 msgid "variable template declared here"
 msgstr ""
 
-#: cp/decl.c:12257
+#: cp/decl.c:12281
 #, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr ""
 
-#: cp/decl.c:12262
+#: cp/decl.c:12286
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr ""
 
-#: cp/decl.c:12272
+#: cp/decl.c:12296
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr ""
 
-#: cp/decl.c:12318
+#: cp/decl.c:12342
 #, gcc-internal-format
 msgid "static data member %qE declared %<concept%>"
 msgstr ""
 
-#: cp/decl.c:12322
+#: cp/decl.c:12346
 #, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr ""
 
-#: cp/decl.c:12350
+#: cp/decl.c:12374
 #, gcc-internal-format
 msgid "non-static data member %qE declared %<concept%>"
 msgstr ""
 
-#: cp/decl.c:12354
+#: cp/decl.c:12378
 #, gcc-internal-format
 msgid "non-static data member %qE declared %<constexpr%>"
 msgstr ""
 
-#: cp/decl.c:12409
+#: cp/decl.c:12433
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:12411
+#: cp/decl.c:12435
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:12415
+#: cp/decl.c:12439
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:12418
+#: cp/decl.c:12442
 #, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:12423
+#: cp/decl.c:12447
 #, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr ""
 
-#: cp/decl.c:12434
+#: cp/decl.c:12458
 #, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.c:12438
+#: cp/decl.c:12462
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.c:12446
+#: cp/decl.c:12470
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr ""
 
-#: cp/decl.c:12453
+#: cp/decl.c:12477
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr ""
 
-#: cp/decl.c:12454
+#: cp/decl.c:12478
 #, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr ""
 
-#: cp/decl.c:12489
+#: cp/decl.c:12513
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr ""
@@ -42118,77 +42160,77 @@
 
 #. 7.1.1: There can be no static function declarations within a
 #. block.
-#: cp/decl.c:12497
+#: cp/decl.c:12521
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr ""
 
-#: cp/decl.c:12533
+#: cp/decl.c:12557
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr ""
 
-#: cp/decl.c:12540
+#: cp/decl.c:12564
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr ""
 
-#: cp/decl.c:12546
+#: cp/decl.c:12570
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr ""
 
-#: cp/decl.c:12553
+#: cp/decl.c:12577
 #, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr ""
 
-#: cp/decl.c:12574
+#: cp/decl.c:12598
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr ""
 
-#: cp/decl.c:12585
+#: cp/decl.c:12609
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr ""
 
-#: cp/decl.c:12589
+#: cp/decl.c:12613
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr ""
 
-#: cp/decl.c:12754
+#: cp/decl.c:12778
 #, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr ""
 
-#: cp/decl.c:12757
+#: cp/decl.c:12781
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr ""
 
-#: cp/decl.c:12841
+#: cp/decl.c:12865
 #, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:12845
+#: cp/decl.c:12869
 #, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:12868
+#: cp/decl.c:12892
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr ""
 
-#: cp/decl.c:12895
+#: cp/decl.c:12919
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.c:12897
+#: cp/decl.c:12921
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr ""
@@ -42208,169 +42250,169 @@
 #. or implicitly defined), there's no need to worry about their
 #. existence.  Theoretically, they should never even be
 #. instantiated, but that's hard to forestall.
-#: cp/decl.c:13150
+#: cp/decl.c:13174
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr ""
 
-#: cp/decl.c:13228
+#: cp/decl.c:13252
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr ""
 
-#: cp/decl.c:13234
+#: cp/decl.c:13258
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr ""
 
-#: cp/decl.c:13261
+#: cp/decl.c:13285
 #, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr ""
 
-#: cp/decl.c:13267
+#: cp/decl.c:13291
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr ""
 
-#: cp/decl.c:13277
+#: cp/decl.c:13301
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr ""
 
 #. 13.4.0.3
-#: cp/decl.c:13303
+#: cp/decl.c:13327
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading operator ?:"
 msgstr ""
 
 #. Variadic.
-#: cp/decl.c:13314
+#: cp/decl.c:13338
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr ""
 
-#: cp/decl.c:13338
+#: cp/decl.c:13362
 #, gcc-internal-format
 msgid "%qD must have either zero or one argument"
 msgstr ""
 
-#: cp/decl.c:13339
+#: cp/decl.c:13363
 #, gcc-internal-format
 msgid "%qD must have either one or two arguments"
 msgstr ""
 
-#: cp/decl.c:13350
+#: cp/decl.c:13374
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr ""
 
-#: cp/decl.c:13351
+#: cp/decl.c:13375
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr ""
 
-#: cp/decl.c:13361
+#: cp/decl.c:13385
 #, gcc-internal-format
 msgid "%qD must have no arguments"
 msgstr "%qD не приймає аргументів"
 
-#: cp/decl.c:13362 cp/decl.c:13371
+#: cp/decl.c:13386 cp/decl.c:13395
 #, gcc-internal-format
 msgid "%qD must have exactly one argument"
 msgstr ""
 
-#: cp/decl.c:13372
+#: cp/decl.c:13396
 #, gcc-internal-format
 msgid "%qD must have exactly two arguments"
 msgstr ""
 
-#: cp/decl.c:13389 cp/decl.c:13392
+#: cp/decl.c:13413 cp/decl.c:13416
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr ""
 
-#: cp/decl.c:13419
+#: cp/decl.c:13443
 #, gcc-internal-format
 msgid "conversion to a reference to void will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13421
+#: cp/decl.c:13445
 #, gcc-internal-format
 msgid "conversion to void will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13428
+#: cp/decl.c:13452
 #, gcc-internal-format
 msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13430
+#: cp/decl.c:13454
 #, gcc-internal-format
 msgid "conversion to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13438
+#: cp/decl.c:13462
 #, gcc-internal-format
 msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13440
+#: cp/decl.c:13464
 #, gcc-internal-format
 msgid "conversion to a base class will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13455
+#: cp/decl.c:13479
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr ""
 
-#: cp/decl.c:13474
+#: cp/decl.c:13498
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.c:13480
+#: cp/decl.c:13504
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.c:13492
+#: cp/decl.c:13516
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr ""
 
-#: cp/decl.c:13547
+#: cp/decl.c:13571
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr ""
 
-#: cp/decl.c:13570
+#: cp/decl.c:13594
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr ""
 
-#: cp/decl.c:13573
+#: cp/decl.c:13597
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr ""
 
-#: cp/decl.c:13575
+#: cp/decl.c:13599
 #, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr ""
 
-#: cp/decl.c:13583
+#: cp/decl.c:13607
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr ""
 
-#: cp/decl.c:13584 cp/decl.c:13591
+#: cp/decl.c:13608 cp/decl.c:13615
 #, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr "%qT має попереднє оголошення тут"
 
-#: cp/decl.c:13590
+#: cp/decl.c:13614
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr ""
@@ -42382,94 +42424,94 @@
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:13605
+#: cp/decl.c:13629
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr ""
 
-#: cp/decl.c:13659 cp/name-lookup.c:4652
+#: cp/decl.c:13683 cp/name-lookup.c:4652
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr ""
 
-#: cp/decl.c:13689 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6425
-#: cp/pt.c:9209
+#: cp/decl.c:13713 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6428
+#: cp/pt.c:9223
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr ""
 
-#: cp/decl.c:13694
+#: cp/decl.c:13718
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:13703 cp/name-lookup.c:4079 cp/name-lookup.c:4086
-#: cp/name-lookup.c:4939 cp/parser.c:6376 cp/parser.c:26300
+#: cp/decl.c:13727 cp/name-lookup.c:4079 cp/name-lookup.c:4086
+#: cp/name-lookup.c:4939 cp/parser.c:6379 cp/parser.c:26297
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr ""
 
-#: cp/decl.c:13806
+#: cp/decl.c:13830
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr ""
 
-#: cp/decl.c:13842
+#: cp/decl.c:13866
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr ""
 
-#: cp/decl.c:13982
+#: cp/decl.c:14006
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr ""
 
-#: cp/decl.c:13989
+#: cp/decl.c:14013
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr ""
 
-#: cp/decl.c:14000
+#: cp/decl.c:14024
 #, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr ""
 
-#: cp/decl.c:14025
+#: cp/decl.c:14049
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr ""
 
-#: cp/decl.c:14055
+#: cp/decl.c:14079
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr ""
 
-#: cp/decl.c:14057
+#: cp/decl.c:14081
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr ""
 
-#: cp/decl.c:14202
+#: cp/decl.c:14226
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14205 cp/decl.c:14213 cp/decl.c:14225 cp/parser.c:18284
+#: cp/decl.c:14229 cp/decl.c:14237 cp/decl.c:14249 cp/parser.c:18281
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr ""
 
-#: cp/decl.c:14210
+#: cp/decl.c:14234
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14222
+#: cp/decl.c:14246
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14300
+#: cp/decl.c:14324
 #, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr ""
@@ -42478,77 +42520,77 @@
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:14447
+#: cp/decl.c:14471
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr ""
 
-#: cp/decl.c:14619
+#: cp/decl.c:14643
 #, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr ""
 
-#: cp/decl.c:14629
+#: cp/decl.c:14653
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr ""
 
-#: cp/decl.c:14678
+#: cp/decl.c:14702
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr ""
 
-#: cp/decl.c:14679
+#: cp/decl.c:14703
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr ""
 
-#: cp/decl.c:14690
+#: cp/decl.c:14714
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr ""
 
-#: cp/decl.c:14710
+#: cp/decl.c:14734
 #, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr ""
 
-#: cp/decl.c:14821
+#: cp/decl.c:14845
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr ""
 
-#: cp/decl.c:14999 cp/typeck.c:9286
+#: cp/decl.c:15023 cp/typeck.c:9286
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr ""
 
-#: cp/decl.c:15344
+#: cp/decl.c:15368
 #, gcc-internal-format
 msgid "invalid function declaration"
 msgstr ""
 
-#: cp/decl.c:15786
+#: cp/decl.c:15810
 #, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr ""
 
-#: cp/decl.c:15788 cp/typeck.c:9166
+#: cp/decl.c:15812 cp/typeck.c:9166
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr ""
 
-#: cp/decl.c:15996
+#: cp/decl.c:16020
 #, gcc-internal-format
 msgid "invalid member function declaration"
 msgstr ""
 
-#: cp/decl.c:16010
+#: cp/decl.c:16034
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr ""
 
-#: cp/decl.c:16386
+#: cp/decl.c:16410
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -42588,7 +42630,7 @@
 msgid "deleting %qT is undefined"
 msgstr ""
 
-#: cp/decl2.c:585 cp/pt.c:5552
+#: cp/decl2.c:585 cp/pt.c:5566
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr ""
@@ -42601,7 +42643,7 @@
 #. [temp.mem]
 #.
 #. A destructor shall not be a member template.
-#: cp/decl2.c:640 cp/pt.c:5511
+#: cp/decl2.c:640 cp/pt.c:5525
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr ""
@@ -42775,47 +42817,47 @@
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr ""
 
-#: cp/decl2.c:2660
+#: cp/decl2.c:2650
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2664
+#: cp/decl2.c:2654
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2669
+#: cp/decl2.c:2659
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2677
+#: cp/decl2.c:2667
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr ""
 
-#: cp/decl2.c:2695
+#: cp/decl2.c:2685
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2699
+#: cp/decl2.c:2689
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2704
+#: cp/decl2.c:2694
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2711
+#: cp/decl2.c:2701
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr ""
 
-#: cp/decl2.c:4309
+#: cp/decl2.c:4299
 #, gcc-internal-format
 msgid "%q#D, declared using unnamed type, is used but never defined"
 msgstr ""
@@ -42824,62 +42866,62 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4318
+#: cp/decl2.c:4308
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4322
+#: cp/decl2.c:4312
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4326
+#: cp/decl2.c:4316
 #, gcc-internal-format
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr ""
 
-#: cp/decl2.c:4334
+#: cp/decl2.c:4324
 #, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr ""
 
-#: cp/decl2.c:4338
+#: cp/decl2.c:4328
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4341
+#: cp/decl2.c:4331
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4529
+#: cp/decl2.c:4519
 #, gcc-internal-format
 msgid "mangling of %q#D as %qE conflicts with a previous mangle"
 msgstr ""
 
-#: cp/decl2.c:4532
+#: cp/decl2.c:4522
 #, gcc-internal-format
 msgid "previous mangling %q#D"
 msgstr ""
 
-#: cp/decl2.c:4534
+#: cp/decl2.c:4524
 #, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr ""
 
-#: cp/decl2.c:4606 cp/decl2.c:4609
+#: cp/decl2.c:4596 cp/decl2.c:4599
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.c:4956
+#: cp/decl2.c:4946
 #, gcc-internal-format
 msgid "inline function %qD used but never defined"
 msgstr ""
 
-#: cp/decl2.c:5143
+#: cp/decl2.c:5133
 #, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr ""
@@ -42886,17 +42928,17 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5251
+#: cp/decl2.c:5241
 #, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.c:5254
+#: cp/decl2.c:5244
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr ""
 
-#: cp/decl2.c:5307
+#: cp/decl2.c:5297
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr ""
@@ -43182,333 +43224,333 @@
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr ""
 
-#: cp/init.c:613
+#: cp/init.c:629
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr ""
 
-#: cp/init.c:615
+#: cp/init.c:631
 #, gcc-internal-format
 msgid "defined here"
 msgstr "визначено тут"
 
-#: cp/init.c:673
+#: cp/init.c:689
 #, gcc-internal-format
 msgid "initializer for flexible array member %q#D"
 msgstr ""
 
-#: cp/init.c:699
+#: cp/init.c:715
 #, gcc-internal-format
 msgid "%qD should be initialized in the member initialization list"
 msgstr ""
 
-#: cp/init.c:720
+#: cp/init.c:736
 #, gcc-internal-format
 msgid "%qD is initialized with itself"
 msgstr ""
 
-#: cp/init.c:831
+#: cp/init.c:847
 #, gcc-internal-format
 msgid "invalid initializer for array member %q#D"
 msgstr ""
 
-#: cp/init.c:845 cp/init.c:869 cp/init.c:2410 cp/method.c:1368
+#: cp/init.c:861 cp/init.c:885 cp/init.c:2427 cp/method.c:1368
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr ""
 
-#: cp/init.c:847 cp/init.c:864 cp/init.c:871 cp/init.c:2395 cp/init.c:2423
+#: cp/init.c:863 cp/init.c:880 cp/init.c:887 cp/init.c:2412 cp/init.c:2440
 #: cp/method.c:1371 cp/method.c:1382
 #, gcc-internal-format
 msgid "%q#D should be initialized"
 msgstr ""
 
-#: cp/init.c:862 cp/init.c:2382 cp/method.c:1379
+#: cp/init.c:878 cp/init.c:2399 cp/method.c:1379
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr ""
 
-#: cp/init.c:1041
+#: cp/init.c:1057
 #, gcc-internal-format
 msgid "%qD will be initialized after"
 msgstr ""
 
-#: cp/init.c:1044
+#: cp/init.c:1060
 #, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr ""
 
-#: cp/init.c:1048
+#: cp/init.c:1064
 #, gcc-internal-format
 msgid "  %q#D"
 msgstr ""
 
-#: cp/init.c:1050
+#: cp/init.c:1066
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr ""
 
-#: cp/init.c:1052
+#: cp/init.c:1068
 #, gcc-internal-format
 msgid "  when initialized here"
 msgstr ""
 
-#: cp/init.c:1069
+#: cp/init.c:1085
 #, gcc-internal-format
 msgid "multiple initializations given for %qD"
 msgstr ""
 
-#: cp/init.c:1073
+#: cp/init.c:1089
 #, gcc-internal-format
 msgid "multiple initializations given for base %qT"
 msgstr ""
 
-#: cp/init.c:1158
+#: cp/init.c:1174
 #, gcc-internal-format
 msgid "initializations for multiple members of %qT"
 msgstr ""
 
-#: cp/init.c:1255
+#: cp/init.c:1271
 #, gcc-internal-format
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr ""
 
-#: cp/init.c:1482 cp/init.c:1501
+#: cp/init.c:1498 cp/init.c:1517
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr ""
 
-#: cp/init.c:1488
+#: cp/init.c:1504
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr ""
 
-#: cp/init.c:1495
+#: cp/init.c:1511
 #, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr ""
 
-#: cp/init.c:1534
+#: cp/init.c:1550
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr ""
 
-#: cp/init.c:1542
+#: cp/init.c:1558
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr ""
 
-#: cp/init.c:1589
+#: cp/init.c:1605
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr ""
 
-#: cp/init.c:1597
+#: cp/init.c:1613
 #, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr ""
 
-#: cp/init.c:1600
+#: cp/init.c:1616
 #, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr ""
 
-#: cp/init.c:1710 cp/init.c:4386 cp/typeck2.c:1175
+#: cp/init.c:1727 cp/init.c:4402 cp/typeck2.c:1175
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
 
-#: cp/init.c:2019 cp/semantics.c:3268
+#: cp/init.c:2036 cp/semantics.c:3271
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr ""
 
-#: cp/init.c:2075
+#: cp/init.c:2092
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr ""
 
-#: cp/init.c:2089
+#: cp/init.c:2106
 #, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr ""
 
-#: cp/init.c:2175 cp/typeck.c:1893
+#: cp/init.c:2192 cp/typeck.c:1893
 #, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr ""
 
-#: cp/init.c:2182 cp/semantics.c:1835
+#: cp/init.c:2199 cp/semantics.c:1835
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr ""
 
-#: cp/init.c:2379
+#: cp/init.c:2396
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2387
+#: cp/init.c:2404
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2391
+#: cp/init.c:2408
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr ""
 
-#: cp/init.c:2407
+#: cp/init.c:2424
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2415
+#: cp/init.c:2432
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2419
+#: cp/init.c:2436
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr ""
 
-#: cp/init.c:2710
+#: cp/init.c:2727
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2721
+#: cp/init.c:2738
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2732
+#: cp/init.c:2749
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2880
+#: cp/init.c:2896
 #, gcc-internal-format
 msgid "integer overflow in array size"
 msgstr ""
 
-#: cp/init.c:2890
+#: cp/init.c:2906
 #, gcc-internal-format
 msgid "array size in new-expression must be constant"
 msgstr ""
 
-#: cp/init.c:2904
+#: cp/init.c:2920
 #, gcc-internal-format
 msgid "variably modified type not allowed in new-expression"
 msgstr ""
 
-#: cp/init.c:2920
+#: cp/init.c:2936
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by typedef"
 msgstr ""
 
-#: cp/init.c:2922
+#: cp/init.c:2938
 #, gcc-internal-format
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr ""
 
-#: cp/init.c:2932
+#: cp/init.c:2948
 #, gcc-internal-format
 msgid "invalid type %<void%> for new"
 msgstr ""
 
-#: cp/init.c:2975
+#: cp/init.c:2991
 #, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr ""
 
-#: cp/init.c:3101
+#: cp/init.c:3117
 #, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr ""
 
-#: cp/init.c:3108 cp/search.c:1023
+#: cp/init.c:3124 cp/search.c:1026
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr ""
 
-#: cp/init.c:3181
+#: cp/init.c:3197
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr ""
 
-#: cp/init.c:3184
+#: cp/init.c:3200
 #, gcc-internal-format
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr ""
 
-#: cp/init.c:3187
+#: cp/init.c:3203
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr ""
 
-#: cp/init.c:3370
+#: cp/init.c:3386
 #, gcc-internal-format
 msgid "parenthesized initializer in array new"
 msgstr ""
 
-#: cp/init.c:3633
+#: cp/init.c:3649
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr ""
 
-#: cp/init.c:3665
+#: cp/init.c:3681
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr ""
 
-#: cp/init.c:3674
+#: cp/init.c:3690
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr ""
 
-#: cp/init.c:3743
+#: cp/init.c:3759
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete [] operator:"
 msgstr ""
 
-#: cp/init.c:3747
+#: cp/init.c:3763
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete [] will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4295
+#: cp/init.c:4311
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr ""
 
-#: cp/init.c:4599
+#: cp/init.c:4615
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr ""
 
-#: cp/init.c:4623
+#: cp/init.c:4639
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete operator:"
 msgstr ""
 
-#: cp/init.c:4628
+#: cp/init.c:4644
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4642
+#: cp/init.c:4658
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4647
+#: cp/init.c:4663
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4954
+#: cp/init.c:4970
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr ""
@@ -43980,7 +44022,7 @@
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr ""
 
-#: cp/name-lookup.c:5111 cp/name-lookup.c:7065
+#: cp/name-lookup.c:5111 cp/name-lookup.c:7073
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr ""
@@ -44028,53 +44070,53 @@
 msgid "it was later defined here"
 msgstr ""
 
-#: cp/name-lookup.c:6687
+#: cp/name-lookup.c:6695
 #, gcc-internal-format
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn't a template"
 msgstr ""
 
-#: cp/name-lookup.c:7059
+#: cp/name-lookup.c:7067
 #, gcc-internal-format
 msgid "strong using directive no longer supported"
 msgstr ""
 
-#: cp/name-lookup.c:7062
+#: cp/name-lookup.c:7070
 #, gcc-internal-format
 msgid "you may use an inline namespace instead"
 msgstr ""
 
-#: cp/name-lookup.c:7079
+#: cp/name-lookup.c:7087
 #, gcc-internal-format
 msgid "attributes ignored on local using directive"
 msgstr ""
 
-#: cp/name-lookup.c:7163
+#: cp/name-lookup.c:7171
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr ""
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:7183
+#: cp/name-lookup.c:7191
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot nest more than %d namespaces"
 msgstr ""
 
-#: cp/name-lookup.c:7218
+#: cp/name-lookup.c:7226
 #, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr ""
 
-#: cp/name-lookup.c:7219
+#: cp/name-lookup.c:7227
 #, gcc-internal-format
 msgid "%qD defined here"
 msgstr "%qD визначено тут"
 
-#: cp/name-lookup.c:7292
+#: cp/name-lookup.c:7300
 #, gcc-internal-format
 msgid "XXX entering pop_everything ()\n"
 msgstr ""
 
-#: cp/name-lookup.c:7301
+#: cp/name-lookup.c:7309
 #, gcc-internal-format
 msgid "XXX leaving pop_everything ()\n"
 msgstr ""
@@ -44094,7 +44136,7 @@
 msgid "LEXER_DEBUGGING_ENABLED_P is not set to true"
 msgstr ""
 
-#: cp/parser.c:1352 cp/parser.c:37254
+#: cp/parser.c:1352 cp/parser.c:37251
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -44119,7 +44161,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr ""
 
-#: cp/parser.c:2949 cp/parser.c:18221
+#: cp/parser.c:2949 cp/parser.c:18218
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr ""
@@ -44199,7 +44241,7 @@
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3143 cp/pt.c:17853
+#: cp/parser.c:3143 cp/pt.c:17890
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr ""
@@ -44421,7 +44463,7 @@
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr ""
 
-#: cp/parser.c:4587 cp/parser.c:12940
+#: cp/parser.c:4587 cp/parser.c:12937
 #, gcc-internal-format
 msgid "expected declaration"
 msgstr ""
@@ -44471,7 +44513,7 @@
 msgid "fold-expressions only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:5275 cp/parser.c:5452 cp/parser.c:5630 cp/semantics.c:3612
+#: cp/parser.c:5275 cp/parser.c:5452 cp/parser.c:5633 cp/semantics.c:3615
 #, gcc-internal-format
 msgid "expected primary-expression"
 msgstr ""
@@ -44491,92 +44533,92 @@
 msgid "local variable %qD may not appear in this context"
 msgstr ""
 
-#: cp/parser.c:5787
+#: cp/parser.c:5790
 #, gcc-internal-format
 msgid "expected id-expression"
 msgstr ""
 
-#: cp/parser.c:5919
+#: cp/parser.c:5922
 #, gcc-internal-format
 msgid "scope %qT before %<~%> is not a class-name"
 msgstr ""
 
-#: cp/parser.c:5948 cp/parser.c:7860
+#: cp/parser.c:5951 cp/parser.c:7860
 #, gcc-internal-format
 msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:6059
+#: cp/parser.c:6062
 #, gcc-internal-format
 msgid "declaration of %<~%T%> as member of %qT"
 msgstr ""
 
-#: cp/parser.c:6074
+#: cp/parser.c:6077
 #, gcc-internal-format
 msgid "typedef-name %qD used as destructor declarator"
 msgstr ""
 
-#: cp/parser.c:6111 cp/parser.c:20249
+#: cp/parser.c:6114 cp/parser.c:20246
 #, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr ""
 
-#: cp/parser.c:6220
+#: cp/parser.c:6223
 #, gcc-internal-format
 msgid "found %<:%> in nested-name-specifier, expected %<::%>"
 msgstr ""
 
-#: cp/parser.c:6288
+#: cp/parser.c:6291
 #, gcc-internal-format
 msgid "decltype evaluates to %qT, which is not a class or enumeration type"
 msgstr ""
 
-#: cp/parser.c:6314
+#: cp/parser.c:6317
 #, gcc-internal-format
 msgid "function template-id %qD in nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:6322
+#: cp/parser.c:6325
 #, gcc-internal-format
 msgid "variable template-id %qD in nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:6426 cp/typeck.c:2684 cp/typeck.c:2687 cp/typeck.c:2704
+#: cp/parser.c:6429 cp/typeck.c:2684 cp/typeck.c:2687 cp/typeck.c:2704
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr ""
 
-#: cp/parser.c:6504
+#: cp/parser.c:6507
 #, gcc-internal-format
 msgid "expected nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:6711 cp/parser.c:8950
+#: cp/parser.c:6714 cp/parser.c:8950
 #, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr ""
 
-#: cp/parser.c:6797
+#: cp/parser.c:6800
 #, gcc-internal-format
 msgid "types may not be defined in a %<typeid%> expression"
 msgstr ""
 
-#: cp/parser.c:6889
+#: cp/parser.c:6892
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "помилкова кількість аргументів %<__builtin_addressof%>"
 
-#: cp/parser.c:6901 cp/pt.c:18416
+#: cp/parser.c:6904 cp/pt.c:18453
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "помилкова кількість аргументів %<__builtin_launder%>"
 
-#: cp/parser.c:6995
+#: cp/parser.c:6998
 #, gcc-internal-format
 msgid "ISO C++ forbids compound-literals"
 msgstr ""
 
-#: cp/parser.c:7054
+#: cp/parser.c:7057
 #, gcc-internal-format
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
@@ -44706,7 +44748,7 @@
 msgid "capture of non-variable %qE"
 msgstr ""
 
-#: cp/parser.c:10391 cp/parser.c:10401 cp/semantics.c:3453 cp/semantics.c:3465
+#: cp/parser.c:10391 cp/parser.c:10401 cp/semantics.c:3456 cp/semantics.c:3468
 #, gcc-internal-format
 msgid "%q#D declared here"
 msgstr ""
@@ -44791,7 +44833,7 @@
 msgid "init-statement in selection statements only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:11546 cp/parser.c:28490
+#: cp/parser.c:11546 cp/parser.c:28487
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr ""
@@ -44811,557 +44853,557 @@
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:12250 cp/parser.c:28493
+#: cp/parser.c:12250 cp/parser.c:28490
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr ""
 
-#: cp/parser.c:12298
+#: cp/parser.c:12297
 #, gcc-internal-format
 msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/parser.c:12426
+#: cp/parser.c:12423
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr "%<goto%> у функції %<constexpr%>"
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:12434
+#: cp/parser.c:12431
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr ""
 
-#: cp/parser.c:12447 cp/parser.c:28496
+#: cp/parser.c:12444 cp/parser.c:28493
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr ""
 
-#: cp/parser.c:12620 cp/parser.c:23584
+#: cp/parser.c:12617 cp/parser.c:23581
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "зайве %<;%>"
 
-#: cp/parser.c:12863
+#: cp/parser.c:12860
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr ""
 
-#: cp/parser.c:13083
+#: cp/parser.c:13080
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:13103
+#: cp/parser.c:13100
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr ""
 
-#: cp/parser.c:13124
+#: cp/parser.c:13121
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr ""
 
-#: cp/parser.c:13148
+#: cp/parser.c:13145
 #, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr ""
 
-#: cp/parser.c:13203
+#: cp/parser.c:13200
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13206
+#: cp/parser.c:13203
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13257
+#: cp/parser.c:13254
 #, gcc-internal-format
 msgid "structured bindings only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:13306
+#: cp/parser.c:13303
 #, gcc-internal-format
 msgid "empty structured binding declaration"
 msgstr ""
 
-#: cp/parser.c:13324
+#: cp/parser.c:13321
 #, gcc-internal-format
 msgid "invalid initializer for structured binding declaration"
 msgstr ""
 
-#: cp/parser.c:13491
+#: cp/parser.c:13488
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr ""
 
-#: cp/parser.c:13558
+#: cp/parser.c:13555
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr ""
 
-#: cp/parser.c:13594
+#: cp/parser.c:13591
 #, gcc-internal-format
 msgid "decl-specifier invalid in condition"
 msgstr ""
 
-#: cp/parser.c:13600
+#: cp/parser.c:13597
 #, gcc-internal-format
 msgid "%qD invalid in lambda"
 msgstr "%qD є некоректним у лямбді"
 
-#: cp/parser.c:13693
+#: cp/parser.c:13690
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr ""
 
-#: cp/parser.c:13763 cp/parser.c:24064
+#: cp/parser.c:13760 cp/parser.c:24061
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:13805
+#: cp/parser.c:13802
 #, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr ""
 
-#: cp/parser.c:13909
+#: cp/parser.c:13906
 #, gcc-internal-format
 msgid "static_assert without a message only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:14111
+#: cp/parser.c:14108
 #, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr ""
 
-#: cp/parser.c:14264
+#: cp/parser.c:14261
 #, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr ""
 
-#: cp/parser.c:14291
+#: cp/parser.c:14288
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr ""
 
-#: cp/parser.c:14295
+#: cp/parser.c:14292
 #, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr ""
 
-#: cp/parser.c:14379
+#: cp/parser.c:14376
 #, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr ""
 
-#: cp/parser.c:14406
+#: cp/parser.c:14403
 #, gcc-internal-format
 msgid "cannot expand initializer for member %qD"
 msgstr ""
 
-#: cp/parser.c:14418 cp/pt.c:24255
+#: cp/parser.c:14415 cp/pt.c:24333
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr ""
 
-#: cp/parser.c:14430 cp/pt.c:24267
+#: cp/parser.c:14427 cp/pt.c:24345
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
 
-#: cp/parser.c:14482
+#: cp/parser.c:14479
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr ""
 
-#: cp/parser.c:14552
+#: cp/parser.c:14549
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:14927
+#: cp/parser.c:14924
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr ""
 
-#: cp/parser.c:14933
+#: cp/parser.c:14930
 #, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr ""
 
-#: cp/parser.c:14942
+#: cp/parser.c:14939
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr ""
 
-#: cp/parser.c:14948
+#: cp/parser.c:14945
 #, gcc-internal-format
 msgid "invalid encoding prefix in literal operator"
 msgstr ""
 
-#: cp/parser.c:14975
+#: cp/parser.c:14972
 #, gcc-internal-format
 msgid "expected operator"
 msgstr ""
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:15020
+#: cp/parser.c:15017
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr ""
 
-#: cp/parser.c:15190
+#: cp/parser.c:15187
 #, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr "некоректний параметр обмеженого типу"
 
-#: cp/parser.c:15198
+#: cp/parser.c:15195
 #, gcc-internal-format
 msgid "cv-qualified type parameter"
 msgstr ""
 
-#: cp/parser.c:15283
+#: cp/parser.c:15280
 #, gcc-internal-format
 msgid "variadic constraint introduced without %<...%>"
 msgstr ""
 
-#: cp/parser.c:15347
+#: cp/parser.c:15344
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr ""
 
-#: cp/parser.c:15582 cp/parser.c:15668 cp/parser.c:21694
+#: cp/parser.c:15579 cp/parser.c:15665 cp/parser.c:21691
 #, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:15586 cp/parser.c:15672
+#: cp/parser.c:15583 cp/parser.c:15669
 #, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr ""
 
-#: cp/parser.c:15738
+#: cp/parser.c:15735
 #, gcc-internal-format
 msgid "expected template-id"
 msgstr ""
 
-#: cp/parser.c:15798
+#: cp/parser.c:15795
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr ""
 
-#: cp/parser.c:15802
+#: cp/parser.c:15799
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr ""
 
-#: cp/parser.c:15806
+#: cp/parser.c:15803
 #, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr ""
 
-#: cp/parser.c:15924
+#: cp/parser.c:15921
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr ""
 
 #. The name does not name a template.
-#: cp/parser.c:15992 cp/parser.c:16122 cp/parser.c:16337
+#: cp/parser.c:15989 cp/parser.c:16119 cp/parser.c:16334
 #, gcc-internal-format
 msgid "expected template-name"
 msgstr ""
 
 #. Explain what went wrong.
-#: cp/parser.c:16038
+#: cp/parser.c:16035
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr ""
 
-#: cp/parser.c:16040
+#: cp/parser.c:16037
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr ""
 
-#: cp/parser.c:16189
+#: cp/parser.c:16186
 #, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr ""
 
-#: cp/parser.c:16298 cp/parser.c:16316 cp/parser.c:16483
+#: cp/parser.c:16295 cp/parser.c:16313 cp/parser.c:16480
 #, gcc-internal-format
 msgid "expected template-argument"
 msgstr ""
 
-#: cp/parser.c:16458
+#: cp/parser.c:16455
 #, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr ""
 
-#: cp/parser.c:16585
+#: cp/parser.c:16582
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr ""
 
-#: cp/parser.c:16589
+#: cp/parser.c:16586
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr ""
 
-#: cp/parser.c:16648
+#: cp/parser.c:16645
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr ""
 
-#: cp/parser.c:16869
+#: cp/parser.c:16866
 #, gcc-internal-format
 msgid "expected type specifier"
 msgstr ""
 
-#: cp/parser.c:17053
+#: cp/parser.c:17050
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:17059
+#: cp/parser.c:17056
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:17064
+#: cp/parser.c:17061
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -fconcepts"
 msgstr ""
 
-#: cp/parser.c:17209
+#: cp/parser.c:17206
 #, gcc-internal-format
 msgid "expected template-id for type"
 msgstr ""
 
-#: cp/parser.c:17278
+#: cp/parser.c:17275
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr "мало бути вказано тип-назву"
 
-#: cp/parser.c:17631
+#: cp/parser.c:17628
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr ""
 
-#: cp/parser.c:17854
+#: cp/parser.c:17851
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr ""
 
-#: cp/parser.c:17942
+#: cp/parser.c:17939
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr ""
 
-#: cp/parser.c:17946
+#: cp/parser.c:17943
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr ""
 
-#: cp/parser.c:17951
+#: cp/parser.c:17948
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr ""
 
-#: cp/parser.c:18085
+#: cp/parser.c:18082
 #, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr ""
 
-#: cp/parser.c:18096
+#: cp/parser.c:18093
 #, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr ""
 
-#: cp/parser.c:18111
+#: cp/parser.c:18108
 #, gcc-internal-format
 msgid "unnamed scoped enum is not allowed"
 msgstr ""
 
-#: cp/parser.c:18166
+#: cp/parser.c:18163
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "мало бути %<;%> або %<{%>"
 
-#: cp/parser.c:18215
+#: cp/parser.c:18212
 #, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr ""
 
-#: cp/parser.c:18229
+#: cp/parser.c:18226
 #, gcc-internal-format
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr ""
 
-#: cp/parser.c:18241 cp/parser.c:23070
+#: cp/parser.c:18238 cp/parser.c:23067
 #, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr ""
 
-#: cp/parser.c:18246 cp/parser.c:23075
+#: cp/parser.c:18243 cp/parser.c:23072
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr ""
 
-#: cp/parser.c:18258 cp/parser.c:23089
+#: cp/parser.c:18255 cp/parser.c:23086
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr ""
 
-#: cp/parser.c:18282
+#: cp/parser.c:18279
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr ""
 
-#: cp/parser.c:18295
+#: cp/parser.c:18292
 #, gcc-internal-format
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "У ISO C++ заборонено порожні enum без назви"
 
-#: cp/parser.c:18315
+#: cp/parser.c:18312
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:18318
+#: cp/parser.c:18315
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:18497
+#: cp/parser.c:18494
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr ""
 
-#: cp/parser.c:18503
+#: cp/parser.c:18500
 #, gcc-internal-format
 msgid "expected namespace-name"
 msgstr ""
 
-#: cp/parser.c:18570
+#: cp/parser.c:18567
 #, gcc-internal-format
 msgid "nested namespace definitions only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:18578
+#: cp/parser.c:18575
 #, gcc-internal-format
 msgid "nested namespace name required"
 msgstr ""
 
-#: cp/parser.c:18583
+#: cp/parser.c:18580
 #, gcc-internal-format
 msgid "namespace name required"
 msgstr ""
 
-#: cp/parser.c:18587
+#: cp/parser.c:18584
 #, gcc-internal-format
 msgid "a nested namespace definition cannot have attributes"
 msgstr ""
 
-#: cp/parser.c:18590
+#: cp/parser.c:18587
 #, gcc-internal-format
 msgid "a nested namespace definition cannot be inline"
 msgstr ""
 
-#: cp/parser.c:18597
+#: cp/parser.c:18594
 #, gcc-internal-format
 msgid "namespace %qD entered"
 msgstr ""
 
-#: cp/parser.c:18652
+#: cp/parser.c:18649
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr ""
 
-#: cp/parser.c:18803
+#: cp/parser.c:18800
 #, gcc-internal-format
 msgid "pack expansion in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:18818
+#: cp/parser.c:18815
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr ""
 
-#: cp/parser.c:18865
+#: cp/parser.c:18862
 #, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:18875
+#: cp/parser.c:18872
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:18940
+#: cp/parser.c:18937
 #, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr ""
 
-#: cp/parser.c:19106
+#: cp/parser.c:19103
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr "%<asm%> у функції %<constexpr%>"
 
-#: cp/parser.c:19493
+#: cp/parser.c:19490
 #, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr ""
 
-#: cp/parser.c:19504
+#: cp/parser.c:19501
 #, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr ""
 
-#: cp/parser.c:19508
+#: cp/parser.c:19505
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr ""
 
-#: cp/parser.c:19559
+#: cp/parser.c:19556
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
 #. Anything else is an error.
-#: cp/parser.c:19598 cp/parser.c:21906
+#: cp/parser.c:19595 cp/parser.c:21903
 #, gcc-internal-format
 msgid "expected initializer"
 msgstr ""
 
-#: cp/parser.c:19679
+#: cp/parser.c:19676
 #, gcc-internal-format
 msgid "initializer provided for function"
 msgstr ""
 
-#: cp/parser.c:19713
+#: cp/parser.c:19710
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr ""
 
-#: cp/parser.c:19727
+#: cp/parser.c:19724
 #, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr ""
 
-#: cp/parser.c:20169
+#: cp/parser.c:20166
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr ""
 
-#: cp/parser.c:20295
+#: cp/parser.c:20292
 #, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr ""
 
-#: cp/parser.c:20299
+#: cp/parser.c:20296
 #, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "%<%T::%E%> не є типом"
@@ -45370,17 +45412,17 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:20328
+#: cp/parser.c:20325
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr ""
 
-#: cp/parser.c:20336
+#: cp/parser.c:20333
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr ""
 
-#: cp/parser.c:20338
+#: cp/parser.c:20335
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr ""
@@ -45387,382 +45429,382 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:20410
+#: cp/parser.c:20407
 #, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr ""
 
-#: cp/parser.c:20435
+#: cp/parser.c:20432
 #, gcc-internal-format
 msgid "expected declarator"
 msgstr ""
 
-#: cp/parser.c:20554
+#: cp/parser.c:20551
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr ""
 
-#: cp/parser.c:20556
+#: cp/parser.c:20553
 #, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr ""
 
-#: cp/parser.c:20577
+#: cp/parser.c:20574
 #, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr ""
 
-#: cp/parser.c:20638
+#: cp/parser.c:20635
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr ""
 
-#: cp/parser.c:20692
+#: cp/parser.c:20689
 #, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr ""
 
-#: cp/parser.c:20729
+#: cp/parser.c:20726
 #, gcc-internal-format
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr "%qE потребує %<-fgnu-tm%>"
 
-#: cp/parser.c:20787
+#: cp/parser.c:20784
 #, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr ""
 
-#: cp/parser.c:21025
+#: cp/parser.c:21022
 #, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr ""
 
-#: cp/parser.c:21031 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2090
+#: cp/parser.c:21028 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2093
 #, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr ""
 
-#: cp/parser.c:21052
+#: cp/parser.c:21049
 #, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr ""
 
-#: cp/parser.c:21057
+#: cp/parser.c:21054
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr ""
 
-#: cp/parser.c:21145
+#: cp/parser.c:21142
 #, gcc-internal-format
 msgid "expected type-specifier"
 msgstr ""
 
-#: cp/parser.c:21429
+#: cp/parser.c:21426
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "мало бути %<,%> або %<...%>"
 
-#: cp/parser.c:21504
+#: cp/parser.c:21501
 #, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr ""
 
-#: cp/parser.c:21678
+#: cp/parser.c:21675
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr ""
 
-#: cp/parser.c:21696
+#: cp/parser.c:21693
 #, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:21702
+#: cp/parser.c:21699
 #, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:21704
+#: cp/parser.c:21701
 #, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:22131
+#: cp/parser.c:22128
 #, gcc-internal-format
 msgid "C++ designated initializers only available with -std=c++2a or -std=gnu++2a"
 msgstr ""
 
-#: cp/parser.c:22151
+#: cp/parser.c:22148
 #, gcc-internal-format
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr ""
 
-#: cp/parser.c:22189
+#: cp/parser.c:22186
 #, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr ""
 
-#: cp/parser.c:22203
+#: cp/parser.c:22200
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr ""
 
-#: cp/parser.c:22228
+#: cp/parser.c:22225
 #, gcc-internal-format
 msgid "%<...%> not allowed in designated initializer list"
 msgstr ""
 
-#: cp/parser.c:22266
+#: cp/parser.c:22263
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr ""
 
-#: cp/parser.c:22322 cp/parser.c:22448
+#: cp/parser.c:22319 cp/parser.c:22445
 #, gcc-internal-format
 msgid "expected class-name"
 msgstr ""
 
-#: cp/parser.c:22650
+#: cp/parser.c:22647
 #, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr ""
 
-#: cp/parser.c:22653
+#: cp/parser.c:22650
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr ""
 
-#: cp/parser.c:22656
+#: cp/parser.c:22653
 #, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr ""
 
-#: cp/parser.c:23012
+#: cp/parser.c:23009
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "мало бути %<{%> або %<:%>"
 
-#: cp/parser.c:23023
+#: cp/parser.c:23020
 #, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr ""
 
-#: cp/parser.c:23031
+#: cp/parser.c:23028
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:23038
+#: cp/parser.c:23035
 #, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr ""
 
-#: cp/parser.c:23050
+#: cp/parser.c:23047
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr ""
 
-#: cp/parser.c:23056
+#: cp/parser.c:23053
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr ""
 
-#: cp/parser.c:23114
+#: cp/parser.c:23111
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr ""
 
-#: cp/parser.c:23146
+#: cp/parser.c:23143
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr ""
 
-#: cp/parser.c:23182
+#: cp/parser.c:23179
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr "не вдалося визначити тип typename"
 
-#: cp/parser.c:23241
+#: cp/parser.c:23238
 #, gcc-internal-format
 msgid "previous definition of %q#T"
 msgstr "попереднє визначення %q#T"
 
-#: cp/parser.c:23331 cp/parser.c:28499
+#: cp/parser.c:23328 cp/parser.c:28496
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr ""
 
-#: cp/parser.c:23355
+#: cp/parser.c:23352
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:23359
+#: cp/parser.c:23356
 #, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "мало бути %<class%> або %<typename%>"
 
-#: cp/parser.c:23605
+#: cp/parser.c:23602
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr ""
 
-#: cp/parser.c:23623
+#: cp/parser.c:23620
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr ""
 
-#: cp/parser.c:23641
+#: cp/parser.c:23638
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:23738
+#: cp/parser.c:23735
 #, gcc-internal-format
 msgid "default member initializers for bit-fields only available with -std=c++2a or -std=gnu++2a"
 msgstr ""
 
-#: cp/parser.c:23745
+#: cp/parser.c:23742
 #, gcc-internal-format
 msgid "default member initializer for unnamed bit-field"
 msgstr ""
 
-#: cp/parser.c:23758
+#: cp/parser.c:23755
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr ""
 
-#: cp/parser.c:23903
+#: cp/parser.c:23900
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr ""
 
-#: cp/parser.c:23923
+#: cp/parser.c:23920
 #, gcc-internal-format
 msgid "extra %<;%> after in-class function definition"
 msgstr ""
 
-#: cp/parser.c:23970
+#: cp/parser.c:23967
 #, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr ""
 
-#: cp/parser.c:23984
+#: cp/parser.c:23981
 #, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr ""
 
-#: cp/parser.c:24058
+#: cp/parser.c:24055
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr ""
 
-#: cp/parser.c:24093
+#: cp/parser.c:24090
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr ""
 
-#: cp/parser.c:24223
+#: cp/parser.c:24220
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr ""
 
-#: cp/parser.c:24243
+#: cp/parser.c:24240
 #, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr ""
 
-#: cp/parser.c:24267
+#: cp/parser.c:24264
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr ""
 
-#: cp/parser.c:24270
+#: cp/parser.c:24267
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:24364 cp/parser.c:24442
+#: cp/parser.c:24361 cp/parser.c:24439
 #, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr ""
 
-#: cp/parser.c:24450
+#: cp/parser.c:24447
 #, gcc-internal-format
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "У ISO C++17 не можна визначати динамічні специфікації виключень"
 
-#: cp/parser.c:24456
+#: cp/parser.c:24453
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr ""
 
-#: cp/parser.c:24500
+#: cp/parser.c:24497
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr ""
 
-#: cp/parser.c:24539
+#: cp/parser.c:24536
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr "%<try%> у функції %<constexpr%>"
 
-#: cp/parser.c:24650
+#: cp/parser.c:24647
 #, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr ""
 
-#: cp/parser.c:25203
+#: cp/parser.c:25200
 #, gcc-internal-format
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr ""
 
-#: cp/parser.c:25217
+#: cp/parser.c:25214
 #, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr ""
 
-#: cp/parser.c:25301
+#: cp/parser.c:25298
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:25305
+#: cp/parser.c:25302
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:25342
+#: cp/parser.c:25339
 #, gcc-internal-format
 msgid "expected attribute before %<...%>"
 msgstr "мав бути атрибут перед %<...%>"
 
-#: cp/parser.c:25403
+#: cp/parser.c:25400
 #, gcc-internal-format
 msgid "attribute using prefix only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:25721
+#: cp/parser.c:25718
 #, gcc-internal-format
 msgid "%<requires%> only available with -fconcepts"
 msgstr ""
 
-#: cp/parser.c:25753
+#: cp/parser.c:25750
 #, gcc-internal-format
 msgid "a requires expression cannot appear outside a template"
 msgstr ""
 
-#: cp/parser.c:26467
+#: cp/parser.c:26464
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:26472
+#: cp/parser.c:26469
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr ""
 
-#: cp/parser.c:26476
+#: cp/parser.c:26473
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr ""
@@ -45771,453 +45813,453 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:26483
+#: cp/parser.c:26480
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr ""
 
-#: cp/parser.c:26832
+#: cp/parser.c:26829
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr ""
 
-#: cp/parser.c:26991
+#: cp/parser.c:26988
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr ""
 
-#: cp/parser.c:26996
+#: cp/parser.c:26993
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr ""
 
-#: cp/parser.c:27066
+#: cp/parser.c:27063
 #, gcc-internal-format
 msgid "empty introduction-list"
 msgstr ""
 
-#: cp/parser.c:27090
+#: cp/parser.c:27087
 #, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr ""
 
-#: cp/parser.c:27112
+#: cp/parser.c:27109
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr ""
 
-#: cp/parser.c:27121
+#: cp/parser.c:27118
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr ""
 
-#: cp/parser.c:27141
+#: cp/parser.c:27138
 #, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr ""
 
-#: cp/parser.c:27245
+#: cp/parser.c:27242
 #, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr ""
 
-#: cp/parser.c:27296
+#: cp/parser.c:27293
 #, gcc-internal-format
 msgid "a class template declaration must not declare anything else"
 msgstr ""
 
-#: cp/parser.c:27342
+#: cp/parser.c:27339
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr ""
 
-#: cp/parser.c:27650
+#: cp/parser.c:27647
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr ""
 
-#: cp/parser.c:27663
+#: cp/parser.c:27660
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr ""
 
-#: cp/parser.c:27958
+#: cp/parser.c:27955
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:28118
+#: cp/parser.c:28115
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr ""
 
-#: cp/parser.c:28133
+#: cp/parser.c:28130
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr ""
 
-#: cp/parser.c:28267
+#: cp/parser.c:28264
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "У ISO C++ 1998 не передбачено підтримки %<long long%>"
 
-#: cp/parser.c:28275
+#: cp/parser.c:28272
 #, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "вказано одразу %<__thread%> і %<thread_local%>"
 
-#: cp/parser.c:28280
+#: cp/parser.c:28277
 #, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "дублювання %qD"
 
-#: cp/parser.c:28304
+#: cp/parser.c:28301
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "дублювання %qs"
 
-#: cp/parser.c:28356
+#: cp/parser.c:28353
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "мало бути %<new%>"
 
-#: cp/parser.c:28359
+#: cp/parser.c:28356
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "мало бути %<delete%>"
 
-#: cp/parser.c:28362
+#: cp/parser.c:28359
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "мало бути %<return%>"
 
-#: cp/parser.c:28368
+#: cp/parser.c:28365
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "мало бути %<extern%>"
 
-#: cp/parser.c:28371
+#: cp/parser.c:28368
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "мало бути %<static_assert%>"
 
-#: cp/parser.c:28374
+#: cp/parser.c:28371
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "мало бути %<decltype%>"
 
-#: cp/parser.c:28377
+#: cp/parser.c:28374
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "мало бути %<operator%>"
 
-#: cp/parser.c:28380
+#: cp/parser.c:28377
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "мало бути %<class%>"
 
-#: cp/parser.c:28383
+#: cp/parser.c:28380
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "мало бути %<template%>"
 
-#: cp/parser.c:28386
+#: cp/parser.c:28383
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "мало бути %<namespace%>"
 
-#: cp/parser.c:28389
+#: cp/parser.c:28386
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "мало бути %<using%>"
 
-#: cp/parser.c:28392
+#: cp/parser.c:28389
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "мало бути %<asm%>"
 
-#: cp/parser.c:28395
+#: cp/parser.c:28392
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "мало бути %<try%>"
 
-#: cp/parser.c:28398
+#: cp/parser.c:28395
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "мало бути %<catch%>"
 
-#: cp/parser.c:28401
+#: cp/parser.c:28398
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "мало бути %<throw%>"
 
-#: cp/parser.c:28404
+#: cp/parser.c:28401
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "мало бути %<__label__%>"
 
-#: cp/parser.c:28407
+#: cp/parser.c:28404
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "мало бути %<@try%>"
 
-#: cp/parser.c:28410
+#: cp/parser.c:28407
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "мало бути %<@synchronized%>"
 
-#: cp/parser.c:28413
+#: cp/parser.c:28410
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "мало бути %<@throw%>"
 
-#: cp/parser.c:28416
+#: cp/parser.c:28413
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "мало бути %<__transaction_atomic%>"
 
-#: cp/parser.c:28419
+#: cp/parser.c:28416
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "мало бути %<__transaction_relaxed%>"
 
-#: cp/parser.c:28451
+#: cp/parser.c:28448
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "мало бути %<::%>"
 
-#: cp/parser.c:28463
+#: cp/parser.c:28460
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "мало бути %<...%>"
 
-#: cp/parser.c:28466
+#: cp/parser.c:28463
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "мало бути %<*%>"
 
-#: cp/parser.c:28469
+#: cp/parser.c:28466
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "мало бути %<~%>"
 
-#: cp/parser.c:28475
+#: cp/parser.c:28472
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "мало бути %<:%> або %<::%>"
 
-#: cp/parser.c:28502
+#: cp/parser.c:28499
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "мало бути %<class%>, %<typename%> або %<template%>"
 
-#: cp/parser.c:28772
+#: cp/parser.c:28769
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "теґ %qs використано у назві %q#T"
 
-#: cp/parser.c:28777
+#: cp/parser.c:28774
 #, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr ""
 
-#: cp/parser.c:28798
+#: cp/parser.c:28795
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr ""
 
-#: cp/parser.c:28819
+#: cp/parser.c:28816
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr ""
 
-#: cp/parser.c:29062
+#: cp/parser.c:29059
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr ""
 
-#: cp/parser.c:29303 cp/parser.c:30620 cp/parser.c:30808
+#: cp/parser.c:29300 cp/parser.c:30617 cp/parser.c:30805
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr ""
 
-#: cp/parser.c:29372
+#: cp/parser.c:29369
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr ""
 
-#: cp/parser.c:29442
+#: cp/parser.c:29439
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:29473
+#: cp/parser.c:29470
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr ""
 
-#: cp/parser.c:29883
+#: cp/parser.c:29880
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr ""
 
-#: cp/parser.c:29958 cp/parser.c:29976
+#: cp/parser.c:29955 cp/parser.c:29973
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr ""
 
-#: cp/parser.c:29970 cp/parser.c:30035
+#: cp/parser.c:29967 cp/parser.c:30032
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr ""
 
-#: cp/parser.c:30078
+#: cp/parser.c:30075
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:30284 cp/parser.c:30291 cp/parser.c:30298
+#: cp/parser.c:30281 cp/parser.c:30288 cp/parser.c:30295
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr ""
 
-#: cp/parser.c:30413
+#: cp/parser.c:30410
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr ""
 
-#: cp/parser.c:30585
+#: cp/parser.c:30582
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:30592
+#: cp/parser.c:30589
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr ""
 
-#: cp/parser.c:30867 cp/parser.c:30874 cp/parser.c:30881
+#: cp/parser.c:30864 cp/parser.c:30871 cp/parser.c:30878
 #, gcc-internal-format
 msgid "invalid type for property"
 msgstr ""
 
-#: cp/parser.c:32011
+#: cp/parser.c:32008
 #, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr ""
 
-#: cp/parser.c:32724
+#: cp/parser.c:32721
 #, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr ""
 
-#: cp/parser.c:34911
+#: cp/parser.c:34908
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:35231 cp/pt.c:16392
+#: cp/parser.c:35228 cp/pt.c:16414
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr ""
 
-#: cp/parser.c:35316
+#: cp/parser.c:35313
 #, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr ""
 
-#: cp/parser.c:37521
+#: cp/parser.c:37518
 #, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr ""
 
-#: cp/parser.c:37549
+#: cp/parser.c:37546
 #, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr ""
 
-#: cp/parser.c:37561
+#: cp/parser.c:37558
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:37662
+#: cp/parser.c:37659
 #, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr ""
 
-#: cp/parser.c:37682 cp/semantics.c:5405
+#: cp/parser.c:37679 cp/semantics.c:5408
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37687 cp/semantics.c:5414
+#: cp/parser.c:37684 cp/semantics.c:5417
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37690 cp/pt.c:12944 cp/semantics.c:5420
+#: cp/parser.c:37687 cp/pt.c:12966 cp/semantics.c:5423
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37693 cp/semantics.c:5426
+#: cp/parser.c:37690 cp/semantics.c:5429
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:38047
+#: cp/parser.c:38044
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:38057
+#: cp/parser.c:38054
 #, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr ""
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:38392
+#: cp/parser.c:38389
 #, gcc-internal-format
 msgid "atomic_cancel"
 msgstr ""
 
-#: cp/parser.c:38435 cp/semantics.c:8575
+#: cp/parser.c:38432 cp/semantics.c:8578
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:38437 cp/semantics.c:8577
+#: cp/parser.c:38434 cp/semantics.c:8580
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:38631
+#: cp/parser.c:38628
 #, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr ""
 
-#: cp/parser.c:38927
+#: cp/parser.c:38924
 #, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "%<#pragma GCC ivdep%> має перебувати всередині функції"
 
-#: cp/parser.c:38959
+#: cp/parser.c:38956
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr "%<#pragma GCC unroll%> має перебувати всередині функції"
 
-#: cp/parser.c:39039
+#: cp/parser.c:39036
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr ""
 
-#: cp/parser.c:39295
+#: cp/parser.c:39292
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:39351
+#: cp/parser.c:39348
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
@@ -46304,7 +46346,7 @@
 msgid "specialization of %qD after instantiation"
 msgstr ""
 
-#: cp/pt.c:1954 cp/semantics.c:5274
+#: cp/pt.c:1954 cp/semantics.c:5277
 #, gcc-internal-format
 msgid "%s %#qD"
 msgstr "%s %#qD"
@@ -46470,107 +46512,107 @@
 msgid "argument to __integer_pack must be between 0 and %d"
 msgstr ""
 
-#: cp/pt.c:3942
+#: cp/pt.c:3955
 #, gcc-internal-format
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr ""
 
-#: cp/pt.c:4010
+#: cp/pt.c:4023
 #, gcc-internal-format
 msgid "expansion pattern %qT contains no argument packs"
 msgstr ""
 
-#: cp/pt.c:4012
+#: cp/pt.c:4025
 #, gcc-internal-format
 msgid "expansion pattern %qE contains no argument packs"
 msgstr ""
 
-#: cp/pt.c:4063
+#: cp/pt.c:4077
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr ""
 
-#: cp/pt.c:4080 cp/pt.c:4835
+#: cp/pt.c:4094 cp/pt.c:4849
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
 
-#: cp/pt.c:4082
+#: cp/pt.c:4096
 #, gcc-internal-format
 msgid "        <anonymous>"
 msgstr ""
 
-#: cp/pt.c:4208
+#: cp/pt.c:4222
 #, gcc-internal-format
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr ""
 
-#: cp/pt.c:4211
+#: cp/pt.c:4225
 #, gcc-internal-format
 msgid "declaration of %q+#D shadows template parameter"
 msgstr ""
 
-#: cp/pt.c:4213
+#: cp/pt.c:4227
 #, gcc-internal-format
 msgid "template parameter %qD declared here"
 msgstr ""
 
-#: cp/pt.c:4771
+#: cp/pt.c:4785
 #, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr ""
 
-#: cp/pt.c:4830
+#: cp/pt.c:4844
 #, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr ""
 
-#: cp/pt.c:4854
+#: cp/pt.c:4868
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:4858
+#: cp/pt.c:4872
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:4862 cp/pt.c:4873
+#: cp/pt.c:4876 cp/pt.c:4887
 #, gcc-internal-format
 msgid "primary template here"
 msgstr ""
 
-#: cp/pt.c:4870
+#: cp/pt.c:4884
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:4885
+#: cp/pt.c:4899
 #, gcc-internal-format
 msgid "partial specialization %qD is not more specialized than"
 msgstr ""
 
-#: cp/pt.c:4887
+#: cp/pt.c:4901
 #, gcc-internal-format
 msgid "primary template %qD"
 msgstr ""
 
-#: cp/pt.c:4934
+#: cp/pt.c:4948
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:4937
+#: cp/pt.c:4951
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:4958
+#: cp/pt.c:4972
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr ""
 
-#: cp/pt.c:5004
+#: cp/pt.c:5018
 #, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
@@ -46578,17 +46620,17 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/pt.c:5066
+#: cp/pt.c:5080
 #, gcc-internal-format
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr ""
 
-#: cp/pt.c:5070
+#: cp/pt.c:5084
 #, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr ""
 
-#: cp/pt.c:5247
+#: cp/pt.c:5261
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr ""
@@ -46596,47 +46638,47 @@
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5269
+#: cp/pt.c:5283
 #, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr ""
 
-#: cp/pt.c:5305
+#: cp/pt.c:5319
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr ""
 
-#: cp/pt.c:5308
+#: cp/pt.c:5322
 #, gcc-internal-format
 msgid "default template arguments may not be used in template friend declarations"
 msgstr ""
 
-#: cp/pt.c:5311
+#: cp/pt.c:5325
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/pt.c:5314
+#: cp/pt.c:5328
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr ""
 
-#: cp/pt.c:5317 cp/pt.c:5375
+#: cp/pt.c:5331 cp/pt.c:5389
 #, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr ""
 
-#: cp/pt.c:5489
+#: cp/pt.c:5503
 #, gcc-internal-format
 msgid "template %qD declared"
 msgstr "оголошено шаблон %qD"
 
-#: cp/pt.c:5496
+#: cp/pt.c:5510
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr ""
 
-#: cp/pt.c:5504
+#: cp/pt.c:5518
 #, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr ""
@@ -46646,57 +46688,57 @@
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5526
+#: cp/pt.c:5540
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr ""
 
-#: cp/pt.c:5669
+#: cp/pt.c:5683
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr ""
 
-#: cp/pt.c:5712
+#: cp/pt.c:5726
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr ""
 
-#: cp/pt.c:5726
+#: cp/pt.c:5740
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr ""
 
-#: cp/pt.c:5729
+#: cp/pt.c:5743
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr ""
 
-#: cp/pt.c:5731
+#: cp/pt.c:5745
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr ""
 
-#: cp/pt.c:5752
+#: cp/pt.c:5766
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr ""
 
-#: cp/pt.c:5755
+#: cp/pt.c:5769
 #, gcc-internal-format
 msgid "use %<template<>%> for an explicit specialization"
 msgstr ""
 
-#: cp/pt.c:5882
+#: cp/pt.c:5896
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr ""
 
-#: cp/pt.c:5895
+#: cp/pt.c:5909
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr ""
 
-#: cp/pt.c:5906
+#: cp/pt.c:5920
 #, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
@@ -46704,7 +46746,7 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/pt.c:5910
+#: cp/pt.c:5924
 #, gcc-internal-format
 msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
@@ -46712,12 +46754,12 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/pt.c:5947
+#: cp/pt.c:5961
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr ""
 
-#: cp/pt.c:5948
+#: cp/pt.c:5962
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr ""
@@ -46726,117 +46768,117 @@
 #.
 #. A template-parameter may not be given default arguments
 #. by two different declarations in the same scope.
-#: cp/pt.c:5958
+#: cp/pt.c:5972
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr ""
 
-#: cp/pt.c:5960
+#: cp/pt.c:5974
 #, gcc-internal-format
 msgid "original definition appeared here"
 msgstr ""
 
-#: cp/pt.c:5988
+#: cp/pt.c:6002
 #, gcc-internal-format
 msgid "redeclaration %q#D with different constraints"
 msgstr ""
 
-#: cp/pt.c:5991
+#: cp/pt.c:6005
 #, gcc-internal-format
 msgid "original declaration appeared here"
 msgstr ""
 
-#: cp/pt.c:6250 cp/pt.c:6318
+#: cp/pt.c:6264 cp/pt.c:6332
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr ""
 
-#: cp/pt.c:6253
+#: cp/pt.c:6267
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6256
+#: cp/pt.c:6270
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6268
+#: cp/pt.c:6282
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr ""
 
-#: cp/pt.c:6272
+#: cp/pt.c:6286
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr ""
 
-#: cp/pt.c:6321
+#: cp/pt.c:6335
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr ""
 
-#: cp/pt.c:6323
+#: cp/pt.c:6337
 #, gcc-internal-format
 msgid "because it is a member of %qT"
 msgstr ""
 
-#: cp/pt.c:6383
+#: cp/pt.c:6397
 #, gcc-internal-format
 msgid "  couldn't deduce template parameter %qD"
 msgstr ""
 
-#: cp/pt.c:6392
+#: cp/pt.c:6406
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.c:6401
+#: cp/pt.c:6415
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:6410
+#: cp/pt.c:6424
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr ""
 
-#: cp/pt.c:6421
+#: cp/pt.c:6435
 #, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr ""
 
-#: cp/pt.c:6431
+#: cp/pt.c:6445
 #, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr ""
 
-#: cp/pt.c:6440
+#: cp/pt.c:6454
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:6452
+#: cp/pt.c:6466
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.c:6456
+#: cp/pt.c:6470
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.c:6467
+#: cp/pt.c:6481
 #, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6478
+#: cp/pt.c:6492
 #, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6490
+#: cp/pt.c:6504
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
@@ -46844,292 +46886,292 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/pt.c:6521
+#: cp/pt.c:6535
 #, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr ""
 
-#: cp/pt.c:6534
+#: cp/pt.c:6548
 #, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr ""
 
-#: cp/pt.c:6538
+#: cp/pt.c:6552
 #, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr ""
 
-#: cp/pt.c:6549
+#: cp/pt.c:6563
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.c:6559
+#: cp/pt.c:6573
 #, gcc-internal-format
 msgid "  can't deduce a template for %qT from non-template type %qT"
 msgstr ""
 
-#: cp/pt.c:6569
+#: cp/pt.c:6583
 #, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
 msgstr ""
 
-#: cp/pt.c:6609
+#: cp/pt.c:6623
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr ""
 
-#: cp/pt.c:6758
+#: cp/pt.c:6772
 #, gcc-internal-format
 msgid "in template argument for type %qT"
 msgstr "в аргументі шаблона для типу %qT"
 
-#: cp/pt.c:6772
+#: cp/pt.c:6786
 #, gcc-internal-format
 msgid "template argument %qE for type %qT not a constant integer"
 msgstr ""
 
-#: cp/pt.c:6833
+#: cp/pt.c:6847
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr ""
 
-#: cp/pt.c:6841
+#: cp/pt.c:6855
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr ""
 
-#: cp/pt.c:6857
+#: cp/pt.c:6871
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr ""
 
-#: cp/pt.c:6864
+#: cp/pt.c:6878
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr ""
 
-#: cp/pt.c:6873
+#: cp/pt.c:6887
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr ""
 
-#: cp/pt.c:6888
+#: cp/pt.c:6902
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6897
+#: cp/pt.c:6911
 #, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6904
+#: cp/pt.c:6918
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr ""
 
-#: cp/pt.c:6933
+#: cp/pt.c:6947
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr ""
 
-#: cp/pt.c:6941
+#: cp/pt.c:6955
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr ""
 
-#: cp/pt.c:6959
+#: cp/pt.c:6973
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr ""
 
-#: cp/pt.c:6975
+#: cp/pt.c:6989
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an object with linkage"
 msgstr ""
 
-#: cp/pt.c:6986
+#: cp/pt.c:7000
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because object %qD does not have linkage"
 msgstr ""
 
-#: cp/pt.c:7036
+#: cp/pt.c:7050
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr ""
 
-#: cp/pt.c:7038
+#: cp/pt.c:7052
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr ""
 
-#: cp/pt.c:7092
+#: cp/pt.c:7106
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr ""
 
-#: cp/pt.c:7654
+#: cp/pt.c:7668
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr ""
 
-#: cp/pt.c:7670
+#: cp/pt.c:7684
 #, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr ""
 
-#: cp/pt.c:7805
+#: cp/pt.c:7819
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr ""
 
-#: cp/pt.c:7834
+#: cp/pt.c:7848
 #, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr ""
 
-#: cp/pt.c:7839
+#: cp/pt.c:7853
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr ""
 
-#: cp/pt.c:7855 cp/pt.c:7877 cp/pt.c:7931
+#: cp/pt.c:7869 cp/pt.c:7891 cp/pt.c:7945
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.c:7860
+#: cp/pt.c:7874
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr ""
 
-#: cp/pt.c:7865
+#: cp/pt.c:7879
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr ""
 
-#: cp/pt.c:7868
+#: cp/pt.c:7882
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr ""
 
-#: cp/pt.c:7882
+#: cp/pt.c:7896
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr ""
 
-#: cp/pt.c:7885
+#: cp/pt.c:7899
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr ""
 
-#: cp/pt.c:7935
+#: cp/pt.c:7949
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr ""
 
-#: cp/pt.c:7949
+#: cp/pt.c:7963
 #, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.c:7952
+#: cp/pt.c:7966
 #, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr "  мало бути %qD, втім, маємо %qD"
 
-#: cp/pt.c:8012
+#: cp/pt.c:8026
 #, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr ""
 
-#: cp/pt.c:8149 cp/pt.c:8465
+#: cp/pt.c:8163 cp/pt.c:8479
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr ""
 
-#: cp/pt.c:8164 cp/pt.c:8298
+#: cp/pt.c:8178 cp/pt.c:8312
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr ""
 
-#: cp/pt.c:8294
+#: cp/pt.c:8308
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr ""
 
-#: cp/pt.c:8303
+#: cp/pt.c:8317
 #, gcc-internal-format
 msgid "provided for %qD"
 msgstr ""
 
-#: cp/pt.c:8328
+#: cp/pt.c:8342
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:8332
+#: cp/pt.c:8346
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr ""
 
-#: cp/pt.c:8431
+#: cp/pt.c:8445
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:9054
+#: cp/pt.c:9068
 #, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr ""
 
-#: cp/pt.c:9221
+#: cp/pt.c:9235
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr ""
 
-#: cp/pt.c:9223
+#: cp/pt.c:9237
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr ""
 
-#: cp/pt.c:9346
+#: cp/pt.c:9360
 #, gcc-internal-format
 msgid "template constraint failure"
 msgstr ""
 
-#: cp/pt.c:9697
+#: cp/pt.c:9718
 #, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr ""
 
-#: cp/pt.c:10125
+#: cp/pt.c:10148
 #, gcc-internal-format, gfc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:11202
+#: cp/pt.c:11225
 #, gcc-internal-format
 msgid "flexible array member %qD in union"
 msgstr ""
 
-#: cp/pt.c:11691
+#: cp/pt.c:11713
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:12160
+#: cp/pt.c:12182
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr ""
 
-#: cp/pt.c:12163
+#: cp/pt.c:12185
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr ""
 
-#: cp/pt.c:12747
+#: cp/pt.c:12769
 #, gcc-internal-format
 msgid "  when instantiating default argument for call to %qD"
 msgstr ""
@@ -47147,276 +47189,276 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:13708
+#: cp/pt.c:13730
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr ""
 
-#: cp/pt.c:13881
+#: cp/pt.c:13903
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr ""
 
-#: cp/pt.c:13883
+#: cp/pt.c:13905
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr ""
 
-#: cp/pt.c:14001
+#: cp/pt.c:14023
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr ""
 
-#: cp/pt.c:14003
+#: cp/pt.c:14025
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr ""
 
-#: cp/pt.c:14043
+#: cp/pt.c:14065
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr ""
 
-#: cp/pt.c:14637
+#: cp/pt.c:14659
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr ""
 
-#: cp/pt.c:14639
+#: cp/pt.c:14661
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr ""
 
-#: cp/pt.c:14641
+#: cp/pt.c:14663
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr ""
 
-#: cp/pt.c:14654
+#: cp/pt.c:14676
 #, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr ""
 
-#: cp/pt.c:14657
+#: cp/pt.c:14679
 #, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr ""
 
-#: cp/pt.c:14705
+#: cp/pt.c:14727
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr ""
 
-#: cp/pt.c:14711
+#: cp/pt.c:14733
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr ""
 
-#: cp/pt.c:14717
+#: cp/pt.c:14739
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr ""
 
-#: cp/pt.c:14783
+#: cp/pt.c:14805
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr ""
 
-#: cp/pt.c:14816
+#: cp/pt.c:14838
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr ""
 
-#: cp/pt.c:14853
+#: cp/pt.c:14875
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr ""
 
-#: cp/pt.c:14861
+#: cp/pt.c:14883
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr ""
 
-#: cp/pt.c:14925
+#: cp/pt.c:14947
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.c:15000
+#: cp/pt.c:15022
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr ""
 
-#: cp/pt.c:15178
+#: cp/pt.c:15200
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/pt.c:15193
+#: cp/pt.c:15215
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr ""
 
-#: cp/pt.c:15195
+#: cp/pt.c:15217
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr ""
 
-#: cp/pt.c:15394
+#: cp/pt.c:15416
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr ""
 
-#: cp/pt.c:15883 cp/pt.c:17386
+#: cp/pt.c:15905 cp/pt.c:17408
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr ""
 
-#: cp/pt.c:15887 cp/pt.c:17390
+#: cp/pt.c:15909 cp/pt.c:17412
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr ""
 
-#: cp/pt.c:18334
+#: cp/pt.c:18371
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:18362
+#: cp/pt.c:18399
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:18367
+#: cp/pt.c:18404
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "скористайтеся краще %<this->%D%>"
 
-#: cp/pt.c:18370
+#: cp/pt.c:18407
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "скористайтеся краще %<%T::%D%>"
 
-#: cp/pt.c:18375
+#: cp/pt.c:18412
 #, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr ""
 
-#: cp/pt.c:18712
+#: cp/pt.c:18752
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT не є класом або простором назв"
 
-#: cp/pt.c:18715
+#: cp/pt.c:18755
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD не є класом або простором назв"
 
-#: cp/pt.c:19026
+#: cp/pt.c:19066
 #, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr ""
 
-#: cp/pt.c:19028
+#: cp/pt.c:19068
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr ""
 
-#: cp/pt.c:19038
+#: cp/pt.c:19078
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT є змінним за змінними типом"
 
-#: cp/pt.c:19053
+#: cp/pt.c:19093
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "інтегральний вираз %qE не є сталою"
 
-#: cp/pt.c:19071
+#: cp/pt.c:19111
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr ""
 
-#: cp/pt.c:22972
+#: cp/pt.c:23050
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr ""
 
-#: cp/pt.c:22974
+#: cp/pt.c:23052
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr ""
 
-#: cp/pt.c:22980
+#: cp/pt.c:23058
 msgid "%s %#qS"
 msgstr "%s %#qS"
 
-#: cp/pt.c:23004 cp/pt.c:23091
+#: cp/pt.c:23082 cp/pt.c:23169
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr ""
 
-#: cp/pt.c:23023
+#: cp/pt.c:23101
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr ""
 
-#: cp/pt.c:23029 cp/pt.c:23086
+#: cp/pt.c:23107 cp/pt.c:23164
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr ""
 
-#: cp/pt.c:23034
+#: cp/pt.c:23112
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr ""
 
-#: cp/pt.c:23042
+#: cp/pt.c:23120
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr ""
 
-#: cp/pt.c:23078
+#: cp/pt.c:23156
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr ""
 
-#: cp/pt.c:23101 cp/pt.c:23187
+#: cp/pt.c:23179 cp/pt.c:23265
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr ""
 
-#: cp/pt.c:23106 cp/pt.c:23204
+#: cp/pt.c:23184 cp/pt.c:23282
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr ""
 
-#: cp/pt.c:23163
+#: cp/pt.c:23241
 #, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr ""
 
-#: cp/pt.c:23165
+#: cp/pt.c:23243
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr ""
 
-#: cp/pt.c:23174
+#: cp/pt.c:23252
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr ""
 
-#: cp/pt.c:23192
+#: cp/pt.c:23270
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr ""
 
-#: cp/pt.c:23238
+#: cp/pt.c:23316
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr ""
 
-#: cp/pt.c:23536
+#: cp/pt.c:23614
 #, gcc-internal-format
 msgid "exception specification of %qD depends on itself"
 msgstr "специфікація виключення %qD залежить від самої себе"
@@ -47428,107 +47470,107 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:23842
+#: cp/pt.c:23920
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr ""
 
-#: cp/pt.c:24043
+#: cp/pt.c:24121
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:24418
+#: cp/pt.c:24496
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "некоректний шаблон нетипізованого параметра"
 
-#: cp/pt.c:24420
+#: cp/pt.c:24498
 #, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr ""
 
-#: cp/pt.c:25723
+#: cp/pt.c:25802
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr ""
 
-#: cp/pt.c:25961
+#: cp/pt.c:26040
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/pt.c:26440
+#: cp/pt.c:26519
 #, gcc-internal-format
 msgid "non-class template %qT used without template arguments"
 msgstr ""
 
-#: cp/pt.c:26586
+#: cp/pt.c:26665
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:26593
+#: cp/pt.c:26672
 #, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr ""
 
-#: cp/pt.c:26607
+#: cp/pt.c:26686
 #, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr ""
 
-#: cp/pt.c:26614
+#: cp/pt.c:26693
 #, gcc-internal-format
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr ""
 
-#: cp/pt.c:26676
+#: cp/pt.c:26755
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:26679
+#: cp/pt.c:26758
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:26711
+#: cp/pt.c:26790
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/pt.c:26746
+#: cp/pt.c:26825
 #, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr ""
 
-#: cp/pt.c:26748
+#: cp/pt.c:26827
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "не вдалося вивести %qT з %qE"
 
-#: cp/pt.c:26781
+#: cp/pt.c:26860
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:26785
+#: cp/pt.c:26864
 #, gcc-internal-format
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.c:26789
+#: cp/pt.c:26868
 #, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.c:26793
+#: cp/pt.c:26872
 #, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.c:26912
+#: cp/pt.c:26991
 #, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr "некоректне використання %qT в аргументі шаблона"
@@ -47583,77 +47625,77 @@
 msgid "cannot dynamic_cast %qE (of type %q#T) to type %q#T (%s)"
 msgstr ""
 
-#: cp/search.c:240
+#: cp/search.c:243
 #, gcc-internal-format
 msgid "%qT is an ambiguous base of %qT"
 msgstr ""
 
-#: cp/search.c:256
+#: cp/search.c:259
 #, gcc-internal-format
 msgid "%qT is an inaccessible base of %qT"
 msgstr ""
 
-#: cp/search.c:1905
+#: cp/search.c:1908
 #, gcc-internal-format
 msgid "invalid covariant return type for %q#D"
 msgstr ""
 
-#: cp/search.c:1907 cp/search.c:1922 cp/search.c:1928 cp/search.c:1957
+#: cp/search.c:1910 cp/search.c:1925 cp/search.c:1931 cp/search.c:1960
 #, gcc-internal-format
 msgid "overridden function is %q#D"
 msgstr "перевизначеною функцією є %q#D"
 
-#: cp/search.c:1920
+#: cp/search.c:1923
 #, gcc-internal-format
 msgid "invalid covariant return type for %q+#D"
 msgstr ""
 
-#: cp/search.c:1926
+#: cp/search.c:1929
 #, gcc-internal-format
 msgid "conflicting return type specified for %q+#D"
 msgstr ""
 
-#: cp/search.c:1942
+#: cp/search.c:1945
 #, gcc-internal-format
 msgid "looser throw specifier for %q+#F"
 msgstr ""
 
-#: cp/search.c:1944
+#: cp/search.c:1947
 #, gcc-internal-format
 msgid "overridden function is %q#F"
 msgstr ""
 
-#: cp/search.c:1955
+#: cp/search.c:1958
 #, gcc-internal-format
 msgid "conflicting type attributes specified for %q+#D"
 msgstr ""
 
-#: cp/search.c:1972
+#: cp/search.c:1975
 #, gcc-internal-format
 msgid "%qD declared %<transaction_safe_dynamic%>"
 msgstr "%qD оголошено як %<transaction_safe_dynamic%>"
 
-#: cp/search.c:1974
+#: cp/search.c:1977
 #, gcc-internal-format
 msgid "overriding %qD declared %<transaction_safe%>"
 msgstr "перевизначаємо %qD, оголошене як %<transaction_safe%>"
 
-#: cp/search.c:1981
+#: cp/search.c:1984
 #, gcc-internal-format
 msgid "deleted function %q+D overriding non-deleted function"
 msgstr ""
 
-#: cp/search.c:1984 cp/search.c:1992 cp/search.c:2000
+#: cp/search.c:1987 cp/search.c:1995 cp/search.c:2003
 #, gcc-internal-format
 msgid "overridden function is %qD"
 msgstr "перевизначеною функцією є %qD"
 
-#: cp/search.c:1989
+#: cp/search.c:1992
 #, gcc-internal-format
 msgid "non-deleted function %q+D overriding deleted function"
 msgstr ""
 
-#: cp/search.c:1998
+#: cp/search.c:2001
 #, gcc-internal-format
 msgid "virtual function %q+D overriding final function"
 msgstr ""
@@ -47660,12 +47702,12 @@
 
 #. A static member function cannot match an inherited
 #. virtual member function.
-#: cp/search.c:2082
+#: cp/search.c:2085
 #, gcc-internal-format
 msgid "%q+#D cannot be declared"
 msgstr ""
 
-#: cp/search.c:2083
+#: cp/search.c:2086
 #, gcc-internal-format
 msgid "  since %q+#D declared in base class"
 msgstr ""
@@ -47705,576 +47747,591 @@
 msgid "invalid use of member %qD in static member function"
 msgstr ""
 
-#: cp/semantics.c:2153
+#: cp/semantics.c:2156
 #, gcc-internal-format
 msgid "a statement expression is an insufficient context for overload resolution"
 msgstr ""
 
-#: cp/semantics.c:2540
+#: cp/semantics.c:2543
 #, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr ""
 
-#: cp/semantics.c:2622
+#: cp/semantics.c:2625
 #, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr ""
 
-#: cp/semantics.c:2624
+#: cp/semantics.c:2627
 #, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr ""
 
-#: cp/semantics.c:2626
+#: cp/semantics.c:2629
 #, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr ""
 
-#: cp/semantics.c:2648
+#: cp/semantics.c:2651
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr ""
 
-#: cp/semantics.c:2656 cp/typeck.c:2604
+#: cp/semantics.c:2659 cp/typeck.c:2604
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/semantics.c:2678
+#: cp/semantics.c:2681
 #, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr ""
 
-#: cp/semantics.c:2751
+#: cp/semantics.c:2754
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr ""
 
-#: cp/semantics.c:2892
+#: cp/semantics.c:2895
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr ""
 
-#: cp/semantics.c:2942
+#: cp/semantics.c:2945
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr ""
 
-#: cp/semantics.c:2945
+#: cp/semantics.c:2948
 #, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr ""
 
-#: cp/semantics.c:2962
+#: cp/semantics.c:2965
 #, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr ""
 
-#: cp/semantics.c:2993
+#: cp/semantics.c:2996
 #, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr ""
 
-#: cp/semantics.c:3263
+#: cp/semantics.c:3266
 #, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr ""
 
-#: cp/semantics.c:3423
+#: cp/semantics.c:3426
 #, gcc-internal-format
 msgid "cannot capture member %qD of anonymous union"
 msgstr ""
 
-#: cp/semantics.c:3443 cp/semantics.c:9269
+#: cp/semantics.c:3446 cp/semantics.c:9272
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr ""
 
-#: cp/semantics.c:3448
+#: cp/semantics.c:3451
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.c:3450
+#: cp/semantics.c:3453
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.c:3462
+#: cp/semantics.c:3465
 #, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr ""
 
-#: cp/semantics.c:3464
+#: cp/semantics.c:3467
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr ""
 
-#: cp/semantics.c:3596
+#: cp/semantics.c:3599
 #, gcc-internal-format
 msgid "use of parameter outside function body"
 msgstr ""
 
-#: cp/semantics.c:3606
+#: cp/semantics.c:3609
 #, gcc-internal-format
 msgid "missing template arguments"
 msgstr "пропущено аргументи шаблона"
 
-#: cp/semantics.c:3633
+#: cp/semantics.c:3636
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr ""
 
-#: cp/semantics.c:3664
+#: cp/semantics.c:3667
 #, gcc-internal-format
 msgid "use of namespace %qD as expression"
 msgstr ""
 
-#: cp/semantics.c:3669
+#: cp/semantics.c:3672
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr ""
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:3675
+#: cp/semantics.c:3678
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr ""
 
-#: cp/semantics.c:3702
+#: cp/semantics.c:3705
 #, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/semantics.c:3841
+#: cp/semantics.c:3844
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr ""
 
-#: cp/semantics.c:3870
+#: cp/semantics.c:3873
 #, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr ""
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4009
+#: cp/semantics.c:4012
 #, gcc-internal-format
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr ""
 
-#: cp/semantics.c:4038
+#: cp/semantics.c:4041
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr ""
 
-#: cp/semantics.c:4052
+#: cp/semantics.c:4055
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr ""
 
-#: cp/semantics.c:4056
+#: cp/semantics.c:4059
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function"
 msgstr ""
 
-#: cp/semantics.c:4061
+#: cp/semantics.c:4064
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr ""
 
-#: cp/semantics.c:4072
+#: cp/semantics.c:4075
 #, gcc-internal-format
 msgid "offsetof within non-standard-layout type %qT is conditionally-supported"
 msgstr ""
 
-#: cp/semantics.c:4583 cp/semantics.c:6069 cp/semantics.c:6140
-#: cp/semantics.c:6183 cp/semantics.c:6533 cp/semantics.c:6632
-#: cp/semantics.c:6775
+#: cp/semantics.c:4586 cp/semantics.c:6072 cp/semantics.c:6143
+#: cp/semantics.c:6186 cp/semantics.c:6536 cp/semantics.c:6635
+#: cp/semantics.c:6778
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5271
+#: cp/semantics.c:5274
 #, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr ""
 
-#: cp/semantics.c:5544
+#: cp/semantics.c:5547
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: cp/semantics.c:5592
+#: cp/semantics.c:5595
 #, gcc-internal-format
 msgid "%qE has const type for %<reduction%>"
 msgstr ""
 
-#: cp/semantics.c:5707
+#: cp/semantics.c:5710
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:5941
+#: cp/semantics.c:5944
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5955
+#: cp/semantics.c:5958
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5977
+#: cp/semantics.c:5980
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6080
+#: cp/semantics.c:6083
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6152
+#: cp/semantics.c:6155
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr ""
 
-#: cp/semantics.c:6195
+#: cp/semantics.c:6198
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr ""
 
-#: cp/semantics.c:6240
+#: cp/semantics.c:6243
 #, gcc-internal-format
 msgid "%<gang%> static expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6254
+#: cp/semantics.c:6257
 #, gcc-internal-format
 msgid "%<gang%> static value must be positive"
 msgstr "статичне значення %<gang%> має бути додатним"
 
-#: cp/semantics.c:6288
+#: cp/semantics.c:6291
 #, gcc-internal-format
 msgid "%<gang%> num expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6291
+#: cp/semantics.c:6294
 #, gcc-internal-format
 msgid "%<vector%> length expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6295
+#: cp/semantics.c:6298
 #, gcc-internal-format
 msgid "%<worker%> num expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6317
+#: cp/semantics.c:6320
 #, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr "значення num %<gang%> має бути додатним"
 
-#: cp/semantics.c:6321
+#: cp/semantics.c:6324
 #, gcc-internal-format
 msgid "%<vector%> length value must be positive"
 msgstr "значення довжини %<vector%> має бути додатним"
 
-#: cp/semantics.c:6326
+#: cp/semantics.c:6329
 #, gcc-internal-format
 msgid "%<worker%> num value must be positive"
 msgstr "значення num %<worker%> має бути додатним"
 
-#: cp/semantics.c:6376
+#: cp/semantics.c:6379
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6406
+#: cp/semantics.c:6409
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6419
+#: cp/semantics.c:6422
 #, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr ""
 
-#: cp/semantics.c:6438
+#: cp/semantics.c:6441
 #, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6466
+#: cp/semantics.c:6469
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6495
+#: cp/semantics.c:6498
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr ""
 
-#: cp/semantics.c:6516
+#: cp/semantics.c:6519
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6543
+#: cp/semantics.c:6546
 #, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr ""
 
-#: cp/semantics.c:6557
+#: cp/semantics.c:6560
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:6563
+#: cp/semantics.c:6566
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: cp/semantics.c:6576
+#: cp/semantics.c:6579
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6625
+#: cp/semantics.c:6628
 #, gcc-internal-format
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr ""
 
-#: cp/semantics.c:6910
+#: cp/semantics.c:6913
 #, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6914
+#: cp/semantics.c:6917
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6979
+#: cp/semantics.c:6982
 #, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7008
+#: cp/semantics.c:7011
 #, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7037
+#: cp/semantics.c:7040
 #, gcc-internal-format
 msgid "%<num_tasks%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7066
+#: cp/semantics.c:7069
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:7105
+#: cp/semantics.c:7108
 #, gcc-internal-format
 msgid "%<tile%> argument needs integral type"
 msgstr ""
 
-#: cp/semantics.c:7524
+#: cp/semantics.c:7527
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.c:7538
+#: cp/semantics.c:7541
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr ""
 
-#: cp/semantics.c:7743
+#: cp/semantics.c:7746
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.c:8171
+#: cp/semantics.c:8174
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.c:8398 cp/semantics.c:8408
+#: cp/semantics.c:8401 cp/semantics.c:8411
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.c:8702
+#: cp/semantics.c:8705
 #, gcc-internal-format
 msgid "static assertion failed"
 msgstr ""
 
-#: cp/semantics.c:8704
+#: cp/semantics.c:8707
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr ""
 
-#: cp/semantics.c:8709
+#: cp/semantics.c:8712
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr ""
 
-#: cp/semantics.c:8739
+#: cp/semantics.c:8742
 #, gcc-internal-format
 msgid "argument to decltype must be an expression"
 msgstr ""
 
-#: cp/semantics.c:8767
+#: cp/semantics.c:8770
 #, gcc-internal-format
 msgid "decltype cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/semantics.c:9308
+#: cp/semantics.c:9311
 #, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.c:9361
+#: cp/semantics.c:9364
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.c:9363
+#: cp/semantics.c:9366
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:9381
+#: cp/semantics.c:9384
 #, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "аргумент, який не є вказівником, у %<__builtin_launder%>"
 
-#: cp/tree.c:1276
+#: cp/tree.c:1295
 #, gcc-internal-format
 msgid "%qV qualifiers cannot be applied to %qT"
 msgstr ""
 
-#: cp/tree.c:1788
+#: cp/tree.c:1807
 #, gcc-internal-format
 msgid "lambda-expression in a constant expression"
 msgstr ""
 
-#: cp/tree.c:1792
+#: cp/tree.c:1811
 #, gcc-internal-format
 msgid "statement-expression in a constant expression"
 msgstr "інструкція-вираз не є сталим виразом"
 
-#: cp/tree.c:4050
+#: cp/tree.c:4083
 #, gcc-internal-format
-msgid "the calling convention for %qT changes in -fabi-version=12 (GCC 8)"
+msgid "-fabi-version=13 (GCC 8.2) fixes the calling convention for %qT, which was accidentally changed in 8.1"
 msgstr ""
 
-#: cp/tree.c:4055
+#: cp/tree.c:4087
 #, gcc-internal-format
+msgid "-fabi-version=12 (GCC 8.1) accidentally changes the calling convention for %qT"
+msgstr ""
+
+#: cp/tree.c:4090
+#, gcc-internal-format
+msgid " declared here"
+msgstr " оголошено тут"
+
+#: cp/tree.c:4094
+#, gcc-internal-format
+msgid "the calling convention for %qT changes in -fabi-version=13 (GCC 8.2)"
+msgstr ""
+
+#: cp/tree.c:4096
+#, gcc-internal-format
 msgid " because all of its copy and move constructors are deleted"
 msgstr ""
 
-#: cp/tree.c:4416
+#: cp/tree.c:4464
 #, gcc-internal-format
 msgid "%qE attribute applied to %qD with void return type"
 msgstr ""
 
-#: cp/tree.c:4423
+#: cp/tree.c:4471
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr ""
 
-#: cp/tree.c:4475
+#: cp/tree.c:4523
 #, gcc-internal-format
 msgid "requested init_priority is not an integer constant"
 msgstr ""
 
-#: cp/tree.c:4497
+#: cp/tree.c:4545
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr ""
 
-#: cp/tree.c:4505
+#: cp/tree.c:4553
 #, gcc-internal-format
 msgid "requested init_priority is out of range"
 msgstr ""
 
-#: cp/tree.c:4515
+#: cp/tree.c:4563
 #, gcc-internal-format
 msgid "requested init_priority is reserved for internal use"
 msgstr ""
 
-#: cp/tree.c:4526
+#: cp/tree.c:4574
 #, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr ""
 
-#: cp/tree.c:4553
+#: cp/tree.c:4601
 #, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %qE"
 msgstr "повторне оголошення %qD додає мітку abi %qE"
 
-#: cp/tree.c:4573
+#: cp/tree.c:4621
 #, gcc-internal-format
 msgid "the %qE attribute requires arguments"
 msgstr ""
 
-#: cp/tree.c:4584
+#: cp/tree.c:4632
 #, gcc-internal-format
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr ""
 
-#: cp/tree.c:4597 cp/tree.c:4610
+#: cp/tree.c:4645 cp/tree.c:4658
 #, gcc-internal-format
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr ""
 
-#: cp/tree.c:4599
+#: cp/tree.c:4647
 #, gcc-internal-format
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr ""
 
-#: cp/tree.c:4612
+#: cp/tree.c:4660
 #, gcc-internal-format
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr ""
 
-#: cp/tree.c:4636
+#: cp/tree.c:4684
 #, gcc-internal-format
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr ""
 
-#: cp/tree.c:4642
+#: cp/tree.c:4690
 #, gcc-internal-format
 msgid "%qE attribute applied to %qT after its definition"
 msgstr ""
 
-#: cp/tree.c:4649
+#: cp/tree.c:4697
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr ""
 
-#: cp/tree.c:4656
+#: cp/tree.c:4704
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr ""
 
-#: cp/tree.c:4678
+#: cp/tree.c:4726
 #, gcc-internal-format
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr ""
 
-#: cp/tree.c:4684
+#: cp/tree.c:4732
 #, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr ""
 
-#: cp/tree.c:5440
+#: cp/tree.c:5488
 #, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr ""
 
-#: cp/tree.c:5453
+#: cp/tree.c:5501
 #, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr ""
@@ -49358,107 +49415,107 @@
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr ""
 
-#: cp/typeck2.c:1496 cp/typeck2.c:1523
+#: cp/typeck2.c:1499 cp/typeck2.c:1526
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr ""
 
-#: cp/typeck2.c:1504
+#: cp/typeck2.c:1507
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr ""
 
-#: cp/typeck2.c:1511
+#: cp/typeck2.c:1514
 #, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr ""
 
-#: cp/typeck2.c:1587
+#: cp/typeck2.c:1590
 #, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr ""
 
-#: cp/typeck2.c:1660
+#: cp/typeck2.c:1663
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr ""
 
-#: cp/typeck2.c:1671
+#: cp/typeck2.c:1674
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr ""
 
-#: cp/typeck2.c:1858
+#: cp/typeck2.c:1861
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr ""
 
-#: cp/typeck2.c:1872
+#: cp/typeck2.c:1875
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr ""
 
-#: cp/typeck2.c:1898
+#: cp/typeck2.c:1901
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr ""
 
-#: cp/typeck2.c:1900
+#: cp/typeck2.c:1903
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr ""
 
-#: cp/typeck2.c:1927
+#: cp/typeck2.c:1930
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr ""
 
-#: cp/typeck2.c:1936
+#: cp/typeck2.c:1939
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr ""
 
-#: cp/typeck2.c:1958
+#: cp/typeck2.c:1961
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2018
+#: cp/typeck2.c:2021
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr ""
 
-#: cp/typeck2.c:2029
+#: cp/typeck2.c:2032
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr ""
 
-#: cp/typeck2.c:2037
+#: cp/typeck2.c:2040
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++2a"
 msgstr ""
 
-#: cp/typeck2.c:2080
+#: cp/typeck2.c:2083
 #, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2096
+#: cp/typeck2.c:2099
 #, gcc-internal-format
 msgid "cannot deduce template arguments for %qT from ()"
 msgstr ""
 
-#: cp/typeck2.c:2114
+#: cp/typeck2.c:2117
 #, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr ""
 
-#: cp/typeck2.c:2341
+#: cp/typeck2.c:2344
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr ""
 
-#: cp/typeck2.c:2344
+#: cp/typeck2.c:2347
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr ""
@@ -49673,11 +49730,11 @@
 msgstr ""
 
 #: fortran/array.c:221 fortran/array.c:661 fortran/check.c:2849
-#: fortran/check.c:5222 fortran/check.c:5260 fortran/check.c:5302
-#: fortran/check.c:5329 fortran/check.c:5529 fortran/match.c:1821
+#: fortran/check.c:5225 fortran/check.c:5263 fortran/check.c:5305
+#: fortran/check.c:5332 fortran/check.c:5532 fortran/match.c:1821
 #: fortran/match.c:3174 fortran/match.c:3516 fortran/match.c:3712
-#: fortran/simplify.c:2909 fortran/simplify.c:2939 fortran/simplify.c:5764
-#: fortran/simplify.c:7658
+#: fortran/simplify.c:2909 fortran/simplify.c:2939 fortran/simplify.c:5769
+#: fortran/simplify.c:7663
 #, gcc-internal-format
 msgid "Coarrays disabled at %C, use %<-fcoarray=%> to enable"
 msgstr ""
@@ -49812,118 +49869,123 @@
 msgid "DO-iterator %qs at %L is inside iterator of the same name"
 msgstr ""
 
-#: fortran/array.c:1073 fortran/array.c:1255
+#: fortran/array.c:1073 fortran/array.c:1264
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in array constructor at %C"
 msgstr ""
 
-#: fortran/array.c:1129
+#: fortran/array.c:1105
 #, gcc-internal-format, gfc-internal-format
+msgid "NULL() at %C cannot appear in an array constructor"
+msgstr ""
+
+#: fortran/array.c:1138
+#, gcc-internal-format, gfc-internal-format
 msgid "[...] style array constructors at %C"
 msgstr ""
 
-#: fortran/array.c:1149
+#: fortran/array.c:1158
 #, gcc-internal-format, gfc-internal-format
 msgid "Array constructor including type specification at %C"
 msgstr ""
 
-#: fortran/array.c:1155 fortran/match.c:4148
+#: fortran/array.c:1164 fortran/match.c:4148
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-spec at %L cannot contain a deferred type parameter"
 msgstr ""
 
-#: fortran/array.c:1163
+#: fortran/array.c:1172
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-spec at %L cannot contain an asterisk for a type parameter"
 msgstr ""
 
-#: fortran/array.c:1181
+#: fortran/array.c:1190
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty array constructor at %C is not allowed"
 msgstr ""
 
-#: fortran/array.c:1218 fortran/array.c:1228
+#: fortran/array.c:1227 fortran/array.c:1237
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible typespec for array element at %L"
 msgstr ""
 
-#: fortran/array.c:1302
+#: fortran/array.c:1311
 #, gcc-internal-format, gfc-internal-format
 msgid "Element in %s array constructor at %L is %s"
 msgstr ""
 
-#: fortran/array.c:1633
+#: fortran/array.c:1642
 #, gcc-internal-format, gfc-internal-format
 msgid "Iterator step at %L cannot be zero"
 msgstr ""
 
-#: fortran/array.c:1770
+#: fortran/array.c:1779
 #, gcc-internal-format
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit.   See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/array.c:1940
+#: fortran/array.c:1949
 #, gcc-internal-format, gfc-internal-format
 msgid "AC-IMPLIED-DO initial expression references control variable at %L"
 msgstr ""
 
-#: fortran/array.c:1947
+#: fortran/array.c:1956
 #, gcc-internal-format, gfc-internal-format
 msgid "AC-IMPLIED-DO final expression references control variable at %L"
 msgstr ""
 
-#: fortran/array.c:1954
+#: fortran/array.c:1963
 #, gcc-internal-format, gfc-internal-format
 msgid "AC-IMPLIED-DO step expression references control variable at %L"
 msgstr ""
 
-#: fortran/array.c:1966
+#: fortran/array.c:1975
 #, gcc-internal-format, gfc-internal-format
 msgid "Array constructor value at %L shall not be unlimited polymorphic [F2008: C4106]"
 msgstr ""
 
-#: fortran/array.c:2055
+#: fortran/array.c:2067
 #, gcc-internal-format, gfc-internal-format
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor at %L"
 msgstr ""
 
-#: fortran/array.c:2174
+#: fortran/array.c:2186
 #, gcc-internal-format
 msgid "spec_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2233
+#: fortran/array.c:2245
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2237
+#: fortran/array.c:2249
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array dimension at %L"
 msgstr ""
 
-#: fortran/array.c:2264 fortran/data.c:552 fortran/data.c:571
-#: fortran/data.c:585 fortran/data.c:714
+#: fortran/array.c:2276 fortran/data.c:563 fortran/data.c:582
+#: fortran/data.c:596 fortran/data.c:725
 #, gcc-internal-format
 msgid "Simplification error"
 msgstr ""
 
-#: fortran/array.c:2376
+#: fortran/array.c:2388
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimen_type"
 msgstr ""
 
-#: fortran/array.c:2427
+#: fortran/array.c:2439
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2472
+#: fortran/array.c:2484
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad EXPR_ARRAY expr"
 msgstr ""
 
-#: fortran/array.c:2620
+#: fortran/array.c:2632
 #, gcc-internal-format
 msgid "gfc_find_array_ref(): No ref found"
 msgstr ""
@@ -49974,7 +50036,7 @@
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or PROCEDURE"
 msgstr ""
 
-#: fortran/check.c:205 fortran/check.c:6658
+#: fortran/check.c:205 fortran/check.c:6661
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a constant"
 msgstr ""
@@ -50089,7 +50151,7 @@
 msgid "Unequal character lengths (%ld/%ld) in %s at %L"
 msgstr ""
 
-#: fortran/check.c:946 fortran/check.c:6602
+#: fortran/check.c:946 fortran/check.c:6605
 #, gcc-internal-format
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have the same type"
 msgstr ""
@@ -50324,9 +50386,9 @@
 msgstr ""
 
 #: fortran/check.c:1939 fortran/check.c:2525 fortran/check.c:2628
-#: fortran/check.c:2835 fortran/check.c:2880 fortran/check.c:4256
-#: fortran/check.c:4390 fortran/check.c:4445 fortran/check.c:5515
-#: fortran/check.c:5644
+#: fortran/check.c:2835 fortran/check.c:2880 fortran/check.c:4259
+#: fortran/check.c:4393 fortran/check.c:4448 fortran/check.c:5518
+#: fortran/check.c:5647
 #, gcc-internal-format
 msgid "%qs intrinsic with KIND argument at %L"
 msgstr ""
@@ -50521,7 +50583,7 @@
 msgid "NULL intrinsic with allocatable MOLD at %L"
 msgstr ""
 
-#: fortran/check.c:3768 fortran/check.c:5591
+#: fortran/check.c:3768 fortran/check.c:5594
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must provide at least as many elements as there are .TRUE. values in %qs (%ld/%d)"
 msgstr ""
@@ -50541,372 +50603,372 @@
 msgid "%qs argument of %qs intrinsic at %L must not be a subobject of %qs"
 msgstr ""
 
-#: fortran/check.c:3901
+#: fortran/check.c:3904
 #, gcc-internal-format, gfc-internal-format
 msgid "The argument of the RANK intrinsic at %L must be a data object"
 msgstr ""
 
-#: fortran/check.c:4005
+#: fortran/check.c:4008
 #, gcc-internal-format
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L must be an array of constant size"
 msgstr ""
 
-#: fortran/check.c:4015
+#: fortran/check.c:4018
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L is empty"
 msgstr ""
 
-#: fortran/check.c:4022
+#: fortran/check.c:4025
 #, gcc-internal-format
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L has more than %d elements"
 msgstr ""
 
-#: fortran/check.c:4039
+#: fortran/check.c:4042
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has negative element (%d)"
 msgstr ""
 
-#: fortran/check.c:4071
+#: fortran/check.c:4074
 #, gcc-internal-format, gfc-internal-format
 msgid "Element %d of actual argument of RESHAPE at %L cannot be negative"
 msgstr ""
 
-#: fortran/check.c:4109
+#: fortran/check.c:4112
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has wrong number of elements (%d/%d)"
 msgstr ""
 
-#: fortran/check.c:4127
+#: fortran/check.c:4130
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has out-of-range dimension (%d)"
 msgstr ""
 
-#: fortran/check.c:4136
+#: fortran/check.c:4139
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has invalid permutation of dimensions (dimension %qd duplicated)"
 msgstr ""
 
-#: fortran/check.c:4172
+#: fortran/check.c:4175
 #, gcc-internal-format, gfc-internal-format
 msgid "Without padding, there are not enough elements in the intrinsic RESHAPE source at %L to match the shape"
 msgstr ""
 
-#: fortran/check.c:4189 fortran/check.c:4208
+#: fortran/check.c:4192 fortran/check.c:4211
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L cannot be of type %s"
 msgstr ""
 
-#: fortran/check.c:4199 fortran/check.c:4218
+#: fortran/check.c:4202 fortran/check.c:4221
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of an extensible type"
 msgstr ""
 
-#: fortran/check.c:4317
+#: fortran/check.c:4320
 #, gcc-internal-format
 msgid "SELECTED_REAL_KIND with neither %<P%> nor %<R%> argument at %L"
 msgstr ""
 
-#: fortran/check.c:4348
+#: fortran/check.c:4351
 #, gcc-internal-format
 msgid "%qs intrinsic with RADIX argument at %L"
 msgstr ""
 
-#: fortran/check.c:4383
+#: fortran/check.c:4386
 #, gcc-internal-format
 msgid "%<source%> argument of %<shape%> intrinsic at %L must not be an assumed size array"
 msgstr ""
 
-#: fortran/check.c:4460 fortran/check.c:6641
+#: fortran/check.c:4463 fortran/check.c:6644
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be a procedure"
 msgstr ""
 
-#: fortran/check.c:4473 fortran/check.c:4612 fortran/check.c:6633
+#: fortran/check.c:4476 fortran/check.c:4615 fortran/check.c:6636
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be TYPE(*)"
 msgstr ""
 
-#: fortran/check.c:4484 fortran/check.c:4624
+#: fortran/check.c:4487 fortran/check.c:4627
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be an assumed-size array"
 msgstr ""
 
-#: fortran/check.c:4554
+#: fortran/check.c:4557
 #, gcc-internal-format
 msgid "is_c_interoperable(): gfc_simplify_expr failed"
 msgstr ""
 
-#: fortran/check.c:4603
+#: fortran/check.c:4606
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be an interoperable data entity: %s"
 msgstr ""
 
-#: fortran/check.c:4642
+#: fortran/check.c:4645
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_1 at %L to C_ASSOCIATED shall have the type TYPE(C_PTR) or TYPE(C_FUNPTR)"
 msgstr ""
 
-#: fortran/check.c:4656
+#: fortran/check.c:4659
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_2 at %L to C_ASSOCIATED shall have the same type as C_PTR_1: %s instead of %s"
 msgstr ""
 
-#: fortran/check.c:4680
+#: fortran/check.c:4683
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_POINTER shall have the type TYPE(C_PTR)"
 msgstr ""
 
-#: fortran/check.c:4692
+#: fortran/check.c:4695
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER must be a pointer"
 msgstr ""
 
-#: fortran/check.c:4699
+#: fortran/check.c:4702
 #, gcc-internal-format, gfc-internal-format
 msgid "FPTR argument at %L to C_F_POINTER shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:4706
+#: fortran/check.c:4709
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:4713
+#: fortran/check.c:4716
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected SHAPE argument at %L to C_F_POINTER with scalar FPTR"
 msgstr ""
 
-#: fortran/check.c:4719
+#: fortran/check.c:4722
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected SHAPE argument to C_F_POINTER with array FPTR at %L"
 msgstr ""
 
-#: fortran/check.c:4738
+#: fortran/check.c:4741
 #, gcc-internal-format, gfc-internal-format
 msgid "SHAPE argument at %L to C_F_POINTER must have the same size as the RANK of FPTR"
 msgstr ""
 
-#: fortran/check.c:4748
+#: fortran/check.c:4751
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic FPTR at %L to C_F_POINTER"
 msgstr ""
 
-#: fortran/check.c:4753
+#: fortran/check.c:4756
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array FPTR at %L to C_F_POINTER: %s"
 msgstr ""
 
-#: fortran/check.c:4769
+#: fortran/check.c:4772
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_PROCPOINTER shall have the type TYPE(C_FUNPTR)"
 msgstr ""
 
-#: fortran/check.c:4781
+#: fortran/check.c:4784
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall be a procedure pointer"
 msgstr ""
 
-#: fortran/check.c:4788
+#: fortran/check.c:4791
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:4794
+#: fortran/check.c:4797
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure pointer at %L to C_F_PROCPOINTER"
 msgstr ""
 
-#: fortran/check.c:4808
+#: fortran/check.c:4811
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:4823
+#: fortran/check.c:4826
 #, gcc-internal-format
 msgid "Function result %qs at %L is invalid as X argument to C_FUNLOC"
 msgstr ""
 
-#: fortran/check.c:4831
+#: fortran/check.c:4834
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall be a procedure or a procedure pointer"
 msgstr ""
 
-#: fortran/check.c:4837
+#: fortran/check.c:4840
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure at %L to C_FUNLOC"
 msgstr ""
 
-#: fortran/check.c:4851
+#: fortran/check.c:4854
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:4857
+#: fortran/check.c:4860
 #, gcc-internal-format, gfc-internal-format
 msgid "X argument at %L to C_LOC shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:4868
+#: fortran/check.c:4871
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall have either the POINTER or the TARGET attribute"
 msgstr ""
 
-#: fortran/check.c:4876
+#: fortran/check.c:4879
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall be not be a zero-sized string"
 msgstr ""
 
-#: fortran/check.c:4885
+#: fortran/check.c:4888
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument at %L to C_LOC shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:4892
+#: fortran/check.c:4895
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array at %L as argument to C_LOC: %s"
 msgstr ""
 
-#: fortran/check.c:4903
+#: fortran/check.c:4906
 #, gcc-internal-format, gfc-internal-format
 msgid "Array of interoperable type at %L to C_LOC which is nonallocatable and neither assumed size nor explicit size"
 msgstr ""
 
-#: fortran/check.c:4908
+#: fortran/check.c:4911
 #, gcc-internal-format, gfc-internal-format
 msgid "Array section at %L to C_LOC"
 msgstr ""
 
-#: fortran/check.c:4936
+#: fortran/check.c:4939
 #, gcc-internal-format, gfc-internal-format
 msgid "non double precision REAL argument to %s intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:4949
+#: fortran/check.c:4952
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be less than rank %d"
 msgstr ""
 
-#: fortran/check.c:4968
+#: fortran/check.c:4971
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L is not a valid dimension index"
 msgstr ""
 
-#: fortran/check.c:5231
+#: fortran/check.c:5234
 #, gcc-internal-format, gfc-internal-format
 msgid "%s argument to IMAGE_INDEX must be a rank one array at %L"
 msgstr ""
 
-#: fortran/check.c:5242
+#: fortran/check.c:5245
 #, gcc-internal-format, gfc-internal-format
 msgid "The number of array elements of the SUB argument to IMAGE_INDEX at %L shall be %d (corank) not %d"
 msgstr ""
 
-#: fortran/check.c:5275
+#: fortran/check.c:5278
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to NUM_IMAGES at %L"
 msgstr ""
 
-#: fortran/check.c:5288
+#: fortran/check.c:5291
 #, gcc-internal-format, gfc-internal-format
 msgid "FAILED= argument to NUM_IMAGES at %L"
 msgstr ""
 
-#: fortran/check.c:5312
+#: fortran/check.c:5315
 #, gcc-internal-format, gfc-internal-format
 msgid "TEAM argument at %L to the intrinsic TEAM_NUMBER shall be of type TEAM_TYPE"
 msgstr ""
 
-#: fortran/check.c:5338
+#: fortran/check.c:5341
 #, gcc-internal-format, gfc-internal-format
 msgid "DIM argument without COARRAY argument not allowed for THIS_IMAGE intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:5345
+#: fortran/check.c:5348
 #, gcc-internal-format, gfc-internal-format
 msgid "The DISTANCE argument may not be specified together with the COARRAY or DIM argument in intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:5356
+#: fortran/check.c:5359
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected DIM argument with noncoarray argument at %L"
 msgstr ""
 
-#: fortran/check.c:5374
+#: fortran/check.c:5377
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to THIS_IMAGE at %L"
 msgstr ""
 
-#: fortran/check.c:5454
+#: fortran/check.c:5457
 #, gcc-internal-format
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L must not be %s"
 msgstr ""
 
-#: fortran/check.c:5483
+#: fortran/check.c:5486
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic TRANSFER at %L has partly undefined result: source size %ld < result size %ld"
 msgstr ""
 
-#: fortran/check.c:5605
+#: fortran/check.c:5608
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must have the same rank as %qs or be a scalar"
 msgstr ""
 
-#: fortran/check.c:5618
+#: fortran/check.c:5621
 #, gcc-internal-format
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have identical shape."
 msgstr ""
 
-#: fortran/check.c:5861 fortran/check.c:5893
+#: fortran/check.c:5864 fortran/check.c:5896
 #, gcc-internal-format
 msgid "Size of %qs argument of %qs intrinsic at %L too small (%i/%i)"
 msgstr ""
 
-#: fortran/check.c:5901
+#: fortran/check.c:5904
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many arguments to %s at %L"
 msgstr ""
 
-#: fortran/check.c:5919
+#: fortran/check.c:5922
 #, gcc-internal-format
 msgid "fe_runtime_error string must be null terminated"
 msgstr ""
 
-#: fortran/check.c:5931
+#: fortran/check.c:5934
 #, gcc-internal-format, gfc-internal-format
 msgid "fe_runtime_error: Wrong number of arguments (%d instead of %d)"
 msgstr ""
 
-#: fortran/check.c:5971
+#: fortran/check.c:5974
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:5990
+#: fortran/check.c:5993
 #, gcc-internal-format, gfc-internal-format
 msgid "Real COUNT_RATE argument to SYSTEM_CLOCK at %L"
 msgstr ""
 
-#: fortran/check.c:6000
+#: fortran/check.c:6003
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT_RATE argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:6017
+#: fortran/check.c:6020
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT_MAX argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:6234
+#: fortran/check.c:6237
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of a kind not wider than the default kind (%d)"
 msgstr ""
 
-#: fortran/check.c:6586 fortran/check.c:6594
+#: fortran/check.c:6589 fortran/check.c:6597
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or LOGICAL"
 msgstr ""
 
-#: fortran/check.c:6625
+#: fortran/check.c:6628
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic function NULL at %L cannot be an actual argument to STORAGE_SIZE, because it returns a disassociated pointer"
 msgstr ""
@@ -50918,7 +50980,7 @@
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:727 fortran/decl.c:3636 fortran/decl.c:10066
+#: fortran/class.c:727 fortran/decl.c:3655 fortran/decl.c:10091
 #, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr ""
@@ -50943,43 +51005,48 @@
 msgid "non-constant array in DATA statement %L"
 msgstr ""
 
-#: fortran/data.c:137
+#: fortran/data.c:140
 #, gcc-internal-format, gfc-internal-format
 msgid "failure to simplify substring reference in DATA statement at %L"
 msgstr ""
 
-#: fortran/data.c:170
+#: fortran/data.c:173
 #, gcc-internal-format, gfc-internal-format
 msgid "Unused initialization string at %L because variable has zero length"
 msgstr ""
 
-#: fortran/data.c:176
+#: fortran/data.c:179
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization string at %L was truncated to fit the variable (%ld/%ld)"
 msgstr ""
 
-#: fortran/data.c:265
+#: fortran/data.c:268
 #, gcc-internal-format
 msgid "%qs at %L already is initialized at %L"
 msgstr ""
 
-#: fortran/data.c:289
+#: fortran/data.c:292
 #, gcc-internal-format, gfc-internal-format
 msgid "Data element below array lower bound at %L"
 msgstr ""
 
-#: fortran/data.c:306 fortran/data.c:395
+#: fortran/data.c:309 fortran/data.c:398
 #, gcc-internal-format, gfc-internal-format
 msgid "Data element above array upper bound at %L"
 msgstr ""
 
-#: fortran/data.c:336 fortran/data.c:505
+#: fortran/data.c:339 fortran/data.c:496
 #, gcc-internal-format
 msgid "re-initialization of %qs at %L"
 msgstr ""
 
-#: fortran/data.c:727
+#: fortran/data.c:515
 #, gcc-internal-format
+msgid "Nonpointer object %qs with default initialization shall not appear in a DATA statement at %L"
+msgstr ""
+
+#: fortran/data.c:738
+#, gcc-internal-format
 msgid "TODO: Vector sections in data statements"
 msgstr ""
 
@@ -51003,784 +51070,784 @@
 msgid "Invalid initializer %s in Data statement at %C"
 msgstr ""
 
-#: fortran/decl.c:536
+#: fortran/decl.c:537
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:573
+#: fortran/decl.c:574
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %C cannot appear within an INTERFACE"
 msgstr ""
 
-#: fortran/decl.c:597
+#: fortran/decl.c:598
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid substring in data-implied-do at %L in DATA statement"
 msgstr ""
 
-#: fortran/decl.c:619
+#: fortran/decl.c:620
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:664
+#: fortran/decl.c:662
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty old style initializer list at %C"
 msgstr ""
 
-#: fortran/decl.c:684
+#: fortran/decl.c:671
 #, gcc-internal-format, gfc-internal-format
+msgid "Array in initializer list at %L must have an explicit shape"
+msgstr ""
+
+#: fortran/decl.c:694
+#, gcc-internal-format, gfc-internal-format
 msgid "Repeat spec invalid in scalar initializer at %C"
 msgstr ""
 
-#: fortran/decl.c:689
+#: fortran/decl.c:699
 #, gcc-internal-format, gfc-internal-format
 msgid "Repeat spec must be an integer at %C"
 msgstr ""
 
-#: fortran/decl.c:698
+#: fortran/decl.c:710
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected data constant after repeat spec at %C"
 msgstr ""
 
-#: fortran/decl.c:729
+#: fortran/decl.c:742
 #, gcc-internal-format, gfc-internal-format
 msgid "End of scalar initializer expected at %C"
 msgstr ""
 
-#: fortran/decl.c:758
+#: fortran/decl.c:773
 #, gcc-internal-format, gfc-internal-format
-msgid "Expected constant array-spec in initializer list at %L"
-msgstr ""
-
-#: fortran/decl.c:767
-#, gcc-internal-format, gfc-internal-format
 msgid "Not enough elements in array initializer at %C"
 msgstr ""
 
-#: fortran/decl.c:769
+#: fortran/decl.c:775
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many elements in array initializer at %C"
 msgstr ""
 
-#: fortran/decl.c:790
+#: fortran/decl.c:795
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in old style initializer list at %C"
 msgstr "Синтаксична помилка у списку ініціалізатора у старому стилі у %C"
 
-#: fortran/decl.c:812
+#: fortran/decl.c:821
 #, gcc-internal-format, gfc-internal-format
 msgid "The assumed-rank array at %C shall not have a codimension"
 msgstr ""
 
-#: fortran/decl.c:876
+#: fortran/decl.c:885
 #, gcc-internal-format, gfc-internal-format
 msgid "Sum of array rank %d and corank %d at %C exceeds maximum allowed dimensions of %d"
 msgstr ""
 
-#: fortran/decl.c:900
+#: fortran/decl.c:909
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad INTENT specification at %C"
 msgstr ""
 
-#: fortran/decl.c:921
+#: fortran/decl.c:930
 #, gcc-internal-format, gfc-internal-format
 msgid "deferred type parameter at %C"
 msgstr ""
 
-#: fortran/decl.c:1004 fortran/resolve.c:11705
+#: fortran/decl.c:1013 fortran/resolve.c:11725
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
 
-#: fortran/decl.c:1030
+#: fortran/decl.c:1039
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style character length at %C"
 msgstr ""
 
-#: fortran/decl.c:1061
+#: fortran/decl.c:1070
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in character length specification at %C"
 msgstr ""
 
-#: fortran/decl.c:1212 fortran/decl.c:1217 fortran/decl.c:1266
+#: fortran/decl.c:1221 fortran/decl.c:1226 fortran/decl.c:1275
 #, gcc-internal-format
 msgid "Procedure %qs at %C is already defined at %L"
 msgstr ""
 
-#: fortran/decl.c:1222
+#: fortran/decl.c:1231
 #, gcc-internal-format
 msgid "Contained procedure %qs at %C clashes with procedure defined at %L"
 msgstr ""
 
-#: fortran/decl.c:1231
+#: fortran/decl.c:1240
 #, gcc-internal-format
 msgid "Name %qs at %C is already defined as a generic interface at %L"
 msgstr ""
 
-#: fortran/decl.c:1244
+#: fortran/decl.c:1253
 #, gcc-internal-format
 msgid "Procedure %qs at %C has an explicit interface from a previous declaration"
 msgstr "Процедура %qs у %C є явним інтерфейсом з попереднього оголошення"
 
-#: fortran/decl.c:1257
+#: fortran/decl.c:1266
 #, gcc-internal-format
 msgid "Procedure %qs defined in interface body at %L clashes with internal procedure defined at %C"
 msgstr ""
 
-#: fortran/decl.c:1335
+#: fortran/decl.c:1344
 #, gcc-internal-format
 msgid "Procedure %qs at %L must have the BIND(C) attribute to be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:1362
+#: fortran/decl.c:1371
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because derived type %qs is not C interoperable"
 msgstr ""
 
-#: fortran/decl.c:1369
+#: fortran/decl.c:1378
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because it is polymorphic"
 msgstr ""
 
-#: fortran/decl.c:1376
+#: fortran/decl.c:1385
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument of the BIND(C) procedure %qs but may not be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:1391
+#: fortran/decl.c:1400
 #, gcc-internal-format
 msgid "Character argument %qs at %L must be length 1 because procedure %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1404
+#: fortran/decl.c:1413
 #, gcc-internal-format
 msgid "Variable %qs at %L with ALLOCATABLE attribute in procedure %qs with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1412
+#: fortran/decl.c:1421
 #, gcc-internal-format
 msgid "Variable %qs at %L with POINTER attribute in procedure %qs with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1421
+#: fortran/decl.c:1430
 #, gcc-internal-format
 msgid "Scalar variable %qs at %L with POINTER or ALLOCATABLE in procedure %qs with BIND(C) is not yet supported"
 msgstr ""
 
-#: fortran/decl.c:1430
+#: fortran/decl.c:1439
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the OPTIONAL and the VALUE attribute because procedure %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1437
+#: fortran/decl.c:1446
 #, gcc-internal-format
 msgid "Variable %qs at %L with OPTIONAL attribute in procedure %qs which is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1448
+#: fortran/decl.c:1457
 #, gcc-internal-format
 msgid "Assumed-shape array %qs at %L as dummy argument to the BIND(C) procedure %qs at %L"
 msgstr ""
 
-#: fortran/decl.c:1516
+#: fortran/decl.c:1525
 #, gcc-internal-format
 msgid "Symbol %qs at %C also declared as a type at %L"
 msgstr ""
 
-#: fortran/decl.c:1575
+#: fortran/decl.c:1584
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %C must be declared with a C interoperable kind since common block %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1615
+#: fortran/decl.c:1624
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER length must be a constant at %L"
 msgstr ""
 
-#: fortran/decl.c:1630
+#: fortran/decl.c:1639
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression at %L is being truncated (%ld/%ld)"
 msgstr ""
 
-#: fortran/decl.c:1638
+#: fortran/decl.c:1647
 #, gcc-internal-format, gfc-internal-format
 msgid "The CHARACTER elements of the array constructor at %L must have the same length (%ld/%ld)"
 msgstr ""
 
-#: fortran/decl.c:1729
+#: fortran/decl.c:1738
 #, gcc-internal-format
 msgid "Initializer not allowed for PARAMETER %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:1739
+#: fortran/decl.c:1748
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER at %L is missing an initializer"
 msgstr ""
 
-#: fortran/decl.c:1749
+#: fortran/decl.c:1758
 #, gcc-internal-format
 msgid "Variable %qs at %C with an initializer already appears in a DATA statement"
 msgstr ""
 
-#: fortran/decl.c:1792
+#: fortran/decl.c:1801
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot initialize parameter array at %L with variable length elements"
 msgstr ""
 
-#: fortran/decl.c:1861
+#: fortran/decl.c:1870
 #, gcc-internal-format, gfc-internal-format
 msgid "Can't initialize implied-shape array at %L with scalar"
 msgstr ""
 
-#: fortran/decl.c:1896
+#: fortran/decl.c:1905
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-constant lower bound in implied-shape declaration at %L"
 msgstr ""
 
-#: fortran/decl.c:1982 fortran/decl.c:1989
+#: fortran/decl.c:1991 fortran/decl.c:1998
 #, gcc-internal-format, gfc-internal-format
 msgid "Component at %C must have the POINTER attribute"
 msgstr ""
 
-#: fortran/decl.c:1998
+#: fortran/decl.c:2007
 #, gcc-internal-format
 msgid "Component %qs with CLASS at %C must be allocatable or pointer"
 msgstr ""
 
-#: fortran/decl.c:2007
+#: fortran/decl.c:2016
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr ""
 
-#: fortran/decl.c:2031 fortran/symbol.c:2230
+#: fortran/decl.c:2040 fortran/symbol.c:2244
 #, gcc-internal-format
 msgid "Component %qs at %C already declared at %L"
 msgstr ""
 
-#: fortran/decl.c:2079
+#: fortran/decl.c:2088
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer array component of structure at %C must have a deferred shape"
 msgstr ""
 
-#: fortran/decl.c:2088
+#: fortran/decl.c:2097
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component of structure at %C must have a deferred shape"
 msgstr ""
 
-#: fortran/decl.c:2097
+#: fortran/decl.c:2106
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have an explicit shape"
 msgstr ""
 
-#: fortran/decl.c:2114
+#: fortran/decl.c:2123
 #, gcc-internal-format
 msgid "Type parameter %qs at %C has no corresponding entry in the type parameter name list at %L"
 msgstr ""
 
-#: fortran/decl.c:2171
+#: fortran/decl.c:2180
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C is ambiguous"
 msgstr ""
 
-#: fortran/decl.c:2188
+#: fortran/decl.c:2197
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C may not have MOLD"
 msgstr ""
 
-#: fortran/decl.c:2205
+#: fortran/decl.c:2214
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of pointer at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:2226
+#: fortran/decl.c:2235
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in pointer initialization at %C"
 msgstr ""
 
-#: fortran/decl.c:2233
+#: fortran/decl.c:2242
 #, gcc-internal-format, gfc-internal-format
 msgid "non-NULL pointer initialization at %C"
 msgstr ""
 
-#: fortran/decl.c:2256
+#: fortran/decl.c:2265
 #, gcc-internal-format
 msgid "RESULT variable %qs at %L prohibits FUNCTION name %qs at %C from appearing in a specification statement"
 msgstr ""
 
-#: fortran/decl.c:2318
+#: fortran/decl.c:2327
 #, gcc-internal-format
 msgid "%qs not allowed outside STRUCTURE at %C"
 msgstr ""
 
-#: fortran/decl.c:2320
+#: fortran/decl.c:2329
 #, gcc-internal-format
 msgid "%qs at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr ""
 
-#: fortran/decl.c:2327
+#: fortran/decl.c:2336
 #, gcc-internal-format
 msgid "%qs entity cannot have attributes at %C"
 msgstr ""
 
-#: fortran/decl.c:2367
+#: fortran/decl.c:2376
 #, gcc-internal-format
 msgid "Non-PARAMETER symbol %qs at %L can't be implied-shape"
 msgstr ""
 
-#: fortran/decl.c:2377
+#: fortran/decl.c:2386
 #, gcc-internal-format, gfc-internal-format
 msgid "Implied-shape array at %L"
 msgstr ""
 
-#: fortran/decl.c:2422
+#: fortran/decl.c:2431
 #, gcc-internal-format, gfc-internal-format
 msgid "Explicit shaped array with nonconstant bounds at %C"
 msgstr ""
 
-#: fortran/decl.c:2501
+#: fortran/decl.c:2510
 #, gcc-internal-format
 msgid "%qs at %C is a redefinition of the declaration in the corresponding interface for MODULE PROCEDURE %qs"
 msgstr ""
 
-#: fortran/decl.c:2512
+#: fortran/decl.c:2521
 #, gcc-internal-format
 msgid "%qs entity cannot have an initializer at %C"
 msgstr ""
 
-#: fortran/decl.c:2538 fortran/decl.c:8369
+#: fortran/decl.c:2547 fortran/decl.c:8388
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr ""
 
-#: fortran/decl.c:2546
+#: fortran/decl.c:2555
 #, gcc-internal-format
 msgid "Couldn't set pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:2609
+#: fortran/decl.c:2618
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style initialization at %C"
 msgstr ""
 
-#: fortran/decl.c:2617
+#: fortran/decl.c:2626
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr ""
 
-#: fortran/decl.c:2630
+#: fortran/decl.c:2639
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in old style initialization of %s at %C"
 msgstr "Синтаксична помилка у ініціалізації у старому стилі %s, адреса — %C"
 
-#: fortran/decl.c:2650 fortran/decl.c:6661
+#: fortran/decl.c:2659 fortran/decl.c:6680
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr ""
 
-#: fortran/decl.c:2663
+#: fortran/decl.c:2672
 #, gcc-internal-format
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr ""
 
-#: fortran/decl.c:2672 fortran/decl.c:10240
+#: fortran/decl.c:2681 fortran/decl.c:10265
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr ""
 
-#: fortran/decl.c:2679
+#: fortran/decl.c:2688
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:2696
+#: fortran/decl.c:2705
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr ""
 
-#: fortran/decl.c:2710
+#: fortran/decl.c:2719
 #, gcc-internal-format, gfc-internal-format
 msgid "The component with KIND or LEN attribute at %C does not not appear in the type parameter list at %L"
 msgstr ""
 
-#: fortran/decl.c:2718
+#: fortran/decl.c:2727
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C that appears in the type parameter list at %L has neither the KIND nor LEN attribute"
 msgstr ""
 
-#: fortran/decl.c:2726
+#: fortran/decl.c:2735
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C which is a type parameter must be a scalar"
 msgstr ""
 
-#: fortran/decl.c:2789 fortran/decl.c:2825
+#: fortran/decl.c:2798 fortran/decl.c:2834
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr ""
 
-#: fortran/decl.c:2831
+#: fortran/decl.c:2840
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr ""
 
-#: fortran/decl.c:2890 fortran/decl.c:2967
+#: fortran/decl.c:2899 fortran/decl.c:2976
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis at %C"
 msgstr ""
 
-#: fortran/decl.c:2903 fortran/decl.c:3038
+#: fortran/decl.c:2912 fortran/decl.c:3047
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr ""
 
-#: fortran/decl.c:2911 fortran/decl.c:3044
+#: fortran/decl.c:2920 fortran/decl.c:3053
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr ""
 
-#: fortran/decl.c:2941 fortran/decl.c:3657
+#: fortran/decl.c:2950 fortran/decl.c:3676
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr ""
 
-#: fortran/decl.c:2954
+#: fortran/decl.c:2963
 #, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr ""
 
-#: fortran/decl.c:2965
+#: fortran/decl.c:2974
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr ""
 
-#: fortran/decl.c:3070
+#: fortran/decl.c:3079
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr ""
 
-#: fortran/decl.c:3202
+#: fortran/decl.c:3211
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:3291
+#: fortran/decl.c:3310
 #, gcc-internal-format, gfc-internal-format
 msgid "RECORD at %C is an extension, enable it with -fdec-structure"
 msgstr ""
 
-#: fortran/decl.c:3304
+#: fortran/decl.c:3323
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected after RECORD at %C"
 msgstr ""
 
-#: fortran/decl.c:3417
+#: fortran/decl.c:3436
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C cannot contain both ASSUMED and DEFERRED parameters"
 msgstr ""
 
-#: fortran/decl.c:3441
+#: fortran/decl.c:3460
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C does not contain enough parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3465
+#: fortran/decl.c:3484
 #, gcc-internal-format
 msgid "The derived parameter %qs at %C does not have a default value"
 msgstr ""
 
-#: fortran/decl.c:3497
+#: fortran/decl.c:3516
 #, gcc-internal-format, gfc-internal-format
 msgid "The parameter expression at %C must be of INTEGER type and not %s type"
 msgstr ""
 
-#: fortran/decl.c:3525
+#: fortran/decl.c:3544
 #, gcc-internal-format
 msgid "The KIND parameter %qs at %C cannot either be ASSUMED or DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:3532
+#: fortran/decl.c:3551
 #, gcc-internal-format
 msgid "The value for the KIND parameter %qs at %C does not reduce to a constant expression"
 msgstr "Значення параметра KIND %qs у %C не спрощується до сталого виразу"
 
-#: fortran/decl.c:3547
+#: fortran/decl.c:3566
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C contains too many parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3556
+#: fortran/decl.c:3575
 #, gcc-internal-format, gfc-internal-format
 msgid "Parameterized derived type at %C is ambiguous"
 msgstr ""
 
-#: fortran/decl.c:3819
+#: fortran/decl.c:3838
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type at %C"
 msgstr ""
 
-#: fortran/decl.c:3824
+#: fortran/decl.c:3843
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr ""
 
-#: fortran/decl.c:3846
+#: fortran/decl.c:3865
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C is not allowed for components"
 msgstr ""
 
-#: fortran/decl.c:3849
+#: fortran/decl.c:3868
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr ""
 
-#: fortran/decl.c:3872 fortran/decl.c:3903 fortran/decl.c:3932
-#: fortran/decl.c:4216
+#: fortran/decl.c:3891 fortran/decl.c:3922 fortran/decl.c:3951
+#: fortran/decl.c:4235
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr ""
 
-#: fortran/decl.c:3928
+#: fortran/decl.c:3947
 #, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr ""
 
-#: fortran/decl.c:3971 fortran/decl.c:4107 fortran/decl.c:4119
-#: fortran/decl.c:4133 fortran/decl.c:4611 fortran/decl.c:4619
+#: fortran/decl.c:3990 fortran/decl.c:4126 fortran/decl.c:4138
+#: fortran/decl.c:4152 fortran/decl.c:4630 fortran/decl.c:4638
 #, gcc-internal-format
 msgid "Type name %qs at %C is ambiguous"
 msgstr ""
 
-#: fortran/decl.c:4066
+#: fortran/decl.c:4085
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4148
+#: fortran/decl.c:4167
 #, gcc-internal-format
 msgid "Type name %qs at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr ""
 
-#: fortran/decl.c:4287
+#: fortran/decl.c:4306
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4296
+#: fortran/decl.c:4315
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr ""
 
-#: fortran/decl.c:4355
+#: fortran/decl.c:4374
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr ""
 
-#: fortran/decl.c:4401
+#: fortran/decl.c:4420
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4454
+#: fortran/decl.c:4473
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr ""
 
-#: fortran/decl.c:4464
+#: fortran/decl.c:4483
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4570
+#: fortran/decl.c:4589
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr ""
 
-#: fortran/decl.c:4577
+#: fortran/decl.c:4596
 #, gcc-internal-format, gfc-internal-format
 msgid "F2008: C1210 IMPORT statement at %C is not permitted in a module procedure interface body"
 msgstr ""
 
-#: fortran/decl.c:4582
+#: fortran/decl.c:4601
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4596
+#: fortran/decl.c:4615
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr ""
 
-#: fortran/decl.c:4625
+#: fortran/decl.c:4644
 #, gcc-internal-format
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr ""
 
-#: fortran/decl.c:4632
+#: fortran/decl.c:4651
 #, gcc-internal-format
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr ""
 
-#: fortran/decl.c:4673
+#: fortran/decl.c:4692
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IMPORT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5010
+#: fortran/decl.c:5029
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing codimension specification at %C"
 msgstr ""
 
-#: fortran/decl.c:5012
+#: fortran/decl.c:5031
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr ""
 
-#: fortran/decl.c:5107
+#: fortran/decl.c:5126
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr ""
 
-#: fortran/decl.c:5124
+#: fortran/decl.c:5143
 #, gcc-internal-format
 msgid "%s at %L is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:5141
+#: fortran/decl.c:5160
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5150
+#: fortran/decl.c:5169
 #, gcc-internal-format, gfc-internal-format
 msgid "KIND attribute at %C in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5158
+#: fortran/decl.c:5177
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be INTEGER"
 msgstr ""
 
-#: fortran/decl.c:5165
+#: fortran/decl.c:5184
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5174
+#: fortran/decl.c:5193
 #, gcc-internal-format, gfc-internal-format
 msgid "LEN attribute at %C in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5182
+#: fortran/decl.c:5201
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be INTEGER"
 msgstr ""
 
-#: fortran/decl.c:5189
+#: fortran/decl.c:5208
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5198
+#: fortran/decl.c:5217
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5216
+#: fortran/decl.c:5235
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5226
+#: fortran/decl.c:5245
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:5236
+#: fortran/decl.c:5255
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed outside a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5249
+#: fortran/decl.c:5268
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5260
+#: fortran/decl.c:5279
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5315 fortran/decl.c:8673
+#: fortran/decl.c:5334 fortran/decl.c:8692
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:5321
+#: fortran/decl.c:5340
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5355
+#: fortran/decl.c:5374
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5362
+#: fortran/decl.c:5381
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5369
+#: fortran/decl.c:5388
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr ""
 
-#: fortran/decl.c:5410
+#: fortran/decl.c:5429
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:5508
+#: fortran/decl.c:5527
 #, gcc-internal-format
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:5530
+#: fortran/decl.c:5549
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5539
+#: fortran/decl.c:5558
 #, gcc-internal-format
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5543
+#: fortran/decl.c:5562
 #, gcc-internal-format
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5555
+#: fortran/decl.c:5574
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr ""
 
-#: fortran/decl.c:5569
+#: fortran/decl.c:5588
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr ""
 
-#: fortran/decl.c:5577
+#: fortran/decl.c:5596
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr ""
 
-#: fortran/decl.c:5589
+#: fortran/decl.c:5608
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr ""
 
-#: fortran/decl.c:5597
+#: fortran/decl.c:5616
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be a character string"
 msgstr ""
@@ -51787,951 +51854,956 @@
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:5608
+#: fortran/decl.c:5627
 #, gcc-internal-format
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr ""
 
-#: fortran/decl.c:5682
+#: fortran/decl.c:5701
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5727
+#: fortran/decl.c:5746
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5734
+#: fortran/decl.c:5753
 #, gcc-internal-format
 msgid "Missing symbol"
 msgstr ""
 
-#: fortran/decl.c:5763
+#: fortran/decl.c:5782
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5850
+#: fortran/decl.c:5869
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr ""
 
-#: fortran/decl.c:5892
+#: fortran/decl.c:5911
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in anonymous structure declaration at %C"
 msgstr "Синтаксична помилка у оголошенні анонімної структури у %C"
 
-#: fortran/decl.c:5901
+#: fortran/decl.c:5920
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:5951
+#: fortran/decl.c:5970
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C"
 msgstr ""
 
-#: fortran/decl.c:5996
+#: fortran/decl.c:6015
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPURE procedure at %C"
 msgstr ""
 
-#: fortran/decl.c:6008
+#: fortran/decl.c:6027
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr ""
 
-#: fortran/decl.c:6054
+#: fortran/decl.c:6073
 #, gcc-internal-format, gfc-internal-format
 msgid "ELEMENTAL prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6061
+#: fortran/decl.c:6080
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6068
+#: fortran/decl.c:6087
 #, gcc-internal-format, gfc-internal-format
 msgid "RECURSIVE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6134 fortran/primary.c:1820
+#: fortran/decl.c:6153 fortran/primary.c:1820
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate-return argument at %C"
 msgstr ""
 
-#: fortran/decl.c:6140 fortran/decl.c:6148
+#: fortran/decl.c:6159 fortran/decl.c:6167
 #, gcc-internal-format, gfc-internal-format
 msgid "A parameter name is required at %C"
 msgstr "Потрібна назва параметра у %C"
 
-#: fortran/decl.c:6188
+#: fortran/decl.c:6207
 #, gcc-internal-format
 msgid "Name %qs at %C is the name of the procedure"
 msgstr ""
 
-#: fortran/decl.c:6201
+#: fortran/decl.c:6220
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected parameter list in type declaration at %C"
 msgstr "У оголошенні типу у %C мав бути список параметрів"
 
-#: fortran/decl.c:6204
+#: fortran/decl.c:6223
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr ""
 
-#: fortran/decl.c:6222
+#: fortran/decl.c:6241
 #, gcc-internal-format
 msgid "Duplicate name %qs in parameter list at %C"
 msgstr ""
 
-#: fortran/decl.c:6225
+#: fortran/decl.c:6244
 #, gcc-internal-format
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr ""
 
-#: fortran/decl.c:6264
+#: fortran/decl.c:6283
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in MODULE PROCEDURE formal argument names (%s/%s) at %C"
 msgstr ""
 
-#: fortran/decl.c:6270
+#: fortran/decl.c:6289
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in number of MODULE PROCEDURE formal arguments at %C"
 msgstr ""
 
-#: fortran/decl.c:6309
+#: fortran/decl.c:6328
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr ""
 
-#: fortran/decl.c:6386
+#: fortran/decl.c:6405
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:6396 fortran/decl.c:7494
+#: fortran/decl.c:6415 fortran/decl.c:7513
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr ""
 
-#: fortran/decl.c:6600
+#: fortran/decl.c:6619
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:6607
+#: fortran/decl.c:6626
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:6613
+#: fortran/decl.c:6632
 #, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr ""
 
-#: fortran/decl.c:6636
+#: fortran/decl.c:6655
 #, gcc-internal-format
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr ""
 
-#: fortran/decl.c:6682 fortran/decl.c:6870 fortran/decl.c:10723
+#: fortran/decl.c:6701 fortran/decl.c:6889 fortran/decl.c:10748
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6731 fortran/decl.c:10623
+#: fortran/decl.c:6750 fortran/decl.c:10648
 #, gcc-internal-format
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr ""
 
-#: fortran/decl.c:6738
+#: fortran/decl.c:6757
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr ""
 
-#: fortran/decl.c:6742
+#: fortran/decl.c:6761
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:6814
+#: fortran/decl.c:6833
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:6832
+#: fortran/decl.c:6851
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr ""
 
-#: fortran/decl.c:6841 fortran/decl.c:9392
+#: fortran/decl.c:6860 fortran/decl.c:9411
 #, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr ""
 
-#: fortran/decl.c:6911
+#: fortran/decl.c:6930
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6983
+#: fortran/decl.c:7002
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr ""
 
-#: fortran/decl.c:7007 fortran/decl.c:7011 fortran/decl.c:7266
-#: fortran/decl.c:7270 fortran/decl.c:7462 fortran/decl.c:7466
-#: fortran/symbol.c:1875
+#: fortran/decl.c:7026 fortran/decl.c:7030 fortran/decl.c:7285
+#: fortran/decl.c:7289 fortran/decl.c:7481 fortran/decl.c:7485
+#: fortran/symbol.c:1889
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr ""
 
-#: fortran/decl.c:7164
+#: fortran/decl.c:7183
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7173
+#: fortran/decl.c:7192
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr ""
 
-#: fortran/decl.c:7176
+#: fortran/decl.c:7195
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr ""
 
-#: fortran/decl.c:7179
+#: fortran/decl.c:7198
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SUBMODULE"
 msgstr ""
 
-#: fortran/decl.c:7182
+#: fortran/decl.c:7201
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr ""
 
-#: fortran/decl.c:7186 fortran/decl.c:7231
+#: fortran/decl.c:7205 fortran/decl.c:7250
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr ""
 
-#: fortran/decl.c:7190
+#: fortran/decl.c:7209
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a STRUCTURE block"
 msgstr ""
 
-#: fortran/decl.c:7194
+#: fortran/decl.c:7213
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr ""
 
-#: fortran/decl.c:7198
+#: fortran/decl.c:7217
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr ""
 
-#: fortran/decl.c:7203
+#: fortran/decl.c:7222
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr ""
 
-#: fortran/decl.c:7207
+#: fortran/decl.c:7226
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr ""
 
-#: fortran/decl.c:7211
+#: fortran/decl.c:7230
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr ""
 
-#: fortran/decl.c:7215
+#: fortran/decl.c:7234
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr ""
 
-#: fortran/decl.c:7219
+#: fortran/decl.c:7238
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr ""
 
-#: fortran/decl.c:7223
+#: fortran/decl.c:7242
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected ENTRY statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7244
+#: fortran/decl.c:7263
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr ""
 
-#: fortran/decl.c:7295 fortran/decl.c:7501
+#: fortran/decl.c:7314 fortran/decl.c:7520
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7563 fortran/decl.c:7570
+#: fortran/decl.c:7582 fortran/decl.c:7589
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:7610
+#: fortran/decl.c:7629
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr ""
 
-#: fortran/decl.c:7626
+#: fortran/decl.c:7645
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr ""
 
-#: fortran/decl.c:7634
+#: fortran/decl.c:7653
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr ""
 
-#: fortran/decl.c:7653
+#: fortran/decl.c:7672
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing closing paren for binding label at %C"
 msgstr ""
 
-#: fortran/decl.c:7659
+#: fortran/decl.c:7678
 #, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7665
+#: fortran/decl.c:7684
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7694
+#: fortran/decl.c:7713
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr ""
 
-#: fortran/decl.c:7939
+#: fortran/decl.c:7958
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7948
+#: fortran/decl.c:7967
 #, gcc-internal-format, gfc-internal-format
 msgid "END statement instead of %s statement at %L"
 msgstr ""
 
 #. We would have required END [something].
-#: fortran/decl.c:7957
+#: fortran/decl.c:7976
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr ""
 
-#: fortran/decl.c:7968
+#: fortran/decl.c:7987
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s statement at %L"
 msgstr ""
 
-#: fortran/decl.c:7988
+#: fortran/decl.c:8007
 #, gcc-internal-format
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr ""
 
-#: fortran/decl.c:8005
+#: fortran/decl.c:8024
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr ""
 
-#: fortran/decl.c:8019 fortran/decl.c:8027
+#: fortran/decl.c:8038 fortran/decl.c:8046
 #, gcc-internal-format
 msgid "Expected label %qs for %s statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8126
+#: fortran/decl.c:8145
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr ""
 
-#: fortran/decl.c:8134
+#: fortran/decl.c:8153
 #, gcc-internal-format, gfc-internal-format
 msgid "Dimensions specified for %s at %L after its initialization"
 msgstr ""
 
-#: fortran/decl.c:8142
+#: fortran/decl.c:8161
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr ""
 
-#: fortran/decl.c:8151
+#: fortran/decl.c:8170
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr ""
 
-#: fortran/decl.c:8249
+#: fortran/decl.c:8268
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr ""
 
-#: fortran/decl.c:8286
+#: fortran/decl.c:8305
 #, gcc-internal-format
 msgid "Expected %<(%> at %C"
 msgstr ""
 
-#: fortran/decl.c:8300 fortran/decl.c:8340
+#: fortran/decl.c:8319 fortran/decl.c:8359
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr ""
 
-#: fortran/decl.c:8316
+#: fortran/decl.c:8335
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C must be an integer"
 msgstr ""
 
-#: fortran/decl.c:8320
+#: fortran/decl.c:8339
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr ""
 
-#: fortran/decl.c:8326
+#: fortran/decl.c:8345
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr ""
 
-#: fortran/decl.c:8365
+#: fortran/decl.c:8384
 #, gcc-internal-format
 msgid "Couldn't set Cray pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:8389
+#: fortran/decl.c:8408
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr ""
 
-#: fortran/decl.c:8401
+#: fortran/decl.c:8420
 #, gcc-internal-format
 msgid "Expected %<,%> or end of statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8427
+#: fortran/decl.c:8446
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:8459
+#: fortran/decl.c:8478
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:8478
+#: fortran/decl.c:8497
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer declaration at %C requires -fcray-pointer flag"
 msgstr ""
 
-#: fortran/decl.c:8517
+#: fortran/decl.c:8536
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8623
+#: fortran/decl.c:8642
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:8640
+#: fortran/decl.c:8659
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:8679
+#: fortran/decl.c:8698
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8717
+#: fortran/decl.c:8736
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8741
+#: fortran/decl.c:8760
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:8778
+#: fortran/decl.c:8797
 #, gcc-internal-format, gfc-internal-format
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:8806
+#: fortran/decl.c:8825
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr ""
 
-#: fortran/decl.c:8813
+#: fortran/decl.c:8832
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8819
+#: fortran/decl.c:8838
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr ""
 
-#: fortran/decl.c:8839
+#: fortran/decl.c:8858
 #, gcc-internal-format, gfc-internal-format
 msgid "Initializing already initialized variable at %C"
 msgstr ""
 
 #. With legacy PARAMETER statements, don't expect a terminating ')'.
-#: fortran/decl.c:8864
+#: fortran/decl.c:8883
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER without '()' at %C"
 msgstr ""
 
-#: fortran/decl.c:8880
+#: fortran/decl.c:8899
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8899 fortran/decl.c:8955
+#: fortran/decl.c:8918 fortran/decl.c:8974
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:8934
+#: fortran/decl.c:8953
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in AUTOMATIC statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8941
+#: fortran/decl.c:8960
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in AUTOMATIC statement at %C"
 msgstr "Синтаксична помилка у інструкції AUTOMATIC у %C"
 
-#: fortran/decl.c:8990
+#: fortran/decl.c:9009
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in STATIC statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8997
+#: fortran/decl.c:9016
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in STATIC statement at %C"
 msgstr "Синтаксична помилка у інструкції STATIC у %C"
 
-#: fortran/decl.c:9016
+#: fortran/decl.c:9035
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:9027
+#: fortran/decl.c:9046
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:9073
+#: fortran/decl.c:9092
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9087
+#: fortran/decl.c:9106
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:9091
+#: fortran/decl.c:9110
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9129
+#: fortran/decl.c:9148
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VALUE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9141
+#: fortran/decl.c:9160
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9168
+#: fortran/decl.c:9187
 #, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr ""
 
-#: fortran/decl.c:9193
+#: fortran/decl.c:9212
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9205
+#: fortran/decl.c:9224
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9249
+#: fortran/decl.c:9268
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9274
+#: fortran/decl.c:9293
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:9367
+#: fortran/decl.c:9386
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr ""
 
-#: fortran/decl.c:9425
+#: fortran/decl.c:9444
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr ""
 
-#: fortran/decl.c:9474
+#: fortran/decl.c:9493
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr ""
 
-#: fortran/decl.c:9483
+#: fortran/decl.c:9502
 #, gcc-internal-format
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr ""
 
-#: fortran/decl.c:9489
+#: fortran/decl.c:9508
 #, gcc-internal-format
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr ""
 
-#: fortran/decl.c:9496
+#: fortran/decl.c:9515
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:9503
+#: fortran/decl.c:9522
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr ""
 
-#: fortran/decl.c:9526
+#: fortran/decl.c:9545
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:9538
+#: fortran/decl.c:9557
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:9559
+#: fortran/decl.c:9578
 #, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
 msgstr ""
 
-#: fortran/decl.c:9605
+#: fortran/decl.c:9624
 #, gcc-internal-format, gfc-internal-format
 msgid "Failed to create structure type '%s' at %C"
 msgstr ""
 
-#: fortran/decl.c:9611
+#: fortran/decl.c:9630
 #, gcc-internal-format
 msgid "Type definition of %qs at %C was already defined at %L"
 msgstr ""
 
-#: fortran/decl.c:9658
+#: fortran/decl.c:9677
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after MAP statement at %C"
 msgstr "Зайві команди після інструкції MAP у %C"
 
-#: fortran/decl.c:9691
+#: fortran/decl.c:9710
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after UNION statement at %C"
 msgstr "Зайві команди після інструкції UNION у %C"
 
-#: fortran/decl.c:9726
+#: fortran/decl.c:9745
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr ""
 
-#: fortran/decl.c:9740
+#: fortran/decl.c:9759
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected in non-nested structure declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:9758
+#: fortran/decl.c:9777
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after non-nested STRUCTURE statement at %C"
 msgstr "Зайві команди після невкладеної інструкції STRUCTURE у %C"
 
-#: fortran/decl.c:9765
+#: fortran/decl.c:9784
 #, gcc-internal-format
 msgid "Structure name %qs at %C cannot be the same as an intrinsic type"
 msgstr ""
 
-#: fortran/decl.c:9926
+#: fortran/decl.c:9947
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr ""
 
-#: fortran/decl.c:9954
+#: fortran/decl.c:9975
 #, gcc-internal-format
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr ""
 
-#: fortran/decl.c:9964
+#: fortran/decl.c:9986
 #, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr ""
 
-#: fortran/decl.c:9981
+#: fortran/decl.c:9989
 #, gcc-internal-format
+msgid "Derived type name %qs at %C already has a basic type"
+msgstr "Похідна назва типу %qs у %C вже має базовий тип"
+
+#: fortran/decl.c:10006
+#, gcc-internal-format
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr ""
 
-#: fortran/decl.c:10042
+#: fortran/decl.c:10067
 #, gcc-internal-format, gfc-internal-format
 msgid "Garbage after PARAMETERIZED TYPE declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:10126
+#: fortran/decl.c:10151
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr ""
 
-#: fortran/decl.c:10146
+#: fortran/decl.c:10171
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM and ENUMERATOR at %C"
 msgstr ""
 
-#: fortran/decl.c:10178
+#: fortran/decl.c:10203
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr ""
 
-#: fortran/decl.c:10257
+#: fortran/decl.c:10282
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr ""
 
-#: fortran/decl.c:10305
+#: fortran/decl.c:10330
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr ""
 
-#: fortran/decl.c:10341
+#: fortran/decl.c:10366
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr ""
 
-#: fortran/decl.c:10388 fortran/decl.c:10403
+#: fortran/decl.c:10413 fortran/decl.c:10428
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate access-specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:10423
+#: fortran/decl.c:10448
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10443
+#: fortran/decl.c:10468
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10470
+#: fortran/decl.c:10495
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:10488
+#: fortran/decl.c:10513
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr ""
 
-#: fortran/decl.c:10504
+#: fortran/decl.c:10529
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DEFERRED at %C"
 msgstr ""
 
-#: fortran/decl.c:10517
+#: fortran/decl.c:10542
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected access-specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:10519
+#: fortran/decl.c:10544
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:10527
+#: fortran/decl.c:10552
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED can't both appear at %C"
 msgstr ""
 
-#: fortran/decl.c:10539
+#: fortran/decl.c:10564
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:10581
+#: fortran/decl.c:10606
 #, gcc-internal-format
 msgid "Interface-name expected after %<(%> at %C"
 msgstr ""
 
-#: fortran/decl.c:10587
+#: fortran/decl.c:10612
 #, gcc-internal-format
 msgid "%<)%> expected at %C"
 msgstr ""
 
-#: fortran/decl.c:10607
+#: fortran/decl.c:10632
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:10612
+#: fortran/decl.c:10637
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:10635
+#: fortran/decl.c:10660
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr ""
 
-#: fortran/decl.c:10639
+#: fortran/decl.c:10664
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
 msgstr ""
 
-#: fortran/decl.c:10651
+#: fortran/decl.c:10676
 #, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:10657
+#: fortran/decl.c:10682
 #, gcc-internal-format
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr ""
 
-#: fortran/decl.c:10667
+#: fortran/decl.c:10692
 #, gcc-internal-format
 msgid "Expected binding target after %<=>%> at %C"
 msgstr ""
 
-#: fortran/decl.c:10684
+#: fortran/decl.c:10709
 #, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr ""
 
-#: fortran/decl.c:10695
+#: fortran/decl.c:10720
 #, gcc-internal-format
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:10746
+#: fortran/decl.c:10771
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr ""
 
-#: fortran/decl.c:10766
+#: fortran/decl.c:10791
 #, gcc-internal-format
 msgid "Expected %<::%> at %C"
 msgstr ""
 
-#: fortran/decl.c:10778
+#: fortran/decl.c:10803
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected generic name or operator descriptor at %C"
 msgstr ""
 
-#: fortran/decl.c:10799
+#: fortran/decl.c:10824
 #, gcc-internal-format, gfc-internal-format
 msgid "Malformed GENERIC statement at %C"
 msgstr ""
 
-#: fortran/decl.c:10810
+#: fortran/decl.c:10835
 #, gcc-internal-format
 msgid "Expected %<=>%> at %C"
 msgstr ""
 
-#: fortran/decl.c:10846
+#: fortran/decl.c:10871
 #, gcc-internal-format
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:10854
+#: fortran/decl.c:10879
 #, gcc-internal-format
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr ""
 
-#: fortran/decl.c:10902
+#: fortran/decl.c:10927
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr ""
 
-#: fortran/decl.c:10912
+#: fortran/decl.c:10937
 #, gcc-internal-format
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:10930
+#: fortran/decl.c:10955
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr ""
 
-#: fortran/decl.c:10965
+#: fortran/decl.c:10990
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr ""
 
-#: fortran/decl.c:10976
+#: fortran/decl.c:11001
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr ""
 
-#: fortran/decl.c:10998
+#: fortran/decl.c:11023
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr ""
 
-#: fortran/decl.c:11005
+#: fortran/decl.c:11030
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr ""
 
-#: fortran/decl.c:11015
+#: fortran/decl.c:11040
 #, gcc-internal-format
 msgid "Expected %<,%> at %C"
 msgstr ""
 
-#: fortran/decl.c:11021
+#: fortran/decl.c:11046
 #, gcc-internal-format
 msgid "Unknown procedure name %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:11034
+#: fortran/decl.c:11059
 #, gcc-internal-format
 msgid "%qs at %C is already defined as FINAL procedure"
 msgstr ""
 
-#: fortran/decl.c:11104
+#: fortran/decl.c:11129
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr ""
 
-#: fortran/decl.c:11150
+#: fortran/decl.c:11175
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr ""
 
-#: fortran/decl.c:11170
+#: fortran/decl.c:11195
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive requires a non-negative integral constant less than or equal to %u at %C"
 msgstr ""
 
-#: fortran/decl.c:11184
+#: fortran/decl.c:11209
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ UNROLL directive at %C"
 msgstr ""
@@ -53066,27 +53138,27 @@
 msgid "BOZ literal at %L used to initialize non-integer variable %qs"
 msgstr ""
 
-#: fortran/expr.c:3369 fortran/resolve.c:10197
+#: fortran/expr.c:3369 fortran/resolve.c:10210
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal at %L outside a DATA statement and outside INT/REAL/DBLE/CMPLX"
 msgstr ""
 
-#: fortran/expr.c:3380 fortran/resolve.c:10208
+#: fortran/expr.c:3380 fortran/resolve.c:10221
 #, gcc-internal-format
 msgid "BOZ literal at %L is bitwise transferred non-integer symbol %qs"
 msgstr ""
 
-#: fortran/expr.c:3388 fortran/resolve.c:10217
+#: fortran/expr.c:3388 fortran/resolve.c:10230
 #, gcc-internal-format
 msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3392 fortran/resolve.c:10221
+#: fortran/expr.c:3392 fortran/resolve.c:10234
 #, gcc-internal-format
 msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3396 fortran/resolve.c:10225
+#: fortran/expr.c:3396 fortran/resolve.c:10238
 #, gcc-internal-format
 msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
@@ -53096,147 +53168,147 @@
 msgid "The assignment to a KIND or LEN component of a parameterized type at %L is not allowed"
 msgstr ""
 
-#: fortran/expr.c:3426
+#: fortran/expr.c:3429
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible types in DATA statement at %L; attempted conversion of %s to %s"
 msgstr ""
 
-#: fortran/expr.c:3465
+#: fortran/expr.c:3468
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is not a POINTER at %L"
 msgstr ""
 
-#: fortran/expr.c:3473
+#: fortran/expr.c:3476
 #, gcc-internal-format
 msgid "%qs in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgstr ""
 
-#: fortran/expr.c:3496
+#: fortran/expr.c:3499
 #, gcc-internal-format
 msgid "Expected bounds specification for %qs at %L"
 msgstr ""
 
-#: fortran/expr.c:3501
+#: fortran/expr.c:3504
 #, gcc-internal-format
 msgid "Bounds specification for %qs in pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3514
+#: fortran/expr.c:3517
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower bound has to be present at %L"
 msgstr ""
 
-#: fortran/expr.c:3520
+#: fortran/expr.c:3523
 #, gcc-internal-format, gfc-internal-format
 msgid "Stride must not be present at %L"
 msgstr ""
 
-#: fortran/expr.c:3532
+#: fortran/expr.c:3535
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the upper bounds must be specified at %L"
 msgstr ""
 
-#: fortran/expr.c:3558
+#: fortran/expr.c:3561
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %L shall not have a coindex"
 msgstr ""
 
-#: fortran/expr.c:3579
+#: fortran/expr.c:3582
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3603
+#: fortran/expr.c:3606
 #, gcc-internal-format
 msgid "Function result %qs is invalid as proc-target in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3612
+#: fortran/expr.c:3615
 #, gcc-internal-format
 msgid "Abstract interface %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3622
+#: fortran/expr.c:3625
 #, gcc-internal-format
 msgid "Statement function %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3628
+#: fortran/expr.c:3631
 #, gcc-internal-format
 msgid "Internal procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3635
+#: fortran/expr.c:3638
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L is invalid in procedure pointer assignment"
 msgstr ""
 
-#: fortran/expr.c:3643
+#: fortran/expr.c:3646
 #, gcc-internal-format
 msgid "Nonintrinsic elemental procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3666
+#: fortran/expr.c:3669
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in the procedure pointer assignment at %L: mismatch in the calling convention"
 msgstr ""
 
-#: fortran/expr.c:3719
+#: fortran/expr.c:3722
 #, gcc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %qs is not a subroutine"
 msgstr ""
 
-#: fortran/expr.c:3729 fortran/expr.c:3744
+#: fortran/expr.c:3732 fortran/expr.c:3747
 #, gcc-internal-format
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr ""
 
-#: fortran/expr.c:3735 fortran/expr.c:3750 fortran/resolve.c:2566
+#: fortran/expr.c:3738 fortran/expr.c:3753 fortran/resolve.c:2566
 #, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr ""
 
-#: fortran/expr.c:3762
+#: fortran/expr.c:3765
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %s"
 msgstr ""
 
-#: fortran/expr.c:3771
+#: fortran/expr.c:3774
 #, gcc-internal-format
 msgid "Procedure pointer target %qs at %L must be either an intrinsic, host or use associated, referenced or have the EXTERNAL attribute"
 msgstr ""
 
-#: fortran/expr.c:3788
+#: fortran/expr.c:3791
 #, gcc-internal-format, gfc-internal-format
 msgid "Data-pointer-object at %L must be unlimited polymorphic, or of a type with the BIND or SEQUENCE attribute, to be compatible with an unlimited polymorphic target"
 msgstr ""
 
-#: fortran/expr.c:3793
+#: fortran/expr.c:3796
 #, gcc-internal-format, gfc-internal-format
 msgid "Different types in pointer assignment at %L; attempted assignment of %s to %s"
 msgstr ""
 
-#: fortran/expr.c:3802
+#: fortran/expr.c:3805
 #, gcc-internal-format, gfc-internal-format
 msgid "Different kind type parameters in pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3809
+#: fortran/expr.c:3812
 #, gcc-internal-format, gfc-internal-format
 msgid "Different ranks in pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3828
+#: fortran/expr.c:3831
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is smaller than size of the pointer (%ld < %ld) at %L"
 msgstr ""
 
-#: fortran/expr.c:3841
+#: fortran/expr.c:3844
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target must be rank 1 or simply contiguous at %L"
 msgstr ""
 
-#: fortran/expr.c:3845
+#: fortran/expr.c:3848
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is not rank 1 at %L"
 msgstr ""
@@ -53244,147 +53316,152 @@
 #. The test above might need to be extend when F08, Note 5.4 has to be
 #. interpreted in the way that target and pointer with the same coindex
 #. are allowed.
-#: fortran/expr.c:3877 fortran/expr.c:3925
+#: fortran/expr.c:3880 fortran/expr.c:3928
 #, gcc-internal-format, gfc-internal-format
 msgid "Data target at %L shall not have a coindex"
 msgstr ""
 
-#: fortran/expr.c:3880
+#: fortran/expr.c:3883
 #, gcc-internal-format, gfc-internal-format
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr ""
 
-#: fortran/expr.c:3888
+#: fortran/expr.c:3891
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr ""
 
-#: fortran/expr.c:3895
+#: fortran/expr.c:3898
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr ""
 
-#: fortran/expr.c:3904
+#: fortran/expr.c:3907
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr ""
 
-#: fortran/expr.c:3912
+#: fortran/expr.c:3915
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/expr.c:3936
+#: fortran/expr.c:3939
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to contiguous pointer from non-contiguous target at %L"
 msgstr ""
 
-#: fortran/expr.c:3975
+#: fortran/expr.c:3978
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr ""
 
-#: fortran/expr.c:4051 fortran/resolve.c:1452
+#: fortran/expr.c:4054 fortran/resolve.c:1452
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/expr.c:4057
+#: fortran/expr.c:4060
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr ""
 
-#: fortran/expr.c:4072 fortran/resolve.c:1458
+#: fortran/expr.c:4075 fortran/resolve.c:1458
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr ""
 
-#: fortran/expr.c:4084
+#: fortran/expr.c:4087
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr ""
 
-#: fortran/expr.c:5512
+#: fortran/expr.c:4557
+#, gcc-internal-format
+msgid "generate_isocbinding_initializer(): bad iso_c_binding type, expected %<c_ptr%> or %<c_funptr%>"
+msgstr ""
+
+#: fortran/expr.c:5568
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5520
+#: fortran/expr.c:5576
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5528
+#: fortran/expr.c:5584
 #, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5537
+#: fortran/expr.c:5593
 #, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr ""
 
-#: fortran/expr.c:5548
+#: fortran/expr.c:5604
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5557
+#: fortran/expr.c:5613
 #, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5570
+#: fortran/expr.c:5626
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5583
+#: fortran/expr.c:5639
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5613
+#: fortran/expr.c:5669
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5621
+#: fortran/expr.c:5677
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5634
+#: fortran/expr.c:5690
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5642
+#: fortran/expr.c:5698
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5654
+#: fortran/expr.c:5710
 #, gcc-internal-format
 msgid "Variable %qs can not appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr ""
 
-#: fortran/expr.c:5713
+#: fortran/expr.c:5769
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:5717
+#: fortran/expr.c:5773
 #, gcc-internal-format
 msgid "%qs at %L associated to expression can not be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:5728
+#: fortran/expr.c:5784
 #, gcc-internal-format
 msgid "Associate-name %qs can not appear in a variable definition context (%s) at %L because its target at %L can not, either"
 msgstr ""
 
-#: fortran/expr.c:5770
+#: fortran/expr.c:5826
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr ""
@@ -53394,22 +53471,22 @@
 msgid "can't open input file: %s"
 msgstr "не вдалося відкрити вхідний файл %s"
 
-#: fortran/frontend-passes.c:190
+#: fortran/frontend-passes.c:192
 #, gcc-internal-format
 msgid "No location in statement"
 msgstr ""
 
-#: fortran/frontend-passes.c:205
+#: fortran/frontend-passes.c:207
 #, gcc-internal-format, gfc-internal-format
 msgid "No location in expression near %L"
 msgstr "Не вказано місця у виразі поряд із %L"
 
-#: fortran/frontend-passes.c:409
+#: fortran/frontend-passes.c:414
 #, gcc-internal-format
 msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
-#: fortran/frontend-passes.c:817 fortran/trans-array.c:1182
+#: fortran/frontend-passes.c:822 fortran/trans-array.c:1182
 #: fortran/trans-array.c:6440 fortran/trans-array.c:7864
 #: fortran/trans-intrinsic.c:7307
 #, gcc-internal-format, gfc-internal-format
@@ -53416,67 +53493,67 @@
 msgid "Creating array temporary at %L"
 msgstr ""
 
-#: fortran/frontend-passes.c:842 fortran/frontend-passes.c:846
+#: fortran/frontend-passes.c:847 fortran/frontend-passes.c:851
 #, gcc-internal-format
 msgid "Removing call to function %qs at %L"
 msgstr ""
 
-#: fortran/frontend-passes.c:1273 fortran/frontend-passes.c:1312
+#: fortran/frontend-passes.c:1278 fortran/frontend-passes.c:1317
 #, gcc-internal-format
 msgid "bad expression"
 msgstr "помилковий вираз"
 
-#: fortran/frontend-passes.c:1308
+#: fortran/frontend-passes.c:1313
 #, gcc-internal-format
 msgid "bad op"
 msgstr "помилковий оператор"
 
-#: fortran/frontend-passes.c:2161
+#: fortran/frontend-passes.c:2166
 #, gcc-internal-format
 msgid "illegal OP in optimize_comparison"
 msgstr ""
 
-#: fortran/frontend-passes.c:2407
+#: fortran/frontend-passes.c:2412
 #, gcc-internal-format
 msgid "Variable %qs at %L set to undefined value inside loop  beginning at %L as INTENT(OUT) argument to subroutine %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:2414
+#: fortran/frontend-passes.c:2419
 #, gcc-internal-format
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to subroutine %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:2637 fortran/frontend-passes.c:2661
+#: fortran/frontend-passes.c:2642 fortran/frontend-passes.c:2666
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L out of bounds (%ld < %ld) in loop beginning at %L"
 msgstr ""
 
-#: fortran/frontend-passes.c:2646 fortran/frontend-passes.c:2670
+#: fortran/frontend-passes.c:2651 fortran/frontend-passes.c:2675
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L out of bounds (%ld > %ld) in loop beginning at %L"
 msgstr ""
 
-#: fortran/frontend-passes.c:2730
+#: fortran/frontend-passes.c:2735
 #, gcc-internal-format
 msgid "Variable %qs at %L set to undefined value inside loop beginning at %L as INTENT(OUT) argument to function %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:2736
+#: fortran/frontend-passes.c:2741
 #, gcc-internal-format
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:3128 fortran/trans-expr.c:1581
+#: fortran/frontend-passes.c:3133 fortran/trans-expr.c:1581
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr ""
 
-#: fortran/frontend-passes.c:3637
+#: fortran/frontend-passes.c:3642
 #, gcc-internal-format
 msgid "Scalarization using DIMEN_RANGE unimplemented"
 msgstr ""
 
-#: fortran/frontend-passes.c:4429
+#: fortran/frontend-passes.c:4434
 #, gcc-internal-format, gfc-internal-format
 msgid "Interchanging loops at %L"
 msgstr ""
@@ -53596,12 +53673,12 @@
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:970 fortran/resolve.c:16351
+#: fortran/interface.c:970 fortran/resolve.c:16378
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:977 fortran/resolve.c:16369
+#: fortran/interface.c:977 fortran/resolve.c:16396
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
@@ -54791,7 +54868,7 @@
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.c:3369 fortran/resolve.c:14263
+#: fortran/io.c:3369 fortran/resolve.c:14283
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -54957,7 +55034,7 @@
 msgid "Integer too large at %C"
 msgstr ""
 
-#: fortran/match.c:580 fortran/parse.c:1132
+#: fortran/match.c:580 fortran/parse.c:1136
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many digits in statement label at %C"
 msgstr ""
@@ -55718,57 +55795,57 @@
 msgid "Expected block name %qs of SELECT construct at %C"
 msgstr ""
 
-#: fortran/match.c:6186
+#: fortran/match.c:6201
 #, gcc-internal-format, gfc-internal-format
 msgid "parse error in SELECT TYPE statement at %C"
 msgstr ""
 
-#: fortran/match.c:6211
+#: fortran/match.c:6226
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr ""
 
-#: fortran/match.c:6249
+#: fortran/match.c:6264
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr ""
 
-#: fortran/match.c:6301
+#: fortran/match.c:6316
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CASE specification at %C"
 msgstr ""
 
-#: fortran/match.c:6319
+#: fortran/match.c:6334
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected TYPE IS statement at %C"
 msgstr ""
 
-#: fortran/match.c:6351
+#: fortran/match.c:6366
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr ""
 
-#: fortran/match.c:6362
+#: fortran/match.c:6377
 #, gcc-internal-format, gfc-internal-format
 msgid "All the LEN type parameters in the TYPE IS statement at %C must be ASSUMED"
 msgstr ""
 
-#: fortran/match.c:6373
+#: fortran/match.c:6388
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr ""
 
-#: fortran/match.c:6449
+#: fortran/match.c:6464
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr ""
 
-#: fortran/match.c:6572
+#: fortran/match.c:6587
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr ""
 
-#: fortran/match.c:6610
+#: fortran/match.c:6625
 #, gcc-internal-format
 msgid "Label %qs at %C doesn't match WHERE label %qs"
 msgstr ""
@@ -55919,188 +55996,188 @@
 msgid "mio_array_ref(): Unknown array ref"
 msgstr ""
 
-#: fortran/module.c:3716
+#: fortran/module.c:3718
 #, gcc-internal-format, gfc-internal-format
 msgid "Namelist %s cannot be renamed by USE association to %s"
 msgstr ""
 
-#: fortran/module.c:4832
+#: fortran/module.c:4834
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4835
+#: fortran/module.c:4837
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:5029
+#: fortran/module.c:5031
 #, gcc-internal-format
 msgid "%qs of module %qs, imported at %C, is also the name of the current program unit"
 msgstr ""
 
-#: fortran/module.c:5381
+#: fortran/module.c:5383
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5388
+#: fortran/module.c:5390
 #, gcc-internal-format
 msgid "User operator %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5393
+#: fortran/module.c:5395
 #, gcc-internal-format
 msgid "Intrinsic operator %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5628
+#: fortran/module.c:5630
 #, gcc-internal-format
 msgid "write_symbol(): bad module symbol %qs"
 msgstr ""
 
-#: fortran/module.c:5961
+#: fortran/module.c:5963
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr ""
 
-#: fortran/module.c:6148
+#: fortran/module.c:6150
 #, gcc-internal-format
 msgid "Can't open module file %qs for writing at %C: %s"
 msgstr ""
 
-#: fortran/module.c:6169
+#: fortran/module.c:6171
 #, gcc-internal-format
 msgid "Error writing module file %qs for writing: %s"
 msgstr ""
 
-#: fortran/module.c:6180
+#: fortran/module.c:6182
 #, gcc-internal-format
 msgid "Can't delete module file %qs: %s"
-msgstr ""
+msgstr "Не вдалося вилучити файл модуля %qs: %s"
 
-#: fortran/module.c:6183
+#: fortran/module.c:6185
 #, gcc-internal-format
 msgid "Can't rename module file %qs to %qs: %s"
 msgstr ""
 
-#: fortran/module.c:6189
+#: fortran/module.c:6191
 #, gcc-internal-format
 msgid "Can't delete temporary module file %qs: %s"
 msgstr ""
 
-#: fortran/module.c:6246
+#: fortran/module.c:6248
 #, gcc-internal-format
 msgid "Symbol %qs at %C already declared"
 msgstr ""
 
-#: fortran/module.c:6317
+#: fortran/module.c:6319
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
-msgstr ""
+msgstr "import_iso_c_binding_module(): не вдалося створити символ для %s"
 
-#: fortran/module.c:6425 fortran/module.c:6769
+#: fortran/module.c:6427 fortran/module.c:6771
 #, gcc-internal-format
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr ""
 
-#: fortran/module.c:6553
+#: fortran/module.c:6555
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr ""
 
-#: fortran/module.c:6574 fortran/module.c:6607 fortran/module.c:6649
+#: fortran/module.c:6576 fortran/module.c:6609 fortran/module.c:6651
 #, gcc-internal-format
 msgid "Symbol %qs already declared"
-msgstr ""
+msgstr "Символ %qs вже оголошено"
 
-#: fortran/module.c:6754
+#: fortran/module.c:6756
 #, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:6776
+#: fortran/module.c:6778
 #, gcc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr ""
 
-#: fortran/module.c:6844
+#: fortran/module.c:6846
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr ""
 
-#: fortran/module.c:6898
+#: fortran/module.c:6900
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr ""
 
-#: fortran/module.c:6924
+#: fortran/module.c:6926
 #, gcc-internal-format, gfc-internal-format
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr ""
 
-#: fortran/module.c:6953
+#: fortran/module.c:6955
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
-msgstr ""
+msgstr "внутрішній модуль ISO_FORTRAN_ENV у %C"
 
-#: fortran/module.c:6965
+#: fortran/module.c:6967
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
-msgstr ""
+msgstr "модуль ISO_C_BINDING у %C"
 
-#: fortran/module.c:6978
+#: fortran/module.c:6980
 #, gcc-internal-format
 msgid "Can't find an intrinsic module named %qs at %C"
 msgstr ""
 
-#: fortran/module.c:6984
+#: fortran/module.c:6986
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
-msgstr ""
+msgstr "модуль IEEE_FEATURES у %C"
 
-#: fortran/module.c:6990
+#: fortran/module.c:6992
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
-msgstr ""
+msgstr "модуль IEEE_EXCEPTIONS у %C"
 
-#: fortran/module.c:6996
+#: fortran/module.c:6998
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
-msgstr ""
+msgstr "модуль IEEE_ARITHMETIC у %C"
 
-#: fortran/module.c:7006
+#: fortran/module.c:7008
 #, gcc-internal-format
 msgid "Can't open module file %qs for reading at %C: %s"
-msgstr ""
+msgstr "Не вдалося відкрити файл модуля %qs для читання у %C: %s"
 
-#: fortran/module.c:7009
+#: fortran/module.c:7011
 #, gcc-internal-format
 msgid "Module file %qs has not been generated, either because the module does not contain a MODULE PROCEDURE or there is an error in the module."
 msgstr ""
 
-#: fortran/module.c:7020
+#: fortran/module.c:7022
 #, gcc-internal-format
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:7043
+#: fortran/module.c:7045
 #, gcc-internal-format
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr ""
 
-#: fortran/module.c:7051
+#: fortran/module.c:7053
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr ""
 
-#: fortran/module.c:7066
+#: fortran/module.c:7068
 #, gcc-internal-format, gfc-internal-format
 msgid "Can't USE the same %smodule we're building"
 msgstr ""
 
 #: fortran/openmp.c:296 fortran/openmp.c:397 fortran/openmp.c:692
-#: fortran/openmp.c:3167
+#: fortran/openmp.c:3166
 #, gcc-internal-format, gfc-internal-format
 msgid "COMMON block /%s/ not found at %C"
 msgstr ""
@@ -56108,7 +56185,7 @@
 #: fortran/openmp.c:335 fortran/openmp.c:425
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in OpenMP variable list at %C"
-msgstr ""
+msgstr "Синтаксична помилка у списку змінних OpenMP у %C"
 
 #: fortran/openmp.c:499
 #, gcc-internal-format, gfc-internal-format
@@ -56118,7 +56195,7 @@
 #: fortran/openmp.c:561
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in OpenACC expression list at %C"
-msgstr ""
+msgstr "Синтаксична помилка у списку виразів OpenACC у %C"
 
 #: fortran/openmp.c:628
 #, gcc-internal-format
@@ -56177,859 +56254,859 @@
 
 #: fortran/openmp.c:2180
 #, gcc-internal-format, gfc-internal-format
-msgid "Invalid argument to !$ACC WAIT at %L"
-msgstr "Некоректний аргумент !$ACC WAIT у %L"
+msgid "Invalid argument to !$ACC WAIT at %C"
+msgstr "Некоректний аргумент !$ACC WAIT у %C"
 
-#: fortran/openmp.c:2188
+#: fortran/openmp.c:2187
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT clause at %L requires a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/openmp.c:2221
+#: fortran/openmp.c:2220
 #, gcc-internal-format, gfc-internal-format
 msgid "ACC CACHE directive must be inside of loop %C"
 msgstr ""
 
-#: fortran/openmp.c:2252
+#: fortran/openmp.c:2251
 #, gcc-internal-format
 msgid "Multiple loop axes specified for routine"
 msgstr ""
 
-#: fortran/openmp.c:2278
+#: fortran/openmp.c:2277
 #, gcc-internal-format, gfc-internal-format
 msgid "Only the !$ACC ROUTINE form without list is allowed in interface block at %C"
 msgstr ""
 
-#: fortran/openmp.c:2306
+#: fortran/openmp.c:2305
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$ACC ROUTINE ( NAME ) at %C, invalid function name %s"
 msgstr ""
 
-#: fortran/openmp.c:2315
+#: fortran/openmp.c:2314
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$ACC ROUTINE ( NAME ) at %C"
 msgstr ""
 
-#: fortran/openmp.c:2322
+#: fortran/openmp.c:2321
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$ACC ROUTINE ( NAME ) at %C, expecting ')' after NAME"
 msgstr ""
 
-#: fortran/openmp.c:2457 fortran/openmp.c:2481
+#: fortran/openmp.c:2456 fortran/openmp.c:2480
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP CRITICAL statement at %C"
 msgstr ""
 
-#: fortran/openmp.c:2548
+#: fortran/openmp.c:2547
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP FLUSH statement at %C"
 msgstr ""
 
-#: fortran/openmp.c:2942 fortran/openmp.c:6225
+#: fortran/openmp.c:2941 fortran/openmp.c:6230
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined %s !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2946 fortran/openmp.c:6229
+#: fortran/openmp.c:2945 fortran/openmp.c:6234
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2951
+#: fortran/openmp.c:2950
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2953
+#: fortran/openmp.c:2952
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2973
+#: fortran/openmp.c:2972
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after !$OMP DECLARE REDUCTION at %C"
 msgstr ""
 
-#: fortran/openmp.c:3010
+#: fortran/openmp.c:3009
 #, gcc-internal-format, gfc-internal-format
 msgid "Only the !$OMP DECLARE TARGET form without clauses is allowed in interface block at %C"
 msgstr ""
 
-#: fortran/openmp.c:3025
+#: fortran/openmp.c:3024
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after !$OMP DECLARE TARGET at %C"
 msgstr ""
 
-#: fortran/openmp.c:3048
+#: fortran/openmp.c:3047
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET variable at %L is an element of a COMMON block"
 msgstr ""
 
-#: fortran/openmp.c:3053
+#: fortran/openmp.c:3052
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET variable at %L previously mentioned in LINK clause and later in TO clause"
 msgstr ""
 
-#: fortran/openmp.c:3059
+#: fortran/openmp.c:3058
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET variable at %L previously mentioned in TO clause and later in LINK clause"
 msgstr ""
 
-#: fortran/openmp.c:3063
+#: fortran/openmp.c:3062
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable at %L mentioned multiple times in clauses of the same OMP DECLARE TARGET directive"
 msgstr ""
 
-#: fortran/openmp.c:3078
+#: fortran/openmp.c:3077
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET COMMON at %L previously mentioned in LINK clause and later in TO clause"
 msgstr ""
 
-#: fortran/openmp.c:3084
+#: fortran/openmp.c:3083
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET COMMON at %L previously mentioned in TO clause and later in LINK clause"
 msgstr ""
 
-#: fortran/openmp.c:3088
+#: fortran/openmp.c:3087
 #, gcc-internal-format, gfc-internal-format
 msgid "COMMON at %L mentioned multiple times in clauses of the same OMP DECLARE TARGET directive"
 msgstr ""
 
-#: fortran/openmp.c:3115
+#: fortran/openmp.c:3114
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$OMP DECLARE TARGET list at %C"
 msgstr ""
 
-#: fortran/openmp.c:3147
+#: fortran/openmp.c:3146
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate variable at %C is an element of a COMMON block"
 msgstr ""
 
-#: fortran/openmp.c:3184
+#: fortran/openmp.c:3183
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after OMP THREADPRIVATE at %C"
 msgstr ""
 
-#: fortran/openmp.c:3191
+#: fortran/openmp.c:3190
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$OMP THREADPRIVATE list at %C"
 msgstr ""
 
-#: fortran/openmp.c:3405
+#: fortran/openmp.c:3404
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after TASKWAIT clause at %C"
 msgstr ""
 
-#: fortran/openmp.c:3419
+#: fortran/openmp.c:3418
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after TASKYIELD clause at %C"
 msgstr ""
 
-#: fortran/openmp.c:3478
+#: fortran/openmp.c:3477
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP WORKSHARE statement at %C"
 msgstr ""
 
-#: fortran/openmp.c:3492
+#: fortran/openmp.c:3491
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP MASTER statement at %C"
 msgstr ""
 
-#: fortran/openmp.c:3551
+#: fortran/openmp.c:3550
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP ATOMIC statement at %C"
 msgstr ""
 
-#: fortran/openmp.c:3578
+#: fortran/openmp.c:3577
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP BARRIER statement at %C"
 msgstr ""
 
-#: fortran/openmp.c:3592
+#: fortran/openmp.c:3591
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP TASKGROUP statement at %C"
 msgstr ""
 
-#: fortran/openmp.c:3642
+#: fortran/openmp.c:3641
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP CANCELLATION POINT statement at %C"
 msgstr ""
 
-#: fortran/openmp.c:3662
+#: fortran/openmp.c:3661
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after NOWAIT clause at %C"
 msgstr ""
 
-#: fortran/openmp.c:3704
+#: fortran/openmp.c:3703
 #, gcc-internal-format, gfc-internal-format
 msgid "%s clause at %L requires a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/openmp.c:3715
+#: fortran/openmp.c:3714
 #, gcc-internal-format, gfc-internal-format
 msgid "INTEGER expression of %s clause at %L must be positive"
 msgstr ""
 
-#: fortran/openmp.c:3726
+#: fortran/openmp.c:3725
 #, gcc-internal-format, gfc-internal-format
 msgid "INTEGER expression of %s clause at %L must be non-negative"
 msgstr "Вираз INTEGER пункту %s у %L має бути невід'ємним"
 
-#: fortran/openmp.c:3737
+#: fortran/openmp.c:3736
 #, gcc-internal-format
 msgid "POINTER object %qs of derived type in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3740
+#: fortran/openmp.c:3739
 #, gcc-internal-format
 msgid "Cray pointer object %qs of derived type in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3743
+#: fortran/openmp.c:3742
 #, gcc-internal-format
 msgid "Cray pointee object %qs of derived type in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3749 fortran/openmp.c:4687
+#: fortran/openmp.c:3748 fortran/openmp.c:4686
 #, gcc-internal-format
 msgid "POINTER object %qs of polymorphic type in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3754
+#: fortran/openmp.c:3753
 #, gcc-internal-format
 msgid "Cray pointer object %qs of polymorphic type in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3759
+#: fortran/openmp.c:3758
 #, gcc-internal-format
 msgid "Cray pointee object %qs of polymorphic type in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3769 fortran/openmp.c:4385 fortran/openmp.c:4490
+#: fortran/openmp.c:3768 fortran/openmp.c:4384 fortran/openmp.c:4489
 #, gcc-internal-format
 msgid "Assumed size array %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3772
+#: fortran/openmp.c:3771
 #, gcc-internal-format
 msgid "Assumed rank array %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3776
+#: fortran/openmp.c:3775
 #, gcc-internal-format
 msgid "Noncontiguous deferred shape array %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3784
+#: fortran/openmp.c:3783
 #, gcc-internal-format
 msgid "ALLOCATABLE object %qs of derived type in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3789
+#: fortran/openmp.c:3788
 #, gcc-internal-format
 msgid "ALLOCATABLE object %qs of polymorphic type in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3801 fortran/openmp.c:4480
+#: fortran/openmp.c:3800 fortran/openmp.c:4479
 #, gcc-internal-format
 msgid "POINTER object %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3806 fortran/openmp.c:4691
+#: fortran/openmp.c:3805 fortran/openmp.c:4690
 #, gcc-internal-format
 msgid "Cray pointer object %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3811 fortran/openmp.c:4694
+#: fortran/openmp.c:3810 fortran/openmp.c:4693
 #, gcc-internal-format
 msgid "Cray pointee object %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3816 fortran/openmp.c:4682
+#: fortran/openmp.c:3815 fortran/openmp.c:4681
 #, gcc-internal-format
 msgid "ALLOCATABLE object %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3819
+#: fortran/openmp.c:3818
 #, gcc-internal-format
 msgid "VALUE object %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3862
+#: fortran/openmp.c:3861
 #, gcc-internal-format, gfc-internal-format
 msgid "Implicitly declared function %s used in !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:3911
+#: fortran/openmp.c:3910
 #, gcc-internal-format, gfc-internal-format
 msgid "Implicitly declared subroutine %s used in !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:3944
+#: fortran/openmp.c:3943
 #, gcc-internal-format, gfc-internal-format
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:3952 fortran/openmp.c:3963 fortran/resolve.c:10028
-#: fortran/resolve.c:11295
+#: fortran/openmp.c:3951 fortran/openmp.c:3962 fortran/resolve.c:10041
+#: fortran/resolve.c:11315
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/openmp.c:3967
+#: fortran/openmp.c:3966
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause without modifier at %L used together with IF clauses with modifiers"
 msgstr ""
 
-#: fortran/openmp.c:4044
+#: fortran/openmp.c:4043
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause modifier %s at %L not appropriate for the current OpenMP construct"
 msgstr ""
 
-#: fortran/openmp.c:4054
+#: fortran/openmp.c:4053
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/openmp.c:4064
+#: fortran/openmp.c:4063
 #, gcc-internal-format, gfc-internal-format
 msgid "SCHEDULE clause's chunk_size at %L requires a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/openmp.c:4069
+#: fortran/openmp.c:4068
 #, gcc-internal-format, gfc-internal-format
 msgid "INTEGER expression of SCHEDULE clause's chunk_size at %L must be positive"
 msgstr ""
 
-#: fortran/openmp.c:4084
+#: fortran/openmp.c:4083
 #, gcc-internal-format
 msgid "Variable %qs is not a dummy argument at %L"
 msgstr ""
 
-#: fortran/openmp.c:4116
+#: fortran/openmp.c:4115 fortran/openmp.c:5998
 #, gcc-internal-format
 msgid "Object %qs is not a variable at %L"
 msgstr ""
 
-#: fortran/openmp.c:4132 fortran/openmp.c:4143 fortran/openmp.c:4151
-#: fortran/openmp.c:4162 fortran/openmp.c:4174 fortran/openmp.c:4189
-#: fortran/openmp.c:6023
+#: fortran/openmp.c:4131 fortran/openmp.c:4142 fortran/openmp.c:4150
+#: fortran/openmp.c:4161 fortran/openmp.c:4173 fortran/openmp.c:4188
+#: fortran/openmp.c:6028
 #, gcc-internal-format
 msgid "Symbol %qs present on multiple clauses at %L"
 msgstr ""
 
-#: fortran/openmp.c:4196
+#: fortran/openmp.c:4195
 #, gcc-internal-format
 msgid "Array %qs is not permitted in reduction at %L"
 msgstr ""
 
-#: fortran/openmp.c:4209
+#: fortran/openmp.c:4208
 #, gcc-internal-format
 msgid "Symbol %qs present on both FROM and TO clauses at %L"
 msgstr ""
 
-#: fortran/openmp.c:4231
+#: fortran/openmp.c:4230
 #, gcc-internal-format
 msgid "Non-THREADPRIVATE object %qs in COPYIN clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4239
+#: fortran/openmp.c:4238
 #, gcc-internal-format
 msgid "Assumed size array %qs in COPYPRIVATE clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4242
+#: fortran/openmp.c:4241
 #, gcc-internal-format
 msgid "INTENT(IN) POINTER %qs in COPYPRIVATE clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4250
+#: fortran/openmp.c:4249
 #, gcc-internal-format
 msgid "THREADPRIVATE object %qs in SHARED clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4253
+#: fortran/openmp.c:4252
 #, gcc-internal-format
 msgid "Cray pointee %qs in SHARED clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4256
+#: fortran/openmp.c:4255
 #, gcc-internal-format
 msgid "ASSOCIATE name %qs in SHARED clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4271
+#: fortran/openmp.c:4270
 #, gcc-internal-format
 msgid "%qs in ALIGNED clause must be POINTER, ALLOCATABLE, Cray pointer or C_PTR at %L"
 msgstr ""
 
-#: fortran/openmp.c:4283
+#: fortran/openmp.c:4282
 #, gcc-internal-format
 msgid "%qs in ALIGNED clause at %L requires a scalar positive constant integer alignment expression"
 msgstr ""
 
-#: fortran/openmp.c:4302
+#: fortran/openmp.c:4301
 #, gcc-internal-format, gfc-internal-format
 msgid "SINK dependence type only allowed on ORDERED directive at %L"
 msgstr ""
 
-#: fortran/openmp.c:4306
+#: fortran/openmp.c:4305
 #, gcc-internal-format, gfc-internal-format
 msgid "DEPEND SINK used together with DEPEND SOURCE on the same construct at %L"
 msgstr ""
 
-#: fortran/openmp.c:4316
+#: fortran/openmp.c:4315
 #, gcc-internal-format, gfc-internal-format
 msgid "SINK addend not a constant integer at %L"
 msgstr ""
 
-#: fortran/openmp.c:4322
+#: fortran/openmp.c:4321
 #, gcc-internal-format, gfc-internal-format
 msgid "Only SOURCE or SINK dependence types are allowed on ORDERED directive at %L"
 msgstr ""
 
-#: fortran/openmp.c:4333 fortran/openmp.c:4354
+#: fortran/openmp.c:4332 fortran/openmp.c:4353
 #, gcc-internal-format
 msgid "%qs in %s clause at %L is not a proper array section"
 msgstr ""
 
-#: fortran/openmp.c:4337
+#: fortran/openmp.c:4336
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarrays not supported in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4346
+#: fortran/openmp.c:4345
 #, gcc-internal-format, gfc-internal-format
 msgid "Stride should not be specified for array section in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4367
+#: fortran/openmp.c:4366
 #, gcc-internal-format
 msgid "%qs in DEPEND clause at %L is a zero size array section"
 msgstr ""
 
-#: fortran/openmp.c:4403
+#: fortran/openmp.c:4402
 #, gcc-internal-format, gfc-internal-format
 msgid "TARGET%s with map-type other than TO, FROM, TOFROM, or ALLOC on MAP clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4419
+#: fortran/openmp.c:4418
 #, gcc-internal-format, gfc-internal-format
 msgid "TARGET ENTER DATA with map-type other than TO, or ALLOC on MAP clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4434
+#: fortran/openmp.c:4433
 #, gcc-internal-format, gfc-internal-format
 msgid "TARGET EXIT DATA with map-type other than FROM, RELEASE, or DELETE on MAP clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4450 fortran/openmp.c:4466
+#: fortran/openmp.c:4449 fortran/openmp.c:4465
 #, gcc-internal-format
 msgid "THREADPRIVATE object %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4453 fortran/openmp.c:4469
+#: fortran/openmp.c:4452 fortran/openmp.c:4468
 #, gcc-internal-format
 msgid "Cray pointee %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4472
+#: fortran/openmp.c:4471
 #, gcc-internal-format
 msgid "ASSOCIATE name %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4477
+#: fortran/openmp.c:4476
 #, gcc-internal-format
 msgid "Procedure pointer %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4483
+#: fortran/openmp.c:4482
 #, gcc-internal-format
 msgid "Cray pointer %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4493
+#: fortran/openmp.c:4492
 #, gcc-internal-format
 msgid "Variable %qs in %s clause is used in NAMELIST statement at %L"
 msgstr ""
 
 #. case OMP_LIST_REDUCTION:
-#: fortran/openmp.c:4503
+#: fortran/openmp.c:4502
 #, gcc-internal-format
 msgid "INTENT(IN) POINTER %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4596
+#: fortran/openmp.c:4595
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP DECLARE REDUCTION %s not found for type %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:4622
+#: fortran/openmp.c:4621
 #, gcc-internal-format, gfc-internal-format
 msgid "LINEAR clause modifier used on DO or SIMD construct at %L"
 msgstr ""
 
-#: fortran/openmp.c:4627
+#: fortran/openmp.c:4626
 #, gcc-internal-format, gfc-internal-format
 msgid "LINEAR clause specified together with ORDERED clause with argument at %L"
 msgstr ""
 
-#: fortran/openmp.c:4632
+#: fortran/openmp.c:4631
 #, gcc-internal-format
 msgid "LINEAR variable %qs must be INTEGER at %L"
 msgstr ""
 
-#: fortran/openmp.c:4637
+#: fortran/openmp.c:4636
 #, gcc-internal-format
 msgid "LINEAR dummy argument %qs with VALUE attribute with %s modifier at %L"
 msgstr ""
 
-#: fortran/openmp.c:4648
+#: fortran/openmp.c:4647
 #, gcc-internal-format
 msgid "%qs in LINEAR clause at %L requires a scalar integer linear-step expression"
 msgstr ""
 
-#: fortran/openmp.c:4665
+#: fortran/openmp.c:4664
 #, gcc-internal-format
 msgid "%qs in LINEAR clause at %L requires a constant integer linear-step expression or dummy argument specified in UNIFORM clause"
 msgstr ""
 
-#: fortran/openmp.c:4699
+#: fortran/openmp.c:4698
 #, gcc-internal-format
 msgid "%s clause variable %qs at %L is neither a POINTER nor an array"
 msgstr ""
 
-#: fortran/openmp.c:4731
+#: fortran/openmp.c:4730
 #, gcc-internal-format, gfc-internal-format
 msgid "DIST_SCHEDULE clause's chunk_size at %L requires a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/openmp.c:4763
+#: fortran/openmp.c:4762
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible use of TILE and COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:4765
+#: fortran/openmp.c:4764
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE dependence type only allowed on ORDERED directive at %L"
 msgstr ""
 
-#: fortran/openmp.c:4778
+#: fortran/openmp.c:4777
 #, gcc-internal-format, gfc-internal-format
 msgid "%s must contain at least one MAP clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4875
+#: fortran/openmp.c:4874
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected !$OMP ATOMIC expression at %L"
 msgstr "неочікуваний вираз !$OMP ATOMIC у %L"
 
-#: fortran/openmp.c:4904
+#: fortran/openmp.c:4903
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC statement must set a scalar variable of intrinsic type at %L"
 msgstr ""
 
-#: fortran/openmp.c:4929
+#: fortran/openmp.c:4928
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC READ statement must read from a scalar variable of intrinsic type at %L"
 msgstr ""
 
-#: fortran/openmp.c:4934
+#: fortran/openmp.c:4933
 #, gcc-internal-format, gfc-internal-format
 msgid "expr in !$OMP ATOMIC WRITE assignment var = expr must be scalar and cannot reference var at %L"
 msgstr ""
 
-#: fortran/openmp.c:4956 fortran/openmp.c:5247
+#: fortran/openmp.c:4955 fortran/openmp.c:5246
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE capture statement must read from a scalar variable of intrinsic type at %L"
 msgstr ""
 
-#: fortran/openmp.c:4971
+#: fortran/openmp.c:4970
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE update statement must set a scalar variable of intrinsic type at %L"
 msgstr ""
 
-#: fortran/openmp.c:4978 fortran/openmp.c:5254
+#: fortran/openmp.c:4977 fortran/openmp.c:5253
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE capture statement reads from different variable than update statement writes into at %L"
 msgstr ""
 
-#: fortran/openmp.c:4994
+#: fortran/openmp.c:4993
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC with ALLOCATABLE variable at %L"
 msgstr ""
 
-#: fortran/openmp.c:5036
+#: fortran/openmp.c:5035
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment operator must be binary +, *, -, /, .AND., .OR., .EQV. or .NEQV. at %L"
 msgstr ""
 
-#: fortran/openmp.c:5084
+#: fortran/openmp.c:5083
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment must be var = var op expr or var = expr op var at %L"
 msgstr ""
 
-#: fortran/openmp.c:5098
+#: fortran/openmp.c:5097
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC var = var op expr not mathematically equivalent to var = var op (expr) at %L"
 msgstr ""
 
-#: fortran/openmp.c:5130
+#: fortran/openmp.c:5129
 #, gcc-internal-format, gfc-internal-format
 msgid "expr in !$OMP ATOMIC assignment var = var op expr must be scalar and cannot reference var at %L"
 msgstr ""
 
-#: fortran/openmp.c:5154
+#: fortran/openmp.c:5153
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment intrinsic IAND, IOR or IEOR must have two arguments at %L"
 msgstr ""
 
-#: fortran/openmp.c:5161
+#: fortran/openmp.c:5160
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment intrinsic must be MIN, MAX, IAND, IOR or IEOR at %L"
 msgstr ""
 
-#: fortran/openmp.c:5178
+#: fortran/openmp.c:5177
 #, gcc-internal-format
 msgid "!$OMP ATOMIC intrinsic arguments except one must not reference %qs at %L"
 msgstr ""
 
-#: fortran/openmp.c:5185
+#: fortran/openmp.c:5184
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC intrinsic arguments must be scalar at %L"
 msgstr ""
 
-#: fortran/openmp.c:5193
+#: fortran/openmp.c:5192
 #, gcc-internal-format
 msgid "First or last !$OMP ATOMIC intrinsic argument must be %qs at %L"
 msgstr ""
 
-#: fortran/openmp.c:5211
+#: fortran/openmp.c:5210
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment must have an operator or intrinsic on right hand side at %L"
 msgstr ""
 
-#: fortran/openmp.c:5225
+#: fortran/openmp.c:5224
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE capture statement must set a scalar variable of intrinsic type at %L"
 msgstr ""
 
-#: fortran/openmp.c:5544
+#: fortran/openmp.c:5543
 #, gcc-internal-format, gfc-internal-format
 msgid "%s cannot be a DO WHILE or DO without loop control at %L"
 msgstr ""
 
-#: fortran/openmp.c:5550
+#: fortran/openmp.c:5549
 #, gcc-internal-format, gfc-internal-format
 msgid "%s cannot be a DO CONCURRENT loop at %L"
 msgstr ""
 
-#: fortran/openmp.c:5556
+#: fortran/openmp.c:5555
 #, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable must be of type integer at %L"
 msgstr ""
 
-#: fortran/openmp.c:5560
+#: fortran/openmp.c:5559
 #, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable must not be THREADPRIVATE at %L"
 msgstr ""
 
-#: fortran/openmp.c:5573
+#: fortran/openmp.c:5572
 #, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable present on clause other than PRIVATE or LASTPRIVATE at %L"
 msgstr ""
 
-#: fortran/openmp.c:5577
+#: fortran/openmp.c:5576
 #, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable present on clause other than LASTPRIVATE at %L"
 msgstr ""
 
-#: fortran/openmp.c:5581
+#: fortran/openmp.c:5580
 #, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable present on clause other than LINEAR at %L"
 msgstr ""
 
-#: fortran/openmp.c:5599
+#: fortran/openmp.c:5598
 #, gcc-internal-format, gfc-internal-format
 msgid "%s collapsed loops don't form rectangular iteration space at %L"
 msgstr ""
 
-#: fortran/openmp.c:5611
+#: fortran/openmp.c:5610
 #, gcc-internal-format, gfc-internal-format
 msgid "collapsed %s loops not perfectly nested at %L"
 msgstr ""
 
-#: fortran/openmp.c:5620 fortran/openmp.c:5628
+#: fortran/openmp.c:5619 fortran/openmp.c:5627
 #, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for collapsed %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:5712 fortran/openmp.c:5725
+#: fortran/openmp.c:5711 fortran/openmp.c:5724
 #, gcc-internal-format, gfc-internal-format
 msgid "The %s directive cannot be specified within a %s region at %L"
 msgstr ""
 
-#: fortran/openmp.c:5744
+#: fortran/openmp.c:5743
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP cannot be a DO WHILE or DO without loop control at %L"
 msgstr ""
 
-#: fortran/openmp.c:5750
+#: fortran/openmp.c:5749
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP iteration variable must be of type integer at %L"
 msgstr ""
 
-#: fortran/openmp.c:5766
+#: fortran/openmp.c:5765
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s loops don't form rectangular iteration space at %L"
 msgstr ""
 
-#: fortran/openmp.c:5778
+#: fortran/openmp.c:5777
 #, gcc-internal-format, gfc-internal-format
 msgid "%s !$ACC LOOP loops not perfectly nested at %L"
 msgstr ""
 
-#: fortran/openmp.c:5788 fortran/openmp.c:5797
+#: fortran/openmp.c:5787 fortran/openmp.c:5796
 #, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for %s !$ACC LOOP at %L"
 msgstr ""
 
-#: fortran/openmp.c:5812 fortran/openmp.c:5819
+#: fortran/openmp.c:5811 fortran/openmp.c:5818
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s in PARALLEL region doesn't allow %s arguments at %L"
 msgstr ""
 
-#: fortran/openmp.c:5841
+#: fortran/openmp.c:5840
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside another loop parallelized across gangs at %L"
 msgstr ""
 
-#: fortran/openmp.c:5845 fortran/openmp.c:5849
+#: fortran/openmp.c:5844 fortran/openmp.c:5848
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside loop parallelized across workers at %L"
 msgstr ""
 
-#: fortran/openmp.c:5856
+#: fortran/openmp.c:5855
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across workers at %L"
 msgstr ""
 
-#: fortran/openmp.c:5860
+#: fortran/openmp.c:5859
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across vectors at %L"
 msgstr ""
 
-#: fortran/openmp.c:5866
+#: fortran/openmp.c:5865
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across vectors is not allowed inside another loop parallelized across vectors at %L"
 msgstr ""
 
-#: fortran/openmp.c:5878
+#: fortran/openmp.c:5877
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with INDEPENDENT at %L"
 msgstr ""
 
-#: fortran/openmp.c:5880
+#: fortran/openmp.c:5879
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with GANG at %L"
 msgstr ""
 
-#: fortran/openmp.c:5882
+#: fortran/openmp.c:5881
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with WORKER at %L"
 msgstr ""
 
-#: fortran/openmp.c:5884
+#: fortran/openmp.c:5883
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with VECTOR at %L"
 msgstr ""
 
-#: fortran/openmp.c:5886
+#: fortran/openmp.c:5885
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with AUTO at %L"
 msgstr ""
 
-#: fortran/openmp.c:5891
+#: fortran/openmp.c:5890
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with GANG at %L"
 msgstr ""
 
-#: fortran/openmp.c:5893
+#: fortran/openmp.c:5892
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with WORKER at %L"
 msgstr ""
 
-#: fortran/openmp.c:5895
+#: fortran/openmp.c:5894
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with VECTOR at %L"
 msgstr ""
 
-#: fortran/openmp.c:5899
+#: fortran/openmp.c:5898
 #, gcc-internal-format, gfc-internal-format
 msgid "Tiled loop cannot be parallelized across gangs, workers and vectors at the same time at %L"
 msgstr ""
 
-#: fortran/openmp.c:5934
+#: fortran/openmp.c:5933
 #, gcc-internal-format, gfc-internal-format
 msgid "TILE requires constant expression at %L"
 msgstr ""
 
-#: fortran/openmp.c:5999
+#: fortran/openmp.c:6004
 #, gcc-internal-format
 msgid "PARAMETER object %qs is not allowed at %L"
 msgstr ""
 
-#: fortran/openmp.c:6006
+#: fortran/openmp.c:6011
 #, gcc-internal-format
 msgid "Array sections: %qs not allowed in !$ACC DECLARE at %L"
 msgstr ""
 
-#: fortran/openmp.c:6133
+#: fortran/openmp.c:6138
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP TARGET UPDATE at %L requires at least one TO or FROM clause"
 msgstr ""
 
-#: fortran/openmp.c:6155
+#: fortran/openmp.c:6160
 #, gcc-internal-format
 msgid "!$OMP DECLARE SIMD should refer to containing procedure %qs at %L"
 msgstr ""
 
-#: fortran/openmp.c:6179
+#: fortran/openmp.c:6184
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_PRIV or OMP_ORIG used in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6187
+#: fortran/openmp.c:6192
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_OUT or OMP_IN used in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6216
+#: fortran/openmp.c:6221
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid operator for !$OMP DECLARE REDUCTION %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:6238
+#: fortran/openmp.c:6243
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER length in !$OMP DECLARE REDUCTION %s not constant at %L"
 msgstr ""
 
-#: fortran/openmp.c:6254
+#: fortran/openmp.c:6259
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6269
+#: fortran/openmp.c:6274
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6279
+#: fortran/openmp.c:6284
 #, gcc-internal-format, gfc-internal-format
 msgid "One of actual subroutine arguments in INITIALIZER clause of !$OMP DECLARE REDUCTION must be OMP_PRIV at %L"
 msgstr ""
 
-#: fortran/openmp.c:6287
+#: fortran/openmp.c:6292
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing INITIALIZER clause for !$OMP DECLARE REDUCTION of derived type without default initializer at %L"
 msgstr ""
@@ -57139,492 +57216,492 @@
 msgid "Unclassifiable statement at %C"
 msgstr ""
 
-#: fortran/parse.c:629
+#: fortran/parse.c:631
 #, gcc-internal-format, gfc-internal-format
 msgid "OpenACC directives at %C may not appear in PURE procedures"
 msgstr ""
 
-#: fortran/parse.c:705
+#: fortran/parse.c:707
 #, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable OpenACC directive at %C"
 msgstr ""
 
-#: fortran/parse.c:831 fortran/parse.c:1040
+#: fortran/parse.c:835 fortran/parse.c:1044
 #, gcc-internal-format, gfc-internal-format
 msgid "OpenMP directives other than SIMD or DECLARE TARGET at %C may not appear in PURE or ELEMENTAL procedures"
 msgstr ""
 
-#: fortran/parse.c:1024
+#: fortran/parse.c:1028
 #, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable OpenMP directive at %C"
 msgstr ""
 
-#: fortran/parse.c:1076
+#: fortran/parse.c:1080
 #, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable GCC directive at %C"
 msgstr ""
 
-#: fortran/parse.c:1135 fortran/parse.c:1362
+#: fortran/parse.c:1139 fortran/parse.c:1366
 #, gcc-internal-format, gfc-internal-format
 msgid "Zero is not a valid statement label at %C"
 msgstr ""
 
-#: fortran/parse.c:1142 fortran/parse.c:1354
+#: fortran/parse.c:1146 fortran/parse.c:1358
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-numeric character in statement label at %C"
 msgstr ""
 
-#: fortran/parse.c:1154 fortran/parse.c:1403
+#: fortran/parse.c:1158 fortran/parse.c:1407
 #, gcc-internal-format, gfc-internal-format
 msgid "Semicolon at %C needs to be preceded by statement"
 msgstr ""
 
-#: fortran/parse.c:1161 fortran/parse.c:1418
+#: fortran/parse.c:1165 fortran/parse.c:1422
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label without statement at %L"
 msgstr ""
 
-#: fortran/parse.c:1224 fortran/parse.c:1405
+#: fortran/parse.c:1228 fortran/parse.c:1409
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Semicolon at %C without preceding statement"
 msgstr ""
 
-#: fortran/parse.c:1247 fortran/parse.c:1381
+#: fortran/parse.c:1251 fortran/parse.c:1385
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad continuation line at %C"
 msgstr ""
 
-#: fortran/parse.c:1679
+#: fortran/parse.c:1683
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT statement at %L does not have a statement label"
 msgstr ""
 
-#: fortran/parse.c:2435
+#: fortran/parse.c:2439
 #, gcc-internal-format
 msgid "gfc_ascii_statement(): Bad statement code"
 msgstr ""
 
-#: fortran/parse.c:2577
+#: fortran/parse.c:2581
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement at %C"
 msgstr ""
 
-#: fortran/parse.c:2732
+#: fortran/parse.c:2736
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot follow %s statement at %L"
 msgstr ""
 
-#: fortran/parse.c:2749
+#: fortran/parse.c:2753
 #, gcc-internal-format
 msgid "Unexpected end of file in %qs"
 msgstr ""
 
-#: fortran/parse.c:2784
+#: fortran/parse.c:2788
 #, gcc-internal-format
 msgid "Derived-type %qs with SEQUENCE must not have a CONTAINS section at %C"
 msgstr ""
 
-#: fortran/parse.c:2787
+#: fortran/parse.c:2791
 #, gcc-internal-format
 msgid "Derived-type %qs with BIND(C) must not have a CONTAINS section at %C"
 msgstr ""
 
-#: fortran/parse.c:2807
+#: fortran/parse.c:2811
 #, gcc-internal-format, gfc-internal-format
 msgid "Components in TYPE at %C must precede CONTAINS"
 msgstr ""
 
-#: fortran/parse.c:2811
+#: fortran/parse.c:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound procedure at %C"
 msgstr ""
 
-#: fortran/parse.c:2819
+#: fortran/parse.c:2823
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC binding at %C"
 msgstr ""
 
-#: fortran/parse.c:2827
+#: fortran/parse.c:2831
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure declaration at %C"
 msgstr ""
 
-#: fortran/parse.c:2839
+#: fortran/parse.c:2843
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type definition at %C with empty CONTAINS section"
 msgstr ""
 
-#: fortran/parse.c:2849 fortran/parse.c:3304
+#: fortran/parse.c:2853 fortran/parse.c:3308
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement in TYPE at %C must be inside a MODULE"
 msgstr ""
 
-#: fortran/parse.c:2856
+#: fortran/parse.c:2860
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede procedure bindings"
 msgstr ""
 
-#: fortran/parse.c:2863 fortran/parse.c:3317
+#: fortran/parse.c:2867 fortran/parse.c:3321
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PRIVATE statement at %C"
 msgstr ""
 
-#: fortran/parse.c:2873
+#: fortran/parse.c:2877
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede CONTAINS"
 msgstr ""
 
-#: fortran/parse.c:2877
+#: fortran/parse.c:2881
 #, gcc-internal-format, gfc-internal-format
 msgid "Already inside a CONTAINS block at %C"
 msgstr ""
 
-#: fortran/parse.c:2996
+#: fortran/parse.c:3000
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s at %L of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray, which is not possible as the component has the pointer attribute"
 msgstr ""
 
-#: fortran/parse.c:3002
+#: fortran/parse.c:3006
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer component %s at %L has a noncoarray subcomponent of type LOCK_TYPE, which must have a codimension or be a subcomponent of a coarray"
 msgstr ""
 
-#: fortran/parse.c:3007
+#: fortran/parse.c:3011
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L of type LOCK_TYPE must have a codimension"
 msgstr ""
 
-#: fortran/parse.c:3011
+#: fortran/parse.c:3015
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L must have a codimension as it has a noncoarray subcomponent of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/parse.c:3016
+#: fortran/parse.c:3020
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as already a coarray subcomponent exists)"
 msgstr ""
 
-#: fortran/parse.c:3023
+#: fortran/parse.c:3027
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as %s at %L has a codimension or a coarray subcomponent)"
 msgstr ""
 
-#: fortran/parse.c:3033
+#: fortran/parse.c:3037
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s at %L of type EVENT_TYPE must have a codimension or be a subcomponent of a coarray, which is not possible as the component has the pointer attribute"
 msgstr ""
 
-#: fortran/parse.c:3039
+#: fortran/parse.c:3043
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer component %s at %L has a noncoarray subcomponent of type EVENT_TYPE, which must have a codimension or be a subcomponent of a coarray"
 msgstr ""
 
-#: fortran/parse.c:3044
+#: fortran/parse.c:3048
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L of type EVENT_TYPE must have a codimension"
 msgstr ""
 
-#: fortran/parse.c:3048
+#: fortran/parse.c:3052
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L must have a codimension as it has a noncoarray subcomponent of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/parse.c:3053
+#: fortran/parse.c:3057
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as already a coarray subcomponent exists)"
 msgstr ""
 
-#: fortran/parse.c:3060
+#: fortran/parse.c:3064
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as %s at %L has a codimension or a coarray subcomponent)"
 msgstr ""
 
-#: fortran/parse.c:3112
+#: fortran/parse.c:3116
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to create map component '%s'"
 msgstr ""
 
-#: fortran/parse.c:3145
+#: fortran/parse.c:3149
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to create union component '%s'"
 msgstr ""
 
-#: fortran/parse.c:3200
+#: fortran/parse.c:3204
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in nested structure declaration at %C"
 msgstr "Синтаксична помилка у оголошенні вкладеної структури у %C"
 
-#: fortran/parse.c:3287
+#: fortran/parse.c:3291
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside CONTAINS"
 msgstr ""
 
-#: fortran/parse.c:3295
+#: fortran/parse.c:3299
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type definition at %C without components"
 msgstr ""
 
-#: fortran/parse.c:3311
+#: fortran/parse.c:3315
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede structure components"
 msgstr ""
 
-#: fortran/parse.c:3328
+#: fortran/parse.c:3332
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede structure components"
 msgstr ""
 
-#: fortran/parse.c:3334
+#: fortran/parse.c:3338
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE attribute at %C already specified in TYPE statement"
 msgstr ""
 
-#: fortran/parse.c:3339
+#: fortran/parse.c:3343
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SEQUENCE statement at %C"
 msgstr ""
 
-#: fortran/parse.c:3349
+#: fortran/parse.c:3353
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS block in derived type definition at %C"
 msgstr ""
 
-#: fortran/parse.c:3407
+#: fortran/parse.c:3411
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM declaration at %C has no ENUMERATORS"
 msgstr ""
 
-#: fortran/parse.c:3494
+#: fortran/parse.c:3498
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in INTERFACE block at %C"
 msgstr ""
 
-#: fortran/parse.c:3518
+#: fortran/parse.c:3522
 #, gcc-internal-format
 msgid "Name %qs of ABSTRACT INTERFACE at %C cannot be the same as an intrinsic type"
 msgstr ""
 
-#: fortran/parse.c:3552
+#: fortran/parse.c:3556
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement at %C in INTERFACE body"
 msgstr ""
 
-#: fortran/parse.c:3570
+#: fortran/parse.c:3574
 #, gcc-internal-format
 msgid "INTERFACE procedure %qs at %L has the same name as the enclosing procedure"
 msgstr ""
 
-#: fortran/parse.c:3700
+#: fortran/parse.c:3704
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/parse.c:3732
+#: fortran/parse.c:3736
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement is not allowed inside of BLOCK DATA at %C"
 msgstr ""
 
-#: fortran/parse.c:3822
+#: fortran/parse.c:3826
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement must appear in a MODULE"
 msgstr ""
 
-#: fortran/parse.c:3830
+#: fortran/parse.c:3834
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C follows another accessibility specification"
 msgstr ""
 
-#: fortran/parse.c:3882
+#: fortran/parse.c:3886
 #, gcc-internal-format
 msgid "Bad kind expression for function %qs at %L"
 msgstr ""
 
-#: fortran/parse.c:3886
+#: fortran/parse.c:3890
 #, gcc-internal-format
 msgid "The type for function %qs at %L is not accessible"
 msgstr ""
 
-#: fortran/parse.c:3946
+#: fortran/parse.c:3950
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C follows previous unmasked ELSEWHERE"
 msgstr ""
 
-#: fortran/parse.c:3968
+#: fortran/parse.c:3972
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in WHERE block at %C"
 msgstr ""
 
-#: fortran/parse.c:4027
+#: fortran/parse.c:4031
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in FORALL block at %C"
 msgstr ""
 
-#: fortran/parse.c:4078
+#: fortran/parse.c:4082
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSE IF statement at %C cannot follow ELSE statement at %L"
 msgstr ""
 
-#: fortran/parse.c:4096
+#: fortran/parse.c:4100
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ELSE statements at %L and %C"
 msgstr ""
 
-#: fortran/parse.c:4157
+#: fortran/parse.c:4161
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected a CASE or END SELECT statement following SELECT CASE at %C"
 msgstr ""
 
-#: fortran/parse.c:4241
+#: fortran/parse.c:4245
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected TYPE IS, CLASS IS or END SELECT statement following SELECT TYPE at %C"
 msgstr ""
 
-#: fortran/parse.c:4303
+#: fortran/parse.c:4307
 #, gcc-internal-format
 msgid "Variable %qs at %C cannot be redefined inside loop beginning at %L"
 msgstr ""
 
-#: fortran/parse.c:4336
+#: fortran/parse.c:4340
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is within another block"
 msgstr ""
 
-#: fortran/parse.c:4346
+#: fortran/parse.c:4350
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is interwoven with another DO loop"
 msgstr ""
 
-#: fortran/parse.c:4372
+#: fortran/parse.c:4376
 #, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL block inside of OpenACC region at %C"
 msgstr ""
 
-#: fortran/parse.c:4373
+#: fortran/parse.c:4377
 #, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL block inside of OpenMP region at %C"
 msgstr ""
 
-#: fortran/parse.c:4399
+#: fortran/parse.c:4403
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label in END CRITICAL at %C does not match CRITICAL label"
 msgstr ""
 
-#: fortran/parse.c:4468
+#: fortran/parse.c:4472
 #, gcc-internal-format, gfc-internal-format
 msgid "BLOCK construct at %C"
 msgstr ""
 
-#: fortran/parse.c:4502
+#: fortran/parse.c:4506
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSOCIATE construct at %C"
 msgstr ""
 
-#: fortran/parse.c:4690
+#: fortran/parse.c:4694
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label in ENDDO at %C doesn't match DO label"
 msgstr ""
 
-#: fortran/parse.c:4706
+#: fortran/parse.c:4710
 #, gcc-internal-format, gfc-internal-format
 msgid "Named block DO at %L requires matching ENDDO name"
 msgstr ""
 
-#: fortran/parse.c:4897
+#: fortran/parse.c:4901
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing !$OMP END ATOMIC after !$OMP ATOMIC CAPTURE at %C"
 msgstr ""
 
-#: fortran/parse.c:4913 fortran/parse.c:4972
+#: fortran/parse.c:4917 fortran/parse.c:4976
 #, gcc-internal-format, gfc-internal-format
 msgid "OpenACC directive inside of CRITICAL block at %C"
 msgstr ""
 
-#: fortran/parse.c:4947
+#: fortran/parse.c:4951
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s at %C"
 msgstr ""
 
-#: fortran/parse.c:4991
+#: fortran/parse.c:4995
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected DO loop at %C"
 msgstr ""
 
-#: fortran/parse.c:5011
+#: fortran/parse.c:5015
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant !$ACC END LOOP at %C"
 msgstr ""
 
-#: fortran/parse.c:5225
+#: fortran/parse.c:5229
 #, gcc-internal-format, gfc-internal-format
 msgid "Name after !$omp critical and !$omp end critical does not match at %C"
 msgstr ""
 
-#: fortran/parse.c:5283
+#: fortran/parse.c:5287
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot terminate a non-block DO loop"
 msgstr ""
 
-#: fortran/parse.c:5297
+#: fortran/parse.c:5301
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %C after the first executable statement"
 msgstr ""
 
-#: fortran/parse.c:5423
+#: fortran/parse.c:5427
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive does not commence a loop at %C"
 msgstr ""
 
-#: fortran/parse.c:5538
+#: fortran/parse.c:5542
 #, gcc-internal-format
 msgid "Contained procedure %qs at %C is already ambiguous"
 msgstr ""
 
-#: fortran/parse.c:5595
+#: fortran/parse.c:5599
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in CONTAINS section at %C"
 msgstr ""
 
-#: fortran/parse.c:5620
+#: fortran/parse.c:5624
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS statement without FUNCTION or SUBROUTINE statement at %L"
 msgstr ""
 
-#: fortran/parse.c:5732
+#: fortran/parse.c:5736
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS statement at %C is already in a contained program unit"
 msgstr ""
 
-#: fortran/parse.c:5784
+#: fortran/parse.c:5788
 #, gcc-internal-format
 msgid "Global binding name %qs at %L is already being used as a %s at %L"
 msgstr ""
 
-#: fortran/parse.c:5788
+#: fortran/parse.c:5792
 #, gcc-internal-format
 msgid "Global name %qs at %L is already being used as a %s at %L"
 msgstr ""
 
-#: fortran/parse.c:5794
+#: fortran/parse.c:5798
 #, gcc-internal-format
 msgid "Global binding name %qs at %L is already being used at %L"
 msgstr ""
 
-#: fortran/parse.c:5797
+#: fortran/parse.c:5801
 #, gcc-internal-format
 msgid "Global name %qs at %L is already being used at %L"
 msgstr ""
 
-#: fortran/parse.c:5819
+#: fortran/parse.c:5823
 #, gcc-internal-format, gfc-internal-format
 msgid "Blank BLOCK DATA at %C conflicts with prior BLOCK DATA at %L"
 msgstr ""
 
-#: fortran/parse.c:5845
+#: fortran/parse.c:5849
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in BLOCK DATA at %C"
 msgstr ""
 
-#: fortran/parse.c:5949
+#: fortran/parse.c:5953
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in MODULE at %C"
 msgstr ""
@@ -57632,7 +57709,7 @@
 #. If we see a duplicate main program, shut down.  If the second
 #. instance is an implied main program, i.e. data decls or executable
 #. statements, we're in for lots of errors.
-#: fortran/parse.c:6333
+#: fortran/parse.c:6337
 #, gcc-internal-format, gfc-internal-format
 msgid "Two main PROGRAMs at %L and %C"
 msgstr ""
@@ -58379,7 +58456,7 @@
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.c:1893 fortran/resolve.c:9560 fortran/resolve.c:11225
+#: fortran/resolve.c:1893 fortran/resolve.c:9573 fortran/resolve.c:11245
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr ""
@@ -58489,7 +58566,7 @@
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr ""
 
-#: fortran/resolve.c:2905 fortran/resolve.c:16283
+#: fortran/resolve.c:2905 fortran/resolve.c:16310
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr ""
@@ -58610,197 +58687,197 @@
 msgid "logical_to_bitwise(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:4059
+#: fortran/resolve.c:4065
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:4229 fortran/resolve.c:4252
+#: fortran/resolve.c:4235 fortran/resolve.c:4258
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:4347
+#: fortran/resolve.c:4353
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4352
+#: fortran/resolve.c:4358
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4362
+#: fortran/resolve.c:4368
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4367
+#: fortran/resolve.c:4373
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4387
+#: fortran/resolve.c:4393
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr ""
 
-#: fortran/resolve.c:4404
+#: fortran/resolve.c:4410
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4412
+#: fortran/resolve.c:4418
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4428
+#: fortran/resolve.c:4434
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4437
+#: fortran/resolve.c:4443
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4453
+#: fortran/resolve.c:4459
 #, gcc-internal-format
 msgid "check_dimension(): Bad array reference"
 msgstr ""
 
-#: fortran/resolve.c:4476
+#: fortran/resolve.c:4482
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:4486
+#: fortran/resolve.c:4492
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.c:4494
+#: fortran/resolve.c:4500
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.c:4510
+#: fortran/resolve.c:4516
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr ""
 
-#: fortran/resolve.c:4538
+#: fortran/resolve.c:4544
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4544
+#: fortran/resolve.c:4550
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr ""
 
-#: fortran/resolve.c:4550
+#: fortran/resolve.c:4556
 #, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr ""
 
-#: fortran/resolve.c:4589
+#: fortran/resolve.c:4595
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4596
+#: fortran/resolve.c:4602
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr ""
 
-#: fortran/resolve.c:4641
+#: fortran/resolve.c:4647
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr ""
 
-#: fortran/resolve.c:4652
+#: fortran/resolve.c:4658
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.c:4663
+#: fortran/resolve.c:4669
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.c:4706
+#: fortran/resolve.c:4712
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr ""
 
-#: fortran/resolve.c:4804
+#: fortran/resolve.c:4810
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:4811
+#: fortran/resolve.c:4817
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4820
+#: fortran/resolve.c:4826
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr ""
 
-#: fortran/resolve.c:4833
+#: fortran/resolve.c:4839
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:4840
+#: fortran/resolve.c:4846
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4850
+#: fortran/resolve.c:4856
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr ""
 
-#: fortran/resolve.c:4860
+#: fortran/resolve.c:4866
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr ""
 
-#: fortran/resolve.c:5013
+#: fortran/resolve.c:5019
 #, gcc-internal-format
 msgid "resolve_ref(): Bad array reference"
 msgstr ""
 
-#: fortran/resolve.c:5027
+#: fortran/resolve.c:5033
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:5037
+#: fortran/resolve.c:5043
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:5056
+#: fortran/resolve.c:5062
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:5154
+#: fortran/resolve.c:5160
 #, gcc-internal-format
 msgid "expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.c:5236
+#: fortran/resolve.c:5242
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr ""
 
-#: fortran/resolve.c:5246
+#: fortran/resolve.c:5252
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -58809,12 +58886,12 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5256
+#: fortran/resolve.c:5262
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5271
+#: fortran/resolve.c:5277
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -58823,268 +58900,268 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5281
+#: fortran/resolve.c:5287
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5292
+#: fortran/resolve.c:5298
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5301
+#: fortran/resolve.c:5307
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5316
+#: fortran/resolve.c:5322
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5478
+#: fortran/resolve.c:5484
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5483
+#: fortran/resolve.c:5489
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5553
+#: fortran/resolve.c:5559
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.c:5566
+#: fortran/resolve.c:5572
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.c:5919
+#: fortran/resolve.c:5925
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:5926
+#: fortran/resolve.c:5932
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5961
+#: fortran/resolve.c:5967
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5970
+#: fortran/resolve.c:5976
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr ""
 
 #. Nothing matching found!
-#: fortran/resolve.c:6158
+#: fortran/resolve.c:6164
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:6185
+#: fortran/resolve.c:6191
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:6236
+#: fortran/resolve.c:6242
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:6786
+#: fortran/resolve.c:6792
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr ""
 
-#: fortran/resolve.c:6812
+#: fortran/resolve.c:6818
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr ""
 
-#: fortran/resolve.c:6822
+#: fortran/resolve.c:6828
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr ""
 
-#: fortran/resolve.c:6826 fortran/resolve.c:6833
+#: fortran/resolve.c:6832 fortran/resolve.c:6839
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6875
+#: fortran/resolve.c:6881
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:6911
+#: fortran/resolve.c:6917
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.c:6928
+#: fortran/resolve.c:6934
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.c:6934
+#: fortran/resolve.c:6940
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.c:6995
+#: fortran/resolve.c:7001
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7000
+#: fortran/resolve.c:7006
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7007
+#: fortran/resolve.c:7013
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7015
+#: fortran/resolve.c:7021
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr ""
 
-#: fortran/resolve.c:7020
+#: fortran/resolve.c:7026
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:7033
+#: fortran/resolve.c:7039
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr ""
 
-#: fortran/resolve.c:7136 fortran/resolve.c:7428
+#: fortran/resolve.c:7142 fortran/resolve.c:7434
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:7144 fortran/resolve.c:7393
+#: fortran/resolve.c:7150 fortran/resolve.c:7399
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7250
+#: fortran/resolve.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7281
+#: fortran/resolve.c:7287
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.c:7439
+#: fortran/resolve.c:7445
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.c:7451
+#: fortran/resolve.c:7457
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.c:7465
+#: fortran/resolve.c:7471
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7480
+#: fortran/resolve.c:7486
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7493
+#: fortran/resolve.c:7499
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.c:7511
+#: fortran/resolve.c:7517
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.c:7592 fortran/resolve.c:7607
+#: fortran/resolve.c:7598 fortran/resolve.c:7613
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7599
+#: fortran/resolve.c:7605
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7622
+#: fortran/resolve.c:7628
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7649
+#: fortran/resolve.c:7655
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7668
+#: fortran/resolve.c:7674
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.c:7683
+#: fortran/resolve.c:7689
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7694
+#: fortran/resolve.c:7700
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7726
+#: fortran/resolve.c:7732
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:7749
+#: fortran/resolve.c:7755
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:7760
+#: fortran/resolve.c:7766
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.c:7771
+#: fortran/resolve.c:7782
 #, gcc-internal-format, gfc-internal-format
-msgid "Errmsg-variable at %L must be a scalar CHARACTER variable"
+msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:7794
+#: fortran/resolve.c:7805
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:7824
+#: fortran/resolve.c:7835
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.c:7830 fortran/resolve.c:7836
+#: fortran/resolve.c:7841 fortran/resolve.c:7847
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -59093,232 +59170,232 @@
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8064
+#: fortran/resolve.c:8075
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr ""
 
-#: fortran/resolve.c:8115
+#: fortran/resolve.c:8126
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr ""
 
-#: fortran/resolve.c:8126
+#: fortran/resolve.c:8137
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr ""
 
-#: fortran/resolve.c:8139
+#: fortran/resolve.c:8150
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:8185
+#: fortran/resolve.c:8196
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr ""
 
-#: fortran/resolve.c:8204
+#: fortran/resolve.c:8215
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr ""
 
-#: fortran/resolve.c:8214
+#: fortran/resolve.c:8225
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr ""
 
-#: fortran/resolve.c:8232 fortran/resolve.c:8240
+#: fortran/resolve.c:8243 fortran/resolve.c:8251
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr ""
 
-#: fortran/resolve.c:8302 fortran/resolve.c:8873
+#: fortran/resolve.c:8313 fortran/resolve.c:8884
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr ""
 
-#: fortran/resolve.c:8328
+#: fortran/resolve.c:8339
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:8340
+#: fortran/resolve.c:8351
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:8355
+#: fortran/resolve.c:8366
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr ""
 
-#: fortran/resolve.c:8458
+#: fortran/resolve.c:8469
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr ""
 
-#: fortran/resolve.c:8518
+#: fortran/resolve.c:8529
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr ""
 
-#: fortran/resolve.c:8523
+#: fortran/resolve.c:8534
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr ""
 
-#: fortran/resolve.c:8545
+#: fortran/resolve.c:8556
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.c:8556
+#: fortran/resolve.c:8567
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:8763
+#: fortran/resolve.c:8774
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8783 fortran/resolve.c:8795
+#: fortran/resolve.c:8794 fortran/resolve.c:8806
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.c:8824
+#: fortran/resolve.c:8835
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr ""
 
-#: fortran/resolve.c:8836
+#: fortran/resolve.c:8847
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr ""
 
-#: fortran/resolve.c:8848
+#: fortran/resolve.c:8859
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr ""
 
-#: fortran/resolve.c:8851
+#: fortran/resolve.c:8862
 #, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:8861
+#: fortran/resolve.c:8872
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.c:9108
+#: fortran/resolve.c:9119
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9204
+#: fortran/resolve.c:9215
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr ""
 
-#: fortran/resolve.c:9257
+#: fortran/resolve.c:9268
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr ""
 
-#: fortran/resolve.c:9267
+#: fortran/resolve.c:9278
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9280
+#: fortran/resolve.c:9291
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9289
+#: fortran/resolve.c:9300
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr ""
 
-#: fortran/resolve.c:9296
+#: fortran/resolve.c:9307
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9307
+#: fortran/resolve.c:9318
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr ""
 
-#: fortran/resolve.c:9313
+#: fortran/resolve.c:9324
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9328
+#: fortran/resolve.c:9339
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:9388
+#: fortran/resolve.c:9399
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:9398
+#: fortran/resolve.c:9409
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:9402
+#: fortran/resolve.c:9413
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr ""
 
-#: fortran/resolve.c:9405
+#: fortran/resolve.c:9416
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr ""
 
-#: fortran/resolve.c:9412 fortran/resolve.c:9533
+#: fortran/resolve.c:9423 fortran/resolve.c:9545
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:9424 fortran/resolve.c:9540
+#: fortran/resolve.c:9435 fortran/resolve.c:9553
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:9436
+#: fortran/resolve.c:9447
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr ""
 
-#: fortran/resolve.c:9449
+#: fortran/resolve.c:9460
 #, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:9510
+#: fortran/resolve.c:9521
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:9514 fortran/resolve.c:9524
+#: fortran/resolve.c:9525 fortran/resolve.c:9535
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr ""
 
-#: fortran/resolve.c:9567
+#: fortran/resolve.c:9580
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9577
+#: fortran/resolve.c:9590
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr ""
@@ -59325,12 +59402,12 @@
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:9594 fortran/resolve.c:9617
+#: fortran/resolve.c:9607 fortran/resolve.c:9630
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.c:9598 fortran/resolve.c:9623
+#: fortran/resolve.c:9611 fortran/resolve.c:9636
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -59338,107 +59415,107 @@
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:9638
+#: fortran/resolve.c:9651
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9710
+#: fortran/resolve.c:9723
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:9726
+#: fortran/resolve.c:9739
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:9734 fortran/resolve.c:9821
+#: fortran/resolve.c:9747 fortran/resolve.c:9834
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:9744 fortran/resolve.c:9831
+#: fortran/resolve.c:9757 fortran/resolve.c:9844
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:9775
+#: fortran/resolve.c:9788
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:9784
+#: fortran/resolve.c:9797
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr ""
 
-#: fortran/resolve.c:9949
+#: fortran/resolve.c:9962
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr ""
 
-#: fortran/resolve.c:9959
+#: fortran/resolve.c:9972
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr ""
 
-#: fortran/resolve.c:10036
+#: fortran/resolve.c:10049
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr ""
 
-#: fortran/resolve.c:10138
+#: fortran/resolve.c:10151
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:10251
+#: fortran/resolve.c:10264
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr ""
 
-#: fortran/resolve.c:10283
+#: fortran/resolve.c:10296
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:10288
+#: fortran/resolve.c:10301
 #, gcc-internal-format, gfc-internal-format
 msgid "The impure variable at %L is assigned to a derived type variable with a POINTER component in a PURE procedure (12.6)"
 msgstr ""
 
-#: fortran/resolve.c:10298
+#: fortran/resolve.c:10311
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:10330
+#: fortran/resolve.c:10343
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:10334
+#: fortran/resolve.c:10347
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:10339
+#: fortran/resolve.c:10352
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.c:10346
+#: fortran/resolve.c:10359
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr ""
 
-#: fortran/resolve.c:10357
+#: fortran/resolve.c:10370
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:10663
+#: fortran/resolve.c:10683
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
@@ -59445,67 +59522,67 @@
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:10905
+#: fortran/resolve.c:10925
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:10917
+#: fortran/resolve.c:10937
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr ""
 
-#: fortran/resolve.c:11157
+#: fortran/resolve.c:11177
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:11160
+#: fortran/resolve.c:11180
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr ""
 
-#: fortran/resolve.c:11171
+#: fortran/resolve.c:11191
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr ""
 
-#: fortran/resolve.c:11233
+#: fortran/resolve.c:11253
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:11278
+#: fortran/resolve.c:11298
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid NULL at %L"
 msgstr ""
 
-#: fortran/resolve.c:11282
+#: fortran/resolve.c:11302
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:11339
+#: fortran/resolve.c:11359
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:11344
+#: fortran/resolve.c:11364
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:11428
+#: fortran/resolve.c:11448
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:11507
+#: fortran/resolve.c:11527
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr ""
 
-#: fortran/resolve.c:11617
+#: fortran/resolve.c:11637
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
@@ -59512,7 +59589,7 @@
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:11630
+#: fortran/resolve.c:11650
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr ""
@@ -59520,57 +59597,57 @@
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:11647
+#: fortran/resolve.c:11667
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.c:11732
+#: fortran/resolve.c:11752
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr ""
 
-#: fortran/resolve.c:11961
+#: fortran/resolve.c:11981
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:11965
+#: fortran/resolve.c:11985
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:11973
+#: fortran/resolve.c:11993
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:11983
+#: fortran/resolve.c:12003
 #, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:11998
+#: fortran/resolve.c:12018
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.c:12010
+#: fortran/resolve.c:12030
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.c:12041
+#: fortran/resolve.c:12061
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.c:12063
+#: fortran/resolve.c:12083
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
 
-#: fortran/resolve.c:12090
+#: fortran/resolve.c:12110
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
@@ -59577,887 +59654,892 @@
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12131
+#: fortran/resolve.c:12151
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr ""
 
-#: fortran/resolve.c:12150
+#: fortran/resolve.c:12170
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr ""
 
-#: fortran/resolve.c:12171
+#: fortran/resolve.c:12191
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr ""
 
-#: fortran/resolve.c:12178
+#: fortran/resolve.c:12198
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr ""
 
-#: fortran/resolve.c:12225
+#: fortran/resolve.c:12245
 #, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12228
+#: fortran/resolve.c:12248
 #, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12232
+#: fortran/resolve.c:12252
 #, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12235
+#: fortran/resolve.c:12255
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12238
+#: fortran/resolve.c:12258
 #, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12241
+#: fortran/resolve.c:12261
 #, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12283
+#: fortran/resolve.c:12303
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L"
 msgstr ""
 
-#: fortran/resolve.c:12310
+#: fortran/resolve.c:12330
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:12332
+#: fortran/resolve.c:12352
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:12354
+#: fortran/resolve.c:12374
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.c:12372
+#: fortran/resolve.c:12392
 #, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12381
+#: fortran/resolve.c:12401
 #, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12389
+#: fortran/resolve.c:12409
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr ""
 
-#: fortran/resolve.c:12399
+#: fortran/resolve.c:12419
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr ""
 
-#: fortran/resolve.c:12418
+#: fortran/resolve.c:12438
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr ""
 
-#: fortran/resolve.c:12422
+#: fortran/resolve.c:12442
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr ""
 
-#: fortran/resolve.c:12426
+#: fortran/resolve.c:12446
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr ""
 
-#: fortran/resolve.c:12430
+#: fortran/resolve.c:12450
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr ""
 
-#: fortran/resolve.c:12443
+#: fortran/resolve.c:12463
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12452
+#: fortran/resolve.c:12472
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:12458
+#: fortran/resolve.c:12478
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:12470
+#: fortran/resolve.c:12490
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:12527
+#: fortran/resolve.c:12547
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12533
+#: fortran/resolve.c:12553
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12539
+#: fortran/resolve.c:12559
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12547
+#: fortran/resolve.c:12567
 #, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12553
+#: fortran/resolve.c:12573
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.c:12596
+#: fortran/resolve.c:12616
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12604
+#: fortran/resolve.c:12624
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12612
+#: fortran/resolve.c:12632
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12621
+#: fortran/resolve.c:12641
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.c:12705
+#: fortran/resolve.c:12725
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:12714
+#: fortran/resolve.c:12734
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr ""
 
-#: fortran/resolve.c:12723
+#: fortran/resolve.c:12743
 #, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr ""
 
-#: fortran/resolve.c:12731
+#: fortran/resolve.c:12751
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:12737
+#: fortran/resolve.c:12757
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:12743
+#: fortran/resolve.c:12763
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr ""
 
-#: fortran/resolve.c:12751
+#: fortran/resolve.c:12771
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:12760
+#: fortran/resolve.c:12780
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr ""
 
-#: fortran/resolve.c:12782
+#: fortran/resolve.c:12802
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr ""
 
-#: fortran/resolve.c:12819
+#: fortran/resolve.c:12839
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr ""
 
-#: fortran/resolve.c:12859
+#: fortran/resolve.c:12879
 #, gcc-internal-format
 msgid "%qs and %qs can't be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12895
+#: fortran/resolve.c:12915
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.c:12954
+#: fortran/resolve.c:12974
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12966
+#: fortran/resolve.c:12986
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.c:12994
+#: fortran/resolve.c:13014
 #, gcc-internal-format
 msgid "GENERIC %qs at %L can't overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.c:13050
+#: fortran/resolve.c:13070
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L can't be NOPASS"
 msgstr ""
 
-#: fortran/resolve.c:13242
+#: fortran/resolve.c:13262
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr ""
 
-#: fortran/resolve.c:13284
+#: fortran/resolve.c:13304
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:13298
+#: fortran/resolve.c:13318
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:13312 fortran/resolve.c:13778
+#: fortran/resolve.c:13332 fortran/resolve.c:13798
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13320
+#: fortran/resolve.c:13340
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr ""
 
-#: fortran/resolve.c:13329
+#: fortran/resolve.c:13349
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:13335
+#: fortran/resolve.c:13355
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13341
+#: fortran/resolve.c:13361
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr ""
 
-#: fortran/resolve.c:13370
+#: fortran/resolve.c:13390
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:13380
+#: fortran/resolve.c:13400
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:13472
+#: fortran/resolve.c:13492
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.c:13574
+#: fortran/resolve.c:13594
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:13583
+#: fortran/resolve.c:13603
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13593
+#: fortran/resolve.c:13613
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.c:13602
+#: fortran/resolve.c:13622
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.c:13613
+#: fortran/resolve.c:13633
 #, gcc-internal-format
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.c:13711
+#: fortran/resolve.c:13731
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:13725
+#: fortran/resolve.c:13745
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:13741
+#: fortran/resolve.c:13761
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:13751
+#: fortran/resolve.c:13771
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:13760
+#: fortran/resolve.c:13780
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:13769
+#: fortran/resolve.c:13789
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13811
+#: fortran/resolve.c:13831
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr ""
 
-#: fortran/resolve.c:13824
+#: fortran/resolve.c:13844
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr ""
 
-#: fortran/resolve.c:13835
+#: fortran/resolve.c:13855
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13868
+#: fortran/resolve.c:13888
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:13876
+#: fortran/resolve.c:13896
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.c:13885
+#: fortran/resolve.c:13905
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr ""
 
-#: fortran/resolve.c:13903 fortran/resolve.c:13915
+#: fortran/resolve.c:13923 fortran/resolve.c:13935
 #, gcc-internal-format
 msgid "The pointer component %qs of %qs at %L is a type that has not been declared"
 msgstr ""
 
-#: fortran/resolve.c:13989
+#: fortran/resolve.c:14009
 #, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr ""
 
-#: fortran/resolve.c:14034
+#: fortran/resolve.c:14054
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.c:14047
+#: fortran/resolve.c:14067
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr ""
 
-#: fortran/resolve.c:14111
+#: fortran/resolve.c:14131
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14144
+#: fortran/resolve.c:14164
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.c:14216
+#: fortran/resolve.c:14236
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:14222
+#: fortran/resolve.c:14242
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14228
+#: fortran/resolve.c:14248
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14236
+#: fortran/resolve.c:14256
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14253
+#: fortran/resolve.c:14273
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14275
+#: fortran/resolve.c:14295
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14286
+#: fortran/resolve.c:14306
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14313
+#: fortran/resolve.c:14333
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14337
+#: fortran/resolve.c:14357
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:14353
+#: fortran/resolve.c:14373
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:14364
+#: fortran/resolve.c:14384
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr ""
 
-#: fortran/resolve.c:14372
+#: fortran/resolve.c:14392
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr ""
 
-#: fortran/resolve.c:14423
+#: fortran/resolve.c:14443
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr ""
 
-#: fortran/resolve.c:14434
+#: fortran/resolve.c:14454
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.c:14441
+#: fortran/resolve.c:14461
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.c:14480
+#: fortran/resolve.c:14500
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:14544
+#: fortran/resolve.c:14564
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:14547
+#: fortran/resolve.c:14567
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:14643
+#: fortran/resolve.c:14663
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:14664
+#: fortran/resolve.c:14684
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr ""
 
-#: fortran/resolve.c:14677
+#: fortran/resolve.c:14697
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14680
+#: fortran/resolve.c:14700
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14688
+#: fortran/resolve.c:14708
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14695
+#: fortran/resolve.c:14715
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:14708
+#: fortran/resolve.c:14728
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr ""
 
-#: fortran/resolve.c:14714
+#: fortran/resolve.c:14734
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14724
+#: fortran/resolve.c:14744
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:14733
+#: fortran/resolve.c:14753
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.c:14746 fortran/resolve.c:14923
+#: fortran/resolve.c:14766 fortran/resolve.c:14943
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.c:14760
+#: fortran/resolve.c:14780
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14769
+#: fortran/resolve.c:14789
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:14778
+#: fortran/resolve.c:14798
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14786
+#: fortran/resolve.c:14806
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:14793
+#: fortran/resolve.c:14813
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:14813
+#: fortran/resolve.c:14833
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.c:14820
+#: fortran/resolve.c:14840
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14827
+#: fortran/resolve.c:14847
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:14834
+#: fortran/resolve.c:14854
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:14860
+#: fortran/resolve.c:14880
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:14870
+#: fortran/resolve.c:14890
 #, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.c:14949
+#: fortran/resolve.c:14969
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:14964
+#: fortran/resolve.c:14984
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14977
+#: fortran/resolve.c:14997
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14995
+#: fortran/resolve.c:15015
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.c:15007
+#: fortran/resolve.c:15027
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:15016
+#: fortran/resolve.c:15036
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:15028
+#: fortran/resolve.c:15048
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr ""
 
-#: fortran/resolve.c:15037
+#: fortran/resolve.c:15057
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15049
+#: fortran/resolve.c:15069
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15065
+#: fortran/resolve.c:15085
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15073
+#: fortran/resolve.c:15093
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15080
+#: fortran/resolve.c:15100
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15092
+#: fortran/resolve.c:15112
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.c:15101
+#: fortran/resolve.c:15121
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15117
+#: fortran/resolve.c:15137
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15123
+#: fortran/resolve.c:15143
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15148
+#: fortran/resolve.c:15168
 #, gcc-internal-format
 msgid "Namelist %qs can not be an argument to subroutine or function at %L"
 msgstr ""
 
-#: fortran/resolve.c:15218
+#: fortran/resolve.c:15238
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:15229
+#: fortran/resolve.c:15249
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:15333
+#: fortran/resolve.c:15353
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:15339
+#: fortran/resolve.c:15359
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:15345
+#: fortran/resolve.c:15365
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.c:15354
+#: fortran/resolve.c:15374
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr ""
 
-#: fortran/resolve.c:15368
+#: fortran/resolve.c:15388
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:15414
+#: fortran/resolve.c:15434
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.c:15427
+#: fortran/resolve.c:15447
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.c:15526
+#: fortran/resolve.c:15546
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15534
+#: fortran/resolve.c:15554
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15542
+#: fortran/resolve.c:15562
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15667
+#: fortran/resolve.c:15687
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.c:15832
+#: fortran/resolve.c:15852
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr ""
 
-#: fortran/resolve.c:15838
+#: fortran/resolve.c:15858
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr ""
 
-#: fortran/resolve.c:15922
+#: fortran/resolve.c:15942
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15931
+#: fortran/resolve.c:15951
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15939
+#: fortran/resolve.c:15959
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:15955
+#: fortran/resolve.c:15975
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16058
+#: fortran/resolve.c:16078
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:16073
+#: fortran/resolve.c:16093
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:16098
+#: fortran/resolve.c:16118
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:16107
+#: fortran/resolve.c:16127
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16180
+#: fortran/resolve.c:16200
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16191
+#: fortran/resolve.c:16211
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16202
+#: fortran/resolve.c:16222
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr ""
 
-#: fortran/resolve.c:16293
+#: fortran/resolve.c:16253
 #, gcc-internal-format
+msgid "Self reference in character length expression for %qs at %L"
+msgstr ""
+
+#: fortran/resolve.c:16320
+#, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.c:16306
+#: fortran/resolve.c:16333
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:16326
+#: fortran/resolve.c:16353
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:16336
+#: fortran/resolve.c:16363
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr ""
 
-#: fortran/resolve.c:16344
+#: fortran/resolve.c:16371
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:16358
+#: fortran/resolve.c:16385
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:16376
+#: fortran/resolve.c:16403
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:16383
+#: fortran/resolve.c:16410
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr ""
 
-#: fortran/resolve.c:16461
+#: fortran/resolve.c:16488
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -60783,19 +60865,12 @@
 msgid "simplify_min_max(): Bad type in arglist"
 msgstr ""
 
-#. Result is processor-dependent.
-#: fortran/simplify.c:5472
-#, gcc-internal-format, gfc-internal-format
-msgid "Second argument MOD at %L is zero"
+#: fortran/simplify.c:5470 fortran/simplify.c:5478
+#, gcc-internal-format
+msgid "Argument %qs of MOD at %L shall not be zero"
 msgstr ""
 
-#. Result is processor-dependent.
-#: fortran/simplify.c:5483
-#, gcc-internal-format, gfc-internal-format
-msgid "Second argument of MOD at %L is zero"
-msgstr ""
-
-#: fortran/simplify.c:5494
+#: fortran/simplify.c:5484
 #, gcc-internal-format
 msgid "gfc_simplify_mod(): Bad arguments"
 msgstr ""
@@ -60803,97 +60878,97 @@
 #. Result is processor-dependent. This processor just opts
 #. to not handle it at all.
 #. Result is processor-dependent.
-#: fortran/simplify.c:5520 fortran/simplify.c:5532
+#: fortran/simplify.c:5525 fortran/simplify.c:5537
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of MODULO at %L is zero"
 msgstr ""
 
-#: fortran/simplify.c:5552
+#: fortran/simplify.c:5557
 #, gcc-internal-format
 msgid "gfc_simplify_modulo(): Bad arguments"
 msgstr ""
 
-#: fortran/simplify.c:5600
+#: fortran/simplify.c:5605
 #, gcc-internal-format, gfc-internal-format
 msgid "Result of NEAREST is NaN at %L"
 msgstr ""
 
-#: fortran/simplify.c:6081
+#: fortran/simplify.c:6086
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative at %L"
 msgstr ""
 
-#: fortran/simplify.c:6137
+#: fortran/simplify.c:6142
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument NCOPIES of REPEAT intrinsic is too large at %L"
 msgstr ""
 
-#: fortran/simplify.c:6174
+#: fortran/simplify.c:6179
 #, gcc-internal-format, gfc-internal-format
 msgid "Evaluation of string longer than 2**28 at %L deferred to runtime, expect bugs"
 msgstr ""
 
-#: fortran/simplify.c:6302
+#: fortran/simplify.c:6307
 #, gcc-internal-format, gfc-internal-format
 msgid "Reshaped array too large at %C"
 msgstr ""
 
-#: fortran/simplify.c:6416
+#: fortran/simplify.c:6421
 #, gcc-internal-format, gfc-internal-format
 msgid "Result of SCALE overflows its kind at %L"
 msgstr ""
 
-#: fortran/simplify.c:6995
+#: fortran/simplify.c:7000
 #, gcc-internal-format
 msgid "Bad type in gfc_simplify_sign"
 msgstr ""
 
-#: fortran/simplify.c:7024
+#: fortran/simplify.c:7029
 #, gcc-internal-format
 msgid "in gfc_simplify_sin(): Bad type"
 msgstr ""
 
-#: fortran/simplify.c:7151 fortran/simplify.c:7431
+#: fortran/simplify.c:7156 fortran/simplify.c:7436
 #, gcc-internal-format
 msgid "Failure getting length of a constant array."
 msgstr ""
 
-#: fortran/simplify.c:7161
+#: fortran/simplify.c:7166
 #, gcc-internal-format
 msgid "The number of elements (%d) in the array constructor at %L requires an increase of the allowed %d upper limit.  See %<-fmax-array-constructor%> option."
 msgstr ""
 
-#: fortran/simplify.c:7227
+#: fortran/simplify.c:7232
 #, gcc-internal-format, gfc-internal-format
 msgid "Simplification of SPREAD at %C not yet implemented"
 msgstr ""
 
-#: fortran/simplify.c:7251
+#: fortran/simplify.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SQRT at %L has a negative value"
 msgstr ""
 
-#: fortran/simplify.c:7267
+#: fortran/simplify.c:7272
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid argument of SQRT at %L"
 msgstr ""
 
-#: fortran/simplify.c:7598
+#: fortran/simplify.c:7603
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY lower bound is %ld)"
 msgstr ""
 
-#: fortran/simplify.c:7621
+#: fortran/simplify.c:7626
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY upper bound is %ld)"
 msgstr ""
 
-#: fortran/simplify.c:7993
+#: fortran/simplify.c:7998
 #, gcc-internal-format
 msgid "gfc_convert_constant(): Unexpected type"
 msgstr ""
 
-#: fortran/simplify.c:8078
+#: fortran/simplify.c:8083
 #, gcc-internal-format
 msgid "Character %qs in string at %L cannot be converted into character kind %d"
 msgstr ""
@@ -60996,7 +61071,7 @@
 msgid "BIND(C) applied to %s %s at %L"
 msgstr ""
 
-#: fortran/symbol.c:901 fortran/symbol.c:912 fortran/symbol.c:1762
+#: fortran/symbol.c:901 fortran/symbol.c:912 fortran/symbol.c:1776
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute conflicts with %s attribute at %L"
 msgstr ""
@@ -61071,17 +61146,22 @@
 msgid "Duplicate VOLATILE attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1367
+#: fortran/symbol.c:1360
 #, gcc-internal-format, gfc-internal-format
+msgid "VOLATILE attribute at %L cannot be specified in a PURE procedure"
+msgstr ""
+
+#: fortran/symbol.c:1381
+#, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ASYNCHRONOUS attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1758
+#: fortran/symbol.c:1772
 #, gcc-internal-format
 msgid "%s attribute of %qs conflicts with %s attribute at %L"
 msgstr ""
 
-#: fortran/symbol.c:1794
+#: fortran/symbol.c:1808
 #, gcc-internal-format, gfc-internal-format
 msgid ""
 "%s procedure at %L is already declared as %s procedure. \n"
@@ -61088,208 +61168,208 @@
 "F2008: A pointer function assignment is ambiguous if it is the first executable statement after the specification block. Please add any other kind of executable statement before it. FIXME"
 msgstr ""
 
-#: fortran/symbol.c:1802
+#: fortran/symbol.c:1816
 #, gcc-internal-format, gfc-internal-format
 msgid "%s procedure at %L is already declared as %s procedure"
 msgstr ""
 
-#: fortran/symbol.c:1837
+#: fortran/symbol.c:1851
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgstr ""
 
-#: fortran/symbol.c:1861
+#: fortran/symbol.c:1875
 #, gcc-internal-format, gfc-internal-format
 msgid "ACCESS specification at %L was already specified"
 msgstr ""
 
-#: fortran/symbol.c:1878
+#: fortran/symbol.c:1892
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate BIND attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1885
+#: fortran/symbol.c:1899
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) at %L"
 msgstr ""
 
-#: fortran/symbol.c:1901
+#: fortran/symbol.c:1915
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate EXTENDS attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1905
+#: fortran/symbol.c:1919
 #, gcc-internal-format, gfc-internal-format
 msgid "EXTENDS at %L"
 msgstr ""
 
-#: fortran/symbol.c:1931
+#: fortran/symbol.c:1945
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has an explicit interface"
 msgstr ""
 
-#: fortran/symbol.c:1938
+#: fortran/symbol.c:1952
 #, gcc-internal-format
 msgid "%qs at %L has attributes specified outside its INTERFACE body"
 msgstr ""
 
-#: fortran/symbol.c:1976
+#: fortran/symbol.c:1990
 #, gcc-internal-format
 msgid "Symbol %qs at %L conflicts with symbol from module %qs, use-associated at %L"
 msgstr ""
 
-#: fortran/symbol.c:1980
+#: fortran/symbol.c:1994
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr ""
 
-#: fortran/symbol.c:1987
+#: fortran/symbol.c:2001
 #, gcc-internal-format
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr ""
 
-#: fortran/symbol.c:1999
+#: fortran/symbol.c:2013
 #, gcc-internal-format
 msgid "Symbol %qs at %L cannot have a type"
 msgstr ""
 
-#: fortran/symbol.c:2242
+#: fortran/symbol.c:2256
 #, gcc-internal-format
 msgid "Component %qs at %C already in the parent type at %L"
 msgstr ""
 
-#: fortran/symbol.c:2327
+#: fortran/symbol.c:2341
 #, gcc-internal-format
 msgid "Symbol %qs at %C is ambiguous"
 msgstr ""
 
-#: fortran/symbol.c:2359
+#: fortran/symbol.c:2373
 #, gcc-internal-format
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr ""
 
-#: fortran/symbol.c:2508
+#: fortran/symbol.c:2522
 #, gcc-internal-format
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr ""
 
-#: fortran/symbol.c:2529
+#: fortran/symbol.c:2543
 #, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure; did you mean %qs?"
 msgstr ""
 
-#: fortran/symbol.c:2533
+#: fortran/symbol.c:2547
 #, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr ""
 
-#: fortran/symbol.c:2697
+#: fortran/symbol.c:2711
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr ""
 
-#: fortran/symbol.c:2708
+#: fortran/symbol.c:2722
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr ""
 
-#: fortran/symbol.c:2718
+#: fortran/symbol.c:2732
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr ""
 
-#: fortran/symbol.c:2724
+#: fortran/symbol.c:2738
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:2766
+#: fortran/symbol.c:2780
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr ""
 
-#: fortran/symbol.c:2775
+#: fortran/symbol.c:2789
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr ""
 
-#: fortran/symbol.c:2781
+#: fortran/symbol.c:2795
 #, gcc-internal-format, gfc-internal-format
 msgid "Shared DO termination label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:3110
+#: fortran/symbol.c:3124
 #, gcc-internal-format
 msgid "new_symbol(): Symbol name too long"
 msgstr ""
 
-#: fortran/symbol.c:3135
+#: fortran/symbol.c:3149
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr ""
 
-#: fortran/symbol.c:3138
+#: fortran/symbol.c:3152
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
 msgstr ""
 
 #. Symbol is from another namespace.
-#: fortran/symbol.c:3381
+#: fortran/symbol.c:3395
 #, gcc-internal-format
 msgid "Symbol %qs at %C has already been host associated"
 msgstr ""
 
-#: fortran/symbol.c:4397
+#: fortran/symbol.c:4411
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr ""
 
-#: fortran/symbol.c:4410
+#: fortran/symbol.c:4424
 #, gcc-internal-format
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr ""
 
-#: fortran/symbol.c:4428
+#: fortran/symbol.c:4442
 #, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr ""
 
-#: fortran/symbol.c:4449
+#: fortran/symbol.c:4463
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:4459
+#: fortran/symbol.c:4473
 #, gcc-internal-format
 msgid "Procedure pointer component %qs at %L cannot be a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:4470
+#: fortran/symbol.c:4484
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:4509
+#: fortran/symbol.c:4523
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.c:4519
+#: fortran/symbol.c:4533
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/symbol.c:4533
+#: fortran/symbol.c:4547
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot be declared with both PRIVATE and BIND(C) attributes"
 msgstr ""
 
-#: fortran/symbol.c:4541
+#: fortran/symbol.c:4555
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.c:5018 fortran/symbol.c:5023
+#: fortran/symbol.c:5032 fortran/symbol.c:5037
 #, gcc-internal-format
 msgid "Symbol %qs is used before it is typed at %L"
 msgstr ""
@@ -61336,7 +61416,7 @@
 msgid "Creating array temporary at %L for argument %qs"
 msgstr ""
 
-#: fortran/trans-array.c:10693
+#: fortran/trans-array.c:10724
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr ""
@@ -61538,12 +61618,12 @@
 msgid "%<dim%> argument of %s intrinsic at %L is not a valid dimension index"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:10572 fortran/trans-stmt.c:1050
+#: fortran/trans-intrinsic.c:10574 fortran/trans-stmt.c:1050
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, the event component of derived type at %L is not yet supported"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:10579
+#: fortran/trans-intrinsic.c:10581
 #, gcc-internal-format, gfc-internal-format
 msgid "The event variable at %L shall not be coindexed"
 msgstr ""
@@ -61583,7 +61663,7 @@
 msgid "Sorry, only support for integer kind %d implemented for image-set at %L"
 msgstr ""
 
-#: fortran/trans-stmt.c:3346
+#: fortran/trans-stmt.c:3343
 #, gcc-internal-format
 msgid "gfc_trans_select(): Bad type for case expr."
 msgstr ""
@@ -61709,7 +61789,7 @@
 msgid "two or more sections for %s"
 msgstr ""
 
-#: lto/lto-partition.c:516
+#: lto/lto-partition.c:570
 #, gcc-internal-format
 msgid "min partition size cannot be greater than max partition size"
 msgstr ""
@@ -61844,57 +61924,57 @@
 msgid "Cannot read %s"
 msgstr "Не вдалося прочитати %s"
 
-#: lto/lto.c:2369
+#: lto/lto.c:2337
 #, gcc-internal-format
 msgid "lto_obj_file_open() failed"
 msgstr ""
 
-#: lto/lto.c:2394
+#: lto/lto.c:2362
 #, gcc-internal-format
 msgid "waitpid failed"
 msgstr "помилка waitpid"
 
-#: lto/lto.c:2397
+#: lto/lto.c:2365
 #, gcc-internal-format
 msgid "streaming subprocess failed"
 msgstr ""
 
-#: lto/lto.c:2400
+#: lto/lto.c:2368
 #, gcc-internal-format
 msgid "streaming subprocess was killed by signal"
 msgstr ""
 
-#: lto/lto.c:2476
+#: lto/lto.c:2445
 #, gcc-internal-format
 msgid "no LTRANS output list filename provided"
 msgstr ""
 
-#: lto/lto.c:2564
+#: lto/lto.c:2525
 #, gcc-internal-format
 msgid "opening LTRANS output list %s: %m"
 msgstr ""
 
-#: lto/lto.c:2570
+#: lto/lto.c:2532
 #, gcc-internal-format
 msgid "writing to LTRANS output list %s: %m"
 msgstr ""
 
-#: lto/lto.c:2581
+#: lto/lto.c:2542
 #, gcc-internal-format
 msgid "closing LTRANS output list %s: %m"
 msgstr ""
 
-#: lto/lto.c:2833
+#: lto/lto.c:2794
 #, gcc-internal-format
 msgid "could not open symbol resolution file: %m"
 msgstr ""
 
-#: lto/lto.c:2954
+#: lto/lto.c:2915
 #, gcc-internal-format, gfc-internal-format
 msgid "missing resolution data for %s"
 msgstr ""
 
-#: lto/lto.c:2986
+#: lto/lto.c:2947
 #, gcc-internal-format
 msgid "errors during merging of translation units"
 msgstr ""
Index: gcc/po/sr.po
===================================================================
--- gcc/po/sr.po	(.../tags/gcc_8_2_0_release)
+++ gcc/po/sr.po	(.../branches/gcc-8-branch)
@@ -6,7 +6,7 @@
 msgstr ""
 "Project-Id-Version: gcc 4.2.1\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2018-05-01 20:30+0000\n"
+"POT-Creation-Date: 2018-07-25 14:25+0000\n"
 "PO-Revision-Date: 2007-08-19 12:00+0200\n"
 "Last-Translator: Caslav Ilic <caslav.ilic@gmx.net>\n"
 "Language-Team: Serbian <gnu@prevod.org>\n"
@@ -38,13 +38,13 @@
 msgid "[cannot find %s]"
 msgstr "[не могу да нађем %s]"
 
-#: collect2.c:1557
+#: collect2.c:1585
 #, fuzzy, c-format
 #| msgid "collect2 version %s"
 msgid "collect2 version %s\n"
 msgstr "collect2 верзија %s"
 
-#: collect2.c:1664
+#: collect2.c:1692
 #, fuzzy, c-format
 #| msgid "%d constructor(s) found\n"
 msgid "%d constructor found\n"
@@ -54,7 +54,7 @@
 msgstr[2] "нађених конструктора: %d\n"
 msgstr[3] "нађених конструктора: %d\n"
 
-#: collect2.c:1668
+#: collect2.c:1696
 #, fuzzy, c-format
 #| msgid "%d destructor(s)  found\n"
 msgid "%d destructor found\n"
@@ -64,7 +64,7 @@
 msgstr[2] "нађених деструктора: %d\n"
 msgstr[3] "нађених деструктора: %d\n"
 
-#: collect2.c:1672
+#: collect2.c:1700
 #, fuzzy, c-format
 #| msgid "%d frame table(s) found\n"
 msgid "%d frame table found\n"
@@ -74,12 +74,12 @@
 msgstr[2] "нађених табела оквира: %d\n"
 msgstr[3] "нађених табела оквира: %d\n"
 
-#: collect2.c:1836
+#: collect2.c:1864
 #, c-format
 msgid "[Leaving %s]\n"
 msgstr "[Напуштам %s]\n"
 
-#: collect2.c:2068
+#: collect2.c:2094
 #, c-format
 msgid ""
 "\n"
@@ -88,7 +88,7 @@
 "\n"
 "write_c_file - излазно име је %s, префикс је %s\n"
 
-#: collect2.c:2584
+#: collect2.c:2610
 #, c-format
 msgid ""
 "\n"
@@ -115,7 +115,7 @@
 msgid "%s: some warnings being treated as errors"
 msgstr "%s: упозорење: нема дозволе за читање датотеке ‘%s’\n"
 
-#: diagnostic.c:324 input.c:222 input.c:1834 c-family/c-opts.c:1377
+#: diagnostic.c:324 input.c:222 input.c:1834 c-family/c-opts.c:1392
 #: fortran/cpp.c:576 fortran/error.c:1008 fortran/error.c:1028
 msgid "<built-in>"
 msgstr "<уграђено>"
@@ -214,13 +214,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:4164 config/arc/arc.c:5784 config/i386/i386.c:17302
+#: final.c:4164 config/arc/arc.c:5775 config/i386/i386.c:17305
 #: config/pdp11/pdp11.c:1715
 #, c-format
 msgid "floating constant misused"
 msgstr "лоша употреба реалне константе"
 
-#: final.c:4222 config/arc/arc.c:5881 config/i386/i386.c:17393
+#: final.c:4222 config/arc/arc.c:5872 config/i386/i386.c:17396
 #: config/pdp11/pdp11.c:1756
 #, c-format
 msgid "invalid expression as operand"
@@ -1253,7 +1253,7 @@
 msgid "GCSE disabled"
 msgstr "ГЦСЕ искључен"
 
-#: gimple-ssa-isolate-paths.c:542 c/c-typeck.c:10240
+#: gimple-ssa-isolate-paths.c:542 c/c-typeck.c:10245
 #, gcc-internal-format
 msgid "function returns address of local variable"
 msgstr "функција враћа адресу на локалну променљиву"
@@ -1599,7 +1599,7 @@
 msgid "options enabled: "
 msgstr "укључене опције: "
 
-#: tree-diagnostic.c:299 c/c-decl.c:5419 c/c-typeck.c:7259 cp/error.c:1042
+#: tree-diagnostic.c:299 c/c-decl.c:5439 c/c-typeck.c:7264 cp/error.c:1042
 #: c-family/c-pretty-print.c:413
 #, gcc-internal-format
 msgid "<anonymous>"
@@ -3184,71 +3184,71 @@
 msgstr "модификатор дужине у формату strfmon"
 
 #. Handle deferred options from command-line.
-#: c-family/c-opts.c:1402 fortran/cpp.c:590
+#: c-family/c-opts.c:1417 fortran/cpp.c:590
 msgid "<command-line>"
 msgstr "<командна-линија>"
 
-#: config/aarch64/aarch64.c:6613
+#: config/aarch64/aarch64.c:6629
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "unsupported operand for code '%c'"
 msgstr "неисправан операнд за кôд ‘%c’"
 
-#: config/aarch64/aarch64.c:6624 config/aarch64/aarch64.c:6640
-#: config/aarch64/aarch64.c:6652 config/aarch64/aarch64.c:6663
-#: config/aarch64/aarch64.c:6673 config/aarch64/aarch64.c:6694
-#: config/aarch64/aarch64.c:6764 config/aarch64/aarch64.c:6775
-#: config/aarch64/aarch64.c:6789 config/aarch64/aarch64.c:7011
-#: config/aarch64/aarch64.c:7029
+#: config/aarch64/aarch64.c:6640 config/aarch64/aarch64.c:6656
+#: config/aarch64/aarch64.c:6668 config/aarch64/aarch64.c:6679
+#: config/aarch64/aarch64.c:6689 config/aarch64/aarch64.c:6710
+#: config/aarch64/aarch64.c:6780 config/aarch64/aarch64.c:6791
+#: config/aarch64/aarch64.c:6805 config/aarch64/aarch64.c:7027
+#: config/aarch64/aarch64.c:7045
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "invalid operand for '%%%c'"
 msgstr "неисправан операнд за кôд ‘%c’"
 
-#: config/aarch64/aarch64.c:6709 config/aarch64/aarch64.c:6720
-#: config/aarch64/aarch64.c:6871 config/aarch64/aarch64.c:6882
+#: config/aarch64/aarch64.c:6725 config/aarch64/aarch64.c:6736
+#: config/aarch64/aarch64.c:6887 config/aarch64/aarch64.c:6898
 #, fuzzy, c-format
 #| msgid "invalid punctuation %qc in constraint"
 msgid "invalid vector constant"
 msgstr "неисправна интерпункција %qc у ограничењу"
 
-#: config/aarch64/aarch64.c:6732 config/aarch64/aarch64.c:6744
-#: config/aarch64/aarch64.c:6755
+#: config/aarch64/aarch64.c:6748 config/aarch64/aarch64.c:6760
+#: config/aarch64/aarch64.c:6771
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6823 config/arm/arm.c:22704
+#: config/aarch64/aarch64.c:6839 config/arm/arm.c:22704
 #, c-format
 msgid "missing operand"
 msgstr "недостаје операнд"
 
-#: config/aarch64/aarch64.c:6908
+#: config/aarch64/aarch64.c:6924
 #, fuzzy, c-format
 #| msgid "invalid insn:"
 msgid "invalid constant"
 msgstr "неисправна ија:"
 
-#: config/aarch64/aarch64.c:6911
+#: config/aarch64/aarch64.c:6927
 #, fuzzy, c-format
 #| msgid "invalid %%d operand"
 msgid "invalid operand"
 msgstr "неисправан %%d операнд"
 
-#: config/aarch64/aarch64.c:7040 config/aarch64/aarch64.c:7045
+#: config/aarch64/aarch64.c:7056 config/aarch64/aarch64.c:7061
 #, fuzzy, c-format
 #| msgid "invalid operand code '%c'"
 msgid "invalid operand prefix '%%%c'"
 msgstr "неисправан кôд операнда ‘%c;’"
 
-#: config/aarch64/aarch64.c:7062
+#: config/aarch64/aarch64.c:7078
 #, fuzzy, c-format
 #| msgid "invalid address"
 msgid "invalid address mode"
 msgstr "неисправна адреса"
 
-#: config/alpha/alpha.c:5125 config/i386/i386.c:18558
-#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21798
+#: config/alpha/alpha.c:5125 config/i386/i386.c:18561
+#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21875
 #: config/sparc/sparc.c:9290
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
@@ -3265,7 +3265,7 @@
 msgstr "неисправна %%r вредност"
 
 #: config/alpha/alpha.c:5223 config/ia64/ia64.c:5534
-#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21506
+#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21583
 #: config/xtensa/xtensa.c:2429
 #, c-format
 msgid "invalid %%R value"
@@ -3272,13 +3272,13 @@
 msgstr "неисправна %%R вредност"
 
 #: config/alpha/alpha.c:5229 config/powerpcspe/powerpcspe.c:23933
-#: config/rs6000/rs6000.c:21426 config/xtensa/xtensa.c:2396
+#: config/rs6000/rs6000.c:21503 config/xtensa/xtensa.c:2396
 #, c-format
 msgid "invalid %%N value"
 msgstr "неисправна %%N вредност"
 
 #: config/alpha/alpha.c:5237 config/powerpcspe/powerpcspe.c:23961
-#: config/rs6000/rs6000.c:21454
+#: config/rs6000/rs6000.c:21531
 #, c-format
 msgid "invalid %%P value"
 msgstr "неисправна %%P вредност"
@@ -3309,7 +3309,7 @@
 msgstr "неисправна %%U вредност"
 
 #: config/alpha/alpha.c:5323 config/powerpcspe/powerpcspe.c:24021
-#: config/rs6000/rs6000.c:21514
+#: config/rs6000/rs6000.c:21591
 #, c-format
 msgid "invalid %%s value"
 msgstr "неисправна %%s вредност"
@@ -3320,7 +3320,7 @@
 msgstr "неисправна %%C вредност"
 
 #: config/alpha/alpha.c:5371 config/powerpcspe/powerpcspe.c:23797
-#: config/rs6000/rs6000.c:21290
+#: config/rs6000/rs6000.c:21367
 #, c-format
 msgid "invalid %%E value"
 msgstr "неисправна %%E вредност"
@@ -3331,7 +3331,7 @@
 msgstr "непознато unspec релокације"
 
 #: config/alpha/alpha.c:5405 config/cr16/cr16.c:1569
-#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21803
+#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21880
 #: config/spu/spu.c:1458
 #, c-format
 msgid "invalid %%xn code"
@@ -3343,61 +3343,61 @@
 msgid "invalid operand address"
 msgstr "неисправна адреса"
 
-#: config/arc/arc.c:3810
+#: config/arc/arc.c:3808
 #, fuzzy, c-format
 #| msgid "invalid operand to %%R code"
 msgid "invalid operand to %%Z code"
 msgstr "неисправан операнд за %%R кôд"
 
-#: config/arc/arc.c:3818
+#: config/arc/arc.c:3816
 #, fuzzy, c-format
 #| msgid "invalid operand to %%R code"
 msgid "invalid operand to %%z code"
 msgstr "неисправан операнд за %%R кôд"
 
-#: config/arc/arc.c:3826
+#: config/arc/arc.c:3824
 #, fuzzy, c-format
 #| msgid "invalid operand to %%R code"
 msgid "invalid operands to %%c code"
 msgstr "неисправан операнд за %%R кôд"
 
-#: config/arc/arc.c:3834
+#: config/arc/arc.c:3832
 #, fuzzy, c-format
 #| msgid "invalid operand to %%R code"
 msgid "invalid operand to %%M code"
 msgstr "неисправан операнд за %%R кôд"
 
-#: config/arc/arc.c:3842 config/m32r/m32r.c:2100
+#: config/arc/arc.c:3840 config/m32r/m32r.c:2100
 #, c-format
 msgid "invalid operand to %%p code"
 msgstr "неисправан операнд за %%p кôд"
 
-#: config/arc/arc.c:3853 config/m32r/m32r.c:2093
+#: config/arc/arc.c:3851 config/m32r/m32r.c:2093
 #, c-format
 msgid "invalid operand to %%s code"
 msgstr "неисправан операнд за %%s кôд"
 
-#: config/arc/arc.c:4001 config/m32r/m32r.c:2126
+#: config/arc/arc.c:3999 config/m32r/m32r.c:2126
 #, c-format
 msgid "invalid operand to %%R code"
 msgstr "неисправан операнд за %%R кôд"
 
-#: config/arc/arc.c:4077 config/m32r/m32r.c:2149
+#: config/arc/arc.c:4075 config/m32r/m32r.c:2149
 #, c-format
 msgid "invalid operand to %%H/%%L code"
 msgstr "неисправан операнд за %%H/%%L кôд"
 
-#: config/arc/arc.c:4145 config/m32r/m32r.c:2220
+#: config/arc/arc.c:4143 config/m32r/m32r.c:2220
 #, c-format
 msgid "invalid operand to %%U code"
 msgstr "неисправан операнд за %%U кôд"
 
-#: config/arc/arc.c:4157
+#: config/arc/arc.c:4155
 #, c-format
 msgid "invalid operand to %%V code"
 msgstr "неисправан операнд за %%V кôд"
 
-#: config/arc/arc.c:4214
+#: config/arc/arc.c:4212
 #, fuzzy, c-format
 #| msgid "invalid operand to %%R code"
 msgid "invalid operand to %%O code"
@@ -3405,19 +3405,19 @@
 
 #. Unknown flag.
 #. Undocumented flag.
-#: config/arc/arc.c:4240 config/epiphany/epiphany.c:1305
-#: config/m32r/m32r.c:2247 config/nds32/nds32.c:3079 config/sparc/sparc.c:9569
+#: config/arc/arc.c:4238 config/epiphany/epiphany.c:1305
+#: config/m32r/m32r.c:2247 config/nds32/nds32.c:3080 config/sparc/sparc.c:9569
 #, c-format
 msgid "invalid operand output code"
 msgstr "неисправан кôд излаза операнада"
 
-#: config/arc/arc.c:5869
+#: config/arc/arc.c:5860
 #, fuzzy, c-format
 #| msgid "invalid UNSPEC as operand"
 msgid "invalid UNSPEC as operand: %d"
 msgstr "неисправан УНСПЕЦ као операнд"
 
-#: config/arc/arc.c:6158 config/cris/cris.c:2568
+#: config/arc/arc.c:6149 config/cris/cris.c:2568
 msgid "unrecognized supposed constant"
 msgstr "непрепозната претпостављена константа"
 
@@ -3453,7 +3453,7 @@
 #: config/arm/arm.c:22685 config/arm/arm.c:22692 config/bfin/bfin.c:1441
 #: config/bfin/bfin.c:1448 config/bfin/bfin.c:1455 config/bfin/bfin.c:1462
 #: config/bfin/bfin.c:1471 config/bfin/bfin.c:1478 config/bfin/bfin.c:1485
-#: config/bfin/bfin.c:1492 config/nds32/nds32.c:3098
+#: config/bfin/bfin.c:1492 config/nds32/nds32.c:3099
 #, c-format
 msgid "invalid operand for code '%c'"
 msgstr "неисправан операнд за кôд ‘%c’"
@@ -3808,112 +3808,112 @@
 msgid "bad output_condmove_single operand"
 msgstr "лош операнд output_condmove_single"
 
-#: config/i386/i386.c:17387
+#: config/i386/i386.c:17390
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "неисправан УНСПЕЦ као операнд"
 
-#: config/i386/i386.c:17925
+#: config/i386/i386.c:17928
 #, fuzzy, c-format
 #| msgid "invalid use of %<restrict%>"
 msgid "invalid use of register '%s'"
 msgstr "неисправна употреба %<restrict%>"
 
-#: config/i386/i386.c:17930
+#: config/i386/i386.c:17933
 #, fuzzy, c-format
 #| msgid "invalid lvalue in asm output %d"
 msgid "invalid use of asm flag output"
 msgstr "неисправна л-вредност у излазу асемблера %d"
 
-#: config/i386/i386.c:18160
+#: config/i386/i386.c:18163
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "invalid operand size for operand code 'O'"
 msgstr "неисправан операнд за кôд ‘%c’"
 
-#: config/i386/i386.c:18195
+#: config/i386/i386.c:18198
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "invalid operand size for operand code 'z'"
 msgstr "неисправан операнд за кôд ‘%c’"
 
-#: config/i386/i386.c:18264
+#: config/i386/i386.c:18267
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "неисправан операнд за кôд ‘%c’"
 
-#: config/i386/i386.c:18269
+#: config/i386/i386.c:18272
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "invalid operand size for operand code 'Z'"
 msgstr "неисправан операнд за кôд ‘%c’"
 
-#: config/i386/i386.c:18346
+#: config/i386/i386.c:18349
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "операнд није ни константа ни условни кôд, неисправан кôд аргумента ‘c’"
 
-#: config/i386/i386.c:18425
+#: config/i386/i386.c:18428
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "операнд није ни константа ни условни кôд, неисправан кôд аргумента ‘c’"
 
-#: config/i386/i386.c:18443
+#: config/i386/i386.c:18446
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "операнд није ни константа ни условни кôд, неисправан кôд аргумента ‘c’"
 
-#: config/i386/i386.c:18456
+#: config/i386/i386.c:18459
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "операнд није ни константа ни условни кôд, неисправан кôд аргумента ‘c’"
 
-#: config/i386/i386.c:18471
+#: config/i386/i386.c:18474
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr "операнд није ни константа ни условни кôд, неисправан кôд аргумента ‘c’"
 
-#: config/i386/i386.c:18499
+#: config/i386/i386.c:18502
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr "операнд није ни константа ни условни кôд, неисправан кôд аргумента ‘c’"
 
-#: config/i386/i386.c:18517
+#: config/i386/i386.c:18520
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr "операнд није ни константа ни условни кôд, неисправан кôд аргумента ‘c’"
 
-#: config/i386/i386.c:18540
+#: config/i386/i386.c:18543
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "операнд није ни константа ни условни кôд, неисправан кôд аргумента ‘c’"
 
-#: config/i386/i386.c:18626
+#: config/i386/i386.c:18629
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "неисправан кôд операнда ‘%c;’"
 
-#: config/i386/i386.c:18688
+#: config/i386/i386.c:18691
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "неисправна ограничења за операнд"
 
-#: config/i386/i386.c:18738
+#: config/i386/i386.c:18741
 #, fuzzy, c-format
 #| msgid "%Hinvalid controlling predicate"
 msgid "invalid vector immediate"
 msgstr "%Hнеисправан контролишући предикат"
 
-#: config/i386/i386.c:29572
+#: config/i386/i386.c:29575
 msgid "unknown insn mode"
 msgstr "непознат режим ије"
 
@@ -3953,7 +3953,7 @@
 msgstr "неисправан %%P операнд"
 
 #: config/iq2000/iq2000.c:3185 config/powerpcspe/powerpcspe.c:23951
-#: config/rs6000/rs6000.c:21444
+#: config/rs6000/rs6000.c:21521
 #, c-format
 msgid "invalid %%p value"
 msgstr "неисправна %%p вредност"
@@ -4011,7 +4011,7 @@
 msgstr "адреса постувећања није регистар"
 
 #: config/m32r/m32r.c:2350 config/m32r/m32r.c:2365
-#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33292
+#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33348
 msgid "bad address"
 msgstr "лоша адреса"
 
@@ -4138,207 +4138,207 @@
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr "Покушајте да покренете ‘%s’ у шкољци да повећате ограничење.\n"
 
-#: config/powerpcspe/powerpcspe.c:4411 config/rs6000/rs6000.c:4258
+#: config/powerpcspe/powerpcspe.c:4411 config/rs6000/rs6000.c:4278
 msgid "-maltivec=le not allowed for big-endian targets"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4423 config/rs6000/rs6000.c:4273
+#: config/powerpcspe/powerpcspe.c:4423 config/rs6000/rs6000.c:4293
 #, fuzzy
 #| msgid "Use hardware floating point"
 msgid "-mvsx requires hardware floating point"
 msgstr "Користи хардверски покретан зарез"
 
-#: config/powerpcspe/powerpcspe.c:4431 config/rs6000/rs6000.c:4281
+#: config/powerpcspe/powerpcspe.c:4431 config/rs6000/rs6000.c:4301
 #, fuzzy
 #| msgid "-f%s and -msdata=%s are incompatible"
 msgid "-mvsx and -mpaired are incompatible"
 msgstr "-f%s и -msdata=%s нису сагласни"
 
-#: config/powerpcspe/powerpcspe.c:4433 config/rs6000/rs6000.c:4283
+#: config/powerpcspe/powerpcspe.c:4433 config/rs6000/rs6000.c:4303
 #, fuzzy
 #| msgid "Disable indexed addressing"
 msgid "-mvsx needs indexed addressing"
 msgstr "Искључи индексно адресирање"
 
-#: config/powerpcspe/powerpcspe.c:4438 config/rs6000/rs6000.c:4288
+#: config/powerpcspe/powerpcspe.c:4438 config/rs6000/rs6000.c:4308
 #, fuzzy
 #| msgid "-f%s and -msdata=%s are incompatible"
 msgid "-mvsx and -mno-altivec are incompatible"
 msgstr "-f%s и -msdata=%s нису сагласни"
 
-#: config/powerpcspe/powerpcspe.c:4440 config/rs6000/rs6000.c:4290
+#: config/powerpcspe/powerpcspe.c:4440 config/rs6000/rs6000.c:4310
 msgid "-mno-altivec disables vsx"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4648 config/rs6000/rs6000.c:4416
+#: config/powerpcspe/powerpcspe.c:4648 config/rs6000/rs6000.c:4436
 #, fuzzy
 #| msgid "--resource requires -o"
 msgid "-mquad-memory requires 64-bit mode"
 msgstr "--resource захтева -o"
 
-#: config/powerpcspe/powerpcspe.c:4651 config/rs6000/rs6000.c:4419
+#: config/powerpcspe/powerpcspe.c:4651 config/rs6000/rs6000.c:4439
 msgid "-mquad-memory-atomic requires 64-bit mode"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4663 config/rs6000/rs6000.c:4431
+#: config/powerpcspe/powerpcspe.c:4663 config/rs6000/rs6000.c:4451
 #, fuzzy
 #| msgid "Generate code in little endian mode"
 msgid "-mquad-memory is not available in little endian mode"
 msgstr "Створи кôд у режиму мале крајности"
 
-#: config/powerpcspe/powerpcspe.c:4735 config/rs6000/rs6000.c:4512
+#: config/powerpcspe/powerpcspe.c:4735 config/rs6000/rs6000.c:4532
 #, fuzzy
 #| msgid "--resource requires -o"
 msgid "-mtoc-fusion requires 64-bit"
 msgstr "--resource захтева -o"
 
-#: config/powerpcspe/powerpcspe.c:4742 config/rs6000/rs6000.c:4519
+#: config/powerpcspe/powerpcspe.c:4742 config/rs6000/rs6000.c:4539
 msgid "-mtoc-fusion requires medium/large code model"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10915
+#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10947
 #, fuzzy
 #| msgid "bad test"
 msgid "bad move"
 msgstr "лоша проба"
 
-#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21087
+#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21164
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21278
+#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21355
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%e value"
 msgstr "неисправна %%H вредност"
 
-#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21299
+#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21376
 #, c-format
 msgid "invalid %%f value"
 msgstr "неисправна %%f вредност"
 
-#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21308
+#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21385
 #, c-format
 msgid "invalid %%F value"
 msgstr "неисправна %%F вредност"
 
-#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21317
+#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21394
 #, c-format
 msgid "invalid %%G value"
 msgstr "неисправна %%G вредност"
 
-#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21352
+#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21429
 #, c-format
 msgid "invalid %%j code"
 msgstr "неисправан %%j кôд"
 
-#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21362
+#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21439
 #, c-format
 msgid "invalid %%J code"
 msgstr "неисправан %%J кôд"
 
-#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21372
+#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21449
 #, c-format
 msgid "invalid %%k value"
 msgstr "неисправна %%k вредност"
 
-#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21387
+#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21464
 #: config/xtensa/xtensa.c:2415
 #, c-format
 msgid "invalid %%K value"
 msgstr "неисправна %%K вредност"
 
-#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21434
+#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21511
 #, c-format
 msgid "invalid %%O value"
 msgstr "неисправна %%O вредност"
 
-#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21481
+#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21558
 #, c-format
 msgid "invalid %%q value"
 msgstr "неисправна %%q вредност"
 
-#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21534
+#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21611
 #, c-format
 msgid "invalid %%T value"
 msgstr "неисправна %%T вредност"
 
-#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21546
+#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21623
 #, c-format
 msgid "invalid %%u value"
 msgstr "неисправна %%u вредност"
 
-#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21560
+#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21637
 #: config/xtensa/xtensa.c:2384
 #, c-format
 msgid "invalid %%v value"
 msgstr "неисправна %%v вредност"
 
-#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21627
+#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21704
 #: config/xtensa/xtensa.c:2436
 #, c-format
 msgid "invalid %%x value"
 msgstr "неисправна %%x вредност"
 
-#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21747
+#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21824
 #, fuzzy, c-format
 #| msgid "invalid punctuation %qc in constraint"
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "неисправна интерпункција %qc у ограничењу"
 
-#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22282
+#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22359
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22288
+#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22365
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22294
+#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22371
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36572
+#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36628
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "алтивек аргумент прослеђен непрототипизираној функцији"
 
-#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38739
+#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38795
 #, fuzzy
 #| msgid "Do not generate a single exit point for each function"
 msgid "Could not generate addis value for fusion"
 msgstr "Не стварај јединствену излазну тачку за сваку функцију"
 
-#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38809
+#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38865
 #, fuzzy
 #| msgid "unable to generate reloads for:"
 msgid "Unable to generate load/store offset for fusion"
 msgstr "не могу да створим поновљена учитавања за:"
 
-#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38908
+#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38964
 msgid "Bad GPR fusion"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39126
+#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39182
 msgid "emit_fusion_p9_load, bad reg #1"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39172
+#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39228
 msgid "emit_fusion_p9_load, bad reg #2"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39175
+#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39231
 msgid "emit_fusion_p9_load not MEM"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39213
+#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39269
 msgid "emit_fusion_p9_store, bad reg #1"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39259
+#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39315
 msgid "emit_fusion_p9_store, bad reg #2"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39262
+#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39318
 msgid "emit_fusion_p9_store not MEM"
 msgstr ""
 
@@ -4752,14 +4752,14 @@
 #: c/gimple-parser.c:188 c/gimple-parser.c:197 c/gimple-parser.c:226
 #: c/gimple-parser.c:1375 c/gimple-parser.c:1404 c/gimple-parser.c:1484
 #: c/gimple-parser.c:1511 c/c-parser.c:3204 c/c-parser.c:9967
-#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27841
-#: cp/parser.c:28430
+#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27838
+#: cp/parser.c:28427
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "очекивано је %<;%>"
 
 #: c/c-parser.c:2431 c/c-parser.c:7573 c/c-parser.c:8015 c/c-parser.c:8058
-#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27839 cp/parser.c:28448
+#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27836 cp/parser.c:28445
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<,%>"
@@ -4775,7 +4775,7 @@
 #: c/gimple-parser.c:821 c/gimple-parser.c:837 c/gimple-parser.c:853
 #: c/gimple-parser.c:880 c/gimple-parser.c:915 c/gimple-parser.c:1038
 #: c/gimple-parser.c:1209 c/gimple-parser.c:1220 c/gimple-parser.c:1342
-#: c/gimple-parser.c:1441 cp/parser.c:28478
+#: c/gimple-parser.c:1441 cp/parser.c:28475
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<)%>"
@@ -4784,7 +4784,7 @@
 #: c/c-parser.c:3824 c/c-parser.c:4733 c/c-parser.c:4769 c/c-parser.c:6441
 #: c/c-parser.c:8125 c/c-parser.c:8983 c/c-parser.c:9127 c/c-parser.c:11588
 #: c/c-parser.c:18220 c/c-parser.c:18222 c/gimple-parser.c:1015
-#: cp/parser.c:28442
+#: cp/parser.c:28439
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<]%>"
@@ -4801,7 +4801,7 @@
 #: c/c-parser.c:17792 c/gimple-parser.c:363 c/gimple-parser.c:811
 #: c/gimple-parser.c:873 c/gimple-parser.c:911 c/gimple-parser.c:1198
 #: c/gimple-parser.c:1339 c/gimple-parser.c:1438 c/c-parser.c:11911
-#: cp/parser.c:28433
+#: cp/parser.c:28430
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "очекивано је %<(%>"
@@ -4808,7 +4808,7 @@
 
 #: c/c-parser.c:4903 c/c-parser.c:10310 c/c-parser.c:16212 c/c-parser.c:18449
 #: c/gimple-parser.c:141 c/gimple-parser.c:1444 c/c-parser.c:3018
-#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18155 cp/parser.c:28439
+#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18152 cp/parser.c:28436
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "очекивано је %<{%>"
@@ -4818,14 +4818,14 @@
 #: c/c-parser.c:12351 c/c-parser.c:12493 c/c-parser.c:12864 c/c-parser.c:12957
 #: c/c-parser.c:13566 c/c-parser.c:17636 c/c-parser.c:17695
 #: c/gimple-parser.c:431 c/gimple-parser.c:1492 c/gimple-parser.c:1519
-#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28472 cp/parser.c:29597
-#: cp/parser.c:32279
+#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28469 cp/parser.c:29594
+#: cp/parser.c:32276
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<:%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.c:5974 cp/parser.c:28365
+#: c/c-parser.c:5974 cp/parser.c:28362
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<while%>"
@@ -4837,20 +4837,20 @@
 msgid "expected %<.%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30172
-#: cp/parser.c:30246
+#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30169
+#: cp/parser.c:30243
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@end%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28457
+#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28454
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<>%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28481
+#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28478
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<,%> or %<)%>"
@@ -4859,36 +4859,36 @@
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15190 c/c-parser.c:15234 c/c-parser.c:15466 c/c-parser.c:15701
 #: c/c-parser.c:17833 c/gimple-parser.c:286 c/c-parser.c:4792
-#: cp/parser.c:28460
+#: cp/parser.c:28457
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "очекивано је %<=%>"
 
-#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28436
-#: cp/parser.c:30389
+#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28433
+#: cp/parser.c:30386
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<}%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35674
+#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35671
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "очекивано је %<#pragma omp section%> или %<}%>"
 
-#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28445 cp/parser.c:31535
+#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28442 cp/parser.c:31532
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<[%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-typeck.c:7847
+#: c/c-typeck.c:7852
 #, fuzzy
 #| msgid "<anonymous>"
 msgid "(anonymous)"
 msgstr "<анонимно>"
 
-#: c/gimple-parser.c:795 cp/parser.c:15791 cp/parser.c:28454
+#: c/gimple-parser.c:795 cp/parser.c:15788 cp/parser.c:28451
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<<%>"
@@ -5193,11 +5193,11 @@
 msgid "%r%s:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr ""
 
-#: cp/pt.c:1949 cp/semantics.c:5268
+#: cp/pt.c:1949 cp/semantics.c:5271
 msgid "candidates are:"
 msgstr "кандидати су:"
 
-#: cp/pt.c:1951 cp/pt.c:22975
+#: cp/pt.c:1951 cp/pt.c:23053
 #, fuzzy
 #| msgid "candidate 1:"
 msgid "candidate is:"
@@ -5261,27 +5261,27 @@
 msgid "source type is not polymorphic"
 msgstr ""
 
-#: cp/typeck.c:6083 c/c-typeck.c:4261
+#: cp/typeck.c:6083 c/c-typeck.c:4266
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "погрешан тип аргумента уз унарно минус"
 
-#: cp/typeck.c:6084 c/c-typeck.c:4248
+#: cp/typeck.c:6084 c/c-typeck.c:4253
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "погрешан тип аргумента уз унарно плус"
 
-#: cp/typeck.c:6111 c/c-typeck.c:4302
+#: cp/typeck.c:6111 c/c-typeck.c:4307
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "погрешан тип аргумента уз битски комплемент"
 
-#: cp/typeck.c:6128 c/c-typeck.c:4310
+#: cp/typeck.c:6128 c/c-typeck.c:4315
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "погрешан тип аргумента за abs"
 
-#: cp/typeck.c:6140 c/c-typeck.c:4322
+#: cp/typeck.c:6140 c/c-typeck.c:4327
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "погрешан тип аргумента за конјугацију"
@@ -5545,67 +5545,67 @@
 msgid "Expected attribute bit name"
 msgstr "Очекивано је име атрибутског бита"
 
-#: fortran/module.c:3223
+#: fortran/module.c:3225
 msgid "Expected integer string"
 msgstr "Очекивана је целобројна ниска"
 
-#: fortran/module.c:3227
+#: fortran/module.c:3229
 msgid "Error converting integer"
 msgstr "Грешка при претварању целог броја"
 
-#: fortran/module.c:3249
+#: fortran/module.c:3251
 msgid "Expected real string"
 msgstr "Очекивана је реална ниска"
 
-#: fortran/module.c:3474
+#: fortran/module.c:3476
 msgid "Expected expression type"
 msgstr "Очекиван је тип израза"
 
-#: fortran/module.c:3554
+#: fortran/module.c:3556
 msgid "Bad operator"
 msgstr "Лош оператор"
 
-#: fortran/module.c:3671
+#: fortran/module.c:3673
 msgid "Bad type in constant expression"
 msgstr "Лош тип у константном изразу"
 
-#: fortran/module.c:7038
+#: fortran/module.c:7040
 msgid "Unexpected end of module"
 msgstr "Неочекиван крај модула"
 
-#: fortran/parse.c:1757
+#: fortran/parse.c:1761
 msgid "arithmetic IF"
 msgstr "аритметичко IF"
 
-#: fortran/parse.c:1766
+#: fortran/parse.c:1770
 msgid "attribute declaration"
 msgstr "декларација атрибута"
 
-#: fortran/parse.c:1802
+#: fortran/parse.c:1806
 msgid "data declaration"
 msgstr "декларација података"
 
-#: fortran/parse.c:1820
+#: fortran/parse.c:1824
 msgid "derived type declaration"
 msgstr "декларација изведеног типа"
 
-#: fortran/parse.c:1947
+#: fortran/parse.c:1951
 msgid "block IF"
 msgstr "блоковско IF"
 
-#: fortran/parse.c:1956
+#: fortran/parse.c:1960
 msgid "implied END DO"
 msgstr "имплицитно END DO"
 
-#: fortran/parse.c:2050 fortran/resolve.c:11199
+#: fortran/parse.c:2054 fortran/resolve.c:11219
 msgid "assignment"
 msgstr "додела"
 
-#: fortran/parse.c:2053 fortran/resolve.c:11250 fortran/resolve.c:11253
+#: fortran/parse.c:2057 fortran/resolve.c:11270 fortran/resolve.c:11273
 msgid "pointer assignment"
 msgstr "додела показивача"
 
-#: fortran/parse.c:2071
+#: fortran/parse.c:2075
 msgid "simple IF"
 msgstr "једноставно IF"
 
@@ -5729,125 +5729,130 @@
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr "Операнд унарног бројевног оператора ‘%s’ код %%L је %s"
 
-#: fortran/resolve.c:3878
+#: fortran/resolve.c:3879
+#, c-format
+msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
+msgstr ""
+
+#: fortran/resolve.c:3884
 #, fuzzy, c-format
 #| msgid "Operands of binary numeric operator '%s' at %%L are %s/%s"
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr "Операнди бинарног бројевног оператора ‘%s’ код %%L су %s/%s"
 
-#: fortran/resolve.c:3893
+#: fortran/resolve.c:3899
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr "Операнди оператора надовезивања ниски код %%L су %s/%s"
 
-#: fortran/resolve.c:3926
+#: fortran/resolve.c:3932
 #, fuzzy, c-format
 #| msgid "Operands of logical operator '%s' at %%L are %s/%s"
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr "Операнди логичког оператора ‘%s’ код %%L су %s/%s"
 
-#: fortran/resolve.c:3949
+#: fortran/resolve.c:3955
 #, fuzzy, c-format
 #| msgid "Operand of .NOT. operator at %%L is %s"
 msgid "Operand of .not. operator at %%L is %s"
 msgstr "Операнд оператора .NOT. код %%L је %s"
 
-#: fortran/resolve.c:3963
+#: fortran/resolve.c:3969
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "Комплексне величине се не могу поредити код %L"
 
-#: fortran/resolve.c:4015
+#: fortran/resolve.c:4021
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr "Логичке код %%L морају бити поређене са %s уместо %s"
 
-#: fortran/resolve.c:4021
+#: fortran/resolve.c:4027
 #, fuzzy, c-format
 #| msgid "Operands of comparison operator '%s' at %%L are %s/%s"
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr "Операнди оператора поређења ‘%s’ код %%L су %s/%s"
 
-#: fortran/resolve.c:4034
+#: fortran/resolve.c:4040
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L; did you mean '%s'?"
 msgstr ""
 
-#: fortran/resolve.c:4037
+#: fortran/resolve.c:4043
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr ""
 
-#: fortran/resolve.c:4040
+#: fortran/resolve.c:4046
 #, fuzzy, c-format
 #| msgid "Operand of user operator '%s' at %%L is %s"
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr "Операнд корисничког оператора ‘%s’ код %%L је %s"
 
-#: fortran/resolve.c:4044
+#: fortran/resolve.c:4050
 #, fuzzy, c-format
 #| msgid "Operands of user operator '%s' at %%L are %s/%s"
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr "Операнди корисничког оператора ‘%s’ код %%L су %s/%s"
 
-#: fortran/resolve.c:4132
+#: fortran/resolve.c:4138
 #, fuzzy, c-format
 #| msgid "Inconsistent ranks for operator at %L and %L"
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "Неусаглашени рангови за оператор код %L и %L"
 
-#: fortran/resolve.c:6849
+#: fortran/resolve.c:6855
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.c:6853
+#: fortran/resolve.c:6859
 #, fuzzy
 #| msgid "Perform variable tracking"
 msgid "iterator variable"
 msgstr "Изврши праћење променљивих"
 
-#: fortran/resolve.c:6857
+#: fortran/resolve.c:6863
 #, fuzzy
 #| msgid "Step expression in DO loop at %L cannot be zero"
 msgid "Start expression in DO loop"
 msgstr "Израз за корак у петљи DO код %L не може бити нула"
 
-#: fortran/resolve.c:6861
+#: fortran/resolve.c:6867
 #, fuzzy
 #| msgid "invalid expression as operand"
 msgid "End expression in DO loop"
 msgstr "неисправан израз као операнд"
 
-#: fortran/resolve.c:6865
+#: fortran/resolve.c:6871
 #, fuzzy
 #| msgid "Step expression in DO loop at %L cannot be zero"
 msgid "Step expression in DO loop"
 msgstr "Израз за корак у петљи DO код %L не може бити нула"
 
-#: fortran/resolve.c:7150 fortran/resolve.c:7153
+#: fortran/resolve.c:7156 fortran/resolve.c:7159
 #, fuzzy
 #| msgid "DEALLOCATE "
 msgid "DEALLOCATE object"
 msgstr "DEALLOCATE "
 
-#: fortran/resolve.c:7525 fortran/resolve.c:7528
+#: fortran/resolve.c:7531 fortran/resolve.c:7534
 #, fuzzy
 #| msgid "ALLOCATE "
 msgid "ALLOCATE object"
 msgstr "ALLOCATE "
 
-#: fortran/resolve.c:7720 fortran/resolve.c:9417
+#: fortran/resolve.c:7726 fortran/resolve.c:9428
 msgid "STAT variable"
 msgstr ""
 
-#: fortran/resolve.c:7764 fortran/resolve.c:9429
+#: fortran/resolve.c:7770 fortran/resolve.c:9440
 msgid "ERRMSG variable"
 msgstr ""
 
-#: fortran/resolve.c:9219
+#: fortran/resolve.c:9230
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.c:9441
+#: fortran/resolve.c:9452
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
@@ -5880,7 +5885,7 @@
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:10154
+#: fortran/trans-expr.c:10157
 #, fuzzy
 #| msgid "assignment of read-only location"
 msgid "Assignment of scalar to unallocated array"
@@ -5891,13 +5896,13 @@
 msgid "Unequal character lengths (%ld/%ld) in %s"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:8088
+#: fortran/trans-intrinsic.c:8090
 #, fuzzy, c-format
 #| msgid "Argument NCOPIES of REPEAT intrinsic is negative"
 msgid "Argument NCOPIES of REPEAT intrinsic is negative (its value is %ld)"
 msgstr "Аргумент NCOPIES уз сопствено REPEAT негативан је"
 
-#: fortran/trans-intrinsic.c:8120
+#: fortran/trans-intrinsic.c:8122
 #, fuzzy
 #| msgid "Argument NCOPIES of REPEAT intrinsic is negative"
 msgid "Argument NCOPIES of REPEAT intrinsic is too large"
@@ -5924,15 +5929,15 @@
 msgid "Invalid image number %d in SYNC IMAGES"
 msgstr ""
 
-#: fortran/trans-stmt.c:2180
+#: fortran/trans-stmt.c:2177
 msgid "Loop iterates infinitely"
 msgstr ""
 
-#: fortran/trans-stmt.c:2200 fortran/trans-stmt.c:2456
+#: fortran/trans-stmt.c:2197 fortran/trans-stmt.c:2453
 msgid "Loop variable has been modified"
 msgstr ""
 
-#: fortran/trans-stmt.c:2309
+#: fortran/trans-stmt.c:2306
 msgid "DO step value is zero"
 msgstr ""
 
@@ -6638,10 +6643,10 @@
 msgid "Allow dollar signs in entity names."
 msgstr "Дозволи долар у именима ентитета"
 
-#: fortran/lang.opt:485 config/alpha/alpha.opt:31 common.opt:783
-#: common.opt:985 common.opt:989 common.opt:993 common.opt:997 common.opt:1532
-#: common.opt:1588 common.opt:1712 common.opt:1716 common.opt:1946
-#: common.opt:2116 common.opt:2792
+#: fortran/lang.opt:485 config/alpha/alpha.opt:31 common.opt:649
+#: common.opt:783 common.opt:989 common.opt:993 common.opt:997 common.opt:1001
+#: common.opt:1536 common.opt:1592 common.opt:1716 common.opt:1720
+#: common.opt:1950 common.opt:2120 common.opt:2796
 #, fuzzy
 #| msgid "Does nothing.  Preserved for backward compatibility."
 msgid "Does nothing. Preserved for backward compatibility."
@@ -6913,12 +6918,12 @@
 msgstr "Додај подвлаке споља видљивим именима"
 
 #: fortran/lang.opt:751 c-family/c.opt:1356 c-family/c.opt:1384
-#: c-family/c.opt:1634 config/pa/pa.opt:42 config/pa/pa.opt:70 common.opt:1154
-#: common.opt:1333 common.opt:1408 common.opt:1676 common.opt:1799
-#: common.opt:2169 common.opt:2205 common.opt:2298 common.opt:2302
-#: common.opt:2407 common.opt:2498 common.opt:2506 common.opt:2514
-#: common.opt:2522 common.opt:2623 common.opt:2675 common.opt:2755
-#: common.opt:2893 common.opt:2897 common.opt:2901 common.opt:2905
+#: c-family/c.opt:1634 config/pa/pa.opt:42 config/pa/pa.opt:70 common.opt:1158
+#: common.opt:1337 common.opt:1412 common.opt:1680 common.opt:1803
+#: common.opt:2173 common.opt:2209 common.opt:2302 common.opt:2306
+#: common.opt:2411 common.opt:2502 common.opt:2510 common.opt:2518
+#: common.opt:2526 common.opt:2627 common.opt:2679 common.opt:2759
+#: common.opt:2897 common.opt:2901 common.opt:2905 common.opt:2909
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr "Не ради ништа. Остављено ради сагласности уназад."
 
@@ -6982,7 +6987,7 @@
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:220 c-family/c.opt:224
 #: c-family/c.opt:236 c-family/c.opt:1855 c-family/c.opt:1863 brig/lang.opt:39
-#: config/darwin.opt:56 common.opt:338 common.opt:341 common.opt:3046
+#: config/darwin.opt:56 common.opt:338 common.opt:341 common.opt:3050
 #, c-format
 msgid "missing filename after %qs"
 msgstr "недостаје име датотеке после %qs"
@@ -7744,7 +7749,7 @@
 #: c-family/c.opt:1525 c-family/c.opt:1528 c-family/c.opt:1569
 #: c-family/c.opt:1704 c-family/c.opt:1731 c-family/c.opt:1771
 #: c-family/c.opt:1802 c-family/c.opt:1806 c-family/c.opt:1822
-#: config/ia64/ia64.opt:167 config/ia64/ia64.opt:170 c-family/c-opts.c:434
+#: config/ia64/ia64.opt:167 config/ia64/ia64.opt:170 c-family/c-opts.c:432
 #, gcc-internal-format
 msgid "switch %qs is no longer supported"
 msgstr "прекидач %qs више није подржан"
@@ -17060,10 +17065,6 @@
 msgid "Warn if dereferencing a NULL pointer may lead to erroneous or undefined behavior."
 msgstr ""
 
-#: common.opt:649
-msgid "Warn if the loop cannot be optimized due to nontrivial assumptions."
-msgstr "Упозори ако се петља не може оптимизовати услед нетривијалних претпоставки."
-
 #: common.opt:656
 msgid "Warn about some C++ One Definition Rule violations during link time optimization."
 msgstr ""
@@ -17302,2188 +17303,2188 @@
 msgid "-dumpdir <dir>\tSet the directory name to be used for dumps."
 msgstr "Постави основно име датотека за пописе"
 
-#: common.opt:946
+#: common.opt:950
 msgid "The version of the C++ ABI in use."
 msgstr ""
 
-#: common.opt:950
+#: common.opt:954
 msgid "Aggressively optimize loops using language constraints."
 msgstr ""
 
-#: common.opt:954
+#: common.opt:958
 #, fuzzy
 #| msgid "Align the start of functions"
 msgid "Align the start of functions."
 msgstr "Поравнај почетке функција"
 
-#: common.opt:964
+#: common.opt:968
 #, fuzzy
 #| msgid "Align labels which are only reached by jumping"
 msgid "Align labels which are only reached by jumping."
 msgstr "Поравнај етикете које се достижу једино скакањем"
 
-#: common.opt:971
+#: common.opt:975
 #, fuzzy
 #| msgid "Align all labels"
 msgid "Align all labels."
 msgstr "Поравнај све етикете"
 
-#: common.opt:978
+#: common.opt:982
 #, fuzzy
 #| msgid "Align the start of loops"
 msgid "Align the start of loops."
 msgstr "Поравнај почетке петљи"
 
-#: common.opt:1001
+#: common.opt:1005
 msgid "Select what to sanitize."
 msgstr ""
 
-#: common.opt:1005
+#: common.opt:1009
 msgid "Select type of coverage sanitization."
 msgstr ""
 
-#: common.opt:1009
+#: common.opt:1013
 msgid "-fasan-shadow-offset=<number>\tUse custom shadow memory offset."
 msgstr ""
 
-#: common.opt:1013
+#: common.opt:1017
 msgid "-fsanitize-sections=<sec1,sec2,...>\tSanitize global variables in user-defined sections."
 msgstr ""
 
-#: common.opt:1018
+#: common.opt:1022
 msgid "After diagnosing undefined behavior attempt to continue execution."
 msgstr ""
 
-#: common.opt:1022
+#: common.opt:1026
 #, fuzzy
 #| msgid "This switch is deprecated; use -Wextra instead"
 msgid "This switch is deprecated; use -fsanitize-recover= instead."
 msgstr "Овај прекидач је превазиђен; користите -Wextra"
 
-#: common.opt:1029
+#: common.opt:1033
 msgid "Use trap instead of a library function for undefined behavior sanitization."
 msgstr ""
 
-#: common.opt:1033
+#: common.opt:1037
 #, fuzzy
 #| msgid "Generate unwind tables that are exact at each instruction boundary"
 msgid "Generate unwind tables that are exact at each instruction boundary."
 msgstr "Стварај табеле одмотавања које су тачне на свакој граници инструкција"
 
-#: common.opt:1037
+#: common.opt:1041
 #, fuzzy
 #| msgid "Generate isel instructions"
 msgid "Generate auto-inc/dec instructions."
 msgstr "Стварај инструкције isel"
 
-#: common.opt:1041
+#: common.opt:1045
 msgid "Use sample profile information for call graph node weights. The default profile file is fbdata.afdo in 'pwd'."
 msgstr ""
 
-#: common.opt:1046
+#: common.opt:1050
 msgid "Use sample profile information for call graph node weights. The profile file is specified in the argument."
 msgstr ""
 
-#: common.opt:1055
+#: common.opt:1059
 #, fuzzy
 #| msgid "Generate code to check bounds before indexing arrays"
 msgid "Generate code to check bounds before indexing arrays."
 msgstr "Стварај кôд за проверу граница пре индексирања низова"
 
-#: common.opt:1059
+#: common.opt:1063
 #, fuzzy
 #| msgid "Replace add, compare, branch with branch on count register"
 msgid "Replace add, compare, branch with branch on count register."
 msgstr "Замени додавање-упоређивање-гранање регистром за гранање-на-збир"
 
-#: common.opt:1063
+#: common.opt:1067
 #, fuzzy
 #| msgid "Use profiling information for branch probabilities"
 msgid "Use profiling information for branch probabilities."
 msgstr "Користи профилишуће информације за вероватноће гранања"
 
-#: common.opt:1067
+#: common.opt:1071
 #, fuzzy
 #| msgid "Perform branch target load optimization before prologue / epilogue threading"
 msgid "Perform branch target load optimization before prologue / epilogue threading."
 msgstr "Оптимизуј учитавање циља гранања пре плетења пролога или епилога"
 
-#: common.opt:1071
+#: common.opt:1075
 #, fuzzy
 #| msgid "Perform branch target load optimization after prologue / epilogue threading"
 msgid "Perform branch target load optimization after prologue / epilogue threading."
 msgstr "Оптимизуј учитавање циља гранања после плетења пролога или епилога"
 
-#: common.opt:1075
+#: common.opt:1079
 #, fuzzy
 #| msgid "Restrict target load migration not to re-use registers in any basic block"
 msgid "Restrict target load migration not to re-use registers in any basic block."
 msgstr "Спречи миграцију учитавања циља да користи исте регистре у било којем основном блоку"
 
-#: common.opt:1079
+#: common.opt:1083
 #, fuzzy
 #| msgid "Mark <register> as being preserved across functions"
 msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions."
 msgstr "Означи да се <register> очувава преко функција"
 
-#: common.opt:1083
+#: common.opt:1087
 #, fuzzy
 #| msgid "Mark <register> as being corrupted by function calls"
 msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls."
 msgstr "Означи да се <register> квари позивима функција"
 
-#: common.opt:1090
+#: common.opt:1094
 #, fuzzy
 #| msgid "Save registers around function calls"
 msgid "Save registers around function calls."
 msgstr "Сачувавај регистре око позива функција"
 
-#: common.opt:1094
+#: common.opt:1098
 #, fuzzy
 #| msgid "This switch is deprecated; use -Wextra instead"
 msgid "This switch is deprecated; do not use."
 msgstr "Овај прекидач је превазиђен; користите -Wextra"
 
-#: common.opt:1098
+#: common.opt:1102
 #, fuzzy
 #| msgid "Check the return value of new"
 msgid "Check the return value of new in C++."
 msgstr "Провери повратни тип за new"
 
-#: common.opt:1102 common.opt:1106
+#: common.opt:1106 common.opt:1110
 #, fuzzy
 #| msgid "internal consistency failure"
 msgid "Perform internal consistency checkings."
 msgstr "неуспех услед унутрашње неусаглашености"
 
-#: common.opt:1110
+#: common.opt:1114
 #, fuzzy
 #| msgid "Enable function profiling"
 msgid "Enable code hoisting."
 msgstr "Укључи профилисање функција"
 
-#: common.opt:1114
+#: common.opt:1118
 msgid "Looks for opportunities to reduce stack adjustments and stack references."
 msgstr ""
 
-#: common.opt:1118
+#: common.opt:1122
 #, fuzzy
 #| msgid "Do not put uninitialized globals in the common section"
 msgid "Do not put uninitialized globals in the common section."
 msgstr "Не стављај неуспостављене глобалне у заједнички одељак"
 
-#: common.opt:1126
+#: common.opt:1130
 msgid "-fcompare-debug[=<opts>]\tCompile with and without e.g. -gtoggle, and compare the final-insns dump."
 msgstr ""
 
-#: common.opt:1130
+#: common.opt:1134
 msgid "Run only the second compilation of -fcompare-debug."
 msgstr ""
 
-#: common.opt:1134
+#: common.opt:1138
 #, fuzzy
 #| msgid "Perform global common subexpression elimination after register allocation"
 msgid "Perform comparison elimination after register allocation has finished."
 msgstr "Елиминиши глобалне заједничке подизразе после резервисања регистара"
 
-#: common.opt:1138
+#: common.opt:1142
 msgid "Do not perform optimizations increasing noticeably stack usage."
 msgstr ""
 
-#: common.opt:1142
+#: common.opt:1146
 #, fuzzy
 #| msgid "Perform a register copy-propagation optimization pass"
 msgid "Perform a register copy-propagation optimization pass."
 msgstr "Изврши оптимизацију за распростирање копирања преко регистара"
 
-#: common.opt:1146
+#: common.opt:1150
 #, fuzzy
 #| msgid "Perform cross-jumping optimization"
 msgid "Perform cross-jumping optimization."
 msgstr "Изврши оптимизацију за укрштање скокова"
 
-#: common.opt:1150
+#: common.opt:1154
 #, fuzzy
 #| msgid "When running CSE, follow jumps to their targets"
 msgid "When running CSE, follow jumps to their targets."
 msgstr "При извршавању ЦСЕа прати скокове до њихових циљева"
 
-#: common.opt:1158
+#: common.opt:1162
 #, fuzzy
 #| msgid "Omit range reduction step when performing complex division"
 msgid "Omit range reduction step when performing complex division."
 msgstr "Изостави корак свођења опсега при комплексним дељењима"
 
-#: common.opt:1162
+#: common.opt:1166
 msgid "Complex multiplication and division follow Fortran rules."
 msgstr ""
 
-#: common.opt:1166
+#: common.opt:1170
 #, fuzzy
 #| msgid "Place data items into their own section"
 msgid "Place data items into their own section."
 msgstr "Стављај податке у њихов сопствени одељак"
 
-#: common.opt:1170
+#: common.opt:1174
 msgid "List all available debugging counters with their limits and counts."
 msgstr ""
 
-#: common.opt:1174
+#: common.opt:1178
 msgid "-fdbg-cnt=<counter>:<limit>[,<counter>:<limit>,...]\tSet the debug counter limit."
 msgstr ""
 
-#: common.opt:1178
+#: common.opt:1182
 msgid "-fdebug-prefix-map=<old>=<new> Map one directory name to another in debug information."
 msgstr ""
 
-#: common.opt:1182
+#: common.opt:1186
 msgid "-ffile-prefix-map=<old>=<new> Map one directory name to another in compilation result."
 msgstr ""
 
-#: common.opt:1186
+#: common.opt:1190
 msgid "Output .debug_types section when using DWARF v4 debuginfo."
 msgstr ""
 
-#: common.opt:1192
+#: common.opt:1196
 #, fuzzy
 #| msgid "Defer popping functions args from stack until later"
 msgid "Defer popping functions args from stack until later."
 msgstr "Одложи за касније подизање аргумената са стека"
 
-#: common.opt:1196
+#: common.opt:1200
 #, fuzzy
 #| msgid "Attempt to fill delay slots of branch instructions"
 msgid "Attempt to fill delay slots of branch instructions."
 msgstr "Покушај да испуниш жлебове застоја за инструкције гранања"
 
-#: common.opt:1200
+#: common.opt:1204
 msgid "Delete dead instructions that may throw exceptions."
 msgstr ""
 
-#: common.opt:1204
+#: common.opt:1208
 #, fuzzy
 #| msgid "Delete useless null pointer checks"
 msgid "Delete useless null pointer checks."
 msgstr "Обриши бескорисне провере нултог показивача"
 
-#: common.opt:1208
+#: common.opt:1212
 msgid "Stream extra data to support more aggressive devirtualization in LTO local transformation mode."
 msgstr ""
 
-#: common.opt:1212
+#: common.opt:1216
 #, fuzzy
 #| msgid "Perform superblock formation via tail duplication"
 msgid "Perform speculative devirtualization."
 msgstr "Формирај суперблокове преко умножавања репа"
 
-#: common.opt:1216
+#: common.opt:1220
 msgid "Try to convert virtual calls to direct ones."
 msgstr ""
 
-#: common.opt:1220
+#: common.opt:1224
 #, fuzzy
 #| msgid "How often to emit source location at the beginning of line-wrapped diagnostics"
 msgid "-fdiagnostics-show-location=[once|every-line]\tHow often to emit source location at the beginning of line-wrapped diagnostics."
 msgstr "Колико често емитовати локацију у извору на почетку дијагностике преломљене у више линија"
 
-#: common.opt:1237
+#: common.opt:1241
 msgid "Show the source line with a caret indicating the column."
 msgstr ""
 
-#: common.opt:1245
+#: common.opt:1249
 msgid "-fdiagnostics-color=[never|always|auto]\tColorize diagnostics."
 msgstr ""
 
-#: common.opt:1265
+#: common.opt:1269
 msgid "Print fix-it hints in machine-readable form."
 msgstr ""
 
-#: common.opt:1269
+#: common.opt:1273
 msgid "Print fix-it hints to stderr in unified diff format."
 msgstr ""
 
-#: common.opt:1273
+#: common.opt:1277
 #, fuzzy
 #| msgid "Amend appropriate diagnostic messages with the command line option that controls them"
 msgid "Amend appropriate diagnostic messages with the command line option that controls them."
 msgstr "Допуни одговарајуће дијагностичке поруке опцијом командне линије које их контролишу"
 
-#: common.opt:1277
+#: common.opt:1281
 msgid "-fdisable-[tree|rtl|ipa]-<pass>=range1+range2 disables an optimization pass."
 msgstr ""
 
-#: common.opt:1281
+#: common.opt:1285
 msgid "-fenable-[tree|rtl|ipa]-<pass>=range1+range2 enables an optimization pass."
 msgstr ""
 
-#: common.opt:1285
+#: common.opt:1289
 #, fuzzy
 #| msgid "Dump various compiler internals to a file"
 msgid "-fdump-<type>\tDump various compiler internals to a file."
 msgstr "Попиши разне унутрашње ствари компилатора у датотеку"
 
-#: common.opt:1292
+#: common.opt:1296
 msgid "-fdump-final-insns=filename\tDump to filename the insns at the end of translation."
 msgstr ""
 
-#: common.opt:1296
+#: common.opt:1300
 msgid "-fdump-go-spec=filename\tWrite all declarations to file as Go code."
 msgstr ""
 
-#: common.opt:1300
+#: common.opt:1304
 #, fuzzy
 #| msgid "Suppress output of addresses in debugging dumps"
 msgid "Suppress output of addresses in debugging dumps."
 msgstr "Сузбиј испис адреса у исправљачким пописима"
 
-#: common.opt:1304
+#: common.opt:1308
 msgid "Collect and dump debug information into temporary file if ICE in C/C++ compiler occurred."
 msgstr ""
 
-#: common.opt:1309
+#: common.opt:1313
 msgid "Dump detailed information on GCC's internal representation of source code locations."
 msgstr ""
 
-#: common.opt:1313
+#: common.opt:1317
 #, fuzzy
 #| msgid "Do the full register move optimization pass"
 msgid "Dump optimization passes."
 msgstr "Изврши потпуни пролаз оптимизације померањем регистара"
 
-#: common.opt:1317
+#: common.opt:1321
 #, fuzzy
 #| msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps"
 msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps."
 msgstr "Сузбиј испис бројева инструкција, бројева линија и адреса у исправљачким пописима"
 
-#: common.opt:1321
+#: common.opt:1325
 #, fuzzy
 #| msgid "Suppress output of addresses in debugging dumps"
 msgid "Suppress output of previous and next insn numbers in debugging dumps."
 msgstr "Сузбиј испис адреса у исправљачким пописима"
 
-#: common.opt:1325
+#: common.opt:1329
 msgid "Enable CFI tables via GAS assembler directives."
 msgstr ""
 
-#: common.opt:1329
+#: common.opt:1333
 #, fuzzy
 #| msgid "Perform early inlining"
 msgid "Perform early inlining."
 msgstr "Изврши рано уткивање"
 
-#: common.opt:1337
+#: common.opt:1341
 #, fuzzy
 #| msgid "Perform Interprocedural constant propagation"
 msgid "Perform interprocedural reduction of aggregates."
 msgstr "Изврши међупроцедурално распростирање константи"
 
-#: common.opt:1341
+#: common.opt:1345
 #, fuzzy
 #| msgid "Perform unused type elimination in debug info"
 msgid "Perform unused symbol elimination in debug info."
 msgstr "Елиминиши неупотребље типове у исправљачким информацијама"
 
-#: common.opt:1345
+#: common.opt:1349
 #, fuzzy
 #| msgid "Perform unused type elimination in debug info"
 msgid "Perform unused type elimination in debug info."
 msgstr "Елиминиши неупотребље типове у исправљачким информацијама"
 
-#: common.opt:1349
+#: common.opt:1353
 msgid "Do not suppress C++ class debug information."
 msgstr "Не сузбијај исправљачке податке Ц++ класа."
 
-#: common.opt:1353
+#: common.opt:1357
 #, fuzzy
 #| msgid "Enable exception handling"
 msgid "Enable exception handling."
 msgstr "Укључи руковање изузецима"
 
-#: common.opt:1357
+#: common.opt:1361
 #, fuzzy
 #| msgid "Perform a number of minor, expensive optimizations"
 msgid "Perform a number of minor, expensive optimizations."
 msgstr "Изврши и неке мање, а скупе оптимизације"
 
-#: common.opt:1361
+#: common.opt:1365
 msgid "-fexcess-precision=[fast|standard]\tSpecify handling of excess floating-point precision."
 msgstr ""
 
-#: common.opt:1364
+#: common.opt:1368
 #, fuzzy, c-format
 #| msgid "unknown demangling style '%s'"
 msgid "unknown excess precision style %qs"
 msgstr "непознат стил распетљавања „%s“"
 
-#: common.opt:1376
+#: common.opt:1380
 msgid "-fpermitted-flt-eval-methods=[c11|ts-18661]\tSpecify which values of FLT_EVAL_METHOD are permitted."
 msgstr ""
 
-#: common.opt:1379
+#: common.opt:1383
 #, c-format
 msgid "unknown specification for the set of FLT_EVAL_METHOD values to permit %qs"
 msgstr ""
 
-#: common.opt:1392
+#: common.opt:1396
 msgid "Output lto objects containing both the intermediate language and binary output."
 msgstr ""
 
-#: common.opt:1396
+#: common.opt:1400
 #, fuzzy
 #| msgid "Assume no NaNs or infinities are generated"
 msgid "Assume no NaNs or infinities are generated."
 msgstr "Претпостави да се не стварају ни НаНи ни бесконачности"
 
-#: common.opt:1400
+#: common.opt:1404
 #, fuzzy
 #| msgid "Mark <register> as being unavailable to the compiler"
 msgid "-ffixed-<register>\tMark <register> as being unavailable to the compiler."
 msgstr "Означи да <register> није доступан компилатору"
 
-#: common.opt:1404
+#: common.opt:1408
 #, fuzzy
 #| msgid "Don't allocate floats and doubles in extended-precision registers"
 msgid "Don't allocate floats and doubles in extended-precision registers."
 msgstr "Не резервиши једноструке и двоструке у регистрима проширене тачности"
 
-#: common.opt:1412
+#: common.opt:1416
 #, fuzzy
 #| msgid "Perform Value Range Propagation on trees"
 msgid "Perform a forward propagation pass on RTL."
 msgstr "Изврши распростирање опсега вредности на стаблима"
 
-#: common.opt:1416
+#: common.opt:1420
 msgid "-ffp-contract=[off|on|fast]\tPerform floating-point expression contraction."
 msgstr ""
 
-#: common.opt:1419
+#: common.opt:1423
 #, fuzzy, c-format
 #| msgid "non-floating-point argument to function %qs"
 msgid "unknown floating point contraction style %qs"
 msgstr "аргумент који није у покретном зарезу за функцију %qs"
 
-#: common.opt:1433
+#: common.opt:1437
 msgid "Allow built-in functions ceil, floor, round, trunc to raise \"inexact\" exceptions."
 msgstr ""
 
-#: common.opt:1440
+#: common.opt:1444
 #, fuzzy
 #| msgid "Allow function addresses to be held in registers"
 msgid "Allow function addresses to be held in registers."
 msgstr "Дозволи држање адреса функција у регистрима"
 
-#: common.opt:1444
+#: common.opt:1448
 #, fuzzy
 #| msgid "Place each function into its own section"
 msgid "Place each function into its own section."
 msgstr "Стави сваку функцију у њен сопствени одељак"
 
-#: common.opt:1448
+#: common.opt:1452
 #, fuzzy
 #| msgid "Perform global common subexpression elimination"
 msgid "Perform global common subexpression elimination."
 msgstr "Елиминиши глобалне заједничке подизразе"
 
-#: common.opt:1452
+#: common.opt:1456
 #, fuzzy
 #| msgid "Perform enhanced load motion during global common subexpression elimination"
 msgid "Perform enhanced load motion during global common subexpression elimination."
 msgstr "Изврши побољшано кретање учитавања током елиминације глобалних заједничких подизраза"
 
-#: common.opt:1456
+#: common.opt:1460
 #, fuzzy
 #| msgid "Perform store motion after global common subexpression elimination"
 msgid "Perform store motion after global common subexpression elimination."
 msgstr "Изврши кретање складиштења током елиминације глобалних заједничких подизраза"
 
-#: common.opt:1460
+#: common.opt:1464
 #, fuzzy
 #| msgid "Perform redundant load after store elimination in global common subexpression"
 msgid "Perform redundant load after store elimination in global common subexpression elimination."
 msgstr "Елиминиши непотребно учитавање после складиштења у глобалном заједничком подизразу"
 
-#: common.opt:1465
+#: common.opt:1469
 #, fuzzy
 #| msgid "Perform global common subexpression elimination after register allocation"
 msgid "Perform global common subexpression elimination after register allocation has finished."
 msgstr "Елиминиши глобалне заједничке подизразе после резервисања регистара"
 
-#: common.opt:1482
+#: common.opt:1486
 msgid "-fgnat-encodings=[all|gdb|minimal]\tSelect the balance between GNAT encodings and standard DWARF emitted in the debug information"
 msgstr ""
 
-#: common.opt:1487
+#: common.opt:1491
 msgid "Enable in and out of Graphite representation."
 msgstr ""
 
-#: common.opt:1491
+#: common.opt:1495
 msgid "Enable Graphite Identity transformation."
 msgstr ""
 
-#: common.opt:1495
+#: common.opt:1499
 msgid "Enable hoisting adjacent loads to encourage generating conditional move instructions."
 msgstr ""
 
-#: common.opt:1504
+#: common.opt:1508
 msgid "Mark all loops as parallel."
 msgstr ""
 
-#: common.opt:1508 common.opt:1516 common.opt:2587
+#: common.opt:1512 common.opt:1520 common.opt:2591
 msgid "Enable loop nest transforms.  Same as -floop-nest-optimize."
 msgstr ""
 
-#: common.opt:1512
+#: common.opt:1516
 #, fuzzy
 #| msgid "Enable loop header copying on trees"
 msgid "Enable loop interchange on trees."
 msgstr "Укључи копирање заглавља петље на стаблима"
 
-#: common.opt:1520
+#: common.opt:1524
 #, fuzzy
 #| msgid "Perform loop unrolling for all loops"
 msgid "Perform unroll-and-jam on loops."
 msgstr "Одмотај све петље"
 
-#: common.opt:1524
+#: common.opt:1528
 msgid "Enable support for GNU transactional memory."
 msgstr ""
 
-#: common.opt:1528
+#: common.opt:1532
 msgid "Use STB_GNU_UNIQUE if supported by the assembler."
 msgstr ""
 
-#: common.opt:1536
+#: common.opt:1540
 #, fuzzy
 #| msgid "Enable label alignment optimizations"
 msgid "Enable the loop nest optimizer."
 msgstr "Укључи оптимизацију равнања етикета"
 
-#: common.opt:1540
+#: common.opt:1544
 msgid "Force bitfield accesses to match their type width."
 msgstr ""
 
-#: common.opt:1544
+#: common.opt:1548
 msgid "Merge adjacent stores."
 msgstr ""
 
-#: common.opt:1548
+#: common.opt:1552
 #, fuzzy
 #| msgid "Enable guessing of branch probabilities"
 msgid "Enable guessing of branch probabilities."
 msgstr "Укључи погађање вероватноћа гранања"
 
-#: common.opt:1556
+#: common.opt:1560
 #, fuzzy
 #| msgid "Process #ident directives"
 msgid "Process #ident directives."
 msgstr "Обради директиве #ident"
 
-#: common.opt:1560
+#: common.opt:1564
 #, fuzzy
 #| msgid "Perform conversion of conditional jumps to branchless equivalents"
 msgid "Perform conversion of conditional jumps to branchless equivalents."
 msgstr "Претвори условне скокове у безгране еквиваленте"
 
-#: common.opt:1564
+#: common.opt:1568
 #, fuzzy
 #| msgid "Perform conversion of conditional jumps to conditional execution"
 msgid "Perform conversion of conditional jumps to conditional execution."
 msgstr "Претвори условне скокове у условно извршавање"
 
-#: common.opt:1568
+#: common.opt:1572
 msgid "-fstack-reuse=[all|named_vars|none]\tSet stack reuse level for local variables."
 msgstr ""
 
-#: common.opt:1571
+#: common.opt:1575
 #, fuzzy, c-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown Stack Reuse Level %qs"
 msgstr "непознат машински режим %qs"
 
-#: common.opt:1584
+#: common.opt:1588
 #, fuzzy
 #| msgid "Perform conversion of conditional jumps to branchless equivalents"
 msgid "Convert conditional jumps in innermost loops to branchless equivalents."
 msgstr "Претвори условне скокове у безгране еквиваленте"
 
-#: common.opt:1596
+#: common.opt:1600
 #, fuzzy
 #| msgid "Do not generate .size directives"
 msgid "Do not generate .size directives."
 msgstr "Не стварај директиве .size"
 
-#: common.opt:1600
+#: common.opt:1604
 #, fuzzy
 #| msgid "Perform early inlining"
 msgid "Perform indirect inlining."
 msgstr "Изврши рано уткивање"
 
-#: common.opt:1606
+#: common.opt:1610
 msgid "Enable inlining of function declared \"inline\", disabling disables all inlining."
 msgstr ""
 
-#: common.opt:1610
+#: common.opt:1614
 #, fuzzy
 #| msgid "Integrate simple functions into their callers"
 msgid "Integrate functions into their callers when code size is known not to grow."
 msgstr "Интегриши једноставне функције у њихове позиваче"
 
-#: common.opt:1614
+#: common.opt:1618
 #, fuzzy
 #| msgid "Integrate functions called once into their callers"
 msgid "Integrate functions not declared \"inline\" into their callers when profitable."
 msgstr "Интегриши функције једном позване у њихове позиваче"
 
-#: common.opt:1618
+#: common.opt:1622
 #, fuzzy
 #| msgid "Integrate functions called once into their callers"
 msgid "Integrate functions only required by their single caller."
 msgstr "Интегриши функције једном позване у њихове позиваче"
 
-#: common.opt:1625
+#: common.opt:1629
 #, fuzzy
 #| msgid "Limit the size of inlined functions to <number>"
 msgid "-finline-limit=<number>\tLimit the size of inlined functions to <number>."
 msgstr "Ограничи број утканих функција на <number>"
 
-#: common.opt:1629
+#: common.opt:1633
 msgid "Inline __atomic operations when a lock free instruction sequence is available."
 msgstr ""
 
-#: common.opt:1636
+#: common.opt:1640
 msgid "-fcf-protection=[full|branch|return|none]\tInstrument functions with checks to verify jump/call/return control-flow transfer instructions have valid targets."
 msgstr ""
 
-#: common.opt:1640
+#: common.opt:1644
 #, c-format
 msgid "unknown Control-Flow Protection Level %qs"
 msgstr ""
 
-#: common.opt:1656
+#: common.opt:1660
 #, fuzzy
 #| msgid "Instrument function entry and exit with profiling calls"
 msgid "Instrument function entry and exit with profiling calls."
 msgstr "Опреми улаз и излаз функција профилишућим позивима"
 
-#: common.opt:1660
+#: common.opt:1664
 msgid "-finstrument-functions-exclude-function-list=name,...  Do not instrument listed functions."
 msgstr ""
 
-#: common.opt:1664
+#: common.opt:1668
 msgid "-finstrument-functions-exclude-file-list=filename,...  Do not instrument functions listed in files."
 msgstr ""
 
-#: common.opt:1668
+#: common.opt:1672
 #, fuzzy
 #| msgid "Perform Interprocedural constant propagation"
 msgid "Perform interprocedural constant propagation."
 msgstr "Изврши међупроцедурално распростирање константи"
 
-#: common.opt:1672
+#: common.opt:1676
 #, fuzzy
 #| msgid "Perform Interprocedural constant propagation"
 msgid "Perform cloning to make Interprocedural constant propagation stronger."
 msgstr "Изврши међупроцедурално распростирање константи"
 
-#: common.opt:1680
+#: common.opt:1684
 #, fuzzy
 #| msgid "Perform Interprocedural constant propagation"
 msgid "Perform interprocedural bitwise constant propagation."
 msgstr "Изврши међупроцедурално распростирање константи"
 
-#: common.opt:1684
+#: common.opt:1688
 #, fuzzy
 #| msgid "Perform Interprocedural constant propagation"
 msgid "Perform interprocedural profile propagation."
 msgstr "Изврши међупроцедурално распростирање константи"
 
-#: common.opt:1688
+#: common.opt:1692
 #, fuzzy
 #| msgid "Perform interprocedural points-to analysis"
 msgid "Perform interprocedural points-to analysis."
 msgstr "Изврши међупроцедуралну анализу показује-на"
 
-#: common.opt:1692
+#: common.opt:1696
 #, fuzzy
 #| msgid "Discover pure and const functions"
 msgid "Discover pure and const functions."
 msgstr "Откривај чисте и константне функције"
 
-#: common.opt:1696
+#: common.opt:1700
 msgid "Perform Identical Code Folding for functions and read-only variables."
 msgstr ""
 
-#: common.opt:1700
+#: common.opt:1704
 msgid "Perform Identical Code Folding for functions."
 msgstr ""
 
-#: common.opt:1704
+#: common.opt:1708
 msgid "Perform Identical Code Folding for variables."
 msgstr ""
 
-#: common.opt:1708
+#: common.opt:1712
 #, fuzzy
 #| msgid "Discover readonly and non addressable static variables"
 msgid "Discover readonly and non addressable static variables."
 msgstr "Откривај статичке променљиве које су само за читање и не могу се адресирати"
 
-#: common.opt:1720
+#: common.opt:1724
 #, fuzzy
 #| msgid "Perform Value Range Propagation on trees"
 msgid "Perform IPA Value Range Propagation."
 msgstr "Изврши распростирање опсега вредности на стаблима"
 
-#: common.opt:1724
+#: common.opt:1728
 msgid "-fira-algorithm=[CB|priority]\tSet the used IRA algorithm."
 msgstr ""
 
-#: common.opt:1727
+#: common.opt:1731
 #, fuzzy, c-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown IRA algorithm %qs"
 msgstr "непознат машински режим %qs"
 
-#: common.opt:1737
+#: common.opt:1741
 msgid "-fira-region=[one|all|mixed]\tSet regions for IRA."
 msgstr ""
 
-#: common.opt:1740
+#: common.opt:1744
 #, fuzzy, c-format
 #| msgid "unknown register name: %s"
 msgid "unknown IRA region %qs"
 msgstr "непознато име регистра: %s"
 
-#: common.opt:1753
+#: common.opt:1757
 msgid "Use IRA based register pressure calculation in RTL hoist optimizations."
 msgstr ""
 
-#: common.opt:1758
+#: common.opt:1762
 msgid "Use IRA based register pressure calculation in RTL loop optimizations."
 msgstr ""
 
-#: common.opt:1763
+#: common.opt:1767
 msgid "Share slots for saving different hard registers."
 msgstr ""
 
-#: common.opt:1767
+#: common.opt:1771
 msgid "Share stack slots for spilled pseudo-registers."
 msgstr ""
 
-#: common.opt:1771
+#: common.opt:1775
 msgid "-fira-verbose=<number>\tControl IRA's level of diagnostic messages."
 msgstr ""
 
-#: common.opt:1775
+#: common.opt:1779
 #, fuzzy
 #| msgid "Optimize induction variables on trees"
 msgid "Optimize induction variables on trees."
 msgstr "Оптимизуј индукционе променљиве на стаблима"
 
-#: common.opt:1779
+#: common.opt:1783
 #, fuzzy
 #| msgid "Use jump tables for sufficiently large switch statements"
 msgid "Use jump tables for sufficiently large switch statements."
 msgstr "Користи табеле скокова за довољно велике наредбе прекидача"
 
-#: common.opt:1783
+#: common.opt:1787
 #, fuzzy
 #| msgid "Generate code for functions even if they are fully inlined"
 msgid "Generate code for functions even if they are fully inlined."
 msgstr "Стварај кôд за функције чак и ако су потпуно уткане"
 
-#: common.opt:1787
+#: common.opt:1791
 #, fuzzy
 #| msgid "Generate code for functions even if they are fully inlined"
 msgid "Generate code for static functions even if they are never called."
 msgstr "Стварај кôд за функције чак и ако су потпуно уткане"
 
-#: common.opt:1791
+#: common.opt:1795
 #, fuzzy
 #| msgid "Emit static const variables even if they are not used"
 msgid "Emit static const variables even if they are not used."
 msgstr "Емитуј статичке константне променљиве чак и ако се не користе"
 
-#: common.opt:1795
+#: common.opt:1799
 #, fuzzy
 #| msgid "Give external symbols a leading underscore"
 msgid "Give external symbols a leading underscore."
 msgstr "Додај спољашњим симболима водећу подвлаку"
 
-#: common.opt:1803
+#: common.opt:1807
 msgid "Do CFG-sensitive rematerialization in LRA."
 msgstr ""
 
-#: common.opt:1807
+#: common.opt:1811
 #, fuzzy
 #| msgid "Enable linker optimizations"
 msgid "Enable link-time optimization."
 msgstr "Укључи оптимизације повезивача"
 
-#: common.opt:1811
+#: common.opt:1815
 msgid "Link-time optimization with number of parallel jobs or jobserver."
 msgstr ""
 
-#: common.opt:1814
+#: common.opt:1818
 #, fuzzy, c-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown LTO partitioning model %qs"
 msgstr "непознат машински режим %qs"
 
-#: common.opt:1833
+#: common.opt:1837
 msgid "Specify the algorithm to partition symbols and vars at linktime."
 msgstr ""
 
-#: common.opt:1838
+#: common.opt:1842
 msgid "-flto-compression-level=<number>\tUse zlib compression level <number> for IL."
 msgstr ""
 
-#: common.opt:1842
+#: common.opt:1846
 msgid "Merge C++ types using One Definition Rule."
 msgstr ""
 
-#: common.opt:1846
+#: common.opt:1850
 msgid "Report various link-time optimization statistics."
 msgstr ""
 
-#: common.opt:1850
+#: common.opt:1854
 msgid "Report various link-time optimization statistics for WPA only."
 msgstr ""
 
-#: common.opt:1854
+#: common.opt:1858
 #, fuzzy
 #| msgid "Set errno after built-in math functions"
 msgid "Set errno after built-in math functions."
 msgstr "Постави errno после уграђених математичких фја"
 
-#: common.opt:1858
+#: common.opt:1862
 #, fuzzy
 #| msgid "Maximum number of errors to report"
 msgid "-fmax-errors=<number>\tMaximum number of errors to report."
 msgstr "Највећи број грешака за пријављивање"
 
-#: common.opt:1862
+#: common.opt:1866
 #, fuzzy
 #| msgid "Report on permanent memory allocation"
 msgid "Report on permanent memory allocation."
 msgstr "Извештавај о трајном резервисању меморије"
 
-#: common.opt:1866
+#: common.opt:1870
 #, fuzzy
 #| msgid "Report on permanent memory allocation"
 msgid "Report on permanent memory allocation in WPA only."
 msgstr "Извештавај о трајном резервисању меморије"
 
-#: common.opt:1873
+#: common.opt:1877
 #, fuzzy
 #| msgid "Attempt to merge identical constants and constant variables"
 msgid "Attempt to merge identical constants and constant variables."
 msgstr "Покушај да стопиш истоветне константе и константне променљиве"
 
-#: common.opt:1877
+#: common.opt:1881
 #, fuzzy
 #| msgid "Attempt to merge identical constants across compilation units"
 msgid "Attempt to merge identical constants across compilation units."
 msgstr "Покушај да стопиш истоветне константе преко компилационих јединица"
 
-#: common.opt:1881
+#: common.opt:1885
 #, fuzzy
 #| msgid "Attempt to merge identical constants across compilation units"
 msgid "Attempt to merge identical debug strings across compilation units."
 msgstr "Покушај да стопиш истоветне константе преко компилационих јединица"
 
-#: common.opt:1885
+#: common.opt:1889
 #, fuzzy
 #| msgid "Limit diagnostics to <number> characters per line.  0 suppresses line-wrapping"
 msgid "-fmessage-length=<number>\tLimit diagnostics to <number> characters per line.  0 suppresses line-wrapping."
 msgstr "Ограничи дијагностику на <number> знакова по линији.  0 сузбија преламање линија"
 
-#: common.opt:1889
+#: common.opt:1893
 #, fuzzy
 #| msgid "Perform SMS based modulo scheduling before the first scheduling pass"
 msgid "Perform SMS based modulo scheduling before the first scheduling pass."
 msgstr "Изврши окретно модуло-распоређивање на основу СМСа пре првог распоређивачког пролаза"
 
-#: common.opt:1893
+#: common.opt:1897
 #, fuzzy
 #| msgid "Perform SMS based modulo scheduling before the first scheduling pass"
 msgid "Perform SMS based modulo scheduling with register moves allowed."
 msgstr "Изврши окретно модуло-распоређивање на основу СМСа пре првог распоређивачког пролаза"
 
-#: common.opt:1897
+#: common.opt:1901
 #, fuzzy
 #| msgid "Move loop invariant computations out of loops"
 msgid "Move loop invariant computations out of loops."
 msgstr "Премести инваријантна рачунања изван петљи"
 
-#: common.opt:1901
+#: common.opt:1905
 #, fuzzy
 #| msgid "Enable dead store elimination"
 msgid "Use the RTL dead code elimination pass."
 msgstr "Укључи елиминацију мртвих складиштења"
 
-#: common.opt:1905
+#: common.opt:1909
 #, fuzzy
 #| msgid "Enable dead store elimination"
 msgid "Use the RTL dead store elimination pass."
 msgstr "Укључи елиминацију мртвих складиштења"
 
-#: common.opt:1909
+#: common.opt:1913
 #, fuzzy
 #| msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling"
 msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling."
 msgstr "Укључи/искључи традиционално распоређивање у петљама које су већ прошле кроз модуло-распоређивање"
 
-#: common.opt:1913
+#: common.opt:1917
 #, fuzzy
 #| msgid "Support synchronous non-call exceptions"
 msgid "Support synchronous non-call exceptions."
 msgstr "Подржи синхроне непозивне изузетке"
 
-#: common.opt:1916
+#: common.opt:1920
 #, fuzzy, c-format
 #| msgid "assertion missing after %qs"
 msgid "options or targets missing after %qs"
 msgstr "недостаје тврдња после %qs"
 
-#: common.opt:1917
+#: common.opt:1921
 msgid "-foffload=<targets>=<options>  Specify offloading targets and options for them."
 msgstr ""
 
-#: common.opt:1921
+#: common.opt:1925
 msgid "-foffload-abi=[lp64|ilp32]     Set the ABI to use in an offload compiler."
 msgstr ""
 
-#: common.opt:1924
+#: common.opt:1928
 #, fuzzy, c-format
 #| msgid "unknown tls-model \"%s\""
 msgid "unknown offload ABI %qs"
 msgstr "непознат ТЛС модел „%s“"
 
-#: common.opt:1934
+#: common.opt:1938
 #, fuzzy
 #| msgid "When possible do not generate stack frames"
 msgid "When possible do not generate stack frames."
 msgstr "Када је могуће не стварај оквире стека"
 
-#: common.opt:1938
+#: common.opt:1942
 #, fuzzy
 #| msgid "Enable loop optimizations on tree level"
 msgid "Enable all optimization info dumps on stderr."
 msgstr "Укључи оптимизације петљи на нивоу стабла"
 
-#: common.opt:1942
+#: common.opt:1946
 msgid "-fopt-info[-<type>=filename]\tDump compiler optimization details."
 msgstr ""
 
-#: common.opt:1950
+#: common.opt:1954
 #, fuzzy
 #| msgid "Optimize sibling and tail recursive calls"
 msgid "Optimize sibling and tail recursive calls."
 msgstr "Оптимизуј сродничке и репно рекурзивне позиве"
 
-#: common.opt:1954
+#: common.opt:1958
 #, fuzzy
 #| msgid "Perform early inlining"
 msgid "Perform partial inlining."
 msgstr "Изврши рано уткивање"
 
-#: common.opt:1958 common.opt:1962
+#: common.opt:1962 common.opt:1966
 msgid "Report on memory allocation before interprocedural optimization."
 msgstr ""
 
-#: common.opt:1966
+#: common.opt:1970
 #, fuzzy
 #| msgid "Pack structure members together without holes"
 msgid "Pack structure members together without holes."
 msgstr "Пакуј чланове структура заједно без рупа"
 
-#: common.opt:1970
+#: common.opt:1974
 #, fuzzy
 #| msgid "Set initial maximum structure member alignment"
 msgid "-fpack-struct=<number>\tSet initial maximum structure member alignment."
 msgstr "Постави почетно највеће равнање чланова структуре"
 
-#: common.opt:1974
+#: common.opt:1978
 #, fuzzy
 #| msgid "Return small aggregates in memory, not registers"
 msgid "Return small aggregates in memory, not registers."
 msgstr "Враћај мале скупине у меморији, не у регистрима"
 
-#: common.opt:1978
+#: common.opt:1982
 #, fuzzy
 #| msgid "Perform loop peeling"
 msgid "Perform loop peeling."
 msgstr "Изврши љушћење петљи"
 
-#: common.opt:1982
+#: common.opt:1986
 #, fuzzy
 #| msgid "Enable machine specific peephole optimizations"
 msgid "Enable machine specific peephole optimizations."
 msgstr "Укључи машински-зависне окнасте оптимизације"
 
-#: common.opt:1986
+#: common.opt:1990
 #, fuzzy
 #| msgid "Enable an RTL peephole pass before sched2"
 msgid "Enable an RTL peephole pass before sched2."
 msgstr "Укључи окнасти РТЛ пролаз пре sched2"
 
-#: common.opt:1990
+#: common.opt:1994
 #, fuzzy
 #| msgid "Generate position-independent code if possible (large mode)"
 msgid "Generate position-independent code if possible (large mode)."
 msgstr "Стварај положајно-независни кôд ако је могуће (велики режим)"
 
-#: common.opt:1994
+#: common.opt:1998
 #, fuzzy
 #| msgid "Generate position-independent code for executables if possible (large mode)"
 msgid "Generate position-independent code for executables if possible (large mode)."
 msgstr "Стварај положајно-независни кôд за извршне ако је могуће (велики режим)"
 
-#: common.opt:1998
+#: common.opt:2002
 #, fuzzy
 #| msgid "Generate position-independent code if possible (small mode)"
 msgid "Generate position-independent code if possible (small mode)."
 msgstr "Стварај положајно-независни кôд ако је могуће (мали режим)"
 
-#: common.opt:2002
+#: common.opt:2006
 #, fuzzy
 #| msgid "Generate position-independent code for executables if possible (small mode)"
 msgid "Generate position-independent code for executables if possible (small mode)."
 msgstr "Стварај положајно-независни кôд за извршне ако је могуће (мали режим)"
 
-#: common.opt:2006
+#: common.opt:2010
 msgid "Use PLT for PIC calls (-fno-plt: load the address from GOT at call site)."
 msgstr ""
 
-#: common.opt:2010
+#: common.opt:2014
 #, fuzzy
 #| msgid "Specify options to GNAT"
 msgid "Specify a plugin to load."
 msgstr "Наведите опције ГНАТу"
 
-#: common.opt:2014
+#: common.opt:2018
 msgid "-fplugin-arg-<name>-<key>[=<value>]\tSpecify argument <key>=<value> for plugin <name>."
 msgstr ""
 
-#: common.opt:2018
+#: common.opt:2022
 #, fuzzy
 #| msgid "Enables a register move optimization"
 msgid "Run predictive commoning optimization."
 msgstr "Укључи оптимизацију померањем регистара"
 
-#: common.opt:2022
+#: common.opt:2026
 #, fuzzy
 #| msgid "Generate prefetch instructions, if available, for arrays in loops"
 msgid "Generate prefetch instructions, if available, for arrays in loops."
 msgstr "Стварај инструкције предохватања, ако су доступне, за низове у петљама"
 
-#: common.opt:2026
+#: common.opt:2030
 #, fuzzy
 #| msgid "Enable basic program profiling code"
 msgid "Enable basic program profiling code."
 msgstr "Укључи основни кôд за профилисање програма"
 
-#: common.opt:2030
+#: common.opt:2034
 msgid "Generate absolute source path names for gcov."
 msgstr ""
 
-#: common.opt:2034
+#: common.opt:2038
 #, fuzzy
 #| msgid "Insert arc-based program profiling code"
 msgid "Insert arc-based program profiling code."
 msgstr "Убаци кôд за профилисање програма на основу лукова"
 
-#: common.opt:2038
+#: common.opt:2042
 msgid "Set the top-level directory for storing the profile data. The default is 'pwd'."
 msgstr ""
 
-#: common.opt:2043
+#: common.opt:2047
 msgid "Enable correction of flow inconsistent profile data input."
 msgstr ""
 
-#: common.opt:2047
+#: common.opt:2051
 msgid "-fprofile-update=[single|atomic|prefer-atomic]\tSet the profile update method."
 msgstr ""
 
-#: common.opt:2050
+#: common.opt:2054
 #, fuzzy, c-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown profile update method %qs"
 msgstr "непознат машински режим %qs"
 
-#: common.opt:2063
+#: common.opt:2067
 #, fuzzy
 #| msgid "Enable common options for generating profile info for profile feedback directed optimizations"
 msgid "Enable common options for generating profile info for profile feedback directed optimizations."
 msgstr "Укључи уобичајене опције за стварање профилних информација, ради оптимизација на основу одзива профилисања"
 
-#: common.opt:2067
+#: common.opt:2071
 #, fuzzy
 #| msgid "Enable common options for generating profile info for profile feedback directed optimizations"
 msgid "Enable common options for generating profile info for profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr "Укључи уобичајене опције за стварање профилних информација, ради оптимизација на основу одзива профилисања"
 
-#: common.opt:2071
+#: common.opt:2075
 #, fuzzy
 #| msgid "Enable common options for performing profile feedback directed optimizations"
 msgid "Enable common options for performing profile feedback directed optimizations."
 msgstr "Укључи уобичајене опције за оптимизације на основу одзива профилисања"
 
-#: common.opt:2075
+#: common.opt:2079
 #, fuzzy
 #| msgid "Enable common options for performing profile feedback directed optimizations"
 msgid "Enable common options for performing profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr "Укључи уобичајене опције за оптимизације на основу одзива профилисања"
 
-#: common.opt:2079
+#: common.opt:2083
 #, fuzzy
 #| msgid "Insert code to profile values of expressions"
 msgid "Insert code to profile values of expressions."
 msgstr "Умећи кôд за профилисање вредности израза"
 
-#: common.opt:2083
+#: common.opt:2087
 #, fuzzy
 #| msgid "internal consistency failure"
 msgid "Report on consistency of profile."
 msgstr "неуспех услед унутрашње неусаглашености"
 
-#: common.opt:2087
+#: common.opt:2091
 #, fuzzy
 #| msgid "Reorder functions to improve code placement"
 msgid "Enable function reordering that improves code placement."
 msgstr "Прераспореди функције ради побољшања постављења кôда"
 
-#: common.opt:2091
+#: common.opt:2095
 #, fuzzy
 #| msgid "Use push instructions to save outgoing arguments"
 msgid "Insert NOP instructions at each function entry."
 msgstr "Користи инструкције гурања за чување одлазећих аргумената"
 
-#: common.opt:2098
+#: common.opt:2102
 #, fuzzy
 #| msgid "Make compile reproducible using <string>"
 msgid "-frandom-seed=<string>\tMake compile reproducible using <string>."
 msgstr "Учини компилацију поновљивом користећи <string>"
 
-#: common.opt:2108
+#: common.opt:2112
 msgid "Record gcc command line switches in the object file."
 msgstr ""
 
-#: common.opt:2112
+#: common.opt:2116
 #, fuzzy
 #| msgid "Return small aggregates in registers"
 msgid "Return small aggregates in registers."
 msgstr "Враћај мале скупине у регистрима"
 
-#: common.opt:2120
+#: common.opt:2124
 msgid "Tell DSE that the storage for a C++ object is dead when the constructor starts and when the destructor finishes."
 msgstr ""
 
-#: common.opt:2128
+#: common.opt:2132
 msgid "Relief of register pressure through live range shrinkage."
 msgstr ""
 
-#: common.opt:2132
+#: common.opt:2136
 #, fuzzy
 #| msgid "Perform a register renaming optimization pass"
 msgid "Perform a register renaming optimization pass."
 msgstr "Изврши пролаз оптимизације преименовањем регистара"
 
-#: common.opt:2136
+#: common.opt:2140
 #, fuzzy
 #| msgid "Perform a register renaming optimization pass"
 msgid "Perform a target dependent instruction fusion optimization pass."
 msgstr "Изврши пролаз оптимизације преименовањем регистара"
 
-#: common.opt:2140
+#: common.opt:2144
 #, fuzzy
 #| msgid "Reorder basic blocks to improve code placement"
 msgid "Reorder basic blocks to improve code placement."
 msgstr "Прераспореди основне блокове ради побољшања постављења кôда"
 
-#: common.opt:2144
+#: common.opt:2148
 msgid "-freorder-blocks-algorithm=[simple|stc]\tSet the used basic block reordering algorithm."
 msgstr ""
 
-#: common.opt:2147
+#: common.opt:2151
 #, c-format
 msgid "unknown basic block reordering algorithm %qs"
 msgstr ""
 
-#: common.opt:2157
+#: common.opt:2161
 #, fuzzy
 #| msgid "Reorder basic blocks and partition into hot and cold sections"
 msgid "Reorder basic blocks and partition into hot and cold sections."
 msgstr "Прераспореди основне блокове и подели на вруће и хладне одељке"
 
-#: common.opt:2161
+#: common.opt:2165
 #, fuzzy
 #| msgid "Reorder functions to improve code placement"
 msgid "Reorder functions to improve code placement."
 msgstr "Прераспореди функције ради побољшања постављења кôда"
 
-#: common.opt:2165
+#: common.opt:2169
 #, fuzzy
 #| msgid "Add a common subexpression elimination pass after loop optimizations"
 msgid "Add a common subexpression elimination pass after loop optimizations."
 msgstr "Додај пролаз елиминације заједничких подизраза после оптимизација петље"
 
-#: common.opt:2173
+#: common.opt:2177
 #, fuzzy
 #| msgid "Disable optimizations that assume default FP rounding behavior"
 msgid "Disable optimizations that assume default FP rounding behavior."
 msgstr "Искључи оптимизације које претпостављају подразумевано понашање ФП заокруживања"
 
-#: common.opt:2177
+#: common.opt:2181
 #, fuzzy
 #| msgid "Enable scheduling across basic blocks"
 msgid "Enable scheduling across basic blocks."
 msgstr "Укључи распоређивање преко основних блокова"
 
-#: common.opt:2181
+#: common.opt:2185
 msgid "Enable register pressure sensitive insn scheduling."
 msgstr ""
 
-#: common.opt:2185
+#: common.opt:2189
 #, fuzzy
 #| msgid "Allow speculative motion of non-loads"
 msgid "Allow speculative motion of non-loads."
 msgstr "Дозволи спекулативно кретање не-учитавања"
 
-#: common.opt:2189
+#: common.opt:2193
 #, fuzzy
 #| msgid "Allow speculative motion of some loads"
 msgid "Allow speculative motion of some loads."
 msgstr "Дозволи спекулативно кретање неких учитавања"
 
-#: common.opt:2193
+#: common.opt:2197
 #, fuzzy
 #| msgid "Allow speculative motion of more loads"
 msgid "Allow speculative motion of more loads."
 msgstr "Дозволи спекулативно кретање више учитавања"
 
-#: common.opt:2197
+#: common.opt:2201
 #, fuzzy
 #| msgid "Set the verbosity level of the scheduler"
 msgid "-fsched-verbose=<number>\tSet the verbosity level of the scheduler."
 msgstr "Постави ниво опширности распоређивача"
 
-#: common.opt:2201
+#: common.opt:2205
 #, fuzzy
 #| msgid "If scheduling post reload, do superblock scheduling"
 msgid "If scheduling post reload, do superblock scheduling."
 msgstr "Ако се распоређује после поновљеног учитавања, изврши суперблоковско распоређивање"
 
-#: common.opt:2209
+#: common.opt:2213
 #, fuzzy
 #| msgid "Reschedule instructions before register allocation"
 msgid "Reschedule instructions before register allocation."
 msgstr "Прераспореди инструкције пре резервисања регистара"
 
-#: common.opt:2213
+#: common.opt:2217
 #, fuzzy
 #| msgid "Reschedule instructions after register allocation"
 msgid "Reschedule instructions after register allocation."
 msgstr "Прераспореди инструкције после резервисања регистара"
 
-#: common.opt:2220
+#: common.opt:2224
 msgid "Schedule instructions using selective scheduling algorithm."
 msgstr ""
 
-#: common.opt:2224
+#: common.opt:2228
 #, fuzzy
 #| msgid "Use data speculation after reload"
 msgid "Run selective scheduling after reload."
 msgstr "Користи спекулацију података после поновног учитавања"
 
-#: common.opt:2228
+#: common.opt:2232
 msgid "Run self-tests, using the given path to locate test files."
 msgstr ""
 
-#: common.opt:2232
+#: common.opt:2236
 msgid "Perform software pipelining of inner loops during selective scheduling."
 msgstr ""
 
-#: common.opt:2236
+#: common.opt:2240
 msgid "Perform software pipelining of outer loops during selective scheduling."
 msgstr ""
 
-#: common.opt:2240
+#: common.opt:2244
 msgid "Reschedule pipelined regions without pipelining."
 msgstr ""
 
-#: common.opt:2244
+#: common.opt:2248
 msgid "Allow interposing function (or variables) by ones with different semantics (or initializer) respectively by dynamic linker."
 msgstr ""
 
-#: common.opt:2250
+#: common.opt:2254
 #, fuzzy
 #| msgid "Allow premature scheduling of queued insns"
 msgid "Allow premature scheduling of queued insns."
 msgstr "Дозволи прерано распоређивање ија у реду"
 
-#: common.opt:2254
+#: common.opt:2258
 #, fuzzy
 #| msgid "Set number of queued insns that can be prematurely scheduled"
 msgid "-fsched-stalled-insns=<number>\tSet number of queued insns that can be prematurely scheduled."
 msgstr "Број ија у реду које се могу прерано распоређивати"
 
-#: common.opt:2262
+#: common.opt:2266
 #, fuzzy
 #| msgid "Set dependence distance checking in premature scheduling of queued insns"
 msgid "Set dependence distance checking in premature scheduling of queued insns."
 msgstr "Провера растојања зависности у прераном распоређивању ија у реду"
 
-#: common.opt:2266
+#: common.opt:2270
 #, fuzzy
 #| msgid "Set dependence distance checking in premature scheduling of queued insns"
 msgid "-fsched-stalled-insns-dep=<number>\tSet dependence distance checking in premature scheduling of queued insns."
 msgstr "Провера растојања зависности у прераном распоређивању ија у реду"
 
-#: common.opt:2270
+#: common.opt:2274
 msgid "Enable the group heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2274
+#: common.opt:2278
 msgid "Enable the critical path heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2278
+#: common.opt:2282
 msgid "Enable the speculative instruction heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2282
+#: common.opt:2286
 #, fuzzy
 #| msgid "Set the verbosity level of the scheduler"
 msgid "Enable the rank heuristic in the scheduler."
 msgstr "Постави ниво опширности распоређивача"
 
-#: common.opt:2286
+#: common.opt:2290
 msgid "Enable the last instruction heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2290
+#: common.opt:2294
 msgid "Enable the dependent count heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2294
+#: common.opt:2298
 #, fuzzy
 #| msgid "Access data in the same section from shared anchor points"
 msgid "Access data in the same section from shared anchor points."
 msgstr "Приступај подацима у истом одељку из дељених сидришних тачака"
 
-#: common.opt:2306
+#: common.opt:2310
 msgid "Turn on Redundant Extensions Elimination pass."
 msgstr ""
 
-#: common.opt:2310
+#: common.opt:2314
 #, fuzzy
 #| msgid "Show column numbers in diagnostics, when available.  Default on"
 msgid "Show column numbers in diagnostics, when available.  Default on."
 msgstr "Приказуј бројеве колона у дијагностици, ако су доступни.  Подразумевано укључено."
 
-#: common.opt:2314
+#: common.opt:2318
 msgid "Emit function prologues only before parts of the function that need it, rather than at the top of the function."
 msgstr ""
 
-#: common.opt:2319
+#: common.opt:2323
 msgid "Shrink-wrap parts of the prologue and epilogue separately."
 msgstr ""
 
-#: common.opt:2323
+#: common.opt:2327
 #, fuzzy
 #| msgid "Disable optimizations observable by IEEE signaling NaNs"
 msgid "Disable optimizations observable by IEEE signaling NaNs."
 msgstr "Искључи оптимизације приметне при ИЕЕЕ издавању НаНа"
 
-#: common.opt:2327
+#: common.opt:2331
 msgid "Disable floating point optimizations that ignore the IEEE signedness of zero."
 msgstr ""
 
-#: common.opt:2331
+#: common.opt:2335
 #, fuzzy
 #| msgid "Convert floating point constants to single precision constants"
 msgid "Convert floating point constants to single precision constants."
 msgstr "Претвори константе у покретном зарезу у једноструку прецизност"
 
-#: common.opt:2335
+#: common.opt:2339
 #, fuzzy
 #| msgid "Split lifetimes of induction variables when loops are unrolled"
 msgid "Split lifetimes of induction variables when loops are unrolled."
 msgstr "Подели времена живота индукционих променљивих када се петље одмотавају"
 
-#: common.opt:2339
+#: common.opt:2343
 #, fuzzy
 #| msgid "Generate APCS conformant stack frames"
 msgid "Generate discontiguous stack frames."
 msgstr "Стварај оквире стека сагласне са АПЦСом"
 
-#: common.opt:2343
+#: common.opt:2347
 msgid "Split wide types into independent registers."
 msgstr ""
 
-#: common.opt:2347
+#: common.opt:2351
 msgid "Enable backward propagation of use properties at the SSA level."
 msgstr ""
 
-#: common.opt:2351
+#: common.opt:2355
 msgid "Optimize conditional patterns using SSA PHI nodes."
 msgstr ""
 
-#: common.opt:2355
+#: common.opt:2359
 msgid "Optimize amount of stdarg registers saved to stack at start of function."
 msgstr ""
 
-#: common.opt:2359
+#: common.opt:2363
 #, fuzzy
 #| msgid "Apply variable expansion when loops are unrolled"
 msgid "Apply variable expansion when loops are unrolled."
 msgstr "Примени ширење променљивих када се петље одмотавају"
 
-#: common.opt:2363
+#: common.opt:2367
 #, fuzzy
 #| msgid "Insert stack checking code into the program"
 msgid "-fstack-check=[no|generic|specific]\tInsert stack checking code into the program."
 msgstr "Уметни кôд за проверу стека у програм"
 
-#: common.opt:2367
+#: common.opt:2371
 #, fuzzy
 #| msgid "Insert stack checking code into the program"
 msgid "Insert stack checking code into the program.  Same as -fstack-check=specific."
 msgstr "Уметни кôд за проверу стека у програм"
 
-#: common.opt:2371
+#: common.opt:2375
 msgid "Insert code to probe each page of stack space as it is allocated to protect from stack-clash style attacks."
 msgstr ""
 
-#: common.opt:2379
+#: common.opt:2383
 #, fuzzy
 #| msgid "Trap if the stack goes past <register>"
 msgid "-fstack-limit-register=<register>\tTrap if the stack goes past <register>."
 msgstr "Хватај ако стек прође поред <register>"
 
-#: common.opt:2383
+#: common.opt:2387
 #, fuzzy
 #| msgid "Trap if the stack goes past symbol <name>"
 msgid "-fstack-limit-symbol=<name>\tTrap if the stack goes past symbol <name>."
 msgstr "Хватај ако стек прође поред симбола <name>"
 
-#: common.opt:2387
+#: common.opt:2391
 #, fuzzy
 #| msgid "Use propolice as a stack protection method"
 msgid "Use propolice as a stack protection method."
 msgstr "Користи propolice као метод заштите стека"
 
-#: common.opt:2391
+#: common.opt:2395
 #, fuzzy
 #| msgid "Use a stack protection method for every function"
 msgid "Use a stack protection method for every function."
 msgstr "Користи метод заштите стека за сваку функцију"
 
-#: common.opt:2395
+#: common.opt:2399
 #, fuzzy
 #| msgid "Use a stack protection method for every function"
 msgid "Use a smart stack protection method for certain functions."
 msgstr "Користи метод заштите стека за сваку функцију"
 
-#: common.opt:2399
+#: common.opt:2403
 #, fuzzy
 #| msgid "Use a stack protection method for every function"
 msgid "Use stack protection method only for functions with the stack_protect attribute."
 msgstr "Користи метод заштите стека за сваку функцију"
 
-#: common.opt:2403
+#: common.opt:2407
 #, fuzzy
 #| msgid "Reuse r30 on a per function basis"
 msgid "Output stack usage information on a per-function basis."
 msgstr "Поново користи r30 од функције до функције"
 
-#: common.opt:2415
+#: common.opt:2419
 #, fuzzy
 #| msgid "Assume strict aliasing rules apply"
 msgid "Assume strict aliasing rules apply."
 msgstr "Претпостави правила строге дволичности"
 
-#: common.opt:2419
+#: common.opt:2423
 #, fuzzy
 #| msgid "Treat signed overflow as undefined"
 msgid "Treat signed overflow as undefined.  Negated as -fwrapv -fwrapv-pointer."
 msgstr "Сматрај означено преливање за недефинисано"
 
-#: common.opt:2423
+#: common.opt:2427
 msgid "Implement __atomic operations via libcalls to legacy __sync functions."
 msgstr ""
 
-#: common.opt:2427
+#: common.opt:2431
 #, fuzzy
 #| msgid "Check for syntax errors, then stop"
 msgid "Check for syntax errors, then stop."
 msgstr "Провери синтаксне грешке, па стани"
 
-#: common.opt:2431
+#: common.opt:2435
 #, fuzzy
 #| msgid "Create data files needed by \"gcov\""
 msgid "Create data files needed by \"gcov\"."
 msgstr "Створи датотеке потребне за „gcov“"
 
-#: common.opt:2435
+#: common.opt:2439
 #, fuzzy
 #| msgid "Perform jump threading optimizations"
 msgid "Perform jump threading optimizations."
 msgstr "Изврши оптимизације плетења скокова"
 
-#: common.opt:2439
+#: common.opt:2443
 #, fuzzy
 #| msgid "Report the time taken by each compiler pass"
 msgid "Report the time taken by each compiler pass."
 msgstr "Извести о времену потрошеном у сваком компилаторском пролазу"
 
-#: common.opt:2443
+#: common.opt:2447
 msgid "Record times taken by sub-phases separately."
 msgstr ""
 
-#: common.opt:2447
+#: common.opt:2451
 #, fuzzy
 #| msgid "Set the default thread-local storage code generation model"
 msgid "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tSet the default thread-local storage code generation model."
 msgstr "Подразумевани модел стварања кôда за нитно-локално складиштење"
 
-#: common.opt:2450
+#: common.opt:2454
 #, fuzzy, c-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown TLS model %qs"
 msgstr "непознат машински режим %qs"
 
-#: common.opt:2466
+#: common.opt:2470
 #, fuzzy
 #| msgid "Reorder top level functions, variables, and asms"
 msgid "Reorder top level functions, variables, and asms."
 msgstr "Преуреди редослед функција, променљива и асмова највишег нивоа"
 
-#: common.opt:2470
+#: common.opt:2474
 #, fuzzy
 #| msgid "Perform superblock formation via tail duplication"
 msgid "Perform superblock formation via tail duplication."
 msgstr "Формирај суперблокове преко умножавања репа"
 
-#: common.opt:2474
+#: common.opt:2478
 msgid "For targets that normally need trampolines for nested functions, always generate them instead of using descriptors."
 msgstr ""
 
-#: common.opt:2482
+#: common.opt:2486
 #, fuzzy
 #| msgid "Assume floating-point operations can trap"
 msgid "Assume floating-point operations can trap."
 msgstr "Претпостави да операције у покретном зарезу могу да хватају"
 
-#: common.opt:2486
+#: common.opt:2490
 #, fuzzy
 #| msgid "Trap for signed overflow in addition, subtraction and multiplication"
 msgid "Trap for signed overflow in addition, subtraction and multiplication."
 msgstr "Хватај преливање означених при додавању, одузимању и множењу"
 
-#: common.opt:2490
+#: common.opt:2494
 #, fuzzy
 #| msgid "Enable SSA-CCP optimization on trees"
 msgid "Enable SSA-CCP optimization on trees."
 msgstr "Укључи ССА-ЦЦП оптимизацију над стаблима"
 
-#: common.opt:2494
+#: common.opt:2498
 #, fuzzy
 #| msgid "Enable SSA-CCP optimization on trees"
 msgid "Enable SSA-BIT-CCP optimization on trees."
 msgstr "Укључи ССА-ЦЦП оптимизацију над стаблима"
 
-#: common.opt:2502
+#: common.opt:2506
 #, fuzzy
 #| msgid "Enable loop header copying on trees"
 msgid "Enable loop header copying on trees."
 msgstr "Укључи копирање заглавља петље на стаблима"
 
-#: common.opt:2510
+#: common.opt:2514
 #, fuzzy
 #| msgid "Enable SSA code sinking on trees"
 msgid "Enable SSA coalescing of user variables."
 msgstr "Укључи ССА потапање кôда на стаблима"
 
-#: common.opt:2518
+#: common.opt:2522
 #, fuzzy
 #| msgid "Enable copy propagation on trees"
 msgid "Enable copy propagation on trees."
 msgstr "Укључи распростирање копирања на стаблима"
 
-#: common.opt:2526
+#: common.opt:2530
 #, fuzzy
 #| msgid "Perform conversion of conditional jumps to conditional execution"
 msgid "Transform condition stores into unconditional ones."
 msgstr "Претвори условне скокове у условно извршавање"
 
-#: common.opt:2530
+#: common.opt:2534
 #, fuzzy
 #| msgid "Perform conversion of conditional jumps to conditional execution"
 msgid "Perform conversions of switch initializations."
 msgstr "Претвори условне скокове у условно извршавање"
 
-#: common.opt:2534
+#: common.opt:2538
 #, fuzzy
 #| msgid "Enable SSA dead code elimination optimization on trees"
 msgid "Enable SSA dead code elimination optimization on trees."
 msgstr "Укључи ССА оптимизацију елиминације мртвог кôда на стаблима"
 
-#: common.opt:2538
+#: common.opt:2542
 #, fuzzy
 #| msgid "Enable dominator optimizations"
 msgid "Enable dominator optimizations."
 msgstr "Укључи доминаторске оптимизације"
 
-#: common.opt:2542
+#: common.opt:2546
 #, fuzzy
 #| msgid "Enable loop header copying on trees"
 msgid "Enable tail merging on trees."
 msgstr "Укључи копирање заглавља петље на стаблима"
 
-#: common.opt:2546
+#: common.opt:2550
 #, fuzzy
 #| msgid "Enable dead store elimination"
 msgid "Enable dead store elimination."
 msgstr "Укључи елиминацију мртвих складиштења"
 
-#: common.opt:2550
+#: common.opt:2554
 #, fuzzy
 #| msgid "Enable copy propagation on trees"
 msgid "Enable forward propagation on trees."
 msgstr "Укључи распростирање копирања на стаблима"
 
-#: common.opt:2554
+#: common.opt:2558
 #, fuzzy
 #| msgid "Enable Full Redundancy Elimination (FRE) on trees"
 msgid "Enable Full Redundancy Elimination (FRE) on trees."
 msgstr "Укључи пуну елиминацију сувишности (ФРЕ) на стаблима"
 
-#: common.opt:2558
+#: common.opt:2562
 #, fuzzy
 #| msgid "Enable SSA-CCP optimization on trees"
 msgid "Enable string length optimizations on trees."
 msgstr "Укључи ССА-ЦЦП оптимизацију над стаблима"
 
-#: common.opt:2562
+#: common.opt:2566
 msgid "Detect paths that trigger erroneous or undefined behavior due to dereferencing a null pointer.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
-#: common.opt:2568
+#: common.opt:2572
 msgid "Detect paths that trigger erroneous or undefined behavior due to a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
-#: common.opt:2575
+#: common.opt:2579
 #, fuzzy
 #| msgid "Enable loop vectorization on trees"
 msgid "Enable loop distribution on trees."
 msgstr "Укључи векторизацију петљи на стаблима"
 
-#: common.opt:2579
+#: common.opt:2583
 msgid "Enable loop distribution for patterns transformed into a library call."
 msgstr ""
 
-#: common.opt:2583
+#: common.opt:2587
 #, fuzzy
 #| msgid "Enable loop invariant motion on trees"
 msgid "Enable loop invariant motion on trees."
 msgstr "Укључи кретање инваријанти петље на стаблима"
 
-#: common.opt:2591
+#: common.opt:2595
 #, fuzzy
 #| msgid "Create canonical induction variables in loops"
 msgid "Create canonical induction variables in loops."
 msgstr "Стварај каноничке индукционе променљиве у петљама"
 
-#: common.opt:2595
+#: common.opt:2599
 #, fuzzy
 #| msgid "Enable loop optimizations on tree level"
 msgid "Enable loop optimizations on tree level."
 msgstr "Укључи оптимизације петљи на нивоу стабла"
 
-#: common.opt:2599
+#: common.opt:2603
 msgid "-ftree-parallelize-loops=<number>\tEnable automatic parallelization of loops."
 msgstr ""
 
-#: common.opt:2603
+#: common.opt:2607
 #, fuzzy
 #| msgid "Enable conditional moves"
 msgid "Enable hoisting loads from conditional pointers."
 msgstr "Укључи условна померања"
 
-#: common.opt:2607
+#: common.opt:2611
 #, fuzzy
 #| msgid "Enable SSA-PRE optimization on trees"
 msgid "Enable SSA-PRE optimization on trees."
 msgstr "Укључи ССА-ПРЕ оптимизацију на стаблима"
 
-#: common.opt:2611
+#: common.opt:2615
 msgid "In SSA-PRE optimization on trees, enable partial-partial redundancy elimination."
 msgstr ""
 
-#: common.opt:2615
+#: common.opt:2619
 #, fuzzy
 #| msgid "Perform interprocedural points-to analysis"
 msgid "Perform function-local points-to analysis on trees."
 msgstr "Изврши међупроцедуралну анализу показује-на"
 
-#: common.opt:2619
+#: common.opt:2623
 #, fuzzy
 #| msgid "Enable loop optimizations on tree level"
 msgid "Enable reassociation on tree level."
 msgstr "Укључи оптимизације петљи на нивоу стабла"
 
-#: common.opt:2627
+#: common.opt:2631
 #, fuzzy
 #| msgid "Enable SSA code sinking on trees"
 msgid "Enable SSA code sinking on trees."
 msgstr "Укључи ССА потапање кôда на стаблима"
 
-#: common.opt:2631
+#: common.opt:2635
 msgid "Perform straight-line strength reduction."
 msgstr ""
 
-#: common.opt:2635
+#: common.opt:2639
 #, fuzzy
 #| msgid "Perform scalar replacement of aggregates"
 msgid "Perform scalar replacement of aggregates."
 msgstr "Изврши скаларну замену скупина"
 
-#: common.opt:2639
+#: common.opt:2643
 #, fuzzy
 #| msgid "Replace temporary expressions in the SSA->normal pass"
 msgid "Replace temporary expressions in the SSA->normal pass."
 msgstr "Замени привремене изразе у пролазу ССА->нормално"
 
-#: common.opt:2643
+#: common.opt:2647
 #, fuzzy
 #| msgid "Perform live range splitting during the SSA->normal pass"
 msgid "Perform live range splitting during the SSA->normal pass."
 msgstr "Изврши поделу опсега уживо током пролаза ССА->нормално"
 
-#: common.opt:2647
+#: common.opt:2651
 #, fuzzy
 #| msgid "Perform Value Range Propagation on trees"
 msgid "Perform Value Range Propagation on trees."
 msgstr "Изврши распростирање опсега вредности на стаблима"
 
-#: common.opt:2651
+#: common.opt:2655
 msgid "Split paths leading to loop backedges."
 msgstr ""
 
-#: common.opt:2655
+#: common.opt:2659
 msgid "Assume common declarations may be overridden with ones with a larger trailing array."
 msgstr ""
 
-#: common.opt:2660
+#: common.opt:2664
 #, fuzzy
 #| msgid "Compile whole compilation unit at a time"
 msgid "Compile whole compilation unit at a time."
 msgstr "Компилуј целу компилациону јединицу у једном тренутку"
 
-#: common.opt:2664
+#: common.opt:2668
 #, fuzzy
 #| msgid "Perform loop unrolling when iteration count is known"
 msgid "Perform loop unrolling when iteration count is known."
 msgstr "Одмотај петљу када се зна број итерација"
 
-#: common.opt:2668
+#: common.opt:2672
 #, fuzzy
 #| msgid "Perform loop unrolling for all loops"
 msgid "Perform loop unrolling for all loops."
 msgstr "Одмотај све петље"
 
-#: common.opt:2679
+#: common.opt:2683
 msgid "Allow optimization for floating-point arithmetic which may change the result of the operation due to rounding."
 msgstr ""
 
-#: common.opt:2684
+#: common.opt:2688
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr ""
 
-#: common.opt:2692
+#: common.opt:2696
 #, fuzzy
 #| msgid "Allow math optimizations that may violate IEEE or ISO standards"
 msgid "Allow math optimizations that may violate IEEE or ISO standards."
 msgstr "Дозволи математичке оптимизације које могу прекршити ИЕЕЕ или ИСО стандарде"
 
-#: common.opt:2696
+#: common.opt:2700
 #, fuzzy
 #| msgid "Perform loop unswitching"
 msgid "Perform loop unswitching."
 msgstr "Изврши одусловљавање петљи"
 
-#: common.opt:2700
+#: common.opt:2704
 #, fuzzy
 #| msgid "Perform loop peeling"
 msgid "Perform loop splitting."
 msgstr "Изврши љушћење петљи"
 
-#: common.opt:2704
+#: common.opt:2708
 #, fuzzy
 #| msgid "Just generate unwind tables for exception handling"
 msgid "Just generate unwind tables for exception handling."
 msgstr "Само створи табеле одмотавања за руковање изузецима"
 
-#: common.opt:2708
+#: common.opt:2712
 msgid "Use the bfd linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2712
+#: common.opt:2716
 msgid "Use the gold linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2724
+#: common.opt:2728
 #, fuzzy
 #| msgid "Perform variable tracking"
 msgid "Perform variable tracking."
 msgstr "Изврши праћење променљивих"
 
-#: common.opt:2732
+#: common.opt:2736
 #, fuzzy
 #| msgid "Perform variable tracking"
 msgid "Perform variable tracking by annotating assignments."
 msgstr "Изврши праћење променљивих"
 
-#: common.opt:2738
+#: common.opt:2742
 msgid "Toggle -fvar-tracking-assignments."
 msgstr ""
 
-#: common.opt:2746
+#: common.opt:2750
 msgid "Perform variable tracking and also tag variables that are uninitialized."
 msgstr ""
 
-#: common.opt:2751
+#: common.opt:2755
 #, fuzzy
 #| msgid "Enable loop vectorization on trees"
 msgid "Enable vectorization on trees."
 msgstr "Укључи векторизацију петљи на стаблима"
 
-#: common.opt:2759
+#: common.opt:2763
 #, fuzzy
 #| msgid "Enable loop vectorization on trees"
 msgid "Enable loop vectorization on trees."
 msgstr "Укључи векторизацију петљи на стаблима"
 
-#: common.opt:2763
+#: common.opt:2767
 #, fuzzy
 #| msgid "Enable loop vectorization on trees"
 msgid "Enable basic block vectorization (SLP) on trees."
 msgstr "Укључи векторизацију петљи на стаблима"
 
-#: common.opt:2767
+#: common.opt:2771
 msgid "Specifies the cost model for vectorization. -fvect-cost-model=[unlimited|dynamic|cheap]\tSpecifies the cost model for vectorization."
 msgstr ""
 
-#: common.opt:2772
+#: common.opt:2776
 msgid "-fsimd-cost-model=[unlimited|dynamic|cheap]\tSpecifies the vectorization cost model for code marked with a simd directive."
 msgstr ""
 
-#: common.opt:2775
+#: common.opt:2779
 #, fuzzy, c-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown vectorizer cost model %qs"
 msgstr "непознат машински режим %qs"
 
-#: common.opt:2788
+#: common.opt:2792
 #, fuzzy
 #| msgid "Does nothing.  Preserved for backward compatibility."
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr "Не ради ништа. Остављено ради сагласности уназад."
 
-#: common.opt:2796
+#: common.opt:2800
 #, fuzzy
 #| msgid "Enable copy propagation for stores and loads"
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr "Укључи распростирање копирања за складиштења и учитавања"
 
-#: common.opt:2806
+#: common.opt:2810
 #, fuzzy
 #| msgid "Add extra commentary to assembler output"
 msgid "Add extra commentary to assembler output."
 msgstr "Додај допунске коментаре у испису асемблера"
 
-#: common.opt:2810
+#: common.opt:2814
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility."
 msgstr ""
 
-#: common.opt:2813
+#: common.opt:2817
 #, fuzzy, c-format
 #| msgid "unrecognized visibility value \"%s\""
 msgid "unrecognized visibility value %qs"
 msgstr "непрепозната вредност видљивости „%s“"
 
-#: common.opt:2829
+#: common.opt:2833
 msgid "Validate vtable pointers before using them."
 msgstr ""
 
-#: common.opt:2832
+#: common.opt:2836
 #, fuzzy, c-format
 #| msgid "(near initialization for %qs)"
 msgid "unknown vtable verify initialization priority %qs"
 msgstr "(близу успостављања за %qs)"
 
-#: common.opt:2845
+#: common.opt:2849
 msgid "Output vtable verification counters."
 msgstr ""
 
-#: common.opt:2849
+#: common.opt:2853
 msgid "Output vtable verification pointer sets information."
 msgstr ""
 
-#: common.opt:2853
+#: common.opt:2857
 #, fuzzy
 #| msgid "Use expression value profiles in optimizations"
 msgid "Use expression value profiles in optimizations."
 msgstr "Користи профиле вредности израза у оптимизацијама"
 
-#: common.opt:2857
+#: common.opt:2861
 #, fuzzy
 #| msgid "Construct webs and split unrelated uses of single variable"
 msgid "Construct webs and split unrelated uses of single variable."
 msgstr "Конструиши мреже и подели неповезане употребе једне променљиве"
 
-#: common.opt:2861
+#: common.opt:2865
 #, fuzzy
 #| msgid "Enable SSA dead code elimination optimization on trees"
 msgid "Enable conditional dead code elimination for builtin calls."
 msgstr "Укључи ССА оптимизацију елиминације мртвог кôда на стаблима"
 
-#: common.opt:2865
+#: common.opt:2869
 #, fuzzy
 #| msgid "Perform whole program optimizations"
 msgid "Perform whole program optimizations."
 msgstr "Изврши оптимизације целог програма"
 
-#: common.opt:2869
+#: common.opt:2873
 #, fuzzy
 #| msgid "Assume signed arithmetic overflow wraps around"
 msgid "Assume pointer overflow wraps around."
 msgstr "Претпостави да се преливање означене аритметике омотава"
 
-#: common.opt:2873
+#: common.opt:2877
 #, fuzzy
 #| msgid "Assume signed arithmetic overflow wraps around"
 msgid "Assume signed arithmetic overflow wraps around."
 msgstr "Претпостави да се преливање означене аритметике омотава"
 
-#: common.opt:2877
+#: common.opt:2881
 #, fuzzy
 #| msgid "Put zero initialized data in the bss section"
 msgid "Put zero initialized data in the bss section."
 msgstr "Стави податке успостављене на нулу у одељак bss"
 
-#: common.opt:2881
+#: common.opt:2885
 #, fuzzy
 #| msgid "Generate debug information in default format"
 msgid "Generate debug information in default format."
 msgstr "Стварај исправљачке информације у подразумеваном формату"
 
-#: common.opt:2885
+#: common.opt:2889
 msgid "Assume assembler support for (DWARF2+) .loc directives"
 msgstr ""
 
-#: common.opt:2889
+#: common.opt:2893
 msgid "Assume assembler support for view in (DWARF2+) .loc directives"
 msgstr ""
 
-#: common.opt:2892 common.opt:2896 common.opt:2900 common.opt:2904
+#: common.opt:2896 common.opt:2900 common.opt:2904 common.opt:2908
 #, fuzzy, c-format
 #| msgid "switch %qs is no longer supported"
 msgid "switch %qs no longer supported"
 msgstr "прекидач %qs више није подржан"
 
-#: common.opt:2909
+#: common.opt:2913
 msgid "Record DW_AT_decl_column and DW_AT_call_column in DWARF."
 msgstr ""
 
-#: common.opt:2913
+#: common.opt:2917
 #, fuzzy
 #| msgid "Generate debug information in default format"
 msgid "Generate debug information in default version of DWARF format."
 msgstr "Стварај исправљачке информације у подразумеваном формату"
 
-#: common.opt:2917
+#: common.opt:2921
 #, fuzzy
 #| msgid "Generate debug information in DWARF v2 format"
 msgid "Generate debug information in DWARF v2 (or later) format."
 msgstr "Стварај исправљачке информације у формату ДВАРФа 2"
 
-#: common.opt:2921
+#: common.opt:2925
 #, fuzzy
 #| msgid "Generate debug information in default extended format"
 msgid "Generate debug information in default extended format."
 msgstr "Стварај исправљачке информације у подразумеваном проширеном формату"
 
-#: common.opt:2925
+#: common.opt:2929
 #, fuzzy
 #| msgid "Generate a single exit point for each function"
 msgid "Generate extended entry point information for inlined functions"
 msgstr "Створи јединствену излазну тачку за сваку функцију"
 
-#: common.opt:2929
+#: common.opt:2933
 msgid "Compute locview reset points based on insn length estimates"
 msgstr ""
 
-#: common.opt:2937
+#: common.opt:2941
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:2941
+#: common.opt:2945
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:2945
+#: common.opt:2949
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr ""
 
-#: common.opt:2949
+#: common.opt:2953
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr ""
 
-#: common.opt:2953
+#: common.opt:2957
 #, fuzzy
 #| msgid "Generate debug information in default format"
 msgid "Generate debug information in separate .dwo files."
 msgstr "Стварај исправљачке информације у подразумеваном формату"
 
-#: common.opt:2957
+#: common.opt:2961
 #, fuzzy
 #| msgid "Generate debug information in STABS format"
 msgid "Generate debug information in STABS format."
 msgstr "Стварај исправљачке информације у формату СТАБСа"
 
-#: common.opt:2961
+#: common.opt:2965
 #, fuzzy
 #| msgid "Generate debug information in extended STABS format"
 msgid "Generate debug information in extended STABS format."
 msgstr "Стварај исправљачке информације у проширеном формату СТАБСа"
 
-#: common.opt:2965
+#: common.opt:2969
 msgid "Emit progressive recommended breakpoint locations."
 msgstr ""
 
-#: common.opt:2969
+#: common.opt:2973
 msgid "Don't emit DWARF additions beyond selected version."
 msgstr ""
 
-#: common.opt:2973
+#: common.opt:2977
 #, fuzzy
 #| msgid "Generate debug information in VMS format"
 msgid "Toggle debug information generation."
 msgstr "Стварај исправљачке информације у формату ВМСа"
 
-#: common.opt:2977
+#: common.opt:2981
 msgid "Augment variable location lists with progressive views."
 msgstr ""
 
-#: common.opt:2984
+#: common.opt:2988
 #, fuzzy
 #| msgid "Generate debug information in VMS format"
 msgid "Generate debug information in VMS format."
 msgstr "Стварај исправљачке информације у формату ВМСа"
 
-#: common.opt:2988
+#: common.opt:2992
 #, fuzzy
 #| msgid "Generate debug information in XCOFF format"
 msgid "Generate debug information in XCOFF format."
 msgstr "Стварај исправљачке информације у формату ИксКОФФа"
 
-#: common.opt:2992
+#: common.opt:2996
 #, fuzzy
 #| msgid "Generate debug information in extended XCOFF format"
 msgid "Generate debug information in extended XCOFF format."
 msgstr "Стварај исправљачке информације у проширеном формату ИксКОФФа"
 
-#: common.opt:3010
+#: common.opt:3014
 #, fuzzy
 #| msgid "Generate isel instructions"
 msgid "Generate compressed debug sections."
 msgstr "Стварај инструкције isel"
 
-#: common.opt:3014
+#: common.opt:3018
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>."
 msgstr ""
 
-#: common.opt:3021
+#: common.opt:3025
 #, fuzzy
 #| msgid "-imultilib <dir> Set <dir> to be the multilib include subdirectory"
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory."
 msgstr "-imultilib <дир> Постави <дир> као поддиректоријум укључивања за вишебиба"
 
-#: common.opt:3025
+#: common.opt:3029
 #, fuzzy
 #| msgid "-imultilib <dir> Set <dir> to be the multilib include subdirectory"
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory."
 msgstr "-imultilib <дир> Постави <дир> као поддиректоријум укључивања за вишебиба"
 
-#: common.opt:3047
+#: common.opt:3051
 #, fuzzy
 #| msgid "Place output into <file>"
 msgid "-o <file>\tPlace output into <file>."
 msgstr "Стави излаз у <file>"
 
-#: common.opt:3051
+#: common.opt:3055
 #, fuzzy
 #| msgid "Enable function profiling"
 msgid "Enable function profiling."
 msgstr "Укључи профилисање функција"
 
-#: common.opt:3061
+#: common.opt:3065
 #, fuzzy
 #| msgid "Like -pedantic but issue them as errors"
 msgid "Like -pedantic but issue them as errors."
 msgstr "Као -pedantic али их издај као грешке"
 
-#: common.opt:3101
+#: common.opt:3105
 #, fuzzy
 #| msgid "Do not display functions compiled or elapsed time"
 msgid "Do not display functions compiled or elapsed time."
 msgstr "Не приказуј компиловане функције или протекло време"
 
-#: common.opt:3133
+#: common.opt:3137
 #, fuzzy
 #| msgid "Enable verbose output"
 msgid "Enable verbose output."
 msgstr "Укључи опширан излаз"
 
-#: common.opt:3137
+#: common.opt:3141
 #, fuzzy
 #| msgid "Display the compiler's version"
 msgid "Display the compiler's version."
 msgstr "Прикажи верзију компилатора"
 
-#: common.opt:3141
+#: common.opt:3145
 #, fuzzy
 #| msgid "Suppress warnings"
 msgid "Suppress warnings."
 msgstr "Сузбиј упозорења"
 
-#: common.opt:3151
+#: common.opt:3155
 #, fuzzy
 #| msgid "Enable ID based shared library"
 msgid "Create a shared library."
 msgstr "Укључи дељене библиотеке на основу ИДа"
 
-#: common.opt:3196
+#: common.opt:3200
 msgid "Don't create a dynamically linked position independent executable."
 msgstr ""
 
-#: common.opt:3200
+#: common.opt:3204
 msgid "Create a dynamically linked position independent executable."
 msgstr ""
 
-#: common.opt:3204
+#: common.opt:3208
 msgid "Create a static position independent executable."
 msgstr ""
 
-#: common.opt:3211
+#: common.opt:3215
 msgid "Use caller save register across calls if possible."
 msgstr ""
 
-#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:598 cp/cvt.c:1308
+#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:599 cp/cvt.c:1308
 #: cp/cvt.c:1561
 #, gcc-internal-format
 msgid "value computed is not used"
@@ -19520,7 +19521,7 @@
 msgstr "Очекиван је тип израза"
 
 #: go/gofrontend/expressions.cc:4331 c/c-parser.c:13477 c/c-parser.c:13484
-#: cp/parser.c:33264 cp/parser.c:33271
+#: cp/parser.c:33261 cp/parser.c:33268
 #, fuzzy, gcc-internal-format
 #| msgid "Expected integer"
 msgid "expected integer"
@@ -20061,8 +20062,8 @@
 msgid "ignoring attribute %qE because it conflicts with attribute %qs"
 msgstr "Атрибут %s коси се са атрибутом %s код %L"
 
-#: attribs.c:449 c-family/c-attribs.c:1894 cp/decl.c:13690 cp/friend.c:302
-#: cp/tree.c:4559
+#: attribs.c:449 c-family/c-attribs.c:1905 cp/decl.c:13714 cp/friend.c:302
+#: cp/tree.c:4607
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D here"
 msgid "previous declaration here"
@@ -20069,7 +20070,7 @@
 msgstr "претходном декларацијом %q+#D овде"
 
 #. Warn about and ignore all others for now, but store them.
-#: attribs.c:564 c-family/c-attribs.c:2717 objc/objc-act.c:4963
+#: attribs.c:564 c-family/c-attribs.c:2728 objc/objc-act.c:4963
 #: objc/objc-act.c:6932 objc/objc-act.c:8119 objc/objc-act.c:8170
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute directive ignored"
@@ -20091,18 +20092,18 @@
 #. This is a c++11 attribute that appertains to a
 #. type-specifier, outside of the definition of, a class
 #. type.  Ignore it.
-#: attribs.c:590 cp/decl.c:10999
+#: attribs.c:590 cp/decl.c:11023
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored"
 msgid "attribute ignored"
 msgstr "атрибут %qE се игнорише"
 
-#: attribs.c:592 cp/decl.c:11000
+#: attribs.c:592 cp/decl.c:11024
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
 
-#: attribs.c:610 c-family/c-attribs.c:3219
+#: attribs.c:610 c-family/c-attribs.c:3230
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute does not apply to types"
 msgid "%qE attribute does not apply to types"
@@ -20120,40 +20121,40 @@
 msgstr "атрибути типа игноришу се пошто је тип већ дефинисан"
 
 #: attribs.c:691 attribs.c:1622 attribs.c:1632 attribs.c:1642
-#: c-family/c-attribs.c:540 c-family/c-attribs.c:559 c-family/c-attribs.c:577
-#: c-family/c-attribs.c:607 c-family/c-attribs.c:628 c-family/c-attribs.c:649
-#: c-family/c-attribs.c:690 c-family/c-attribs.c:717 c-family/c-attribs.c:733
-#: c-family/c-attribs.c:750 c-family/c-attribs.c:766 c-family/c-attribs.c:792
-#: c-family/c-attribs.c:807 c-family/c-attribs.c:835 c-family/c-attribs.c:852
-#: c-family/c-attribs.c:870 c-family/c-attribs.c:893 c-family/c-attribs.c:931
-#: c-family/c-attribs.c:954 c-family/c-attribs.c:971 c-family/c-attribs.c:1000
-#: c-family/c-attribs.c:1021 c-family/c-attribs.c:1042
-#: c-family/c-attribs.c:1069 c-family/c-attribs.c:1099
-#: c-family/c-attribs.c:1136 c-family/c-attribs.c:1189
-#: c-family/c-attribs.c:1255 c-family/c-attribs.c:1313
-#: c-family/c-attribs.c:1402 c-family/c-attribs.c:1432
-#: c-family/c-attribs.c:1483 c-family/c-attribs.c:1998
-#: c-family/c-attribs.c:2035 c-family/c-attribs.c:2096
-#: c-family/c-attribs.c:2152 c-family/c-attribs.c:2230
-#: c-family/c-attribs.c:2312 c-family/c-attribs.c:2371
-#: c-family/c-attribs.c:2390 c-family/c-attribs.c:2498
-#: c-family/c-attribs.c:2514 c-family/c-attribs.c:2530
-#: c-family/c-attribs.c:2551 c-family/c-attribs.c:2608
-#: c-family/c-attribs.c:2635 c-family/c-attribs.c:2690
-#: c-family/c-attribs.c:2870 c-family/c-attribs.c:2891
-#: c-family/c-attribs.c:3004 c-family/c-attribs.c:3031
-#: c-family/c-attribs.c:3221 c-family/c-attribs.c:3239
-#: c-family/c-attribs.c:3262 c-family/c-attribs.c:3301
-#: c-family/c-attribs.c:3383 c-family/c-attribs.c:3439
-#: c-family/c-attribs.c:3455 c-family/c-attribs.c:3549
-#: c-family/c-common.c:5600 config/darwin.c:2072 config/arm/arm.c:6868
+#: c-family/c-attribs.c:547 c-family/c-attribs.c:566 c-family/c-attribs.c:584
+#: c-family/c-attribs.c:614 c-family/c-attribs.c:635 c-family/c-attribs.c:656
+#: c-family/c-attribs.c:697 c-family/c-attribs.c:728 c-family/c-attribs.c:744
+#: c-family/c-attribs.c:761 c-family/c-attribs.c:777 c-family/c-attribs.c:803
+#: c-family/c-attribs.c:818 c-family/c-attribs.c:846 c-family/c-attribs.c:863
+#: c-family/c-attribs.c:881 c-family/c-attribs.c:904 c-family/c-attribs.c:942
+#: c-family/c-attribs.c:965 c-family/c-attribs.c:982 c-family/c-attribs.c:1011
+#: c-family/c-attribs.c:1032 c-family/c-attribs.c:1053
+#: c-family/c-attribs.c:1080 c-family/c-attribs.c:1110
+#: c-family/c-attribs.c:1147 c-family/c-attribs.c:1200
+#: c-family/c-attribs.c:1266 c-family/c-attribs.c:1324
+#: c-family/c-attribs.c:1413 c-family/c-attribs.c:1443
+#: c-family/c-attribs.c:1494 c-family/c-attribs.c:2009
+#: c-family/c-attribs.c:2046 c-family/c-attribs.c:2107
+#: c-family/c-attribs.c:2163 c-family/c-attribs.c:2241
+#: c-family/c-attribs.c:2323 c-family/c-attribs.c:2382
+#: c-family/c-attribs.c:2401 c-family/c-attribs.c:2509
+#: c-family/c-attribs.c:2525 c-family/c-attribs.c:2541
+#: c-family/c-attribs.c:2562 c-family/c-attribs.c:2619
+#: c-family/c-attribs.c:2646 c-family/c-attribs.c:2701
+#: c-family/c-attribs.c:2881 c-family/c-attribs.c:2902
+#: c-family/c-attribs.c:3015 c-family/c-attribs.c:3042
+#: c-family/c-attribs.c:3232 c-family/c-attribs.c:3250
+#: c-family/c-attribs.c:3273 c-family/c-attribs.c:3312
+#: c-family/c-attribs.c:3394 c-family/c-attribs.c:3450
+#: c-family/c-attribs.c:3466 c-family/c-attribs.c:3560
+#: c-family/c-common.c:5598 config/darwin.c:2072 config/arm/arm.c:6868
 #: config/arm/arm.c:6896 config/arm/arm.c:6913 config/avr/avr.c:9698
-#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6497
-#: config/i386/i386.c:41520 config/ia64/ia64.c:788
-#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33056
-#: config/spu/spu.c:3743 ada/gcc-interface/utils.c:6244
-#: ada/gcc-interface/utils.c:6261 ada/gcc-interface/utils.c:6277
-#: ada/gcc-interface/utils.c:6303 brig/brig-lang.c:476 lto/lto-lang.c:283
+#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6500
+#: config/i386/i386.c:41514 config/ia64/ia64.c:788
+#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33112
+#: config/spu/spu.c:3743 ada/gcc-interface/utils.c:6249
+#: ada/gcc-interface/utils.c:6266 ada/gcc-interface/utils.c:6282
+#: ada/gcc-interface/utils.c:6308 brig/brig-lang.c:476 lto/lto-lang.c:283
 #, gcc-internal-format
 msgid "%qE attribute ignored"
 msgstr "атрибут %qE се игнорише"
@@ -20551,93 +20552,109 @@
 msgid "%Kattempt to free a non-heap object"
 msgstr ""
 
-#: calls.c:1434
+#: calls.c:1291 file-prefix-map.c:50
+#, fuzzy, gcc-internal-format
+#| msgid "Invalid argument type %qs to %qs"
+msgid "invalid argument %qs to %qs"
+msgstr "Неисправан тип аргумента %qs за %qs"
+
+#: calls.c:1452
 #, gcc-internal-format
 msgid "%Kargument %i value %qE is negative"
 msgstr ""
 
-#: calls.c:1452
+#: calls.c:1470
 #, fuzzy, gcc-internal-format
 #| msgid "Second argument MOD at %L is zero"
 msgid "%Kargument %i value is zero"
 msgstr "Други аргумент у MOD код %L је нула"
 
-#: calls.c:1469
+#: calls.c:1487
 #, gcc-internal-format
 msgid "%Kargument %i value %qE exceeds maximum object size %E"
 msgstr ""
 
-#: calls.c:1483
+#: calls.c:1501
 #, gcc-internal-format
 msgid "%Kargument %i range [%E, %E] is negative"
 msgstr ""
 
-#: calls.c:1490
+#: calls.c:1508
 #, gcc-internal-format
 msgid "%Kargument %i range [%E, %E] exceeds maximum object size %E"
 msgstr ""
 
-#: calls.c:1520
+#: calls.c:1538
 #, gcc-internal-format
 msgid "%Kproduct %<%E * %E%> of arguments %i and %i exceeds %<SIZE_MAX%>"
 msgstr ""
 
-#: calls.c:1526
+#: calls.c:1544
 #, gcc-internal-format
 msgid "%Kproduct %<%E * %E%> of arguments %i and %i exceeds maximum object size %E"
 msgstr ""
 
-#: calls.c:1537 calls.c:1540
+#: calls.c:1555 calls.c:1558
 #, gcc-internal-format
 msgid "argument %i in the range [%E, %E]"
 msgstr ""
 
-#: calls.c:1551
+#: calls.c:1569
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "in a call to built-in allocation function %qD"
 msgstr "позив не-функције %qD"
 
-#: calls.c:1554
+#: calls.c:1572
 #, gcc-internal-format
 msgid "in a call to allocation function %qD declared here"
 msgstr ""
 
-#: calls.c:1711
+#: calls.c:1835
 #, gcc-internal-format
-msgid "%qD argument %i declared attribute %<nonstring%> is smaller than the specified bound %E"
+msgid "%qD argument %i declared attribute %<nonstring%> is smaller than the specified bound %wu"
 msgstr ""
 
-#: calls.c:1716
+#: calls.c:1841
+#, gcc-internal-format
+msgid "%qD argument %i declared attribute %<nonstring%> is smaller than the specified bound [%E, %E]"
+msgstr ""
+
+#: calls.c:1847
+#, gcc-internal-format
+msgid "%qD argument %i declared attribute %<nonstring%> may be smaller than the specified bound [%E, %E]"
+msgstr ""
+
+#: calls.c:1857
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared with attribute noinline"
 msgid "%qD argument %i declared attribute %<nonstring%>"
 msgstr "функција %q+D поново декларисана са атрибутом неуткане"
 
-#: calls.c:1721
+#: calls.c:1862
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "argument %qD declared here"
 msgstr "%q+D декларисано овде"
 
-#: calls.c:1735
+#: calls.c:1876
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot find class %qs"
 msgid "cannot tail-call: %s"
 msgstr "не могу да нађем класу %qs"
 
-#: calls.c:3365
+#: calls.c:3506
 #, gcc-internal-format
 msgid "function call has aggregate value"
 msgstr "позив функције има скупинску вредност"
 
-#: calls.c:4059
+#: calls.c:4200
 #, fuzzy, gcc-internal-format
 #| msgid "Pass arguments on the stack"
 msgid "passing too large argument on stack"
 msgstr "Прослеђуј аргументе на стеку"
 
-#: cfgexpand.c:1665 function.c:1002 varasm.c:2231
+#: cfgexpand.c:1665 function.c:1002 varasm.c:2242
 #, gcc-internal-format
 msgid "size of variable %q+D is too large"
 msgstr "величина променљиве %q+D је превелика"
@@ -21248,244 +21265,244 @@
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr "број об. белешки у ланцу ија (%d) != n_basic_blocks (%d)"
 
-#: cgraph.c:3051
+#: cgraph.c:3056
 #, fuzzy, gcc-internal-format
 #| msgid "caller edge count is negative"
 msgid "caller edge count invalid"
 msgstr "број ивица позивача је негативан"
 
-#: cgraph.c:3135
+#: cgraph.c:3140
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr "помоћно поље постављено за ивицу %s->%s"
 
-#: cgraph.c:3142
+#: cgraph.c:3147
 #, gcc-internal-format
 msgid "cgraph count invalid"
 msgstr ""
 
-#: cgraph.c:3147
+#: cgraph.c:3152
 #, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr ""
 
-#: cgraph.c:3152
+#: cgraph.c:3157
 #, fuzzy, gcc-internal-format
 #| msgid "Assume symbols might be invalid"
 msgid "local symbols must be defined"
 msgstr "Претпостави да симболи могу бити неважећи"
 
-#: cgraph.c:3157
+#: cgraph.c:3162
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr ""
 
-#: cgraph.c:3162
+#: cgraph.c:3167
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr ""
 
-#: cgraph.c:3167
+#: cgraph.c:3172
 #, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr ""
 
-#: cgraph.c:3174
+#: cgraph.c:3179
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "aux field set for edge %s->%s"
 msgid "aux field set for indirect edge from %s"
 msgstr "помоћно поље постављено за ивицу %s->%s"
 
-#: cgraph.c:3181
+#: cgraph.c:3186
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr ""
 
-#: cgraph.c:3196
+#: cgraph.c:3201
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr ""
 
-#: cgraph.c:3206
+#: cgraph.c:3211
 #, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr "показивач inlined_to је погрешан"
 
-#: cgraph.c:3211
+#: cgraph.c:3216
 #, gcc-internal-format
 msgid "multiple inline callers"
 msgstr "вишеструки уткани позивачи"
 
-#: cgraph.c:3218
+#: cgraph.c:3223
 #, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr "показивач inlined_to постављен за неуткане позиваче"
 
-#: cgraph.c:3239
+#: cgraph.c:3244
 #, fuzzy, gcc-internal-format
 #| msgid "incoming edge count does not match number of PHI arguments"
 msgid "caller edge count does not match BB count"
 msgstr "долазна ивица се не поклапа са бројем ПХИ аргумената"
 
-#: cgraph.c:3261
+#: cgraph.c:3266
 #, fuzzy, gcc-internal-format
 #| msgid "incoming edge count does not match number of PHI arguments"
 msgid "indirect call count does not match BB count"
 msgstr "долазна ивица се не поклапа са бројем ПХИ аргумената"
 
-#: cgraph.c:3272
+#: cgraph.c:3277
 #, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr "показивач inlined_to постављен али нема претходника"
 
-#: cgraph.c:3277
+#: cgraph.c:3282
 #, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr "показивач inlined_to упућује на самог себе"
 
-#: cgraph.c:3289
+#: cgraph.c:3294
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr ""
 
-#: cgraph.c:3301
+#: cgraph.c:3306
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr ""
 
-#: cgraph.c:3307
+#: cgraph.c:3312
 #, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr ""
 
-#: cgraph.c:3312
+#: cgraph.c:3317
 #, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr ""
 
-#: cgraph.c:3317
+#: cgraph.c:3322
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr ""
 
-#: cgraph.c:3329
+#: cgraph.c:3334
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr ""
 
-#: cgraph.c:3337
+#: cgraph.c:3342
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr ""
 
-#: cgraph.c:3342
+#: cgraph.c:3347
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr ""
 
-#: cgraph.c:3349
+#: cgraph.c:3354
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr ""
 
-#: cgraph.c:3358
+#: cgraph.c:3363
 #, gcc-internal-format
 msgid "Instrumentation clone does not reference original node"
 msgstr ""
 
-#: cgraph.c:3365
+#: cgraph.c:3370
 #, gcc-internal-format
 msgid "Not instrumented node has non-NULL original declaration"
 msgstr ""
 
-#: cgraph.c:3375
+#: cgraph.c:3380
 #, gcc-internal-format
 msgid "Instrumented node has wrong original declaration"
 msgstr ""
 
-#: cgraph.c:3393
+#: cgraph.c:3398
 #, gcc-internal-format
 msgid "Node has more than one chkp reference"
 msgstr ""
 
-#: cgraph.c:3398
+#: cgraph.c:3403
 #, gcc-internal-format
 msgid "Wrong node is referenced with chkp reference"
 msgstr ""
 
-#: cgraph.c:3406
+#: cgraph.c:3411
 #, gcc-internal-format
 msgid "Analyzed node has no reference to instrumented version"
 msgstr ""
 
-#: cgraph.c:3420
+#: cgraph.c:3425
 #, gcc-internal-format
 msgid "Alias chain for instrumented node is broken"
 msgstr ""
 
-#: cgraph.c:3429
+#: cgraph.c:3434
 #, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3434
+#: cgraph.c:3439
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3439
+#: cgraph.c:3444
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr ""
 
-#: cgraph.c:3445
+#: cgraph.c:3450
 #, gcc-internal-format
 msgid "Instrumentation thunk has wrong edge callee"
 msgstr ""
 
-#: cgraph.c:3481
+#: cgraph.c:3486
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr "дељени call_stmt:"
 
-#: cgraph.c:3489
+#: cgraph.c:3494
 #, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr "ивица показује на погрешну декларацију:"
 
-#: cgraph.c:3498
+#: cgraph.c:3503
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr ""
 
-#: cgraph.c:3508
+#: cgraph.c:3513
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr "недостаје графпоз ивица за call_stmt:"
 
-#: cgraph.c:3518
+#: cgraph.c:3523
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "reference to dead statement"
 msgstr "очекивана је наредба"
 
-#: cgraph.c:3531
+#: cgraph.c:3536
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr "ивица %s->%s нема одговарајући call_stmt"
 
-#: cgraph.c:3543
+#: cgraph.c:3548
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "edge %s->%s has no corresponding call_stmt"
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr "ивица %s->%s нема одговарајући call_stmt"
 
-#: cgraph.c:3554
+#: cgraph.c:3559
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr "verify_cgraph_node није успело"
 
-#: cgraph.c:3661 varpool.c:306
+#: cgraph.c:3666 varpool.c:306
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument to '-%s' is missing"
 msgid "%s: section %s is missing"
@@ -21522,12 +21539,12 @@
 msgstr "атрибут %qE се игнорише јер је %qT већ дефинисан"
 
 #. include_self=
-#: cgraphunit.c:981 c/c-decl.c:11282
+#: cgraphunit.c:981 c/c-decl.c:11302
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F употребљено али недефинисано"
 
-#: cgraphunit.c:983 c/c-decl.c:11291
+#: cgraphunit.c:983 c/c-decl.c:11311
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "%q+F декларисано као %<static%> али нигде дефинисано"
@@ -21657,13 +21674,13 @@
 msgid "cannot find '%s'"
 msgstr "не могу да нађем ‘%s’"
 
-#: collect-utils.c:183 collect2.c:2361 collect2.c:2560 gcc.c:3080 gcc.c:6856
+#: collect-utils.c:183 collect2.c:2387 collect2.c:2586 gcc.c:3080 gcc.c:6856
 #, fuzzy, gcc-internal-format
 #| msgid "pex_init failed"
 msgid "pex_init failed: %m"
 msgstr "pex_init није прошло"
 
-#: collect-utils.c:192 collect2.c:2370 collect2.c:2568 gcc.c:8498
+#: collect-utils.c:192 collect2.c:2396 collect2.c:2594 gcc.c:8498
 #, fuzzy, gcc-internal-format
 #| msgid "%s: %s"
 msgid "%s: %m"
@@ -21674,7 +21691,7 @@
 msgid "COLLECT_LTO_WRAPPER must be set"
 msgstr ""
 
-#: collect2.c:966 gcc.c:7382 lto-wrapper.c:1666
+#: collect2.c:969 gcc.c:7382 lto-wrapper.c:1692
 #: config/i386/intelmic-mkoffload.c:556 config/nvptx/mkoffload.c:405
 #, fuzzy, gcc-internal-format
 #| msgid "pex_init failed"
@@ -21681,92 +21698,92 @@
 msgid "atexit failed"
 msgstr "pex_init није прошло"
 
-#: collect2.c:1064
+#: collect2.c:1067
 #, gcc-internal-format
 msgid "no arguments"
 msgstr "без аргумената"
 
-#: collect2.c:1303 opts.c:904
+#: collect2.c:1311 opts.c:904
 #, fuzzy, gcc-internal-format
 #| msgid "-m%s not supported in this configuration"
 msgid "LTO support has not been enabled in this configuration"
 msgstr "-m%s није подржано у овој конфигурацији"
 
-#: collect2.c:1344
+#: collect2.c:1352
 #, gcc-internal-format
 msgid "can't open %s: %m"
 msgstr "не могу да отворим %s: %m"
 
-#: collect2.c:1450
+#: collect2.c:1472
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown demangling style '%s'"
 msgstr "непознат стил распетљавања „%s“"
 
-#: collect2.c:1546 collect2.c:1729 collect2.c:1769
+#: collect2.c:1574 collect2.c:1757 collect2.c:1797
 #, fuzzy, gcc-internal-format
 #| msgid "fopen %s"
 msgid "fopen %s: %m"
 msgstr "fopen %s"
 
-#: collect2.c:1549 collect2.c:1734 collect2.c:1772
+#: collect2.c:1577 collect2.c:1762 collect2.c:1800
 #, fuzzy, gcc-internal-format
 #| msgid "fclose %s"
 msgid "fclose %s: %m"
 msgstr "fclose %s"
 
-#: collect2.c:2335
+#: collect2.c:2361
 #, gcc-internal-format
 msgid "cannot find 'nm'"
 msgstr "не могу да нађем ‘nm’"
 
-#: collect2.c:2383
+#: collect2.c:2409
 #, fuzzy, gcc-internal-format
 #| msgid "can't open nm output"
 msgid "can't open nm output: %m"
 msgstr "не могу да отворим излаз из nm"
 
-#: collect2.c:2467
+#: collect2.c:2493
 #, gcc-internal-format, gfc-internal-format
 msgid "init function found in object %s"
 msgstr "функција init нађена у објекту %s"
 
-#: collect2.c:2478
+#: collect2.c:2504
 #, gcc-internal-format, gfc-internal-format
 msgid "fini function found in object %s"
 msgstr "функција fini нађена у објекту %s"
 
-#: collect2.c:2535
+#: collect2.c:2561
 #, gcc-internal-format
 msgid "cannot find 'ldd'"
 msgstr "не могу да нађем „ldd“"
 
-#: collect2.c:2581
+#: collect2.c:2607
 #, fuzzy, gcc-internal-format
 #| msgid "can't open ldd output"
 msgid "can't open ldd output: %m"
 msgstr "не могу да отворим излаз из ldd"
 
-#: collect2.c:2599
+#: collect2.c:2625
 #, gcc-internal-format, gfc-internal-format
 msgid "dynamic dependency %s not found"
 msgstr "динамичка зависност %s није нађена"
 
-#: collect2.c:2611
+#: collect2.c:2637
 #, gcc-internal-format, gfc-internal-format
 msgid "unable to open dynamic dependency '%s'"
 msgstr "не могу да отворим динамичку зависност ‘%s’"
 
-#: collect2.c:2765
+#: collect2.c:2791
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: not a COFF file"
 msgstr "%s: није КОФФ датотека"
 
-#: collect2.c:2930
+#: collect2.c:2961
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: cannot open as COFF file"
 msgstr "%s: не могу да отворим као КОФФ датотеку"
 
-#: collect2.c:2989
+#: collect2.c:3020
 #, gcc-internal-format, gfc-internal-format
 msgid "library lib%s not found"
 msgstr "библиотека lib%s није нађена"
@@ -21987,12 +22004,12 @@
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr ""
 
-#: dwarf2out.c:10901
+#: dwarf2out.c:10909
 #, gcc-internal-format
 msgid "-gdwarf-6 is output as version 5 with incompatibilities"
 msgstr ""
 
-#: dwarf2out.c:14415
+#: dwarf2out.c:14423
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
@@ -22118,12 +22135,6 @@
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr "функција %q+D поново декларисана са атрибутом неуткане"
 
-#: file-prefix-map.c:50
-#, fuzzy, gcc-internal-format
-#| msgid "Invalid argument type %qs to %qs"
-msgid "invalid argument %qs to %qs"
-msgstr "Неисправан тип аргумента %qs за %qs"
-
 #: final.c:1868
 #, fuzzy, gcc-internal-format
 #| msgid "size of %q+D is larger than %wd bytes"
@@ -22148,44 +22159,44 @@
 msgid "large fixed-point constant implicitly truncated to fixed-point type"
 msgstr "велики целобројни имплицитно подсечен на неозначени тип"
 
-#: fold-const.c:4151 fold-const.c:4161
+#: fold-const.c:4157 fold-const.c:4167
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d due to width of bit-field"
 msgstr "поређење је увек %d услед ширине битског поља"
 
-#: fold-const.c:5478 tree-ssa-reassoc.c:2374 tree-ssa-reassoc.c:3214
+#: fold-const.c:5484 tree-ssa-reassoc.c:2379 tree-ssa-reassoc.c:3219
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr "претпостављам да се означено преливање не дешава при упрошћавању пробе опсега"
 
-#: fold-const.c:5928 fold-const.c:5942
+#: fold-const.c:5934 fold-const.c:5948
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr "поређење је увек %d"
 
-#: fold-const.c:6085
+#: fold-const.c:6091
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr "%<or%> непоклопљених тестова неједнакости је увек 1"
 
-#: fold-const.c:6090
+#: fold-const.c:6096
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr "%<and%> међусобно искључивих тестова једнакости је увек 0"
 
-#: fold-const.c:8310
+#: fold-const.c:8316
 #, fuzzy, gcc-internal-format
 #| msgid "assuming signed overflow does not occur when negating a division"
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr "претпостављам да се означено преливање не дешава при негирању дељења"
 
-#: fold-const.c:8710
+#: fold-const.c:8716
 #, fuzzy, gcc-internal-format
 #| msgid "assuming signed overflow does not occur when negating a division"
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr "претпостављам да се означено преливање не дешава при негирању дељења"
 
-#: fold-const.c:12063
+#: fold-const.c:12069
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr "провера сажимања: првобитно дрво измењено сажимањем"
@@ -22196,7 +22207,7 @@
 msgid "total size of local objects too large"
 msgstr "%Jукупна величина локалних објеката је превелика"
 
-#: function.c:1776 gimplify.c:6270
+#: function.c:1776 gimplify.c:6273
 #, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr "немогуће ограничење у %<asm%>"
@@ -22533,7 +22544,7 @@
 msgid "%s: linker input file unused because linking not done"
 msgstr "%s: улазна датотека повезивача се не користи је се повезивање не извршава"
 
-#: gcc.c:8420 c-family/c-opts.c:770
+#: gcc.c:8420 c-family/c-opts.c:768
 #, gcc-internal-format
 msgid "cannot use %<-%> as input filename for a precompiled header"
 msgstr ""
@@ -22795,7 +22806,7 @@
 msgid "%G%qD destination unchanged after copying no bytes"
 msgstr ""
 
-#: gimple-fold.c:2052 tree-ssa-strlen.c:2050
+#: gimple-fold.c:2052 tree-ssa-strlen.c:2074
 msgid "%G%qD specified bound %E equals destination size"
 msgstr ""
 
@@ -22818,12 +22829,12 @@
 msgid "null pointer dereference"
 msgstr "Одредба мора бити упућивач"
 
-#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12451
-#: tree.c:12488 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10147
-#: c/c-typeck.c:10164 c/gimple-parser.c:1616 c/gimple-parser.c:1624
+#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12455
+#: tree.c:12492 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10152
+#: c/c-typeck.c:10169 c/gimple-parser.c:1616 c/gimple-parser.c:1624
 #: cp/call.c:6493 cp/call.c:8098 cp/constexpr.c:820 cp/constexpr.c:2309
-#: cp/cvt.c:1015 cp/cvt.c:1042 cp/decl.c:7334 cp/decl2.c:5256 cp/pt.c:8334
-#: cp/semantics.c:1836 cp/semantics.c:4053 cp/typeck.c:1700 cp/typeck.c:1895
+#: cp/cvt.c:1015 cp/cvt.c:1042 cp/decl.c:7355 cp/decl2.c:5246 cp/pt.c:8348
+#: cp/semantics.c:1836 cp/semantics.c:4056 cp/typeck.c:1700 cp/typeck.c:1895
 #: cp/typeck.c:3837
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
@@ -22835,27 +22846,27 @@
 msgid "nonnull argument %qD compared to NULL"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2517 gimple-ssa-sprintf.c:2637
+#: gimple-ssa-sprintf.c:2555 gimple-ssa-sprintf.c:2675
 #, gcc-internal-format
 msgid "%qE output may be truncated before the last format character"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2519 gimple-ssa-sprintf.c:2639
+#: gimple-ssa-sprintf.c:2557 gimple-ssa-sprintf.c:2677
 #, gcc-internal-format
 msgid "%qE output truncated before the last format character"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2522 gimple-ssa-sprintf.c:2642
+#: gimple-ssa-sprintf.c:2560 gimple-ssa-sprintf.c:2680
 #, gcc-internal-format
 msgid "%qE may write a terminating nul past the end of the destination"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2524 gimple-ssa-sprintf.c:2644
+#: gimple-ssa-sprintf.c:2562 gimple-ssa-sprintf.c:2682
 #, gcc-internal-format
 msgid "%qE writing a terminating nul past the end of the destination"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2534
+#: gimple-ssa-sprintf.c:2572
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size %wu"
@@ -22864,7 +22875,7 @@
 msgstr[2] ""
 msgstr[3] ""
 
-#: gimple-ssa-sprintf.c:2541
+#: gimple-ssa-sprintf.c:2579
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size %wu"
@@ -22873,7 +22884,7 @@
 msgstr[2] ""
 msgstr[3] ""
 
-#: gimple-ssa-sprintf.c:2548
+#: gimple-ssa-sprintf.c:2586
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size %wu"
@@ -22882,67 +22893,67 @@
 msgstr[2] ""
 msgstr[3] ""
 
-#: gimple-ssa-sprintf.c:2559
+#: gimple-ssa-sprintf.c:2597
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2562
+#: gimple-ssa-sprintf.c:2600
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2564
+#: gimple-ssa-sprintf.c:2602
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2576
+#: gimple-ssa-sprintf.c:2614
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2579
+#: gimple-ssa-sprintf.c:2617
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2582
+#: gimple-ssa-sprintf.c:2620
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2591
+#: gimple-ssa-sprintf.c:2629
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2594
+#: gimple-ssa-sprintf.c:2632
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2597
+#: gimple-ssa-sprintf.c:2635
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2606
+#: gimple-ssa-sprintf.c:2644
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2609
+#: gimple-ssa-sprintf.c:2647
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2611
+#: gimple-ssa-sprintf.c:2649
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2653
+#: gimple-ssa-sprintf.c:2691
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size between %wu and %wu"
@@ -22951,7 +22962,7 @@
 msgstr[2] ""
 msgstr[3] ""
 
-#: gimple-ssa-sprintf.c:2660
+#: gimple-ssa-sprintf.c:2698
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size between %wu and %wu"
@@ -22960,7 +22971,7 @@
 msgstr[2] ""
 msgstr[3] ""
 
-#: gimple-ssa-sprintf.c:2668
+#: gimple-ssa-sprintf.c:2706
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size between %wu and %wu"
@@ -22969,102 +22980,102 @@
 msgstr[2] ""
 msgstr[3] ""
 
-#: gimple-ssa-sprintf.c:2680
+#: gimple-ssa-sprintf.c:2718
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2683
+#: gimple-ssa-sprintf.c:2721
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2686
+#: gimple-ssa-sprintf.c:2724
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2699
+#: gimple-ssa-sprintf.c:2737
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2702
+#: gimple-ssa-sprintf.c:2740
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2705
+#: gimple-ssa-sprintf.c:2743
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2715
+#: gimple-ssa-sprintf.c:2753
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2718
+#: gimple-ssa-sprintf.c:2756
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2721
+#: gimple-ssa-sprintf.c:2759
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2730
+#: gimple-ssa-sprintf.c:2768
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2733
+#: gimple-ssa-sprintf.c:2771
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2736
+#: gimple-ssa-sprintf.c:2774
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2825
+#: gimple-ssa-sprintf.c:2863
 #, gcc-internal-format
 msgid "%<%.*s%> directive argument is null"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2890
+#: gimple-ssa-sprintf.c:2928
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes exceeds minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2897
+#: gimple-ssa-sprintf.c:2935
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may exceed minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2900
+#: gimple-ssa-sprintf.c:2938
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes exceeds minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2929
+#: gimple-ssa-sprintf.c:2967
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2936
+#: gimple-ssa-sprintf.c:2974
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2939
+#: gimple-ssa-sprintf.c:2977
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may cause result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2949
+#: gimple-ssa-sprintf.c:2987
 #, gcc-internal-format
 msgid "assuming directive output of %wu byte"
 msgid_plural "assuming directive output of %wu bytes"
@@ -23073,79 +23084,79 @@
 msgstr[2] ""
 msgstr[3] ""
 
-#: gimple-ssa-sprintf.c:2956
+#: gimple-ssa-sprintf.c:2994
 #, fuzzy, gcc-internal-format
 #| msgid "invalid option argument %qs"
 msgid "directive argument %qE"
 msgstr "неисправан аргумент опције %qs"
 
-#: gimple-ssa-sprintf.c:2958
+#: gimple-ssa-sprintf.c:2996
 #, gcc-internal-format
 msgid "directive argument in the range [%E, %E]"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2962
+#: gimple-ssa-sprintf.c:3000
 #, gcc-internal-format
 msgid "using the range [%E, %E] for directive argument"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2982
+#: gimple-ssa-sprintf.c:3020
 #, gcc-internal-format
 msgid "%qE output %wu byte into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2983
+#: gimple-ssa-sprintf.c:3021
 #, gcc-internal-format
 msgid "%qE output %wu bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2987
+#: gimple-ssa-sprintf.c:3025
 #, gcc-internal-format
 msgid "%qE output between %wu and %wu bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2992
+#: gimple-ssa-sprintf.c:3030
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes (assuming %wu) into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2997
+#: gimple-ssa-sprintf.c:3035
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3368
+#: gimple-ssa-sprintf.c:3406
 #, gcc-internal-format
 msgid "%<%.*s%> directive width out of range"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3402
+#: gimple-ssa-sprintf.c:3440
 #, gcc-internal-format
 msgid "%<%.*s%> directive precision out of range"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3893
+#: gimple-ssa-sprintf.c:3931
 #, gcc-internal-format
 msgid "specified bound %wu exceeds maximum object size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3899
+#: gimple-ssa-sprintf.c:3937
 #, gcc-internal-format
 msgid "specified bound %wu exceeds %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3949
+#: gimple-ssa-sprintf.c:3987
 #, fuzzy, gcc-internal-format
 #| msgid "Maintain backchain pointer"
 msgid "null destination pointer"
 msgstr "Одржавај показивач контраланца"
 
-#: gimple-ssa-sprintf.c:3966
+#: gimple-ssa-sprintf.c:4004
 #, gcc-internal-format
 msgid "specified bound %wu exceeds the size %wu of the destination object"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3978
+#: gimple-ssa-sprintf.c:4016
 #, fuzzy, gcc-internal-format
 #| msgid "%s in format string at %C"
 msgid "null format string"
@@ -23385,10 +23396,10 @@
 msgstr ""
 
 #: gimple-ssa-warn-restrict.c:1678 c/c-decl.c:3603 c/c-decl.c:3874
-#: c/c-typeck.c:8345 cp/class.c:1346 cp/class.c:3098 cp/decl.c:3979
-#: cp/decl.c:10753 cp/decl.c:11151 cp/decl.c:11160 cp/friend.c:384
+#: c/c-typeck.c:8350 cp/class.c:1346 cp/class.c:3102 cp/decl.c:3979
+#: cp/decl.c:10777 cp/decl.c:11175 cp/decl.c:11184 cp/friend.c:384
 #: cp/friend.c:393 cp/parser.c:3275 cp/parser.c:3372 cp/parser.c:3422
-#: cp/parser.c:6327 cp/parser.c:21027
+#: cp/parser.c:6330 cp/parser.c:21024
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%qD declared here"
@@ -23464,238 +23475,238 @@
 msgid "using result of function returning %<void%>"
 msgstr "нема повратне наредбе у функцији која враћа непразан тип"
 
-#: gimplify.c:6128
+#: gimplify.c:6131
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid lvalue in asm output %d"
 msgstr "неисправна л-вредност у излазу асемблера %d"
 
-#: gimplify.c:6271
+#: gimplify.c:6274
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr "немеморијски улаз %d мора остати у меморији"
 
-#: gimplify.c:6311 gimplify.c:6320
+#: gimplify.c:6314 gimplify.c:6323
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr "меморијски улаз %d не може се непосредно адресирати"
 
-#: gimplify.c:6928
+#: gimplify.c:6931
 #, fuzzy, gcc-internal-format
 #| msgid "threadprivate variables not supported in this target"
 msgid "threadprivate variable %qE used in target region"
 msgstr "нитно-локалне променљиве нису подржане за овај циљ"
 
-#: gimplify.c:6930
+#: gimplify.c:6933
 #, fuzzy, gcc-internal-format
 #| msgid "%Henclosing parallel"
 msgid "enclosing target region"
 msgstr "%Hобухватајуће паралелно"
 
-#: gimplify.c:6942
+#: gimplify.c:6945
 #, fuzzy, gcc-internal-format
 #| msgid "threadprivate variables not supported in this target"
 msgid "threadprivate variable %qE used in untied task"
 msgstr "нитно-локалне променљиве нису подржане за овај циљ"
 
-#: gimplify.c:6944
+#: gimplify.c:6947
 #, fuzzy, gcc-internal-format
 #| msgid "%Henclosing parallel"
 msgid "enclosing task"
 msgstr "%Hобухватајуће паралелно"
 
-#: gimplify.c:7016
+#: gimplify.c:7019
 #, fuzzy, gcc-internal-format
 #| msgid "%qs not specified in enclosing parallel"
 msgid "%qE not specified in enclosing %qs"
 msgstr "%qs није наведено у обухватајућем паралелном"
 
-#: gimplify.c:7018
+#: gimplify.c:7021
 #, fuzzy, gcc-internal-format
 #| msgid "error closing %s: %m"
 msgid "enclosing %qs"
 msgstr "грешка при затварању %s: %m"
 
-#: gimplify.c:7143
+#: gimplify.c:7146
 #, fuzzy, gcc-internal-format
 #| msgid "%qs not specified in enclosing parallel"
 msgid "%qE not specified in enclosing OpenACC %qs construct"
 msgstr "%qs није наведено у обухватајућем паралелном"
 
-#: gimplify.c:7145
+#: gimplify.c:7148
 #, gcc-internal-format
 msgid "enclosing OpenACC %qs construct"
 msgstr ""
 
-#: gimplify.c:7198
+#: gimplify.c:7201
 #, gcc-internal-format
 msgid "%qE with %<link%> clause used in %<routine%> function"
 msgstr ""
 
-#: gimplify.c:7206
+#: gimplify.c:7209
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE undeclared (first use in this function)"
 msgid "%qE requires a %<declare%> directive for use in a %<routine%> function"
 msgstr "%H%qE недекларисано (прва употреба у овој функцији)"
 
-#: gimplify.c:7272 gimplify.c:7872
+#: gimplify.c:7275 gimplify.c:7875
 #, fuzzy, gcc-internal-format
 #| msgid "variable %q+D declared %<inline%>"
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr "променљива %q+D декларисана као %<inline%>"
 
-#: gimplify.c:7293
+#: gimplify.c:7296
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr ""
 
-#: gimplify.c:7411 gimplify.c:7443
+#: gimplify.c:7414 gimplify.c:7446
 #, fuzzy, gcc-internal-format
 #| msgid "%Hiteration variable %qE is unsigned"
 msgid "iteration variable %qE is predetermined linear"
 msgstr "%Hнеозначена променљива итерације %qE"
 
-#: gimplify.c:7414
+#: gimplify.c:7417
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable %qs should be private"
 msgid "iteration variable %qE should be private"
 msgstr "требало би да променљива итерације %qs буде приватна"
 
-#: gimplify.c:7428
+#: gimplify.c:7431
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable %qs should not be firstprivate"
 msgid "iteration variable %qE should not be firstprivate"
 msgstr "не би требало да променљива итерације %qs буде firstprivate"
 
-#: gimplify.c:7431
+#: gimplify.c:7434
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable %qs should not be reduction"
 msgid "iteration variable %qE should not be reduction"
 msgstr "не би требало да променљива итерације %qs буде свођена"
 
-#: gimplify.c:7434
+#: gimplify.c:7437
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable %qs should not be reduction"
 msgid "iteration variable %qE should not be linear"
 msgstr "не би требало да променљива итерације %qs буде свођена"
 
-#: gimplify.c:7437
+#: gimplify.c:7440
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable %qs should not be firstprivate"
 msgid "iteration variable %qE should not be lastprivate"
 msgstr "не би требало да променљива итерације %qs буде firstprivate"
 
-#: gimplify.c:7440
+#: gimplify.c:7443
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable %qs should be private"
 msgid "iteration variable %qE should not be private"
 msgstr "требало би да променљива итерације %qs буде приватна"
 
-#: gimplify.c:7742
+#: gimplify.c:7745
 #, gcc-internal-format
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr ""
 
-#: gimplify.c:7949
+#: gimplify.c:7952
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr ""
 
-#: gimplify.c:8160
+#: gimplify.c:8163
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qE appears more than once in map clauses"
 msgstr "%qE се појављује више од једном у одредбама података"
 
-#: gimplify.c:8464
+#: gimplify.c:8467
 #, fuzzy, gcc-internal-format
 #| msgid "%s variable %qs is private in outer context"
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr "%s променљива %qs је приватна у спољашњем контексту"
 
-#: gimplify.c:8484
+#: gimplify.c:8487
 #, fuzzy, gcc-internal-format
 #| msgid "%s variable %qs is private in outer context"
 msgid "%s variable %qE is private in outer context"
 msgstr "%s променљива %qs је приватна у спољашњем контексту"
 
-#: gimplify.c:8510
+#: gimplify.c:8513
 #, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr ""
 
-#: gimplify.c:8775
+#: gimplify.c:8778
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr ""
 
-#: gimplify.c:8808
+#: gimplify.c:8811
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:9000
+#: gimplify.c:9003
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:9051
+#: gimplify.c:9054
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr ""
 
-#: gimplify.c:9133
+#: gimplify.c:9136
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to present_or_copy"
 msgstr ""
 
-#: gimplify.c:9278
+#: gimplify.c:9281
 #, fuzzy, gcc-internal-format
 #| msgid "invalid template declaration of %qD"
 msgid "invalid private reduction on %qE"
 msgstr "неисправна декларација шаблона %qD"
 
-#: gimplify.c:11103 omp-low.c:2791
+#: gimplify.c:11106 omp-low.c:2791
 #, fuzzy, gcc-internal-format
 #| msgid "ordered region must be closely nested inside a loop region with an ordered clause"
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr "уређена област мора бити блиско угњеждена унутар петље са одредбом уређености"
 
-#: gimplify.c:11121
+#: gimplify.c:11124
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr ""
 
-#: gimplify.c:11134
+#: gimplify.c:11137
 #, gcc-internal-format
 msgid "number of variables in %<depend(sink)%> clause does not match number of iteration variables"
 msgstr ""
 
-#: gimplify.c:11147
+#: gimplify.c:11150
 #, gcc-internal-format
 msgid "more than one %<depend(source)%> clause on an %<ordered%> construct"
 msgstr ""
 
-#: gimplify.c:11158
+#: gimplify.c:11161
 #, gcc-internal-format
 msgid "%<depend(source)%> clause specified together with %<depend(sink:)%> clauses on the same construct"
 msgstr ""
 
-#: gimplify.c:12393
+#: gimplify.c:12396
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr "гимплификација није успела"
 
-#: gimplify.c:12936
+#: gimplify.c:12939
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr "%qT се унапређује у %qT при прослеђивању кроз %<...%>"
 
-#: gimplify.c:12941
+#: gimplify.c:12944
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr "(стога би требало да проследите %qT уместо %qT за %<va_arg%>)"
 
-#: gimplify.c:12948
+#: gimplify.c:12951
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr "ако се овај кôд досегне, програм ће се прекинути"
@@ -24203,49 +24214,49 @@
 msgid "Max. number of generated reload insns per insn is achieved (%d)\n"
 msgstr ""
 
-#: lto-cgraph.c:1294
+#: lto-cgraph.c:1296
 #, gcc-internal-format, gfc-internal-format
 msgid "bytecode stream: found multiple instances of cgraph node with uid %d"
 msgstr ""
 
-#: lto-cgraph.c:1472
+#: lto-cgraph.c:1474
 #, gcc-internal-format
 msgid "bytecode stream: no caller found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1478
+#: lto-cgraph.c:1480
 #, gcc-internal-format
 msgid "bytecode stream: no callee found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1552
+#: lto-cgraph.c:1554
 #, gcc-internal-format
 msgid "bytecode stream: found empty cgraph node"
 msgstr ""
 
-#: lto-cgraph.c:1730
+#: lto-cgraph.c:1732
 #, gcc-internal-format, gfc-internal-format
 msgid "At most %i profile runs is supported. Perhaps corrupted profile?"
 msgstr ""
 
-#: lto-cgraph.c:1817
+#: lto-cgraph.c:1819
 #, gcc-internal-format, gfc-internal-format
 msgid "Profile information in %s corrupted"
 msgstr ""
 
-#: lto-cgraph.c:1855
+#: lto-cgraph.c:1857
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot find class %qs"
 msgid "cannot find LTO cgraph in %s"
 msgstr "не могу да нађем класу %qs"
 
-#: lto-cgraph.c:1865
+#: lto-cgraph.c:1867
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot find protocol declaration for %qs"
 msgid "cannot find LTO section refs in %s"
 msgstr "не могу да нађем декларацију протокола за %qs"
 
-#: lto-cgraph.c:1946
+#: lto-cgraph.c:1948
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid rotate insn"
 msgid "invalid offload table in %s"
@@ -24321,92 +24332,98 @@
 msgid "bytecode stream in file %qs generated with LTO version %d.%d instead of the expected %d.%d"
 msgstr ""
 
-#: lto-wrapper.c:117
+#: lto-wrapper.c:118
 #, fuzzy, gcc-internal-format
 #| msgid "opening output file %s: %m"
 msgid "deleting LTRANS file %s: %m"
 msgstr "отварам улазну датотеку %s: %m"
 
-#: lto-wrapper.c:154
+#: lto-wrapper.c:155
 #, gcc-internal-format
 msgid "malformed COLLECT_GCC_OPTIONS"
 msgstr ""
 
-#: lto-wrapper.c:308
+#: lto-wrapper.c:309
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "created and used with different endianness"
 msgid "Option %s with different values"
 msgstr "направљено и употребељно са различитом крајношћу"
 
-#: lto-wrapper.c:392
+#: lto-wrapper.c:393
 #, gcc-internal-format, gfc-internal-format
 msgid "Option %s not used consistently in all LTO input files"
 msgstr ""
 
-#: lto-wrapper.c:832
+#: lto-wrapper.c:833
 #, gcc-internal-format, gfc-internal-format
 msgid "problem with building target image for %s\n"
 msgstr ""
 
-#: lto-wrapper.c:852
+#: lto-wrapper.c:853
 #, fuzzy, gcc-internal-format
 #| msgid "no input files"
 msgid "reading input file"
 msgstr "нема улазних датотека"
 
-#: lto-wrapper.c:857
+#: lto-wrapper.c:858
 #, fuzzy, gcc-internal-format
 #| msgid "%s:error writing output file '%s'\n"
 msgid "writing output file"
 msgstr "%s:грешка при писању у излазну датотеку ‘%s’\n"
 
-#: lto-wrapper.c:889
+#: lto-wrapper.c:890
 #, gcc-internal-format
 msgid "installation error, can't find crtoffloadtable.o"
 msgstr ""
 
-#: lto-wrapper.c:1000 lto-wrapper.c:1012
+#: lto-wrapper.c:1001 lto-wrapper.c:1013
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s: %s"
 msgid "%s: %s\n"
 msgstr "%s: %s"
 
-#: lto-wrapper.c:1056
+#: lto-wrapper.c:1064
 #, fuzzy, gcc-internal-format
 #| msgid "environment variable DJGPP not defined"
 msgid "environment variable COLLECT_GCC must be set"
 msgstr "променљива окружења DJGPP није дефинисана"
 
-#: lto-wrapper.c:1060 config/nvptx/mkoffload.c:363
+#: lto-wrapper.c:1068 config/nvptx/mkoffload.c:363
 #, fuzzy, gcc-internal-format
 #| msgid "environment variable DJGPP not defined"
 msgid "environment variable COLLECT_GCC_OPTIONS must be set"
 msgstr "променљива окружења DJGPP није дефинисана"
 
-#: lto-wrapper.c:1229 lto-wrapper.c:1285
+#: lto-wrapper.c:1237 lto-wrapper.c:1293
 #, fuzzy, gcc-internal-format
 #| msgid "can't open %s: %m"
 msgid "cannot open %s: %m"
 msgstr "не могу да отворим %s: %m"
 
-#: lto-wrapper.c:1232 lto-wrapper.c:1291
+#: lto-wrapper.c:1240 lto-wrapper.c:1299
 #, fuzzy, gcc-internal-format
 #| msgid "can%'t read %s: %m"
 msgid "cannot read %s: %m"
 msgstr "не могу да читам %s: %m"
 
-#: lto-wrapper.c:1259
+#: lto-wrapper.c:1267
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid #pragma %s"
 msgid "invalid format of %s"
 msgstr "неисправна #pragma %s"
 
-#: lto-wrapper.c:1482
+#: lto-wrapper.c:1491
 #, fuzzy, gcc-internal-format
 #| msgid "fopen %s"
 msgid "fopen: %s: %m"
 msgstr "fopen %s"
 
+#: lto-wrapper.c:1508
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "opening output file %s: %m"
+msgid "Corrupted ltrans output file %s"
+msgstr "отварам улазну датотеку %s: %m"
+
 #: multiple_target.c:76
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
@@ -24786,13 +24803,13 @@
 msgid "unrecognized argument in option %qs"
 msgstr "непрепозната опција командне линије „%s“"
 
-#: opts-common.c:1198 config/i386/i386.c:3206
+#: opts-common.c:1198 config/i386/i386.c:3209
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid argument type %qs to %qs"
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "Неисправан тип аргумента %qs за %qs"
 
-#: opts-common.c:1201 config/i386/i386.c:3209
+#: opts-common.c:1201 config/i386/i386.c:3212
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid argument type %qs to %qs"
 msgid "valid arguments to %qs are: %s"
@@ -25435,22 +25452,22 @@
 msgid "output operand %d must use %<&%> constraint"
 msgstr "излазни операнд %d мора користити ограничење %<&%>"
 
-#: regcprop.c:1187
+#: regcprop.c:1193
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad next_regno for empty chain (%u)"
 msgstr "validate_value_data: [%u] Лош next_regno за празан ланац (%u)"
 
-#: regcprop.c:1199
+#: regcprop.c:1205
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: Loop in regno chain (%u)"
 msgstr "validate_value_data: Петља у regno ланцу (%u)"
 
-#: regcprop.c:1202
+#: regcprop.c:1208
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad oldest_regno (%u)"
 msgstr "validate_value_data: [%u] Лош oldest_regno (%u)"
 
-#: regcprop.c:1214
+#: regcprop.c:1220
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Non-empty reg in chain (%s %u %i)"
 msgstr "validate_value_data: [%u] Непразан рег. у ланцу (%s %u %i)"
@@ -25499,7 +25516,7 @@
 msgstr "регистар се користи за две глобалне регистарске променљиве"
 
 #: reginfo.c:789 config/powerpcspe/powerpcspe.c:32259
-#: config/rs6000/rs6000.c:29453
+#: config/rs6000/rs6000.c:29530
 #, fuzzy, gcc-internal-format
 #| msgid "  conflict with %q+D"
 msgid "conflicts with %qD"
@@ -25753,159 +25770,164 @@
 msgid "function symbol is not function"
 msgstr "функција враћа функцију"
 
-#: symtab.c:1006
+#: symtab.c:1005
+#, gcc-internal-format
+msgid "inconsistent `ifunc' attribute"
+msgstr ""
+
+#: symtab.c:1013
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to variables"
 msgid "variable symbol is not variable"
 msgstr "атрибут %qs примењује се само на променљиве"
 
-#: symtab.c:1012
+#: symtab.c:1019
 #, gcc-internal-format
 msgid "node has unknown type"
 msgstr ""
 
-#: symtab.c:1021
+#: symtab.c:1028
 #, gcc-internal-format
 msgid "node not found node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.c:1029
+#: symtab.c:1036
 #, gcc-internal-format
 msgid "node differs from node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.c:1038
+#: symtab.c:1045
 #, gcc-internal-format
 msgid "assembler name hash list corrupted"
 msgstr ""
 
-#: symtab.c:1051
+#: symtab.c:1058
 #, fuzzy, gcc-internal-format
 #| msgid "node not found in cgraph_hash"
 msgid "node not found in symtab assembler name hash"
 msgstr "чвор није нађен у cgraph_hash"
 
-#: symtab.c:1058
+#: symtab.c:1065
 #, gcc-internal-format
 msgid "double linked list of assembler names corrupted"
 msgstr ""
 
-#: symtab.c:1063
+#: symtab.c:1070
 #, gcc-internal-format
 msgid "node has body_removed but is definition"
 msgstr ""
 
-#: symtab.c:1068
+#: symtab.c:1075
 #, fuzzy, gcc-internal-format
 #| msgid "called object %qE is not a function"
 msgid "node is analyzed but it is not a definition"
 msgstr "позвани објекат %qE није функција"
 
-#: symtab.c:1073
+#: symtab.c:1080
 #, gcc-internal-format
 msgid "node is alias but not implicit alias"
 msgstr ""
 
-#: symtab.c:1078
+#: symtab.c:1085
 #, fuzzy, gcc-internal-format
 #| msgid "%Jold-style function definition"
 msgid "node is alias but not definition"
 msgstr "%Jстаровремска дефиниција функције"
 
-#: symtab.c:1083
+#: symtab.c:1090
 #, gcc-internal-format
 msgid "node is weakref but not an transparent_alias"
 msgstr ""
 
-#: symtab.c:1088
+#: symtab.c:1095
 #, gcc-internal-format
 msgid "node is transparent_alias but not an alias"
 msgstr ""
 
-#: symtab.c:1097
+#: symtab.c:1104
 #, gcc-internal-format
 msgid "node is in same_comdat_group list but has no comdat_group"
 msgstr ""
 
-#: symtab.c:1102
+#: symtab.c:1109
 #, gcc-internal-format
 msgid "same_comdat_group list across different groups"
 msgstr ""
 
-#: symtab.c:1107
+#: symtab.c:1114
 #, gcc-internal-format
 msgid "mixing different types of symbol in same comdat groups is not supported"
 msgstr ""
 
-#: symtab.c:1112
+#: symtab.c:1119
 #, gcc-internal-format
 msgid "node is alone in a comdat group"
 msgstr ""
 
-#: symtab.c:1119
+#: symtab.c:1126
 #, gcc-internal-format
 msgid "same_comdat_group is not a circular list"
 msgstr ""
 
-#: symtab.c:1134
+#: symtab.c:1141
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local symbol referred to by %s outside its comdat"
 msgstr ""
 
-#: symtab.c:1144
+#: symtab.c:1151
 #, gcc-internal-format
 msgid "implicit_section flag is set but section isn't"
 msgstr ""
 
-#: symtab.c:1151
+#: symtab.c:1158
 #, gcc-internal-format
 msgid "Both section and comdat group is set"
 msgstr ""
 
-#: symtab.c:1163
+#: symtab.c:1170
 #, gcc-internal-format
 msgid "Alias and target's section differs"
 msgstr ""
 
-#: symtab.c:1170
+#: symtab.c:1177
 #, gcc-internal-format
 msgid "Alias and target's comdat groups differs"
 msgstr ""
 
-#: symtab.c:1185
+#: symtab.c:1192
 #, gcc-internal-format
 msgid "Transparent alias and target's assembler names differs"
 msgstr ""
 
-#: symtab.c:1193
+#: symtab.c:1200
 #, gcc-internal-format
 msgid "Chained transparent aliases"
 msgstr ""
 
-#: symtab.c:1216 symtab.c:1253
+#: symtab.c:1223 symtab.c:1260
 #, fuzzy, gcc-internal-format
 #| msgid "verify_ssa failed"
 msgid "symtab_node::verify failed"
 msgstr "verify_ssa није успело"
 
-#: symtab.c:1249
+#: symtab.c:1256
 #, gcc-internal-format
 msgid "Two symbols with same comdat_group are not linked by the same_comdat_group list."
 msgstr ""
 
-#: symtab.c:1658
+#: symtab.c:1665
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared as inline"
 msgid "function %q+D part of alias cycle"
 msgstr "функција %q+D поново декларисана као уткана"
 
-#: symtab.c:1660
+#: symtab.c:1667
 #, fuzzy, gcc-internal-format
 #| msgid "variable %qD has function type"
 msgid "variable %q+D part of alias cycle"
 msgstr "променљива %qD има функцијски тип"
 
-#: symtab.c:1688
+#: symtab.c:1695
 #, gcc-internal-format
 msgid "section of alias %q+D must match section of its target"
 msgstr ""
@@ -26786,7 +26808,7 @@
 msgid "the first argument of a VEC_COND_EXPR must be of a boolean vector type of the same number of elements as the result"
 msgstr ""
 
-#: tree-cfg.c:4395 c/c-typeck.c:5212
+#: tree-cfg.c:4395 c/c-typeck.c:5217
 #, gcc-internal-format
 msgid "type mismatch in conditional expression"
 msgstr "неслагање типова у условном изразу"
@@ -27174,25 +27196,25 @@
 msgid "missing edge %i->%i"
 msgstr "недостаје ивица %i->%i"
 
-#: tree-cfg.c:9379
+#: tree-cfg.c:9388
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<noreturn%> function does return"
 msgid "%<noreturn%> function does return"
 msgstr "%H%<noreturn%> функција ипак враћа"
 
-#: tree-cfg.c:9400 tree-cfg.c:9432
+#: tree-cfg.c:9409 tree-cfg.c:9441
 #, fuzzy, gcc-internal-format
 #| msgid "%Hcontrol reaches end of non-void function"
 msgid "control reaches end of non-void function"
 msgstr "%Hконтрола стиже до краја функције непразног типа"
 
-#: tree-cfg.c:9498 cp/cvt.c:1039
+#: tree-cfg.c:9507 cp/cvt.c:1039
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgstr "%Hигноришем повратну вредност из %qD декларисану уз атрибут warn_unused_result"
 
-#: tree-cfg.c:9503 cp/cvt.c:1046
+#: tree-cfg.c:9512 cp/cvt.c:1046
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of function declared with attribute warn_unused_result"
 msgid "ignoring return value of function declared with attribute warn_unused_result"
@@ -27474,7 +27496,7 @@
 msgid "stmt volatile flag not up-to-date"
 msgstr ""
 
-#: tree-ssa-strlen.c:1975
+#: tree-ssa-strlen.c:1999
 msgid "%G%qD output truncated before terminating nul copying %E byte from a string of the same length"
 msgid_plural "%G%qD output truncated before terminating nul copying %E bytes from a string of the same length"
 msgstr[0] ""
@@ -27482,7 +27504,7 @@
 msgstr[2] ""
 msgstr[3] ""
 
-#: tree-ssa-strlen.c:1989
+#: tree-ssa-strlen.c:2013
 msgid "%G%qD output truncated copying %E byte from a string of length %wu"
 msgid_plural "%G%qD output truncated copying %E bytes from a string of length %wu"
 msgstr[0] ""
@@ -27490,11 +27512,11 @@
 msgstr[2] ""
 msgstr[3] ""
 
-#: tree-ssa-strlen.c:1996
+#: tree-ssa-strlen.c:2020
 msgid "%G%qD output truncated copying between %wu and %wu bytes from a string of length %wu"
 msgstr ""
 
-#: tree-ssa-strlen.c:2008
+#: tree-ssa-strlen.c:2032
 msgid "%G%qD output may be truncated copying %E byte from a string of length %wu"
 msgid_plural "%G%qD output may be truncated copying %E bytes from a string of length %wu"
 msgstr[0] ""
@@ -27502,25 +27524,25 @@
 msgstr[2] ""
 msgstr[3] ""
 
-#: tree-ssa-strlen.c:2015 tree-ssa-strlen.c:2029
+#: tree-ssa-strlen.c:2039 tree-ssa-strlen.c:2053
 msgid "%G%qD output may be truncated copying between %wu and %wu bytes from a string of length %wu"
 msgstr ""
 
-#: tree-ssa-strlen.c:2150
+#: tree-ssa-strlen.c:2174
 msgid "%G%qD output truncated before terminating nul copying as many bytes from a string as its length"
 msgstr ""
 
-#: tree-ssa-strlen.c:2156
+#: tree-ssa-strlen.c:2180
 msgid "%G%qD specified bound depends on the length of the source argument"
 msgstr ""
 
-#: tree-ssa-strlen.c:2163
+#: tree-ssa-strlen.c:2187
 #, fuzzy, gcc-internal-format
 #| msgid "length modifier"
 msgid "length computed here"
 msgstr "модификатор дужине"
 
-#: tree-ssa-uninit.c:191 varasm.c:331
+#: tree-ssa-uninit.c:191 varasm.c:342
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qD was declared here"
 msgid "%qD was declared here"
@@ -27702,27 +27724,27 @@
 msgid "target specific builtin not available"
 msgstr ""
 
-#: tree-vect-generic.c:287
+#: tree-vect-generic.c:283
 #, gcc-internal-format
 msgid "vector operation will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-generic.c:290
+#: tree-vect-generic.c:286
 #, gcc-internal-format
 msgid "vector operation will be expanded in parallel"
 msgstr ""
 
-#: tree-vect-generic.c:341
+#: tree-vect-generic.c:337
 #, gcc-internal-format
 msgid "vector operation will be expanded with a single scalar operation"
 msgstr ""
 
-#: tree-vect-generic.c:941
+#: tree-vect-generic.c:937
 #, gcc-internal-format
 msgid "vector condition will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-generic.c:1373
+#: tree-vect-generic.c:1369
 #, gcc-internal-format
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr ""
@@ -27732,29 +27754,29 @@
 msgid "vectorization did not happen for a simd loop"
 msgstr ""
 
-#: tree-vrp.c:4930 tree-vrp.c:4974
+#: tree-vrp.c:4931 tree-vrp.c:4975
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "array subscript %E is above array bounds of %qT"
 msgstr "индекс низа није целобројан"
 
-#: tree-vrp.c:4956
+#: tree-vrp.c:4957
 #, gcc-internal-format
 msgid "array subscript [%E, %E] is outside array bounds of %qT"
 msgstr ""
 
-#: tree-vrp.c:4988
+#: tree-vrp.c:4989
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "array subscript %E is below array bounds of %qT"
 msgstr "индекс низа није целобројан"
 
-#: tree-vrp.c:5046
+#: tree-vrp.c:5047
 #, gcc-internal-format
 msgid "array subscript %wi is below array bounds of %qT"
 msgstr ""
 
-#: tree-vrp.c:5060
+#: tree-vrp.c:5061
 #, gcc-internal-format
 msgid "array subscript %wu is above array bounds of %qT"
 msgstr ""
@@ -27769,99 +27791,99 @@
 msgid "side-effects element in no-side-effects CONSTRUCTOR"
 msgstr ""
 
-#: tree.c:7852
+#: tree.c:7856
 #, gcc-internal-format
 msgid "arrays of functions are not meaningful"
 msgstr "низови функција немају смисла"
 
-#: tree.c:8019
+#: tree.c:8023
 #, gcc-internal-format
 msgid "function return type cannot be function"
 msgstr "повратни тип функције не може бити функција"
 
-#: tree.c:9327 tree.c:9412 tree.c:9473
+#: tree.c:9331 tree.c:9416 tree.c:9477
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: %s, have %s in %s, at %s:%d"
 msgstr "провера стабла: %s, имам %s у %s, код %s:%d"
 
-#: tree.c:9364
+#: tree.c:9368
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected none of %s, have %s in %s, at %s:%d"
 msgstr "провера стабла: не очекивах ниједно од %s, имам %s у %s, код %s:%d"
 
-#: tree.c:9377
+#: tree.c:9381
 #, gcc-internal-format
 msgid "tree check: expected class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "провера стабла: очекивах класу %qs, имам %qs (%s) у %s, код %s:%d"
 
-#: tree.c:9426
+#: tree.c:9430
 #, gcc-internal-format
 msgid "tree check: did not expect class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "провера стабла: нисам очекивао класу %qs, имам %qs (%s) у %s, код %s:%d"
 
-#: tree.c:9439
+#: tree.c:9443
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected omp_clause %s, have %s in %s, at %s:%d"
 msgstr "провера стабла: очекивах omp_clause %s, имам %s у %s, код %s:%d"
 
-#: tree.c:9499
+#: tree.c:9503
 #, fuzzy, gcc-internal-format
 #| msgid "tree check: expected tree that contains %qs structure, have %qs  in %s, at %s:%d"
 msgid "tree check: expected tree that contains %qs structure, have %qs in %s, at %s:%d"
 msgstr "провера стабла: очекивах стабло које садржи структуру %qs, имам %qs у %s, код %s:%d"
 
-#: tree.c:9513
+#: tree.c:9517
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "tree check: accessed elt %d of tree_vec with %d elts in %s, at %s:%d"
 msgid "tree check: accessed elt %d of tree_int_cst with %d elts in %s, at %s:%d"
 msgstr "провера стабла: приступих елту %d у tree_vec са %d елтова у %s, код %s:%d"
 
-#: tree.c:9525
+#: tree.c:9529
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_vec with %d elts in %s, at %s:%d"
 msgstr "провера стабла: приступих елту %d у tree_vec са %d елтова у %s, код %s:%d"
 
-#: tree.c:9538
+#: tree.c:9542
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of %s with %d operands in %s, at %s:%d"
 msgstr "провера стабла: приступих операнду %d од %s са %d операнада у %s, код %s:%d"
 
-#: tree.c:9551
+#: tree.c:9555
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of omp_clause %s with %d operands in %s, at %s:%d"
 msgstr "провера стабла: приступих операнду %d од omp_clause %s са %d операнада у %s, код %s:%d"
 
-#: tree.c:12446
+#: tree.c:12450
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated"
 msgid "%qD is deprecated: %s"
 msgstr "%qs је превазиђено"
 
-#: tree.c:12449
+#: tree.c:12453
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated"
 msgid "%qD is deprecated"
 msgstr "%qs је превазиђено"
 
-#: tree.c:12473 tree.c:12495
+#: tree.c:12477 tree.c:12499
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated"
 msgid "%qE is deprecated: %s"
 msgstr "%qs је превазиђено"
 
-#: tree.c:12476 tree.c:12498
+#: tree.c:12480 tree.c:12502
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated"
 msgid "%qE is deprecated"
 msgstr "%qs је превазиђено"
 
-#: tree.c:12482 tree.c:12503
+#: tree.c:12486 tree.c:12507
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "type is deprecated"
 msgid "type is deprecated: %s"
 msgstr "тип је превазиђен"
 
-#: tree.c:12485 tree.c:12506
+#: tree.c:12489 tree.c:12510
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr "тип је превазиђен"
@@ -27886,245 +27908,245 @@
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.c:13043
+#: tree.c:13047
 #, gcc-internal-format, gfc-internal-format
 msgid "type variant differs by %s"
 msgstr ""
 
-#: tree.c:13084
+#: tree.c:13088
 #, gcc-internal-format
 msgid "type variant has different TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13086
+#: tree.c:13090
 #, gcc-internal-format
 msgid "type variant's TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13088
+#: tree.c:13092
 #, gcc-internal-format
 msgid "type's TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13108
+#: tree.c:13112
 #, gcc-internal-format
 msgid "type variant with TYPE_ALIAS_SET_KNOWN_P"
 msgstr ""
 
-#: tree.c:13121
+#: tree.c:13125
 #, gcc-internal-format
 msgid "type variant has different TYPE_VFIELD"
 msgstr ""
 
-#: tree.c:13157
+#: tree.c:13161
 #, gcc-internal-format
 msgid "type variant has different TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13159
+#: tree.c:13163
 #, gcc-internal-format
 msgid "type variant's TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13161
+#: tree.c:13165
 #, gcc-internal-format
 msgid "type's TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13199
+#: tree.c:13203
 #, gcc-internal-format
 msgid "type variant has different TYPE_FIELDS"
 msgstr ""
 
-#: tree.c:13201
+#: tree.c:13205
 #, gcc-internal-format
 msgid "first mismatch is field"
 msgstr ""
 
-#: tree.c:13203
+#: tree.c:13207
 #, gcc-internal-format
 msgid "and field"
 msgstr ""
 
-#: tree.c:13220
+#: tree.c:13224
 #, gcc-internal-format
 msgid "type variant has different TREE_TYPE"
 msgstr ""
 
-#: tree.c:13222 tree.c:13233
+#: tree.c:13226 tree.c:13237
 #, gcc-internal-format
 msgid "type variant's TREE_TYPE"
 msgstr ""
 
-#: tree.c:13224 tree.c:13235
+#: tree.c:13228 tree.c:13239
 #, gcc-internal-format
 msgid "type's TREE_TYPE"
 msgstr ""
 
-#: tree.c:13231
+#: tree.c:13235
 #, fuzzy, gcc-internal-format
 #| msgid "assert: %s is assign compatible with %s"
 msgid "type is not compatible with its variant"
 msgstr "тврдња: %s је доделом сагласно са %s"
 
-#: tree.c:13534
+#: tree.c:13538
 #, fuzzy, gcc-internal-format
 #| msgid "environment variable DJGPP not defined"
 msgid "Main variant is not defined"
 msgstr "променљива окружења DJGPP није дефинисана"
 
-#: tree.c:13539
+#: tree.c:13543
 #, gcc-internal-format
 msgid "TYPE_MAIN_VARIANT has different TYPE_MAIN_VARIANT"
 msgstr ""
 
-#: tree.c:13551
+#: tree.c:13555
 #, gcc-internal-format
 msgid "TYPE_CANONICAL has different TYPE_CANONICAL"
 msgstr ""
 
-#: tree.c:13569
+#: tree.c:13573
 #, gcc-internal-format
 msgid "TYPE_CANONICAL is not compatible"
 msgstr ""
 
-#: tree.c:13577
+#: tree.c:13581
 #, gcc-internal-format
 msgid "TYPE_MODE of TYPE_CANONICAL is not compatible"
 msgstr ""
 
-#: tree.c:13583
+#: tree.c:13587
 #, gcc-internal-format
 msgid "TYPE_CANONICAL of main variant is not main variant"
 msgstr ""
 
-#: tree.c:13599
+#: tree.c:13603
 #, gcc-internal-format
 msgid "TYPE_VFIELD is not FIELD_DECL nor TREE_LIST"
 msgstr ""
 
-#: tree.c:13609
+#: tree.c:13613
 #, gcc-internal-format
 msgid "TYPE_NEXT_PTR_TO is not POINTER_TYPE"
 msgstr ""
 
-#: tree.c:13619
+#: tree.c:13623
 #, gcc-internal-format
 msgid "TYPE_NEXT_REF_TO is not REFERENCE_TYPE"
 msgstr ""
 
-#: tree.c:13640
+#: tree.c:13644
 #, gcc-internal-format
 msgid "TYPE_BINFO is not TREE_BINFO"
 msgstr ""
 
-#: tree.c:13646
+#: tree.c:13650
 #, gcc-internal-format
 msgid "TYPE_BINFO type is not TYPE_MAIN_VARIANT"
 msgstr ""
 
-#: tree.c:13657
+#: tree.c:13661
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not record nor union"
 msgstr ""
 
-#: tree.c:13668
+#: tree.c:13672
 #, gcc-internal-format
 msgid "TYPE_OFFSET_BASETYPE is not record nor union"
 msgstr ""
 
-#: tree.c:13686
+#: tree.c:13690
 #, gcc-internal-format
 msgid "TYPE_ARRAY_MAX_SIZE not INTEGER_CST"
 msgstr ""
 
-#: tree.c:13693
+#: tree.c:13697
 #, gcc-internal-format
 msgid "TYPE_MAX_VALUE_RAW non-NULL"
 msgstr ""
 
-#: tree.c:13700
+#: tree.c:13704
 #, gcc-internal-format
 msgid "TYPE_LANG_SLOT_1 (binfo) field is non-NULL"
 msgstr ""
 
-#: tree.c:13716
+#: tree.c:13720
 #, gcc-internal-format
 msgid "Enum value is not CONST_DECL or INTEGER_CST"
 msgstr ""
 
-#: tree.c:13724
+#: tree.c:13728
 #, gcc-internal-format
 msgid "Enum value type is not INTEGER_TYPE nor convertible to the enum"
 msgstr ""
 
-#: tree.c:13731
+#: tree.c:13735
 #, gcc-internal-format
 msgid "Enum value name is not IDENTIFIER_NODE"
 msgstr ""
 
-#: tree.c:13741
+#: tree.c:13745
 #, gcc-internal-format
 msgid "Array TYPE_DOMAIN is not integer type"
 msgstr ""
 
-#: tree.c:13750
+#: tree.c:13754
 #, fuzzy, gcc-internal-format
 #| msgid "field %qs has incomplete type"
 msgid "TYPE_FIELDS defined in incomplete type"
 msgstr "поље %qs има непотпун тип"
 
-#: tree.c:13772
+#: tree.c:13776
 #, gcc-internal-format
 msgid "Wrong tree in TYPE_FIELDS list"
 msgstr ""
 
-#: tree.c:13787
+#: tree.c:13791
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is %i while TYPE_CACHED_VALUES is %p"
 msgstr ""
 
-#: tree.c:13793
+#: tree.c:13797
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES is not TREE_VEC"
 msgstr ""
 
-#: tree.c:13806
+#: tree.c:13810
 #, gcc-internal-format
 msgid "wrong TYPE_CACHED_VALUES entry"
 msgstr ""
 
-#: tree.c:13819
+#: tree.c:13823
 #, gcc-internal-format
 msgid "TREE_PURPOSE is non-NULL in TYPE_ARG_TYPES list"
 msgstr ""
 
-#: tree.c:13825
+#: tree.c:13829
 #, gcc-internal-format
 msgid "Wrong entry in TYPE_ARG_TYPES list"
 msgstr ""
 
-#: tree.c:13832
+#: tree.c:13836
 #, gcc-internal-format
 msgid "TYPE_VALUES_RAW field is non-NULL"
 msgstr ""
 
-#: tree.c:13844
+#: tree.c:13848
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is set while it should not"
 msgstr ""
 
-#: tree.c:13850
+#: tree.c:13854
 #, gcc-internal-format
 msgid "TYPE_STRING_FLAG is set on wrong type code"
 msgstr ""
 
-#: tree.c:13860
+#: tree.c:13864
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not main variant"
 msgstr ""
 
-#: tree.c:13867
+#: tree.c:13871
 #, fuzzy, gcc-internal-format
 #| msgid "verify_eh_tree failed"
 msgid "verify_type failed"
@@ -28152,198 +28174,198 @@
 msgid "corrupted value profile: %s profile counter (%d out of %d) inconsistent with basic-block count (%d)"
 msgstr "%HИскварена вредност профила: укупни број профилизатора %s (%d) не поклапа се са бројем об. (%d)"
 
-#: var-tracking.c:7166
+#: var-tracking.c:7184
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded with -fvar-tracking-assignments, retrying without"
 msgstr ""
 
-#: var-tracking.c:7170
+#: var-tracking.c:7188
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded"
 msgstr ""
 
-#: varasm.c:326
+#: varasm.c:337
 #, fuzzy, gcc-internal-format
 #| msgid "%+D causes a section type conflict"
 msgid "%+qD causes a section type conflict with %qD"
 msgstr "%+D изазива сукоб типа одељка"
 
-#: varasm.c:329
+#: varasm.c:340
 #, fuzzy, gcc-internal-format
 #| msgid "  conflict with %q+D"
 msgid "section type conflict with %qD"
 msgstr "  коси се са %q+D"
 
-#: varasm.c:334
+#: varasm.c:345
 #, fuzzy, gcc-internal-format
 #| msgid "%+D causes a section type conflict"
 msgid "%+qD causes a section type conflict"
 msgstr "%+D изазива сукоб типа одељка"
 
-#: varasm.c:336
+#: varasm.c:347
 #, fuzzy, gcc-internal-format
 #| msgid "%+D causes a section type conflict"
 msgid "section type conflict"
 msgstr "%+D изазива сукоб типа одељка"
 
-#: varasm.c:1019
+#: varasm.c:1030
 #, fuzzy, gcc-internal-format
 #| msgid "alignment of %q+D is greater than maximum object file alignment.  Using %d"
 msgid "alignment of %q+D is greater than maximum object file alignment %d"
 msgstr "равнање за %q+D веће је од највећег равнања објектне датотеке.  Користим %d"
 
-#: varasm.c:1172
+#: varasm.c:1183
 #, fuzzy, gcc-internal-format
 #| msgid "Put zero initialized data in the bss section"
 msgid "only zero initializers are allowed in section %qs"
 msgstr "Стави податке успостављене на нулу у одељак bss"
 
-#: varasm.c:1378 varasm.c:1387
+#: varasm.c:1389 varasm.c:1398
 #, gcc-internal-format
 msgid "register name not specified for %q+D"
 msgstr "име регистра није наведено за %q+D"
 
-#: varasm.c:1389
+#: varasm.c:1400
 #, gcc-internal-format
 msgid "invalid register name for %q+D"
 msgstr "неисправно име регистра за %q+D"
 
-#: varasm.c:1391
+#: varasm.c:1402
 #, gcc-internal-format
 msgid "data type of %q+D isn%'t suitable for a register"
 msgstr "тип податка за %q+D није погодан за регистар"
 
-#: varasm.c:1394
+#: varasm.c:1405
 #, fuzzy, gcc-internal-format
 #| msgid "register specified for %q+D isn%'t suitable for data type"
 msgid "the register specified for %q+D cannot be accessed by the current target"
 msgstr "регистар наведен за %q+D није погодан за тип податка"
 
-#: varasm.c:1397
+#: varasm.c:1408
 #, fuzzy, gcc-internal-format
 #| msgid "register used for two global register variables"
 msgid "the register specified for %q+D is not general enough to be used as a register variable"
 msgstr "регистар се користи за две глобалне регистарске променљиве"
 
-#: varasm.c:1400
+#: varasm.c:1411
 #, gcc-internal-format
 msgid "register specified for %q+D isn%'t suitable for data type"
 msgstr "регистар наведен за %q+D није погодан за тип податка"
 
-#: varasm.c:1410
+#: varasm.c:1421
 #, gcc-internal-format
 msgid "global register variable has initial value"
 msgstr "глобална регистарска променљива има почетну вредност"
 
-#: varasm.c:1414
+#: varasm.c:1425
 #, gcc-internal-format
 msgid "optimization may eliminate reads and/or writes to register variables"
 msgstr "оптимизација може уклонити читања и/или писања у регистарске променљиве"
 
-#: varasm.c:1460
+#: varasm.c:1471
 #, gcc-internal-format
 msgid "register name given for non-register variable %q+D"
 msgstr "име регистра дато за нерегистарску променљиву %q+D"
 
-#: varasm.c:1870
+#: varasm.c:1881
 #, gcc-internal-format
 msgid "Patchable function entry > size"
 msgstr ""
 
-#: varasm.c:2069
+#: varasm.c:2080
 #, gcc-internal-format
 msgid "thread-local COMMON data not implemented"
 msgstr "нитно-локални COMMON подаци нису имплементирани"
 
-#: varasm.c:2102
+#: varasm.c:2113
 #, gcc-internal-format
 msgid "requested alignment for %q+D is greater than implemented alignment of %wu"
 msgstr "захтевано равнање за %q+D веће је од имплементираног равнања за %wu"
 
-#: varasm.c:2205 c/c-decl.c:5027 c/c-parser.c:1534
+#: varasm.c:2216 c/c-decl.c:5027 c/c-parser.c:1534
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t known"
 msgstr "величина складишта за %q+D није позната"
 
-#: varasm.c:4910
+#: varasm.c:4921
 #, fuzzy, gcc-internal-format
 #| msgid "initializer for integer value is too complicated"
 msgid "initializer for integer/fixed-point value is too complicated"
 msgstr "успостављач за целобројну вредност је превише компликован"
 
-#: varasm.c:4915
+#: varasm.c:4926
 #, gcc-internal-format
 msgid "initializer for floating value is not a floating constant"
 msgstr "успостављач за реалну вредност није реална константа"
 
-#: varasm.c:5227
+#: varasm.c:5238
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initial value for member %qs"
 msgid "invalid initial value for member %qE"
 msgstr "неисправна почетна вредност за члан %qs"
 
-#: varasm.c:5487
+#: varasm.c:5498
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after being called"
 msgid "%+qD declared weak after being used"
 msgstr "%q+D декларисано уткано пошто је већ позвано"
 
-#: varasm.c:5539
+#: varasm.c:5550
 #, fuzzy, gcc-internal-format
 #| msgid "weak declaration of %q+D must precede definition"
 msgid "weak declaration of %q+D being applied to a already existing, static definition"
 msgstr "слаба декларација %q+D мора претходити дефиницији"
 
-#: varasm.c:5575
+#: varasm.c:5586
 #, gcc-internal-format
 msgid "weak declaration of %q+D must be public"
 msgstr "слаба декларација %q+D мора бити јавна"
 
-#: varasm.c:5579
+#: varasm.c:5590
 #, gcc-internal-format
 msgid "weak declaration of %q+D not supported"
 msgstr "слаба декларација %q+D није подржана"
 
-#: varasm.c:5608 varasm.c:5912
+#: varasm.c:5619 varasm.c:5926
 #, gcc-internal-format
 msgid "only weak aliases are supported in this configuration"
 msgstr "само слаби алијаси су подржани у овој конфигурацији"
 
-#: varasm.c:5802
+#: varasm.c:5813
 #, fuzzy, gcc-internal-format
 #| msgid "%Jweakref is not supported in this configuration"
 msgid "weakref is not supported in this configuration"
 msgstr "%Jслаби упућивач није подржан у овој конфигурацији"
 
-#: varasm.c:5834
+#: varasm.c:5846
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "ifunc is not supported on this target"
 msgstr "ограничења стека нису подржана на овом циљу"
 
-#: varasm.c:5892
+#: varasm.c:5904
 #, gcc-internal-format
 msgid "weakref %q+D ultimately targets itself"
 msgstr "слаби упућивач %q+D на крају циља самог себе"
 
-#: varasm.c:5894
+#: varasm.c:5906
 #, gcc-internal-format
 msgid "weakref %q+D must have static linkage"
 msgstr "слаби упућивач %q+D мора имати статичку повезивост"
 
-#: varasm.c:5901
+#: varasm.c:5913
 #, fuzzy, gcc-internal-format
 #| msgid "%Jalias definitions not supported in this configuration"
 msgid "alias definitions not supported in this configuration"
 msgstr "%Jдефиниције алијаса нису подржане у овој конфигурацији"
 
-#: varasm.c:5909
+#: varasm.c:5923
 #, fuzzy, gcc-internal-format
 #| msgid "-m%s not supported in this configuration"
 msgid "ifunc is not supported in this configuration"
 msgstr "-m%s није подржано у овој конфигурацији"
 
-#: varasm.c:6127 config/sol2.c:159 config/i386/winnt.c:265
+#: varasm.c:6141 config/sol2.c:159 config/i386/winnt.c:265
 #, gcc-internal-format
 msgid "visibility attribute not supported in this configuration; ignored"
 msgstr "атрибут видљивости није подржан у овој конфигурацији, игноришем"
@@ -28424,194 +28446,200 @@
 msgid "bytecode stream: tag %s is not in the expected range [%s, %s]"
 msgstr ""
 
-#: c-family/c-attribs.c:529
+#: c-family/c-attribs.c:524
+#, fuzzy, gcc-internal-format
+#| msgid "%qE attribute ignored for %qE"
+msgid "%qE attribute ignored for type %qT"
+msgstr "атрибут %qE се игнорише за %qE"
+
+#: c-family/c-attribs.c:536
 #, gcc-internal-format
 msgid "%qE attribute ignored for field of type %qT"
 msgstr "атрибут %qE се игнорише за поље типа %qT"
 
-#: c-family/c-attribs.c:696
+#: c-family/c-attribs.c:706
 #, fuzzy, gcc-internal-format
 #| msgid "alias argument not a string"
 msgid "no_sanitize argument not a string"
 msgstr "аргумент алијаса није ниска"
 
-#: c-family/c-attribs.c:826 ada/gcc-interface/utils.c:6235
+#: c-family/c-attribs.c:837 ada/gcc-interface/utils.c:6240
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "%qE attribute ignored due to conflict with attribute %qs"
 msgstr "Атрибут %s коси се са атрибутом %s код %L"
 
-#: c-family/c-attribs.c:875
+#: c-family/c-attribs.c:886
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute ignored. Use -fcf-protection option to enable it"
 msgstr "атрибут %qE се игнорише на не-класним типовима"
 
-#: c-family/c-attribs.c:914 c-family/c-attribs.c:920 c-family/c-attribs.c:3388
-#: c-family/c-attribs.c:3423 c-family/c-attribs.c:3429
+#: c-family/c-attribs.c:925 c-family/c-attribs.c:931 c-family/c-attribs.c:3399
+#: c-family/c-attribs.c:3434 c-family/c-attribs.c:3440
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "%qE attribute ignored due to conflict with %qs attribute"
 msgstr "Атрибут %s коси се са атрибутом %s код %L"
 
-#: c-family/c-attribs.c:976 brig/brig-lang.c:482 lto/lto-lang.c:288
+#: c-family/c-attribs.c:987 brig/brig-lang.c:482 lto/lto-lang.c:288
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute have effect only on public objects"
 msgid "%qE attribute has no effect on unit local functions"
 msgstr "атрибут %qE има утицаја само у јавним објектима"
 
-#: c-family/c-attribs.c:1130
+#: c-family/c-attribs.c:1141
 #, gcc-internal-format
 msgid "%qE attribute have effect only on public objects"
 msgstr "атрибут %qE има утицаја само у јавним објектима"
 
-#: c-family/c-attribs.c:1159
+#: c-family/c-attribs.c:1170
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to variables"
 msgid "%qE attribute only affects top level objects"
 msgstr "атрибут %qs примењује се само на променљиве"
 
-#: c-family/c-attribs.c:1198 c-family/c-attribs.c:2682
+#: c-family/c-attribs.c:1209 c-family/c-attribs.c:2693
 #, fuzzy, gcc-internal-format
 #| msgid "%<return%> with a value, in function returning void"
 msgid "%qE attribute on function returning %<void%>"
 msgstr "%<return%> са вредношћу у функцији која враћа празан тип"
 
-#: c-family/c-attribs.c:1221 c-family/c-pragma.c:419
+#: c-family/c-attribs.c:1232 c-family/c-pragma.c:419
 #, gcc-internal-format
 msgid "scalar_storage_order is not supported because endianness is not uniform"
 msgstr ""
 
-#: c-family/c-attribs.c:1238
+#: c-family/c-attribs.c:1249
 #, gcc-internal-format
 msgid "scalar_storage_order argument must be one of \"big-endian\" or \"little-endian\""
 msgstr ""
 
-#: c-family/c-attribs.c:1334
+#: c-family/c-attribs.c:1345
 #, fuzzy, gcc-internal-format
 #| msgid "trampolines not supported"
 msgid "destructor priorities are not supported"
 msgstr "трамполине нису подржане"
 
-#: c-family/c-attribs.c:1336
+#: c-family/c-attribs.c:1347
 #, fuzzy, gcc-internal-format
 #| msgid "trampolines not supported"
 msgid "constructor priorities are not supported"
 msgstr "трамполине нису подржане"
 
-#: c-family/c-attribs.c:1358
+#: c-family/c-attribs.c:1369
 #, gcc-internal-format, gfc-internal-format
 msgid "destructor priorities from 0 to %d are reserved for the implementation"
 msgstr ""
 
-#: c-family/c-attribs.c:1363
+#: c-family/c-attribs.c:1374
 #, gcc-internal-format, gfc-internal-format
 msgid "constructor priorities from 0 to %d are reserved for the implementation"
 msgstr ""
 
-#: c-family/c-attribs.c:1371
+#: c-family/c-attribs.c:1382
 #, gcc-internal-format, gfc-internal-format
 msgid "destructor priorities must be integers from 0 to %d inclusive"
 msgstr ""
 
-#: c-family/c-attribs.c:1374
+#: c-family/c-attribs.c:1385
 #, gcc-internal-format, gfc-internal-format
 msgid "constructor priorities must be integers from 0 to %d inclusive"
 msgstr ""
 
-#: c-family/c-attribs.c:1527
+#: c-family/c-attribs.c:1538
 #, fuzzy, gcc-internal-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown machine mode %qE"
 msgstr "непознат машински режим %qs"
 
-#: c-family/c-attribs.c:1557
+#: c-family/c-attribs.c:1568
 #, gcc-internal-format
 msgid "specifying vector types with __attribute__ ((mode)) is deprecated"
 msgstr "превазиђено задавање векторских типова помоћу __attribute__ ((режим))"
 
-#: c-family/c-attribs.c:1560
+#: c-family/c-attribs.c:1571
 #, gcc-internal-format
 msgid "use __attribute__ ((vector_size)) instead"
 msgstr "употребите __attribute__ ((величина_вектора)) уместо тога"
 
-#: c-family/c-attribs.c:1569
+#: c-family/c-attribs.c:1580
 #, gcc-internal-format
 msgid "unable to emulate %qs"
 msgstr "не могу да емулирам %qs"
 
-#: c-family/c-attribs.c:1582
+#: c-family/c-attribs.c:1593
 #, gcc-internal-format
 msgid "invalid pointer mode %qs"
 msgstr "неисправан режим показивача %qs"
 
-#: c-family/c-attribs.c:1599
+#: c-family/c-attribs.c:1610
 #, gcc-internal-format
 msgid "signedness of type and machine mode %qs don%'t match"
 msgstr ""
 
-#: c-family/c-attribs.c:1610
+#: c-family/c-attribs.c:1621
 #, gcc-internal-format
 msgid "no data type for mode %qs"
 msgstr "нема типа података за режим %qs"
 
-#: c-family/c-attribs.c:1620
+#: c-family/c-attribs.c:1631
 #, gcc-internal-format
 msgid "cannot use mode %qs for enumeral types"
 msgstr "не могу да користим режим %qs за бројевне типове"
 
-#: c-family/c-attribs.c:1647
+#: c-family/c-attribs.c:1658
 #, gcc-internal-format
 msgid "mode %qs applied to inappropriate type"
 msgstr "режим %qs примењен на неодговарајући тип"
 
-#: c-family/c-attribs.c:1669
+#: c-family/c-attribs.c:1680
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsection attributes are not supported for this target"
 msgid "section attributes are not supported for this target"
 msgstr "%Jатрибути одељка нису подржани за овај циљ"
 
-#: c-family/c-attribs.c:1675
+#: c-family/c-attribs.c:1686
 #, gcc-internal-format
 msgid "section attribute not allowed for %q+D"
 msgstr "атрибут одељка није допуштен за %q+D"
 
-#: c-family/c-attribs.c:1681
+#: c-family/c-attribs.c:1692
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute argument not a string constant"
 msgid "section attribute argument not a string constant"
 msgstr "аргумент атрибута %qs није константна ниска"
 
-#: c-family/c-attribs.c:1690
+#: c-family/c-attribs.c:1701
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsection attribute cannot be specified for local variables"
 msgid "section attribute cannot be specified for local variables"
 msgstr "%Jатрибут одељка се не може навести за локалне променљиве"
 
-#: c-family/c-attribs.c:1700 config/bfin/bfin.c:4806 config/bfin/bfin.c:4857
+#: c-family/c-attribs.c:1711 config/bfin/bfin.c:4806 config/bfin/bfin.c:4857
 #: config/bfin/bfin.c:4883 config/bfin/bfin.c:4896
 #, gcc-internal-format
 msgid "section of %q+D conflicts with previous declaration"
 msgstr "одељак за %q+D коси се са претходном декларацијом"
 
-#: c-family/c-attribs.c:1708
+#: c-family/c-attribs.c:1719
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D cannot be overloaded"
 msgid "section of %q+D cannot be overridden"
 msgstr "%q+#D не може бити препуњено"
 
-#: c-family/c-attribs.c:1773
+#: c-family/c-attribs.c:1784
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "requested alignment is too large"
 msgid "requested alignment %d is larger than %d"
 msgstr "захтевано равнање је превелико"
 
-#: c-family/c-attribs.c:1866
+#: c-family/c-attribs.c:1877
 #, gcc-internal-format
 msgid "alignment may not be specified for %q+D"
 msgstr "равнање се не може навести за %q+D"
 
-#: c-family/c-attribs.c:1886
+#: c-family/c-attribs.c:1897
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "ignoring attribute %<%E (%u)%> because it conflicts with attribute %<%E (%u)%>"
@@ -28618,316 +28646,316 @@
 msgstr "Атрибут %s коси се са атрибутом %s код %L"
 
 #. Do not error out for attribute warn_if_not_aligned.
-#: c-family/c-attribs.c:1891 c-family/c-attribs.c:1920
+#: c-family/c-attribs.c:1902 c-family/c-attribs.c:1931
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "alignment for %q+D must be at least %d"
 msgstr "Стварни аргумент за ‘%s’ код %L мора бити показивач"
 
-#: c-family/c-attribs.c:1916
+#: c-family/c-attribs.c:1927
 #, gcc-internal-format
 msgid "alignment for %q+D was previously specified as %d and may not be decreased"
 msgstr ""
 
-#: c-family/c-attribs.c:1943
+#: c-family/c-attribs.c:1954
 #, fuzzy, gcc-internal-format
 #| msgid "alignment may not be specified for %q+D"
 msgid "%<warn_if_not_aligned%> may not be specified for %q+D"
 msgstr "равнање се не може навести за %q+D"
 
-#: c-family/c-attribs.c:1986
+#: c-family/c-attribs.c:1997
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "inline function %q+D declared weak"
 msgstr "уграђена функција %q+D декларисана као нефункција"
 
-#: c-family/c-attribs.c:1991
+#: c-family/c-attribs.c:2002
 #, fuzzy, gcc-internal-format
 #| msgid "function %qs cannot be declared %<mutable%>"
 msgid "indirect function %q+D cannot be declared weak"
 msgstr "функција %qs не може бити декларисана %<mutable%>"
 
-#: c-family/c-attribs.c:2015
+#: c-family/c-attribs.c:2026
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to functions"
 msgid "%qE attribute is only applicable on functions"
 msgstr "атрибут %qs примењује се само на функције"
 
-#: c-family/c-attribs.c:2046
+#: c-family/c-attribs.c:2057
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D defined both normally and as an alias"
 msgid "%q+D defined both normally and as %qE attribute"
 msgstr "%q+D дефинисано и нормално и као алијас"
 
-#: c-family/c-attribs.c:2054
+#: c-family/c-attribs.c:2065
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D cannot be declared"
 msgid "weak %q+D cannot be defined %qE"
 msgstr "%q+#D се не може декларисати"
 
-#: c-family/c-attribs.c:2071 c-family/c-attribs.c:2582
+#: c-family/c-attribs.c:2082 c-family/c-attribs.c:2593
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute argument not a string constant"
 msgid "attribute %qE argument not a string"
 msgstr "аргумент атрибута %qs није константна ниска"
 
-#: c-family/c-attribs.c:2106
+#: c-family/c-attribs.c:2117
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after being called"
 msgid "%+qD declared alias after being used"
 msgstr "%q+D декларисано уткано пошто је већ позвано"
 
-#: c-family/c-attribs.c:2108
+#: c-family/c-attribs.c:2119
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after being called"
 msgid "%+qD declared ifunc after being used"
 msgstr "%q+D декларисано уткано пошто је већ позвано"
 
-#: c-family/c-attribs.c:2159
+#: c-family/c-attribs.c:2170
 #, fuzzy, gcc-internal-format
 #| msgid "function %qs cannot be declared %<mutable%>"
 msgid "indirect function %q+D cannot be declared weakref"
 msgstr "функција %qs не може бити декларисана %<mutable%>"
 
-#: c-family/c-attribs.c:2181
+#: c-family/c-attribs.c:2192
 #, fuzzy, gcc-internal-format
 #| msgid "%Jweakref attribute must appear before alias attribute"
 msgid "weakref attribute must appear before alias attribute"
 msgstr "%Jатрибут слабог упућивања мора се јавити пре атрибута алијаса"
 
-#: c-family/c-attribs.c:2193
+#: c-family/c-attribs.c:2204
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after being called"
 msgid "%+qD declared weakref after being used"
 msgstr "%q+D декларисано уткано пошто је већ позвано"
 
-#: c-family/c-attribs.c:2217
+#: c-family/c-attribs.c:2228
 #, gcc-internal-format
 msgid "%qE attribute ignored on non-class types"
 msgstr "атрибут %qE се игнорише на не-класним типовима"
 
-#: c-family/c-attribs.c:2223
+#: c-family/c-attribs.c:2234
 #, gcc-internal-format
 msgid "%qE attribute ignored because %qT is already defined"
 msgstr "атрибут %qE се игнорише јер је %qT већ дефинисан"
 
-#: c-family/c-attribs.c:2236
+#: c-family/c-attribs.c:2247
 #, gcc-internal-format
 msgid "visibility argument not a string"
 msgstr "видљивост аргумента није ниска"
 
-#: c-family/c-attribs.c:2248
+#: c-family/c-attribs.c:2259
 #, gcc-internal-format
 msgid "%qE attribute ignored on types"
 msgstr "атрибут %qE се игнорише на типовима"
 
-#: c-family/c-attribs.c:2264
+#: c-family/c-attribs.c:2275
 #, gcc-internal-format
 msgid "visibility argument must be one of \"default\", \"hidden\", \"protected\" or \"internal\""
 msgstr "аргумент видљивости мора бити једно од „default“, „hidden“, „protected“ или „internal“"
 
-#: c-family/c-attribs.c:2275
+#: c-family/c-attribs.c:2286
 #, gcc-internal-format
 msgid "%qD redeclared with different visibility"
 msgstr "%qD поново декларисано са другачијом видљивошћу"
 
-#: c-family/c-attribs.c:2278 c-family/c-attribs.c:2282
+#: c-family/c-attribs.c:2289 c-family/c-attribs.c:2293
 #, fuzzy, gcc-internal-format
 #| msgid "%qD redeclared with different visibility"
 msgid "%qD was declared %qs which implies default visibility"
 msgstr "%qD поново декларисано са другачијом видљивошћу"
 
-#: c-family/c-attribs.c:2320
+#: c-family/c-attribs.c:2331
 #, gcc-internal-format
 msgid "tls_model argument not a string"
 msgstr "аргумент за tls_model није ниска"
 
-#: c-family/c-attribs.c:2333
+#: c-family/c-attribs.c:2344
 #, gcc-internal-format
 msgid "tls_model argument must be one of \"local-exec\", \"initial-exec\", \"local-dynamic\" or \"global-dynamic\""
 msgstr "аргумент за tls_model мора бити једно од „local-exec“, „initial-exec“, „local-dynamic“ или „global-dynamic“"
 
-#: c-family/c-attribs.c:2353 c-family/c-attribs.c:2656
-#: c-family/c-attribs.c:3497 config/m32c/m32c.c:2944
+#: c-family/c-attribs.c:2364 c-family/c-attribs.c:2667
+#: c-family/c-attribs.c:3508 config/m32c/m32c.c:2944
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qE attribute applies only to functions"
 msgid "%qE attribute applies only to functions"
 msgstr "%Jатрибут %qE примењује се само на функције"
 
-#: c-family/c-attribs.c:2417
+#: c-family/c-attribs.c:2428
 #, gcc-internal-format
 msgid "alloc_size parameter outside range"
 msgstr ""
 
-#: c-family/c-attribs.c:2443
+#: c-family/c-attribs.c:2454
 #, gcc-internal-format
 msgid "alloc_align parameter outside range"
 msgstr ""
 
-#: c-family/c-attribs.c:2467
+#: c-family/c-attribs.c:2478
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute argument not an integer constant"
 msgid "assume_aligned parameter not integer constant"
 msgstr "аргумент атрибута %qs није целобројна константа"
 
-#: c-family/c-attribs.c:2595
+#: c-family/c-attribs.c:2606
 #, gcc-internal-format
 msgid "only %<inbranch%> and %<notinbranch%> flags are allowed for %<__simd__%> attribute"
 msgstr ""
 
-#: c-family/c-attribs.c:2662 c-family/c-attribs.c:3503
+#: c-family/c-attribs.c:2673 c-family/c-attribs.c:3514
 #, fuzzy, gcc-internal-format
 #| msgid "%Jcan%'t set %qE attribute after definition"
 msgid "can%'t set %qE attribute after definition"
 msgstr "%Jатрибут %qE не може се поставити после дефиниције"
 
-#: c-family/c-attribs.c:2727
+#: c-family/c-attribs.c:2738
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored"
 msgid "%qE attribute duplicated"
 msgstr "атрибут %qE се игнорише"
 
-#: c-family/c-attribs.c:2729
+#: c-family/c-attribs.c:2740
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored for %qE"
 msgid "%qE attribute follows %qE"
 msgstr "атрибут %qE се игнорише за %qE"
 
-#: c-family/c-attribs.c:2828
+#: c-family/c-attribs.c:2839
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously declared here"
 msgid "type was previously declared %qE"
 msgstr "%q+#D претходно декларисано овде"
 
-#: c-family/c-attribs.c:2841 cp/class.c:4397
+#: c-family/c-attribs.c:2852 cp/class.c:4401
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
 msgstr "%qs може бити наведено само за функције"
 
-#: c-family/c-attribs.c:2899
+#: c-family/c-attribs.c:2910
 #, fuzzy, gcc-internal-format
 #| msgid "cleanup argument not an identifier"
 msgid "%qE argument not an identifier"
 msgstr "чистачки аргумент није идентификатор"
 
-#: c-family/c-attribs.c:2910
+#: c-family/c-attribs.c:2921
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not declared in %qD"
 msgid "%qD is not compatible with %qD"
 msgstr "%qD није декларисано у %qD"
 
-#: c-family/c-attribs.c:2913
+#: c-family/c-attribs.c:2924
 #, fuzzy, gcc-internal-format
 #| msgid "cleanup argument not a function"
 msgid "%qE argument is not a function"
 msgstr "чистачки аргумент није функција"
 
-#: c-family/c-attribs.c:2961
+#: c-family/c-attribs.c:2972
 #, fuzzy, gcc-internal-format
 #| msgid "requested alignment is not a constant"
 msgid "deprecated message is not a string"
 msgstr "захтевано равнање није константа"
 
-#: c-family/c-attribs.c:3002
+#: c-family/c-attribs.c:3013
 #, gcc-internal-format
 msgid "%qE attribute ignored for %qE"
 msgstr "атрибут %qE се игнорише за %qE"
 
-#: c-family/c-attribs.c:3065
+#: c-family/c-attribs.c:3076
 #, gcc-internal-format
 msgid "invalid vector type for attribute %qE"
 msgstr "неисправан тип вектора за атрибут %qE"
 
-#: c-family/c-attribs.c:3071 ada/gcc-interface/utils.c:3896
+#: c-family/c-attribs.c:3082 ada/gcc-interface/utils.c:3899
 #, gcc-internal-format
 msgid "vector size not an integral multiple of component size"
 msgstr "величина вектора није целобројни умножак величине компоненте"
 
-#: c-family/c-attribs.c:3077 ada/gcc-interface/utils.c:3903
+#: c-family/c-attribs.c:3088 ada/gcc-interface/utils.c:3906
 #, gcc-internal-format
 msgid "zero vector size"
 msgstr "нулта величина вектора"
 
-#: c-family/c-attribs.c:3085
+#: c-family/c-attribs.c:3096
 #, gcc-internal-format
 msgid "number of components of the vector not a power of two"
 msgstr "број компоненти вектора није степен двојке"
 
-#: c-family/c-attribs.c:3118 ada/gcc-interface/utils.c:6092
+#: c-family/c-attribs.c:3129 ada/gcc-interface/utils.c:6098
 #, gcc-internal-format
 msgid "nonnull attribute without arguments on a non-prototype"
 msgstr "ненулти атрибут без аргумената код непрототипа"
 
-#: c-family/c-attribs.c:3137 ada/gcc-interface/utils.c:6106
+#: c-family/c-attribs.c:3148 ada/gcc-interface/utils.c:6112
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument has invalid operand number (argument %lu)"
 msgstr "ненулти аргумент има неисправан број операнада (аргумент %lu)"
 
-#: c-family/c-attribs.c:3159 ada/gcc-interface/utils.c:6128
+#: c-family/c-attribs.c:3170 ada/gcc-interface/utils.c:6134
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument with out-of-range operand number (argument %lu, operand %lu)"
 msgstr "ненулти аргумент са бројем операнада ван опсега (аргумент %lu, операнд %lu)"
 
-#: c-family/c-attribs.c:3168 ada/gcc-interface/utils.c:6137
+#: c-family/c-attribs.c:3179 ada/gcc-interface/utils.c:6143
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument references non-pointer operand (argument %lu, operand %lu)"
 msgstr "ненулти аргумент упућује на непоказивачки операнд (аргумент %lu, операнд %lu)"
 
-#: c-family/c-attribs.c:3208
+#: c-family/c-attribs.c:3219
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored for field of type %qT"
 msgid "%qE attribute ignored on objects of type %qT"
 msgstr "атрибут %qE се игнорише за поље типа %qT"
 
-#: c-family/c-attribs.c:3216
+#: c-family/c-attribs.c:3227
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute does not apply to types"
 msgid "%qE attribute does not apply to functions"
 msgstr "атрибут %qs није примењив на типове"
 
-#: c-family/c-attribs.c:3273
+#: c-family/c-attribs.c:3284
 #, gcc-internal-format
 msgid "cleanup argument not an identifier"
 msgstr "чистачки аргумент није идентификатор"
 
-#: c-family/c-attribs.c:3280
+#: c-family/c-attribs.c:3291
 #, gcc-internal-format
 msgid "cleanup argument not a function"
 msgstr "чистачки аргумент није функција"
 
-#: c-family/c-attribs.c:3317
+#: c-family/c-attribs.c:3328
 #, gcc-internal-format
 msgid "%qE attribute requires prototypes with named arguments"
 msgstr "атрибут %qE захтева прототипове са именованим аргументима"
 
-#: c-family/c-attribs.c:3325
+#: c-family/c-attribs.c:3336
 #, gcc-internal-format
 msgid "%qE attribute only applies to variadic functions"
 msgstr "атрибут %qE је примењив само на варијадичке функције"
 
-#: c-family/c-attribs.c:3341 ada/gcc-interface/utils.c:6179
+#: c-family/c-attribs.c:3352 ada/gcc-interface/utils.c:6185
 #, gcc-internal-format
 msgid "requested position is not an integer constant"
 msgstr "захтевани положај није целобројна константа"
 
-#: c-family/c-attribs.c:3349 ada/gcc-interface/utils.c:6186
+#: c-family/c-attribs.c:3360 ada/gcc-interface/utils.c:6192
 #, gcc-internal-format
 msgid "requested position is less than zero"
 msgstr "захтевани положај је мањи од нуле"
 
-#: c-family/c-attribs.c:3404
+#: c-family/c-attribs.c:3415
 #, gcc-internal-format
 msgid "empty string in attribute %<target%>"
 msgstr ""
 
-#: c-family/c-attribs.c:3520
+#: c-family/c-attribs.c:3531
 #, fuzzy, gcc-internal-format
 #| msgid "return-statement with a value, in function returning 'void'"
 msgid "returns_nonnull attribute on a function not returning a pointer"
 msgstr "наредба враћања са вредношћу, у функцији која враћа ‘void’"
 
-#: c-family/c-attribs.c:3535
+#: c-family/c-attribs.c:3546
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to function types"
 msgid "%qE attribute is only valid on %<struct%> type"
@@ -28974,13 +29002,13 @@
 msgid "__builtin_shuffle argument vector(s) inner type must have the same size as inner type of the mask"
 msgstr ""
 
-#: c-family/c-common.c:1262 c-family/c-warn.c:1194
+#: c-family/c-common.c:1262 c-family/c-warn.c:1202
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT discards qualifiers"
 msgid "unsigned conversion from %qT to %qT changes value from %qE to %qE"
 msgstr "претварање из %qT у %qT одбацује одредбе"
 
-#: c-family/c-common.c:1267 c-family/c-warn.c:1202
+#: c-family/c-common.c:1267 c-family/c-warn.c:1210
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "unsigned conversion from %qT to %qT changes the value of %qE"
@@ -29117,7 +29145,7 @@
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "предлажем заграде око израза употребљеног као истинитосна вредност"
 
-#: c-family/c-common.c:3518 c/c-decl.c:4325 c/c-decl.c:6430 c/c-typeck.c:14177
+#: c-family/c-common.c:3518 c/c-decl.c:4325 c/c-decl.c:6450 c/c-typeck.c:14182
 #, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr "неисправна употреба %<restrict%>"
@@ -29202,7 +29230,7 @@
 msgid "duplicate case value"
 msgstr "удвостручена вредност случаја"
 
-#: c-family/c-common.c:4867 c-family/c-warn.c:2216
+#: c-family/c-common.c:4867 c-family/c-warn.c:2225
 #, fuzzy, gcc-internal-format
 #| msgid "%Jpreviously used here"
 msgid "previously used here"
@@ -29251,217 +29279,217 @@
 msgid "missing sentinel in function call"
 msgstr "недостаје стражар у позиву функције"
 
-#: c-family/c-common.c:5411
+#: c-family/c-common.c:5409
 #, gcc-internal-format, gfc-internal-format
 msgid "null argument where non-null required (argument %lu)"
 msgstr "нулти аргумент где је неопходан ненулти (аргумент %lu)"
 
-#: c-family/c-common.c:5506 c-family/c-common.c:5553
+#: c-family/c-common.c:5504 c-family/c-common.c:5551
 #, gcc-internal-format
 msgid "bad option %qs to attribute %<optimize%>"
 msgstr ""
 
-#: c-family/c-common.c:5509 c-family/c-common.c:5557
+#: c-family/c-common.c:5507 c-family/c-common.c:5555
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operator for %<#pragma omp atomic%>"
 msgid "bad option %qs to pragma %<optimize%>"
 msgstr "неисправан оператор за %<#pragma omp atomic%>"
 
-#: c-family/c-common.c:5589
+#: c-family/c-common.c:5587
 #, gcc-internal-format
 msgid "%<fallthrough%> attribute specified multiple times"
 msgstr ""
 
-#: c-family/c-common.c:5593
+#: c-family/c-common.c:5591
 #, gcc-internal-format
 msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr ""
 
-#: c-family/c-common.c:5733 c-family/c-common.c:6485 c-family/c-common.c:6558
+#: c-family/c-common.c:5731 c-family/c-common.c:6477 c-family/c-common.c:6550
 #: c/c-typeck.c:3555
 #, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr "премало аргумената за функцију %qE"
 
-#: c-family/c-common.c:5738 c-family/c-common.c:6584 c/c-typeck.c:3284
+#: c-family/c-common.c:5736 c-family/c-common.c:6576 c/c-typeck.c:3284
 #, gcc-internal-format
 msgid "too many arguments to function %qE"
 msgstr "превише аргумената за функцију %qE"
 
-#: c-family/c-common.c:5769
+#: c-family/c-common.c:5767
 #, fuzzy, gcc-internal-format
 #| msgid "third argument to %<__builtin_prefetch%> must be a constant"
 msgid "third argument to function %qE must be a constant integer"
 msgstr "трећи аргумент за %<__builtin_prefetch%> мора бити константа"
 
-#: c-family/c-common.c:5794
+#: c-family/c-common.c:5792
 #, gcc-internal-format
 msgid "second argument to function %qE must be a constant integer power of 2 between %qi and %qu bits"
 msgstr ""
 
-#: c-family/c-common.c:5815 c-family/c-common.c:5859
+#: c-family/c-common.c:5813 c-family/c-common.c:5857
 #, fuzzy, gcc-internal-format
 #| msgid "non-floating-point argument to function %qs"
 msgid "non-floating-point argument in call to function %qE"
 msgstr "аргумент који није у покретном зарезу за функцију %qs"
 
-#: c-family/c-common.c:5838
+#: c-family/c-common.c:5836
 #, fuzzy, gcc-internal-format
 #| msgid "non-floating-point argument to function %qs"
 msgid "non-floating-point arguments in call to function %qE"
 msgstr "аргумент који није у покретном зарезу за функцију %qs"
 
-#: c-family/c-common.c:5852
+#: c-family/c-common.c:5850
 #, fuzzy, gcc-internal-format
 #| msgid "non-floating-point argument to function %qs"
 msgid "non-const integer argument %u in call to function %qE"
 msgstr "аргумент који није у покретном зарезу за функцију %qs"
 
-#: c-family/c-common.c:5872
+#: c-family/c-common.c:5870
 #, fuzzy, gcc-internal-format
 #| msgid "non-floating-point argument to function %qs"
 msgid "non-integer argument 3 in call to function %qE"
 msgstr "аргумент који није у покретном зарезу за функцију %qs"
 
-#: c-family/c-common.c:5889 c-family/c-common.c:5925
+#: c-family/c-common.c:5887 c-family/c-common.c:5923
 #, fuzzy, gcc-internal-format
 #| msgid "Argument list function at %L is not allowed in this context"
 msgid "argument %u in call to function %qE does not have integral type"
 msgstr "Функција листе аргумената код %L није дозвољена у овом контексту"
 
-#: c-family/c-common.c:5896
+#: c-family/c-common.c:5894
 #, fuzzy, gcc-internal-format
 #| msgid "Argument list function at %L is not allowed in this context"
 msgid "argument 3 in call to function %qE does not have pointer to integral type"
 msgstr "Функција листе аргумената код %L није дозвољена у овом контексту"
 
-#: c-family/c-common.c:5902
+#: c-family/c-common.c:5900
 #, fuzzy, gcc-internal-format
 #| msgid "call to function %qD which throws incomplete type %q#T"
 msgid "argument 3 in call to function %qE has pointer to enumerated type"
 msgstr "позив функције %qD која баца непотпун тип %q#T"
 
-#: c-family/c-common.c:5908
+#: c-family/c-common.c:5906
 #, gcc-internal-format
 msgid "argument 3 in call to function %qE has pointer to boolean type"
 msgstr ""
 
-#: c-family/c-common.c:5931
+#: c-family/c-common.c:5929
 #, fuzzy, gcc-internal-format
 #| msgid "call to function %qD which throws incomplete type %q#T"
 msgid "argument 3 in call to function %qE has enumerated type"
 msgstr "позив функције %qD која баца непотпун тип %q#T"
 
-#: c-family/c-common.c:5937
+#: c-family/c-common.c:5935
 #, gcc-internal-format
 msgid "argument 3 in call to function %qE has boolean type"
 msgstr ""
 
-#: c-family/c-common.c:6184
+#: c-family/c-common.c:6183
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to static data member %qD"
 msgstr "не могу применити %<offsetof%> на статички члански податак %qD"
 
-#: c-family/c-common.c:6189
+#: c-family/c-common.c:6188
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> when %<operator[]%> is overloaded"
 msgstr "не могу применити %<offsetof%> када је %<operator[]%> препуњен"
 
-#: c-family/c-common.c:6196
+#: c-family/c-common.c:6195
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply %<offsetof%> to member function %qD"
 msgid "cannot apply %<offsetof%> to a non constant address"
 msgstr "не може се применити %<offsetof%> на чланску функцију %qD"
 
-#: c-family/c-common.c:6209
+#: c-family/c-common.c:6208
 #, gcc-internal-format
 msgid "attempt to take address of bit-field structure member %qD"
 msgstr "покушај узимања адресе битског поља %qD у структури"
 
-#: c-family/c-common.c:6261
+#: c-family/c-common.c:6260
 #, gcc-internal-format
 msgid "index %E denotes an offset greater than size of %qT"
 msgstr ""
 
-#: c-family/c-common.c:6427 cp/init.c:3004 cp/init.c:3023
+#: c-family/c-common.c:6419 cp/init.c:3020 cp/init.c:3039
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "size of array is too large"
 msgstr "величина низа %qs је превелика"
 
-#: c-family/c-common.c:6517
+#: c-family/c-common.c:6509
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible type for argument %d of %qE"
 msgid "operand type %qT is incompatible with argument %d of %qE"
 msgstr "несагласни тип за аргумент %d у %qE"
 
-#: c-family/c-common.c:6651
+#: c-family/c-common.c:6643
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %qE"
 msgid "incorrect number of arguments to function %qE"
 msgstr "премало аргумената за функцију %qE"
 
-#: c-family/c-common.c:6665
+#: c-family/c-common.c:6657
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs must be a 2-bit unsigned literal"
 msgid "argument 1 of %qE must be a non-void pointer type"
 msgstr "аргумент за %qs мора бити двобитна неозначена константа"
 
-#: c-family/c-common.c:6674
+#: c-family/c-common.c:6666
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfirst argument of %D must be a pointer, second integer constant"
 msgid "argument 1 of %qE must be a pointer to a constant size type"
 msgstr "%Hпрви аргумент за %D мора бити показивач, а други целобројна константа"
 
-#: c-family/c-common.c:6685
+#: c-family/c-common.c:6677
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfirst argument of %D must be a pointer, second integer constant"
 msgid "argument 1 of %qE must be a pointer to a nonzero size object"
 msgstr "%Hпрви аргумент за %D мора бити показивач, а други целобројна константа"
 
-#: c-family/c-common.c:6706
+#: c-family/c-common.c:6698
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE from incompatible pointer type"
 msgid "argument %d of %qE must be a pointer type"
 msgstr "прослеђивање аргумента %d од %qE из несагласног показивачког типа"
 
-#: c-family/c-common.c:6714
+#: c-family/c-common.c:6706
 #, fuzzy, gcc-internal-format
 #| msgid "argument %d of %qE might be a candidate for a format attribute"
 msgid "argument %d of %qE must be a pointer to a constant size type"
 msgstr "аргумент %d од %qE може бити кандидат за форматски атрибут"
 
-#: c-family/c-common.c:6720
+#: c-family/c-common.c:6712
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE makes integer from pointer without a cast"
 msgid "argument %d of %qE must not be a pointer to a function"
 msgstr "прослеђивање аргумента %d од %qE прави целобројни од показивача без претапања"
 
-#: c-family/c-common.c:6728
+#: c-family/c-common.c:6720
 #, fuzzy, gcc-internal-format
 #| msgid "Type/rank mismatch in argument '%s' at %L"
 msgid "size mismatch in argument %d of %qE"
 msgstr "Неслагање типа/ранга у аргументу ‘%s’ код %L"
 
-#: c-family/c-common.c:6740
+#: c-family/c-common.c:6732
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible type for argument %d of %qE"
 msgid "non-integer memory model argument %d of %qE"
 msgstr "несагласни тип за аргумент %d у %qE"
 
-#: c-family/c-common.c:6753
+#: c-family/c-common.c:6745
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument of %qs"
 msgid "invalid memory model argument %d of %qE"
 msgstr "неисправан аргумент типа за %qs"
 
-#: c-family/c-common.c:7672
+#: c-family/c-common.c:7664
 #, fuzzy, gcc-internal-format
 #| msgid "index in dimension %d is out of bounds at %L"
 msgid "index value is out of bound"
 msgstr "Индекс у димензији %d је ван граница код %L"
 
-#: c-family/c-common.c:7714 c-family/c-common.c:7763 c-family/c-common.c:7779
+#: c-family/c-common.c:7706 c-family/c-common.c:7755 c-family/c-common.c:7771
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "conversion of scalar %qT to vector %qT involves truncation"
@@ -29469,25 +29497,25 @@
 
 #. Reject arguments that are built-in functions with
 #. no library fallback.
-#: c-family/c-common.c:7867
+#: c-family/c-common.c:7859
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D used but never defined"
 msgid "built-in function %qE must be directly called"
 msgstr "уткана функција %q+D употребљена али недефинисана"
 
-#: c-family/c-common.c:7889 c/c-decl.c:6177
+#: c-family/c-common.c:7881 c/c-decl.c:6197
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "size of array %qE is too large"
 msgstr "величина низа %qs је превелика"
 
-#: c-family/c-common.c:7891 c/c-decl.c:6180
+#: c-family/c-common.c:7883 c/c-decl.c:6200
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "size of unnamed array is too large"
 msgstr "величина низа %qs је превелика"
 
-#: c-family/c-common.c:7921
+#: c-family/c-common.c:7913
 #, gcc-internal-format
 msgid "environment variable SOURCE_DATE_EPOCH must expand to a non-negative integer less than or equal to %wd"
 msgstr ""
@@ -30027,7 +30055,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr ""
 
-#: c-family/c-omp.c:557 cp/semantics.c:8186
+#: c-family/c-omp.c:557 cp/semantics.c:8189
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid type for iteration variable %qE"
 msgid "invalid type for iteration variable %qE"
@@ -30045,25 +30073,25 @@
 msgid "%qE is not initialized"
 msgstr "%H%qE није успостављено"
 
-#: c-family/c-omp.c:599 cp/semantics.c:8076
+#: c-family/c-omp.c:599 cp/semantics.c:8079
 #, fuzzy, gcc-internal-format
 #| msgid "%Hmissing controlling predicate"
 msgid "missing controlling predicate"
 msgstr "%Hнедостаје контролишући предикат"
 
-#: c-family/c-omp.c:704 cp/semantics.c:7732
+#: c-family/c-omp.c:704 cp/semantics.c:7735
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid controlling predicate"
 msgid "invalid controlling predicate"
 msgstr "%Hнеисправан контролишући предикат"
 
-#: c-family/c-omp.c:711 cp/semantics.c:8082
+#: c-family/c-omp.c:711 cp/semantics.c:8085
 #, fuzzy, gcc-internal-format
 #| msgid "%Hmissing increment expression"
 msgid "missing increment expression"
 msgstr "%Hнедостаје израз увећања"
 
-#: c-family/c-omp.c:775 cp/semantics.c:7847
+#: c-family/c-omp.c:775 cp/semantics.c:7850
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid increment expression"
 msgid "invalid increment expression"
@@ -30124,118 +30152,133 @@
 msgid "%<-Wabi=1%> is not supported, using =2"
 msgstr "static није подржано на ТПФ-ОСу"
 
-#: c-family/c-opts.c:612 fortran/cpp.c:350
+#: c-family/c-opts.c:610 fortran/cpp.c:350
 #, gcc-internal-format
 msgid "output filename specified twice"
 msgstr "излазна датотека наведена двапут"
 
-#: c-family/c-opts.c:799
+#: c-family/c-opts.c:797
 #, gcc-internal-format
 msgid "-fexcess-precision=standard for C++"
 msgstr ""
 
-#: c-family/c-opts.c:834
+#: c-family/c-opts.c:832
 #, fuzzy, gcc-internal-format
 #| msgid "-fno-gnu89-inline is not supported"
 msgid "-fno-gnu89-inline is only supported in GNU99 or C99 mode"
 msgstr "-fno-gnu89-inline није подржано"
 
-#: c-family/c-opts.c:880
+#: c-family/c-opts.c:878
 #, gcc-internal-format
 msgid "-Wformat-y2k ignored without -Wformat"
 msgstr "-Wformat-y2k се игнорише без -Wformat"
 
-#: c-family/c-opts.c:882
+#: c-family/c-opts.c:880
 #, gcc-internal-format
 msgid "-Wformat-extra-args ignored without -Wformat"
 msgstr "-Wformat-extra-args се игнорише без -Wformat"
 
-#: c-family/c-opts.c:884
+#: c-family/c-opts.c:882
 #, gcc-internal-format
 msgid "-Wformat-zero-length ignored without -Wformat"
 msgstr "-Wformat-zero-length се игнорише без -Wformat"
 
-#: c-family/c-opts.c:886
+#: c-family/c-opts.c:884
 #, gcc-internal-format
 msgid "-Wformat-nonliteral ignored without -Wformat"
 msgstr "-Wformat-nonliteral се игнорише без -Wformat"
 
-#: c-family/c-opts.c:888
+#: c-family/c-opts.c:886
 #, fuzzy, gcc-internal-format
 #| msgid "-Wformat-nonliteral ignored without -Wformat"
 msgid "-Wformat-contains-nul ignored without -Wformat"
 msgstr "-Wformat-nonliteral се игнорише без -Wformat"
 
-#: c-family/c-opts.c:890
+#: c-family/c-opts.c:888
 #, gcc-internal-format
 msgid "-Wformat-security ignored without -Wformat"
 msgstr "-Wformat-security се игнорише без -Wformat"
 
-#: c-family/c-opts.c:928
+#: c-family/c-opts.c:918
 #, gcc-internal-format
 msgid "%<-fabi-compat-version=1%> is not supported, using =2"
 msgstr ""
 
-#: c-family/c-opts.c:988
+#: c-family/c-opts.c:944
+#, gcc-internal-format
+msgid "-Wabi won't warn about anything"
+msgstr ""
+
+#: c-family/c-opts.c:946
+#, gcc-internal-format
+msgid "-Wabi warns about differences from the most up-to-date ABI, which is also used by default"
+msgstr ""
+
+#: c-family/c-opts.c:949
+#, gcc-internal-format
+msgid "use e.g. -Wabi=11 to warn about changes from GCC 7"
+msgstr ""
+
+#: c-family/c-opts.c:1003
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "external TLS initialization functions not supported on this target"
 msgstr "ограничења стека нису подржана на овом циљу"
 
-#: c-family/c-opts.c:1001
+#: c-family/c-opts.c:1016
 #, gcc-internal-format, gfc-internal-format
 msgid "too many filenames given.  Type %s --help for usage"
 msgstr "задато је превише датотека.  Упишите %s --help за употребу"
 
-#: c-family/c-opts.c:1016
+#: c-family/c-opts.c:1031
 #, gcc-internal-format
 msgid "opening output file %s: %m"
 msgstr "отварам улазну датотеку %s: %m"
 
-#: c-family/c-opts.c:1036
+#: c-family/c-opts.c:1051
 #, gcc-internal-format, gfc-internal-format
 msgid "the \"%s\" debug format cannot be used with pre-compiled headers"
 msgstr ""
 
-#: c-family/c-opts.c:1190
+#: c-family/c-opts.c:1205
 #, gcc-internal-format
 msgid "opening dependency file %s: %m"
 msgstr "отварам датотеку зависности %s: %m"
 
-#: c-family/c-opts.c:1201
+#: c-family/c-opts.c:1216
 #, gcc-internal-format
 msgid "closing dependency file %s: %m"
 msgstr "затварам датотеку зависности %s: %m"
 
-#: c-family/c-opts.c:1204
+#: c-family/c-opts.c:1219
 #, gcc-internal-format
 msgid "when writing output to %s: %m"
 msgstr "када уписујем излаз у %s: %m"
 
-#: c-family/c-opts.c:1284
+#: c-family/c-opts.c:1299
 #, gcc-internal-format
 msgid "to generate dependencies you must specify either -M or -MM"
 msgstr "да бисте створили зависности морате навести или -M или -MM"
 
-#: c-family/c-opts.c:1307
+#: c-family/c-opts.c:1322
 #, fuzzy, gcc-internal-format
 #| msgid "-mn is used without -mh or -ms"
 msgid "-MG may only be used with -M or -MM"
 msgstr "-mn се користи без -mh или -ms"
 
-#: c-family/c-opts.c:1340
+#: c-family/c-opts.c:1355
 #, fuzzy, gcc-internal-format
 #| msgid "-findirect-dispatch is incompatible with -freduced-reflection"
 msgid "-fdirectives-only is incompatible with -Wunused_macros"
 msgstr "-findirect-dispatch није сагласно са -freduced-reflection"
 
-#: c-family/c-opts.c:1342
+#: c-family/c-opts.c:1357
 #, fuzzy, gcc-internal-format
 #| msgid "-findirect-dispatch is incompatible with -freduced-reflection"
 msgid "-fdirectives-only is incompatible with -traditional"
 msgstr "-findirect-dispatch није сагласно са -freduced-reflection"
 
-#: c-family/c-opts.c:1534
+#: c-family/c-opts.c:1549
 #, gcc-internal-format
 msgid "too late for # directive to set debug directory"
 msgstr "прекасно за # директиву да постави исправљачки директоријум"
@@ -30644,708 +30687,708 @@
 msgid "wrong type argument to %s"
 msgstr "погрешан тип аргумента за abs"
 
-#: c-family/c-warn.c:53 c-family/c-warn.c:66 cp/constexpr.c:1847
+#: c-family/c-warn.c:54 c-family/c-warn.c:67 cp/constexpr.c:1847
 #: cp/constexpr.c:4099
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "преливање у константном изразу"
 
-#: c-family/c-warn.c:93
+#: c-family/c-warn.c:94
 #, fuzzy, gcc-internal-format
 #| msgid "integer overflow in expression"
 msgid "integer overflow in expression %qE of type %qT results in %qE"
 msgstr "целобројно преливање у изразу"
 
-#: c-family/c-warn.c:95
+#: c-family/c-warn.c:96
 #, fuzzy, gcc-internal-format
 #| msgid "integer overflow in expression"
 msgid "integer overflow in expression of type %qT results in %qE"
 msgstr "целобројно преливање у изразу"
 
-#: c-family/c-warn.c:101
+#: c-family/c-warn.c:102
 #, fuzzy, gcc-internal-format
 #| msgid "floating point overflow in expression"
 msgid "floating point overflow in expression %qE of type %qT results in %qE"
 msgstr "преливање покретног зареза у изразу"
 
-#: c-family/c-warn.c:103
+#: c-family/c-warn.c:104
 #, fuzzy, gcc-internal-format
 #| msgid "floating point overflow in expression"
 msgid "floating point overflow in expression of type %qT results in %qE"
 msgstr "преливање покретног зареза у изразу"
 
-#: c-family/c-warn.c:109
+#: c-family/c-warn.c:110
 #, gcc-internal-format
 msgid "fixed-point overflow in expression %qE of type %qT results in %qE"
 msgstr ""
 
-#: c-family/c-warn.c:111
+#: c-family/c-warn.c:112
 #, fuzzy, gcc-internal-format
 #| msgid "floating point overflow in expression"
 msgid "fixed-point overflow in expression of type %qT results in %qE"
 msgstr "преливање покретног зареза у изразу"
 
-#: c-family/c-warn.c:117
+#: c-family/c-warn.c:118
 #, fuzzy, gcc-internal-format
 #| msgid "vector overflow in expression"
 msgid "vector overflow in expression %qE of type %qT results in %qE"
 msgstr "векторско преливање у изразу"
 
-#: c-family/c-warn.c:119
+#: c-family/c-warn.c:120
 #, fuzzy, gcc-internal-format
 #| msgid "vector overflow in expression"
 msgid "vector overflow in expression of type %qT results in %qE"
 msgstr "векторско преливање у изразу"
 
-#: c-family/c-warn.c:126
+#: c-family/c-warn.c:127
 #, fuzzy, gcc-internal-format
 #| msgid "integer overflow in expression"
 msgid "complex integer overflow in expression %qE of type %qT results in %qE"
 msgstr "целобројно преливање у изразу"
 
-#: c-family/c-warn.c:128
+#: c-family/c-warn.c:129
 #, fuzzy, gcc-internal-format
 #| msgid "integer overflow in expression"
 msgid "complex integer overflow in expression of type %qT results in %qE"
 msgstr "целобројно преливање у изразу"
 
-#: c-family/c-warn.c:132
+#: c-family/c-warn.c:133
 #, fuzzy, gcc-internal-format
 #| msgid "floating point overflow in expression"
 msgid "complex floating point overflow in expression %qE of type %qT results in %qE"
 msgstr "преливање покретног зареза у изразу"
 
-#: c-family/c-warn.c:134
+#: c-family/c-warn.c:135
 #, fuzzy, gcc-internal-format
 #| msgid "floating point overflow in expression"
 msgid "complex floating point overflow in expression of type %qT results in %qE"
 msgstr "преливање покретног зареза у изразу"
 
-#: c-family/c-warn.c:216
+#: c-family/c-warn.c:217
 #, gcc-internal-format
 msgid "logical %<or%> applied to non-boolean constant"
 msgstr ""
 
-#: c-family/c-warn.c:219
+#: c-family/c-warn.c:220
 #, gcc-internal-format
 msgid "logical %<and%> applied to non-boolean constant"
 msgstr ""
 
-#: c-family/c-warn.c:289
+#: c-family/c-warn.c:290
 #, fuzzy, gcc-internal-format
 #| msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgid "logical %<or%> of collectively exhaustive tests is always true"
 msgstr "%<and%> међусобно искључивих тестова једнакости је увек 0"
 
-#: c-family/c-warn.c:293
+#: c-family/c-warn.c:294
 #, fuzzy, gcc-internal-format
 #| msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgid "logical %<and%> of mutually exclusive tests is always false"
 msgstr "%<and%> међусобно искључивих тестова једнакости је увек 0"
 
-#: c-family/c-warn.c:303
+#: c-family/c-warn.c:304
 #, gcc-internal-format
 msgid "logical %<or%> of equal expressions"
 msgstr ""
 
-#: c-family/c-warn.c:306
+#: c-family/c-warn.c:307
 #, gcc-internal-format
 msgid "logical %<and%> of equal expressions"
 msgstr ""
 
-#: c-family/c-warn.c:384
+#: c-family/c-warn.c:385
 #, gcc-internal-format
 msgid "bitwise comparison always evaluates to false"
 msgstr ""
 
-#: c-family/c-warn.c:387
+#: c-family/c-warn.c:388
 #, fuzzy, gcc-internal-format
 #| msgid "the address of %qD will always evaluate as %<true%>"
 msgid "bitwise comparison always evaluates to true"
 msgstr "адреса за %qD ће увек бити израчуната као %<true%>"
 
-#: c-family/c-warn.c:441
+#: c-family/c-warn.c:442
 #, fuzzy, gcc-internal-format
 #| msgid "user-defined %qD always evaluates both arguments"
 msgid "self-comparison always evaluates to true"
 msgstr "кориснички дефинисано %qD увек израчунава оба аргумента"
 
-#: c-family/c-warn.c:444
+#: c-family/c-warn.c:445
 #, fuzzy, gcc-internal-format
 #| msgid "user-defined %qD always evaluates both arguments"
 msgid "self-comparison always evaluates to false"
 msgstr "кориснички дефинисано %qD увек израчунава оба аргумента"
 
-#: c-family/c-warn.c:494
+#: c-family/c-warn.c:495
 #, gcc-internal-format
 msgid "logical not is only applied to the left hand side of comparison"
 msgstr ""
 
-#: c-family/c-warn.c:502
+#: c-family/c-warn.c:503
 #, gcc-internal-format
 msgid "add parentheses around left hand side expression to silence this warning"
 msgstr ""
 
-#: c-family/c-warn.c:636
+#: c-family/c-warn.c:637
 #, gcc-internal-format
 msgid "type-punning to incomplete type might break strict-aliasing rules"
 msgstr "типско преметање у непотпун тип може прекршити правила строге дволичности"
 
-#: c-family/c-warn.c:654
+#: c-family/c-warn.c:655
 #, gcc-internal-format
 msgid "dereferencing type-punned pointer will break strict-aliasing rules"
 msgstr "разрешавање типски преметнутог показивача ће прекршити правила строге дволичности"
 
-#: c-family/c-warn.c:662 c-family/c-warn.c:680
+#: c-family/c-warn.c:663 c-family/c-warn.c:681
 #, gcc-internal-format
 msgid "dereferencing type-punned pointer might break strict-aliasing rules"
 msgstr "разрешавање типски преметнутог показивача може прекршити правила строге дволичности"
 
-#: c-family/c-warn.c:803
+#: c-family/c-warn.c:811
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to use the size of the destination?"
 msgstr ""
 
-#: c-family/c-warn.c:834
+#: c-family/c-warn.c:842
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the destination; did you mean to remove the addressof?"
 msgstr ""
 
-#: c-family/c-warn.c:841
+#: c-family/c-warn.c:849
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the destination; did you mean to provide an explicit length?"
 msgstr ""
 
-#: c-family/c-warn.c:846
+#: c-family/c-warn.c:854
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the destination; did you mean to dereference it?"
 msgstr ""
 
-#: c-family/c-warn.c:858
+#: c-family/c-warn.c:866
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the destination; expected %qT or an explicit length"
 msgstr ""
 
-#: c-family/c-warn.c:874
+#: c-family/c-warn.c:882
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to remove the addressof?"
 msgstr ""
 
-#: c-family/c-warn.c:881
+#: c-family/c-warn.c:889
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to provide an explicit length?"
 msgstr ""
 
-#: c-family/c-warn.c:886
+#: c-family/c-warn.c:894
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to dereference it?"
 msgstr ""
 
-#: c-family/c-warn.c:898
+#: c-family/c-warn.c:906
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the source; expected %qT or an explicit length"
 msgstr ""
 
-#: c-family/c-warn.c:914
+#: c-family/c-warn.c:922
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the first source; did you mean to remove the addressof?"
 msgstr ""
 
-#: c-family/c-warn.c:921
+#: c-family/c-warn.c:929
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the first source; did you mean to provide an explicit length?"
 msgstr ""
 
-#: c-family/c-warn.c:926
+#: c-family/c-warn.c:934
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the first source; did you mean to dereference it?"
 msgstr ""
 
-#: c-family/c-warn.c:938
+#: c-family/c-warn.c:946
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the first source; expected %qT or an explicit length"
 msgstr ""
 
-#: c-family/c-warn.c:954
+#: c-family/c-warn.c:962
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the second source; did you mean to remove the addressof?"
 msgstr ""
 
-#: c-family/c-warn.c:961
+#: c-family/c-warn.c:969
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the second source; did you mean to provide an explicit length?"
 msgstr ""
 
-#: c-family/c-warn.c:966
+#: c-family/c-warn.c:974
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the second source; did you mean to dereference it?"
 msgstr ""
 
-#: c-family/c-warn.c:978
+#: c-family/c-warn.c:986
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the second source; expected %qT or an explicit length"
 msgstr ""
 
-#: c-family/c-warn.c:1007 c-family/c-warn.c:1014
+#: c-family/c-warn.c:1015 c-family/c-warn.c:1022
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter type %qT"
 msgid "%<_Atomic%>-qualified parameter type %qT of %q+D"
 msgstr "неисправан тип параметра %qT"
 
-#: c-family/c-warn.c:1024
+#: c-family/c-warn.c:1032
 #, gcc-internal-format
 msgid "first argument of %q+D should be %<int%>"
 msgstr "први аргумент за %q+D треба да је %<int%>"
 
-#: c-family/c-warn.c:1033
+#: c-family/c-warn.c:1041
 #, gcc-internal-format
 msgid "second argument of %q+D should be %<char **%>"
 msgstr "други аргумент за %q+D треба да је %<char **%>"
 
-#: c-family/c-warn.c:1042
+#: c-family/c-warn.c:1050
 #, gcc-internal-format
 msgid "third argument of %q+D should probably be %<char **%>"
 msgstr "трећи аргумент за %q+D вероватно треба да је %<char **%>"
 
-#: c-family/c-warn.c:1053
+#: c-family/c-warn.c:1061
 #, gcc-internal-format
 msgid "%q+D takes only zero or two arguments"
 msgstr "%q+D прима или ниједан или два аргумента"
 
-#: c-family/c-warn.c:1057
+#: c-family/c-warn.c:1065
 #, fuzzy, gcc-internal-format
 #| msgid "field %qs declared as a function"
 msgid "%q+D declared as variadic function"
 msgstr "поље %qs декларисано као функција"
 
-#: c-family/c-warn.c:1099
+#: c-family/c-warn.c:1107
 #, fuzzy, gcc-internal-format
 #| msgid "converting to %qT from %qT"
 msgid "conversion to %qT from boolean expression"
 msgstr "претварање у %qT из %qT"
 
-#: c-family/c-warn.c:1117 c-family/c-warn.c:1192
+#: c-family/c-warn.c:1125 c-family/c-warn.c:1200
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT discards qualifiers"
 msgid "conversion from %qT to %qT changes value from %qE to %qE"
 msgstr "претварање из %qT у %qT одбацује одредбе"
 
-#: c-family/c-warn.c:1121 c-family/c-warn.c:1200
+#: c-family/c-warn.c:1129 c-family/c-warn.c:1208
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "conversion from %qT to %qT changes the value of %qE"
 msgstr "двосмислено претварање из %qT у %qT"
 
-#: c-family/c-warn.c:1141
+#: c-family/c-warn.c:1149
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT discards qualifiers"
 msgid "conversion from %qT to %qT discards imaginary component"
 msgstr "претварање из %qT у %qT одбацује одредбе"
 
-#: c-family/c-warn.c:1153
+#: c-family/c-warn.c:1161
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "conversion from %qT to %qT may change value"
 msgstr "двосмислено претварање из %qT у %qT"
 
-#: c-family/c-warn.c:1213 c-family/c-warn.c:1230 c-family/c-warn.c:1247
+#: c-family/c-warn.c:1221 c-family/c-warn.c:1238 c-family/c-warn.c:1255
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT discards qualifiers"
 msgid "overflow in conversion from %qT to %qT changes value from %qE to %qE"
 msgstr "претварање из %qT у %qT одбацује одредбе"
 
-#: c-family/c-warn.c:1218 c-family/c-warn.c:1235 c-family/c-warn.c:1252
+#: c-family/c-warn.c:1226 c-family/c-warn.c:1243 c-family/c-warn.c:1260
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "overflow in conversion from %qT to %qT changes the value of %qE"
 msgstr "двосмислено претварање из %qT у %qT"
 
-#: c-family/c-warn.c:1282
+#: c-family/c-warn.c:1290
 #, fuzzy, gcc-internal-format
 #| msgid "%Jcase value %qs not in enumerated type"
 msgid "case value %qs not in enumerated type"
 msgstr "%Jвредност случаја %qs није у набројивом типу"
 
-#: c-family/c-warn.c:1287
+#: c-family/c-warn.c:1295
 #, fuzzy, gcc-internal-format
 #| msgid "%Jcase value %qs not in enumerated type %qT"
 msgid "case value %qs not in enumerated type %qT"
 msgstr "%Jвредност случаја %qs није у набројивом типу %qT"
 
-#: c-family/c-warn.c:1348
+#: c-family/c-warn.c:1356
 #, fuzzy, gcc-internal-format
 #| msgid "%Hswitch missing default case"
 msgid "switch missing default case"
 msgstr "%Hпрекидачу недостаје подразумевани случај"
 
-#: c-family/c-warn.c:1393
+#: c-family/c-warn.c:1401
 #, gcc-internal-format
 msgid "switch condition has boolean value"
 msgstr ""
 
-#: c-family/c-warn.c:1466
+#: c-family/c-warn.c:1474
 #, fuzzy, gcc-internal-format
 #| msgid "%Henumeration value %qE not handled in switch"
 msgid "enumeration value %qE not handled in switch"
 msgstr "%Hнабројива вредност %qE није обрађена у прекидачу"
 
-#: c-family/c-warn.c:1494
+#: c-family/c-warn.c:1502
 #, gcc-internal-format
 msgid "the omitted middle operand in ?: will always be %<true%>, suggest explicit middle operand"
 msgstr ""
 
-#: c-family/c-warn.c:1515
+#: c-family/c-warn.c:1523
 #, fuzzy, gcc-internal-format
 #| msgid "assignment of read-only location"
 msgid "assignment of member %qD in read-only object"
 msgstr "додела само-за-читање локацији"
 
-#: c-family/c-warn.c:1517
+#: c-family/c-warn.c:1525
 #, fuzzy, gcc-internal-format
 #| msgid "increment of read-only location"
 msgid "increment of member %qD in read-only object"
 msgstr "увећање само-за-читање локације"
 
-#: c-family/c-warn.c:1519
+#: c-family/c-warn.c:1527
 #, fuzzy, gcc-internal-format
 #| msgid "decrement of read-only location"
 msgid "decrement of member %qD in read-only object"
 msgstr "умањење само-за-читање локације"
 
-#: c-family/c-warn.c:1521
+#: c-family/c-warn.c:1529
 #, fuzzy, gcc-internal-format
 #| msgid "read-only location used as %<asm%> output"
 msgid "member %qD in read-only object used as %<asm%> output"
 msgstr "само-за-читање локација употребљена као %<asm%> излаз"
 
-#: c-family/c-warn.c:1525
+#: c-family/c-warn.c:1533
 #, gcc-internal-format
 msgid "assignment of read-only member %qD"
 msgstr "додела само-за-читање члану %qD"
 
-#: c-family/c-warn.c:1526
+#: c-family/c-warn.c:1534
 #, gcc-internal-format
 msgid "increment of read-only member %qD"
 msgstr "увећање само-за-читање члана %qD"
 
-#: c-family/c-warn.c:1527
+#: c-family/c-warn.c:1535
 #, gcc-internal-format
 msgid "decrement of read-only member %qD"
 msgstr "умањење само-за-читање члана %qD"
 
-#: c-family/c-warn.c:1528
+#: c-family/c-warn.c:1536
 #, gcc-internal-format
 msgid "read-only member %qD used as %<asm%> output"
 msgstr "само-за-читање члан %qD употребљен као %<asm%> излаз"
 
-#: c-family/c-warn.c:1532
+#: c-family/c-warn.c:1540
 #, gcc-internal-format
 msgid "assignment of read-only variable %qD"
 msgstr "додела само-за-читање променљивој %qD"
 
-#: c-family/c-warn.c:1533
+#: c-family/c-warn.c:1541
 #, gcc-internal-format
 msgid "increment of read-only variable %qD"
 msgstr "увећање само-за-читање променљиве %qD"
 
-#: c-family/c-warn.c:1534
+#: c-family/c-warn.c:1542
 #, gcc-internal-format
 msgid "decrement of read-only variable %qD"
 msgstr "умањење само-за-читање променљиве %qD"
 
-#: c-family/c-warn.c:1535
+#: c-family/c-warn.c:1543
 #, gcc-internal-format
 msgid "read-only variable %qD used as %<asm%> output"
 msgstr "само-за-читање променљива %qD употребљена као %<asm%> излаз"
 
-#: c-family/c-warn.c:1538
+#: c-family/c-warn.c:1546
 #, fuzzy, gcc-internal-format
 #| msgid "assignment of read-only member %qD"
 msgid "assignment of read-only parameter %qD"
 msgstr "додела само-за-читање члану %qD"
 
-#: c-family/c-warn.c:1539
+#: c-family/c-warn.c:1547
 #, fuzzy, gcc-internal-format
 #| msgid "increment of read-only member %qD"
 msgid "increment of read-only parameter %qD"
 msgstr "увећање само-за-читање члана %qD"
 
-#: c-family/c-warn.c:1540
+#: c-family/c-warn.c:1548
 #, fuzzy, gcc-internal-format
 #| msgid "decrement of read-only member %qD"
 msgid "decrement of read-only parameter %qD"
 msgstr "умањење само-за-читање члана %qD"
 
-#: c-family/c-warn.c:1541
+#: c-family/c-warn.c:1549
 #, fuzzy, gcc-internal-format
 #| msgid "read-only member %qD used as %<asm%> output"
 msgid "read-only parameter %qD use as %<asm%> output"
 msgstr "само-за-читање члан %qD употребљен као %<asm%> излаз"
 
-#: c-family/c-warn.c:1546
+#: c-family/c-warn.c:1554
 #, fuzzy, gcc-internal-format
 #| msgid "assignment of read-only variable %qD"
 msgid "assignment of read-only named return value %qD"
 msgstr "додела само-за-читање променљивој %qD"
 
-#: c-family/c-warn.c:1548
+#: c-family/c-warn.c:1556
 #, fuzzy, gcc-internal-format
 #| msgid "increment of read-only variable %qD"
 msgid "increment of read-only named return value %qD"
 msgstr "увећање само-за-читање променљиве %qD"
 
-#: c-family/c-warn.c:1550
+#: c-family/c-warn.c:1558
 #, fuzzy, gcc-internal-format
 #| msgid "decrement of read-only variable %qD"
 msgid "decrement of read-only named return value %qD"
 msgstr "умањење само-за-читање променљиве %qD"
 
-#: c-family/c-warn.c:1552
+#: c-family/c-warn.c:1560
 #, fuzzy, gcc-internal-format
 #| msgid "read-only variable %qD used as %<asm%> output"
 msgid "read-only named return value %qD used as %<asm%>output"
 msgstr "само-за-читање променљива %qD употребљена као %<asm%> излаз"
 
-#: c-family/c-warn.c:1557
+#: c-family/c-warn.c:1565
 #, fuzzy, gcc-internal-format
 #| msgid "assignment of read-only location"
 msgid "assignment of function %qD"
 msgstr "додела само-за-читање локацији"
 
-#: c-family/c-warn.c:1558
+#: c-family/c-warn.c:1566
 #, fuzzy, gcc-internal-format
 #| msgid "increment of read-only location"
 msgid "increment of function %qD"
 msgstr "увећање само-за-читање локације"
 
-#: c-family/c-warn.c:1559
+#: c-family/c-warn.c:1567
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %qs"
 msgid "decrement of function %qD"
 msgstr "премало аргумената за функцију %qs"
 
-#: c-family/c-warn.c:1560
+#: c-family/c-warn.c:1568
 #, fuzzy, gcc-internal-format
 #| msgid "read-only location used as %<asm%> output"
 msgid "function %qD used as %<asm%> output"
 msgstr "само-за-читање локација употребљена као %<asm%> излаз"
 
-#: c-family/c-warn.c:1563 c/c-typeck.c:4762
+#: c-family/c-warn.c:1571 c/c-typeck.c:4767
 #, fuzzy, gcc-internal-format
 #| msgid "assignment of read-only location"
 msgid "assignment of read-only location %qE"
 msgstr "додела само-за-читање локацији"
 
-#: c-family/c-warn.c:1564 c/c-typeck.c:4765
+#: c-family/c-warn.c:1572 c/c-typeck.c:4770
 #, fuzzy, gcc-internal-format
 #| msgid "increment of read-only location"
 msgid "increment of read-only location %qE"
 msgstr "увећање само-за-читање локације"
 
-#: c-family/c-warn.c:1565 c/c-typeck.c:4768
+#: c-family/c-warn.c:1573 c/c-typeck.c:4773
 #, fuzzy, gcc-internal-format
 #| msgid "decrement of read-only location"
 msgid "decrement of read-only location %qE"
 msgstr "умањење само-за-читање локације"
 
-#: c-family/c-warn.c:1566
+#: c-family/c-warn.c:1574
 #, fuzzy, gcc-internal-format
 #| msgid "read-only location used as %<asm%> output"
 msgid "read-only location %qE used as %<asm%> output"
 msgstr "само-за-читање локација употребљена као %<asm%> излаз"
 
-#: c-family/c-warn.c:1580
+#: c-family/c-warn.c:1588
 #, gcc-internal-format
 msgid "lvalue required as left operand of assignment"
 msgstr "неопходна л-вредност као леви операнд у додели"
 
-#: c-family/c-warn.c:1583
+#: c-family/c-warn.c:1591
 #, gcc-internal-format
 msgid "lvalue required as increment operand"
 msgstr "неопходна л-вредност као операнд увећања"
 
-#: c-family/c-warn.c:1586
+#: c-family/c-warn.c:1594
 #, gcc-internal-format
 msgid "lvalue required as decrement operand"
 msgstr "неопходна л-вредност као операнд умањења"
 
-#: c-family/c-warn.c:1589
+#: c-family/c-warn.c:1597
 #, gcc-internal-format
 msgid "lvalue required as unary %<&%> operand"
 msgstr "неопходна л-вредност као операнд унарног %<&%>"
 
-#: c-family/c-warn.c:1592
+#: c-family/c-warn.c:1600
 #, gcc-internal-format
 msgid "lvalue required in asm statement"
 msgstr "неопходна л-вредност у asm наредби"
 
-#: c-family/c-warn.c:1609
+#: c-family/c-warn.c:1617
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument of %qs"
 msgid "invalid type argument (have %qT)"
 msgstr "неисправан аргумент типа за %qs"
 
-#: c-family/c-warn.c:1613
+#: c-family/c-warn.c:1621
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument of %qs"
 msgid "invalid type argument of array indexing (have %qT)"
 msgstr "неисправан аргумент типа за %qs"
 
-#: c-family/c-warn.c:1618
+#: c-family/c-warn.c:1626
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument of %qs"
 msgid "invalid type argument of unary %<*%> (have %qT)"
 msgstr "неисправан аргумент типа за %qs"
 
-#: c-family/c-warn.c:1623
+#: c-family/c-warn.c:1631
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument of %qs"
 msgid "invalid type argument of %<->%> (have %qT)"
 msgstr "неисправан аргумент типа за %qs"
 
-#: c-family/c-warn.c:1628
+#: c-family/c-warn.c:1636
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument of %qs"
 msgid "invalid type argument of %<->*%> (have %qT)"
 msgstr "неисправан аргумент типа за %qs"
 
-#: c-family/c-warn.c:1633
+#: c-family/c-warn.c:1641
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument of %qs"
 msgid "invalid type argument of implicit conversion (have %qT)"
 msgstr "неисправан аргумент типа за %qs"
 
-#: c-family/c-warn.c:1654
+#: c-family/c-warn.c:1662
 #, gcc-internal-format
 msgid "array subscript has type %<char%>"
 msgstr "индекс низа је типа %<char%>"
 
-#: c-family/c-warn.c:1689 c-family/c-warn.c:1692
+#: c-family/c-warn.c:1697 c-family/c-warn.c:1700
 #, fuzzy, gcc-internal-format
 #| msgid "suggest parentheses around + or - inside shift"
 msgid "suggest parentheses around %<+%> inside %<<<%>"
 msgstr "предложи заграде око + или - унутар помака"
 
-#: c-family/c-warn.c:1695 c-family/c-warn.c:1698
+#: c-family/c-warn.c:1703 c-family/c-warn.c:1706
 #, fuzzy, gcc-internal-format
 #| msgid "suggest parentheses around + or - inside shift"
 msgid "suggest parentheses around %<-%> inside %<<<%>"
 msgstr "предложи заграде око + или - унутар помака"
 
-#: c-family/c-warn.c:1704 c-family/c-warn.c:1707
+#: c-family/c-warn.c:1712 c-family/c-warn.c:1715
 #, fuzzy, gcc-internal-format
 #| msgid "suggest parentheses around + or - inside shift"
 msgid "suggest parentheses around %<+%> inside %<>>%>"
 msgstr "предложи заграде око + или - унутар помака"
 
-#: c-family/c-warn.c:1710 c-family/c-warn.c:1713
+#: c-family/c-warn.c:1718 c-family/c-warn.c:1721
 #, fuzzy, gcc-internal-format
 #| msgid "suggest parentheses around + or - inside shift"
 msgid "suggest parentheses around %<-%> inside %<>>%>"
 msgstr "предложи заграде око + или - унутар помака"
 
-#: c-family/c-warn.c:1719 c-family/c-warn.c:1722
+#: c-family/c-warn.c:1727 c-family/c-warn.c:1730
 #, fuzzy, gcc-internal-format
 #| msgid "suggest parentheses around && within ||"
 msgid "suggest parentheses around %<&&%> within %<||%>"
 msgstr "предложи заграде око && унутар ||"
 
-#: c-family/c-warn.c:1729 c-family/c-warn.c:1733
+#: c-family/c-warn.c:1737 c-family/c-warn.c:1741
 #, fuzzy, gcc-internal-format
 #| msgid "suggest parentheses around arithmetic in operand of |"
 msgid "suggest parentheses around arithmetic in operand of %<|%>"
 msgstr "предложи заграде око аритметике у операнду уз |"
 
-#: c-family/c-warn.c:1737 c-family/c-warn.c:1740
+#: c-family/c-warn.c:1745 c-family/c-warn.c:1748
 #, fuzzy, gcc-internal-format
 #| msgid "suggest parentheses around comparison in operand of |"
 msgid "suggest parentheses around comparison in operand of %<|%>"
 msgstr "предложи заграде око поређења у операнду уз |"
 
-#: c-family/c-warn.c:1745
+#: c-family/c-warn.c:1753
 #, gcc-internal-format
 msgid "suggest parentheses around operand of %<!%> or change %<|%> to %<||%> or %<!%> to %<~%>"
 msgstr ""
 
-#: c-family/c-warn.c:1753 c-family/c-warn.c:1757
+#: c-family/c-warn.c:1761 c-family/c-warn.c:1765
 #, fuzzy, gcc-internal-format
 #| msgid "suggest parentheses around arithmetic in operand of ^"
 msgid "suggest parentheses around arithmetic in operand of %<^%>"
 msgstr "предложи заграде око аритметике у операнду уз ^"
 
-#: c-family/c-warn.c:1761 c-family/c-warn.c:1764
+#: c-family/c-warn.c:1769 c-family/c-warn.c:1772
 #, fuzzy, gcc-internal-format
 #| msgid "suggest parentheses around comparison in operand of ^"
 msgid "suggest parentheses around comparison in operand of %<^%>"
 msgstr "предложи заграде око поређења у операнду уз ^"
 
-#: c-family/c-warn.c:1770 c-family/c-warn.c:1773
+#: c-family/c-warn.c:1778 c-family/c-warn.c:1781
 #, fuzzy, gcc-internal-format
 #| msgid "suggest parentheses around + or - in operand of &"
 msgid "suggest parentheses around %<+%> in operand of %<&%>"
 msgstr "предложи заграде око + или - у операнду уз &"
 
-#: c-family/c-warn.c:1776 c-family/c-warn.c:1779
+#: c-family/c-warn.c:1784 c-family/c-warn.c:1787
 #, fuzzy, gcc-internal-format
 #| msgid "suggest parentheses around + or - in operand of &"
 msgid "suggest parentheses around %<-%> in operand of %<&%>"
 msgstr "предложи заграде око + или - у операнду уз &"
 
-#: c-family/c-warn.c:1783 c-family/c-warn.c:1786
+#: c-family/c-warn.c:1791 c-family/c-warn.c:1794
 #, fuzzy, gcc-internal-format
 #| msgid "suggest parentheses around comparison in operand of &"
 msgid "suggest parentheses around comparison in operand of %<&%>"
 msgstr "предложи заграде око поређења у операнду уз &"
 
-#: c-family/c-warn.c:1791
+#: c-family/c-warn.c:1799
 #, gcc-internal-format
 msgid "suggest parentheses around operand of %<!%> or change %<&%> to %<&&%> or %<!%> to %<~%>"
 msgstr ""
 
-#: c-family/c-warn.c:1798 c-family/c-warn.c:1801
+#: c-family/c-warn.c:1806 c-family/c-warn.c:1809
 #, fuzzy, gcc-internal-format
 #| msgid "suggest parentheses around comparison in operand of |"
 msgid "suggest parentheses around comparison in operand of %<==%>"
 msgstr "предложи заграде око поређења у операнду уз |"
 
-#: c-family/c-warn.c:1806 c-family/c-warn.c:1809
+#: c-family/c-warn.c:1814 c-family/c-warn.c:1817
 #, fuzzy, gcc-internal-format
 #| msgid "suggest parentheses around comparison in operand of |"
 msgid "suggest parentheses around comparison in operand of %<!=%>"
 msgstr "предложи заграде око поређења у операнду уз |"
 
-#: c-family/c-warn.c:1819 c-family/c-warn.c:1825
+#: c-family/c-warn.c:1827 c-family/c-warn.c:1833
 #, fuzzy, gcc-internal-format
 #| msgid "comparisons like X<=Y<=Z do not have their mathematical meaning"
 msgid "comparisons like %<X<=Y<=Z%> do not have their mathematical meaning"
 msgstr "поређења као X<=Y<=Z немају своје математичко значење"
 
-#: c-family/c-warn.c:1841
+#: c-family/c-warn.c:1849
 #, gcc-internal-format
 msgid "label %q+D defined but not used"
 msgstr "етикета %q+D дефинисана али неупотребљена"
 
-#: c-family/c-warn.c:1843
+#: c-family/c-warn.c:1851
 #, gcc-internal-format
 msgid "label %q+D declared but not defined"
 msgstr "етикета %q+D декларисана али недефинисана"
 
-#: c-family/c-warn.c:1866
+#: c-family/c-warn.c:1874
 #, gcc-internal-format
 msgid "division by zero"
 msgstr "дељење нулом"
 
-#: c-family/c-warn.c:1886
+#: c-family/c-warn.c:1894
 #, gcc-internal-format
 msgid "%<memset%> used with constant zero length parameter; this could be due to transposed parameters"
 msgstr ""
 
-#: c-family/c-warn.c:1909
+#: c-family/c-warn.c:1918
 #, gcc-internal-format
 msgid "%<memset%> used with length equal to number of elements without multiplication by element size"
 msgstr ""
 
-#: c-family/c-warn.c:1948 c/c-typeck.c:11499 c/c-typeck.c:11667
+#: c-family/c-warn.c:1957 c/c-typeck.c:11504 c/c-typeck.c:11672
 #: cp/typeck.c:5048
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between types %q#T and %q#T"
@@ -31352,79 +31395,79 @@
 msgid "comparison between types %qT and %qT"
 msgstr "поређење између типова %q#T и %q#T"
 
-#: c-family/c-warn.c:1998
+#: c-family/c-warn.c:2007
 #, gcc-internal-format
 msgid "comparison of integer expressions of different signedness: %qT and %qT"
 msgstr ""
 
-#: c-family/c-warn.c:2051
+#: c-family/c-warn.c:2060
 #, gcc-internal-format
 msgid "promoted ~unsigned is always non-zero"
 msgstr ""
 
-#: c-family/c-warn.c:2054
+#: c-family/c-warn.c:2063
 #, gcc-internal-format
 msgid "comparison of promoted ~unsigned with constant"
 msgstr "поређење унапређеног ~неозначеног са константом"
 
-#: c-family/c-warn.c:2064
+#: c-family/c-warn.c:2073
 #, gcc-internal-format
 msgid "comparison of promoted ~unsigned with unsigned"
 msgstr "поређење унапређеног ~неозначеног са неозначеним"
 
-#: c-family/c-warn.c:2118
+#: c-family/c-warn.c:2127
 #, fuzzy, gcc-internal-format
 #| msgid "unused parameter %q+D"
 msgid "unused parameter %qD"
 msgstr "неупотребљен параметар %q+D"
 
-#: c-family/c-warn.c:2180
+#: c-family/c-warn.c:2189
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D defined but not used"
 msgid "typedef %qD locally defined but not used"
 msgstr "%q+D дефинисано али неупотребљено"
 
-#: c-family/c-warn.c:2215
+#: c-family/c-warn.c:2224
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<const%>"
 msgid "duplicated %<if%> condition"
 msgstr "удвостручено %<const%>"
 
-#: c-family/c-warn.c:2244
+#: c-family/c-warn.c:2253
 #, gcc-internal-format
 msgid "optimization attribute on %qD follows definition but the attribute doesn%'t match"
 msgstr ""
 
-#: c-family/c-warn.c:2254
+#: c-family/c-warn.c:2261
 #, fuzzy, gcc-internal-format
 #| msgid "inline declaration of %qD follows declaration with attribute noinline"
 msgid "inline declaration of %qD follows declaration with attribute %qs"
 msgstr "уткана декларација %q+D прати декларацију без атрибута noinline"
 
-#: c-family/c-warn.c:2259
+#: c-family/c-warn.c:2266
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D with attribute noinline follows inline declaration "
 msgid "declaration of %q+D with attribute %qs follows inline declaration"
 msgstr "декларација %q+D са атрибутом noinline прати уткану декларацију "
 
-#: c-family/c-warn.c:2306
+#: c-family/c-warn.c:2313
 #, gcc-internal-format
 msgid "result of %qE requires %u bits to represent, but %qT only has %u bits"
 msgstr ""
 
-#: c-family/c-warn.c:2344 c-family/c-warn.c:2368
+#: c-family/c-warn.c:2351 c-family/c-warn.c:2375
 #, fuzzy, gcc-internal-format
 #| msgid "comparison of unsigned expression < 0 is always false"
 msgid "comparison of constant %qE with boolean expression is always false"
 msgstr "поређење неозначеног израза < 0 је увек тачно"
 
-#: c-family/c-warn.c:2347 c-family/c-warn.c:2365
+#: c-family/c-warn.c:2354 c-family/c-warn.c:2372
 #, fuzzy, gcc-internal-format
 #| msgid "comparison of unsigned expression >= 0 is always true"
 msgid "comparison of constant %qE with boolean expression is always true"
 msgstr "поређење неозначеног израза >= 0 је увек тачно"
 
-#: c-family/c-warn.c:2415
+#: c-family/c-warn.c:2422
 #, fuzzy
 #| msgid "passing argument %d of %qE discards qualifiers from pointer target type"
 msgid "passing argument %i to restrict-qualified parameter aliases with argument %Z"
@@ -31434,17 +31477,17 @@
 msgstr[2] "прослеђивање аргумента %d од %qE одбацује одредбе са циљног типа показивача"
 msgstr[3] "прослеђивање аргумента %d од %qE одбацује одредбе са циљног типа показивача"
 
-#: c-family/c-warn.c:2480 c/c-typeck.c:5288 cp/call.c:5365
+#: c-family/c-warn.c:2487 c/c-typeck.c:5293 cp/call.c:5365
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr ""
 
-#: c-family/c-warn.c:2586
+#: c-family/c-warn.c:2593
 #, gcc-internal-format
 msgid "macro expands to multiple statements"
 msgstr ""
 
-#: c-family/c-warn.c:2587
+#: c-family/c-warn.c:2594
 #, gcc-internal-format
 msgid "some parts of macro expansion are not guarded by this %qs clause"
 msgstr ""
@@ -31460,7 +31503,7 @@
 msgid "too many input files"
 msgstr "превише улазних датотека"
 
-#: common/config/aarch64/aarch64-common.c:319 config/aarch64/aarch64.c:10686
+#: common/config/aarch64/aarch64-common.c:319 config/aarch64/aarch64.c:10702
 #, fuzzy, gcc-internal-format
 #| msgid "bad value %qs for -mcpu switch"
 msgid "unknown value %qs for -mcpu"
@@ -31493,7 +31536,7 @@
 msgstr ""
 
 #: common/config/arm/arm-common.c:322 common/config/arm/arm-common.c:376
-#: common/config/arm/arm-common.c:423 config/aarch64/aarch64.c:10639
+#: common/config/arm/arm-common.c:423 config/aarch64/aarch64.c:10655
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid argument type %qs to %qs"
 msgid "valid arguments are: %s; did you mean %qs?"
@@ -31500,7 +31543,7 @@
 msgstr "Неисправан тип аргумента %qs за %qs"
 
 #: common/config/arm/arm-common.c:325 common/config/arm/arm-common.c:379
-#: common/config/arm/arm-common.c:426 config/aarch64/aarch64.c:10642
+#: common/config/arm/arm-common.c:426 config/aarch64/aarch64.c:10658
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid type argument of %qs"
 msgid "valid arguments are: %s"
@@ -32003,13 +32046,13 @@
 msgid "profiler support for VxWorks"
 msgstr "подршка профилисања за ВиксВоркс"
 
-#: config/aarch64/aarch64-builtins.c:1109 config/arm/arm-builtins.c:2262
+#: config/aarch64/aarch64-builtins.c:1109 config/arm/arm-builtins.c:2272
 #, fuzzy, gcc-internal-format
 #| msgid "argument %qd is not a constant"
 msgid "%Kargument %d must be a constant immediate"
 msgstr "аргумент %qd није константа"
 
-#: config/aarch64/aarch64-builtins.c:1180 config/arm/arm-builtins.c:2492
+#: config/aarch64/aarch64-builtins.c:1180 config/arm/arm-builtins.c:2502
 #, fuzzy, gcc-internal-format
 #| msgid "mask must be an immediate"
 msgid "%Klane index must be a constant immediate"
@@ -32020,186 +32063,186 @@
 msgid "%Ktotal size and element size must be a non-zero constant immediate"
 msgstr ""
 
-#: config/aarch64/aarch64.c:1053
+#: config/aarch64/aarch64.c:1069
 #, fuzzy, gcc-internal-format
 #| msgid "assert: %s is assign compatible with %s"
 msgid "%qs is incompatible with %s %s"
 msgstr "тврдња: %s је доделом сагласно са %s"
 
-#: config/aarch64/aarch64.c:1055
+#: config/aarch64/aarch64.c:1071
 #, fuzzy, gcc-internal-format
 #| msgid "assert: %s is assign compatible with %s"
 msgid "%qs feature modifier is incompatible with %s %s"
 msgstr "тврдња: %s је доделом сагласно са %s"
 
-#: config/aarch64/aarch64.c:3772
+#: config/aarch64/aarch64.c:3788
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10287
+#: config/aarch64/aarch64.c:10303
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown flag passed in -moverride=%s (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10331
+#: config/aarch64/aarch64.c:10347
 #, gcc-internal-format, gfc-internal-format
 msgid "%s string ill-formed\n"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10388
+#: config/aarch64/aarch64.c:10404
 #, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10406
+#: config/aarch64/aarch64.c:10422
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unknown spec function '%s'"
 msgid "unknown tuning option (%s)"
 msgstr "непозната функција навода ‘%s’"
 
-#: config/aarch64/aarch64.c:10683
+#: config/aarch64/aarch64.c:10699
 #, gcc-internal-format
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10690
+#: config/aarch64/aarch64.c:10706
 #, fuzzy, gcc-internal-format
 #| msgid "invalid thread pointer option: -mtp=%s"
 msgid "invalid feature modifier in %<-mcpu=%s%>"
 msgstr "неисправна опција показивача нити: -mtp=%s"
 
-#: config/aarch64/aarch64.c:10717
+#: config/aarch64/aarch64.c:10733
 #, gcc-internal-format
 msgid "missing arch name in %<-march=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10720
+#: config/aarch64/aarch64.c:10736
 #, fuzzy, gcc-internal-format
 #| msgid "Unknown value %qs of -mmacosx-version-min"
 msgid "unknown value %qs for -march"
 msgstr "Непозната вредност %qs за -mmacosx-version-min"
 
-#: config/aarch64/aarch64.c:10724
+#: config/aarch64/aarch64.c:10740
 #, fuzzy, gcc-internal-format
 #| msgid "invalid thread pointer option: -mtp=%s"
 msgid "invalid feature modifier in %<-march=%s%>"
 msgstr "неисправна опција показивача нити: -mtp=%s"
 
-#: config/aarch64/aarch64.c:10750
+#: config/aarch64/aarch64.c:10766
 #, gcc-internal-format
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10753
+#: config/aarch64/aarch64.c:10769
 #, fuzzy, gcc-internal-format
 #| msgid "Unknown value %qs of -mmacosx-version-min"
 msgid "unknown value %qs for -mtune"
 msgstr "Непозната вредност %qs за -mmacosx-version-min"
 
-#: config/aarch64/aarch64.c:10871 config/arm/arm.c:3173
+#: config/aarch64/aarch64.c:10887 config/arm/arm.c:3173
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "switch -mcpu=%s conflicts with -march= switch"
 msgid "switch -mcpu=%s conflicts with -march=%s switch"
 msgstr "прекидач -mcpu=%s коси се са -march="
 
-#: config/aarch64/aarch64.c:10906
+#: config/aarch64/aarch64.c:10922
 #, fuzzy, gcc-internal-format
 #| msgid "does not support multilib"
 msgid "assembler does not support -mabi=ilp32"
 msgstr "не подржава вишебиб"
 
-#: config/aarch64/aarch64.c:10913
+#: config/aarch64/aarch64.c:10929
 #, gcc-internal-format
 msgid "return address signing is only supported for -mabi=lp64"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10975
+#: config/aarch64/aarch64.c:10991
 #, gcc-internal-format
 msgid "code model %qs with -f%s"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11138
+#: config/aarch64/aarch64.c:11154
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11141
+#: config/aarch64/aarch64.c:11157
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11145 config/aarch64/aarch64.c:11184
-#: config/aarch64/aarch64.c:11257
+#: config/aarch64/aarch64.c:11161 config/aarch64/aarch64.c:11200
+#: config/aarch64/aarch64.c:11273
 #, gcc-internal-format
 msgid "invalid value (\"%s\") in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11177
+#: config/aarch64/aarch64.c:11193
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11180
+#: config/aarch64/aarch64.c:11196
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11213
+#: config/aarch64/aarch64.c:11229
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"tune=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11253
+#: config/aarch64/aarch64.c:11269
 #, gcc-internal-format
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11306 config/aarch64/aarch64.c:11483
+#: config/aarch64/aarch64.c:11322 config/aarch64/aarch64.c:11499
 #, fuzzy, gcc-internal-format
 #| msgid "malformed %<#pragma init%>"
 msgid "malformed %<target()%> pragma or attribute"
 msgstr "лоше формирано %<#pragma init%>"
 
-#: config/aarch64/aarch64.c:11354
+#: config/aarch64/aarch64.c:11370
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11362
+#: config/aarch64/aarch64.c:11378
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11416
+#: config/aarch64/aarch64.c:11432
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11473 config/arm/arm.c:30742
-#: config/i386/i386.c:5440 config/powerpcspe/powerpcspe.c:39760
-#: config/rs6000/rs6000.c:36904 config/s390/s390.c:15746
+#: config/aarch64/aarch64.c:11489 config/arm/arm.c:30742
+#: config/i386/i386.c:5443 config/powerpcspe/powerpcspe.c:39760
+#: config/rs6000/rs6000.c:36960 config/s390/s390.c:15746
 #, fuzzy, gcc-internal-format
 #| msgid "alias argument not a string"
 msgid "attribute %<target%> argument not a string"
 msgstr "аргумент алијаса није ниска"
 
-#: config/aarch64/aarch64.c:11500
+#: config/aarch64/aarch64.c:11516
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11509
+#: config/aarch64/aarch64.c:11525
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13571
+#: config/aarch64/aarch64.c:13587
 #, gcc-internal-format
 msgid "%Klane %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13573
+#: config/aarch64/aarch64.c:13589
 #, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr ""
@@ -32260,8 +32303,8 @@
 msgid "bad value %qs for -mmemory-latency"
 msgstr "лоша вредност %qs за -mmemory-latency"
 
-#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6526
-#: config/arc/arc.c:6800 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
+#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6517
+#: config/arc/arc.c:6791 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
 #: config/tilepro/tilepro.c:3108
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -32379,11 +32422,11 @@
 #: config/arm/arm.c:7029 config/avr/avr.c:9718 config/avr/avr.c:9734
 #: config/bfin/bfin.c:4705 config/bfin/bfin.c:4766 config/bfin/bfin.c:4795
 #: config/epiphany/epiphany.c:491 config/h8300/h8300.c:5459
-#: config/i386/i386.c:6452 config/i386/i386.c:12479 config/i386/i386.c:41424
-#: config/i386/i386.c:41474 config/i386/i386.c:41544 config/m68k/m68k.c:780
+#: config/i386/i386.c:6455 config/i386/i386.c:12482 config/i386/i386.c:41418
+#: config/i386/i386.c:41468 config/i386/i386.c:41538 config/m68k/m68k.c:780
 #: config/mcore/mcore.c:3070 config/nvptx/nvptx.c:4611
 #: config/powerpcspe/powerpcspe.c:35785 config/riscv/riscv.c:2698
-#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:32982
+#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:33038
 #: config/rx/rx.c:2719 config/rx/rx.c:2745 config/s390/s390.c:1056
 #: config/s390/s390.c:1143 config/sh/sh.c:8428 config/sh/sh.c:8446
 #: config/sh/sh.c:8470 config/sh/sh.c:8541 config/sh/sh.c:8564
@@ -32394,121 +32437,121 @@
 msgid "%qE attribute only applies to functions"
 msgstr "атрибут %qs примењује се само на функције"
 
-#: config/arc/arc.c:6425
+#: config/arc/arc.c:6416
 #, fuzzy, gcc-internal-format
 #| msgid "%<__builtin_next_arg%> called without an argument"
 msgid "__builtin_arc_aligned with non-constant alignment"
 msgstr "%<__builtin_next_arg%> позвано без аргумената"
 
-#: config/arc/arc.c:6433
+#: config/arc/arc.c:6424
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to %<__builtin_frame_address%>"
 msgid "invalid alignment value for __builtin_arc_aligned"
 msgstr "неисправан аргумент за %<__builtin_frame_address%>"
 
-#: config/arc/arc.c:6596
+#: config/arc/arc.c:6587
 #, gcc-internal-format
 msgid "operand 1 should be an unsigned 3-bit immediate"
 msgstr ""
 
-#: config/arc/arc.c:6637 config/arc/arc.c:6734
+#: config/arc/arc.c:6628 config/arc/arc.c:6725
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6670 config/arc/arc.c:6702
+#: config/arc/arc.c:6661 config/arc/arc.c:6693
 #, gcc-internal-format
 msgid "operand 1 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6674 config/arc/arc.c:6706
+#: config/arc/arc.c:6665 config/arc/arc.c:6697
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 8-bit value"
 msgstr ""
 
-#: config/arc/arc.c:6738
+#: config/arc/arc.c:6729
 #, gcc-internal-format
 msgid "operand 3 should be an unsigned 8-bit value"
 msgstr ""
 
-#: config/arc/arc.c:6771
+#: config/arc/arc.c:6762
 #, gcc-internal-format
 msgid "operand 4 should be an unsigned 8-bit value (0-255)"
 msgstr ""
 
-#: config/arc/arc.c:6775
+#: config/arc/arc.c:6766
 #, gcc-internal-format
 msgid "operand 3 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6782
+#: config/arc/arc.c:6773
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (subreg 0-7)"
 msgstr ""
 
-#: config/arc/arc.c:6785
+#: config/arc/arc.c:6776
 #, gcc-internal-format
 msgid "operand 2 should be an even 3-bit value (subreg 0,2,4,6)"
 msgstr ""
 
-#: config/arc/arc.c:6832
+#: config/arc/arc.c:6823
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "lvalue required as increment operand"
 msgid "builtin requires an immediate for operand %d"
 msgstr "неопходна л-вредност као операнд увећања"
 
-#: config/arc/arc.c:6837
+#: config/arc/arc.c:6828
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "operand %d should be a 6 bit unsigned immediate"
 msgstr "аргумент 2 мора бити петобитна неозначена константа"
 
-#: config/arc/arc.c:6841
+#: config/arc/arc.c:6832
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "operand %d should be a 8 bit unsigned immediate"
 msgstr "аргумент 2 мора бити петобитна неозначена константа"
 
-#: config/arc/arc.c:6845
+#: config/arc/arc.c:6836
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "operand %d should be a 3 bit unsigned immediate"
 msgstr "аргумент 2 мора бити петобитна неозначена константа"
 
-#: config/arc/arc.c:6848
+#: config/arc/arc.c:6839
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown builtin immediate operand type for operand %d"
 msgstr ""
 
-#: config/arc/arc.c:6899
+#: config/arc/arc.c:6890
 #, gcc-internal-format
 msgid "register number must be a compile-time constant. Try giving higher optimization levels"
 msgstr ""
 
-#: config/arc/arc.c:7685
+#: config/arc/arc.c:7747
 #, gcc-internal-format
 msgid "Insn addresses not set after shorten_branches"
 msgstr ""
 
-#: config/arc/arc.c:7894
+#: config/arc/arc.c:7956
 #, fuzzy, gcc-internal-format
 #| msgid "pre-increment address is not a register"
 msgid "insn addresses not freed"
 msgstr "адреса предувећања није регистар"
 
-#: config/arc/arc.c:10682
+#: config/arc/arc.c:10670
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to variables"
 msgid "%qE attribute only valid for ARCv2 architecture"
 msgstr "атрибут %qs примењује се само на променљиве"
 
-#: config/arc/arc.c:10690 config/arc/arc.c:10729
+#: config/arc/arc.c:10678 config/arc/arc.c:10717
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "argument of %qE attribute is missing"
 msgstr "аргумент атрибута %qs није константна ниска"
 
-#: config/arc/arc.c:10701 config/arc/arc.c:10740 config/arc/arc.c:10842
+#: config/arc/arc.c:10689 config/arc/arc.c:10728 config/arc/arc.c:10830
 #: config/avr/avr.c:9790
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
@@ -32515,25 +32558,25 @@
 msgid "%qE attribute allows only an integer constant argument"
 msgstr "атрибут %qs захтева целобројну константу као аргумент"
 
-#: config/arc/arc.c:10721
+#: config/arc/arc.c:10709
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to variables"
 msgid "%qE attribute only valid for ARC EM architecture"
 msgstr "атрибут %qs примењује се само на променљиве"
 
-#: config/arc/arc.c:10776
+#: config/arc/arc.c:10764
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to function types"
 msgid "%qE attribute only applies to types"
 msgstr "атрибут %qs је примењив само на функцијске типове"
 
-#: config/arc/arc.c:10782
+#: config/arc/arc.c:10770
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored"
 msgid "argument of %qE attribute ignored"
 msgstr "атрибут %qE се игнорише"
 
-#: config/arc/arc.c:10832 config/avr/avr.c:9777 config/bfin/bfin.c:4827
+#: config/arc/arc.c:10820 config/avr/avr.c:9777 config/bfin/bfin.c:4827
 #: config/i386/winnt.c:63 config/msp430/msp430.c:2018
 #: config/nvptx/nvptx.c:4634
 #, fuzzy, gcc-internal-format
@@ -32541,175 +32584,175 @@
 msgid "%qE attribute only applies to variables"
 msgstr "атрибут %qs примењује се само на променљиве"
 
-#: config/arm/arm-builtins.c:2370
+#: config/arm/arm-builtins.c:2380
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "this builtin is not supported for this target"
 msgstr "-fdata-sections није подржано за овај циљ"
 
-#: config/arm/arm-builtins.c:2475
+#: config/arm/arm-builtins.c:2485
 #, gcc-internal-format
 msgid "You must enable NEON instructions (e.g. -mfloat-abi=softfp -mfpu=neon) to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2513
+#: config/arm/arm-builtins.c:2523
 #, gcc-internal-format
 msgid "You must enable VFP instructions to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2573
+#: config/arm/arm-builtins.c:2583
 #, gcc-internal-format
 msgid "You must enable crypto instructions (e.g. include -mfloat-abi=softfp -mfpu=crypto-neon...) to use these intrinsics."
 msgstr ""
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:2633 config/arm/arm-builtins.c:2737
+#: config/arm/arm-builtins.c:2643 config/arm/arm-builtins.c:2747
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr "селектор мора бити непосредни"
 
-#: config/arm/arm-builtins.c:2641 config/arm/arm-builtins.c:2686
-#: config/arm/arm-builtins.c:2744 config/arm/arm-builtins.c:2753
+#: config/arm/arm-builtins.c:2651 config/arm/arm-builtins.c:2696
+#: config/arm/arm-builtins.c:2754 config/arm/arm-builtins.c:2763
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2646 config/arm/arm-builtins.c:2755
+#: config/arm/arm-builtins.c:2656 config/arm/arm-builtins.c:2765
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2651 config/arm/arm-builtins.c:2757
+#: config/arm/arm-builtins.c:2661 config/arm/arm-builtins.c:2767
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2823
+#: config/arm/arm-builtins.c:2833
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr "маска мора бити непосредна"
 
-#: config/arm/arm-builtins.c:2828
+#: config/arm/arm-builtins.c:2838
 #, gcc-internal-format
 msgid "the range of mask should be in 0 to 255"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3016
+#: config/arm/arm-builtins.c:3026
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3018
+#: config/arm/arm-builtins.c:3028
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3020
+#: config/arm/arm-builtins.c:3030
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3022
+#: config/arm/arm-builtins.c:3032
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3028
+#: config/arm/arm-builtins.c:3038
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3030
+#: config/arm/arm-builtins.c:3040
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3035
+#: config/arm/arm-builtins.c:3045
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3037
+#: config/arm/arm-builtins.c:3047
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3039
+#: config/arm/arm-builtins.c:3049
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3041
+#: config/arm/arm-builtins.c:3051
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3043
+#: config/arm/arm-builtins.c:3053
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3045
+#: config/arm/arm-builtins.c:3055
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3047
+#: config/arm/arm-builtins.c:3057
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3049
+#: config/arm/arm-builtins.c:3059
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3051
+#: config/arm/arm-builtins.c:3061
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3053
+#: config/arm/arm-builtins.c:3063
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3055
+#: config/arm/arm-builtins.c:3065
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3057
+#: config/arm/arm-builtins.c:3067
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3059
+#: config/arm/arm-builtins.c:3069
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3061
+#: config/arm/arm-builtins.c:3071
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3063
+#: config/arm/arm-builtins.c:3073
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3065
+#: config/arm/arm-builtins.c:3075
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3067
+#: config/arm/arm-builtins.c:3077
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3069
+#: config/arm/arm-builtins.c:3079
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr ""
@@ -33699,18 +33742,18 @@
 msgid "can%'t set position in PCH file: %m"
 msgstr "не могу да поставим положај у ПЦХ датотеци: %m"
 
-#: config/i386/i386.c:3177
+#: config/i386/i386.c:3180
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qs"
 msgid "wrong argument %qs to option %qs"
 msgstr "превише аргумената за функцију %qs"
 
-#: config/i386/i386.c:3183
+#: config/i386/i386.c:3186
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr ""
 
-#: config/i386/i386.c:3193
+#: config/i386/i386.c:3196
 #, fuzzy, gcc-internal-format
 #| msgid "register name not specified for %q+D"
 msgid "wrong strategy name %qs specified for option %qs"
@@ -33717,47 +33760,47 @@
 msgstr "име регистра није наведено за %q+D"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3219
+#: config/i386/i386.c:3222
 #, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386.c:3232
+#: config/i386/i386.c:3235
 #, fuzzy, gcc-internal-format
 #| msgid "alignment may not be specified for %q+D"
 msgid "unknown alignment %qs specified for option %qs"
 msgstr "равнање се не може навести за %q+D"
 
-#: config/i386/i386.c:3242
+#: config/i386/i386.c:3245
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr ""
 
-#: config/i386/i386.c:3249
+#: config/i386/i386.c:3252
 #, fuzzy, gcc-internal-format
 #| msgid "no class name specified with %qs"
 msgid "too many size ranges specified in option %qs"
 msgstr "нема имена класе наведеног помоћу %qs"
 
-#: config/i386/i386.c:3302
+#: config/i386/i386.c:3305
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unknown register name: %s"
 msgid "unknown parameter to option -mtune-ctrl: %s"
 msgstr "непознато име регистра: %s"
 
-#: config/i386/i386.c:3726
+#: config/i386/i386.c:3729
 #, fuzzy, gcc-internal-format
 #| msgid "64-bit ABI not supported in ESA/390 mode"
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "64-битни АБИ није подржан у режиму ЕСЕ/390"
 
-#: config/i386/i386.c:3775
+#: config/i386/i386.c:3778
 #, fuzzy, gcc-internal-format
 #| msgid "-mtune=x86-64 is deprecated.  Use -mtune=k8 or -mtune=generic instead as appropriate."
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "-mtune=x86-64 је превазиђено. Користите -mtune=k8 или -mtune=generic уместо тога."
 
-#: config/i386/i386.c:3777
+#: config/i386/i386.c:3780
 #, fuzzy, gcc-internal-format
 #| msgid "-mtune=x86-64 is deprecated.  Use -mtune=k8 or -mtune=generic instead as appropriate."
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
@@ -33764,546 +33807,546 @@
 msgstr "-mtune=x86-64 је превазиђено. Користите -mtune=k8 или -mtune=generic уместо тога."
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3804
+#: config/i386/i386.c:3807
 #, gcc-internal-format
 msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386.c:3821
+#: config/i386/i386.c:3824
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in the %s bit mode"
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "модела кôда %qs није подржан у %s-битном режиму"
 
-#: config/i386/i386.c:3833
+#: config/i386/i386.c:3836
 #, fuzzy, gcc-internal-format
 #| msgid "profiling not supported with -mg\n"
 msgid "-mabi=ms not supported with X32 ABI"
 msgstr "профилисање није подржано уз -mg\n"
 
-#: config/i386/i386.c:3851 config/i386/i386.c:3860 config/i386/i386.c:3872
-#: config/i386/i386.c:3883 config/i386/i386.c:3894
+#: config/i386/i386.c:3854 config/i386/i386.c:3863 config/i386/i386.c:3875
+#: config/i386/i386.c:3886 config/i386/i386.c:3897
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "модела кôда %qs није подржан у %s-битном режиму"
 
-#: config/i386/i386.c:3863 config/i386/i386.c:3875
+#: config/i386/i386.c:3866 config/i386/i386.c:3878
 #, fuzzy, gcc-internal-format
 #| msgid "code model %s not supported in PIC mode"
 msgid "code model %qs not supported in x32 mode"
 msgstr "модела кôда %s није подржан у ПИЦ режиму"
 
-#: config/i386/i386.c:3881 config/i386/i386.c:3890 config/i386/i386.c:5213
+#: config/i386/i386.c:3884 config/i386/i386.c:3893 config/i386/i386.c:5216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "code model %s not supported in PIC mode"
 msgid "code model %s does not support PIC mode"
 msgstr "модела кôда %s није подржан у ПИЦ режиму"
 
-#: config/i386/i386.c:3918
+#: config/i386/i386.c:3921
 #, fuzzy, gcc-internal-format
 #| msgid "-m%s not supported in this configuration"
 msgid "-masm=intel not supported in this configuration"
 msgstr "-m%s није подржано у овој конфигурацији"
 
-#: config/i386/i386.c:3923
+#: config/i386/i386.c:3926
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "%i-битни режим није укомпилован"
 
-#: config/i386/i386.c:3932
+#: config/i386/i386.c:3935
 #, fuzzy, gcc-internal-format
 #| msgid "generic CPU can be used only for -mtune= switch"
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr "генерички ЦПУ може бити употребљен само за прекидач -mtune="
 
-#: config/i386/i386.c:3934
+#: config/i386/i386.c:3937
 #, fuzzy, gcc-internal-format
 #| msgid "generic CPU can be used only for -mtune= switch"
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "генерички ЦПУ може бити употребљен само за прекидач -mtune="
 
-#: config/i386/i386.c:3941
+#: config/i386/i386.c:3944
 #, fuzzy, gcc-internal-format
 #| msgid "generic CPU can be used only for -mtune= switch"
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr "генерички ЦПУ може бити употребљен само за прекидач -mtune="
 
-#: config/i386/i386.c:3943
+#: config/i386/i386.c:3946
 #, fuzzy, gcc-internal-format
 #| msgid "generic CPU can be used only for -mtune= switch"
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "генерички ЦПУ може бити употребљен само за прекидач -mtune="
 
-#: config/i386/i386.c:3951 config/i386/i386.c:4265
+#: config/i386/i386.c:3954 config/i386/i386.c:4268
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "ЦПУ који сте изабрали не подржава скуп инструкција икс86-64"
 
-#: config/i386/i386.c:4197 config/i386/i386.c:4200
+#: config/i386/i386.c:4200 config/i386/i386.c:4203
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "Intel MPX does not support x32"
 msgstr "%s не подржава %s"
 
-#: config/i386/i386.c:4205
+#: config/i386/i386.c:4208
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "bad value (%qs) for %<-march=%> switch"
 msgstr "лоша вредност (%s) за прекидач -march="
 
-#: config/i386/i386.c:4206
+#: config/i386/i386.c:4209
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "bad value (%qs) for %<target(\"arch=\")%> attribute"
 msgstr "лоша вредност (%s) за прекидач -march="
 
-#: config/i386/i386.c:4228
+#: config/i386/i386.c:4231
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4230
+#: config/i386/i386.c:4233
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4235
+#: config/i386/i386.c:4238
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "лоша вредност (%s) за прекидач -march="
 
-#: config/i386/i386.c:4236
+#: config/i386/i386.c:4239
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "неисправан аргумент за атрибут %qs"
 
-#: config/i386/i386.c:4284
+#: config/i386/i386.c:4287
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -mtune= switch"
 msgid "bad value (%qs) for %<-mtune=%> switch"
 msgstr "лоша вредност (%s) за прекидач -mtune="
 
-#: config/i386/i386.c:4285
+#: config/i386/i386.c:4288
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -mtune= switch"
 msgid "bad value (%qs) for %<target(\"tune=\")%> attribute"
 msgstr "лоша вредност (%s) за прекидач -mtune="
 
-#: config/i386/i386.c:4305
+#: config/i386/i386.c:4308
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4307
+#: config/i386/i386.c:4310
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4312
+#: config/i386/i386.c:4315
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid argument %qs for %<instanceof%>"
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "Неисправан аргумент %qs за %<instanceof%>"
 
-#: config/i386/i386.c:4313
+#: config/i386/i386.c:4316
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "неисправан аргумент за атрибут %qs"
 
-#: config/i386/i386.c:4379
+#: config/i386/i386.c:4382
 #, gcc-internal-format
 msgid "-mregparm is ignored in 64-bit mode"
 msgstr ""
 
-#: config/i386/i386.c:4381
+#: config/i386/i386.c:4384
 #, gcc-internal-format
 msgid "-mregparm is ignored for Intel MCU psABI"
 msgstr ""
 
-#: config/i386/i386.c:4384
+#: config/i386/i386.c:4387
 #, gcc-internal-format, gfc-internal-format
 msgid "-mregparm=%d is not between 0 and %d"
 msgstr "-mregparm=%d није између 0 и %d"
 
-#: config/i386/i386.c:4417
+#: config/i386/i386.c:4420
 #, fuzzy, gcc-internal-format
 #| msgid "-mrtd calling convention not supported in the 64bit mode"
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "конвенција позивања -mrtd није подржана у 64-битном режиму"
 
-#: config/i386/i386.c:4418
+#: config/i386/i386.c:4421
 #, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr ""
 
-#: config/i386/i386.c:4497
+#: config/i386/i386.c:4500
 #, fuzzy, gcc-internal-format
 #| msgid "-fprefetch-loop-arrays not supported for this target"
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "-fprefetch-loop-arrays није подржано за овај циљ"
 
-#: config/i386/i386.c:4500
+#: config/i386/i386.c:4503
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and 12"
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d није између %d и 12"
 
-#: config/i386/i386.c:4523
+#: config/i386/i386.c:4526
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and 12"
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr "-mpreferred-stack-boundary=%d није између %d и 12"
 
-#: config/i386/i386.c:4536
+#: config/i386/i386.c:4539
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "-march=%s није сагласно са изабраним АБИјем"
 
-#: config/i386/i386.c:4539
+#: config/i386/i386.c:4542
 #, fuzzy, gcc-internal-format
 #| msgid "inter-module optimizations not implemented for C++"
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr "унутармодулске оптимизације нису имплеметиране за Ц++"
 
-#: config/i386/i386.c:4545
+#: config/i386/i386.c:4548
 #, fuzzy, gcc-internal-format
 #| msgid "-msseregparm used without SSE enabled"
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "-msseregparm употребљено без укључених ССЕ инструкција"
 
-#: config/i386/i386.c:4546
+#: config/i386/i386.c:4549
 #, fuzzy, gcc-internal-format
 #| msgid "-msseregparm used without SSE enabled"
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "-msseregparm употребљено без укључених ССЕ инструкција"
 
-#: config/i386/i386.c:4556
+#: config/i386/i386.c:4559
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "скуп ССЕ инструкција искључен, користим 387 аритметику"
 
-#: config/i386/i386.c:4563
+#: config/i386/i386.c:4566
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "скуп 387 инструкција искључен, користим ССЕ аритметику"
 
-#: config/i386/i386.c:4613
+#: config/i386/i386.c:4616
 #, fuzzy, gcc-internal-format
 #| msgid "unwind tables currently require either a frame pointer or -maccumulate-outgoing-args for correctness"
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr "табеле одмотавања тренутно захтевају или показивач оквира или -maccumulate-outgoing-args за исправност"
 
-#: config/i386/i386.c:4615
+#: config/i386/i386.c:4618
 #, fuzzy, gcc-internal-format
 #| msgid "unwind tables currently require either a frame pointer or -maccumulate-outgoing-args for correctness"
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr "табеле одмотавања тренутно захтевају или показивач оквира или -maccumulate-outgoing-args за исправност"
 
-#: config/i386/i386.c:4629
+#: config/i386/i386.c:4632
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr ""
 
-#: config/i386/i386.c:4631
+#: config/i386/i386.c:4634
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr ""
 
-#: config/i386/i386.c:4741
+#: config/i386/i386.c:4744
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr ""
 
-#: config/i386/i386.c:4744
+#: config/i386/i386.c:4747
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr ""
 
-#: config/i386/i386.c:4748
+#: config/i386/i386.c:4751
 #, gcc-internal-format
 msgid "-mcall-ms2sysv-xlogues isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386.c:4813 config/powerpcspe/powerpcspe.c:5663
+#: config/i386/i386.c:4816 config/powerpcspe/powerpcspe.c:5663
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unknown -m%s= option specified: '%s'"
 msgid "unknown option for -mrecip=%s"
 msgstr "непозната опција типа -m%s=: „%s“"
 
-#: config/i386/i386.c:4870 config/powerpcspe/powerpcspe.c:5339
+#: config/i386/i386.c:4873 config/powerpcspe/powerpcspe.c:5339
 #, gcc-internal-format
 msgid "%qs is not a valid number in -mstack-protector-guard-offset="
 msgstr ""
 
-#: config/i386/i386.c:4875 config/powerpcspe/powerpcspe.c:5344
+#: config/i386/i386.c:4878 config/powerpcspe/powerpcspe.c:5344
 #, gcc-internal-format
 msgid "%qs is not a valid offset in -mstack-protector-guard-offset="
 msgstr ""
 
-#: config/i386/i386.c:4907 config/powerpcspe/powerpcspe.c:5356
+#: config/i386/i386.c:4910 config/powerpcspe/powerpcspe.c:5356
 #, gcc-internal-format
 msgid "%qs is not a valid base register in -mstack-protector-guard-reg="
 msgstr ""
 
-#: config/i386/i386.c:5506 config/i386/i386.c:5553 config/s390/s390.c:15812
+#: config/i386/i386.c:5509 config/i386/i386.c:5556 config/s390/s390.c:15812
 #: config/s390/s390.c:15862 config/s390/s390.c:15879
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr ""
 
-#: config/i386/i386.c:5534
+#: config/i386/i386.c:5537
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ACCESS specification at %L was already specified"
 msgid "option(\"%s\") was already specified"
 msgstr "Одредница ACCESS код %L је већ наведена "
 
-#: config/i386/i386.c:5837
+#: config/i386/i386.c:5840
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and cdecl attributes are not compatible"
 msgid "interrupt and naked attributes are not compatible"
 msgstr "атрибути stdcall и cdecl нису сагласни"
 
-#: config/i386/i386.c:5852
+#: config/i386/i386.c:5855
 #, gcc-internal-format
 msgid "Only DWARF debug format is supported for interrupt service routine."
 msgstr ""
 
-#: config/i386/i386.c:5901
+#: config/i386/i386.c:5904
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s и -mcall-%s нису сагласни"
 
-#: config/i386/i386.c:5913
+#: config/i386/i386.c:5916
 #, gcc-internal-format
 msgid "%<-mindirect-branch=thunk-extern%>, %<-fcf-protection=branch%> and %<-fcheck-pointer-bounds%> are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5949
+#: config/i386/i386.c:5952
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s и -mcall-%s нису сагласни"
 
-#: config/i386/i386.c:6047
+#: config/i386/i386.c:6050
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "standard conversions are not allowed in this context"
 msgid "%s instructions aren't allowed in %s service routine"
 msgstr "стандардна претварања нису дозвољена у овом контексту"
 
-#: config/i386/i386.c:6051
+#: config/i386/i386.c:6054
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in function with no_caller_saved_registers attribute"
 msgstr ""
 
-#: config/i386/i386.c:6465 config/i386/i386.c:6516
+#: config/i386/i386.c:6468 config/i386/i386.c:6519
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "атрибути fastcall и regparm нису сагласни"
 
-#: config/i386/i386.c:6470
+#: config/i386/i386.c:6473
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "атрибути fastcall и stdcall нису сагласни"
 
-#: config/i386/i386.c:6477 config/i386/i386.c:41444
+#: config/i386/i386.c:6480 config/i386/i386.c:41438
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
 msgid "%qE attribute requires an integer constant argument"
 msgstr "атрибут %qs захтева целобројну константу као аргумент"
 
-#: config/i386/i386.c:6483
+#: config/i386/i386.c:6486
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs attribute larger than %d"
 msgid "argument to %qE attribute larger than %d"
 msgstr "аргумент за атрибут %qs већи од %d"
 
-#: config/i386/i386.c:6508 config/i386/i386.c:6551
+#: config/i386/i386.c:6511 config/i386/i386.c:6554
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "атрибути fastcall и cdecl нису сагласни"
 
-#: config/i386/i386.c:6512
+#: config/i386/i386.c:6515
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "атрибути fastcall и stdcall нису сагласни"
 
-#: config/i386/i386.c:6520 config/i386/i386.c:6569
+#: config/i386/i386.c:6523 config/i386/i386.c:6572
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "атрибути fastcall и stdcall нису сагласни"
 
-#: config/i386/i386.c:6530 config/i386/i386.c:6547
+#: config/i386/i386.c:6533 config/i386/i386.c:6550
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "атрибути stdcall и cdecl нису сагласни"
 
-#: config/i386/i386.c:6534
+#: config/i386/i386.c:6537
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "атрибути stdcall и fastcall нису сагласни"
 
-#: config/i386/i386.c:6538 config/i386/i386.c:6565
+#: config/i386/i386.c:6541 config/i386/i386.c:6568
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and fastcall attributes are not compatible"
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "атрибути stdcall и fastcall нису сагласни"
 
-#: config/i386/i386.c:6555 config/i386/i386.c:6573
+#: config/i386/i386.c:6558 config/i386/i386.c:6576
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and fastcall attributes are not compatible"
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "атрибути stdcall и fastcall нису сагласни"
 
-#: config/i386/i386.c:6561
+#: config/i386/i386.c:6564
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute is used for non-class method"
 msgstr "атрибут %qE се игнорише на не-класним типовима"
 
-#: config/i386/i386.c:6805
+#: config/i386/i386.c:6808
 #, fuzzy, gcc-internal-format
 #| msgid "Calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "Позивање %qD са атрибутом sseregparm без укључених ССЕ/ССЕ2"
 
-#: config/i386/i386.c:6808
+#: config/i386/i386.c:6811
 #, fuzzy, gcc-internal-format
 #| msgid "Calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "Позивање %qT са атрибутом sseregparm без укључених ССЕ/ССЕ2"
 
-#: config/i386/i386.c:7126
+#: config/i386/i386.c:7129
 #, fuzzy, gcc-internal-format
 #| msgid "does not support multilib"
 msgid "X32 does not support ms_abi attribute"
 msgstr "не подржава вишебиб"
 
-#: config/i386/i386.c:7160
+#: config/i386/i386.c:7163
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr "-march=%s није сагласно са изабраним АБИјем"
 
-#: config/i386/i386.c:7502
+#: config/i386/i386.c:7505
 #, fuzzy, gcc-internal-format
 #| msgid "MMX vector argument without MMX enabled changes the ABI"
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr "ММИкс векторски аргумент без укључених ММИкс мења АБИ"
 
-#: config/i386/i386.c:7508
+#: config/i386/i386.c:7511
 #, fuzzy, gcc-internal-format
 #| msgid "MMX vector return without MMX enabled changes the ABI"
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr "ММИкс векторско враћање без укључених ММИкс мења АБИ"
 
-#: config/i386/i386.c:7522
+#: config/i386/i386.c:7525
 #, fuzzy, gcc-internal-format
 #| msgid "MMX vector argument without MMX enabled changes the ABI"
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr "ММИкс векторски аргумент без укључених ММИкс мења АБИ"
 
-#: config/i386/i386.c:7528
+#: config/i386/i386.c:7531
 #, fuzzy, gcc-internal-format
 #| msgid "MMX vector return without MMX enabled changes the ABI"
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr "ММИкс векторско враћање без укључених ММИкс мења АБИ"
 
-#: config/i386/i386.c:7544
+#: config/i386/i386.c:7547
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr "ССЕ векторски аргумент без укључених ССЕ мења АБИ"
 
-#: config/i386/i386.c:7550
+#: config/i386/i386.c:7553
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr "ССЕ векторско враћање без укључених ССЕ мења АБИ"
 
-#: config/i386/i386.c:7566
+#: config/i386/i386.c:7569
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr "ММИкс векторски аргумент без укључених ММИкс мења АБИ"
 
-#: config/i386/i386.c:7572
+#: config/i386/i386.c:7575
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr "ММИкс векторско враћање без укључених ММИкс мења АБИ"
 
-#: config/i386/i386.c:7754
+#: config/i386/i386.c:7757
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:7871
+#: config/i386/i386.c:7874
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:7989
+#: config/i386/i386.c:7992
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:8152
+#: config/i386/i386.c:8155
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr "ССЕ враћање регистра уз искључене ССЕ"
 
-#: config/i386/i386.c:8158
+#: config/i386/i386.c:8161
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr "ССЕ регистарски аргумент уз искључене ССЕ"
 
-#: config/i386/i386.c:8174
+#: config/i386/i386.c:8177
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr "враћање из регистра x87 када је x87 искључено"
 
-#: config/i386/i386.c:8471 config/i386/i386.c:8750 config/i386/i386.c:9276
+#: config/i386/i386.c:8474 config/i386/i386.c:8753 config/i386/i386.c:9279
 #, fuzzy, gcc-internal-format
 #| msgid "Calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr "Позивање %qD са атрибутом sseregparm без укључених ССЕ/ССЕ2"
 
-#: config/i386/i386.c:8473 config/i386/i386.c:8752 config/i386/i386.c:9278
+#: config/i386/i386.c:8476 config/i386/i386.c:8755 config/i386/i386.c:9281
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr ""
 
-#: config/i386/i386.c:9178
+#: config/i386/i386.c:9181
 #, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr ""
 
-#: config/i386/i386.c:11601
+#: config/i386/i386.c:11604
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "assert: %s is assign compatible with %s"
 msgid "-mcall-ms2sysv-xlogues is not compatible with %s"
 msgstr "тврдња: %s је доделом сагласно са %s"
 
-#: config/i386/i386.c:13593
+#: config/i386/i386.c:13596
 #, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr ""
 
-#: config/i386/i386.c:13683
+#: config/i386/i386.c:13686
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr ""
 
-#: config/i386/i386.c:14970
+#: config/i386/i386.c:14973
 #, fuzzy, gcc-internal-format
 #| msgid "%s not supported for nested functions"
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr "%s није подржано за угњеждене функције"
 
-#: config/i386/i386.c:14990
+#: config/i386/i386.c:14993
 #, fuzzy, gcc-internal-format
 #| msgid "%s not supported for nested functions"
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
@@ -34311,267 +34354,267 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:15001
+#: config/i386/i386.c:15004
 #, fuzzy, gcc-internal-format
 #| msgid "%s functions limited to %d register parameters"
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr "%s функције ограничене на %d регистарских параметара"
 
-#: config/i386/i386.c:17939
+#: config/i386/i386.c:17942
 #, gcc-internal-format
 msgid "'V' modifier on non-integer register"
 msgstr ""
 
-#: config/i386/i386.c:17950 config/i386/i386.c:17964
+#: config/i386/i386.c:17953 config/i386/i386.c:17967
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported operand size for extended register"
 msgid "unsupported size for integer register"
 msgstr "неподржана величина операнда за проширени регистар"
 
-#: config/i386/i386.c:17996
+#: config/i386/i386.c:17999
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr "проширени регистри немају високе половине"
 
-#: config/i386/i386.c:18011
+#: config/i386/i386.c:18014
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr "неподржана величина операнда за проширени регистар"
 
-#: config/i386/i386.c:18202
+#: config/i386/i386.c:18205
 #, gcc-internal-format
 msgid "non-integer operand used with operand code 'z'"
 msgstr ""
 
-#: config/i386/i386.c:28467
+#: config/i386/i386.c:28470
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine can't be called directly"
 msgstr "сервисне рутине прекида не могу бити кодиране у режиму Тамба"
 
-#: config/i386/i386.c:29995
+#: config/i386/i386.c:29998
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in -fabi-version=12 (GCC 8)"
 msgstr ""
 
-#: config/i386/i386.c:32435
+#: config/i386/i386.c:32438
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr ""
 
-#: config/i386/i386.c:32485
+#: config/i386/i386.c:32488
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "No label definition found for %qs"
 msgid "No dispatcher found for %s"
 msgstr "Није нађена дефиниција етикете за %qs"
 
-#: config/i386/i386.c:32495
+#: config/i386/i386.c:32498
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr ""
 
-#: config/i386/i386.c:32657
+#: config/i386/i386.c:32660
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386.c:32662 config/i386/i386.c:32938
-#: config/rs6000/rs6000.c:37850
+#: config/i386/i386.c:32665 config/i386/i386.c:32941
+#: config/rs6000/rs6000.c:37906
 #, fuzzy, gcc-internal-format
 #| msgid "stack limit expression is not supported"
 msgid "Virtual function multiversioning not supported"
 msgstr "израз ограничења стека није подржан"
 
-#: config/i386/i386.c:32795 config/rs6000/rs6000.c:37607
+#: config/i386/i386.c:32798 config/rs6000/rs6000.c:37663
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "__builtin_eh_return није подржан на овом циљу"
 
-#: config/i386/i386.c:33207
+#: config/i386/i386.c:33210
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs must be a 2-bit unsigned literal"
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr "аргумент за %qs мора бити двобитна неозначена константа"
 
-#: config/i386/i386.c:33232 config/i386/i386.c:33282
+#: config/i386/i386.c:33235 config/i386/i386.c:33285
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument to -ffpe-trap is not valid: %s"
 msgid "Parameter to builtin not valid: %s"
 msgstr "Аргумент за -ffpe-trap није исправан: %s"
 
-#: config/i386/i386.c:33975 config/i386/i386.c:35415
+#: config/i386/i386.c:33978 config/i386/i386.c:35418
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 2-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386.c:34370
+#: config/i386/i386.c:34373
 #, fuzzy, gcc-internal-format
 #| msgid "shift must be an immediate"
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "помак мора бити непосредни"
 
-#: config/i386/i386.c:34465
+#: config/i386/i386.c:34468
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the third argument must be an 8-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386.c:35346
+#: config/i386/i386.c:35349
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be an 1-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386.c:35361
+#: config/i386/i386.c:35364
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 3-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386.c:35394
+#: config/i386/i386.c:35397
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "the last argument must be a 4-bit immediate"
 msgstr "аргумент 3 мора бити четворобитна неозначена константа"
 
-#: config/i386/i386.c:35434
+#: config/i386/i386.c:35437
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 1-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386.c:35447
+#: config/i386/i386.c:35450
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 5-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386.c:35457
+#: config/i386/i386.c:35460
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386.c:35462 config/i386/i386.c:36249
+#: config/i386/i386.c:35465 config/i386/i386.c:36252
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be an 8-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386.c:35596
+#: config/i386/i386.c:35599
 #, fuzzy, gcc-internal-format
 #| msgid "third argument to %<__builtin_prefetch%> must be a constant"
 msgid "the third argument must be comparison constant"
 msgstr "трећи аргумент за %<__builtin_prefetch%> мора бити константа"
 
-#: config/i386/i386.c:35601
+#: config/i386/i386.c:35604
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect comparison mode"
 msgstr "нетачна ија:"
 
-#: config/i386/i386.c:35607 config/i386/i386.c:35814
+#: config/i386/i386.c:35610 config/i386/i386.c:35817
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect sharing of tree nodes"
 msgid "incorrect rounding operand"
 msgstr "нетачно дељење чворова стабла"
 
-#: config/i386/i386.c:35796
+#: config/i386/i386.c:35799
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "аргумент 3 мора бити четворобитна неозначена константа"
 
-#: config/i386/i386.c:35802
+#: config/i386/i386.c:35805
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386.c:35805
+#: config/i386/i386.c:35808
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386.c:36247
+#: config/i386/i386.c:36250
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 32-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386.c:36329 config/powerpcspe/powerpcspe.c:16219
-#: config/rs6000/rs6000.c:15304
+#: config/i386/i386.c:36332 config/powerpcspe/powerpcspe.c:16219
+#: config/rs6000/rs6000.c:15348
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr "селектор мора бити целобројна константа у опсегу 0..%wi"
 
-#: config/i386/i386.c:36539
+#: config/i386/i386.c:36542
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr ""
 
-#: config/i386/i386.c:36543
+#: config/i386/i386.c:36546
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr ""
 
-#: config/i386/i386.c:37381
+#: config/i386/i386.c:37375
 #, fuzzy, gcc-internal-format
 #| msgid "mask must be an immediate"
 msgid "last argument must be an immediate"
 msgstr "маска мора бити непосредна"
 
-#: config/i386/i386.c:38108 config/i386/i386.c:38290
+#: config/i386/i386.c:38102 config/i386/i386.c:38284
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386.c:38343
+#: config/i386/i386.c:38337
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386.c:38349
+#: config/i386/i386.c:38343
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect hint operand"
 msgstr "нетачна ија:"
 
-#: config/i386/i386.c:38368
+#: config/i386/i386.c:38362
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386.c:41431
+#: config/i386/i386.c:41425
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to variables"
 msgid "%qE attribute only available for 32-bit"
 msgstr "атрибут %qs примењује се само на променљиве"
 
-#: config/i386/i386.c:41452
+#: config/i386/i386.c:41446
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "аргумент атрибута %qs није константна ниска"
 
-#: config/i386/i386.c:41485 config/i386/i386.c:41494
+#: config/i386/i386.c:41479 config/i386/i386.c:41488
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr "атрибути fastcall и stdcall нису сагласни"
 
-#: config/i386/i386.c:41530 config/powerpcspe/powerpcspe.c:35868
-#: config/rs6000/rs6000.c:33065
+#: config/i386/i386.c:41524 config/powerpcspe/powerpcspe.c:35868
+#: config/rs6000/rs6000.c:33121
 #, fuzzy, gcc-internal-format
 #| msgid "%qs incompatible attribute ignored"
 msgid "%qE incompatible attribute ignored"
 msgstr "%qs несагласан атрибут игнорисан"
 
-#: config/i386/i386.c:41555 config/i386/i386.c:41577 config/ia64/ia64.c:815
+#: config/i386/i386.c:41549 config/i386/i386.c:41571 config/ia64/ia64.c:815
 #: config/s390/s390.c:1153
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
@@ -34578,84 +34621,84 @@
 msgid "%qE attribute requires a string constant argument"
 msgstr "атрибут %qs захтева целобројну константу као аргумент"
 
-#: config/i386/i386.c:41565 config/i386/i386.c:41587 config/s390/s390.c:1182
+#: config/i386/i386.c:41559 config/i386/i386.c:41581 config/s390/s390.c:1182
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "аргумент атрибута %qs није константна ниска"
 
-#: config/i386/i386.c:41619
+#: config/i386/i386.c:41613
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386.c:41626
+#: config/i386/i386.c:41620
 #, gcc-internal-format, gfc-internal-format
 msgid "interrupt service routine should have unsigned %sint as the second argument"
 msgstr ""
 
-#: config/i386/i386.c:41636
+#: config/i386/i386.c:41630
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386.c:41639
+#: config/i386/i386.c:41633
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine can't have non-void return value"
 msgstr "сервисне рутине прекида не могу бити кодиране у режиму Тамба"
 
-#: config/i386/i386.c:44676
+#: config/i386/i386.c:44670
 #, fuzzy, gcc-internal-format
 #| msgid "By-value argument at %L is not allowed in this context"
 msgid "alternatives not allowed in asm flag output"
 msgstr "Аргумент-по-вредности код %L није дозвољен у овом контексту"
 
-#: config/i386/i386.c:44740
+#: config/i386/i386.c:44734
 #, fuzzy, gcc-internal-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown asm flag output %qs"
 msgstr "непознат машински режим %qs"
 
-#: config/i386/i386.c:44769
+#: config/i386/i386.c:44763
 #, fuzzy, gcc-internal-format
 #| msgid "invalid lvalue in asm output %d"
 msgid "invalid type for asm flag output"
 msgstr "неисправна л-вредност у излазу асемблера %d"
 
-#: config/i386/i386.c:50634
+#: config/i386/i386.c:50628
 #, gcc-internal-format
 msgid "unknown architecture specific memory model"
 msgstr ""
 
-#: config/i386/i386.c:50641
+#: config/i386/i386.c:50635
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50647
+#: config/i386/i386.c:50641
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50671 config/i386/i386.c:50787
+#: config/i386/i386.c:50665 config/i386/i386.c:50781
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "unsupported simdlen %d"
 msgstr "неподржана комбинација: %s"
 
-#: config/i386/i386.c:50690
+#: config/i386/i386.c:50684
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd"
 msgstr ""
 
-#: config/i386/i386.c:50712
+#: config/i386/i386.c:50706
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid argument type %qs to %qs"
 msgid "unsupported argument type %qT for simd"
 msgstr "Неисправан тип аргумента %qs за %qs"
 
-#: config/i386/i386.c:51033
+#: config/i386/i386.c:51027
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr ""
@@ -34899,7 +34942,7 @@
 msgstr ""
 
 #: config/m68k/m68k.c:1128 config/powerpcspe/powerpcspe.c:28512
-#: config/rs6000/rs6000.c:25791
+#: config/rs6000/rs6000.c:25868
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "израз ограничења стека није подржан"
@@ -35523,10 +35566,10 @@
 
 #. Trampoline is not supported on reduced-set registers yet.
 #: config/nds32/nds32.c:2327 config/nds32/nds32.c:2381
-#: config/nds32/nds32.c:3127 config/nds32/nds32.c:3201
-#: config/nds32/nds32.c:3216 config/nds32/nds32.c:3222
-#: config/nds32/nds32.c:3284 config/nds32/nds32.c:3290
-#: config/nds32/nds32.c:3322
+#: config/nds32/nds32.c:3128 config/nds32/nds32.c:3202
+#: config/nds32/nds32.c:3217 config/nds32/nds32.c:3223
+#: config/nds32/nds32.c:3285 config/nds32/nds32.c:3291
+#: config/nds32/nds32.c:3323
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "a nested function is not supported for reduced registers"
@@ -35533,55 +35576,55 @@
 msgstr "-fdata-sections није подржано за овај циљ"
 
 #. The enum index value for array size is out of range.
-#: config/nds32/nds32.c:3025
+#: config/nds32/nds32.c:3026
 #, fuzzy, gcc-internal-format
 #| msgid "invalid register in the instruction"
 msgid "intrinsic register index is out of range"
 msgstr "неисправан регистар у инструкцији"
 
-#: config/nds32/nds32.c:3041 config/nds32/nds32.c:3048
-#: config/nds32/nds32.c:3055 config/nds32/nds32.c:3062
-#: config/nds32/nds32.c:3069
+#: config/nds32/nds32.c:3042 config/nds32/nds32.c:3049
+#: config/nds32/nds32.c:3056 config/nds32/nds32.c:3063
+#: config/nds32/nds32.c:3070
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic function %s(%d) not recognized"
 msgid "CCTL intrinsic function subtype out of range!"
 msgstr "Сопствена функција %s(%d) није препозната"
 
-#: config/nds32/nds32.c:3508
+#: config/nds32/nds32.c:3509
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute %qE"
 msgid "invalid id value for interrupt/exception attribute"
 msgstr "неисправан тип вектора за атрибут %qE"
 
-#: config/nds32/nds32.c:3536
+#: config/nds32/nds32.c:3537
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "invalid id value for reset attribute"
 msgstr "неисправан аргумент за атрибут %qs"
 
-#: config/nds32/nds32.c:3552
+#: config/nds32/nds32.c:3553
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "invalid nmi function for reset attribute"
 msgstr "неисправан аргумент за атрибут %qs"
 
-#: config/nds32/nds32.c:3565
+#: config/nds32/nds32.c:3566
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "invalid warm function for reset attribute"
 msgstr "неисправан аргумент за атрибут %qs"
 
-#: config/nds32/nds32.c:3638
+#: config/nds32/nds32.c:3639
 #, gcc-internal-format
 msgid "Disable FPU ISA, the ABI option must be enable '-mfloat-abi=soft'"
 msgstr ""
 
-#: config/nds32/nds32.c:3641
+#: config/nds32/nds32.c:3642
 #, gcc-internal-format
 msgid "'-mabi=2fp+' option only support when FPU available, must be enable '-mext-fpu-sp' or '-mext-fpu-dp'"
 msgstr ""
 
-#: config/nds32/nds32.c:3647
+#: config/nds32/nds32.c:3648
 #, fuzzy, gcc-internal-format
 #| msgid "Generate position-independent code if possible (large mode)"
 msgid "position-independent code not supported"
@@ -35932,12 +35975,12 @@
 msgid "junk at end of #pragma longcall"
 msgstr "смеће на крају #pragma longcall"
 
-#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6154
+#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6152
 #, gcc-internal-format
 msgid "vec_lvsl is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6158
+#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6156
 #, gcc-internal-format
 msgid "vec_lvsr is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
@@ -35990,7 +36033,7 @@
 msgid "vec_insert only accepts 3 arguments"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6868
+#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6866
 #, fuzzy, gcc-internal-format
 #| msgid "passing arg %d of %qE discards qualifiers frompointer target type"
 msgid "passing arg %d of %qE discards qualifiers from pointer target type"
@@ -36080,7 +36123,7 @@
 msgid "target attribute or pragma changes SPE ABI"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4351 config/rs6000/rs6000.c:4223
+#: config/powerpcspe/powerpcspe.c:4351 config/rs6000/rs6000.c:4243
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "AltiVec not supported in this target"
@@ -36237,7 +36280,7 @@
 msgid "-mvsx-small-integer requires -mpower8-vector, -mupper-regs-di, and -mdirect-move"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4959 config/rs6000/rs6000.c:4601
+#: config/powerpcspe/powerpcspe.c:4959 config/rs6000/rs6000.c:4628
 #, gcc-internal-format
 msgid "target attribute or pragma changes long double size"
 msgstr ""
@@ -36278,22 +36321,22 @@
 msgstr ""
 
 #: config/powerpcspe/powerpcspe.c:5140 config/powerpcspe/powerpcspe.c:5155
-#: config/rs6000/rs6000.c:4766 config/rs6000/rs6000.c:4781
+#: config/rs6000/rs6000.c:4791 config/rs6000/rs6000.c:4806
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:5168 config/rs6000/rs6000.c:4794
+#: config/powerpcspe/powerpcspe.c:5168 config/rs6000/rs6000.c:4819
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:5234 config/rs6000/rs6000.c:4828
+#: config/powerpcspe/powerpcspe.c:5234 config/rs6000/rs6000.c:4853
 #, gcc-internal-format
 msgid "target attribute or pragma changes single precision floating point"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:5237 config/rs6000/rs6000.c:4831
+#: config/powerpcspe/powerpcspe.c:5237 config/rs6000/rs6000.c:4856
 #, gcc-internal-format
 msgid "target attribute or pragma changes double precision floating point"
 msgstr ""
@@ -36303,12 +36346,12 @@
 msgid "-mstack-protector-guard=tls needs a valid base register"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:8415 config/rs6000/rs6000.c:7925
+#: config/powerpcspe/powerpcspe.c:8415 config/rs6000/rs6000.c:7950
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11237
+#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11269
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "ГЦЦ вектор враћен упућивачем: нестандарно проширење АБИја, без јемства сагласности"
@@ -36318,7 +36361,7 @@
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "вредност се не може вратити у векторском регистру јер су алтивек инструкције искључене; употребите -maltivec да их укључите"
 
-#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11595
+#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11633
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr ""
@@ -36328,12 +36371,12 @@
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "вредност се не може проследити у векторском регистру јер су алтивек инструкције искључене; употребите -maltivec да их укључите"
 
-#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12604
+#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12648
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12779
+#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12823
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "ГЦЦ вектор прослеђен упућивачем: нестандарно проширење АБИја, без јемства сагласности"
@@ -36344,30 +36387,30 @@
 msgid "internal error: builtin function %s already processed"
 msgstr "Сматрај улазну датотеку већ предобрађеном"
 
-#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:13971
+#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:14015
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "argument 1 must be an 8-bit field value"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14015
+#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14059
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
 #: config/powerpcspe/powerpcspe.c:14934 config/powerpcspe/powerpcspe.c:16803
-#: config/rs6000/rs6000.c:14101
+#: config/rs6000/rs6000.c:14145
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "аргумент 2 мора бити петобитна неозначена константа"
 
-#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14119
+#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14163
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "аргумент 2 мора бити петобитна неозначена константа"
 
-#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14135
+#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14179
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 7-bit unsigned literal"
@@ -36388,13 +36431,13 @@
 msgid "builtin %s is only valid in 64-bit mode"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14791
+#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14835
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument %d must be an unsigned literal"
 msgstr "аргумент 2 мора бити петобитна неозначена константа"
 
-#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14793
+#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14837
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument %d is an unsigned literal that is out of range"
@@ -36420,60 +36463,60 @@
 msgid "hwcap %s is an invalid argument to builtin %s"
 msgstr "неисправан аргумент за уграђену функцију"
 
-#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15065
+#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15109
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "аргумент 3 мора бити четворобитна неозначена константа"
 
-#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15090
+#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15134
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "аргумент 3 мора бити четворобитна неозначена константа"
 
-#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15110
+#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15154
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "аргумент 3 мора бити четворобитна неозначена константа"
 
-#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15122
+#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15166
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "argument 1 must be 0 or 2"
 msgstr "број мора бити 0 или 1"
 
-#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15134
+#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15178
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "аргумент 2 мора бити петобитна неозначена константа"
 
-#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15148
+#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15192
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "аргумент 2 мора бити петобитна неозначена константа"
 
-#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15160
+#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15204
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "argument 2 must be 0 or 1"
 msgstr "број мора бити 0 или 1"
 
-#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15168
+#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15212
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ATANH at %L must be inside the range -1 to 1"
 msgid "argument 3 must be in the range 0..15"
 msgstr "Аргумент у ATANH код %L мора бити у опсегу -1 до 1"
 
-#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15237
-#: config/rs6000/rs6000.c:15569
+#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15281
+#: config/rs6000/rs6000.c:15613
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "аргумент за %qs мора бити двобитна неозначена константа"
 
-#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15394
+#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15438
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr "неразрешено препуњавање за алтивек уграђено %qF"
@@ -36610,7 +36653,7 @@
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25758
+#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25835
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr "оквир стека превелик"
@@ -36620,12 +36663,12 @@
 msgid "-fsplit-stack uses register r29"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29459
+#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29536
 #, gcc-internal-format
 msgid "Stack frame larger than 2G is not supported for -fsplit-stack"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30447
+#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30524
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "нема профилисања 64-битног кôда за овај АБИ"
@@ -36635,22 +36678,22 @@
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32830
+#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32907
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "употреба %<long double%> у алтивек типовима није исправна"
 
-#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32832
+#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32909
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "употреба логичких типова у алтивек типовима није исправна"
 
-#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32834
+#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32911
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "употреба %<complex%> у алтивек типовима није исправна"
 
-#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32836
+#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32913
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr "употреба децималних реалних типова у алтивек типовима није исправна"
@@ -36661,7 +36704,7 @@
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr "употреба %<long%> у алтивек типовима није исправна у 64-битном кôду"
 
-#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32845
+#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32922
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "превазиђена употреба %<long%> у алтивек; користите %<int%>"
@@ -37223,78 +37266,78 @@
 "Please use an explicit cpu name.  Valid cpu names are: %s"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6168 config/rs6000/rs6000-c.c:6219
-#: config/rs6000/rs6000-c.c:6489 config/rs6000/rs6000-c.c:6555
-#: config/rs6000/rs6000-c.c:6916 config/rs6000/rs6000-c.c:6963
+#: config/rs6000/rs6000-c.c:6166 config/rs6000/rs6000-c.c:6217
+#: config/rs6000/rs6000-c.c:6487 config/rs6000/rs6000-c.c:6553
+#: config/rs6000/rs6000-c.c:6914 config/rs6000/rs6000-c.c:6961
 #, gcc-internal-format
 msgid "builtin %qs only accepts 2 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6292 config/rs6000/rs6000-c.c:6375
-#: config/rs6000/rs6000-c.c:6736
+#: config/rs6000/rs6000-c.c:6290 config/rs6000/rs6000-c.c:6373
+#: config/rs6000/rs6000-c.c:6734
 #, gcc-internal-format
 msgid "builtin %qs only accepts 3 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6484
+#: config/rs6000/rs6000-c.c:6482
 #, gcc-internal-format
 msgid "builtin %qs only accepts 1 argument"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:7054
+#: config/rs6000/rs6000-c.c:7052
 #, gcc-internal-format
 msgid "builtin %qs requires builtin %qs"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:7058
+#: config/rs6000/rs6000-c.c:7056
 #, fuzzy, gcc-internal-format
 #| msgid "%Jalias definitions not supported in this configuration"
 msgid "builtin function %qs not supported in this compiler configuration"
 msgstr "%Jдефиниције алијаса нису подржане у овој конфигурацији"
 
-#: config/rs6000/rs6000-c.c:7068
+#: config/rs6000/rs6000-c.c:7066
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter combination for AltiVec intrinsic"
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr "неисправна комбинација параметара за алтивек сопствену"
 
-#: config/rs6000/rs6000.c:3754 config/rs6000/rs6000.c:3757
-#: config/rs6000/rs6000.c:3760
+#: config/rs6000/rs6000.c:3772 config/rs6000/rs6000.c:3775
+#: config/rs6000/rs6000.c:3778
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is predetermined %qs for %qs"
 msgid "%qs requires %qs or %qs"
 msgstr "%qE је предодређено као %qs за %qs"
 
-#: config/rs6000/rs6000.c:3861
+#: config/rs6000/rs6000.c:3879
 #, fuzzy, gcc-internal-format
 #| msgid "-m64 requires PowerPC64 architecture, enabling"
 msgid "%qs requires PowerPC64 architecture, enabling"
 msgstr "-m64 захтева архитектуру ПауерПЦ-64, укључујем"
 
-#: config/rs6000/rs6000.c:4037
+#: config/rs6000/rs6000.c:4057
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated"
 msgid "%qs command-line option is deprecated"
 msgstr "%qs је превазиђено"
 
-#: config/rs6000/rs6000.c:4048
+#: config/rs6000/rs6000.c:4068
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-power is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgid "%qs is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr "-malign-power није подржано на 64-битном Дарвину; није сагласно са инсталираним Ц и Ц++ библиотекама"
 
-#: config/rs6000/rs6000.c:4147
+#: config/rs6000/rs6000.c:4167
 #, gcc-internal-format
 msgid "will not generate %qs instructions because assembler lacks %qs support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4240
+#: config/rs6000/rs6000.c:4260
 #, fuzzy, gcc-internal-format
 #| msgid "-mstring is not supported on little endian systems"
 msgid "%qs is not supported on little endian systems"
 msgstr "-mstring није подржано на системима мале крајности"
 
-#: config/rs6000/rs6000.c:4333
+#: config/rs6000/rs6000.c:4353
 #, gcc-internal-format
 msgid "power9 target option is incompatible with %<%s=<xxx>%> for <xxx> less than power9"
 msgstr ""
@@ -37301,7 +37344,7 @@
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:4341
+#: config/rs6000/rs6000.c:4361
 #, fuzzy, gcc-internal-format
 #| msgid "-fjni is incompatible with -freduced-reflection"
 msgid "%qs incompatible with explicitly disabled options"
@@ -37311,125 +37354,125 @@
 #. error messages.  However, if users have managed to select
 #. power9-fusion without selecting power8-fusion, they
 #. already know about undocumented flags.
-#: config/rs6000/rs6000.c:4366 config/rs6000/rs6000.c:4373
-#: config/rs6000/rs6000.c:4380 config/rs6000/rs6000.c:4388
-#: config/rs6000/rs6000.c:4407 config/rs6000/rs6000.c:4464
-#: config/rs6000/rs6000.c:4468 config/rs6000/rs6000.c:4485
-#: config/rs6000/rs6000.c:4538 config/rs6000/rs6000.c:4565
-#: config/rs6000/rs6000.c:4580 config/rs6000/rs6000.c:4588
-#: config/rs6000/rs6000.c:4684
+#: config/rs6000/rs6000.c:4386 config/rs6000/rs6000.c:4393
+#: config/rs6000/rs6000.c:4400 config/rs6000/rs6000.c:4408
+#: config/rs6000/rs6000.c:4427 config/rs6000/rs6000.c:4484
+#: config/rs6000/rs6000.c:4488 config/rs6000/rs6000.c:4505
+#: config/rs6000/rs6000.c:4558 config/rs6000/rs6000.c:4585
+#: config/rs6000/rs6000.c:4600 config/rs6000/rs6000.c:4608
+#: config/rs6000/rs6000.c:4709
 #, fuzzy, gcc-internal-format
 #| msgid "%qT referred to as %qs"
 msgid "%qs requires %qs"
 msgstr "%qT се помиње као %qs"
 
-#: config/rs6000/rs6000.c:4625
+#: config/rs6000/rs6000.c:4650
 #, gcc-internal-format
 msgid "Using IEEE extended precision long double"
 msgstr "Користим ИЕЕЕ дугачки двоструки проширене тачности"
 
-#: config/rs6000/rs6000.c:4627
+#: config/rs6000/rs6000.c:4652
 #, gcc-internal-format
 msgid "Using IBM extended precision long double"
 msgstr "Користим ИБМов дугачки двоструки проширене тачности"
 
-#: config/rs6000/rs6000.c:4644
+#: config/rs6000/rs6000.c:4669
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "%qs requires VSX support"
 msgstr "%s не подржава %s"
 
-#: config/rs6000/rs6000.c:4653
+#: config/rs6000/rs6000.c:4678
 #, gcc-internal-format
 msgid "The -mfloat128 option may not be fully supported"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4676
+#: config/rs6000/rs6000.c:4701
 #, gcc-internal-format
 msgid "%qs requires full ISA 3.0 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4743
+#: config/rs6000/rs6000.c:4768
 #, gcc-internal-format
 msgid "unknown vectorization library ABI type (%qs) for %qs switch"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4930
+#: config/rs6000/rs6000.c:4955
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "%qs is not a valid number in %qs"
 msgstr "%qs није исправно за %qs"
 
-#: config/rs6000/rs6000.c:4935
+#: config/rs6000/rs6000.c:4960
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "%qs is not a valid offset in %qs"
 msgstr "%qs није исправно за %qs"
 
-#: config/rs6000/rs6000.c:4947
+#: config/rs6000/rs6000.c:4972
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "%qs is not a valid base register in %qs"
 msgstr "%qs није исправно за %qs"
 
-#: config/rs6000/rs6000.c:4955
+#: config/rs6000/rs6000.c:4980
 #, fuzzy, gcc-internal-format
 #| msgid "Need a call-clobbered target register"
 msgid "%qs needs a valid base register"
 msgstr "Потребан је позивом продрман циљни регистар"
 
-#: config/rs6000/rs6000.c:5253
+#: config/rs6000/rs6000.c:5278
 #, gcc-internal-format
 msgid "unknown option for %<%s=%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:5290
+#: config/rs6000/rs6000.c:5315
 #, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11401
+#: config/rs6000/rs6000.c:11439
 #, fuzzy, gcc-internal-format
 #| msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgid "cannot return value in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr "вредност се не може вратити у векторском регистру јер су алтивек инструкције искључене; употребите -maltivec да их укључите"
 
-#: config/rs6000/rs6000.c:11862
+#: config/rs6000/rs6000.c:11906
 #, fuzzy, gcc-internal-format
 #| msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr "вредност се не може проследити у векторском регистру јер су алтивек инструкције искључене; употребите -maltivec да их укључите"
 
-#: config/rs6000/rs6000.c:13572
+#: config/rs6000/rs6000.c:13616
 #, fuzzy, gcc-internal-format
 #| msgid "Treat the input file as already preprocessed"
 msgid "internal error: builtin function %qs already processed"
 msgstr "Сматрај улазну датотеку већ предобрађеном"
 
-#: config/rs6000/rs6000.c:14150
+#: config/rs6000/rs6000.c:14194
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 1-bit unsigned literal"
 msgstr "аргумент 2 мора бити петобитна неозначена константа"
 
-#: config/rs6000/rs6000.c:14189
+#: config/rs6000/rs6000.c:14233
 #, fuzzy, gcc-internal-format
 #| msgid "argument %qd is not a constant"
 msgid "argument 1 of %qs must be a constant"
 msgstr "аргумент %qd није константа"
 
-#: config/rs6000/rs6000.c:14247 config/rs6000/rs6000.c:15898
+#: config/rs6000/rs6000.c:14291 config/rs6000/rs6000.c:15942
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument 1 of %qs is out of range"
 msgstr "аргумент 1 за __builtin_spe_predicate ван опсега"
 
-#: config/rs6000/rs6000.c:14742
+#: config/rs6000/rs6000.c:14786
 #, gcc-internal-format
 msgid "builtin %qs is only valid in 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14939
+#: config/rs6000/rs6000.c:14983
 #, fuzzy, gcc-internal-format
 #| msgid "%qs expects a constant argument"
 msgid "builtin %qs only accepts a string argument"
@@ -37436,7 +37479,7 @@
 msgstr "%qs очекује константан аргумент"
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000.c:14958
+#: config/rs6000/rs6000.c:15002
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to builtin function"
 msgid "cpu %qs is an invalid argument to builtin %qs"
@@ -37443,138 +37486,139 @@
 msgstr "неисправан аргумент за уграђену функцију"
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000.c:14986
+#: config/rs6000/rs6000.c:15030
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to builtin function"
 msgid "%s %qs is an invalid argument to builtin %qs"
 msgstr "неисправан аргумент за уграђену функцију"
 
-#: config/rs6000/rs6000.c:15012
+#: config/rs6000/rs6000.c:15056
 #, gcc-internal-format
 msgid "builtin %qs needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15616
+#: config/rs6000/rs6000.c:15660
 #, fuzzy, gcc-internal-format
 #| msgid "second argument of %q+D should be %<char **%>"
 msgid "second argument to %qs must be 0..12"
 msgstr "други аргумент за %q+D треба да је %<char **%>"
 
-#: config/rs6000/rs6000.c:15631
+#: config/rs6000/rs6000.c:15675
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "third argument to %qs must be 0..12"
 msgstr "неисправан аргумент за атрибут %qs"
 
-#: config/rs6000/rs6000.c:15850
+#: config/rs6000/rs6000.c:15894
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate must be a constant"
 msgid "argument 1 of %s must be a constant"
 msgstr "аргумент 1 за __builtin_spe_predicate мора бити константа"
 
-#: config/rs6000/rs6000.c:15932
+#: config/rs6000/rs6000.c:15976
 #, fuzzy, gcc-internal-format
 #| msgid "this builtin function is only available on the fr450"
 msgid "builtin function %qs is only valid for the cell processor"
 msgstr "ова уграђена функција доступна је само на фр450"
 
-#: config/rs6000/rs6000.c:15934 config/rs6000/rs6000.c:15936
-#: config/rs6000/rs6000.c:15938 config/rs6000/rs6000.c:15940
-#: config/rs6000/rs6000.c:15946 config/rs6000/rs6000.c:15948
-#: config/rs6000/rs6000.c:15955 config/rs6000/rs6000.c:15962
-#: config/rs6000/rs6000.c:15969 config/rs6000/rs6000.c:15975
+#: config/rs6000/rs6000.c:15978 config/rs6000/rs6000.c:15980
+#: config/rs6000/rs6000.c:15982 config/rs6000/rs6000.c:15984
+#: config/rs6000/rs6000.c:15990 config/rs6000/rs6000.c:15992
+#: config/rs6000/rs6000.c:15999 config/rs6000/rs6000.c:16006
+#: config/rs6000/rs6000.c:16011 config/rs6000/rs6000.c:16014
+#: config/rs6000/rs6000.c:16018 config/rs6000/rs6000.c:16024
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "builtin function %qs requires the %qs option"
 msgstr "уграђена функција %q+D декларисана као нефункција"
 
-#: config/rs6000/rs6000.c:15943 config/rs6000/rs6000.c:15952
-#: config/rs6000/rs6000.c:15959 config/rs6000/rs6000.c:15966
+#: config/rs6000/rs6000.c:15987 config/rs6000/rs6000.c:15996
+#: config/rs6000/rs6000.c:16003
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "builtin function %qs requires the %qs and %qs options"
 msgstr "уграђена функција %q+D декларисана као нефункција"
 
-#: config/rs6000/rs6000.c:15972
+#: config/rs6000/rs6000.c:16021
 #, gcc-internal-format
 msgid "builtin function %qs requires ISA 3.0 IEEE 128-bit floating point"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15978
+#: config/rs6000/rs6000.c:16027
 #, gcc-internal-format
 msgid "builtin function %qs requires the %qs (or newer), and %qs or %qs options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15982
+#: config/rs6000/rs6000.c:16031
 #, fuzzy, gcc-internal-format
 #| msgid "command line option %qs is not supported by this configuration"
 msgid "builtin function %qs is not supported with the current options"
 msgstr "опција командне линије %qs није подржана овом конфигурацијом"
 
-#: config/rs6000/rs6000.c:18218
+#: config/rs6000/rs6000.c:18290
 #, gcc-internal-format
 msgid "internal error: builtin function %qs had an unexpected return type %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18235
+#: config/rs6000/rs6000.c:18307
 #, gcc-internal-format
 msgid "internal error: builtin function %qs, argument %d had unexpected argument type %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:29451
+#: config/rs6000/rs6000.c:29528
 #, fuzzy, gcc-internal-format
 #| msgid "Use registers r2 and r5"
 msgid "%qs uses register r29"
 msgstr "Користи регистре r2 и r5"
 
-#: config/rs6000/rs6000.c:32748
+#: config/rs6000/rs6000.c:32825
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "не може се узети адреса од %<this%>, јер је д-вредносни израз"
 
-#: config/rs6000/rs6000.c:32842
+#: config/rs6000/rs6000.c:32919
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long%> in AltiVec types is invalid for 64-bit code"
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "употреба %<long%> у алтивек типовима није исправна у 64-битном кôду"
 
-#: config/rs6000/rs6000.c:32850
+#: config/rs6000/rs6000.c:32927
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long long%> in AltiVec types is invalid"
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "употреба %<long long%> у алтивек типовима није исправна"
 
-#: config/rs6000/rs6000.c:32853
+#: config/rs6000/rs6000.c:32930
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<double%> in AltiVec types is invalid"
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "употреба %<double%> у алтивек типовима није исправна"
 
-#: config/rs6000/rs6000.c:36876
+#: config/rs6000/rs6000.c:36932
 #, fuzzy, gcc-internal-format
 #| msgid "invalid abstract type %qT for %qE"
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "неисправан апстрактни тип %qT за %qE"
 
-#: config/rs6000/rs6000.c:36879
+#: config/rs6000/rs6000.c:36935
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE is not initialized"
 msgid "%s%qs%s is not allowed"
 msgstr "%H%qE није успостављено"
 
-#: config/rs6000/rs6000.c:36881
+#: config/rs6000/rs6000.c:36937
 #, fuzzy, gcc-internal-format
 #| msgid "spec '%s' is invalid"
 msgid "%s%qs%s is invalid"
 msgstr "навод ‘%s’ није исправан"
 
-#: config/rs6000/rs6000.c:37416
+#: config/rs6000/rs6000.c:37472
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:37575
+#: config/rs6000/rs6000.c:37631
 #, gcc-internal-format
 msgid "target_clones attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
@@ -38369,54 +38413,54 @@
 msgid "subprogram %q+F not marked Inline"
 msgstr ""
 
-#: ada/gcc-interface/trans.c:6404
+#: ada/gcc-interface/trans.c:6401
 #, gcc-internal-format
 msgid "out-of-bounds access may be optimized away"
 msgstr ""
 
-#: ada/gcc-interface/trans.c:6406
+#: ada/gcc-interface/trans.c:6403
 #, fuzzy, gcc-internal-format
 #| msgid "%<continue%> must be in loop"
 msgid "containing loop"
 msgstr "%<continue%> мора бити у оквиру петље"
 
-#: ada/gcc-interface/utils.c:3887
+#: ada/gcc-interface/utils.c:3890
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute %qE"
 msgid "invalid element type for attribute %qs"
 msgstr "неисправан тип вектора за атрибут %qE"
 
-#: ada/gcc-interface/utils.c:3911
+#: ada/gcc-interface/utils.c:3914
 #, fuzzy, gcc-internal-format
 #| msgid "number of components of the vector not a power of two"
 msgid "number of components of vector not a power of two"
 msgstr "број компоненти вектора није степен двојке"
 
-#: ada/gcc-interface/utils.c:6037 ada/gcc-interface/utils.c:6215
-#: ada/gcc-interface/utils.c:6322
+#: ada/gcc-interface/utils.c:6043 ada/gcc-interface/utils.c:6220
+#: ada/gcc-interface/utils.c:6327
 #, gcc-internal-format
 msgid "%qs attribute ignored"
 msgstr "атрибут %qs се игнорише"
 
-#: ada/gcc-interface/utils.c:6158
+#: ada/gcc-interface/utils.c:6164
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute requires prototypes with named arguments"
 msgid "%qs attribute requires prototypes with named arguments"
 msgstr "атрибут %qE захтева прототипове са именованим аргументима"
 
-#: ada/gcc-interface/utils.c:6167
+#: ada/gcc-interface/utils.c:6173
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to variadic functions"
 msgid "%qs attribute only applies to variadic functions"
 msgstr "атрибут %qE је примењив само на варијадичке функције"
 
-#: ada/gcc-interface/utils.c:6282
+#: ada/gcc-interface/utils.c:6287
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored"
 msgid "%qE attribute has no effect"
 msgstr "атрибут %qE се игнорише"
 
-#: ada/gcc-interface/utils.c:6406
+#: ada/gcc-interface/utils.c:6411
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to variables"
 msgid "attribute %qs applies to array types only"
@@ -38433,7 +38477,7 @@
 #. an unprototyped function, it is compile-time undefined;
 #. making it a constraint in that case was rejected in
 #. DR#252.
-#: c/c-convert.c:101 c/c-typeck.c:2175 c/c-typeck.c:6507 c/c-typeck.c:12138
+#: c/c-convert.c:101 c/c-typeck.c:2175 c/c-typeck.c:6512 c/c-typeck.c:12143
 #: cp/typeck.c:2027 cp/typeck.c:7977 cp/typeck.c:8742
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
@@ -38496,7 +38540,7 @@
 msgid "type of array %q+D completed incompatibly with implicit initialization"
 msgstr "тип низа %q+D довршен несагласно са имплицитним успостављањем"
 
-#: c/c-decl.c:1567 c/c-decl.c:6701 c/c-decl.c:7574 c/c-decl.c:8381
+#: c/c-decl.c:1567 c/c-decl.c:6721 c/c-decl.c:7594 c/c-decl.c:8401
 #, fuzzy, gcc-internal-format
 #| msgid "original label is here"
 msgid "originally defined here"
@@ -38926,16 +38970,11 @@
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.c:4548 c/c-decl.c:7147
+#: c/c-decl.c:4548 c/c-decl.c:7167
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr "%<[*]%> није дозвољено другде осим у досегу прототипа функције"
 
-#: c/c-decl.c:4635 cp/decl2.c:1520
-#, gcc-internal-format
-msgid "%q+D in declare target directive does not have mappable type"
-msgstr ""
-
 #: c/c-decl.c:4693
 #, gcc-internal-format
 msgid "%q+D is usually a function"
@@ -38961,7 +39000,7 @@
 #. of VLAs themselves count as VLAs, it does not make
 #. sense to permit them to be initialized given that
 #. ordinary VLAs may not be initialized.
-#: c/c-decl.c:4732 c/c-decl.c:4747 c/c-typeck.c:7630
+#: c/c-decl.c:4732 c/c-decl.c:4747 c/c-typeck.c:7635
 #, gcc-internal-format
 msgid "variable-sized object may not be initialized"
 msgstr "објекат променљиве величине не може се успостављати"
@@ -39024,224 +39063,229 @@
 msgid "uninitialized const %qD is invalid in C++"
 msgstr "неуспостављена константа %qD"
 
-#: c/c-decl.c:5268
+#: c/c-decl.c:5224 cp/decl.c:7318
 #, gcc-internal-format
+msgid "%q+D in declare target directive does not have mappable type"
+msgstr ""
+
+#: c/c-decl.c:5288
+#, gcc-internal-format
 msgid "ISO C forbids forward parameter declarations"
 msgstr "ИСО Ц забрањује унапредне декларације параметара"
 
-#: c/c-decl.c:5371
+#: c/c-decl.c:5391
 #, gcc-internal-format
 msgid "defining a type in a compound literal is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:5425 c/c-decl.c:5440
+#: c/c-decl.c:5445 c/c-decl.c:5460
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant"
 msgstr "ширина битског поља %qs није целобројна константа"
 
-#: c/c-decl.c:5435
+#: c/c-decl.c:5455
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qs width not an integer constant"
 msgid "bit-field %qs width not an integer constant expression"
 msgstr "ширина битског поља %qs није целобројна константа"
 
-#: c/c-decl.c:5446
+#: c/c-decl.c:5466
 #, gcc-internal-format
 msgid "negative width in bit-field %qs"
 msgstr "негативна ширина у битском пољу %qs"
 
-#: c/c-decl.c:5451
+#: c/c-decl.c:5471
 #, gcc-internal-format
 msgid "zero width for bit-field %qs"
 msgstr "нулта ширина за битско поље %qs"
 
-#: c/c-decl.c:5461
+#: c/c-decl.c:5481
 #, gcc-internal-format
 msgid "bit-field %qs has invalid type"
 msgstr "битско поље %qs има неисправан тип"
 
-#: c/c-decl.c:5467
+#: c/c-decl.c:5487
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare bit-field %qD with function type"
 msgid "cannot declare bit-field %qs with %<warn_if_not_aligned%> type"
 msgstr "не може се декларисати битско поље %qD са функцијским типом"
 
-#: c/c-decl.c:5478
+#: c/c-decl.c:5498
 #, gcc-internal-format
 msgid "type of bit-field %qs is a GCC extension"
 msgstr "тип битског поља %qs је проширење ГЦЦа"
 
-#: c/c-decl.c:5484
+#: c/c-decl.c:5504
 #, gcc-internal-format
 msgid "width of %qs exceeds its type"
 msgstr "ширина %qs премашује свој тип"
 
-#: c/c-decl.c:5497
+#: c/c-decl.c:5517
 #, gcc-internal-format
 msgid "%qs is narrower than values of its type"
 msgstr "%qs је уже од вредности свог типа"
 
-#: c/c-decl.c:5512
+#: c/c-decl.c:5532
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids array %qs whose size can%'t be evaluated"
 msgid "ISO C90 forbids array %qE whose size can%'t be evaluated"
 msgstr "ИСО Ц 90 забрањује низ %qs чија се величина не може израчунати"
 
-#: c/c-decl.c:5515
+#: c/c-decl.c:5535
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids array %qs whose size can%'t be evaluated"
 msgid "ISO C90 forbids array whose size can%'t be evaluated"
 msgstr "ИСО Ц 90 забрањује низ %qs чија се величина не може израчунати"
 
-#: c/c-decl.c:5522
+#: c/c-decl.c:5542
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable-size array %qs"
 msgid "ISO C90 forbids variable length array %qE"
 msgstr "ИСО Ц 90 забрањује низ променљиве величине %qs"
 
-#: c/c-decl.c:5524
+#: c/c-decl.c:5544
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable-size array %qs"
 msgid "ISO C90 forbids variable length array"
 msgstr "ИСО Ц 90 забрањује низ променљиве величине %qs"
 
-#: c/c-decl.c:5733 c/c-decl.c:6107 c/c-decl.c:6117
+#: c/c-decl.c:5753 c/c-decl.c:6127 c/c-decl.c:6137
 #, fuzzy, gcc-internal-format
 #| msgid "variably modified %qs at file scope"
 msgid "variably modified %qE at file scope"
 msgstr "променљиво измењиво %qs у досегу датотеке"
 
-#: c/c-decl.c:5735
+#: c/c-decl.c:5755
 #, fuzzy, gcc-internal-format
 #| msgid "variably modified %qs at file scope"
 msgid "variably modified field at file scope"
 msgstr "променљиво измењиво %qs у досегу датотеке"
 
-#: c/c-decl.c:5755
+#: c/c-decl.c:5775
 #, fuzzy, gcc-internal-format
 #| msgid "type defaults to %<int%> in declaration of %qs"
 msgid "type defaults to %<int%> in declaration of %qE"
 msgstr "тип спада на %<int%> у декларацији %qs"
 
-#: c/c-decl.c:5759
+#: c/c-decl.c:5779
 #, fuzzy, gcc-internal-format
 #| msgid "type defaults to %<int%> in declaration of %qs"
 msgid "type defaults to %<int%> in type name"
 msgstr "тип спада на %<int%> у декларацији %qs"
 
-#: c/c-decl.c:5791
+#: c/c-decl.c:5811
 #, gcc-internal-format
 msgid "duplicate %<const%>"
 msgstr "удвостручено %<const%>"
 
-#: c/c-decl.c:5793
+#: c/c-decl.c:5813
 #, gcc-internal-format
 msgid "duplicate %<restrict%>"
 msgstr "удвостручено %<restrict%>"
 
-#: c/c-decl.c:5795
+#: c/c-decl.c:5815
 #, gcc-internal-format
 msgid "duplicate %<volatile%>"
 msgstr "удвостручено %<volatile%>"
 
-#: c/c-decl.c:5797
+#: c/c-decl.c:5817
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<restrict%>"
 msgid "duplicate %<_Atomic%>"
 msgstr "удвостручено %<restrict%>"
 
-#: c/c-decl.c:5800
+#: c/c-decl.c:5820
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "conflicting super class name %qs"
 msgid "conflicting named address spaces (%s vs %s)"
 msgstr "сукобљено име наткласе %qs"
 
-#: c/c-decl.c:5823 c/c-parser.c:2821
+#: c/c-decl.c:5843 c/c-parser.c:2821
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified array type"
 msgstr ""
 
-#: c/c-decl.c:5837
+#: c/c-decl.c:5857
 #, gcc-internal-format
 msgid "function definition declared %<auto%>"
 msgstr "дефиниција функције декларисана као %<auto%>"
 
-#: c/c-decl.c:5839
+#: c/c-decl.c:5859
 #, gcc-internal-format
 msgid "function definition declared %<register%>"
 msgstr "дефиниција функције декларисана као %<register%>"
 
-#: c/c-decl.c:5841
+#: c/c-decl.c:5861
 #, gcc-internal-format
 msgid "function definition declared %<typedef%>"
 msgstr "дефиниција функције декларисана као %<typedef%>"
 
-#: c/c-decl.c:5843
+#: c/c-decl.c:5863
 #, fuzzy, gcc-internal-format
 #| msgid "function definition declared %<auto%>"
 msgid "function definition declared %qs"
 msgstr "дефиниција функције декларисана као %<auto%>"
 
-#: c/c-decl.c:5861
+#: c/c-decl.c:5881
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for structure field %qs"
 msgid "storage class specified for structure field %qE"
 msgstr "складишна класа наведена за поље структуре %qs"
 
-#: c/c-decl.c:5864
+#: c/c-decl.c:5884
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for structure field %qs"
 msgid "storage class specified for structure field"
 msgstr "складишна класа наведена за поље структуре %qs"
 
-#: c/c-decl.c:5868
+#: c/c-decl.c:5888
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "storage class specified for parameter %qE"
 msgstr "складишна класа наведена за параметар %qs"
 
-#: c/c-decl.c:5871
+#: c/c-decl.c:5891
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "storage class specified for unnamed parameter"
 msgstr "складишна класа наведена за параметар %qs"
 
-#: c/c-decl.c:5874 cp/decl.c:10935
+#: c/c-decl.c:5894 cp/decl.c:10959
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "складишна класа наведена за име типа"
 
-#: c/c-decl.c:5891
+#: c/c-decl.c:5911
 #, fuzzy, gcc-internal-format
 #| msgid "%qs initialized and declared %<extern%>"
 msgid "%qE initialized and declared %<extern%>"
 msgstr "%qs успостављено и декларисано као %<extern%>"
 
-#: c/c-decl.c:5895
+#: c/c-decl.c:5915
 #, fuzzy, gcc-internal-format
 #| msgid "%qs has both %<extern%> and initializer"
 msgid "%qE has both %<extern%> and initializer"
 msgstr "%qs има и %<extern%> и успостављач"
 
-#: c/c-decl.c:5900
+#: c/c-decl.c:5920
 #, fuzzy, gcc-internal-format
 #| msgid "file-scope declaration of %qs specifies %<auto%>"
 msgid "file-scope declaration of %qE specifies %<auto%>"
 msgstr "декларација датотечног досега за %qs наводи %<auto%>"
 
-#: c/c-decl.c:5904
+#: c/c-decl.c:5924
 #, fuzzy, gcc-internal-format
 #| msgid "file-scope declaration of %qs specifies %<register%>"
 msgid "file-scope declaration of %qE specifies %<register%>"
 msgstr "декларација датотечног досега за %qs наводи %<register%>"
 
-#: c/c-decl.c:5909
+#: c/c-decl.c:5929
 #, fuzzy, gcc-internal-format
 #| msgid "nested function %qs declared %<extern%>"
 msgid "nested function %qE declared %<extern%>"
 msgstr "угњеждена функција %qs декларисана као %<extern%>"
 
-#: c/c-decl.c:5912
+#: c/c-decl.c:5932
 #, fuzzy, gcc-internal-format
 #| msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgid "function-scope %qE implicitly auto and declared %qs"
@@ -39250,780 +39294,780 @@
 #. Only the innermost declarator (making a parameter be of
 #. array type which is converted to pointer type)
 #. may have static or type qualifiers.
-#: c/c-decl.c:5959 c/c-decl.c:6328
+#: c/c-decl.c:5979 c/c-decl.c:6348
 #, gcc-internal-format
 msgid "static or type qualifiers in non-parameter array declarator"
 msgstr "статичка или одредба типа у непараметарском декларатору низа"
 
-#: c/c-decl.c:6007
+#: c/c-decl.c:6027
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of voids"
 msgid "declaration of %qE as array of voids"
 msgstr "декларација %qs као низа празних"
 
-#: c/c-decl.c:6009
+#: c/c-decl.c:6029
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of voids"
 msgid "declaration of type name as array of voids"
 msgstr "декларација %qs као низа празних"
 
-#: c/c-decl.c:6016
+#: c/c-decl.c:6036
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of %qE as array of functions"
 msgstr "декларација %qs као низа функција"
 
-#: c/c-decl.c:6019
+#: c/c-decl.c:6039
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of type name as array of functions"
 msgstr "декларација %qs као низа функција"
 
-#: c/c-decl.c:6027 c/c-decl.c:8085
+#: c/c-decl.c:6047 c/c-decl.c:8105
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr "неисправна употреба структуре са флексибилним чланским низом"
 
-#: c/c-decl.c:6053
+#: c/c-decl.c:6073
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs has non-integer type"
 msgid "size of array %qE has non-integer type"
 msgstr "величина низа %qs има нецелобројни тип"
 
-#: c/c-decl.c:6057
+#: c/c-decl.c:6077
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs has non-integer type"
 msgid "size of unnamed array has non-integer type"
 msgstr "величина низа %qs има нецелобројни тип"
 
-#: c/c-decl.c:6064
+#: c/c-decl.c:6084
 #, fuzzy, gcc-internal-format
 #| msgid "elements of array %q#D have incomplete type"
 msgid "size of array %qE has incomplete type"
 msgstr "елементи низа %q#D имају непотпун тип"
 
-#: c/c-decl.c:6067
+#: c/c-decl.c:6087
 #, fuzzy, gcc-internal-format
 #| msgid "name %qT has incomplete type"
 msgid "size of unnamed array has incomplete type"
 msgstr "име %qT има непотпун тип"
 
-#: c/c-decl.c:6078
+#: c/c-decl.c:6098
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids zero-size array %qs"
 msgid "ISO C forbids zero-size array %qE"
 msgstr "ИСО Ц забрањује нулту величину низа %qs"
 
-#: c/c-decl.c:6081
+#: c/c-decl.c:6101
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids zero-size array"
 msgid "ISO C forbids zero-size array"
 msgstr "ИСО Ц++ забрањује низ нулте величине"
 
-#: c/c-decl.c:6090
+#: c/c-decl.c:6110
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is negative"
 msgid "size of array %qE is negative"
 msgstr "величина низа %qs је негативна"
 
-#: c/c-decl.c:6092
+#: c/c-decl.c:6112
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is negative"
 msgid "size of unnamed array is negative"
 msgstr "негативна величина низа"
 
-#: c/c-decl.c:6216 c/c-decl.c:6871
+#: c/c-decl.c:6236 c/c-decl.c:6891
 #, gcc-internal-format
 msgid "ISO C90 does not support flexible array members"
 msgstr "ИСО Ц 90 не подржава флексибилне чланске низове"
 
 #. C99 6.7.5.2p4
-#: c/c-decl.c:6238
+#: c/c-decl.c:6258
 #, fuzzy, gcc-internal-format
 #| msgid "%<[*]%> not allowed in other than a declaration"
 msgid "%<[*]%> not in a declaration"
 msgstr "%<[*]%> није дозвољено другде осим у декларацији"
 
-#: c/c-decl.c:6251
+#: c/c-decl.c:6271
 #, fuzzy, gcc-internal-format
 #| msgid "array type has incomplete element type"
 msgid "array type has incomplete element type %qT"
 msgstr "низовни тип има непотпун тип елемента"
 
-#: c/c-decl.c:6257
+#: c/c-decl.c:6277
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgid "declaration of %qE as multidimensional array must have bounds for all dimensions except the first"
 msgstr "декларација %qD као вишедимензионог низа мора имати границе за све димензије осим прве"
 
-#: c/c-decl.c:6261
+#: c/c-decl.c:6281
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgid "declaration of multidimensional array must have bounds for all dimensions except the first"
 msgstr "декларација %qD као вишедимензионог низа мора имати границе за све димензије осим прве"
 
-#: c/c-decl.c:6364
+#: c/c-decl.c:6384
 #, fuzzy, gcc-internal-format
 #| msgid "%qs declared as function returning a function"
 msgid "%qE declared as function returning a function"
 msgstr "%qs декларисано као функција која враћа функцију"
 
-#: c/c-decl.c:6367
+#: c/c-decl.c:6387
 #, fuzzy, gcc-internal-format
 #| msgid "%qs declared as function returning a function"
 msgid "type name declared as function returning a function"
 msgstr "%qs декларисано као функција која враћа функцију"
 
-#: c/c-decl.c:6374
+#: c/c-decl.c:6394
 #, fuzzy, gcc-internal-format
 #| msgid "%qs declared as function returning an array"
 msgid "%qE declared as function returning an array"
 msgstr "%qs декларисано као функција која враћа низ"
 
-#: c/c-decl.c:6377
+#: c/c-decl.c:6397
 #, fuzzy, gcc-internal-format
 #| msgid "%qs declared as function returning an array"
 msgid "type name declared as function returning an array"
 msgstr "%qs декларисано као функција која враћа низ"
 
-#: c/c-decl.c:6418
+#: c/c-decl.c:6438
 #, gcc-internal-format
 msgid "function definition has qualified void return type"
 msgstr "дефиниција функције има одређен празан повратни тип"
 
-#: c/c-decl.c:6421 cp/decl.c:11201
+#: c/c-decl.c:6441 cp/decl.c:11225
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "одредбе типова се игноришу на повратном типу функције"
 
-#: c/c-decl.c:6459 c/c-decl.c:6668 c/c-decl.c:6721 c/c-decl.c:6805
-#: c/c-decl.c:6926 c/c-parser.c:2823
+#: c/c-decl.c:6479 c/c-decl.c:6688 c/c-decl.c:6741 c/c-decl.c:6825
+#: c/c-decl.c:6946 c/c-parser.c:2823
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids qualified function types"
 msgid "%<_Atomic%>-qualified function type"
 msgstr "ИСО Ц забрањује одређене функцијске типове"
 
-#: c/c-decl.c:6465 c/c-decl.c:6674 c/c-decl.c:6810 c/c-decl.c:6931
+#: c/c-decl.c:6485 c/c-decl.c:6694 c/c-decl.c:6830 c/c-decl.c:6951
 #, gcc-internal-format
 msgid "ISO C forbids qualified function types"
 msgstr "ИСО Ц забрањује одређене функцијске типове"
 
-#: c/c-decl.c:6559
+#: c/c-decl.c:6579
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting type qualifiers for %q+D"
 msgid "%qs combined with %<auto%> qualifier for %qE"
 msgstr "сукобљене одредбе типа за %q+D"
 
-#: c/c-decl.c:6563
+#: c/c-decl.c:6583
 #, gcc-internal-format
 msgid "%qs combined with %<register%> qualifier for %qE"
 msgstr ""
 
-#: c/c-decl.c:6569
+#: c/c-decl.c:6589
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid type for iteration variable %qE"
 msgid "%qs specified for auto variable %qE"
 msgstr "%Hнеисправан тип променљиве итерације %qE"
 
-#: c/c-decl.c:6585
+#: c/c-decl.c:6605
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "%qs specified for parameter %qE"
 msgstr "складишна класа наведена за параметар %qs"
 
-#: c/c-decl.c:6588
+#: c/c-decl.c:6608
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "%qs specified for unnamed parameter"
 msgstr "складишна класа наведена за параметар %qs"
 
-#: c/c-decl.c:6594
+#: c/c-decl.c:6614
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for structure field %qs"
 msgid "%qs specified for structure field %qE"
 msgstr "складишна класа наведена за поље структуре %qs"
 
-#: c/c-decl.c:6597
+#: c/c-decl.c:6617
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for structure field %qs"
 msgid "%qs specified for structure field"
 msgstr "складишна класа наведена за поље структуре %qs"
 
-#: c/c-decl.c:6612
+#: c/c-decl.c:6632
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qs has invalid type"
 msgid "bit-field %qE has atomic type"
 msgstr "битско поље %qs има неисправан тип"
 
-#: c/c-decl.c:6614
+#: c/c-decl.c:6634
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qs has invalid type"
 msgid "bit-field has atomic type"
 msgstr "битско поље %qs има неисправан тип"
 
-#: c/c-decl.c:6623
+#: c/c-decl.c:6643
 #, fuzzy, gcc-internal-format
 #| msgid "alignment may not be specified for %q+D"
 msgid "alignment specified for typedef %qE"
 msgstr "равнање се не може навести за %q+D"
 
-#: c/c-decl.c:6625
+#: c/c-decl.c:6645
 #, fuzzy, gcc-internal-format
 #| msgid "alignment may not be specified for %q+D"
 msgid "alignment specified for %<register%> object %qE"
 msgstr "равнање се не може навести за %q+D"
 
-#: c/c-decl.c:6630
+#: c/c-decl.c:6650
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "alignment specified for parameter %qE"
 msgstr "складишна класа наведена за параметар %qs"
 
-#: c/c-decl.c:6632
+#: c/c-decl.c:6652
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "alignment specified for unnamed parameter"
 msgstr "складишна класа наведена за параметар %qs"
 
-#: c/c-decl.c:6637
+#: c/c-decl.c:6657
 #, fuzzy, gcc-internal-format
 #| msgid "alignment may not be specified for %q+D"
 msgid "alignment specified for bit-field %qE"
 msgstr "равнање се не може навести за %q+D"
 
-#: c/c-decl.c:6639
+#: c/c-decl.c:6659
 #, fuzzy, gcc-internal-format
 #| msgid "%<__alignof%> applied to a bit-field"
 msgid "alignment specified for unnamed bit-field"
 msgstr "%<__alignof%> примењено на битско поље"
 
-#: c/c-decl.c:6642
+#: c/c-decl.c:6662
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "alignment specified for function %qE"
 msgstr "%qs може бити наведено само за функције"
 
-#: c/c-decl.c:6649
+#: c/c-decl.c:6669
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of %qE"
 msgstr ""
 
-#: c/c-decl.c:6652
+#: c/c-decl.c:6672
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of unnamed field"
 msgstr ""
 
-#: c/c-decl.c:6683
+#: c/c-decl.c:6703
 #, gcc-internal-format
 msgid "typedef %q+D declared %<inline%>"
 msgstr "дефиниција типа %q+D декларисана као %<inline%>"
 
-#: c/c-decl.c:6685
+#: c/c-decl.c:6705
 #, fuzzy, gcc-internal-format
 #| msgid "typedef %q+D declared %<inline%>"
 msgid "typedef %q+D declared %<_Noreturn%>"
 msgstr "дефиниција типа %q+D декларисана као %<inline%>"
 
-#: c/c-decl.c:6727
+#: c/c-decl.c:6747
 #, gcc-internal-format
 msgid "ISO C forbids const or volatile function types"
 msgstr "ИСО Ц забрањује константне или непостојане функцијске типове"
 
 #. C99 6.7.2.1p8
-#: c/c-decl.c:6738
+#: c/c-decl.c:6758
 #, gcc-internal-format
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "члан структуре или уније не може имати променљиво измењив тип"
 
-#: c/c-decl.c:6755 cp/decl.c:9989
+#: c/c-decl.c:6775 cp/decl.c:10010
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "променљива или поље %qE декларисано празним"
 
-#: c/c-decl.c:6795
+#: c/c-decl.c:6815
 #, gcc-internal-format
 msgid "attributes in parameter array declarator ignored"
 msgstr "атрибути у параметарском декларатору низа игнорисани"
 
-#: c/c-decl.c:6837
+#: c/c-decl.c:6857
 #, gcc-internal-format
 msgid "parameter %q+D declared %<inline%>"
 msgstr "параметар %q+D декларисан као %<inline%>"
 
-#: c/c-decl.c:6839
+#: c/c-decl.c:6859
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared %<inline%>"
 msgid "parameter %q+D declared %<_Noreturn%>"
 msgstr "параметар %q+D декларисан као %<inline%>"
 
-#: c/c-decl.c:6852
+#: c/c-decl.c:6872
 #, fuzzy, gcc-internal-format
 #| msgid "field %qs declared as a function"
 msgid "field %qE declared as a function"
 msgstr "поље %qs декларисано као функција"
 
-#: c/c-decl.c:6859
+#: c/c-decl.c:6879
 #, fuzzy, gcc-internal-format
 #| msgid "field %qs has incomplete type"
 msgid "field %qE has incomplete type"
 msgstr "поље %qs има непотпун тип"
 
-#: c/c-decl.c:6861
+#: c/c-decl.c:6881
 #, fuzzy, gcc-internal-format
 #| msgid "name %qT has incomplete type"
 msgid "unnamed field has incomplete type"
 msgstr "име %qT има непотпун тип"
 
-#: c/c-decl.c:6897 c/c-decl.c:6908 c/c-decl.c:6911
+#: c/c-decl.c:6917 c/c-decl.c:6928 c/c-decl.c:6931
 #, fuzzy, gcc-internal-format
 #| msgid "invalid storage class for function %qs"
 msgid "invalid storage class for function %qE"
 msgstr "неисправна складишна класа за функцију %qs"
 
-#: c/c-decl.c:6968
+#: c/c-decl.c:6988
 #, gcc-internal-format
 msgid "cannot inline function %<main%>"
 msgstr "функција %<main%> се не може уткати"
 
-#: c/c-decl.c:6970
+#: c/c-decl.c:6990
 #, fuzzy, gcc-internal-format
 #| msgid "%qs initialized and declared %<extern%>"
 msgid "%<main%> declared %<_Noreturn%>"
 msgstr "%qs успостављено и декларисано као %<extern%>"
 
-#: c/c-decl.c:6981
+#: c/c-decl.c:7001
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<long long%>"
 msgid "ISO C99 does not support %<_Noreturn%>"
 msgstr "ИСО Ц 90 не подржава %<long long%>"
 
-#: c/c-decl.c:6984
+#: c/c-decl.c:7004
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<long long%>"
 msgid "ISO C90 does not support %<_Noreturn%>"
 msgstr "ИСО Ц 90 не подржава %<long long%>"
 
-#: c/c-decl.c:7013
+#: c/c-decl.c:7033
 #, gcc-internal-format
 msgid "variable previously declared %<static%> redeclared %<extern%>"
 msgstr "променљива претходно декларисана као %<static%> поново декларисана као %<extern%>"
 
-#: c/c-decl.c:7023
+#: c/c-decl.c:7043
 #, gcc-internal-format
 msgid "variable %q+D declared %<inline%>"
 msgstr "променљива %q+D декларисана као %<inline%>"
 
-#: c/c-decl.c:7025
+#: c/c-decl.c:7045
 #, fuzzy, gcc-internal-format
 #| msgid "variable %q+D declared %<inline%>"
 msgid "variable %q+D declared %<_Noreturn%>"
 msgstr "променљива %q+D декларисана као %<inline%>"
 
-#: c/c-decl.c:7060
+#: c/c-decl.c:7080
 #, fuzzy, gcc-internal-format
 #| msgid "jump into scope of identifier with variably modified type"
 msgid "non-nested function with variably modified type"
 msgstr "скок у досег идентификатора са променљиво измењивим типом"
 
-#: c/c-decl.c:7062
+#: c/c-decl.c:7082
 #, gcc-internal-format
 msgid "object with variably modified type must have no linkage"
 msgstr "објекат променљиво измењивог типа не може имати повезивост"
 
-#: c/c-decl.c:7153 c/c-decl.c:8821
+#: c/c-decl.c:7173 c/c-decl.c:8841
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr "декларација функције није прототип"
 
-#: c/c-decl.c:7163
+#: c/c-decl.c:7183
 #, gcc-internal-format
 msgid "parameter names (without types) in function declaration"
 msgstr "имена параметара (без типова) у декларацији функције"
 
-#: c/c-decl.c:7201
+#: c/c-decl.c:7221
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has incomplete type"
 msgstr "параметар %u (%q+D) има непотпун тип"
 
-#: c/c-decl.c:7205
+#: c/c-decl.c:7225
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%Jparameter %u has incomplete type"
 msgid "parameter %u has incomplete type"
 msgstr "%Jпараметар %u има непотпун тип"
 
-#: c/c-decl.c:7216
+#: c/c-decl.c:7236
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has void type"
 msgstr "параметар %u (%q+D) има празан тип"
 
-#: c/c-decl.c:7220
+#: c/c-decl.c:7240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%Jparameter %u has void type"
 msgid "parameter %u has void type"
 msgstr "%Jпараметар %u има празан тип"
 
-#: c/c-decl.c:7294
+#: c/c-decl.c:7314
 #, gcc-internal-format
 msgid "%<void%> as only parameter may not be qualified"
 msgstr "%<void%> као једини параметар не може бити одређен"
 
-#: c/c-decl.c:7298 c/c-decl.c:7334
+#: c/c-decl.c:7318 c/c-decl.c:7354
 #, gcc-internal-format
 msgid "%<void%> must be the only parameter"
 msgstr "%<void%> мора бити једини параметар"
 
-#: c/c-decl.c:7328
+#: c/c-decl.c:7348
 #, gcc-internal-format
 msgid "parameter %q+D has just a forward declaration"
 msgstr "параметар %q+D има само унапредну декларацију"
 
-#: c/c-decl.c:7374
+#: c/c-decl.c:7394
 #, gcc-internal-format
 msgid "%<%s %E%> declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr ""
 
-#: c/c-decl.c:7380
+#: c/c-decl.c:7400
 #, gcc-internal-format, gfc-internal-format
 msgid "anonymous %s declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr ""
 
-#: c/c-decl.c:7482
+#: c/c-decl.c:7502
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "enum type defined here"
 msgstr "%q+#D претходно дефинисано овде"
 
-#: c/c-decl.c:7488
+#: c/c-decl.c:7508
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "struct defined here"
 msgstr "%q+#D претходно дефинисано овде"
 
-#: c/c-decl.c:7494
+#: c/c-decl.c:7514
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "union defined here"
 msgstr "%q+#D претходно дефинисано овде"
 
-#: c/c-decl.c:7570
+#: c/c-decl.c:7590
 #, gcc-internal-format
 msgid "redefinition of %<union %E%>"
 msgstr "поновна дефиниција %<union %E%>"
 
-#: c/c-decl.c:7572
+#: c/c-decl.c:7592
 #, gcc-internal-format
 msgid "redefinition of %<struct %E%>"
 msgstr "поновна дефиниција %<struct %E%>"
 
-#: c/c-decl.c:7581
+#: c/c-decl.c:7601
 #, gcc-internal-format
 msgid "nested redefinition of %<union %E%>"
 msgstr "угњеждена поновна дефиниција %<union %E%>"
 
-#: c/c-decl.c:7583
+#: c/c-decl.c:7603
 #, gcc-internal-format
 msgid "nested redefinition of %<struct %E%>"
 msgstr "угњеждена поновна дефиниција %<struct %E%>"
 
-#: c/c-decl.c:7613 c/c-decl.c:8400
+#: c/c-decl.c:7633 c/c-decl.c:8420
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:7680 cp/decl.c:4802
+#: c/c-decl.c:7700 cp/decl.c:4802
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "декларација ништа не декларише"
 
-#: c/c-decl.c:7685
+#: c/c-decl.c:7705
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C doesn%'t support unnamed structs/unions"
 msgid "ISO C99 doesn%'t support unnamed structs/unions"
 msgstr "ИСО Ц не подржава неименоване струкутре/уније"
 
-#: c/c-decl.c:7688
+#: c/c-decl.c:7708
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C doesn%'t support unnamed structs/unions"
 msgid "ISO C90 doesn%'t support unnamed structs/unions"
 msgstr "ИСО Ц не подржава неименоване струкутре/уније"
 
-#: c/c-decl.c:7781 c/c-decl.c:7799 c/c-decl.c:7860
+#: c/c-decl.c:7801 c/c-decl.c:7819 c/c-decl.c:7880
 #, gcc-internal-format
 msgid "duplicate member %q+D"
 msgstr "удвостручени члан %q+D"
 
-#: c/c-decl.c:7886
+#: c/c-decl.c:7906
 #, gcc-internal-format
 msgid "empty struct has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.c:7889
+#: c/c-decl.c:7909
 #, gcc-internal-format
 msgid "empty union has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.c:7994
+#: c/c-decl.c:8014
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr "унија нема именованих чланова"
 
-#: c/c-decl.c:7996
+#: c/c-decl.c:8016
 #, gcc-internal-format
 msgid "union has no members"
 msgstr "унија нема чланова"
 
-#: c/c-decl.c:8001
+#: c/c-decl.c:8021
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr "структура нема именованих чланова"
 
-#: c/c-decl.c:8003
+#: c/c-decl.c:8023
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr "структура нема чланова"
 
-#: c/c-decl.c:8064 cp/decl.c:12069
+#: c/c-decl.c:8084 cp/decl.c:12093
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in union"
 msgid "flexible array member in union"
 msgstr "%Jфлексибилан члански низ у унији"
 
-#: c/c-decl.c:8070
+#: c/c-decl.c:8090
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member not at end of struct"
 msgid "flexible array member not at end of struct"
 msgstr "%Jфлексибилан члански низ није на крају структуре"
 
-#: c/c-decl.c:8076
+#: c/c-decl.c:8096
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in union"
 msgid "flexible array member in a struct with no named members"
 msgstr "%Jфлексибилан члански низ у унији"
 
-#: c/c-decl.c:8107
+#: c/c-decl.c:8127
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "type %qT is too large"
 msgstr "величина низа %qs је превелика"
 
-#: c/c-decl.c:8230
+#: c/c-decl.c:8250
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr "унија не може бити учињена провидном"
 
-#: c/c-decl.c:8372
+#: c/c-decl.c:8392
 #, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr "угњеждена поновна дефиниција %<enum %E%>"
 
 #. This enum is a named one that has been declared already.
-#: c/c-decl.c:8379
+#: c/c-decl.c:8399
 #, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr "поновљена декларација %<enum %E%>"
 
-#: c/c-decl.c:8458 cp/decl.c:14423
+#: c/c-decl.c:8478 cp/decl.c:14447
 #, gcc-internal-format
 msgid "specified mode too small for enumeral values"
 msgstr "наведени режим је премали за набројиве вредности"
 
-#: c/c-decl.c:8473
+#: c/c-decl.c:8493
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr "вредности у набрајању премашују опсег највећег целог броја"
 
-#: c/c-decl.c:8587 c/c-decl.c:8603
+#: c/c-decl.c:8607 c/c-decl.c:8623
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr "вредност набрајача за %qE није целобројна константа"
 
-#: c/c-decl.c:8598
+#: c/c-decl.c:8618
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qE is not an integer constant"
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr "вредност набрајача за %qE није целобројна константа"
 
-#: c/c-decl.c:8622
+#: c/c-decl.c:8642
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr "преливање у вредностима набрајача"
 
-#: c/c-decl.c:8630
+#: c/c-decl.c:8650
 #, gcc-internal-format
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "ИСО Ц ограничава вредности набрајача на опсег %<int%>"
 
-#: c/c-decl.c:8715 cp/decl.c:5104 cp/decl.c:14955
+#: c/c-decl.c:8735 cp/decl.c:5104 cp/decl.c:14979
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D given attribute noinline"
 msgid "inline function %qD given attribute noinline"
 msgstr "утканој функцији %q+D дат је атрибут noinline"
 
-#: c/c-decl.c:8733
+#: c/c-decl.c:8753
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr "повратни тип је непотпун тип"
 
-#: c/c-decl.c:8744
+#: c/c-decl.c:8764
 #, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr "повратни тип спада на %<int%>"
 
-#: c/c-decl.c:8771
+#: c/c-decl.c:8791
 #, fuzzy, gcc-internal-format
 #| msgid "Warn about global functions without prototypes"
 msgid "%q+D defined as variadic function without prototype"
 msgstr "Упозори на глобалне функције без прототипа"
 
-#: c/c-decl.c:8830
+#: c/c-decl.c:8850
 #, fuzzy, gcc-internal-format
 #| msgid "no previous prototype for %q+D"
 msgid "no previous prototype for %qD"
 msgstr "нема претходног прототипа за %q+D"
 
-#: c/c-decl.c:8839
+#: c/c-decl.c:8859
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was used with no prototype before its definition"
 msgid "%qD was used with no prototype before its definition"
 msgstr "%q+D је употребљено без прототипа пре дефиниције"
 
-#: c/c-decl.c:8847 cp/decl.c:15090
+#: c/c-decl.c:8867 cp/decl.c:15114
 #, fuzzy, gcc-internal-format
 #| msgid "no previous declaration for %q+D"
 msgid "no previous declaration for %qD"
 msgstr "нема претходне декларације за %q+D"
 
-#: c/c-decl.c:8857
+#: c/c-decl.c:8877
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was used with no declaration before its definition"
 msgid "%qD was used with no declaration before its definition"
 msgstr "%q+D је употребљено без декларације пре дефиниције"
 
-#: c/c-decl.c:8876
+#: c/c-decl.c:8896
 #, fuzzy, gcc-internal-format
 #| msgid "return type of %q+D is not %<int%>"
 msgid "return type of %qD is not %<int%>"
 msgstr "повратни тип за %q+D није %<int%>"
 
-#: c/c-decl.c:8878
+#: c/c-decl.c:8898
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr ""
 
-#: c/c-decl.c:8885
+#: c/c-decl.c:8905
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is normally a non-static function"
 msgid "%qD is normally a non-static function"
 msgstr "%q+D је обично нестатичка функција"
 
-#: c/c-decl.c:8922
+#: c/c-decl.c:8942
 #, fuzzy, gcc-internal-format
 #| msgid "%Jold-style parameter declarations in prototyped function definition"
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr "%Jстаровремска декларација параметара у дефиницији функције са прототипом"
 
-#: c/c-decl.c:8937
+#: c/c-decl.c:8957
 #, fuzzy, gcc-internal-format
 #| msgid "%Jtraditional C rejects ISO C style function definitions"
 msgid "traditional C rejects ISO C style function definitions"
 msgstr "%Jтрадиционални Ц одбија дефиниције функција у стилу ИСО Ц-а"
 
-#: c/c-decl.c:8953
+#: c/c-decl.c:8973
 #, fuzzy, gcc-internal-format
 #| msgid "%Jparameter name omitted"
 msgid "parameter name omitted"
 msgstr "%Jизостављено име параметра"
 
-#: c/c-decl.c:8990
+#: c/c-decl.c:9010
 #, fuzzy, gcc-internal-format
 #| msgid "%Jold-style function definition"
 msgid "old-style function definition"
 msgstr "%Jстаровремска дефиниција функције"
 
-#: c/c-decl.c:8999
+#: c/c-decl.c:9019
 #, fuzzy, gcc-internal-format
 #| msgid "%Jparameter name missing from parameter list"
 msgid "parameter name missing from parameter list"
 msgstr "%Jнедостаје име параметра у листи параметара"
 
-#: c/c-decl.c:9015
+#: c/c-decl.c:9035
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a non-parameter"
 msgid "%qD declared as a non-parameter"
 msgstr "%q+D декларисано као не-параметарско"
 
-#: c/c-decl.c:9023
+#: c/c-decl.c:9043
 #, fuzzy, gcc-internal-format
 #| msgid "multiple parameters named %q+D"
 msgid "multiple parameters named %qD"
 msgstr "више параметара по имену %q+D"
 
-#: c/c-decl.c:9032
+#: c/c-decl.c:9052
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared with void type"
 msgid "parameter %qD declared with void type"
 msgstr "параметар %q+D декларисан са празним типом"
 
-#: c/c-decl.c:9061 c/c-decl.c:9066
+#: c/c-decl.c:9081 c/c-decl.c:9086
 #, fuzzy, gcc-internal-format
 #| msgid "type of %q+D defaults to %<int%>"
 msgid "type of %qD defaults to %<int%>"
 msgstr "тип за %q+D спада на %<int%>"
 
-#: c/c-decl.c:9086
+#: c/c-decl.c:9106
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D has incomplete type"
 msgid "parameter %qD has incomplete type"
 msgstr "параметар %q+D има непотпун тип"
 
-#: c/c-decl.c:9093
+#: c/c-decl.c:9113
 #, fuzzy, gcc-internal-format
 #| msgid "declaration for parameter %q+D but no such parameter"
 msgid "declaration for parameter %qD but no such parameter"
 msgstr "декларација за параметар %q+D, али нема таквог"
 
-#: c/c-decl.c:9146
+#: c/c-decl.c:9166
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr "број аргумената не одговора уграђеном прототипу"
 
-#: c/c-decl.c:9157
+#: c/c-decl.c:9177
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr "број аргумената не одговара прототипу"
 
-#: c/c-decl.c:9160 c/c-decl.c:9207 c/c-decl.c:9221
+#: c/c-decl.c:9180 c/c-decl.c:9227 c/c-decl.c:9241
 #, fuzzy, gcc-internal-format
 #| msgid "%Hprototype declaration"
 msgid "prototype declaration"
 msgstr "%Hдекларација прототипа"
 
-#: c/c-decl.c:9199
+#: c/c-decl.c:9219
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr "унапређени аргумент %qD не одговара уграђеном прототипу"
 
-#: c/c-decl.c:9204
+#: c/c-decl.c:9224
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr "унапређени аргумент %qD не одговара прототипу"
 
-#: c/c-decl.c:9214
+#: c/c-decl.c:9234
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr "аргумент %qD не одговара уграђеном прототипу"
 
-#: c/c-decl.c:9219
+#: c/c-decl.c:9239
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr "аргумент %qD не одговара прототипу"
 
-#: c/c-decl.c:9470 cp/decl.c:15873
+#: c/c-decl.c:9490 cp/decl.c:15897
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "нема повратне наредбе у функцији која враћа непразан тип"
 
-#: c/c-decl.c:9490 cp/decl.c:15905
+#: c/c-decl.c:9510 cp/decl.c:15929
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD is initialized"
 msgid "parameter %qD set but not used"
@@ -40032,269 +40076,269 @@
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:9586
+#: c/c-decl.c:9606
 #, fuzzy, gcc-internal-format
 #| msgid "%<for%> loop initial declaration used outside C99 mode"
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "Почетна декларација у %<for%> петљи употребљена ван режима Ц-а 99"
 
-#: c/c-decl.c:9591
+#: c/c-decl.c:9611
 #, gcc-internal-format
 msgid "use option -std=c99, -std=gnu99, -std=c11 or -std=gnu11 to compile your code"
 msgstr ""
 
-#: c/c-decl.c:9626
+#: c/c-decl.c:9646
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of static variable %q+D in %<for%> loop initial declaration"
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "декларација статичке променљиве %q+D у почетној декларацији %<for%> петље"
 
-#: c/c-decl.c:9630
+#: c/c-decl.c:9650
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %<extern%> variable %q+D in %<for%> loop initial declaration"
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "декларација спољашње променљиве %q+D у почетној декларацији %<for%> петље"
 
-#: c/c-decl.c:9637
+#: c/c-decl.c:9657
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "%<struct %E%> декларисана у почетној декларацији %<for%> петље"
 
-#: c/c-decl.c:9642
+#: c/c-decl.c:9662
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "%<union %E%> декларисана у почетној декларацији %<for%> петље"
 
-#: c/c-decl.c:9646
+#: c/c-decl.c:9666
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "%<enum %E%> декларисан у почетној декларацији %<for%> петље"
 
-#: c/c-decl.c:9650
+#: c/c-decl.c:9670
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of non-variable %q+D in %<for%> loop initial declaration"
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "декларација не-променљиве %q+D у почетној декларацији %<for%> петље"
 
-#: c/c-decl.c:9900
+#: c/c-decl.c:9920
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr ""
 
-#: c/c-decl.c:9958 c/c-decl.c:9965
+#: c/c-decl.c:9978 c/c-decl.c:9985
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "duplicate %qE declaration specifier"
 msgstr "очекивани су наводиоци декларације"
 
-#: c/c-decl.c:9992 c/c-decl.c:10376 c/c-decl.c:10766
+#: c/c-decl.c:10012 c/c-decl.c:10396 c/c-decl.c:10786
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr "два или више типова података у наводиоцима декларације"
 
-#: c/c-decl.c:10004 cp/parser.c:28261
+#: c/c-decl.c:10024 cp/parser.c:28258
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> је предуго за ГЦЦ"
 
-#: c/c-decl.c:10017
+#: c/c-decl.c:10037
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ИСО Ц 90 не подржава %<long long%>"
 
-#: c/c-decl.c:10246 c/c-parser.c:8848
+#: c/c-decl.c:10266 c/c-parser.c:8848
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ИСО Ц 90 не подржава комплексне типове"
 
-#: c/c-decl.c:10292
+#: c/c-decl.c:10312
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support saturating types"
 msgstr "ИСО Ц не подржава комплексне целобројне типове"
 
-#: c/c-decl.c:10363 c/c-decl.c:10923
+#: c/c-decl.c:10383 c/c-decl.c:10943
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "удвостручено %qE"
 
-#: c/c-decl.c:10419
+#: c/c-decl.c:10439
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ИСО Ц не подржава комплексне целобројне типове"
 
-#: c/c-decl.c:10441
+#: c/c-decl.c:10461
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "%<__int%d%> is not supported on this target"
 msgstr "ограничења стека нису подржана на овом циљу"
 
-#: c/c-decl.c:10484
+#: c/c-decl.c:10504
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support complex types"
 msgid "ISO C90 does not support boolean types"
 msgstr "ИСО Ц 90 не подржава комплексне типове"
 
-#: c/c-decl.c:10603
+#: c/c-decl.c:10623
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support complex types"
 msgid "ISO C does not support the %<_Float%d%s%> type"
 msgstr "ИСО Ц 90 не подржава комплексне типове"
 
-#: c/c-decl.c:10653
+#: c/c-decl.c:10673
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "ограничења стека нису подржана на овом циљу"
 
-#: c/c-decl.c:10724
+#: c/c-decl.c:10744
 #, gcc-internal-format
 msgid "ISO C does not support decimal floating point"
 msgstr "ИСО Ц не подржава децимални покретни зарез"
 
-#: c/c-decl.c:10747 c/c-decl.c:11013 c/c-parser.c:7842
+#: c/c-decl.c:10767 c/c-decl.c:11033 c/c-parser.c:7842
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "fixed-point types not supported for this target"
 msgstr "-fdata-sections није подржано за овај циљ"
 
-#: c/c-decl.c:10749
+#: c/c-decl.c:10769
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support fixed-point types"
 msgstr "ИСО Ц не подржава комплексне целобројне типове"
 
-#: c/c-decl.c:10784
+#: c/c-decl.c:10804
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr ""
 
-#: c/c-decl.c:10797
+#: c/c-decl.c:10817
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr "%qE није ни по дефиницији типа ни уграђени тип"
 
-#: c/c-decl.c:10845
+#: c/c-decl.c:10865
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qE није на почетку декларације"
 
-#: c/c-decl.c:10866
+#: c/c-decl.c:10886
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<auto%>"
 msgid "%qE used with %<auto%>"
 msgstr "%<__thread%> употребљено уз %<auto%>"
 
-#: c/c-decl.c:10868
+#: c/c-decl.c:10888
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<register%>"
 msgid "%qE used with %<register%>"
 msgstr "%<__thread%> употребљено уз %<register%>"
 
-#: c/c-decl.c:10870
+#: c/c-decl.c:10890
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<typedef%>"
 msgid "%qE used with %<typedef%>"
 msgstr "%<__thread%> употребљено уз %<typedef%>"
 
-#: c/c-decl.c:10884 c/c-parser.c:7360
+#: c/c-decl.c:10904 c/c-parser.c:7360
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "ISO C99 does not support %qE"
 msgstr "%s не подржава %s"
 
-#: c/c-decl.c:10887 c/c-parser.c:7363
+#: c/c-decl.c:10907 c/c-parser.c:7363
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<long long%>"
 msgid "ISO C90 does not support %qE"
 msgstr "ИСО Ц 90 не подржава %<long long%>"
 
-#: c/c-decl.c:10899
+#: c/c-decl.c:10919
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<__thread%> пре %<extern%>"
 
-#: c/c-decl.c:10908
+#: c/c-decl.c:10928
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<__thread%> пре %<static%>"
 
-#: c/c-decl.c:10921
+#: c/c-decl.c:10941
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr ""
 
-#: c/c-decl.c:10929
+#: c/c-decl.c:10949
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr "вишеструке складишне класе у наводиоцима декларације"
 
-#: c/c-decl.c:10937
+#: c/c-decl.c:10957
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %qE"
 msgid "%qs used with %qE"
 msgstr "%<__thread%> употребљено уз %qE"
 
-#: c/c-decl.c:11010
+#: c/c-decl.c:11030
 #, fuzzy, gcc-internal-format
 #| msgid "%<@try%> without %<@catch%> or %<@finally%>"
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "%<@try%> без %<@catch%> или %<@finally%>"
 
-#: c/c-decl.c:11025
+#: c/c-decl.c:11045
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ИСО Ц не подржава да обичан %<complex%> значи %<double complex%>"
 
-#: c/c-decl.c:11076 c/c-decl.c:11092 c/c-decl.c:11118
+#: c/c-decl.c:11096 c/c-decl.c:11112 c/c-decl.c:11138
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ИСО Ц не подржава комплексне целобројне типове"
 
-#: c/c-decl.c:11514 cp/semantics.c:5348
+#: c/c-decl.c:11534 cp/semantics.c:5351
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:11518 cp/semantics.c:5352
+#: c/c-decl.c:11538 cp/semantics.c:5355
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.c:385 c/c-typeck.c:11426 cp/typeck.c:4680
+#: c/c-fold.c:385 c/c-typeck.c:11431 cp/typeck.c:4680
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count is negative"
 msgid "left shift of negative value"
 msgstr "негативан леви помак"
 
-#: c/c-fold.c:395 c/c-typeck.c:11435 cp/typeck.c:4688
+#: c/c-fold.c:395 c/c-typeck.c:11440 cp/typeck.c:4688
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "негативан леви помак"
 
-#: c/c-fold.c:396 c/c-typeck.c:11365 cp/typeck.c:4633
+#: c/c-fold.c:396 c/c-typeck.c:11370 cp/typeck.c:4633
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "негативан десни помак"
 
-#: c/c-fold.c:404 c/c-typeck.c:11454 cp/typeck.c:4696
+#: c/c-fold.c:404 c/c-typeck.c:11459 cp/typeck.c:4696
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "леви помак >= од ширине типа"
 
-#: c/c-fold.c:405 c/c-typeck.c:11389 cp/typeck.c:4641
+#: c/c-fold.c:405 c/c-typeck.c:11394 cp/typeck.c:4641
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "десни помак >= од ширине типа"
 
-#: c/c-fold.c:412 c/c-typeck.c:11446
+#: c/c-fold.c:412 c/c-typeck.c:11451
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count >= width of type"
 msgid "left shift count >= width of vector element"
 msgstr "леви помак >= од ширине типа"
 
-#: c/c-fold.c:413 c/c-typeck.c:11376
+#: c/c-fold.c:413 c/c-typeck.c:11381
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count >= width of type"
 msgid "right shift count >= width of vector element"
@@ -40315,7 +40359,7 @@
 msgid "to match this %qs"
 msgstr ""
 
-#: c/c-parser.c:1216 cp/parser.c:28484
+#: c/c-parser.c:1216 cp/parser.c:28481
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of module"
 msgid "expected end of line"
@@ -40360,7 +40404,7 @@
 msgstr "непознато име регистра: %s"
 
 #: c/c-parser.c:1848 c/c-parser.c:11129 c/c-parser.c:16147 c/c-parser.c:16585
-#: c/c-parser.c:17061 cp/parser.c:36007 cp/parser.c:38993
+#: c/c-parser.c:17061 cp/parser.c:36004 cp/parser.c:38990
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "очекивани су наводиоци декларације"
@@ -40377,7 +40421,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "очекиван је идентификатор или %<(%>"
 
-#: c/c-parser.c:1906 cp/parser.c:30161 cp/parser.c:30235
+#: c/c-parser.c:1906 cp/parser.c:30158 cp/parser.c:30232
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored for %qE"
 msgid "prefix attributes are ignored for methods"
@@ -40438,7 +40482,7 @@
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr ""
 
-#: c/c-parser.c:2220 cp/parser.c:13002 cp/parser.c:13159
+#: c/c-parser.c:2220 cp/parser.c:12999 cp/parser.c:13156
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "очекивано је %<,%> или %<;%>"
@@ -40468,7 +40512,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ИСО Ц 90 не подржава %<long long%>"
 
-#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38634
+#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38631
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr "очекивана је дословна ниска"
@@ -40540,13 +40584,13 @@
 #: c/c-parser.c:10745 c/c-parser.c:10798 c/c-parser.c:10814 c/c-parser.c:10860
 #: c/c-parser.c:11496 c/c-parser.c:11537 c/c-parser.c:13445 c/c-parser.c:13681
 #: c/c-parser.c:15544 c/c-parser.c:18218 c/gimple-parser.c:1058
-#: c/gimple-parser.c:1096 cp/parser.c:28487 cp/parser.c:31013
-#: cp/parser.c:31043 cp/parser.c:31113 cp/parser.c:33230 cp/parser.c:38350
+#: c/gimple-parser.c:1096 cp/parser.c:28484 cp/parser.c:31010
+#: cp/parser.c:31040 cp/parser.c:31110 cp/parser.c:33227 cp/parser.c:38347
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "очекиван је идентификатор"
 
-#: c/c-parser.c:2995 cp/parser.c:18384
+#: c/c-parser.c:2995 cp/parser.c:18381
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "зарез на крају листе набрајања"
@@ -40719,13 +40763,13 @@
 msgid "expected statement"
 msgstr "очекивана је наредба"
 
-#: c/c-parser.c:5639 cp/parser.c:12516
+#: c/c-parser.c:5639 cp/parser.c:12513
 #, fuzzy, gcc-internal-format
 #| msgid "%Hempty body in an if-statement"
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "%Hпразно тело у наредби if"
 
-#: c/c-parser.c:5681 cp/parser.c:12519
+#: c/c-parser.c:5681 cp/parser.c:12516
 #, fuzzy, gcc-internal-format
 #| msgid "%Hempty body in an else-statement"
 msgid "suggest braces around empty body in an %<else%> statement"
@@ -41103,7 +41147,7 @@
 msgid "%<__builtin_complex%> operands of different types"
 msgstr "%<__builtin_longjmp%> други аргумент мора бити 1"
 
-#: c/c-parser.c:8891 cp/parser.c:6918
+#: c/c-parser.c:8891 cp/parser.c:6921
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for %qs attribute"
 msgid "wrong number of arguments to %<__builtin_shuffle%>"
@@ -41167,83 +41211,83 @@
 msgid "no type or storage class may be specified here,"
 msgstr "складишна класа наведена за %qs"
 
-#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31073
+#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31070
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr ""
 
-#: c/c-parser.c:10682 cp/parser.c:31033
+#: c/c-parser.c:10682 cp/parser.c:31030
 #, fuzzy, gcc-internal-format
 #| msgid "missing %<(%> after %<#pragma pack%> - ignored"
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "недостаје %<(%> после %<#pragma pack%> — игноришем"
 
-#: c/c-parser.c:10685 cp/parser.c:31036
+#: c/c-parser.c:10685 cp/parser.c:31033
 #, fuzzy, gcc-internal-format
 #| msgid "missing %<(%> after %<#pragma pack%> - ignored"
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "недостаје %<(%> после %<#pragma pack%> — игноришем"
 
-#: c/c-parser.c:10699 cp/parser.c:31051
+#: c/c-parser.c:10699 cp/parser.c:31048
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsection attribute cannot be specified for local variables"
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "%Jатрибут одељка се не може навести за локалне променљиве"
 
-#: c/c-parser.c:10704 cp/parser.c:31057
+#: c/c-parser.c:10704 cp/parser.c:31054
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.c:10711 cp/parser.c:31065
+#: c/c-parser.c:10711 cp/parser.c:31062
 #, fuzzy, gcc-internal-format
 #| msgid "%Jaddress area attribute cannot be specified for functions"
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "%Jадресна област атрибута не може бити наведена за функције"
 
-#: c/c-parser.c:10905 cp/parser.c:38674
+#: c/c-parser.c:10905 cp/parser.c:38671
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
 #: c/c-parser.c:10949 c/c-parser.c:16582 c/c-parser.c:16840 c/c-parser.c:16899
-#: c/c-parser.c:16983 cp/parser.c:36004 cp/parser.c:36298 cp/parser.c:36386
-#: cp/parser.c:36457 cp/parser.c:38721 cp/parser.c:38736 cp/parser.c:38752
-#: cp/parser.c:38768 cp/parser.c:38784 cp/parser.c:38811 cp/parser.c:38824
-#: cp/parser.c:38847 cp/parser.c:38860
+#: c/c-parser.c:16983 cp/parser.c:36001 cp/parser.c:36295 cp/parser.c:36383
+#: cp/parser.c:36454 cp/parser.c:38718 cp/parser.c:38733 cp/parser.c:38749
+#: cp/parser.c:38765 cp/parser.c:38781 cp/parser.c:38808 cp/parser.c:38821
+#: cp/parser.c:38844 cp/parser.c:38857
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp flush%> may only be used in compound statements"
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<#pragma omp flush%> може бити употребљено само у сложеним наредбама"
 
-#: c/c-parser.c:10972 cp/parser.c:38837
+#: c/c-parser.c:10972 cp/parser.c:38834
 #, fuzzy, gcc-internal-format
 #| msgid "%<continue%> must be in loop"
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<continue%> мора бити у оквиру петље"
 
-#: c/c-parser.c:11050 cp/parser.c:38918
+#: c/c-parser.c:11050 cp/parser.c:38915
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<#pragma omp section%> може бити употребљено само у конструкцији %<#pragma omp sections%>"
 
-#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38947 cp/parser.c:38980
+#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38944 cp/parser.c:38977
 #, fuzzy, gcc-internal-format
 #| msgid "for statement expected"
 msgid "for, while or do statement expected"
 msgstr "очекивана је наредба for"
 
-#: c/c-parser.c:11111 cp/parser.c:38711
+#: c/c-parser.c:11111 cp/parser.c:38708
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%> мора бити прво"
 
-#: c/c-parser.c:11421 cp/parser.c:31457
+#: c/c-parser.c:11421 cp/parser.c:31454
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "превише %qs одредби"
 
-#: c/c-parser.c:11443 cp/parser.c:31994
+#: c/c-parser.c:11443 cp/parser.c:31991
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "expected integer expression before ')'"
@@ -41261,60 +41305,60 @@
 msgid "%qD is not a variable"
 msgstr "%qD није променљива у одредби %qs"
 
-#: c/c-parser.c:11746 cp/semantics.c:6808
+#: c/c-parser.c:11746 cp/semantics.c:6811
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template"
 msgid "%qD is not a pointer variable"
 msgstr "%qD није шаблон"
 
-#: c/c-parser.c:11788 cp/parser.c:32073
+#: c/c-parser.c:11788 cp/parser.c:32070
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between signed and unsigned integer expressions"
 msgid "collapse argument needs positive constant integer expression"
 msgstr "поређење означених и неозначених целобројних израза"
 
-#: c/c-parser.c:11865 cp/parser.c:32137
+#: c/c-parser.c:11865 cp/parser.c:32134
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<none%> or %<present%>"
 msgstr "очекивано је %<none%> или %<shared%>"
 
-#: c/c-parser.c:11867 cp/parser.c:32139
+#: c/c-parser.c:11867 cp/parser.c:32136
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "очекивано је %<none%> или %<shared%>"
 
-#: c/c-parser.c:11968 cp/parser.c:32242
+#: c/c-parser.c:11968 cp/parser.c:32239
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "очекивано је %<,%>, %<;%> или %<}%>"
 
-#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32260
-#: cp/parser.c:36290 cp/parser.c:36378
+#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32257
+#: cp/parser.c:36287 cp/parser.c:36375
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<data%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.c:12035 cp/parser.c:32313
+#: c/c-parser.c:12035 cp/parser.c:32310
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:12042 cp/parser.c:32320
+#: c/c-parser.c:12042 cp/parser.c:32317
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<if%> clauses"
 msgstr "превише %qs одредби"
 
-#: c/c-parser.c:12044 cp/parser.c:32322
+#: c/c-parser.c:12044 cp/parser.c:32319
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<if%> clauses without modifier"
 msgstr "превише %qs одредби"
 
-#: c/c-parser.c:12050 cp/parser.c:32328
+#: c/c-parser.c:12050 cp/parser.c:32325
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -41337,96 +41381,96 @@
 msgid "%<num_tasks%> value must be positive"
 msgstr "вредност %<num_threads%> мора бити позитивна"
 
-#: c/c-parser.c:12229 cp/semantics.c:6992
+#: c/c-parser.c:12229 cp/semantics.c:6995
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<grainsize%> value must be positive"
 msgstr "вредност %<num_threads%> мора бити позитивна"
 
-#: c/c-parser.c:12276 cp/semantics.c:7021
+#: c/c-parser.c:12276 cp/semantics.c:7024
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<priority%> value must be non-negative"
 msgstr "вредност %<num_threads%> мора бити позитивна"
 
-#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32545 cp/parser.c:32552
+#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32542 cp/parser.c:32549
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<tofrom%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32561 cp/parser.c:32568
+#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32558 cp/parser.c:32565
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<scalar%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.c:12425 cp/semantics.c:6299
+#: c/c-parser.c:12425 cp/semantics.c:6302
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%qs expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6331
+#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6334
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%qs value must be positive"
 msgstr "вредност %<num_threads%> мора бити позитивна"
 
-#: c/c-parser.c:12499 cp/parser.c:31853
+#: c/c-parser.c:12499 cp/parser.c:31850
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<static%> arguments"
 msgstr "превише %qs одредби"
 
-#: c/c-parser.c:12533 cp/parser.c:31886
+#: c/c-parser.c:12533 cp/parser.c:31883
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected element"
 msgid "unexpected argument"
 msgstr "Неочекивани елемент"
 
-#: c/c-parser.c:12699 cp/semantics.c:7120
+#: c/c-parser.c:12699 cp/semantics.c:7123
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute argument not an integer constant"
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "аргумент атрибута %qs није целобројна константа"
 
-#: c/c-parser.c:12765 cp/parser.c:32626
+#: c/c-parser.c:12765 cp/parser.c:32623
 #, fuzzy, gcc-internal-format
 #| msgid "ordered comparison of pointer with integer zero"
 msgid "ordered argument needs positive constant integer expression"
 msgstr "поређење уређености показивача са целобројном нулом"
 
-#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37643
+#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37640
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, or %<||%>"
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "очекивано је %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%> или %<||%>"
 
-#: c/c-parser.c:12967 cp/parser.c:32840
+#: c/c-parser.c:12967 cp/parser.c:32837
 #, fuzzy, gcc-internal-format
 #| msgid "both %<long%> and %<void%> in declaration specifiers"
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "и %<long%> и %<void%> у наводиоцима декларације"
 
-#: c/c-parser.c:13021 cp/parser.c:32856
+#: c/c-parser.c:13021 cp/parser.c:32853
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "распоред %<runtime%> не узима параметар %<chunk_size%>"
 
-#: c/c-parser.c:13025 cp/parser.c:32859
+#: c/c-parser.c:13025 cp/parser.c:32856
 #, fuzzy, gcc-internal-format
 #| msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "распоред %<runtime%> не узима параметар %<chunk_size%>"
 
-#: c/c-parser.c:13037 cp/semantics.c:6389
+#: c/c-parser.c:13037 cp/semantics.c:6392
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "chunk size value must be positive"
 msgstr "вредност %<num_threads%> мора бити позитивна"
 
-#: c/c-parser.c:13060 cp/parser.c:32879
+#: c/c-parser.c:13060 cp/parser.c:32876
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "неисправна врста распореда"
@@ -41437,13 +41481,13 @@
 msgid "%<num_teams%> value must be positive"
 msgstr "вредност %<num_threads%> мора бити позитивна"
 
-#: c/c-parser.c:13226 cp/semantics.c:6479
+#: c/c-parser.c:13226 cp/semantics.c:6482
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<thread_limit%> value must be positive"
 msgstr "вредност %<num_threads%> мора бити позитивна"
 
-#: c/c-parser.c:13271 cp/semantics.c:6589
+#: c/c-parser.c:13271 cp/semantics.c:6592
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr ""
@@ -41464,19 +41508,19 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:13584 cp/parser.c:33374 cp/parser.c:33599
+#: c/c-parser.c:13584 cp/parser.c:33371 cp/parser.c:33596
 #, fuzzy, gcc-internal-format
 #| msgid "invalid schedule kind"
 msgid "invalid depend kind"
 msgstr "неисправна врста распореда"
 
-#: c/c-parser.c:13669 cp/parser.c:33447
+#: c/c-parser.c:13669 cp/parser.c:33444
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mask"
 msgid "invalid map kind"
 msgstr "неисправна маска"
 
-#: c/c-parser.c:13767 cp/parser.c:33546
+#: c/c-parser.c:13767 cp/parser.c:33543
 #, fuzzy, gcc-internal-format
 #| msgid "invalid schedule kind"
 msgid "invalid dist_schedule kind"
@@ -41488,73 +41532,73 @@
 msgid "invalid proc_bind kind"
 msgstr "неисправна врста распореда"
 
-#: c/c-parser.c:14059 cp/parser.c:33825
+#: c/c-parser.c:14059 cp/parser.c:33822
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected %<#pragma acc%> clause"
 msgstr "очекивана је одредба %<#pragma omp%>"
 
-#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33836 cp/parser.c:34143
+#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33833 cp/parser.c:34140
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs није исправно за %qs"
 
-#: c/c-parser.c:14214 cp/parser.c:34010
+#: c/c-parser.c:14214 cp/parser.c:34007
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a nested class of %qT"
 msgid "%qs must be the first clause of %qs"
 msgstr "%qT није угњеждена класа у %qT"
 
-#: c/c-parser.c:14334 cp/parser.c:34132
+#: c/c-parser.c:14334 cp/parser.c:34129
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "очекивана је одредба %<#pragma omp%>"
 
-#: c/c-parser.c:14472 cp/parser.c:36803
+#: c/c-parser.c:14472 cp/parser.c:36800
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14482 cp/parser.c:36813
+#: c/c-parser.c:14482 cp/parser.c:36810
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14502 cp/parser.c:36833
+#: c/c-parser.c:14502 cp/parser.c:36830
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr ""
 
-#: c/c-parser.c:14513 cp/parser.c:36844
+#: c/c-parser.c:14513 cp/parser.c:36841
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr ""
 
-#: c/c-parser.c:14520 cp/parser.c:36851
+#: c/c-parser.c:14520 cp/parser.c:36848
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %<extern%> variable %q+D in %<for%> loop initial declaration"
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "декларација спољашње променљиве %q+D у почетној декларацији %<for%> петље"
 
-#: c/c-parser.c:14528 cp/parser.c:36859
+#: c/c-parser.c:14528 cp/parser.c:36856
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<--%> on bool variable %qD"
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "неисправна употреба %<--%> на логичкој променљивој %qD"
 
-#: c/c-parser.c:14540 cp/parser.c:36871
+#: c/c-parser.c:14540 cp/parser.c:36868
 #, fuzzy, gcc-internal-format
 #| msgid "Variable %qs is used more than once in the argument list of method %qs"
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr "Променљива %qs употребљена више од једном у листи аргумената метода %qs"
 
-#: c/c-parser.c:14632 cp/parser.c:36957
+#: c/c-parser.c:14632 cp/parser.c:36954
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "очекивано је %<,%> или %<;%>"
 
-#: c/c-parser.c:14648 cp/parser.c:36974
+#: c/c-parser.c:14648 cp/parser.c:36971
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr ""
@@ -41571,7 +41615,7 @@
 msgid "expected function name"
 msgstr "очекивано је име класе"
 
-#: c/c-parser.c:14893 cp/parser.c:38064
+#: c/c-parser.c:14893 cp/parser.c:38061
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is not a function,"
 msgid "%qD does not refer to a function"
@@ -41582,44 +41626,44 @@
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14953 cp/parser.c:38118 cp/parser.c:38160
+#: c/c-parser.c:14953 cp/parser.c:38115 cp/parser.c:38157
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14970 cp/parser.c:38174
+#: c/c-parser.c:14970 cp/parser.c:38171
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> already applied to %qD"
 msgstr ""
 
-#: c/c-parser.c:14979 cp/parser.c:38183
+#: c/c-parser.c:14979 cp/parser.c:38180
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr ""
 
-#: c/c-parser.c:14980 cp/parser.c:38184
+#: c/c-parser.c:14980 cp/parser.c:38181
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma align%> must appear before the declaration of %D, ignoring"
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<#pragma align%> мора да се јави пре декларације %D, игноришем"
 
-#: c/c-parser.c:15023 cp/parser.c:37152
+#: c/c-parser.c:15023 cp/parser.c:37149
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
 
-#: c/c-parser.c:15435 cp/parser.c:34511 cp/parser.c:34537
+#: c/c-parser.c:15435 cp/parser.c:34508 cp/parser.c:34534
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operator for %<#pragma omp atomic%>"
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "неисправан оператор за %<#pragma omp atomic%>"
 
-#: c/c-parser.c:15439 cp/parser.c:34568 cp/parser.c:34584
+#: c/c-parser.c:15439 cp/parser.c:34565 cp/parser.c:34581
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "неисправан оператор за %<#pragma omp atomic%>"
 
-#: c/c-parser.c:15488 cp/semantics.c:8401 cp/semantics.c:8411
+#: c/c-parser.c:15488 cp/semantics.c:8404 cp/semantics.c:8414
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
@@ -41629,22 +41673,22 @@
 msgid "expected %<(%> or end of line"
 msgstr "очекивано је %<(%> или крај линије"
 
-#: c/c-parser.c:15619 cp/parser.c:35103
+#: c/c-parser.c:15619 cp/parser.c:35100
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:15630 cp/parser.c:35114
+#: c/c-parser.c:15630 cp/parser.c:35111
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:15648 cp/parser.c:35141
+#: c/c-parser.c:15648 cp/parser.c:35138
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "очекивана је наредба for"
 
-#: c/c-parser.c:15718 cp/semantics.c:8066 cp/semantics.c:8153
+#: c/c-parser.c:15718 cp/semantics.c:8069 cp/semantics.c:8156
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "очекивано је успостављање или декларација итерације"
@@ -41654,77 +41698,77 @@
 msgid "not enough perfectly nested loops"
 msgstr ""
 
-#: c/c-parser.c:15862 cp/parser.c:35364
+#: c/c-parser.c:15862 cp/parser.c:35361
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.c:15909 cp/parser.c:35184 cp/parser.c:35226 cp/pt.c:16385
+#: c/c-parser.c:15909 cp/parser.c:35181 cp/parser.c:35223 cp/pt.c:16407
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable %qs should not be firstprivate"
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "не би требало да променљива итерације %qs буде firstprivate"
 
-#: c/c-parser.c:16000 cp/parser.c:35437
+#: c/c-parser.c:16000 cp/parser.c:35434
 #, fuzzy, gcc-internal-format
 #| msgid "%<void%> as only parameter may not be qualified"
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "%<void%> као једини параметар не може бити одређен"
 
-#: c/c-parser.c:16166 cp/parser.c:35600
+#: c/c-parser.c:16166 cp/parser.c:35597
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr "%<#pragma omp barrier%> може бити употребљено само у сложеним наредбама"
 
-#: c/c-parser.c:16374 cp/parser.c:35799
+#: c/c-parser.c:16374 cp/parser.c:35796
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<for%> after %qs"
 msgstr "очекивано је %<,%> или %<;%>"
 
-#: c/c-parser.c:16573 cp/parser.c:35995
+#: c/c-parser.c:16573 cp/parser.c:35992
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<point%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.c:16793 cp/parser.c:36232
+#: c/c-parser.c:16793 cp/parser.c:36229
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16806 cp/parser.c:36245
+#: c/c-parser.c:16806 cp/parser.c:36242
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16853 cp/parser.c:36470
+#: c/c-parser.c:16853 cp/parser.c:36467
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:16925 cp/parser.c:36325
+#: c/c-parser.c:16925 cp/parser.c:36322
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16937 cp/parser.c:36337
+#: c/c-parser.c:16937 cp/parser.c:36334
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17011 cp/parser.c:36414
+#: c/c-parser.c:17011 cp/parser.c:36411
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17024 cp/parser.c:36427
+#: c/c-parser.c:17024 cp/parser.c:36424
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17238 cp/parser.c:36680
+#: c/c-parser.c:17238 cp/parser.c:36677
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -41745,34 +41789,34 @@
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17395 cp/parser.c:37273
+#: c/c-parser.c:17395 cp/parser.c:37270
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17474 cp/parser.c:37343
+#: c/c-parser.c:17474 cp/parser.c:37340
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> with clauses in between %<#pragma omp declare target%> without clauses and %<#pragma omp end declare target%>"
 msgstr ""
 
-#: c/c-parser.c:17493 cp/parser.c:37362
+#: c/c-parser.c:17493 cp/parser.c:37359
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17534 cp/parser.c:37409
+#: c/c-parser.c:17534 cp/parser.c:37406
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<target%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.c:17541 cp/parser.c:37416
+#: c/c-parser.c:17541 cp/parser.c:37413
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<declare%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.c:17547 cp/parser.c:37423
+#: c/c-parser.c:17547 cp/parser.c:37420
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr ""
@@ -41830,48 +41874,48 @@
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:17947 cp/parser.c:37868
+#: c/c-parser.c:17947 cp/parser.c:37865
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp section%> or %<}%>"
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr "очекивано је %<#pragma omp section%> или %<}%>"
 
-#: c/c-parser.c:18162 cp/semantics.c:7531
+#: c/c-parser.c:18162 cp/semantics.c:7534
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE декларисано као нитно-локално после прве употребе"
 
-#: c/c-parser.c:18164 cp/semantics.c:7533
+#: c/c-parser.c:18164 cp/semantics.c:7536
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "аутоматска променљива %qE не може бити нитно-локална"
 
-#: c/c-parser.c:18168 cp/semantics.c:7535
+#: c/c-parser.c:18168 cp/semantics.c:7538
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "нитно-локално %qE има непотпун тип"
 
-#: c/c-parser.c:18368 cp/parser.c:38565
+#: c/c-parser.c:18368 cp/parser.c:38562
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:18374 cp/parser.c:38571
+#: c/c-parser.c:18374 cp/parser.c:38568
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
 
-#: c/c-parser.c:18383 cp/parser.c:38580
+#: c/c-parser.c:18383 cp/parser.c:38577
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.c:18385 cp/parser.c:38583
+#: c/c-parser.c:18385 cp/parser.c:38580
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.c:18391 cp/parser.c:38589
+#: c/c-parser.c:18391 cp/parser.c:38586
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
@@ -41888,7 +41932,7 @@
 msgid "%qD has an incomplete type %qT"
 msgstr "%qD има непотпун тип"
 
-#: c/c-typeck.c:237 c/c-typeck.c:9994 c/c-typeck.c:10036 cp/call.c:4147
+#: c/c-typeck.c:237 c/c-typeck.c:9999 c/c-typeck.c:10041 cp/call.c:4147
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "неисправна употреба израза празног типа"
@@ -41967,13 +42011,13 @@
 msgid "converting an array compound literal to a pointer is ill-formed in C++"
 msgstr ""
 
-#: c/c-typeck.c:2417 c/c-typeck.c:8641
+#: c/c-typeck.c:2417 c/c-typeck.c:8646
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%qT has no member named %qE; did you mean %qE?"
 msgstr "%qT нема члан по имену %qE"
 
-#: c/c-typeck.c:2421 c/c-typeck.c:8645
+#: c/c-typeck.c:2421 c/c-typeck.c:8650
 #, gcc-internal-format
 msgid "%qT has no member named %qE"
 msgstr "%qT нема члан по имену %qE"
@@ -42183,505 +42227,505 @@
 msgid "pointer to a function used in subtraction"
 msgstr "показивач на функцију употребљен у одузимању"
 
-#: c/c-typeck.c:3847
+#: c/c-typeck.c:3852
 #, gcc-internal-format
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "аритметика са показивачем на непотпун тип"
 
-#: c/c-typeck.c:3852 cp/typeck.c:5562
+#: c/c-typeck.c:3857 cp/typeck.c:5562
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr "аритметика са показивачем на непотпун тип"
 
-#: c/c-typeck.c:4283
+#: c/c-typeck.c:4288
 #, fuzzy, gcc-internal-format
 #| msgid "  in thrown expression"
 msgid "%<~%> on a boolean expression"
 msgstr "  у баченом изразу"
 
-#: c/c-typeck.c:4287
+#: c/c-typeck.c:4292
 #, gcc-internal-format
 msgid "did you mean to use logical not?"
 msgstr ""
 
-#: c/c-typeck.c:4296
+#: c/c-typeck.c:4301
 #, gcc-internal-format
 msgid "ISO C does not support %<~%> for complex conjugation"
 msgstr "ИСО Ц не подржава %<~%> за комплексну конјугацију"
 
-#: c/c-typeck.c:4335
+#: c/c-typeck.c:4340
 #, gcc-internal-format
 msgid "wrong type argument to unary exclamation mark"
 msgstr "погрешан тип аргумента уз унарни знак узвика"
 
-#: c/c-typeck.c:4393
+#: c/c-typeck.c:4398
 #, gcc-internal-format
 msgid "increment of enumeration value is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:4396
+#: c/c-typeck.c:4401
 #, gcc-internal-format
 msgid "decrement of enumeration value is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:4403
+#: c/c-typeck.c:4408
 #, fuzzy, gcc-internal-format
 #| msgid "%Hmissing increment expression"
 msgid "increment of a boolean expression"
 msgstr "%Hнедостаје израз увећања"
 
-#: c/c-typeck.c:4406
+#: c/c-typeck.c:4411
 #, fuzzy, gcc-internal-format
 #| msgid "decrement of read-only location"
 msgid "decrement of a boolean expression"
 msgstr "умањење само-за-читање локације"
 
-#: c/c-typeck.c:4422
+#: c/c-typeck.c:4427
 #, gcc-internal-format
 msgid "ISO C does not support %<++%> and %<--%> on complex types"
 msgstr "ИСО Ц не подржава %<++%> и %<--%> за комплексне типове"
 
-#: c/c-typeck.c:4447 c/c-typeck.c:4481
+#: c/c-typeck.c:4452 c/c-typeck.c:4486
 #, gcc-internal-format
 msgid "wrong type argument to increment"
 msgstr "погрешан тип аргумента уз увећање"
 
-#: c/c-typeck.c:4449 c/c-typeck.c:4484
+#: c/c-typeck.c:4454 c/c-typeck.c:4489
 #, gcc-internal-format
 msgid "wrong type argument to decrement"
 msgstr "погрешан тип аргумента уз умањење"
 
-#: c/c-typeck.c:4469
+#: c/c-typeck.c:4474
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "increment of pointer to an incomplete type %qT"
 msgstr "аритметика са показивачем на непотпун тип"
 
-#: c/c-typeck.c:4473
+#: c/c-typeck.c:4478
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "decrement of pointer to an incomplete type %qT"
 msgstr "аритметика са показивачем на непотпун тип"
 
-#: c/c-typeck.c:4577
+#: c/c-typeck.c:4582
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of expression of type %<void%>"
 msgstr "узимање адресе привременог"
 
-#: c/c-typeck.c:4636
+#: c/c-typeck.c:4641
 #, gcc-internal-format
 msgid "cannot take address of bit-field %qD"
 msgstr "не може се узети адреса битског поља %qD"
 
-#: c/c-typeck.c:4649
+#: c/c-typeck.c:4654
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgid "cannot take address of scalar with reverse storage order"
 msgstr "не може се узети адреса од %<this%>, јер је д-вредносни израз"
 
-#: c/c-typeck.c:4657
+#: c/c-typeck.c:4662
 #, fuzzy, gcc-internal-format
 #| msgid "address of register variable %qD requested"
 msgid "address of array with reverse scalar storage order requested"
 msgstr "затражена адреса регистарске променљиве %qD"
 
-#: c/c-typeck.c:4838
+#: c/c-typeck.c:4843
 #, gcc-internal-format
 msgid "global register variable %qD used in nested function"
 msgstr "глобална регистарска променљива %qD употребљена у угњежденој функцији"
 
-#: c/c-typeck.c:4841
+#: c/c-typeck.c:4846
 #, gcc-internal-format
 msgid "register variable %qD used in nested function"
 msgstr "регистарска променљива %qD употребљена у угњежденој функцији"
 
-#: c/c-typeck.c:4846
+#: c/c-typeck.c:4851
 #, gcc-internal-format
 msgid "address of global register variable %qD requested"
 msgstr "затражена адреса глобалне регистарске променљиве %qD"
 
-#: c/c-typeck.c:4848
+#: c/c-typeck.c:4853
 #, gcc-internal-format
 msgid "address of register variable %qD requested"
 msgstr "затражена адреса регистарске променљиве %qD"
 
-#: c/c-typeck.c:4951
+#: c/c-typeck.c:4956
 #, gcc-internal-format
 msgid "non-lvalue array in conditional expression"
 msgstr "не-л-вредносни низ у условном изразу"
 
-#: c/c-typeck.c:5033
+#: c/c-typeck.c:5038
 #, fuzzy, gcc-internal-format
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "implicit conversion from %qT to %qT to match other result of conditional"
 msgstr "захтев за имплицтно претварање из %qT у %qT није дозвољен у Ц++у"
 
-#: c/c-typeck.c:5092 c/c-typeck.c:5098
+#: c/c-typeck.c:5097 c/c-typeck.c:5103
 #, gcc-internal-format
 msgid "operand of ?: changes signedness from %qT to %qT due to unsignedness of other operand"
 msgstr ""
 
-#: c/c-typeck.c:5115
+#: c/c-typeck.c:5120
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr with only one void side"
 msgstr "ИСО Ц забрањује условне изразе са само једном празном страном"
 
-#: c/c-typeck.c:5132
+#: c/c-typeck.c:5137
 #, fuzzy, gcc-internal-format
 #| msgid "pointer type mismatch in conditional expression"
 msgid "pointers to disjoint address spaces used in conditional expression"
 msgstr "неслагање показивачких типова у условном изразу"
 
-#: c/c-typeck.c:5143 c/c-typeck.c:5160
+#: c/c-typeck.c:5148 c/c-typeck.c:5165
 #, fuzzy, gcc-internal-format
 #| msgid "pointer type mismatch in conditional expression"
 msgid "pointer to array loses qualifier in conditional expression"
 msgstr "неслагање показивачких типова у условном изразу"
 
-#: c/c-typeck.c:5148 c/c-typeck.c:5165
+#: c/c-typeck.c:5153 c/c-typeck.c:5170
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr between %<void *%> and function pointer"
 msgstr "ИСО Ц забрањује условни израз између %<void *%> и функцијског показивача"
 
-#: c/c-typeck.c:5178
+#: c/c-typeck.c:5183
 #, gcc-internal-format
 msgid "pointer type mismatch in conditional expression"
 msgstr "неслагање показивачких типова у условном изразу"
 
-#: c/c-typeck.c:5187 c/c-typeck.c:5198
+#: c/c-typeck.c:5192 c/c-typeck.c:5203
 #, gcc-internal-format
 msgid "pointer/integer type mismatch in conditional expression"
 msgstr "неслагање типова показивача или целобројних у условном изразу"
 
-#: c/c-typeck.c:5336
+#: c/c-typeck.c:5341
 #, gcc-internal-format
 msgid "left-hand operand of comma expression has no effect"
 msgstr "леви операнд зарез-израза нема ефекта"
 
-#: c/c-typeck.c:5354 c/c-typeck.c:10636
+#: c/c-typeck.c:5359 c/c-typeck.c:10641
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "right-hand operand of comma expression has no effect"
 msgstr "леви операнд зарез-израза нема ефекта"
 
-#: c/c-typeck.c:5423
+#: c/c-typeck.c:5428
 #, fuzzy
 #| msgid "cast adds new qualifiers to function type"
 msgid "cast adds %q#v qualifier to function type"
 msgstr "претапање додаје нове одредбе функцијском типу"
 
-#: c/c-typeck.c:5429
+#: c/c-typeck.c:5434
 #, fuzzy
 #| msgid "cast discards qualifiers from pointer target type"
 msgid "cast discards %qv qualifier from pointer target type"
 msgstr "претапање одбацује одредбе са циљног типа показивача"
 
-#: c/c-typeck.c:5464
+#: c/c-typeck.c:5469
 #, gcc-internal-format
 msgid "to be safe all intermediate pointers in cast from %qT to %qT must be %<const%> qualified"
 msgstr ""
 
-#: c/c-typeck.c:5554
+#: c/c-typeck.c:5559
 #, gcc-internal-format
 msgid "cast specifies array type"
 msgstr "претапање наводи низовни тип"
 
-#: c/c-typeck.c:5560
+#: c/c-typeck.c:5565
 #, gcc-internal-format
 msgid "cast specifies function type"
 msgstr "претапање наводи функцијски тип"
 
-#: c/c-typeck.c:5575
+#: c/c-typeck.c:5580
 #, gcc-internal-format
 msgid "ISO C forbids casting nonscalar to the same type"
 msgstr "ИСО Ц забрањује претапање нескалара у исти тип"
 
-#: c/c-typeck.c:5595
+#: c/c-typeck.c:5600
 #, gcc-internal-format
 msgid "ISO C forbids casts to union type"
 msgstr "ИСО Ц забрањује претапање у унијски тип"
 
-#: c/c-typeck.c:5605
+#: c/c-typeck.c:5610
 #, gcc-internal-format
 msgid "cast to union type from type not present in union"
 msgstr "претапање у унијски тип из типа који не чини унију"
 
-#: c/c-typeck.c:5640
+#: c/c-typeck.c:5645
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint generic address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5645
+#: c/c-typeck.c:5650
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to generic address space pointer from disjoint %s address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5650
+#: c/c-typeck.c:5655
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint %s address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5670
+#: c/c-typeck.c:5675
 #, gcc-internal-format
 msgid "cast increases required alignment of target type"
 msgstr "претапање увећава неопходно равнање циљног типа"
 
-#: c/c-typeck.c:5681
+#: c/c-typeck.c:5686
 #, gcc-internal-format
 msgid "cast from pointer to integer of different size"
 msgstr "претапање из показивача у целобројни различите величине"
 
-#: c/c-typeck.c:5686
+#: c/c-typeck.c:5691
 #, gcc-internal-format
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "претапање из функцијског позива типа %qT у непоклапајући тип %qT"
 
-#: c/c-typeck.c:5695 cp/typeck.c:7811
+#: c/c-typeck.c:5700 cp/typeck.c:7811
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "претапање из целобројног у показивач различите величине"
 
-#: c/c-typeck.c:5709
+#: c/c-typeck.c:5714
 #, gcc-internal-format
 msgid "ISO C forbids conversion of function pointer to object pointer type"
 msgstr "ИСО Ц забрањује претварање показивача на функцију у показивач на објекат"
 
-#: c/c-typeck.c:5718
+#: c/c-typeck.c:5723
 #, gcc-internal-format
 msgid "ISO C forbids conversion of object pointer to function pointer type"
 msgstr "ИСО Ц забрањује претварање показивача на објекат у показивач на функцијски тип"
 
-#: c/c-typeck.c:5728
+#: c/c-typeck.c:5733
 #, fuzzy, gcc-internal-format
 #| msgid "can't convert from incomplete type %qT to %qT"
 msgid "cast between incompatible function types from %qT to %qT"
 msgstr "не може се претворити из непотпуног типа %qT у %qT"
 
-#: c/c-typeck.c:5815
+#: c/c-typeck.c:5820
 #, gcc-internal-format
 msgid "defining a type in a cast is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:5856
+#: c/c-typeck.c:5861
 #, fuzzy, gcc-internal-format
 #| msgid "assignment suppression"
 msgid "assignment to expression with array type"
 msgstr "потискивање доделе"
 
-#: c/c-typeck.c:5982
+#: c/c-typeck.c:5987
 #, gcc-internal-format
 msgid "enum conversion in assignment is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:6180 c/c-typeck.c:6202 c/c-typeck.c:6226
+#: c/c-typeck.c:6185 c/c-typeck.c:6207 c/c-typeck.c:6231
 #, gcc-internal-format
 msgid "(near initialization for %qs)"
 msgstr "(близу успостављања за %qs)"
 
-#: c/c-typeck.c:6241
+#: c/c-typeck.c:6246
 #, gcc-internal-format
 msgid "array initialized from parenthesized string constant"
 msgstr "низ успостављен константном ниском у заградама"
 
-#: c/c-typeck.c:6284 c/c-typeck.c:6476 c/c-typeck.c:6908
+#: c/c-typeck.c:6289 c/c-typeck.c:6481 c/c-typeck.c:6913
 #, fuzzy, gcc-internal-format
 #| msgid "format %q.*s expects type %<%T%s%>, but argument %d has type %qT"
 msgid "expected %qT but argument is of type %qT"
 msgstr "формат %q.*s очекује тип %<%T%s%>, али аргумент %d је типа %qT"
 
-#: c/c-typeck.c:6471
+#: c/c-typeck.c:6476
 #, fuzzy, gcc-internal-format
 #| msgid "pointer targets in passing argument %d of %qE differ in signedness"
 msgid "enum conversion when passing argument %d of %qE is invalid in C++"
 msgstr "циљеви показивача у прослеђивању аргумента %d за %qE разликују се у означености"
 
-#: c/c-typeck.c:6480
+#: c/c-typeck.c:6485
 #, fuzzy, gcc-internal-format
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "enum conversion from %qT to %qT in assignment is invalid in C++"
 msgstr "захтев за имплицтно претварање из %qT у %qT није дозвољен у Ц++у"
 
-#: c/c-typeck.c:6484
+#: c/c-typeck.c:6489
 #, fuzzy, gcc-internal-format
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "enum conversion from %qT to %qT in initialization is invalid in C++"
 msgstr "захтев за имплицтно претварање из %qT у %qT није дозвољен у Ц++у"
 
-#: c/c-typeck.c:6489
+#: c/c-typeck.c:6494
 #, fuzzy, gcc-internal-format
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "enum conversion from %qT to %qT in return is invalid in C++"
 msgstr "захтев за имплицтно претварање из %qT у %qT није дозвољен у Ц++у"
 
-#: c/c-typeck.c:6523
+#: c/c-typeck.c:6528
 #, gcc-internal-format
 msgid "cannot pass rvalue to reference parameter"
 msgstr "д-вредност се не може проследити упућивачком параметру"
 
-#: c/c-typeck.c:6656 c/c-typeck.c:6942
+#: c/c-typeck.c:6661 c/c-typeck.c:6947
 #, fuzzy
 #| msgid "passing argument %d of %qE makes qualified function pointer from unqualified"
 msgid "passing argument %d of %qE makes %q#v qualified function pointer from unqualified"
 msgstr "прослеђивање аргумента %d од %qE прави одређени функцијски показивач од неодређеног"
 
-#: c/c-typeck.c:6659 c/c-typeck.c:6945
+#: c/c-typeck.c:6664 c/c-typeck.c:6950
 #, fuzzy
 #| msgid "assignment makes qualified function pointer from unqualified"
 msgid "assignment makes %q#v qualified function pointer from unqualified"
 msgstr "додела прави одређени функцијски показивач од неодређеног"
 
-#: c/c-typeck.c:6662 c/c-typeck.c:6947
+#: c/c-typeck.c:6667 c/c-typeck.c:6952
 #, fuzzy
 #| msgid "initialization makes qualified function pointer from unqualified"
 msgid "initialization makes %q#v qualified function pointer from unqualified"
 msgstr "успостављање прави одређени функцијски показивач од неодређеног"
 
-#: c/c-typeck.c:6665 c/c-typeck.c:6949
+#: c/c-typeck.c:6670 c/c-typeck.c:6954
 #, fuzzy
 #| msgid "return makes qualified function pointer from unqualified"
 msgid "return makes %q#v qualified function pointer from unqualified"
 msgstr "повратак прави одређени функцијски показивач од неодређеног"
 
-#: c/c-typeck.c:6673 c/c-typeck.c:6840 c/c-typeck.c:6883
+#: c/c-typeck.c:6678 c/c-typeck.c:6845 c/c-typeck.c:6888
 #, fuzzy
 #| msgid "passing argument %d of %qE discards qualifiers from pointer target type"
 msgid "passing argument %d of %qE discards %qv qualifier from pointer target type"
 msgstr "прослеђивање аргумента %d од %qE одбацује одредбе са циљног типа показивача"
 
-#: c/c-typeck.c:6675 c/c-typeck.c:6842 c/c-typeck.c:6885
+#: c/c-typeck.c:6680 c/c-typeck.c:6847 c/c-typeck.c:6890
 #, fuzzy
 #| msgid "assignment discards qualifiers from pointer target type"
 msgid "assignment discards %qv qualifier from pointer target type"
 msgstr "додела одбацује одредбе са циљног типа показивача"
 
-#: c/c-typeck.c:6677 c/c-typeck.c:6844 c/c-typeck.c:6887
+#: c/c-typeck.c:6682 c/c-typeck.c:6849 c/c-typeck.c:6892
 #, fuzzy
 #| msgid "initialization discards qualifiers from pointer target type"
 msgid "initialization discards %qv qualifier from pointer target type"
 msgstr "успостављање одбацује одредбе са циљног типа показивача"
 
-#: c/c-typeck.c:6679 c/c-typeck.c:6846 c/c-typeck.c:6889
+#: c/c-typeck.c:6684 c/c-typeck.c:6851 c/c-typeck.c:6894
 #, fuzzy
 #| msgid "return discards qualifiers from pointer target type"
 msgid "return discards %qv qualifier from pointer target type"
 msgstr "повратак одбацује одредбе са циљног типа показивача"
 
-#: c/c-typeck.c:6688
+#: c/c-typeck.c:6693
 #, gcc-internal-format
 msgid "ISO C prohibits argument conversion to union type"
 msgstr "ИСО Ц забрањује претварање аргумента у унијски тип"
 
-#: c/c-typeck.c:6750
+#: c/c-typeck.c:6755
 #, gcc-internal-format
 msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgstr "захтев за имплицтно претварање из %qT у %qT није дозвољен у Ц++у"
 
-#: c/c-typeck.c:6762
+#: c/c-typeck.c:6767
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE from incompatible pointer type"
 msgid "passing argument %d of %qE from pointer to non-enclosed address space"
 msgstr "прослеђивање аргумента %d од %qE из несагласног показивачког типа"
 
-#: c/c-typeck.c:6766
+#: c/c-typeck.c:6771
 #, fuzzy, gcc-internal-format
 #| msgid "cast from pointer to integer of different size"
 msgid "assignment from pointer to non-enclosed address space"
 msgstr "претапање из показивача у целобројни различите величине"
 
-#: c/c-typeck.c:6770
+#: c/c-typeck.c:6775
 #, fuzzy, gcc-internal-format
 #| msgid "initialization from incompatible pointer type"
 msgid "initialization from pointer to non-enclosed address space"
 msgstr "успостављање из несагласног показивачког типа"
 
-#: c/c-typeck.c:6774
+#: c/c-typeck.c:6779
 #, gcc-internal-format
 msgid "return from pointer to non-enclosed address space"
 msgstr ""
 
-#: c/c-typeck.c:6792
+#: c/c-typeck.c:6797
 #, gcc-internal-format
 msgid "argument %d of %qE might be a candidate for a format attribute"
 msgstr "аргумент %d од %qE може бити кандидат за форматски атрибут"
 
-#: c/c-typeck.c:6798
+#: c/c-typeck.c:6803
 #, gcc-internal-format
 msgid "assignment left-hand side might be a candidate for a format attribute"
 msgstr "лева страна доделе може бити кандидат за форматски атрибут"
 
-#: c/c-typeck.c:6803
+#: c/c-typeck.c:6808
 #, gcc-internal-format
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "лева страна успостављања може бити кандидат за форматски атрибут"
 
-#: c/c-typeck.c:6808 cp/typeck.c:8891
+#: c/c-typeck.c:6813 cp/typeck.c:8891
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "повратни тип може бити кандидат за форматски атрибут"
 
-#: c/c-typeck.c:6857
+#: c/c-typeck.c:6862
 #, gcc-internal-format
 msgid "ISO C forbids passing argument %d of %qE between function pointer and %<void *%>"
 msgstr "ИСО Ц забрањује прослеђивање аргумента %d од %qE између функцијског показивача и %<void *%>"
 
-#: c/c-typeck.c:6860
+#: c/c-typeck.c:6865
 #, gcc-internal-format
 msgid "ISO C forbids assignment between function pointer and %<void *%>"
 msgstr "ИСО Ц забрањује доделу између функцијског показивача и %<void *%>"
 
-#: c/c-typeck.c:6862
+#: c/c-typeck.c:6867
 #, gcc-internal-format
 msgid "ISO C forbids initialization between function pointer and %<void *%>"
 msgstr "ИСО Ц забрањује успостављање између функцијског показивача и %<void *%>"
 
-#: c/c-typeck.c:6864
+#: c/c-typeck.c:6869
 #, gcc-internal-format
 msgid "ISO C forbids return between function pointer and %<void *%>"
 msgstr "ИСО Ц забрањује повратак између функцијског показивача и %<void *%>"
 
-#: c/c-typeck.c:6904
+#: c/c-typeck.c:6909
 #, gcc-internal-format
 msgid "pointer targets in passing argument %d of %qE differ in signedness"
 msgstr "циљеви показивача у прослеђивању аргумента %d за %qE разликују се у означености"
 
-#: c/c-typeck.c:6913
+#: c/c-typeck.c:6918
 #, fuzzy, gcc-internal-format
 #| msgid "pointer targets in assignment differ in signedness"
 msgid "pointer targets in assignment from %qT to %qT differ in signedness"
 msgstr "циљеви показивача у додели разликују се у означености"
 
-#: c/c-typeck.c:6918
+#: c/c-typeck.c:6923
 #, fuzzy, gcc-internal-format
 #| msgid "pointer targets in initialization differ in signedness"
 msgid "pointer targets in initialization of %qT from %qT differ in signedness"
 msgstr "циљеви показивача у успостављању разликују се у означености"
 
-#: c/c-typeck.c:6923
+#: c/c-typeck.c:6928
 #, fuzzy, gcc-internal-format
 #| msgid "pointer targets in passing argument %d of %qE differ in signedness"
 msgid "pointer targets in returning %qT from a function with return type %qT differ in signedness"
 msgstr "циљеви показивача у прослеђивању аргумента %d за %qE разликују се у означености"
 
-#: c/c-typeck.c:6961
+#: c/c-typeck.c:6966
 #, gcc-internal-format
 msgid "passing argument %d of %qE from incompatible pointer type"
 msgstr "прослеђивање аргумента %d од %qE из несагласног показивачког типа"
 
-#: c/c-typeck.c:6967
+#: c/c-typeck.c:6972
 #, fuzzy, gcc-internal-format
 #| msgid "assignment from incompatible pointer type"
 msgid "assignment to %qT from incompatible pointer type %qT"
 msgstr "додела из несагласног показивачког типа"
 
-#: c/c-typeck.c:6972
+#: c/c-typeck.c:6977
 #, fuzzy, gcc-internal-format
 #| msgid "initialization from incompatible pointer type"
 msgid "initialization of %qT from incompatible pointer type %qT"
 msgstr "успостављање из несагласног показивачког типа"
 
-#: c/c-typeck.c:6977
+#: c/c-typeck.c:6982
 #, fuzzy, gcc-internal-format
 #| msgid "return from incompatible pointer type"
 msgid "returning %qT from a function with incompatible return type %qT"
@@ -42689,833 +42733,833 @@
 
 #. ??? This should not be an error when inlining calls to
 #. unprototyped functions.
-#: c/c-typeck.c:6991 c/c-typeck.c:7514 cp/typeck.c:2063
+#: c/c-typeck.c:6996 c/c-typeck.c:7519 cp/typeck.c:2063
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "неисправна употреба не-л-вредносног низа"
 
-#: c/c-typeck.c:7004
+#: c/c-typeck.c:7009
 #, gcc-internal-format
 msgid "passing argument %d of %qE makes pointer from integer without a cast"
 msgstr "прослеђивање аргумента %d од %qE прави показивач од целобројног без претапања"
 
-#: c/c-typeck.c:7010
+#: c/c-typeck.c:7015
 #, fuzzy, gcc-internal-format
 #| msgid "assignment makes pointer from integer without a cast"
 msgid "assignment to %qT from %qT makes pointer from integer without a cast"
 msgstr "додела прави показивач од целобројног без претапања"
 
-#: c/c-typeck.c:7015
+#: c/c-typeck.c:7020
 #, fuzzy, gcc-internal-format
 #| msgid "initialization makes pointer from integer without a cast"
 msgid "initialization of %qT from %qT makes pointer from integer without a cast"
 msgstr "успостављање прави показивач од целобројног без претапања"
 
-#: c/c-typeck.c:7019
+#: c/c-typeck.c:7024
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE makes pointer from integer without a cast"
 msgid "returning %qT from a function with return type %qT makes pointer from integer without a cast"
 msgstr "прослеђивање аргумента %d од %qE прави показивач од целобројног без претапања"
 
-#: c/c-typeck.c:7035
+#: c/c-typeck.c:7040
 #, gcc-internal-format
 msgid "passing argument %d of %qE makes integer from pointer without a cast"
 msgstr "прослеђивање аргумента %d од %qE прави целобројни од показивача без претапања"
 
-#: c/c-typeck.c:7041
+#: c/c-typeck.c:7046
 #, fuzzy, gcc-internal-format
 #| msgid "assignment makes integer from pointer without a cast"
 msgid "assignment to %qT from %qT makes integer from pointer without a cast"
 msgstr "додела прави целобројни од показивача без претапања"
 
-#: c/c-typeck.c:7046
+#: c/c-typeck.c:7051
 #, fuzzy, gcc-internal-format
 #| msgid "initialization makes integer from pointer without a cast"
 msgid "initialization of %qT from %qT makes integer from pointer without a cast"
 msgstr "успостављање прави целобројни од показивача без претапања"
 
-#: c/c-typeck.c:7050
+#: c/c-typeck.c:7055
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE makes integer from pointer without a cast"
 msgid "returning %qT from a function with return type %qT makes integer from pointer without a cast"
 msgstr "прослеђивање аргумента %d од %qE прави целобројни од показивача без претапања"
 
-#: c/c-typeck.c:7073
+#: c/c-typeck.c:7078
 #, gcc-internal-format
 msgid "incompatible type for argument %d of %qE"
 msgstr "несагласни тип за аргумент %d у %qE"
 
-#: c/c-typeck.c:7078
+#: c/c-typeck.c:7083
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible types in assignment of %qT to %qT"
 msgid "incompatible types when assigning to type %qT from type %qT"
 msgstr "несагласни типови у додели %qT у %qT"
 
-#: c/c-typeck.c:7083
+#: c/c-typeck.c:7088
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible types in initialization"
 msgid "incompatible types when initializing type %qT using type %qT"
 msgstr "несагласни типови у успостављању"
 
-#: c/c-typeck.c:7088
+#: c/c-typeck.c:7093
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible types in assignment of %qT to %qT"
 msgid "incompatible types when returning type %qT but %qT was expected"
 msgstr "несагласни типови у додели %qT у %qT"
 
-#: c/c-typeck.c:7152
+#: c/c-typeck.c:7157
 #, gcc-internal-format
 msgid "traditional C rejects automatic aggregate initialization"
 msgstr "традиционални Ц одбија аутоматску успостављање скупина"
 
-#: c/c-typeck.c:7388 c/c-typeck.c:8284 cp/typeck2.c:1045
+#: c/c-typeck.c:7393 c/c-typeck.c:8289 cp/typeck2.c:1045
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "успостављање флексибилног чланског низа"
 
-#: c/c-typeck.c:7398 cp/typeck2.c:1059
+#: c/c-typeck.c:7403 cp/typeck2.c:1059
 #, gcc-internal-format
 msgid "char-array initialized from wide string"
 msgstr "char-низ успостављен широком ниском"
 
-#: c/c-typeck.c:7407
+#: c/c-typeck.c:7412
 #, fuzzy, gcc-internal-format
 #| msgid "wchar_t-array initialized from non-wide string"
 msgid "wide character array initialized from non-wide string"
 msgstr "wchar_t-низ успостављен не-широком ниском"
 
-#: c/c-typeck.c:7413
+#: c/c-typeck.c:7418
 #, fuzzy, gcc-internal-format
 #| msgid "wchar_t-array initialized from non-wide string"
 msgid "wide character array initialized from incompatible wide string"
 msgstr "wchar_t-низ успостављен не-широком ниском"
 
-#: c/c-typeck.c:7446
+#: c/c-typeck.c:7451
 #, gcc-internal-format
 msgid "array of inappropriate type initialized from string constant"
 msgstr "низ неподесног типа успостављен константном ниском"
 
-#: c/c-typeck.c:7533 c/c-typeck.c:7557 c/c-typeck.c:7560 c/c-typeck.c:7568
-#: c/c-typeck.c:7608 c/c-typeck.c:9131 c/c-typeck.c:9181
+#: c/c-typeck.c:7538 c/c-typeck.c:7562 c/c-typeck.c:7565 c/c-typeck.c:7573
+#: c/c-typeck.c:7613 c/c-typeck.c:9136 c/c-typeck.c:9186
 #, gcc-internal-format
 msgid "initializer element is not constant"
 msgstr "елемент успостављача није константан"
 
-#: c/c-typeck.c:7542
+#: c/c-typeck.c:7547
 #, gcc-internal-format
 msgid "array initialized from non-constant array expression"
 msgstr "низ успостављен не-константним низовним изразом"
 
-#: c/c-typeck.c:7573 c/c-typeck.c:7621 c/c-typeck.c:9191
+#: c/c-typeck.c:7578 c/c-typeck.c:7626 c/c-typeck.c:9196
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not constant"
 msgid "initializer element is not a constant expression"
 msgstr "елемент успостављача није константан"
 
-#: c/c-typeck.c:7615 c/c-typeck.c:9186
+#: c/c-typeck.c:7620 c/c-typeck.c:9191
 #, gcc-internal-format
 msgid "initializer element is not computable at load time"
 msgstr "елемент успостављача се не може израчунати при учитавању"
 
-#: c/c-typeck.c:7634
+#: c/c-typeck.c:7639
 #, gcc-internal-format
 msgid "invalid initializer"
 msgstr "неисправан успостављач"
 
-#: c/c-typeck.c:7912 cp/decl.c:6396
+#: c/c-typeck.c:7917 cp/decl.c:6396
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "непрозирни векторски типови не могу бити успостављени"
 
-#: c/c-typeck.c:8132
+#: c/c-typeck.c:8137
 #, gcc-internal-format
 msgid "extra brace group at end of initializer"
 msgstr "сувишна група витичастих заграда на крају успостављача"
 
-#: c/c-typeck.c:8215
+#: c/c-typeck.c:8220
 #, gcc-internal-format
 msgid "braces around scalar initializer"
 msgstr "витичасте заграде око скаларног успостављача"
 
-#: c/c-typeck.c:8281 c/c-typeck.c:9615 cp/typeck2.c:1084 cp/typeck2.c:1297
+#: c/c-typeck.c:8286 c/c-typeck.c:9620 cp/typeck2.c:1084 cp/typeck2.c:1297
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "успостављање флексибилног чланског низа у угњежденом контексту"
 
-#: c/c-typeck.c:8318
+#: c/c-typeck.c:8323
 #, gcc-internal-format
 msgid "missing braces around initializer"
 msgstr "недостају витичасте заграде око успостављача"
 
-#: c/c-typeck.c:8341
+#: c/c-typeck.c:8346
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "missing initializer for field %qD of %qT"
 msgstr "недостаје успостављач за члан %qD"
 
-#: c/c-typeck.c:8365
+#: c/c-typeck.c:8370
 #, gcc-internal-format
 msgid "empty scalar initializer"
 msgstr "празан скаларни успостављач"
 
-#: c/c-typeck.c:8370
+#: c/c-typeck.c:8375
 #, gcc-internal-format
 msgid "extra elements in scalar initializer"
 msgstr "сувишни елементи у скаларном инцијализатору"
 
-#: c/c-typeck.c:8483 c/c-typeck.c:8565
+#: c/c-typeck.c:8488 c/c-typeck.c:8570
 #, gcc-internal-format
 msgid "array index in non-array initializer"
 msgstr "индекс низа у не-низовном успостављачу"
 
-#: c/c-typeck.c:8488 c/c-typeck.c:8627
+#: c/c-typeck.c:8493 c/c-typeck.c:8632
 #, gcc-internal-format
 msgid "field name not in record or union initializer"
 msgstr "име поља није у успостављачу слога или уније"
 
-#: c/c-typeck.c:8538
+#: c/c-typeck.c:8543
 #, gcc-internal-format
 msgid "array index in initializer not of integer type"
 msgstr "индекс низа у успостављачу није целобројан"
 
-#: c/c-typeck.c:8547 c/c-typeck.c:8556
+#: c/c-typeck.c:8552 c/c-typeck.c:8561
 #, fuzzy, gcc-internal-format
 #| msgid "array index in initializer not of integer type"
 msgid "array index in initializer is not an integer constant expression"
 msgstr "индекс низа у успостављачу није целобројан"
 
-#: c/c-typeck.c:8561 c/c-typeck.c:8563
+#: c/c-typeck.c:8566 c/c-typeck.c:8568
 #, gcc-internal-format
 msgid "nonconstant array index in initializer"
 msgstr "неконстантан индекс низа у успостављачу"
 
-#: c/c-typeck.c:8567 c/c-typeck.c:8570
+#: c/c-typeck.c:8572 c/c-typeck.c:8575
 #, gcc-internal-format
 msgid "array index in initializer exceeds array bounds"
 msgstr "индекс у успостављачу премашује границе низа"
 
-#: c/c-typeck.c:8589
+#: c/c-typeck.c:8594
 #, gcc-internal-format
 msgid "empty index range in initializer"
 msgstr "празан индексни опсег у успостављачу"
 
-#: c/c-typeck.c:8598
+#: c/c-typeck.c:8603
 #, gcc-internal-format
 msgid "array index range in initializer exceeds array bounds"
 msgstr "индексни опсег у успостављачу премашује границе низа"
 
-#: c/c-typeck.c:8700 c/c-typeck.c:8730 c/c-typeck.c:9274
+#: c/c-typeck.c:8705 c/c-typeck.c:8735 c/c-typeck.c:9279
 #, gcc-internal-format
 msgid "initialized field with side-effects overwritten"
 msgstr "успостављено поље са споредним ефектима пребрисано"
 
-#: c/c-typeck.c:8704 c/c-typeck.c:8734 c/c-typeck.c:9277
+#: c/c-typeck.c:8709 c/c-typeck.c:8739 c/c-typeck.c:9282
 #, gcc-internal-format
 msgid "initialized field overwritten"
 msgstr "успостављено поље пребрисано"
 
-#: c/c-typeck.c:9208
+#: c/c-typeck.c:9213
 #, gcc-internal-format
 msgid "enum conversion in initialization is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:9496
+#: c/c-typeck.c:9501
 #, gcc-internal-format
 msgid "excess elements in char array initializer"
 msgstr "сувишни елементи у успостављачу знаковног низа"
 
-#: c/c-typeck.c:9503 c/c-typeck.c:9574
+#: c/c-typeck.c:9508 c/c-typeck.c:9579
 #, gcc-internal-format
 msgid "excess elements in struct initializer"
 msgstr "сувишни елементи у успостављачу структуре"
 
-#: c/c-typeck.c:9518
+#: c/c-typeck.c:9523
 #, gcc-internal-format
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr ""
 
-#: c/c-typeck.c:9589
+#: c/c-typeck.c:9594
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr "нестатичко успостављање флексибилног чланског низа"
 
-#: c/c-typeck.c:9687
+#: c/c-typeck.c:9692
 #, gcc-internal-format
 msgid "excess elements in union initializer"
 msgstr "сувишни елементи у успостављачу уније"
 
-#: c/c-typeck.c:9709
+#: c/c-typeck.c:9714
 #, gcc-internal-format
 msgid "traditional C rejects initialization of unions"
 msgstr "традиционални Ц одбија успостављање унија"
 
-#: c/c-typeck.c:9777
+#: c/c-typeck.c:9782
 #, gcc-internal-format
 msgid "excess elements in array initializer"
 msgstr "сувишни елементи у успостављачу низа"
 
-#: c/c-typeck.c:9811
+#: c/c-typeck.c:9816
 #, gcc-internal-format
 msgid "excess elements in vector initializer"
 msgstr "сувишни елементи у успостављачу вектора"
 
-#: c/c-typeck.c:9843
+#: c/c-typeck.c:9848
 #, gcc-internal-format
 msgid "excess elements in scalar initializer"
 msgstr "сувишни елементи у успостављачу скалара"
 
-#: c/c-typeck.c:10086
+#: c/c-typeck.c:10091
 #, gcc-internal-format
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ИСО Ц забрањује %<goto *expr;%>"
 
-#: c/c-typeck.c:10113 c/gimple-parser.c:1604 cp/typeck.c:9113
+#: c/c-typeck.c:10118 c/gimple-parser.c:1604 cp/typeck.c:9113
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "функција декларисана са %<noreturn%> има наредбу %<return%>"
 
-#: c/c-typeck.c:10139 c/c-typeck.c:10143
+#: c/c-typeck.c:10144 c/c-typeck.c:10148
 #, gcc-internal-format
 msgid "%<return%> with no value, in function returning non-void"
 msgstr "%<return%> без вредности у функцији која не враћа празан тип"
 
-#: c/c-typeck.c:10157 c/gimple-parser.c:1614
+#: c/c-typeck.c:10162 c/gimple-parser.c:1614
 #, gcc-internal-format
 msgid "%<return%> with a value, in function returning void"
 msgstr "%<return%> са вредношћу у функцији која враћа празан тип"
 
-#: c/c-typeck.c:10160
+#: c/c-typeck.c:10165
 #, fuzzy, gcc-internal-format
 #| msgid "%<return%> with a value, in function returning void"
 msgid "ISO C forbids %<return%> with expression, in function returning void"
 msgstr "%<return%> са вредношћу у функцији која враћа празан тип"
 
-#: c/c-typeck.c:10236
+#: c/c-typeck.c:10241
 #, fuzzy, gcc-internal-format
 #| msgid "function returns address of local variable"
 msgid "function returns address of label"
 msgstr "функција враћа адресу на локалну променљиву"
 
-#: c/c-typeck.c:10327 cp/semantics.c:1171
+#: c/c-typeck.c:10332 cp/semantics.c:1171
 #, gcc-internal-format
 msgid "switch quantity not an integer"
 msgstr "величина у прекидачу није целобројна"
 
-#: c/c-typeck.c:10352
+#: c/c-typeck.c:10357
 #, gcc-internal-format
 msgid "%<long%> switch expression not converted to %<int%> in ISO C"
 msgstr "%<long%> израз у прекидачу не претвара се у %<int%> у ИСО Ц-у"
 
-#: c/c-typeck.c:10390 c/c-typeck.c:10398
+#: c/c-typeck.c:10395 c/c-typeck.c:10403
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "case label is not an integer constant expression"
 msgstr "величина низа није интегралан констатан израз"
 
-#: c/c-typeck.c:10404 cp/parser.c:11067
+#: c/c-typeck.c:10409 cp/parser.c:11067
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "етикета случаја није у оквиру наредбе прекидача"
 
-#: c/c-typeck.c:10406
+#: c/c-typeck.c:10411
 #, gcc-internal-format
 msgid "%<default%> label not within a switch statement"
 msgstr "етикета %<default%> није у оквиру наредбе прекидача"
 
-#: c/c-typeck.c:10578 cp/parser.c:12356
+#: c/c-typeck.c:10583 cp/parser.c:12353
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "наредба искакања није у оквиру петље или прекидача"
 
-#: c/c-typeck.c:10580 cp/parser.c:12379
+#: c/c-typeck.c:10585 cp/parser.c:12376
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "наредба настављања није у оквиру петље"
 
-#: c/c-typeck.c:10585 cp/parser.c:12369
+#: c/c-typeck.c:10590 cp/parser.c:12366
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr "наредба искакања употребљена са ОпенМПом за петљу"
 
-#: c/c-typeck.c:10590
+#: c/c-typeck.c:10595
 #, fuzzy, gcc-internal-format
 #| msgid "break statement not within loop or switch"
 msgid "break statement within %<#pragma simd%> loop body"
 msgstr "наредба искакања није у оквиру петље или прекидача"
 
-#: c/c-typeck.c:10592
+#: c/c-typeck.c:10597
 #, fuzzy, gcc-internal-format
 #| msgid "continue statement not within a loop"
 msgid "continue statement within %<#pragma simd%> loop body"
 msgstr "наредба настављања није у оквиру петље"
 
-#: c/c-typeck.c:10618 cp/cp-gimplify.c:432
+#: c/c-typeck.c:10623 cp/cp-gimplify.c:432
 #, gcc-internal-format
 msgid "statement with no effect"
 msgstr "наредба без ефекта"
 
-#: c/c-typeck.c:10662
+#: c/c-typeck.c:10667
 #, gcc-internal-format
 msgid "expression statement has incomplete type"
 msgstr "наредба израза има непотпун тип"
 
-#: c/c-typeck.c:11476 c/c-typeck.c:11644 cp/typeck.c:5017
+#: c/c-typeck.c:11481 c/c-typeck.c:11649 cp/typeck.c:5017
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr ""
 
-#: c/c-typeck.c:11484 c/c-typeck.c:11652 cp/typeck.c:5030
+#: c/c-typeck.c:11489 c/c-typeck.c:11657 cp/typeck.c:5030
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr ""
 
-#: c/c-typeck.c:11509 c/c-typeck.c:11677 cp/typeck.c:5058
+#: c/c-typeck.c:11514 c/c-typeck.c:11682 cp/typeck.c:5058
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr ""
 
-#: c/c-typeck.c:11523 cp/typeck.c:4743
+#: c/c-typeck.c:11528 cp/typeck.c:4743
 #, gcc-internal-format
 msgid "comparing floating point with == or != is unsafe"
 msgstr "поређење реалних помоћу == или != није безбедно"
 
-#: c/c-typeck.c:11541 c/c-typeck.c:11562
+#: c/c-typeck.c:11546 c/c-typeck.c:11567
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<false%> for the address of %qD will never be NULL"
 msgstr ""
 
-#: c/c-typeck.c:11547 c/c-typeck.c:11568
+#: c/c-typeck.c:11552 c/c-typeck.c:11573
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<true%> for the address of %qD will never be NULL"
 msgstr ""
 
-#: c/c-typeck.c:11589 c/c-typeck.c:11718
+#: c/c-typeck.c:11594 c/c-typeck.c:11723
 #, fuzzy, gcc-internal-format
 #| msgid "comparison of distinct pointer types lacks a cast"
 msgid "comparison of pointers to disjoint address spaces"
 msgstr "поређењу различитих показивачких типова недостаје претапање"
 
-#: c/c-typeck.c:11596 c/c-typeck.c:11602
+#: c/c-typeck.c:11601 c/c-typeck.c:11607
 #, gcc-internal-format
 msgid "ISO C forbids comparison of %<void *%> with function pointer"
 msgstr "ИСО Ц забрањује поређење %<void *%> и функцијског показивача"
 
-#: c/c-typeck.c:11609 c/c-typeck.c:11728
+#: c/c-typeck.c:11614 c/c-typeck.c:11733
 #, gcc-internal-format
 msgid "comparison of distinct pointer types lacks a cast"
 msgstr "поређењу различитих показивачких типова недостаје претапање"
 
-#: c/c-typeck.c:11621 c/c-typeck.c:11626 c/c-typeck.c:11754 c/c-typeck.c:11759
+#: c/c-typeck.c:11626 c/c-typeck.c:11631 c/c-typeck.c:11759 c/c-typeck.c:11764
 #, gcc-internal-format
 msgid "comparison between pointer and integer"
 msgstr "поређење између показивача и целобројног"
 
-#: c/c-typeck.c:11706
+#: c/c-typeck.c:11711
 #, gcc-internal-format
 msgid "comparison of complete and incomplete pointers"
 msgstr "поређење потпуног и непотпуног показивача"
 
-#: c/c-typeck.c:11708
+#: c/c-typeck.c:11713
 #, gcc-internal-format
 msgid "ISO C forbids ordered comparisons of pointers to functions"
 msgstr "ИСО Ц забрањује поређена уређености показивача на функције"
 
-#: c/c-typeck.c:11713
+#: c/c-typeck.c:11718
 #, fuzzy, gcc-internal-format
 #| msgid "ordered comparison of pointer with integer zero"
 msgid "ordered comparison of pointer with null pointer"
 msgstr "поређење уређености показивача са целобројном нулом"
 
-#: c/c-typeck.c:11736 c/c-typeck.c:11739 c/c-typeck.c:11746 c/c-typeck.c:11749
+#: c/c-typeck.c:11741 c/c-typeck.c:11744 c/c-typeck.c:11751 c/c-typeck.c:11754
 #: cp/typeck.c:5081 cp/typeck.c:5088
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "поређење уређености показивача са целобројном нулом"
 
-#: c/c-typeck.c:11811
+#: c/c-typeck.c:11816
 #, fuzzy, gcc-internal-format
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
 msgstr "захтев за имплицтно претварање из %qT у %qT није дозвољен у Ц++у"
 
-#: c/c-typeck.c:12126
+#: c/c-typeck.c:12131
 #, gcc-internal-format
 msgid "used array that cannot be converted to pointer where scalar is required"
 msgstr "употребљен низ који се не може претворити у показивач где се захтева скалар"
 
-#: c/c-typeck.c:12130
+#: c/c-typeck.c:12135
 #, gcc-internal-format
 msgid "used struct type value where scalar is required"
 msgstr "употребљена вредност структурног типа где се захтева скалар"
 
-#: c/c-typeck.c:12134
+#: c/c-typeck.c:12139
 #, gcc-internal-format
 msgid "used union type value where scalar is required"
 msgstr "употребљена вредност унијског типа где се захтева скалар"
 
-#: c/c-typeck.c:12150
+#: c/c-typeck.c:12155
 #, fuzzy, gcc-internal-format
 #| msgid "used struct type value where scalar is required"
 msgid "used vector type where scalar is required"
 msgstr "употребљена вредност структурног типа где се захтева скалар"
 
-#: c/c-typeck.c:12340 cp/semantics.c:8508
+#: c/c-typeck.c:12345 cp/semantics.c:8511
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12379 cp/semantics.c:8545
+#: c/c-typeck.c:12384 cp/semantics.c:8548
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12423 c/c-typeck.c:13581 c/c-typeck.c:13642 c/c-typeck.c:13704
+#: c/c-typeck.c:12428 c/c-typeck.c:13586 c/c-typeck.c:13647 c/c-typeck.c:13709
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "превише %qs одредби"
 
-#: c/c-typeck.c:12436 c/c-typeck.c:13628 cp/semantics.c:4546
-#: cp/semantics.c:6717
+#: c/c-typeck.c:12441 c/c-typeck.c:13633 cp/semantics.c:4549
+#: cp/semantics.c:6720
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12445 c/c-typeck.c:13652 cp/semantics.c:4556
-#: cp/semantics.c:6735
+#: c/c-typeck.c:12450 c/c-typeck.c:13657 cp/semantics.c:4559
+#: cp/semantics.c:6738
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qE is a member of a union"
 msgstr "%qD није чланска шаблонска функција"
 
-#: c/c-typeck.c:12455 cp/semantics.c:4570 cp/semantics.c:6760
+#: c/c-typeck.c:12460 cp/semantics.c:4573 cp/semantics.c:6763
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD није променљива у одредби %qs"
 
-#: c/c-typeck.c:12459 c/c-typeck.c:13669 cp/semantics.c:4574
-#: cp/semantics.c:6763
+#: c/c-typeck.c:12464 c/c-typeck.c:13674 cp/semantics.c:4577
+#: cp/semantics.c:6766
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qE није променљива у одредби %qs"
 
-#: c/c-typeck.c:12466
+#: c/c-typeck.c:12471
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "%<_Atomic%> %qD in %qs clause"
 msgstr "превише %qs одредби"
 
-#: c/c-typeck.c:12475 c/c-typeck.c:13676 c/c-typeck.c:13778
-#: cp/semantics.c:4591 cp/semantics.c:6769 cp/semantics.c:6931
+#: c/c-typeck.c:12480 c/c-typeck.c:13681 c/c-typeck.c:13783
+#: cp/semantics.c:4594 cp/semantics.c:6772 cp/semantics.c:6934
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD није променљива у одредби %qs"
 
-#: c/c-typeck.c:12511 cp/semantics.c:4623
+#: c/c-typeck.c:12516 cp/semantics.c:4626
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "low bound %qE of array section does not have integral type"
 msgstr "величина у низовном new мора бити интегралног типа"
 
-#: c/c-typeck.c:12518 cp/semantics.c:4630
+#: c/c-typeck.c:12523 cp/semantics.c:4633
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "length %qE of array section does not have integral type"
 msgstr "величина у низовном new мора бити интегралног типа"
 
-#: c/c-typeck.c:12545 c/c-typeck.c:12609 c/c-typeck.c:12867
-#: cp/semantics.c:4666 cp/semantics.c:4730
+#: c/c-typeck.c:12550 c/c-typeck.c:12614 c/c-typeck.c:12872
+#: cp/semantics.c:4669 cp/semantics.c:4733
 #, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12564 cp/semantics.c:4685
+#: c/c-typeck.c:12569 cp/semantics.c:4688
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12572 cp/semantics.c:4693
+#: c/c-typeck.c:12577 cp/semantics.c:4696
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12581 c/c-typeck.c:12691 cp/semantics.c:4702
-#: cp/semantics.c:4812
+#: c/c-typeck.c:12586 c/c-typeck.c:12696 cp/semantics.c:4705
+#: cp/semantics.c:4815
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12598 cp/semantics.c:4719
+#: c/c-typeck.c:12603 cp/semantics.c:4722
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12635 cp/semantics.c:4756
+#: c/c-typeck.c:12640 cp/semantics.c:4759
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12650 cp/semantics.c:4771
+#: c/c-typeck.c:12655 cp/semantics.c:4774
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12683 cp/semantics.c:4804
+#: c/c-typeck.c:12688 cp/semantics.c:4807
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12701 c/c-typeck.c:12810 cp/semantics.c:4822
-#: cp/semantics.c:4934
+#: c/c-typeck.c:12706 c/c-typeck.c:12815 cp/semantics.c:4825
+#: cp/semantics.c:4937
 #, fuzzy, gcc-internal-format
 #| msgid "Copy array sections into a contiguous block on procedure entry"
 msgid "array section is not contiguous in %qs clause"
 msgstr "Копирај одељке низа у непрекидан блок при улазу у процедуру"
 
-#: c/c-typeck.c:12709 cp/semantics.c:4830
+#: c/c-typeck.c:12714 cp/semantics.c:4833
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not have class type"
 msgid "%qE does not have pointer or array type"
 msgstr "%qE нема класни тип"
 
-#: c/c-typeck.c:13103 c/c-typeck.c:13113
+#: c/c-typeck.c:13108 c/c-typeck.c:13118
 #, gcc-internal-format
 msgid "%qD in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: c/c-typeck.c:13130
+#: c/c-typeck.c:13135
 #, gcc-internal-format
 msgid "%<_Atomic%> %qE in %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13178
+#: c/c-typeck.c:13183
 #, gcc-internal-format
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "%qE има неисправан тип за %<reduction(%s)%>"
 
-#: c/c-typeck.c:13187 cp/semantics.c:5755
+#: c/c-typeck.c:13192 cp/semantics.c:5758
 #, fuzzy, gcc-internal-format
 #| msgid "No label definition found for %qs"
 msgid "user defined reduction not found for %qE"
 msgstr "Није нађена дефиниција етикете за %qs"
 
-#: c/c-typeck.c:13275
+#: c/c-typeck.c:13280
 #, gcc-internal-format
 msgid "variable length element type in array %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13293 c/c-typeck.c:13836 cp/semantics.c:7249
+#: c/c-typeck.c:13298 c/c-typeck.c:13841 cp/semantics.c:7252
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13305 cp/semantics.c:7289
+#: c/c-typeck.c:13310 cp/semantics.c:7292
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE мора бити нитно-локално за %<copyin%>"
 
-#: c/c-typeck.c:13319 cp/semantics.c:5929
+#: c/c-typeck.c:13324 cp/semantics.c:5932
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr ""
 
-#: c/c-typeck.c:13327
+#: c/c-typeck.c:13332
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with type %qT"
 msgstr ""
 
-#: c/c-typeck.c:13335
+#: c/c-typeck.c:13340
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13354 cp/semantics.c:5999
+#: c/c-typeck.c:13359 cp/semantics.c:6002
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
-#: c/c-typeck.c:13384 c/c-typeck.c:13771 cp/semantics.c:6083
-#: cp/semantics.c:6924
+#: c/c-typeck.c:13389 c/c-typeck.c:13776 cp/semantics.c:6086
+#: cp/semantics.c:6927
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE није променљива у одредби %qs"
 
-#: c/c-typeck.c:13393 cp/semantics.c:6092
+#: c/c-typeck.c:13398 cp/semantics.c:6095
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in reduction clauses"
 msgstr "%qD се појављује више од једном у одредбама података"
 
-#: c/c-typeck.c:13404 c/c-typeck.c:13434 c/c-typeck.c:13463
+#: c/c-typeck.c:13409 c/c-typeck.c:13439 c/c-typeck.c:13468
 #, gcc-internal-format
 msgid "%qE appears more than once in data clauses"
 msgstr "%qE се појављује више од једном у одредбама података"
 
-#: c/c-typeck.c:13411 c/c-typeck.c:13440 c/c-typeck.c:13600 c/c-typeck.c:13714
-#: c/c-typeck.c:13720 c/c-typeck.c:13733 c/c-typeck.c:13742
-#: cp/semantics.c:6102 cp/semantics.c:6109 cp/semantics.c:6160
-#: cp/semantics.c:6166 cp/semantics.c:6203 cp/semantics.c:6680
-#: cp/semantics.c:6817 cp/semantics.c:6823 cp/semantics.c:6836
-#: cp/semantics.c:6845
+#: c/c-typeck.c:13416 c/c-typeck.c:13445 c/c-typeck.c:13605 c/c-typeck.c:13719
+#: c/c-typeck.c:13725 c/c-typeck.c:13738 c/c-typeck.c:13747
+#: cp/semantics.c:6105 cp/semantics.c:6112 cp/semantics.c:6163
+#: cp/semantics.c:6169 cp/semantics.c:6206 cp/semantics.c:6683
+#: cp/semantics.c:6820 cp/semantics.c:6826 cp/semantics.c:6839
+#: cp/semantics.c:6848
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr "%qD се појављује више од једном у одредбама података"
 
-#: c/c-typeck.c:13413 c/c-typeck.c:13442 c/c-typeck.c:13722 c/c-typeck.c:13744
-#: cp/semantics.c:6111 cp/semantics.c:6168 cp/semantics.c:6825
-#: cp/semantics.c:6847
+#: c/c-typeck.c:13418 c/c-typeck.c:13447 c/c-typeck.c:13727 c/c-typeck.c:13749
+#: cp/semantics.c:6114 cp/semantics.c:6171 cp/semantics.c:6828
+#: cp/semantics.c:6850
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears both in data and map clauses"
 msgstr "%qD се појављује више од једном у одредбама података"
 
-#: c/c-typeck.c:13427 cp/semantics.c:6154
+#: c/c-typeck.c:13432 cp/semantics.c:6157
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "%qE није променљива у одредби %<firstprivate%>"
 
-#: c/c-typeck.c:13456 cp/semantics.c:6197
+#: c/c-typeck.c:13461 cp/semantics.c:6200
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "%qE није променљива у одредби %<lastprivate%>"
 
-#: c/c-typeck.c:13475 cp/semantics.c:6545
+#: c/c-typeck.c:13480 cp/semantics.c:6548
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "%qE није променљива у одредби %qs"
 
-#: c/c-typeck.c:13482
+#: c/c-typeck.c:13487
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array"
 msgstr "тип уз векторско delete није ни показивачки ни низовни"
 
-#: c/c-typeck.c:13489
+#: c/c-typeck.c:13494
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<aligned%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13496
+#: c/c-typeck.c:13501
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr "%qE се појављује више од једном у одредбама података"
 
-#: c/c-typeck.c:13551 cp/semantics.c:6627
+#: c/c-typeck.c:13556 cp/semantics.c:6630
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr "%qE није променљива у одредби %qs"
 
-#: c/c-typeck.c:13573 cp/semantics.c:6658
+#: c/c-typeck.c:13578 cp/semantics.c:6661
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13597 c/c-typeck.c:13731 cp/semantics.c:6677
-#: cp/semantics.c:6834
+#: c/c-typeck.c:13602 c/c-typeck.c:13736 cp/semantics.c:6680
+#: cp/semantics.c:6837
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD се појављује више од једном у одредбама података"
 
-#: c/c-typeck.c:13603 c/c-typeck.c:13735 cp/semantics.c:6683
-#: cp/semantics.c:6838
+#: c/c-typeck.c:13608 c/c-typeck.c:13740 cp/semantics.c:6686
+#: cp/semantics.c:6841
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD се појављује више од једном у одредбама података"
 
-#: c/c-typeck.c:13635 cp/semantics.c:6724
+#: c/c-typeck.c:13640 cp/semantics.c:6727
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qE није променљива у одредби %qs"
 
-#: c/c-typeck.c:13695 c/c-typeck.c:13785 cp/semantics.c:6799
-#: cp/semantics.c:6938
+#: c/c-typeck.c:13700 c/c-typeck.c:13790 cp/semantics.c:6802
+#: cp/semantics.c:6941
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD није променљива у одредби %qs"
 
-#: c/c-typeck.c:13766 cp/semantics.c:6918
+#: c/c-typeck.c:13771 cp/semantics.c:6921
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE није променљива у одредби %qs"
 
-#: c/c-typeck.c:13794 cp/semantics.c:6947
+#: c/c-typeck.c:13799 cp/semantics.c:6950
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qE се појављује више од једном у одредбама података"
 
-#: c/c-typeck.c:13808 cp/semantics.c:6962
+#: c/c-typeck.c:13813 cp/semantics.c:6965
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD није променљива у одредби %qs"
 
-#: c/c-typeck.c:13811 cp/semantics.c:6964
+#: c/c-typeck.c:13816 cp/semantics.c:6967
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qE није променљива у одредби %qs"
 
-#: c/c-typeck.c:13826
+#: c/c-typeck.c:13831
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "тип уз векторско delete није ни показивачки ни низовни"
 
-#: c/c-typeck.c:13900 cp/semantics.c:6359
+#: c/c-typeck.c:13905 cp/semantics.c:6362
 #, gcc-internal-format
 msgid "%<nonmonotonic%> modifier specified for %qs schedule kind"
 msgstr ""
 
-#: c/c-typeck.c:13931 cp/semantics.c:7141
+#: c/c-typeck.c:13936 cp/semantics.c:7144
 #, fuzzy, gcc-internal-format
 #| msgid "%<-G%> is incompatible with %<-mabicalls%>"
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr "%<-G%> није сагласно са %<-mabicalls%>"
 
-#: c/c-typeck.c:13981 cp/semantics.c:7332
+#: c/c-typeck.c:13986 cp/semantics.c:7335
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE је предодређено као %qs за %qs"
 
-#: c/c-typeck.c:14001 cp/semantics.c:7223
+#: c/c-typeck.c:14006 cp/semantics.c:7226
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:14013 cp/semantics.c:7236
+#: c/c-typeck.c:14018 cp/semantics.c:7239
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14031 cp/semantics.c:7203
+#: c/c-typeck.c:14036 cp/semantics.c:7206
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14204
+#: c/c-typeck.c:14209
 #, gcc-internal-format
 msgid "cannot use %<va_arg%> with reverse storage order"
 msgstr ""
 
-#: c/c-typeck.c:14209
+#: c/c-typeck.c:14214
 #, fuzzy, gcc-internal-format
 #| msgid "first argument to %<va_arg%> not of type %<va_list%>"
 msgid "second argument to %<va_arg%> is of incomplete type %qT"
 msgstr "први аргумент за %<va_arg%> није типа %<va_list%>"
 
-#: c/c-typeck.c:14215
+#: c/c-typeck.c:14220
 #, gcc-internal-format
 msgid "C++ requires promoted type, not enum type, in %<va_arg%>"
 msgstr ""
@@ -43649,7 +43693,7 @@
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "  за претварање из %qT у %qT"
 
-#: cp/call.c:3441 cp/pt.c:6495
+#: cp/call.c:3441 cp/pt.c:6509
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -43973,7 +44017,7 @@
 msgid "%q#D is private within this context"
 msgstr "у овом контексту"
 
-#: cp/call.c:6478 cp/decl.c:7343
+#: cp/call.c:6478 cp/decl.c:7364
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "declared private here"
@@ -43985,7 +44029,7 @@
 msgid "%q#D is protected within this context"
 msgstr "у овом контексту"
 
-#: cp/call.c:6486 cp/decl.c:7344
+#: cp/call.c:6486 cp/decl.c:7365
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "declared protected here"
@@ -44318,7 +44362,7 @@
 msgid "call to non-function %qD"
 msgstr "позив не-функције %qD"
 
-#: cp/call.c:9119 cp/pt.c:15053 cp/typeck.c:2901
+#: cp/call.c:9119 cp/pt.c:15075 cp/typeck.c:2901
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
@@ -44556,281 +44600,281 @@
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr "не може се претворити из основе %qT у изведени тип %qT преко виртуелне основе %qT"
 
-#: cp/class.c:2098
+#: cp/class.c:2103
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr "све чланске функције у класи %qT су приватне"
 
-#: cp/class.c:2110
+#: cp/class.c:2115
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr "%q#T дефинише само приватни деструктор и нема пријатељâ"
 
-#: cp/class.c:2152
+#: cp/class.c:2156
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr "%q#T дефинише само приватне конструкторе и нема пријатељâ"
 
-#: cp/class.c:2156
+#: cp/class.c:2160
 #, gcc-internal-format
 msgid "%q#D is public, but requires an existing %q#T object"
 msgstr ""
 
-#: cp/class.c:2430
+#: cp/class.c:2434
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr "нема јединственог коначног потискивача за %qD у %qT"
 
-#: cp/class.c:2785
+#: cp/class.c:2789
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D cannot be overloaded"
 msgid "%qD can be marked override"
 msgstr "%q+#D не може бити препуњено"
 
-#: cp/class.c:2797
+#: cp/class.c:2801
 #, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr ""
 
-#: cp/class.c:2799
+#: cp/class.c:2803
 #, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr ""
 
-#: cp/class.c:2861
+#: cp/class.c:2865
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was hidden"
 msgid "%qD was hidden"
 msgstr "%q+D је сакривено"
 
-#: cp/class.c:2863
+#: cp/class.c:2867
 #, fuzzy, gcc-internal-format
 #| msgid "  by %q+D"
 msgid "  by %qD"
 msgstr "  овим %q+D"
 
-#: cp/class.c:2896
+#: cp/class.c:2900
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D invalid; an anonymous union can only have non-static data members"
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "%q+#D није исправно; анонимна унија може имати само нестатичке чланске податке"
 
-#: cp/class.c:2906 cp/name-lookup.c:3293 cp/parser.c:19720
+#: cp/class.c:2910 cp/name-lookup.c:3293 cp/parser.c:19717
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
 
-#: cp/class.c:3097
+#: cp/class.c:3101
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr ""
 
-#: cp/class.c:3213
+#: cp/class.c:3217
 #, gcc-internal-format
 msgid "bit-field %q+#D with non-integral type"
 msgstr "битско поље %q+#D неинтегралног типа"
 
-#: cp/class.c:3229
+#: cp/class.c:3233
 #, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr "ширина битског поља %q+D није целобројна константа"
 
-#: cp/class.c:3234
+#: cp/class.c:3238
 #, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr "негативна ширина у бистком пољу %q+D"
 
-#: cp/class.c:3239
+#: cp/class.c:3243
 #, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr "нулта ширина за битско поље %q+D"
 
-#: cp/class.c:3249
+#: cp/class.c:3253
 #, fuzzy, gcc-internal-format
 #| msgid "width of %q+D exceeds its type"
 msgid "width of %qD exceeds its type"
 msgstr "ширина %q+D премашује свој тип"
 
-#: cp/class.c:3255
+#: cp/class.c:3259
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is too small to hold all values of %q#T"
 msgid "%qD is too small to hold all values of %q#T"
 msgstr "%q+D је премало да садржи све вредности за %q#T"
 
-#: cp/class.c:3316
+#: cp/class.c:3320
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr "члан %q+#D са конструктором није дозвољен у унији"
 
-#: cp/class.c:3319
+#: cp/class.c:3323
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr "члан %q+#D са деструктором није дозвољен у унији"
 
-#: cp/class.c:3321
+#: cp/class.c:3325
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr "члан %q+#D са оператором копирања-доделе није дозвољен у унији"
 
-#: cp/class.c:3325
+#: cp/class.c:3329
 #, gcc-internal-format
 msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/class.c:3453
+#: cp/class.c:3457
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D may not be static because it is a member of a union"
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr "%q+D не може бити статичко зато што је члан уније"
 
-#: cp/class.c:3460
+#: cp/class.c:3464
 #, fuzzy, gcc-internal-format
 #| msgid "non-static const member %q+#D in class without a constructor"
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr "нестатчики константни члан %q+#D у класи без конструктора"
 
-#: cp/class.c:3470
+#: cp/class.c:3474
 #, gcc-internal-format
 msgid "field %q+D invalidly declared function type"
 msgstr "поље %q+D неисправно декларисан функцијски тип"
 
-#: cp/class.c:3476
+#: cp/class.c:3480
 #, gcc-internal-format
 msgid "field %q+D invalidly declared method type"
 msgstr "поље %q+D неисправно декларисан методски тип"
 
-#: cp/class.c:3536
+#: cp/class.c:3540
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring packed attribute because of unpacked non-POD field %q+#D"
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr "игноришем атрибут паковања због непакованог не-ПОД поља %q+#D"
 
-#: cp/class.c:3585
+#: cp/class.c:3589
 #, fuzzy, gcc-internal-format
 #| msgid "non-member %qs cannot be declared %<mutable%>"
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr "не-члан %qs не може бити декларисан %<mutable%>"
 
-#: cp/class.c:3591
+#: cp/class.c:3595
 #, fuzzy, gcc-internal-format
 #| msgid "non-member %qs cannot be declared %<mutable%>"
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr "не-члан %qs не може бити декларисан %<mutable%>"
 
-#: cp/class.c:3617
+#: cp/class.c:3621
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr "успостављена вишеструка поља у унији %qT"
 
-#: cp/class.c:3658
+#: cp/class.c:3662
 #, fuzzy, gcc-internal-format
 #| msgid "field %q+#D with same name as class"
 msgid "field %q#D with same name as class"
 msgstr "поље %q+#D истог имена као и класа"
 
-#: cp/class.c:3681
+#: cp/class.c:3685
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr "%q#T има показивачке чланске податке"
 
-#: cp/class.c:3686
+#: cp/class.c:3690
 #, gcc-internal-format
 msgid "  but does not override %<%T(const %T&)%>"
 msgstr "  али не потискује %<%T(const %T&)%>"
 
-#: cp/class.c:3688
+#: cp/class.c:3692
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr "  или %<operator=(const %T&)%>"
 
-#: cp/class.c:3692
+#: cp/class.c:3696
 #, gcc-internal-format
 msgid "  but does not override %<operator=(const %T&)%>"
 msgstr "  али не потискује %<operator=(const %T&)%>"
 
-#: cp/class.c:4097
+#: cp/class.c:4101
 #, gcc-internal-format
 msgid "alignment of %qD increased in -fabi-version=9 (GCC 5.2)"
 msgstr ""
 
-#: cp/class.c:4100
+#: cp/class.c:4104
 #, gcc-internal-format
 msgid "alignment of %qD will increase in -fabi-version=9"
 msgstr ""
 
-#: cp/class.c:4378
+#: cp/class.c:4382
 #, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "успостављач наведен за невиртуелни метод %q+D"
 
-#: cp/class.c:4813
+#: cp/class.c:4817
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr ""
 
-#: cp/class.c:4834
+#: cp/class.c:4838
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr ""
 
-#: cp/class.c:5350 cp/constexpr.c:237
+#: cp/class.c:5367 cp/constexpr.c:237
 #, gcc-internal-format
 msgid "enclosing class of %<constexpr%> non-static member function %q+#D is not a literal type"
 msgstr ""
 
-#: cp/class.c:5374
+#: cp/class.c:5391
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a class"
 msgid "%q+T is not literal because:"
 msgstr "%q#T није класа"
 
-#: cp/class.c:5377
+#: cp/class.c:5394
 #, gcc-internal-format
 msgid "  %qT is a closure type, which is only literal in C++17 and later"
 msgstr ""
 
-#: cp/class.c:5380
+#: cp/class.c:5397
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "  %q+T has a non-trivial destructor"
 msgstr "основна класа %q#T има не-виртуелни деструктор"
 
-#: cp/class.c:5387
+#: cp/class.c:5404
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no %<constexpr%> constructor that is not a copy or move constructor"
 msgstr ""
 
-#: cp/class.c:5420
+#: cp/class.c:5437
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "основна класа %q#T има не-виртуелни деструктор"
 
-#: cp/class.c:5435
+#: cp/class.c:5452
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD has non-integral type %qT"
 msgid "  non-static data member %qD has non-literal type"
 msgstr "величина низа %qD има неинтегрални тип %qT"
 
-#: cp/class.c:5442
+#: cp/class.c:5459
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static data member %qD"
 msgid "  non-static data member %qD has volatile type"
 msgstr "неисправна употреба нестатичког чланског податка %qD"
 
-#: cp/class.c:5561
+#: cp/class.c:5578
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "основна класа %q#T има не-виртуелни деструктор"
 
-#: cp/class.c:5590
+#: cp/class.c:5607
 #, fuzzy, gcc-internal-format
 #| msgid "non-static reference %q+#D in class without a constructor"
 msgid "non-static reference %q#D in class without a constructor"
 msgstr "нестатички упућивач %q+#D у класи без конструктора"
 
-#: cp/class.c:5596
+#: cp/class.c:5613
 #, fuzzy, gcc-internal-format
 #| msgid "non-static const member %q+#D in class without a constructor"
 msgid "non-static const member %q#D in class without a constructor"
@@ -44838,167 +44882,167 @@
 
 #. If the function is defaulted outside the class, we just
 #. give the synthesis error.
-#: cp/class.c:5624
+#: cp/class.c:5641
 #, gcc-internal-format
 msgid "%q+D declared to take const reference, but implicit declaration would take non-const"
 msgstr ""
 
-#: cp/class.c:5898
+#: cp/class.c:5915
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr "непосредна основа %qT није доступна у %qT услед двосмислености"
 
-#: cp/class.c:5910
+#: cp/class.c:5927
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr "виртуелна основа %qT није доступна у %qT услед двосмислености"
 
-#: cp/class.c:6133
+#: cp/class.c:6150
 #, fuzzy, gcc-internal-format
 #| msgid "offset of %q+D is not ABI-compliant and may change in a future version of GCC"
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr "помак за %q+D можда не поштује АБИ и може се изменити у будућим верзијама ГЦЦа"
 
-#: cp/class.c:6291
+#: cp/class.c:6308
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr "величина низа %qs је превелика"
 
-#: cp/class.c:6576
+#: cp/class.c:6593
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of structure with flexible array member"
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr "неисправна употреба структуре са флексибилним чланским низом"
 
-#: cp/class.c:6578
+#: cp/class.c:6595
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of structure with flexible array member"
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr "неисправна употреба структуре са флексибилним чланским низом"
 
-#: cp/class.c:6583
+#: cp/class.c:6600
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "array member %q#D declared here"
 msgstr "  %q+#D декларисано овде"
 
-#: cp/class.c:6610
+#: cp/class.c:6627
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member not at end of struct"
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr "%Jфлексибилан члански низ није на крају структуре"
 
-#: cp/class.c:6612
+#: cp/class.c:6629
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in otherwise empty struct"
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr "%Jфлексибилан члански низ у иначе празној структури"
 
-#: cp/class.c:6620 cp/class.c:6650
+#: cp/class.c:6637 cp/class.c:6667
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %q#T"
 msgid "in the definition of %q#T"
 msgstr "поновна дефиниција %q#T"
 
-#: cp/class.c:6628
+#: cp/class.c:6645
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member not at end of struct"
 msgid "flexible array member %qD not at end of %q#T"
 msgstr "%Jфлексибилан члански низ није на крају структуре"
 
-#: cp/class.c:6630
+#: cp/class.c:6647
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in otherwise empty struct"
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr "%Jфлексибилан члански низ у иначе празној структури"
 
-#: cp/class.c:6648
+#: cp/class.c:6665
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "next member %q#D declared here"
 msgstr "  %q+#D декларисано овде"
 
-#: cp/class.c:6760 cp/parser.c:23239
+#: cp/class.c:6777 cp/parser.c:23236
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "поновна дефиниција %q#T"
 
-#: cp/class.c:6897
+#: cp/class.c:6914
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T has virtual functions but non-virtual destructor"
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "%q#T има виртуелне функције, али невиртуелни деструктор"
 
-#: cp/class.c:6925
+#: cp/class.c:6942
 #, fuzzy, gcc-internal-format
 #| msgid "class %qT does not have any field named %qD"
 msgid "type transparent %q#T does not have any fields"
 msgstr "класа %qT нема поље по имену %qD"
 
-#: cp/class.c:6931
+#: cp/class.c:6948
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr ""
 
-#: cp/class.c:6935
+#: cp/class.c:6952
 #, fuzzy, gcc-internal-format
 #| msgid "type %qs has virtual member functions"
 msgid "type transparent class %qT has virtual functions"
 msgstr "тип %qs има виртуелне чланске функције"
 
-#: cp/class.c:6941
+#: cp/class.c:6958
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:7071
+#: cp/class.c:7088
 #, fuzzy, gcc-internal-format
 #| msgid "definition of %q#D is marked %<dllimport%>"
 msgid "definition of %qD does not match %<#include <initializer_list>%>"
 msgstr "дефиниција %q+D означена као %<dllimport%>"
 
-#: cp/class.c:7082
+#: cp/class.c:7099
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr "у покушају да довршим структуру, али избачен услед претходних грешака у рашчлањивању"
 
-#: cp/class.c:7582
+#: cp/class.c:7599
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "језичка ниска %<\"%E\"%> није препозната"
 
-#: cp/class.c:7672
+#: cp/class.c:7689
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr "не могу да разрешим препуњену функцију %qD на основу претварања у тип %qT"
 
-#: cp/class.c:7817
+#: cp/class.c:7834
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr "нема поклапања за претварање функције %qD у тип %q#T"
 
-#: cp/class.c:7844
+#: cp/class.c:7861
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "двосмислено претварање препуњене функције %qD у тип %q#T"
 
-#: cp/class.c:7870
+#: cp/class.c:7887
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "претпостављам показивач на члан %qD"
 
-#: cp/class.c:7873
+#: cp/class.c:7890
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(показивач на члан може бити формиран само помоћу %<&%E%>)"
 
-#: cp/class.c:7948 cp/class.c:7990
+#: cp/class.c:7965 cp/class.c:8007
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "нема довољно података о типу"
 
-#: cp/class.c:7968
+#: cp/class.c:7985
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "не може се претворити %qE из типа %qT у тип %qT"
@@ -45008,12 +45052,12 @@
 #. A name N used in a class S shall refer to the same declaration
 #. in its context and when re-evaluated in the completed scope of
 #. S.
-#: cp/class.c:8235
+#: cp/class.c:8252
 #, gcc-internal-format
 msgid "declaration of %q#D"
 msgstr "декларација %q#D"
 
-#: cp/class.c:8237
+#: cp/class.c:8254
 #, fuzzy, gcc-internal-format
 #| msgid "changes meaning of %qD from %q+#D"
 msgid "changes meaning of %qD from %q#D"
@@ -45457,17 +45501,17 @@
 msgid "unexpected AST of kind %s"
 msgstr "Неочекиван крај датотеке у ‘%s’"
 
-#: cp/cp-gimplify.c:1415
+#: cp/cp-gimplify.c:1416
 #, gcc-internal-format
 msgid "throw will always call terminate()"
 msgstr ""
 
-#: cp/cp-gimplify.c:1418
+#: cp/cp-gimplify.c:1419
 #, gcc-internal-format
 msgid "in C++11 destructors default to noexcept"
 msgstr ""
 
-#: cp/cp-gimplify.c:1429
+#: cp/cp-gimplify.c:1430
 #, gcc-internal-format
 msgid "in C++11 this throw will terminate because destructors default to noexcept"
 msgstr ""
@@ -45929,7 +45973,7 @@
 msgid "redeclaration %qD differs in %<constexpr%> from previous declaration"
 msgstr "декларација коришћења %q+D коси се са претходном декларацијом коришћења"
 
-#: cp/decl.c:1304 cp/decl.c:13843
+#: cp/decl.c:1304 cp/decl.c:13867
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D"
 msgid "previous declaration %qD"
@@ -46298,7 +46342,7 @@
 msgid "  enters OpenMP structured block"
 msgstr "  улази структуирани блок ОпенМПа"
 
-#: cp/decl.c:3434 cp/parser.c:12366 cp/parser.c:12387
+#: cp/decl.c:3434 cp/parser.c:12363 cp/parser.c:12384
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr "неисправан излаз из структуираног блока ОпенМПа"
@@ -46308,7 +46352,7 @@
 msgid "%qD is not a type"
 msgstr "%qD није тип"
 
-#: cp/decl.c:3838 cp/parser.c:6366
+#: cp/decl.c:3838 cp/parser.c:6369
 #, gcc-internal-format
 msgid "%qD used without template parameters"
 msgstr "%qD употребљено без параметара шаблона"
@@ -46720,8 +46764,8 @@
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.c:6011 cp/decl.c:6234 cp/typeck2.c:1310 cp/typeck2.c:1590
-#: cp/typeck2.c:1638 cp/typeck2.c:1685
+#: cp/decl.c:6011 cp/decl.c:6234 cp/typeck2.c:1310 cp/typeck2.c:1593
+#: cp/typeck2.c:1641 cp/typeck2.c:1688
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "превише успостављача за %qT"
@@ -46803,13 +46847,13 @@
 msgid "assignment (not initialization) in declaration"
 msgstr "додела (не успостављање) у декларацији"
 
-#: cp/decl.c:6873 cp/decl.c:12605
+#: cp/decl.c:6873 cp/decl.c:12629
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ИСО Ц++ не дозвољава утврђене успостављаче"
 
-#: cp/decl.c:6877 cp/decl.c:12609
+#: cp/decl.c:6877 cp/decl.c:12633
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for %qs"
 msgid "%<register%> storage class specifier used"
@@ -46836,46 +46880,46 @@
 msgid "function %q#D is initialized like a variable"
 msgstr "функција %q#D успостављена као променљива"
 
-#: cp/decl.c:7329
+#: cp/decl.c:7350
 #, fuzzy, gcc-internal-format
 #| msgid "  cannot use obsolete binding at %q+D because it has a destructor"
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "  не може се користити застарело везивање код %q+D јер има деструктор"
 
-#: cp/decl.c:7332
+#: cp/decl.c:7353
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.c:7339
+#: cp/decl.c:7360
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is an inaccessible base of %qT"
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "%qT је неприступачна основа за %qT"
 
-#: cp/decl.c:7365
+#: cp/decl.c:7386
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:7374
+#: cp/decl.c:7395
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:7592
+#: cp/decl.c:7613
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type %qT"
 msgid "structured binding refers to incomplete type %qT"
 msgstr "не може се %s показивач на непотпуни тип %qT"
 
-#: cp/decl.c:7608
+#: cp/decl.c:7629
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare variable %q+D to be of abstract type %qT"
 msgid "cannot decompose variable length array %qT"
 msgstr "не може се декларисати променљива %q+D апстрактног типа %qT"
 
-#: cp/decl.c:7617 cp/decl.c:7702
+#: cp/decl.c:7638 cp/decl.c:7723
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "initializer provided for function"
 msgid "%u name provided for structured binding"
@@ -46885,7 +46929,7 @@
 msgstr[2] "успостављач дат за функцију"
 msgstr[3] "успостављач дат за функцију"
 
-#: cp/decl.c:7621
+#: cp/decl.c:7642
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
@@ -46894,7 +46938,7 @@
 msgstr[2] ""
 msgstr[3] ""
 
-#: cp/decl.c:7624
+#: cp/decl.c:7645
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
@@ -46903,965 +46947,965 @@
 msgstr[2] ""
 msgstr[3] ""
 
-#: cp/decl.c:7669
+#: cp/decl.c:7690
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to %q#T"
 msgid "cannot decompose variable length vector %qT"
 msgstr "не може се декларисати показивач на %q#T"
 
-#: cp/decl.c:7695
+#: cp/decl.c:7716
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "величина низа није интегралан констатан израз"
 
-#: cp/decl.c:7704
+#: cp/decl.c:7725
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.c:7725
+#: cp/decl.c:7746
 #, fuzzy, gcc-internal-format
 #| msgid "initialization string truncated to match variable at %L"
 msgid "in initialization of structured binding variable %qD"
 msgstr "успостављачка ниска подсечена да одговара променљивој код %L"
 
-#: cp/decl.c:7751
+#: cp/decl.c:7772
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert type %qT to type %qT"
 msgid "cannot decompose union type %qT"
 msgstr "не може се претворити из типа %qT у %qT"
 
-#: cp/decl.c:7756
+#: cp/decl.c:7777
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "стварање показивача на члан некласног типа %qT"
 
-#: cp/decl.c:7761
+#: cp/decl.c:7782
 #, fuzzy, gcc-internal-format
 #| msgid "cannot decompose address"
 msgid "cannot decompose lambda closure type %qT"
 msgstr "не могу да разложим адресу"
 
-#: cp/decl.c:7765
+#: cp/decl.c:7786
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type %qT"
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "не може се %s показивач на непотпуни тип %qT"
 
-#: cp/decl.c:7774
+#: cp/decl.c:7795
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply %<offsetof%> to static data member %qD"
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "не могу применити %<offsetof%> на статички члански податак %qD"
 
-#: cp/decl.c:8213
+#: cp/decl.c:8234
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:8216
+#: cp/decl.c:8237
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:8222
+#: cp/decl.c:8243
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:8450
+#: cp/decl.c:8471
 #, fuzzy, gcc-internal-format
 #| msgid "initializer fails to determine size of %qD"
 msgid "initializer fails to determine size of %qT"
 msgstr "успостављач не одређује величину %qD"
 
-#: cp/decl.c:8454
+#: cp/decl.c:8475
 #, fuzzy, gcc-internal-format
 #| msgid "array size missing in %qD"
 msgid "array size missing in %qT"
 msgstr "недостаје величина низа у %qD"
 
-#: cp/decl.c:8457
+#: cp/decl.c:8478
 #, fuzzy, gcc-internal-format
 #| msgid "zero-size array %qD"
 msgid "zero-size array %qT"
 msgstr "низ %qD нулте величине"
 
-#: cp/decl.c:8473
+#: cp/decl.c:8494
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "деструктор за туђинску класу %qT не може бити члан"
 
-#: cp/decl.c:8475
+#: cp/decl.c:8496
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "конструктор за туђинску класу %qT не може бити члан"
 
-#: cp/decl.c:8499
+#: cp/decl.c:8520
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD декларисано као %<virtual%> %s"
 
-#: cp/decl.c:8501
+#: cp/decl.c:8522
 #, fuzzy, gcc-internal-format
 #| msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "наводиоци функције %<const%> и %<volatile%> за %qD нису исправни у декларацији %s"
 
-#: cp/decl.c:8506
+#: cp/decl.c:8527
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD декларисано као %<virtual%> %s"
 
-#: cp/decl.c:8508
+#: cp/decl.c:8529
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD декларисано као %<inline%> %s"
 
-#: cp/decl.c:8510
+#: cp/decl.c:8531
 #, fuzzy, gcc-internal-format
 #| msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "наводиоци функције %<const%> и %<volatile%> за %qD нису исправни у декларацији %s"
 
-#: cp/decl.c:8515
+#: cp/decl.c:8536
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD декларисано као %<virtual%> %s"
 
-#: cp/decl.c:8517
+#: cp/decl.c:8538
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD декларисано као %<inline%> %s"
 
-#: cp/decl.c:8519
+#: cp/decl.c:8540
 #, fuzzy, gcc-internal-format
 #| msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "наводиоци функције %<const%> и %<volatile%> за %qD нису исправни у декларацији %s"
 
-#: cp/decl.c:8524
+#: cp/decl.c:8545
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD декларисано као %<virtual%> %s"
 
-#: cp/decl.c:8526
+#: cp/decl.c:8547
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD декларисано као %<inline%> %s"
 
-#: cp/decl.c:8528
+#: cp/decl.c:8549
 #, fuzzy, gcc-internal-format
 #| msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "наводиоци функције %<const%> и %<volatile%> за %qD нису исправни у декларацији %s"
 
-#: cp/decl.c:8535
+#: cp/decl.c:8556
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D декларисано као пријатељ"
 
-#: cp/decl.c:8542
+#: cp/decl.c:8563
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D декларисано са одредницом изузетака"
 
-#: cp/decl.c:8574
+#: cp/decl.c:8595
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "дефиниција %qD није у именском простору који обухвата %qT"
 
-#: cp/decl.c:8614
+#: cp/decl.c:8635
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "статичка чланска функција %q#D декларисана са одредбама типа"
 
-#: cp/decl.c:8624
+#: cp/decl.c:8645
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a non-parameter"
 msgid "concept %q#D declared with function parameters"
 msgstr "%q+D декларисано као не-параметарско"
 
-#: cp/decl.c:8630
+#: cp/decl.c:8651
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared with void type"
 msgid "concept %q#D declared with a deduced return type"
 msgstr "параметар %q+D декларисан са празним типом"
 
-#: cp/decl.c:8632
+#: cp/decl.c:8653
 #, fuzzy, gcc-internal-format
 #| msgid "Java method %qD has non-Java return type %qT"
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "јавански метод %qD има не-јавански повратни тип %qT"
 
-#: cp/decl.c:8703
+#: cp/decl.c:8724
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "concept %qD has no definition"
 msgstr "декларација %qD као не-функције"
 
-#: cp/decl.c:8772
+#: cp/decl.c:8793
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "дефиниција експлицитне специјализације %qD у декларацији пријатеља"
 
 #. Something like `template <class T> friend void f<T>()'.
-#: cp/decl.c:8782
+#: cp/decl.c:8803
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "неисправна употреба ид. шаблона %qD у декларацији примарног шаблона"
 
-#: cp/decl.c:8800
+#: cp/decl.c:8821
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "подразумевани аргументи нису дозвољени у декларацији пријатељске специјализације шаблона %qD"
 
-#: cp/decl.c:8808
+#: cp/decl.c:8829
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "%<inline%> није дозвољено у декларацији пријатељске специјализације шаблона %qD"
 
-#: cp/decl.c:8857
+#: cp/decl.c:8878
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "%<::main%> се не може декларисати као шаблон"
 
-#: cp/decl.c:8859
+#: cp/decl.c:8880
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "%<::main%> се не може декларисати као уткано"
 
-#: cp/decl.c:8861
+#: cp/decl.c:8882
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be inline"
 msgid "cannot declare %<::main%> to be %<constexpr%>"
 msgstr "%<::main%> се не може декларисати као уткано"
 
-#: cp/decl.c:8863
+#: cp/decl.c:8884
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "%<::main%> се не може декларисати као статичко"
 
-#: cp/decl.c:8920
+#: cp/decl.c:8941
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "%sчланска функција %qD не може имати кн-одредбу"
 
-#: cp/decl.c:8921
+#: cp/decl.c:8942
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "%sчланска функција %qD не може имати кн-одредбу"
 
-#: cp/decl.c:8929
+#: cp/decl.c:8950
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "%sчланска функција %qD не може имати кн-одредбу"
 
-#: cp/decl.c:8930
+#: cp/decl.c:8951
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "%sчланска функција %qD не може имати кн-одредбу"
 
-#: cp/decl.c:8940
+#: cp/decl.c:8961
 #, fuzzy, gcc-internal-format
 #| msgid "%qD may not be declared within a namespace"
 msgid "deduction guide %qD must be declared at namespace scope"
 msgstr "%qD не може бити декларисано унутар именског простора"
 
-#: cp/decl.c:8946
+#: cp/decl.c:8967
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "deduction guide %qD must not have a function body"
 msgstr "декларација %qD као не-функције"
 
-#: cp/decl.c:8959
+#: cp/decl.c:8980
 #, fuzzy, gcc-internal-format
 #| msgid "template with C linkage"
 msgid "literal operator with C linkage"
 msgstr "шаблон са Ц повезивошћу"
 
-#: cp/decl.c:8969
+#: cp/decl.c:8990
 #, fuzzy, gcc-internal-format
 #| msgid "invalid option argument %qs"
 msgid "%qD has invalid argument list"
 msgstr "неисправан аргумент опције %qs"
 
-#: cp/decl.c:8977
+#: cp/decl.c:8998
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:8983
+#: cp/decl.c:9004
 #, gcc-internal-format
 msgid "floating point suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:8991
+#: cp/decl.c:9012
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/decl.c:8996
+#: cp/decl.c:9017
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a nonstatic member function"
 msgid "%qD must be a non-member function"
 msgstr "%qD мора бити нестатичка чланска функција"
 
-#: cp/decl.c:9076
+#: cp/decl.c:9097
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> мора враћати %<int%>"
 
-#: cp/decl.c:9116
+#: cp/decl.c:9137
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "дефиниција имплицитно декларисаног %qD"
 
-#: cp/decl.c:9121
+#: cp/decl.c:9142
 #, fuzzy, gcc-internal-format
 #| msgid "definition of implicitly-declared %qD"
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "дефиниција имплицитно декларисаног %qD"
 
-#: cp/decl.c:9123
+#: cp/decl.c:9144
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "%q#D explicitly defaulted here"
 msgstr "%q+#D претходно дефинисано овде"
 
-#: cp/decl.c:9140
+#: cp/decl.c:9161
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "чланска функција %q#D није декларисана у класи %qT"
 
-#: cp/decl.c:9329
+#: cp/decl.c:9350
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be a template"
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "%<::main%> се не може декларисати као шаблон"
 
-#: cp/decl.c:9337
+#: cp/decl.c:9358
 #, fuzzy, gcc-internal-format
 #| msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "аутоматска променљива %qE не може бити нитно-локална"
 
-#: cp/decl.c:9344
+#: cp/decl.c:9365
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.c:9464
+#: cp/decl.c:9485
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "неисправно успостављање унутар класе статичког чланског податка неинтегралног типа %qT"
 
-#: cp/decl.c:9468
+#: cp/decl.c:9489
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "неисправно успостављање унутар класе статичког чланског податка неинтегралног типа %qT"
 
-#: cp/decl.c:9472
+#: cp/decl.c:9493
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "неисправно успостављање унутар класе статичког чланског податка неинтегралног типа %qT"
 
-#: cp/decl.c:9486
+#: cp/decl.c:9507
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "неисправно успостављање унутар класе статичког чланског податка неинтегралног типа %qT"
 
-#: cp/decl.c:9493
+#: cp/decl.c:9514
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ИСО Ц++ забрањује успостављање унутар класе неконстантног статичког члана %qD"
 
-#: cp/decl.c:9498
+#: cp/decl.c:9519
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ИСО Ц++ забрањује успостављање чланске константе %qD неинтегралног типа %qT"
 
-#: cp/decl.c:9598
+#: cp/decl.c:9619
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "величина низа %qD има неинтегрални тип %qT"
 
-#: cp/decl.c:9600
+#: cp/decl.c:9621
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "величина низа има неинтегрални тип %qT"
 
-#: cp/decl.c:9630 cp/decl.c:9680
+#: cp/decl.c:9651 cp/decl.c:9701
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "величина низа није интегралан констатан израз"
 
-#: cp/decl.c:9646
+#: cp/decl.c:9667
 #, gcc-internal-format
 msgid "size of array %qD is negative"
 msgstr "негативна величина низа %qD"
 
-#: cp/decl.c:9648 cp/init.c:3651
+#: cp/decl.c:9669 cp/init.c:3667
 #, gcc-internal-format
 msgid "size of array is negative"
 msgstr "негативна величина низа"
 
-#: cp/decl.c:9662
+#: cp/decl.c:9683
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ИСО Ц++ забрањује низ нулте величине %qD"
 
-#: cp/decl.c:9664
+#: cp/decl.c:9685
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ИСО Ц++ забрањује низ нулте величине"
 
-#: cp/decl.c:9677
+#: cp/decl.c:9698
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "величина низа %qD није интегралан констатан израз"
 
-#: cp/decl.c:9686
+#: cp/decl.c:9707
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids variable-size array %qD"
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ИСО Ц++ забрањује низ променљиве величине %qD"
 
-#: cp/decl.c:9688
+#: cp/decl.c:9709
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids variable-size array"
 msgid "ISO C++ forbids variable length array"
 msgstr "ИСО Ц++ забрањује низ променљиве величине"
 
-#: cp/decl.c:9694
+#: cp/decl.c:9715
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr ""
 
-#: cp/decl.c:9697
+#: cp/decl.c:9718
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr ""
 
-#: cp/decl.c:9746
+#: cp/decl.c:9767
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "преливање у димензији низа"
 
-#: cp/decl.c:9799
+#: cp/decl.c:9820
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "%qD declared as array of %qT"
 msgstr "%q+D декларисано као пријатељ"
 
-#: cp/decl.c:9809
+#: cp/decl.c:9830
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of voids"
 msgid "declaration of %qD as array of void"
 msgstr "декларација %qs као низа празних"
 
-#: cp/decl.c:9811
+#: cp/decl.c:9832
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of %qT"
 msgid "creating array of void"
 msgstr "стварање низа типа %qT"
 
-#: cp/decl.c:9816
+#: cp/decl.c:9837
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of %qD as array of functions"
 msgstr "декларација %qs као низа функција"
 
-#: cp/decl.c:9818
+#: cp/decl.c:9839
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of %qT"
 msgid "creating array of functions"
 msgstr "стварање низа типа %qT"
 
-#: cp/decl.c:9823
+#: cp/decl.c:9844
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of %qD as array of references"
 msgstr "декларација %qs као низа функција"
 
-#: cp/decl.c:9825
+#: cp/decl.c:9846
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of %qT"
 msgid "creating array of references"
 msgstr "стварање низа типа %qT"
 
-#: cp/decl.c:9830
+#: cp/decl.c:9851
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of %qD as array of function members"
 msgstr "декларација %qs као низа функција"
 
-#: cp/decl.c:9832
+#: cp/decl.c:9853
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "creating array of function members"
 msgstr "декларација %qs као низа функција"
 
-#: cp/decl.c:9846
+#: cp/decl.c:9867
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "декларација %qD као вишедимензионог низа мора имати границе за све димензије осим прве"
 
-#: cp/decl.c:9850
+#: cp/decl.c:9871
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "вишедимензиони низ мора имати границе за све димензије осим прве"
 
-#: cp/decl.c:9909
+#: cp/decl.c:9930
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "навод повратног типа за конструктор није исправан"
 
-#: cp/decl.c:9912
+#: cp/decl.c:9933
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "одредбе нису дозвољене уз декларацију %<operator %T%>"
 
-#: cp/decl.c:9922
+#: cp/decl.c:9943
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "навод повратног типа за деструктор није исправан"
 
-#: cp/decl.c:9925
+#: cp/decl.c:9946
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "одредбе нису дозвољене уз декларацију %<operator %T%>"
 
-#: cp/decl.c:9937
+#: cp/decl.c:9958
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "наведен повратни тип за %<operator %T%>"
 
-#: cp/decl.c:9940
+#: cp/decl.c:9961
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "одредбе нису дозвољене уз декларацију %<operator %T%>"
 
-#: cp/decl.c:9948
+#: cp/decl.c:9969
 #, fuzzy, gcc-internal-format
 #| msgid "return type specification for destructor invalid"
 msgid "return type specified for deduction guide"
 msgstr "навод повратног типа за деструктор није исправан"
 
-#: cp/decl.c:9951
+#: cp/decl.c:9972
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "одредбе нису дозвољене уз декларацију %<operator %T%>"
 
-#: cp/decl.c:9955
+#: cp/decl.c:9976
 #, fuzzy, gcc-internal-format
 #| msgid "too many template parameter lists in declaration of %qD"
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "превише листа шаблонских параметара у декларацији %qD"
 
-#: cp/decl.c:9964
+#: cp/decl.c:9985
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting specifiers in declaration of %qs"
 msgid "decl-specifier in declaration of deduction guide"
 msgstr "сукобљени наводиоци у декларацији %qs"
 
-#: cp/decl.c:9985
+#: cp/decl.c:10006
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "неименована променљива или поље декларисано празним"
 
-#: cp/decl.c:9992
+#: cp/decl.c:10013
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "променљива или поље декларисано празним"
 
-#: cp/decl.c:10007
+#: cp/decl.c:10028
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "наводилац %<inline%> није исправан за функцију %qs декларисану изван глобалног досега"
 
-#: cp/decl.c:10013
+#: cp/decl.c:10034
 #, gcc-internal-format
 msgid "inline variables are only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/decl.c:10268
+#: cp/decl.c:10292
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "неисправна употреба одређеног имена %<::%D%>"
 
-#: cp/decl.c:10271 cp/decl.c:10291
+#: cp/decl.c:10295 cp/decl.c:10315
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "неисправна употреба одређеног имена %<%T::%D%>"
 
-#: cp/decl.c:10274
+#: cp/decl.c:10298
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "неисправна употреба одређеног имена %<%D::%D%>"
 
-#: cp/decl.c:10283
+#: cp/decl.c:10307
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a class or namespace"
 msgid "%q#T is not a class or a namespace"
 msgstr "%qT није ни класа ни именски простор"
 
-#: cp/decl.c:10305 cp/decl.c:10398 cp/decl.c:10407 cp/decl.c:11970
+#: cp/decl.c:10329 cp/decl.c:10422 cp/decl.c:10431 cp/decl.c:11994
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "декларација %qD као не-функције"
 
-#: cp/decl.c:10311
+#: cp/decl.c:10335
 #, gcc-internal-format
 msgid "declaration of %qD as non-member"
 msgstr "декларација %qD као не-члана"
 
-#: cp/decl.c:10339
+#: cp/decl.c:10363
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "недостаје ид. декларатора; користи се резервисана реч %qD"
 
-#: cp/decl.c:10390
+#: cp/decl.c:10414
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "дефиниција функције не декларише параметре"
 
-#: cp/decl.c:10415
+#: cp/decl.c:10439
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as %s"
 msgid "declaration of %qD as %<typedef%>"
 msgstr "декларација %qD као %s"
 
-#: cp/decl.c:10420
+#: cp/decl.c:10444
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of %qD as parameter"
 msgstr "декларација %q+D заклања параметар"
 
-#: cp/decl.c:10454
+#: cp/decl.c:10478
 #, fuzzy, gcc-internal-format
 #| msgid "a template-id may not appear in a using-declaration"
 msgid "%<concept%> cannot appear in a typedef declaration"
 msgstr "ид. шаблона не може да се јави у декларацији употребе"
 
-#: cp/decl.c:10460
+#: cp/decl.c:10484
 #, fuzzy, gcc-internal-format
 #| msgid "a template-id may not appear in a using-declaration"
 msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgstr "ид. шаблона не може да се јави у декларацији употребе"
 
-#: cp/decl.c:10468
+#: cp/decl.c:10492
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "два или више типова података у декларацији %qs"
 
-#: cp/decl.c:10474
+#: cp/decl.c:10498
 #, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr "сукобљени наводиоци у декларацији %qs"
 
-#: cp/decl.c:10515
+#: cp/decl.c:10539
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ИСО Ц не подржава да обичан %<complex%> значи %<double complex%>"
 
-#: cp/decl.c:10564 cp/decl.c:10567 cp/decl.c:10570
+#: cp/decl.c:10588 cp/decl.c:10591 cp/decl.c:10594
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ИСО Ц++ забрањује декларацију %qs без типа"
 
-#: cp/decl.c:10586
+#: cp/decl.c:10610
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_saveregs not supported by this target"
 msgid "%<__int%d%> is not supported by this target"
 msgstr "__builtin_saveregs није подржано овим циљем"
 
-#: cp/decl.c:10592
+#: cp/decl.c:10616
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not support %<long long%>"
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ИСО Ц++ не подржава %<long long%>"
 
-#: cp/decl.c:10614 cp/decl.c:10634
+#: cp/decl.c:10638 cp/decl.c:10658
 #, gcc-internal-format
 msgid "%<signed%> or %<unsigned%> invalid for %qs"
 msgstr "%<signed%> или %<unsigned%> неисправни за %qs"
 
-#: cp/decl.c:10616
+#: cp/decl.c:10640
 #, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgstr "%<signed%> и %<unsigned%> наведени заједно за %qs"
 
-#: cp/decl.c:10618
+#: cp/decl.c:10642
 #, gcc-internal-format
 msgid "%<long long%> invalid for %qs"
 msgstr "%<long long%> неисправно за %qs"
 
-#: cp/decl.c:10620
+#: cp/decl.c:10644
 #, gcc-internal-format
 msgid "%<long%> invalid for %qs"
 msgstr "%<long%> неисправно за %qs"
 
-#: cp/decl.c:10622
+#: cp/decl.c:10646
 #, gcc-internal-format
 msgid "%<short%> invalid for %qs"
 msgstr "%<short%> неисправно за %qs"
 
-#: cp/decl.c:10624
+#: cp/decl.c:10648
 #, gcc-internal-format
 msgid "%<long%> or %<short%> invalid for %qs"
 msgstr "%<long%> или %<short%> неисправни за %qs"
 
-#: cp/decl.c:10626
+#: cp/decl.c:10650
 #, fuzzy, gcc-internal-format
 #| msgid "%<long%> or %<short%> invalid for %qs"
 msgid "%<long%>, %<int%>, %<short%>, or %<char%> invalid for %qs"
 msgstr "%<long%> или %<short%> неисправни за %qs"
 
-#: cp/decl.c:10628
+#: cp/decl.c:10652
 #, gcc-internal-format
 msgid "%<long%> or %<short%> specified with char for %qs"
 msgstr "%<long%> или %<short%> наведено уз char за %qs"
 
-#: cp/decl.c:10630
+#: cp/decl.c:10654
 #, gcc-internal-format
 msgid "%<long%> and %<short%> specified together for %qs"
 msgstr "%<long%> и %<short%> наведени заједно за %qs"
 
-#: cp/decl.c:10636
+#: cp/decl.c:10660
 #, fuzzy, gcc-internal-format
 #| msgid "%<long%> or %<short%> invalid for %qs"
 msgid "%<short%> or %<long%> invalid for %qs"
 msgstr "%<long%> или %<short%> неисправни за %qs"
 
-#: cp/decl.c:10644
+#: cp/decl.c:10668
 #, gcc-internal-format
 msgid "long, short, signed or unsigned used invalidly for %qs"
 msgstr "long, short, signed или unsigned употребљени неисправно за %qs"
 
-#: cp/decl.c:10712
+#: cp/decl.c:10736
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "complex неисправно за %qs"
 
-#: cp/decl.c:10751
+#: cp/decl.c:10775
 #, gcc-internal-format
 msgid "template placeholder type %qT must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.c:10769
+#: cp/decl.c:10793
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "члан %qD не може бити декларисан и као виртуелни и као статички"
 
-#: cp/decl.c:10775
+#: cp/decl.c:10799
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD cannot be declared both %<virtual%> and %<constexpr%>"
 msgstr "члан %qD не може бити декларисан и као виртуелни и као статички"
 
-#: cp/decl.c:10785
+#: cp/decl.c:10809
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "декларација typedef није исправна у декларацији параметра"
 
-#: cp/decl.c:10790
+#: cp/decl.c:10814
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "storage class specified for template parameter %qs"
 msgstr "складишна класа наведена за параметар %qs"
 
-#: cp/decl.c:10796
+#: cp/decl.c:10820
 #, gcc-internal-format
 msgid "storage class specifiers invalid in parameter declarations"
 msgstr "наводиоци складишне класе нису исправни у декларацијама параметара"
 
-#: cp/decl.c:10800
+#: cp/decl.c:10824
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared %<inline%>"
 msgid "a parameter cannot be declared %<concept%>"
 msgstr "параметар %q+D декларисан као %<inline%>"
 
-#: cp/decl.c:10805
+#: cp/decl.c:10829
 #, fuzzy, gcc-internal-format
 #| msgid "non-member %qs cannot be declared %<mutable%>"
 msgid "a parameter cannot be declared %<constexpr%>"
 msgstr "не-члан %qs не може бити декларисан %<mutable%>"
 
-#: cp/decl.c:10815
+#: cp/decl.c:10839
 #, fuzzy, gcc-internal-format
 #| msgid "virtual outside class declaration"
 msgid "%<virtual%> outside class declaration"
 msgstr "virtual изван декларације класе"
 
-#: cp/decl.c:10825
+#: cp/decl.c:10849
 #, fuzzy, gcc-internal-format
 #| msgid "Warn when an inlined function cannot be inlined"
 msgid "structured binding declaration cannot be %<inline%>"
 msgstr "Упозори када се уткана функција не може уткати"
 
-#: cp/decl.c:10828
+#: cp/decl.c:10852
 #, fuzzy, gcc-internal-format
 #| msgid "function definition declared %<typedef%>"
 msgid "structured binding declaration cannot be %<typedef%>"
 msgstr "дефиниција функције декларисана као %<typedef%>"
 
-#: cp/decl.c:10830
+#: cp/decl.c:10854
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<constexpr%>"
 msgstr ""
 
-#: cp/decl.c:10834
+#: cp/decl.c:10858
 #, fuzzy, gcc-internal-format
 #| msgid "attribute ignored in declaration of %q+#T"
 msgid "structured binding declaration cannot be %qs"
 msgstr "атрибут игнорисан у декларацији %q+#T"
 
-#: cp/decl.c:10839
+#: cp/decl.c:10863
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<concept%>"
 msgstr ""
 
-#: cp/decl.c:10845
+#: cp/decl.c:10869
 #, fuzzy, gcc-internal-format
 #| msgid "subscripting array declared %<register%>"
 msgid "structured binding declaration cannot be %<register%>"
 msgstr "индексирање низа декларисаног као %<register%>"
 
-#: cp/decl.c:10849
+#: cp/decl.c:10873
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<static%>"
 msgstr ""
 
-#: cp/decl.c:10853
+#: cp/decl.c:10877
 #, fuzzy, gcc-internal-format
 #| msgid "nested function %qs declared %<extern%>"
 msgid "structured binding declaration cannot be %<extern%>"
 msgstr "угњеждена функција %qs декларисана као %<extern%>"
 
-#: cp/decl.c:10857
+#: cp/decl.c:10881
 #, fuzzy, gcc-internal-format
 #| msgid "function %qs cannot be declared %<mutable%>"
 msgid "structured binding declaration cannot be %<mutable%>"
 msgstr "функција %qs не може бити декларисана %<mutable%>"
 
-#: cp/decl.c:10861
+#: cp/decl.c:10885
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10872
+#: cp/decl.c:10896
 #, fuzzy, gcc-internal-format
 #| msgid "attribute ignored in declaration of %q+#T"
 msgid "structured binding declaration cannot have type %qT"
 msgstr "атрибут игнорисан у декларацији %q+#T"
 
-#: cp/decl.c:10875
+#: cp/decl.c:10899
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10906
+#: cp/decl.c:10930
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "вишеструке складишне класе у декларацији %qs"
 
-#: cp/decl.c:10929
+#: cp/decl.c:10953
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "складишна класа наведена за %qs"
 
-#: cp/decl.c:10933
+#: cp/decl.c:10957
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "складишна класа наведена за параметар %qs"
 
-#: cp/decl.c:10946
+#: cp/decl.c:10970
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "угњеждена функција %qs декларисана као %<extern%>"
 
-#: cp/decl.c:10950
+#: cp/decl.c:10974
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "декларација %qs на највишем нивоу наводи %<auto%>"
 
-#: cp/decl.c:10957
+#: cp/decl.c:10981
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "%qs досега функције имплицитно аутоматска и декларасина као %<__thread%>"
 
-#: cp/decl.c:10969
+#: cp/decl.c:10993
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "наводиоци складишне класе нису исправни у декларацијама пријатељских функција"
 
-#: cp/decl.c:11050
+#: cp/decl.c:11074
 #, fuzzy, gcc-internal-format
 #| msgid "multiple storage classes in declaration of %qs"
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "вишеструке складишне класе у декларацији %qs"
 
-#: cp/decl.c:11098
+#: cp/decl.c:11122
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.c:11118
+#: cp/decl.c:11142
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.c:11121
+#: cp/decl.c:11145
 #, gcc-internal-format
 msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/decl.c:11127
+#: cp/decl.c:11151
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual function cannot have deduced return type"
 msgstr "виртуелне функције не могу бити пријатељи"
 
-#: cp/decl.c:11134
+#: cp/decl.c:11158
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:11147
+#: cp/decl.c:11171
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "deduced class type %qD in function return type"
 msgstr "одредбе типова се игноришу на повратном типу функције"
 
-#: cp/decl.c:11156
+#: cp/decl.c:11180
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr ""
 
-#: cp/decl.c:11169
+#: cp/decl.c:11193
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
@@ -47868,59 +47912,59 @@
 
 #. Not using maybe_warn_cpp0x because this should
 #. always be an error.
-#: cp/decl.c:11180
+#: cp/decl.c:11204
 #, gcc-internal-format
 msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/decl.c:11183
+#: cp/decl.c:11207
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.c:11212
+#: cp/decl.c:11236
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs декларисано као функција која враћа функцију"
 
-#: cp/decl.c:11218
+#: cp/decl.c:11242
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs декларисано као функција која враћа низ"
 
-#: cp/decl.c:11247
+#: cp/decl.c:11271
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "деструктор не може бити статичка чланска функција"
 
-#: cp/decl.c:11248
+#: cp/decl.c:11272
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "конструктор не може бити статичка чланска функција"
 
-#: cp/decl.c:11252
+#: cp/decl.c:11276
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "деструктори не могу бити кн-одређени"
 
-#: cp/decl.c:11253
+#: cp/decl.c:11277
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "конструктори не могу бити кн-одређени"
 
-#: cp/decl.c:11261
+#: cp/decl.c:11285
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "destructors may not be ref-qualified"
 msgstr "деструктори не могу бити кн-одређени"
 
-#: cp/decl.c:11262
+#: cp/decl.c:11286
 #, fuzzy, gcc-internal-format
 #| msgid "constructors may not be cv-qualified"
 msgid "constructors may not be ref-qualified"
 msgstr "конструктори не могу бити кн-одређени"
 
-#: cp/decl.c:11280
+#: cp/decl.c:11304
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructors cannot be declared %<virtual%>"
@@ -47927,264 +47971,264 @@
 msgstr "конструктор не може бити виртуелан"
 
 #. Cannot be both friend and virtual.
-#: cp/decl.c:11295
+#: cp/decl.c:11319
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "виртуелне функције не могу бити пријатељи"
 
-#: cp/decl.c:11299
+#: cp/decl.c:11323
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "декларација пријатеља није у дефиницији класе"
 
-#: cp/decl.c:11301
+#: cp/decl.c:11325
 #, fuzzy, gcc-internal-format
 #| msgid "can't define friend function %qs in a local class definition"
 msgid "can%'t define friend function %qs in a local class definition"
 msgstr "не може се дефинисати пријатељска функција %qs у дефиницији локалне класе"
 
-#: cp/decl.c:11313
+#: cp/decl.c:11337
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr ""
 
-#: cp/decl.c:11339
+#: cp/decl.c:11363
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "деструктори не могу имати параметре"
 
-#: cp/decl.c:11379
+#: cp/decl.c:11403
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "не може се декларисати показивач на %q#T"
 
-#: cp/decl.c:11392 cp/decl.c:11399
+#: cp/decl.c:11416 cp/decl.c:11423
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "не може се декларисати упућивач на %q#T"
 
-#: cp/decl.c:11401
+#: cp/decl.c:11425
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "не може се декларисати показивач на члан %q#T"
 
-#: cp/decl.c:11430
+#: cp/decl.c:11454
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "не може се декларисати упућивач на %q#T"
 
-#: cp/decl.c:11431
+#: cp/decl.c:11455
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare bit-field %qD with function type"
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "не може се декларисати битско поље %qD са функцијским типом"
 
-#: cp/decl.c:11504
+#: cp/decl.c:11528
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.c:11574
+#: cp/decl.c:11598
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "ид. шаблона %qD употребљен као декларатор"
 
-#: cp/decl.c:11599
+#: cp/decl.c:11623
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "чланске функције су имплицитно пријатељи својих класа"
 
-#: cp/decl.c:11605
+#: cp/decl.c:11629
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "сувишна одредба %<%T::%> на члану %qs"
 
-#: cp/decl.c:11635
+#: cp/decl.c:11659
 #, fuzzy, gcc-internal-format
 #| msgid "cannot define member function %<%T::%s%> within %<%T%>"
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "не може се дефинисати чланска функција %<%T::%s%> унутар %<%T%>"
 
-#: cp/decl.c:11637
+#: cp/decl.c:11661
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member function %<%T::%s%> within %<%T%>"
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "не може се декларисати функција %<%T::%s%> унутар %<%T%>"
 
-#: cp/decl.c:11645
+#: cp/decl.c:11669
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "не може се декларисати члан %<%T::%s%> унутар %qT"
 
-#: cp/decl.c:11685
+#: cp/decl.c:11709
 #, fuzzy, gcc-internal-format
 #| msgid "data member %qD cannot be a member template"
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "члански податак %qD не може бити члански шаблон"
 
-#: cp/decl.c:11693
+#: cp/decl.c:11717
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "члански податак не може имати променљиво измењив тип %qT"
 
-#: cp/decl.c:11695
+#: cp/decl.c:11719
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "параметар не може имати променљиво измењив тип %qT"
 
-#: cp/decl.c:11706
+#: cp/decl.c:11730
 #, fuzzy, gcc-internal-format
 #| msgid "virtual outside class declaration"
 msgid "%<explicit%> outside class declaration"
 msgstr "virtual изван декларације класе"
 
-#: cp/decl.c:11709
+#: cp/decl.c:11733
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<explicit%> in friend declaration"
 msgstr "%<inline%> у празној декларацији"
 
-#: cp/decl.c:11712
+#: cp/decl.c:11736
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be %<explicit%>"
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "само декларације конструктора могу имати %<explicit%>"
 
-#: cp/decl.c:11721
+#: cp/decl.c:11745
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "не-члан %qs не може бити декларисан %<mutable%>"
 
-#: cp/decl.c:11726
+#: cp/decl.c:11750
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "не-објектни члан %qs не може бити декларисан %<mutable%>"
 
-#: cp/decl.c:11732
+#: cp/decl.c:11756
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "функција %qs не може бити декларисана %<mutable%>"
 
-#: cp/decl.c:11737
+#: cp/decl.c:11761
 #, gcc-internal-format
 msgid "static %qs cannot be declared %<mutable%>"
 msgstr "статичко %qs не може бити декларисано %<mutable%>"
 
-#: cp/decl.c:11742
+#: cp/decl.c:11766
 #, gcc-internal-format
 msgid "const %qs cannot be declared %<mutable%>"
 msgstr "константно %qs не може бити декларисано %<mutable%>"
 
-#: cp/decl.c:11747
+#: cp/decl.c:11771
 #, fuzzy, gcc-internal-format
 #| msgid "function %qs cannot be declared %<mutable%>"
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "функција %qs не може бити декларисана %<mutable%>"
 
-#: cp/decl.c:11778
+#: cp/decl.c:11802
 #, fuzzy, gcc-internal-format
 #| msgid "typedef %q+D declared %<inline%>"
 msgid "typedef declared %<auto%>"
 msgstr "дефиниција типа %q+D декларисана као %<inline%>"
 
-#: cp/decl.c:11783
+#: cp/decl.c:11807
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.c:11787
+#: cp/decl.c:11811
 #, fuzzy, gcc-internal-format
 #| msgid "%Jtypedef name may not be a nested-name-specifier"
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "%Jиме за дефиницију типа не може бити угњеждени-именски-наводилац"
 
-#: cp/decl.c:11813
+#: cp/decl.c:11837
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ИСО Ц++ забрањује угњеждени тип %qD истог имена као и обухватајућа класа"
 
-#: cp/decl.c:11900
+#: cp/decl.c:11924
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "%<inline%> наведено уз декларацију пријатељске класе"
 
-#: cp/decl.c:11908
+#: cp/decl.c:11932
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "шаблонски параметри не могу бити пријатељи"
 
-#: cp/decl.c:11910
+#: cp/decl.c:11934
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "декларација пријатеља захтева реч class, тј. %<friend class %T::%D%>"
 
-#: cp/decl.c:11914
+#: cp/decl.c:11938
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "декларација пријатеља захтева реч class, тј. %<friend %#T%>"
 
-#: cp/decl.c:11927
+#: cp/decl.c:11951
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "покушај да се класа %qT учини пријатељем глобалног досега"
 
-#: cp/decl.c:11947
+#: cp/decl.c:11971
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "неисправне одредбе уз тип не-чланске функције"
 
-#: cp/decl.c:11951
+#: cp/decl.c:11975
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.c:11961
+#: cp/decl.c:11985
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "апстрактни декларатор %qT употребљен као декларација"
 
-#: cp/decl.c:11976
+#: cp/decl.c:12000
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of C++ built-in type %qT"
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "поновљена декларација Ц++ уграђеног типа %qT"
 
-#: cp/decl.c:11995
+#: cp/decl.c:12019
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "не може се користити %<::%> у декларацији параметра"
 
-#: cp/decl.c:12001
+#: cp/decl.c:12025
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "%<this%> се не може употребити у овом контексту"
 
-#: cp/decl.c:12003
+#: cp/decl.c:12027
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared %<inline%>"
 msgid "parameter declared %<auto%>"
 msgstr "параметар %q+D декларисан као %<inline%>"
 
-#: cp/decl.c:12052 cp/parser.c:3270
+#: cp/decl.c:12076 cp/parser.c:3270
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "неисправна употреба шаблонског имена %qE без листе аргумената"
 
-#: cp/decl.c:12056
+#: cp/decl.c:12080
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "non-static data member declared with placeholder %qT"
 msgstr "статички члан %qD декларисан као %<register%>"
 
-#: cp/decl.c:12080
+#: cp/decl.c:12104
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids zero-size array %qD"
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ИСО Ц++ забрањује низ нулте величине %qD"
 
-#: cp/decl.c:12083
+#: cp/decl.c:12107
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array members"
@@ -48191,177 +48235,177 @@
 msgstr "ИСО Ц 90 не подржава флексибилне чланске низове"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:12099
+#: cp/decl.c:12123
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "неисправна употреба %<::%>"
 
-#: cp/decl.c:12121
+#: cp/decl.c:12145
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of C function %q#D conflicts with"
 msgid "declaration of function %qD in invalid context"
 msgstr "декларација Ц функције %q#D коси се са"
 
-#: cp/decl.c:12130
+#: cp/decl.c:12154
 #, fuzzy, gcc-internal-format
 #| msgid "function %qD declared virtual inside a union"
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "функција %qD декларисана виртуелном унутар уније"
 
-#: cp/decl.c:12139
+#: cp/decl.c:12163
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be declared virtual, since it is always static"
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%qD не може бити декларисана виртуелном, јер је увек статичка"
 
-#: cp/decl.c:12153
+#: cp/decl.c:12177
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "очекивано одређено име у декларацији пријатеља за деструктор %qD"
 
-#: cp/decl.c:12160
+#: cp/decl.c:12184
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "декларација %qD као члана %qT"
 
-#: cp/decl.c:12166
+#: cp/decl.c:12190
 #, fuzzy, gcc-internal-format
 #| msgid "destructor cannot be static member function"
 msgid "a destructor cannot be %<concept%>"
 msgstr "деструктор не може бити статичка чланска функција"
 
-#: cp/decl.c:12171
+#: cp/decl.c:12195
 #, fuzzy, gcc-internal-format
 #| msgid "Constructor can't be %s"
 msgid "a destructor cannot be %<constexpr%>"
 msgstr "Конструктор не може бити %s"
 
-#: cp/decl.c:12177
+#: cp/decl.c:12201
 #, fuzzy, gcc-internal-format
 #| msgid "expected qualified name in friend declaration for destructor %qD"
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "очекивано одређено име у декларацији пријатеља за деструктор %qD"
 
-#: cp/decl.c:12185
+#: cp/decl.c:12209
 #, fuzzy, gcc-internal-format
 #| msgid "Constructor can't be %s"
 msgid "a constructor cannot be %<concept%>"
 msgstr "Конструктор не може бити %s"
 
-#: cp/decl.c:12190
+#: cp/decl.c:12214
 #, fuzzy, gcc-internal-format
 #| msgid "constructor cannot be static member function"
 msgid "a concept cannot be a member function"
 msgstr "конструктор не може бити статичка чланска функција"
 
-#: cp/decl.c:12199
+#: cp/decl.c:12223
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of implicitly-declared special member function"
 msgid "specialization of variable template %qD declared as function"
 msgstr "специјализација имплицитно декларисане посебне чланске функције"
 
-#: cp/decl.c:12202
+#: cp/decl.c:12226
 #, fuzzy, gcc-internal-format
 #| msgid "variable or field declared void"
 msgid "variable template declared here"
 msgstr "променљива или поље декларисано празним"
 
-#: cp/decl.c:12257
+#: cp/decl.c:12281
 #, fuzzy, gcc-internal-format
 #| msgid "field %qD has incomplete type"
 msgid "field %qD has incomplete type %qT"
 msgstr "поље %qD има непотпун тип"
 
-#: cp/decl.c:12262
+#: cp/decl.c:12286
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "име %qT има непотпун тип"
 
-#: cp/decl.c:12272
+#: cp/decl.c:12296
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE није ни функција ни чланска функција; не може се декларисати пријатељем"
 
-#: cp/decl.c:12318
+#: cp/decl.c:12342
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "static data member %qE declared %<concept%>"
 msgstr "статички члан %qD декларисан као %<register%>"
 
-#: cp/decl.c:12322
+#: cp/decl.c:12346
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L cannot have an initializer"
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "Сопствено ‘%s’ код %L не може имати успостављач"
 
-#: cp/decl.c:12350
+#: cp/decl.c:12374
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "non-static data member %qE declared %<concept%>"
 msgstr "статички члан %qD декларисан као %<register%>"
 
-#: cp/decl.c:12354
+#: cp/decl.c:12378
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "non-static data member %qE declared %<constexpr%>"
 msgstr "статички члан %qD декларисан као %<register%>"
 
-#: cp/decl.c:12409
+#: cp/decl.c:12433
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "складишна класа %<auto%> неисправна за функцију %qs"
 
-#: cp/decl.c:12411
+#: cp/decl.c:12435
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "складишна класа %<register%> неисправна за функцију %qs"
 
-#: cp/decl.c:12415
+#: cp/decl.c:12439
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "складишна класа %<__thread%> неисправна за функцију %qs"
 
-#: cp/decl.c:12418
+#: cp/decl.c:12442
 #, fuzzy, gcc-internal-format
 #| msgid "storage class %<__thread%> invalid for function %qs"
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "складишна класа %<__thread%> неисправна за функцију %qs"
 
-#: cp/decl.c:12423
+#: cp/decl.c:12447
 #, fuzzy, gcc-internal-format
 #| msgid "an asm-specification is not allowed on a function-definition"
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "навод asm није дозвољен на дефиницији функције"
 
-#: cp/decl.c:12434
+#: cp/decl.c:12458
 #, fuzzy, gcc-internal-format
 #| msgid "%<static%> specified invalid for function %qs declared out of global scope"
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "%<static%> неисправно наведено за функцију %qs декларисану изван глобалног досега"
 
-#: cp/decl.c:12438
+#: cp/decl.c:12462
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "наводилац %<inline%> није исправан за функцију %qs декларисану изван глобалног досега"
 
-#: cp/decl.c:12446
+#: cp/decl.c:12470
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "виртуелна не-класна функција %qs"
 
-#: cp/decl.c:12453
+#: cp/decl.c:12477
 #, fuzzy, gcc-internal-format
 #| msgid "No variable %qs defined in class %qs"
 msgid "%qs defined in a non-class scope"
 msgstr "Променљива %qs није дефинисана у класи %qs"
 
-#: cp/decl.c:12454
+#: cp/decl.c:12478
 #, fuzzy, gcc-internal-format
 #| msgid "%qD was not declared in this scope"
 msgid "%qs declared in a non-class scope"
 msgstr "%qD није декларисано у овом досегу"
 
-#: cp/decl.c:12489
+#: cp/decl.c:12513
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "не може се декларисати статичка повезивост за чланску функцију %qD"
@@ -48368,83 +48412,83 @@
 
 #. 7.1.1: There can be no static function declarations within a
 #. block.
-#: cp/decl.c:12497
+#: cp/decl.c:12521
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "не може се декларисати статичка функција унутар друге функције"
 
-#: cp/decl.c:12533
+#: cp/decl.c:12557
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "%<static%> не може бити употребљено при дефинисању (насупрот декларисања) статичког чланског податка"
 
-#: cp/decl.c:12540
+#: cp/decl.c:12564
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "статички члан %qD декларисан као %<register%>"
 
-#: cp/decl.c:12546
+#: cp/decl.c:12570
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "не може се експлицитно декларисати спољашња повезивост за члан %q#D"
 
-#: cp/decl.c:12553
+#: cp/decl.c:12577
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %<extern%> variable %q+D in %<for%> loop initial declaration"
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "декларација спољашње променљиве %q+D у почетној декларацији %<for%> петље"
 
-#: cp/decl.c:12574
+#: cp/decl.c:12598
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D has %<extern%> and is initialized"
 msgid "declaration of %q#D has no initializer"
 msgstr "декларација %q#D има %<extern%> и ипак је успостављена"
 
-#: cp/decl.c:12585
+#: cp/decl.c:12609
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs успостављено и декларисано као %<extern%>"
 
-#: cp/decl.c:12589
+#: cp/decl.c:12613
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs има и %<extern%> и успостављач"
 
-#: cp/decl.c:12754
+#: cp/decl.c:12778
 #, fuzzy, gcc-internal-format
 #| msgid "default argument %qE uses local variable %qD"
 msgid "default argument %qE uses %qD"
 msgstr "подразумевани аргумент %qE користи локалну променљиву %qD"
 
-#: cp/decl.c:12757
+#: cp/decl.c:12781
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "подразумевани аргумент %qE користи локалну променљиву %qD"
 
-#: cp/decl.c:12841
+#: cp/decl.c:12865
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specifiers invalid in parameter declarations"
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "наводиоци складишне класе нису исправни у декларацијама параметара"
 
-#: cp/decl.c:12845
+#: cp/decl.c:12869
 #, fuzzy, gcc-internal-format
 #| msgid "cannot use %<::%> in parameter declaration"
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "не може се користити %<::%> у декларацији параметра"
 
-#: cp/decl.c:12868
+#: cp/decl.c:12892
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "параметар %qD неисправно декларише тип метода"
 
-#: cp/decl.c:12895
+#: cp/decl.c:12919
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD includes %s to array of unknown bound %qT"
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "параметар %qD укључује %s у низ непознатих граница %qT"
 
-#: cp/decl.c:12897
+#: cp/decl.c:12921
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD includes %s to array of unknown bound %qT"
 msgid "parameter %qD includes reference to array of unknown bound %qT"
@@ -48465,185 +48509,185 @@
 #. or implicitly defined), there's no need to worry about their
 #. existence.  Theoretically, they should never even be
 #. instantiated, but that's hard to forestall.
-#: cp/decl.c:13150
+#: cp/decl.c:13174
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "неисправан конструктор; вероватно сте мислили %<%T (const %T&)%>"
 
-#: cp/decl.c:13228
+#: cp/decl.c:13252
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD не може бити декларисано унутар именског простора"
 
-#: cp/decl.c:13234
+#: cp/decl.c:13258
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD не може бити декларисано статичко"
 
-#: cp/decl.c:13261
+#: cp/decl.c:13285
 #, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr "%qD мора бити нестатичка чланска функција"
 
-#: cp/decl.c:13267
+#: cp/decl.c:13291
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD мора бити или нестатичка чланска функција или не-чланска функција"
 
-#: cp/decl.c:13277
+#: cp/decl.c:13301
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD мора имати аргумент класног или набројивог типа"
 
 #. 13.4.0.3
-#: cp/decl.c:13303
+#: cp/decl.c:13327
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading operator ?:"
 msgstr "ИСО Ц++ забрањује препуњавање оператора ?:"
 
 #. Variadic.
-#: cp/decl.c:13314
+#: cp/decl.c:13338
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD не може имати променљив број аргумената"
 
-#: cp/decl.c:13338
+#: cp/decl.c:13362
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either zero or one argument"
 msgid "%qD must have either zero or one argument"
 msgstr "%qD мора узимати ниједан или један аргумент"
 
-#: cp/decl.c:13339
+#: cp/decl.c:13363
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either one or two arguments"
 msgid "%qD must have either one or two arguments"
 msgstr "%qD мора узимати један или два аргумента"
 
-#: cp/decl.c:13350
+#: cp/decl.c:13374
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its argument"
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "постфиксно %qD мора узимати %<int%> као аргумент"
 
-#: cp/decl.c:13351
+#: cp/decl.c:13375
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its second argument"
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "постфиксно %qD мора узимати %<int%> као други аргумент"
 
-#: cp/decl.c:13361
+#: cp/decl.c:13385
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have no arguments"
 msgstr "%qD мора узимати тачно два аргумента"
 
-#: cp/decl.c:13362 cp/decl.c:13371
+#: cp/decl.c:13386 cp/decl.c:13395
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly one argument"
 msgid "%qD must have exactly one argument"
 msgstr "%qD мора узимати тачно један аргумент"
 
-#: cp/decl.c:13372
+#: cp/decl.c:13396
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have exactly two arguments"
 msgstr "%qD мора узимати тачно два аргумента"
 
-#: cp/decl.c:13389 cp/decl.c:13392
+#: cp/decl.c:13413 cp/decl.c:13416
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD не може имати подразумеване аргументе"
 
-#: cp/decl.c:13419
+#: cp/decl.c:13443
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to a reference to void will never use a type conversion operator"
 msgstr "претварање у %s%s никад неће користити оператор претварања типа"
 
-#: cp/decl.c:13421
+#: cp/decl.c:13445
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to void will never use a type conversion operator"
 msgstr "претварање у %s%s никад неће користити оператор претварања типа"
 
-#: cp/decl.c:13428
+#: cp/decl.c:13452
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgstr "претварање у %s%s никад неће користити оператор претварања типа"
 
-#: cp/decl.c:13430
+#: cp/decl.c:13454
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to the same type will never use a type conversion operator"
 msgstr "претварање у %s%s никад неће користити оператор претварања типа"
 
-#: cp/decl.c:13438
+#: cp/decl.c:13462
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgstr "претварање у %s%s никад неће користити оператор претварања типа"
 
-#: cp/decl.c:13440
+#: cp/decl.c:13464
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to a base class will never use a type conversion operator"
 msgstr "претварање у %s%s никад неће користити оператор претварања типа"
 
-#: cp/decl.c:13455
+#: cp/decl.c:13479
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "кориснички дефинисано %qD увек израчунава оба аргумента"
 
-#: cp/decl.c:13474
+#: cp/decl.c:13498
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "префиксно %qD треба да враћа %qT"
 
-#: cp/decl.c:13480
+#: cp/decl.c:13504
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "постфиксно %qD треба да враћа %qT"
 
-#: cp/decl.c:13492
+#: cp/decl.c:13516
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD треба да враћа по вредност"
 
-#: cp/decl.c:13547
+#: cp/decl.c:13571
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "употреба параметра шаблонског типа %qT после %qs"
 
-#: cp/decl.c:13570
+#: cp/decl.c:13594
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous template specialization %qD for %q+D"
 msgid "using alias template specialization %qT after %qs"
 msgstr "двосмислена специјализација шаблона %qD за %q+D"
 
-#: cp/decl.c:13573
+#: cp/decl.c:13597
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "употреба typedef-имена %qD после %qs"
 
-#: cp/decl.c:13575
+#: cp/decl.c:13599
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D has a previous declaration here"
 msgid "%qD has a previous declaration here"
 msgstr "%q+D има претходну декларацију овде"
 
-#: cp/decl.c:13583
+#: cp/decl.c:13607
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "%qT се помиње као %qs"
 
-#: cp/decl.c:13584 cp/decl.c:13591
+#: cp/decl.c:13608 cp/decl.c:13615
 #, fuzzy, gcc-internal-format
 #| msgid "%q+T has a previous declaration here"
 msgid "%qT has a previous declaration here"
 msgstr "%q+T има претходну декларацију овде"
 
-#: cp/decl.c:13590
+#: cp/decl.c:13614
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "%qT се помиње као набрајање"
@@ -48655,96 +48699,96 @@
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:13605
+#: cp/decl.c:13629
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "потребан шаблонски аргумент за %<%s %T%>"
 
-#: cp/decl.c:13659 cp/name-lookup.c:4652
+#: cp/decl.c:13683 cp/name-lookup.c:4652
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD има исто име као и класа у којој је декларисано"
 
-#: cp/decl.c:13689 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6425
-#: cp/pt.c:9209
+#: cp/decl.c:13713 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6428
+#: cp/pt.c:9223
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT није шаблон"
 
-#: cp/decl.c:13694
+#: cp/decl.c:13718
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:13703 cp/name-lookup.c:4079 cp/name-lookup.c:4086
-#: cp/name-lookup.c:4939 cp/parser.c:6376 cp/parser.c:26300
+#: cp/decl.c:13727 cp/name-lookup.c:4079 cp/name-lookup.c:4086
+#: cp/name-lookup.c:4939 cp/parser.c:6379 cp/parser.c:26297
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "двосмислено упућивање на %qD"
 
-#: cp/decl.c:13806
+#: cp/decl.c:13830
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "употреба набрајања %q#D без претходне декларације"
 
-#: cp/decl.c:13842
+#: cp/decl.c:13866
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "поновљена декларација %qT као не-шаблона"
 
-#: cp/decl.c:13982
+#: cp/decl.c:14006
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "неисправна изведена унија %qT"
 
-#: cp/decl.c:13989
+#: cp/decl.c:14013
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr ""
 
-#: cp/decl.c:14000
+#: cp/decl.c:14024
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not a direct or virtual base of %qT"
 msgid "%qT defined with direct virtual base"
 msgstr "тип %qT није непосредна или виртуелна основа од %qT"
 
-#: cp/decl.c:14025
+#: cp/decl.c:14049
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "тип основе %qT није класа или структура"
 
-#: cp/decl.c:14055
+#: cp/decl.c:14079
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "недефинисан рекурзивни тип %qT"
 
-#: cp/decl.c:14057
+#: cp/decl.c:14081
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "неисправан удвостручен тип основе %qT"
 
-#: cp/decl.c:14202
+#: cp/decl.c:14226
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14205 cp/decl.c:14213 cp/decl.c:14225 cp/parser.c:18284
+#: cp/decl.c:14229 cp/decl.c:14237 cp/decl.c:14249 cp/parser.c:18281
 #, fuzzy, gcc-internal-format
 #| msgid "%Jprevious definition here"
 msgid "previous definition here"
 msgstr "%Jпретходна дефиниција је овде"
 
-#: cp/decl.c:14210
+#: cp/decl.c:14234
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14222
+#: cp/decl.c:14246
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14300
+#: cp/decl.c:14324
 #, fuzzy, gcc-internal-format
 #| msgid "Cray pointer at %C must be an integer."
 msgid "underlying type %qT of %qT must be an integral type"
@@ -48754,85 +48798,85 @@
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:14447
+#: cp/decl.c:14471
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "ниједан интегрални тип не може представљати све вредности набрајача за %qT"
 
-#: cp/decl.c:14619
+#: cp/decl.c:14643
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qD not integer constant"
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "вредност набрајача за %qD није целобројна константа"
 
-#: cp/decl.c:14629
+#: cp/decl.c:14653
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qE is not an integer constant"
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "вредност набрајача за %qE није целобројна константа"
 
-#: cp/decl.c:14678
+#: cp/decl.c:14702
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C restricts enumerator values to range of %<int%>"
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "ИСО Ц ограничава вредности набрајача на опсег %<int%>"
 
-#: cp/decl.c:14679
+#: cp/decl.c:14703
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C restricts enumerator values to range of %<int%>"
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "ИСО Ц ограничава вредности набрајача на опсег %<int%>"
 
-#: cp/decl.c:14690
+#: cp/decl.c:14714
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "преливање у вредностима набрајача код %qD"
 
-#: cp/decl.c:14710
+#: cp/decl.c:14734
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qE is not an integer constant"
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "вредност набрајача за %qE није целобројна константа"
 
-#: cp/decl.c:14821
+#: cp/decl.c:14845
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "повратни тип %q#T није потпун"
 
-#: cp/decl.c:14999 cp/typeck.c:9286
+#: cp/decl.c:15023 cp/typeck.c:9286
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> треба да враћа упућивач на %<*this%>"
 
-#: cp/decl.c:15344
+#: cp/decl.c:15368
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member function declaration"
 msgid "invalid function declaration"
 msgstr "неисправна декларација чланске функције"
 
-#: cp/decl.c:15786
+#: cp/decl.c:15810
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statements in function returning %qT"
 msgstr "нема повратне наредбе у функцији која враћа непразан тип"
 
-#: cp/decl.c:15788 cp/typeck.c:9166
+#: cp/decl.c:15812 cp/typeck.c:9166
 #, fuzzy, gcc-internal-format
 #| msgid "function return types not compatible due to %<volatile%>"
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "повратни типови функција нису сагласни услед %<volatile%>"
 
-#: cp/decl.c:15996
+#: cp/decl.c:16020
 #, gcc-internal-format
 msgid "invalid member function declaration"
 msgstr "неисправна декларација чланске функције"
 
-#: cp/decl.c:16010
+#: cp/decl.c:16034
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD је већ дефинисано у класи %qT"
 
-#: cp/decl.c:16386
+#: cp/decl.c:16410
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -48873,7 +48917,7 @@
 msgid "deleting %qT is undefined"
 msgstr "брисање %qT није дефинисано"
 
-#: cp/decl2.c:585 cp/pt.c:5552
+#: cp/decl2.c:585 cp/pt.c:5566
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "декларација шаблона %q#D"
@@ -48887,7 +48931,7 @@
 #. [temp.mem]
 #.
 #. A destructor shall not be a member template.
-#: cp/decl2.c:640 cp/pt.c:5511
+#: cp/decl2.c:640 cp/pt.c:5525
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "деструктор %qD декларисан као члански шаблон"
@@ -49074,51 +49118,51 @@
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "%<operator delete%> узима тип %<size_t%> (%qT) као први параметар"
 
-#: cp/decl2.c:2660
+#: cp/decl2.c:2650
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgid "%qT has a field %qD whose type has no linkage"
 msgstr "%qT има поље %qD чији тип користи анонимни именски простор"
 
-#: cp/decl2.c:2664
+#: cp/decl2.c:2654
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr "%qT има поље %qD чији тип користи анонимни именски простор"
 
-#: cp/decl2.c:2669
+#: cp/decl2.c:2659
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr "%qT има поље %qD чији тип користи анонимни именски простор"
 
-#: cp/decl2.c:2677
+#: cp/decl2.c:2667
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr "%qT декларисано са већом видљивошћу од типа његовог поља %qD"
 
-#: cp/decl2.c:2695
+#: cp/decl2.c:2685
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgid "%qT has a base %qT whose type has no linkage"
 msgstr "%qT има основу %qT чији тип користи анонимни именски простор"
 
-#: cp/decl2.c:2699
+#: cp/decl2.c:2689
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgid "%qT has a base %qT whose type depends on the type %qT which has no linkage"
 msgstr "%qT има основу %qT чији тип користи анонимни именски простор"
 
-#: cp/decl2.c:2704
+#: cp/decl2.c:2694
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr "%qT има основу %qT чији тип користи анонимни именски простор"
 
-#: cp/decl2.c:2711
+#: cp/decl2.c:2701
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr "%qT декларисано са већом видљивошћу од своје основе %qT"
 
-#: cp/decl2.c:4309
+#: cp/decl2.c:4299
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%q#D, declared using unnamed type, is used but never defined"
@@ -49128,68 +49172,68 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4318
+#: cp/decl2.c:4308
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4322
+#: cp/decl2.c:4312
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4326
+#: cp/decl2.c:4316
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D does not refer to the unqualified type, so it is not used for linkage"
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr "%q+#D не упућује на неодређени тип, тако да се не користи за повезивост"
 
-#: cp/decl2.c:4334
+#: cp/decl2.c:4324
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "%q+F декларисано као %<static%> али нигде дефинисано"
 
-#: cp/decl2.c:4338
+#: cp/decl2.c:4328
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4341
+#: cp/decl2.c:4331
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+#D with %qL linkage"
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "претходна декларација %q+#D са повезивошћу %qL"
 
-#: cp/decl2.c:4529
+#: cp/decl2.c:4519
 #, fuzzy, gcc-internal-format
 #| msgid "section of %q+D conflicts with previous declaration"
 msgid "mangling of %q#D as %qE conflicts with a previous mangle"
 msgstr "одељак за %q+D коси се са претходном декларацијом"
 
-#: cp/decl2.c:4532
+#: cp/decl2.c:4522
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D"
 msgid "previous mangling %q#D"
 msgstr "претходна декларација %q+D"
 
-#: cp/decl2.c:4534
+#: cp/decl2.c:4524
 #, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr ""
 
-#: cp/decl2.c:4606 cp/decl2.c:4609
+#: cp/decl2.c:4596 cp/decl2.c:4599
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.c:4956
+#: cp/decl2.c:4946
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D used but never defined"
 msgid "inline function %qD used but never defined"
 msgstr "уткана функција %q+D употребљена али недефинисана"
 
-#: cp/decl2.c:5143
+#: cp/decl2.c:5133
 #, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr "недостаје подразумевани аргумент за параметар %P од %q+#D"
@@ -49196,18 +49240,18 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5251
+#: cp/decl2.c:5241
 #, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.c:5254
+#: cp/decl2.c:5244
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "use of deleted function %qD"
 msgstr "неисправна употреба нестатичке чланске функције %qD"
 
-#: cp/decl2.c:5307
+#: cp/decl2.c:5297
 #, fuzzy, gcc-internal-format
 #| msgid "using %<typename%> outside of template"
 msgid "use of built-in parameter pack %qD outside of a template"
@@ -49508,48 +49552,48 @@
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr "поновљена дефиниција подразумеваног аргумента за %q#D"
 
-#: cp/init.c:613
+#: cp/init.c:629
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr ""
 
-#: cp/init.c:615
+#: cp/init.c:631
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "defined here"
 msgstr "%q+D декларисано овде"
 
-#: cp/init.c:673
+#: cp/init.c:689
 #, fuzzy, gcc-internal-format
 #| msgid "initialization of a flexible array member"
 msgid "initializer for flexible array member %q#D"
 msgstr "успостављање флексибилног чланског низа"
 
-#: cp/init.c:699
+#: cp/init.c:715
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qD should be initialized in the member initialization list"
 msgid "%qD should be initialized in the member initialization list"
 msgstr "%J%qD треба да се успостави у листи успостављања чланова"
 
-#: cp/init.c:720
+#: cp/init.c:736
 #, fuzzy, gcc-internal-format
 #| msgid "class %qT is implicitly friends with itself"
 msgid "%qD is initialized with itself"
 msgstr "класа %qT је имплицитно сама себи пријатељска"
 
-#: cp/init.c:831
+#: cp/init.c:847
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initial value for member %qs"
 msgid "invalid initializer for array member %q#D"
 msgstr "неисправна почетна вредност за члан %qs"
 
-#: cp/init.c:845 cp/init.c:869 cp/init.c:2410 cp/method.c:1368
+#: cp/init.c:861 cp/init.c:885 cp/init.c:2427 cp/method.c:1368
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const member %qD"
 msgid "uninitialized const member in %q#T"
 msgstr "неуспостављени константни члан %qD"
 
-#: cp/init.c:847 cp/init.c:864 cp/init.c:871 cp/init.c:2395 cp/init.c:2423
+#: cp/init.c:863 cp/init.c:880 cp/init.c:887 cp/init.c:2412 cp/init.c:2440
 #: cp/method.c:1371 cp/method.c:1382
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D will be initialized after"
@@ -49556,312 +49600,312 @@
 msgid "%q#D should be initialized"
 msgstr "%q+D ће бити успостављено после"
 
-#: cp/init.c:862 cp/init.c:2382 cp/method.c:1379
+#: cp/init.c:878 cp/init.c:2399 cp/method.c:1379
 #, fuzzy, gcc-internal-format
 #| msgid "%Juninitialized reference member %qD"
 msgid "uninitialized reference member in %q#T"
 msgstr "%Jнеуспостављени упућивачки члан %qD"
 
-#: cp/init.c:1041
+#: cp/init.c:1057
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D will be initialized after"
 msgid "%qD will be initialized after"
 msgstr "%q+D ће бити успостављено после"
 
-#: cp/init.c:1044
+#: cp/init.c:1060
 #, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr "основно %qT ће бити успостављено после"
 
-#: cp/init.c:1048
+#: cp/init.c:1064
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D"
 msgid "  %q#D"
 msgstr "  %q+#D"
 
-#: cp/init.c:1050
+#: cp/init.c:1066
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr "  основног %qT"
 
-#: cp/init.c:1052
+#: cp/init.c:1068
 #, fuzzy, gcc-internal-format
 #| msgid "%J  when initialized here"
 msgid "  when initialized here"
 msgstr "%J  када се успостави овде"
 
-#: cp/init.c:1069
+#: cp/init.c:1085
 #, fuzzy, gcc-internal-format
 #| msgid "%Jmultiple initializations given for %qD"
 msgid "multiple initializations given for %qD"
 msgstr "%Jвишеструка успостављања дата за %qD"
 
-#: cp/init.c:1073
+#: cp/init.c:1089
 #, fuzzy, gcc-internal-format
 #| msgid "%Jmultiple initializations given for base %qT"
 msgid "multiple initializations given for base %qT"
 msgstr "%Jвишеструка успостављања дата за основно %qT"
 
-#: cp/init.c:1158
+#: cp/init.c:1174
 #, fuzzy, gcc-internal-format
 #| msgid "%Jinitializations for multiple members of %qT"
 msgid "initializations for multiple members of %qT"
 msgstr "%Jуспостављања за више чланова из %qT"
 
-#: cp/init.c:1255
+#: cp/init.c:1271
 #, fuzzy, gcc-internal-format
 #| msgid "%Jbase class %q#T should be explicitly initialized in the copy constructor"
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr "%Jосновна класа %q#T треба да се експлицитно успостави у копи-конструктору"
 
-#: cp/init.c:1482 cp/init.c:1501
+#: cp/init.c:1498 cp/init.c:1517
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr "класа %qT нема поље по имену %qD"
 
-#: cp/init.c:1488
+#: cp/init.c:1504
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr "%q#D је статички члански податак; може се успостављати само при дефинисању"
 
-#: cp/init.c:1495
+#: cp/init.c:1511
 #, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr "%q#D је нестатички члански податак у %qT"
 
-#: cp/init.c:1534
+#: cp/init.c:1550
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr "неименовани успостављач за %qT, која нема основних класа"
 
-#: cp/init.c:1542
+#: cp/init.c:1558
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr "неименовани успостављач за %qT, која користи вишеструко наслеђивање"
 
-#: cp/init.c:1589
+#: cp/init.c:1605
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr "%qD је и непосредна основа и посредна виртуелна основа"
 
-#: cp/init.c:1597
+#: cp/init.c:1613
 #, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr "тип %qT није непосредна или виртуелна основа од %qT"
 
-#: cp/init.c:1600
+#: cp/init.c:1616
 #, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr "тип %qT није непосредна основа од %qT"
 
-#: cp/init.c:1710 cp/init.c:4386 cp/typeck2.c:1175
+#: cp/init.c:1727 cp/init.c:4402 cp/typeck2.c:1175
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "успостављач низа мора бити нешто у витичастим заградама"
 
-#: cp/init.c:2019 cp/semantics.c:3268
+#: cp/init.c:2036 cp/semantics.c:3271
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a class"
 msgid "%qT is not a class type"
 msgstr "%q#T није класа"
 
-#: cp/init.c:2075
+#: cp/init.c:2092
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr "непотпун тип %qT нема члан %qD"
 
-#: cp/init.c:2089
+#: cp/init.c:2106
 #, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr "неисправан показивач на битско поље %qD"
 
-#: cp/init.c:2175 cp/typeck.c:1893
+#: cp/init.c:2192 cp/typeck.c:1893
 #, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "неисправна употреба нестатичке чланске функције %qD"
 
-#: cp/init.c:2182 cp/semantics.c:1835
+#: cp/init.c:2199 cp/semantics.c:1835
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "неисправна употреба нестатичког чланског податка %qD"
 
-#: cp/init.c:2379
+#: cp/init.c:2396
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2387
+#: cp/init.c:2404
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2391
+#: cp/init.c:2408
 #, fuzzy, gcc-internal-format
 #| msgid "%Juninitialized reference member %qD"
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr "%Jнеуспостављени упућивачки члан %qD"
 
-#: cp/init.c:2407
+#: cp/init.c:2424
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const in %<new%> of %q#T"
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr "неуспостављена константа у %<new%> за %q#T"
 
-#: cp/init.c:2415
+#: cp/init.c:2432
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2419
+#: cp/init.c:2436
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const in %<new%> of %q#T"
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr "неуспостављена константа у %<new%> за %q#T"
 
-#: cp/init.c:2710
+#: cp/init.c:2727
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2721
+#: cp/init.c:2738
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2732
+#: cp/init.c:2749
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2880
+#: cp/init.c:2896
 #, fuzzy, gcc-internal-format
 #| msgid "integer overflow in expression"
 msgid "integer overflow in array size"
 msgstr "целобројно преливање у изразу"
 
-#: cp/init.c:2890
+#: cp/init.c:2906
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "array size in new-expression must be constant"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/init.c:2904
+#: cp/init.c:2920
 #, gcc-internal-format
 msgid "variably modified type not allowed in new-expression"
 msgstr ""
 
-#: cp/init.c:2920
+#: cp/init.c:2936
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by typedef"
 msgstr ""
 
-#: cp/init.c:2922
+#: cp/init.c:2938
 #, fuzzy, gcc-internal-format
 #| msgid "try removing the parentheses around the type-id"
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr "покушајте да уклоните заграде око ид. типа"
 
-#: cp/init.c:2932
+#: cp/init.c:2948
 #, gcc-internal-format
 msgid "invalid type %<void%> for new"
 msgstr "неисправан тип %<void%> за new"
 
-#: cp/init.c:2975
+#: cp/init.c:2991
 #, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr "неуспостављена константа у %<new%> за %q#T"
 
-#: cp/init.c:3101
+#: cp/init.c:3117
 #, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr "ниједно погодно %qD није нађено у класи %qT"
 
-#: cp/init.c:3108 cp/search.c:1023
+#: cp/init.c:3124 cp/search.c:1026
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "двосмислен захтев за чланом %qD"
 
-#: cp/init.c:3181
+#: cp/init.c:3197
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr ""
 
-#: cp/init.c:3184
+#: cp/init.c:3200
 #, fuzzy, gcc-internal-format
 #| msgid "class %qT does not have any field named %qD"
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr "класа %qT нема поље по имену %qD"
 
-#: cp/init.c:3187
+#: cp/init.c:3203
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr ""
 
-#: cp/init.c:3370
+#: cp/init.c:3386
 #, fuzzy, gcc-internal-format
 #| msgid "attributes after parenthesized initializer ignored"
 msgid "parenthesized initializer in array new"
 msgstr "игноришу се атрибути после заграђеног успостављача"
 
-#: cp/init.c:3633
+#: cp/init.c:3649
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr "величина у низовном new мора бити интегралног типа"
 
-#: cp/init.c:3665
+#: cp/init.c:3681
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr "new се не може применити на упућивачки тип"
 
-#: cp/init.c:3674
+#: cp/init.c:3690
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr "new се не може применити на функцијиски тип"
 
-#: cp/init.c:3743
+#: cp/init.c:3759
 #, fuzzy, gcc-internal-format
 #| msgid "possible problem detected in invocation of delete operator:"
 msgid "possible problem detected in invocation of delete [] operator:"
 msgstr "откривен могућ проблем у позиву оператора delete:"
 
-#: cp/init.c:3747
+#: cp/init.c:3763
 #, fuzzy, gcc-internal-format
 #| msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined."
 msgid "neither the destructor nor the class-specific operator delete [] will be called, even if they are declared when the class is defined"
 msgstr "ни деструктор, ни класи посебан оператор delete неће бити позван, чак и ако су декларисани када се класа дефинише."
 
-#: cp/init.c:4295
+#: cp/init.c:4311
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "успостављач се прерано окончава"
 
-#: cp/init.c:4599
+#: cp/init.c:4615
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr "непозната величина низа за delete"
 
-#: cp/init.c:4623
+#: cp/init.c:4639
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete operator:"
 msgstr "откривен могућ проблем у позиву оператора delete:"
 
-#: cp/init.c:4628
+#: cp/init.c:4644
 #, fuzzy, gcc-internal-format
 #| msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined."
 msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
 msgstr "ни деструктор, ни класи посебан оператор delete неће бити позван, чак и ако су декларисани када се класа дефинише."
 
-#: cp/init.c:4642
+#: cp/init.c:4658
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4647
+#: cp/init.c:4663
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4954
+#: cp/init.c:4970
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "тип уз векторско delete није ни показивачки ни низовни"
@@ -50367,7 +50411,7 @@
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr ""
 
-#: cp/name-lookup.c:5111 cp/name-lookup.c:7065
+#: cp/name-lookup.c:5111 cp/name-lookup.c:7073
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "атрибутска директива %qD игнорисана"
@@ -50420,57 +50464,57 @@
 msgid "it was later defined here"
 msgstr "%J%qD декларисано овде"
 
-#: cp/name-lookup.c:6687
+#: cp/name-lookup.c:6695
 #, gcc-internal-format
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn't a template"
 msgstr ""
 
-#: cp/name-lookup.c:7059
+#: cp/name-lookup.c:7067
 #, fuzzy, gcc-internal-format
 #| msgid "switch %qs is no longer supported"
 msgid "strong using directive no longer supported"
 msgstr "прекидач %qs више није подржан"
 
-#: cp/name-lookup.c:7062
+#: cp/name-lookup.c:7070
 #, gcc-internal-format
 msgid "you may use an inline namespace instead"
 msgstr ""
 
-#: cp/name-lookup.c:7079
+#: cp/name-lookup.c:7087
 #, fuzzy, gcc-internal-format
 #| msgid "attributes ignored on uninstantiated type"
 msgid "attributes ignored on local using directive"
 msgstr "атрибут се игнорише за класе без примерака"
 
-#: cp/name-lookup.c:7163
+#: cp/name-lookup.c:7171
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "алијас именског простора %qD није дозвољен овде, претпостављам %qD"
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:7183
+#: cp/name-lookup.c:7191
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qD may not be declared within a namespace"
 msgid "cannot nest more than %d namespaces"
 msgstr "%qD не може бити декларисано унутар именског простора"
 
-#: cp/name-lookup.c:7218
+#: cp/name-lookup.c:7226
 #, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr ""
 
-#: cp/name-lookup.c:7219
+#: cp/name-lookup.c:7227
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%qD defined here"
 msgstr "%q+D декларисано овде"
 
-#: cp/name-lookup.c:7292
+#: cp/name-lookup.c:7300
 #, gcc-internal-format
 msgid "XXX entering pop_everything ()\n"
 msgstr "XXX entering pop_everything ()\n"
 
-#: cp/name-lookup.c:7301
+#: cp/name-lookup.c:7309
 #, gcc-internal-format
 msgid "XXX leaving pop_everything ()\n"
 msgstr "XXX leaving pop_everything ()\n"
@@ -50491,7 +50535,7 @@
 msgid "LEXER_DEBUGGING_ENABLED_P is not set to true"
 msgstr ""
 
-#: cp/parser.c:1352 cp/parser.c:37254
+#: cp/parser.c:1352 cp/parser.c:37251
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -50519,7 +50563,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr "захтев за члан %qD у некласном типу %qT"
 
-#: cp/parser.c:2949 cp/parser.c:18221
+#: cp/parser.c:2949 cp/parser.c:18218
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> has not been declared"
 msgid "%<%T::%E%> has not been declared"
@@ -50611,7 +50655,7 @@
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "ИСО Ц++ забрањује употребу показивача на функцију у одузимању"
 
-#: cp/parser.c:3143 cp/pt.c:17853
+#: cp/parser.c:3143 cp/pt.c:17890
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr "претапање у тип који није ни интегрални ни набројиви не може се јавити у изразу константе"
@@ -50857,7 +50901,7 @@
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr ""
 
-#: cp/parser.c:4587 cp/parser.c:12940
+#: cp/parser.c:4587 cp/parser.c:12937
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "expected declaration"
@@ -50915,7 +50959,7 @@
 msgid "fold-expressions only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:5275 cp/parser.c:5452 cp/parser.c:5630 cp/semantics.c:3612
+#: cp/parser.c:5275 cp/parser.c:5452 cp/parser.c:5633 cp/semantics.c:3615
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "expected primary-expression"
@@ -50937,102 +50981,102 @@
 msgid "local variable %qD may not appear in this context"
 msgstr "локална променљива %qD не може се појавити у овом контексту"
 
-#: cp/parser.c:5787
+#: cp/parser.c:5790
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "expected id-expression"
 msgstr "очекиван је израз"
 
-#: cp/parser.c:5919
+#: cp/parser.c:5922
 #, gcc-internal-format
 msgid "scope %qT before %<~%> is not a class-name"
 msgstr "досег %qT пре %<~%> није име класе"
 
-#: cp/parser.c:5948 cp/parser.c:7860
+#: cp/parser.c:5951 cp/parser.c:7860
 #, gcc-internal-format
 msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:6059
+#: cp/parser.c:6062
 #, gcc-internal-format
 msgid "declaration of %<~%T%> as member of %qT"
 msgstr "декларација %<~%T%> као члана у %qT"
 
-#: cp/parser.c:6074
+#: cp/parser.c:6077
 #, gcc-internal-format
 msgid "typedef-name %qD used as destructor declarator"
 msgstr "typedef-име %qD употребљено као декларатор деструктора"
 
-#: cp/parser.c:6111 cp/parser.c:20249
+#: cp/parser.c:6114 cp/parser.c:20246
 #, fuzzy, gcc-internal-format
 #| msgid "expected specifier-qualifier-list"
 msgid "expected unqualified-id"
 msgstr "очекивана је листа наводилаца-одредби"
 
-#: cp/parser.c:6220
+#: cp/parser.c:6223
 #, gcc-internal-format
 msgid "found %<:%> in nested-name-specifier, expected %<::%>"
 msgstr ""
 
-#: cp/parser.c:6288
+#: cp/parser.c:6291
 #, fuzzy, gcc-internal-format
 #| msgid "%qT resolves to %qT, which is not an enumeration type"
 msgid "decltype evaluates to %qT, which is not a class or enumeration type"
 msgstr "%qT се разрешава до %qT, што није набројиви тип"
 
-#: cp/parser.c:6314
+#: cp/parser.c:6317
 #, fuzzy, gcc-internal-format
 #| msgid "incomplete type %qT used in nested name specifier"
 msgid "function template-id %qD in nested-name-specifier"
 msgstr "непотпун тип %qT употребљен у угњежденом наводиоцу имена"
 
-#: cp/parser.c:6322
+#: cp/parser.c:6325
 #, fuzzy, gcc-internal-format
 #| msgid "incomplete type %qT used in nested name specifier"
 msgid "variable template-id %qD in nested-name-specifier"
 msgstr "непотпун тип %qT употребљен у угњежденом наводиоцу имена"
 
-#: cp/parser.c:6426 cp/typeck.c:2684 cp/typeck.c:2687 cp/typeck.c:2704
+#: cp/parser.c:6429 cp/typeck.c:2684 cp/typeck.c:2687 cp/typeck.c:2704
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD није шаблон"
 
-#: cp/parser.c:6504
+#: cp/parser.c:6507
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "expected nested-name-specifier"
 msgstr "очекивани су наводиоци декларације"
 
-#: cp/parser.c:6711 cp/parser.c:8950
+#: cp/parser.c:6714 cp/parser.c:8950
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in casts"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:6797
+#: cp/parser.c:6800
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in a %<typeid%> expression"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:6889
+#: cp/parser.c:6892
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %<__builtin_frame_address%>"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "неподржан аргумент за %<__builtin_frame_address%>"
 
-#: cp/parser.c:6901 cp/pt.c:18416
+#: cp/parser.c:6904 cp/pt.c:18453
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %<__builtin_return_address%>"
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "неподржан аргумент за %<__builtin_return_address%>"
 
-#: cp/parser.c:6995
+#: cp/parser.c:6998
 #, gcc-internal-format
 msgid "ISO C++ forbids compound-literals"
 msgstr "ИСО Ц++ забрањује сложене константе"
 
-#: cp/parser.c:7054
+#: cp/parser.c:7057
 #, gcc-internal-format
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
@@ -51175,7 +51219,7 @@
 msgid "capture of non-variable %qE"
 msgstr "увећање само-за-читање променљиве %qD"
 
-#: cp/parser.c:10391 cp/parser.c:10401 cp/semantics.c:3453 cp/semantics.c:3465
+#: cp/parser.c:10391 cp/parser.c:10401 cp/semantics.c:3456 cp/semantics.c:3468
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%q#D declared here"
@@ -51266,7 +51310,7 @@
 msgid "init-statement in selection statements only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:11546 cp/parser.c:28490
+#: cp/parser.c:11546 cp/parser.c:28487
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration or statement"
 msgid "expected selection-statement"
@@ -51289,214 +51333,214 @@
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:12250 cp/parser.c:28493
+#: cp/parser.c:12250 cp/parser.c:28490
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration or statement"
 msgid "expected iteration-statement"
 msgstr "очекивана је декларација или наредба"
 
-#: cp/parser.c:12298
+#: cp/parser.c:12297
 #, gcc-internal-format
 msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/parser.c:12426
+#: cp/parser.c:12423
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr ""
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:12434
+#: cp/parser.c:12431
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ИСО Ц++ забрањује рачунско goto"
 
-#: cp/parser.c:12447 cp/parser.c:28496
+#: cp/parser.c:12444 cp/parser.c:28493
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected jump-statement"
 msgstr "очекивана је наредба"
 
-#: cp/parser.c:12620 cp/parser.c:23584
+#: cp/parser.c:12617 cp/parser.c:23581
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "сувишно %<;%>"
 
-#: cp/parser.c:12863
+#: cp/parser.c:12860
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr ""
 
-#: cp/parser.c:13083
+#: cp/parser.c:13080
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:13103
+#: cp/parser.c:13100
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr ""
 
-#: cp/parser.c:13124
+#: cp/parser.c:13121
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr "забрањено је мешање декларација и дефиниција функција"
 
-#: cp/parser.c:13148
+#: cp/parser.c:13145
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in a for-range-declaration"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:13203
+#: cp/parser.c:13200
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13206
+#: cp/parser.c:13203
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13257
+#: cp/parser.c:13254
 #, gcc-internal-format
 msgid "structured bindings only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:13306
+#: cp/parser.c:13303
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "empty structured binding declaration"
 msgstr "празна декларација"
 
-#: cp/parser.c:13324
+#: cp/parser.c:13321
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member function declaration"
 msgid "invalid initializer for structured binding declaration"
 msgstr "неисправна декларација чланске функције"
 
-#: cp/parser.c:13491
+#: cp/parser.c:13488
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr "%<friend%> употребљено изван класе"
 
-#: cp/parser.c:13558
+#: cp/parser.c:13555
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr ""
 
-#: cp/parser.c:13594
+#: cp/parser.c:13591
 #, fuzzy, gcc-internal-format
 #| msgid "pure-specifier on function-definition"
 msgid "decl-specifier invalid in condition"
 msgstr "наводилац pure на дефиницији функције"
 
-#: cp/parser.c:13600
+#: cp/parser.c:13597
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D invalid in %q#T"
 msgid "%qD invalid in lambda"
 msgstr "%q+D неисправно у %q#T"
 
-#: cp/parser.c:13693
+#: cp/parser.c:13690
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "дефиниција класе не може бити декларисана пријатељем"
 
-#: cp/parser.c:13763 cp/parser.c:24064
+#: cp/parser.c:13760 cp/parser.c:24061
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr "шаблони не могу бити виртуелни"
 
-#: cp/parser.c:13805
+#: cp/parser.c:13802
 #, fuzzy, gcc-internal-format
 #| msgid "invalid base-class specification"
 msgid "invalid linkage-specification"
 msgstr "неисправан навод основне класе"
 
-#: cp/parser.c:13909
+#: cp/parser.c:13906
 #, gcc-internal-format
 msgid "static_assert without a message only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:14111
+#: cp/parser.c:14108
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:14264
+#: cp/parser.c:14261
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in a conversion-type-id"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:14291
+#: cp/parser.c:14288
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<this%> in non-member function"
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "неисправна употреба %<this%> у нечланској функцији"
 
-#: cp/parser.c:14295
+#: cp/parser.c:14292
 #, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr ""
 
-#: cp/parser.c:14379
+#: cp/parser.c:14376
 #, fuzzy, gcc-internal-format
 #| msgid "only constructors take base initializers"
 msgid "only constructors take member initializers"
 msgstr "само конструктори узимају успостављаче основе"
 
-#: cp/parser.c:14406
+#: cp/parser.c:14403
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "cannot expand initializer for member %qD"
 msgstr "недостаје успостављач за члан %qD"
 
-#: cp/parser.c:14418 cp/pt.c:24255
+#: cp/parser.c:14415 cp/pt.c:24333
 #, fuzzy, gcc-internal-format
 #| msgid "static declaration of %q+D follows non-static declaration"
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "статичка декларација %q+D прати нестатичку декларацију"
 
-#: cp/parser.c:14430 cp/pt.c:24267
+#: cp/parser.c:14427 cp/pt.c:24345
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
 
-#: cp/parser.c:14482
+#: cp/parser.c:14479
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr "анахронистични старовремски успостављач основне класе"
 
-#: cp/parser.c:14552
+#: cp/parser.c:14549
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr "кључна реч %<typename%> није дозвољена у овом контексту (успостављач одређеног члана имплицитно је тип)"
 
-#: cp/parser.c:14927
+#: cp/parser.c:14924
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr ""
 
-#: cp/parser.c:14933
+#: cp/parser.c:14930
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier"
 msgid "expected suffix identifier"
 msgstr "очекиван је идентификатор"
 
-#: cp/parser.c:14942
+#: cp/parser.c:14939
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr ""
 
-#: cp/parser.c:14948
+#: cp/parser.c:14945
 #, fuzzy, gcc-internal-format
 #| msgid "invalid conditional operand"
 msgid "invalid encoding prefix in literal operator"
 msgstr "неисправан операнд услова"
 
-#: cp/parser.c:14975
+#: cp/parser.c:14972
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected operator"
@@ -51503,75 +51547,75 @@
 msgstr "неочекиван операнд"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:15020
+#: cp/parser.c:15017
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "кључна реч %<export%> није имплементирана, игнорише се"
 
-#: cp/parser.c:15190
+#: cp/parser.c:15187
 #, fuzzy, gcc-internal-format
 #| msgid "invalid constraints for operand"
 msgid "invalid constrained type parameter"
 msgstr "неисправна ограничења за операнд"
 
-#: cp/parser.c:15198
+#: cp/parser.c:15195
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "cv-qualified type parameter"
 msgstr "неисправан типски аргумент"
 
-#: cp/parser.c:15283
+#: cp/parser.c:15280
 #, gcc-internal-format
 msgid "variadic constraint introduced without %<...%>"
 msgstr ""
 
-#: cp/parser.c:15347
+#: cp/parser.c:15344
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<this%> at top level"
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "неисправна употреба %<this%> на највишем нивоу"
 
-#: cp/parser.c:15582 cp/parser.c:15668 cp/parser.c:21694
+#: cp/parser.c:15579 cp/parser.c:15665 cp/parser.c:21691
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "%qD не може имати подразумеване аргументе"
 
-#: cp/parser.c:15586 cp/parser.c:15672
+#: cp/parser.c:15583 cp/parser.c:15669
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "template parameter packs cannot have default arguments"
 msgstr "шаблонски параметри не могу бити пријатељи"
 
-#: cp/parser.c:15738
+#: cp/parser.c:15735
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected template-id"
 msgstr "очекивана је наредба"
 
-#: cp/parser.c:15798
+#: cp/parser.c:15795
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "%<<::%> не може започети листу шаблонских аргумената"
 
-#: cp/parser.c:15802
+#: cp/parser.c:15799
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr "%<<:%> је другачије написано %<[%>. Убаците размак између %<<%> и %<::%>"
 
-#: cp/parser.c:15806
+#: cp/parser.c:15803
 #, fuzzy, gcc-internal-format
 #| msgid "(if you use -fpermissive G++ will accept your code)"
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr "(Г++ ће прихватити ово ако задате -fpermissive)"
 
-#: cp/parser.c:15924
+#: cp/parser.c:15921
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "грешка у рашчлањивању листе шаблонских аргумената"
 
 #. The name does not name a template.
-#: cp/parser.c:15992 cp/parser.c:16122 cp/parser.c:16337
+#: cp/parser.c:15989 cp/parser.c:16119 cp/parser.c:16334
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected template-name"
@@ -51578,320 +51622,320 @@
 msgstr "очекивана је наредба"
 
 #. Explain what went wrong.
-#: cp/parser.c:16038
+#: cp/parser.c:16035
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr "%qD употребљено као шаблон, а није"
 
-#: cp/parser.c:16040
+#: cp/parser.c:16037
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr "употребите %<%T::template %D%> да назначите да је шаблон"
 
-#: cp/parser.c:16189
+#: cp/parser.c:16186
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers or %<...%>"
 msgid "expected parameter pack before %<...%>"
 msgstr "очекивани су наводиоци декларације или %<...%>"
 
-#: cp/parser.c:16298 cp/parser.c:16316 cp/parser.c:16483
+#: cp/parser.c:16295 cp/parser.c:16313 cp/parser.c:16480
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected template-argument"
 msgstr "очекивана је наредба"
 
-#: cp/parser.c:16458
+#: cp/parser.c:16455
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "invalid non-type template argument"
 msgstr "неисправан типски аргумент"
 
-#: cp/parser.c:16585
+#: cp/parser.c:16582
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type %qT"
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "експлицитно извођење нешаблонског типа %qT"
 
-#: cp/parser.c:16589
+#: cp/parser.c:16586
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type %qT"
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "експлицитно извођење нешаблонског типа %qT"
 
-#: cp/parser.c:16648
+#: cp/parser.c:16645
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr "специјализација шаблона са Ц повезивошћу"
 
-#: cp/parser.c:16869
+#: cp/parser.c:16866
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "expected type specifier"
 msgstr "очекивани су наводиоци декларације"
 
-#: cp/parser.c:17053
+#: cp/parser.c:17050
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:17059
+#: cp/parser.c:17056
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:17064
+#: cp/parser.c:17061
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -fconcepts"
 msgstr ""
 
-#: cp/parser.c:17209
+#: cp/parser.c:17206
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "expected template-id for type"
 msgstr "Очекиван је тип израза"
 
-#: cp/parser.c:17278
+#: cp/parser.c:17275
 #, fuzzy, gcc-internal-format
 #| msgid "Expected name"
 msgid "expected type-name"
 msgstr "Очекивано је име"
 
-#: cp/parser.c:17631
+#: cp/parser.c:17628
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr ""
 
-#: cp/parser.c:17854
+#: cp/parser.c:17851
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "declaration %qD does not declare anything"
 msgstr "декларација ништа не декларише"
 
-#: cp/parser.c:17942
+#: cp/parser.c:17939
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "атрибут се игнорише за класе без примерака"
 
-#: cp/parser.c:17946
+#: cp/parser.c:17943
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "атрибут се игнорише при извођењу шаблона"
 
-#: cp/parser.c:17951
+#: cp/parser.c:17948
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr "атрибут се игнорише при предоченом-наводиоцу-типа који није унапредна декларација"
 
-#: cp/parser.c:18085
+#: cp/parser.c:18082
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%qD is an enumeration template"
 msgstr "%qD није шаблон функције"
 
-#: cp/parser.c:18096
+#: cp/parser.c:18093
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qT"
 msgid "%qD does not name an enumeration in %qT"
 msgstr "%qD није члан у %qT"
 
-#: cp/parser.c:18111
+#: cp/parser.c:18108
 #, fuzzy, gcc-internal-format
 #| msgid "Min/max instructions not allowed"
 msgid "unnamed scoped enum is not allowed"
 msgstr "Инструкције min/max нису дозвољене"
 
-#: cp/parser.c:18166
+#: cp/parser.c:18163
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<;%> or %<{%>"
 msgstr "очекивано је %<,%> или %<;%>"
 
-#: cp/parser.c:18215
+#: cp/parser.c:18212
 #, fuzzy, gcc-internal-format
 #| msgid "Enable automatic template instantiation"
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "Укључи аутоматско извођење шаблона"
 
-#: cp/parser.c:18229
+#: cp/parser.c:18226
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration does not name a class or function"
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "декларација пријатеља не именује ни класу ни функцију"
 
-#: cp/parser.c:18241 cp/parser.c:23070
+#: cp/parser.c:18238 cp/parser.c:23067
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD in %qD which does not enclose %qD"
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "декларација %qD у %qD која не обухвата %qD"
 
-#: cp/parser.c:18246 cp/parser.c:23075
+#: cp/parser.c:18243 cp/parser.c:23072
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "декларација %qD у %qD која не обухвата %qD"
 
-#: cp/parser.c:18258 cp/parser.c:23089
+#: cp/parser.c:18255 cp/parser.c:23086
 #, fuzzy, gcc-internal-format
 #| msgid "extra qualification ignored"
 msgid "extra qualification not allowed"
 msgstr "сувишне одредбе се игноришу"
 
-#: cp/parser.c:18282
+#: cp/parser.c:18279
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "вишеструке дефиниције %q#T"
 
-#: cp/parser.c:18295
+#: cp/parser.c:18292
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing an enum"
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ИСО Ц++ забрањује %s-вање набрајања"
 
-#: cp/parser.c:18315
+#: cp/parser.c:18312
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:18318
+#: cp/parser.c:18315
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:18497
+#: cp/parser.c:18494
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD није име именског простора"
 
-#: cp/parser.c:18503
+#: cp/parser.c:18500
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected namespace-name"
 msgstr "очекивано је име класе"
 
-#: cp/parser.c:18570
+#: cp/parser.c:18567
 #, gcc-internal-format
 msgid "nested namespace definitions only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:18578
+#: cp/parser.c:18575
 #, gcc-internal-format
 msgid "nested namespace name required"
 msgstr ""
 
-#: cp/parser.c:18583
+#: cp/parser.c:18580
 #, gcc-internal-format
 msgid "namespace name required"
 msgstr ""
 
-#: cp/parser.c:18587
+#: cp/parser.c:18584
 #, gcc-internal-format
 msgid "a nested namespace definition cannot have attributes"
 msgstr ""
 
-#: cp/parser.c:18590
+#: cp/parser.c:18587
 #, fuzzy, gcc-internal-format
 #| msgid "Warn when an inlined function cannot be inlined"
 msgid "a nested namespace definition cannot be inline"
 msgstr "Упозори када се уткана функција не може уткати"
 
-#: cp/parser.c:18597
+#: cp/parser.c:18594
 #, fuzzy, gcc-internal-format
 #| msgid "use of namespace %qD as expression"
 msgid "namespace %qD entered"
 msgstr "употреба именског простора %qD као израза"
 
-#: cp/parser.c:18652
+#: cp/parser.c:18649
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma%> is not allowed here"
 msgid "%<namespace%> definition is not allowed here"
 msgstr "%<#pragma%> није дозвољена овде"
 
-#: cp/parser.c:18803
+#: cp/parser.c:18800
 #, gcc-internal-format
 msgid "pack expansion in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:18818
+#: cp/parser.c:18815
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "ид. шаблона не може да се јави у декларацији употребе"
 
-#: cp/parser.c:18865
+#: cp/parser.c:18862
 #, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:18875
+#: cp/parser.c:18872
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:18940
+#: cp/parser.c:18937
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in alias template declarations"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:19106
+#: cp/parser.c:19103
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:19493
+#: cp/parser.c:19490
 #, fuzzy, gcc-internal-format
 #| msgid "%s: function definition not converted\n"
 msgid "a function-definition is not allowed here"
 msgstr "%s: дефиниција функције није претворена\n"
 
-#: cp/parser.c:19504
+#: cp/parser.c:19501
 #, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr "навод asm није дозвољен на дефиницији функције"
 
-#: cp/parser.c:19508
+#: cp/parser.c:19505
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "атрибути нису дозвољени на дефиницији функције"
 
-#: cp/parser.c:19559
+#: cp/parser.c:19556
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
 #. Anything else is an error.
-#: cp/parser.c:19598 cp/parser.c:21906
+#: cp/parser.c:19595 cp/parser.c:21903
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier"
 msgid "expected initializer"
 msgstr "очекиван је идентификатор"
 
-#: cp/parser.c:19679
+#: cp/parser.c:19676
 #, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "успостављач дат за функцију"
 
-#: cp/parser.c:19713
+#: cp/parser.c:19710
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "игноришу се атрибути после заграђеног успостављача"
 
-#: cp/parser.c:19727
+#: cp/parser.c:19724
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared as inline"
 msgid "non-function %qD declared as implicit template"
 msgstr "функција %q+D поново декларисана као уткана"
 
-#: cp/parser.c:20169
+#: cp/parser.c:20166
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "граница низа није целобројна константа"
 
-#: cp/parser.c:20295
+#: cp/parser.c:20292
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type %qT"
 msgid "cannot define member of dependent typedef %qT"
 msgstr "стварање показивача на члан упућивачког типа %qT"
 
-#: cp/parser.c:20299
+#: cp/parser.c:20296
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a type"
 msgid "%<%T::%E%> is not a type"
@@ -51901,18 +51945,18 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:20328
+#: cp/parser.c:20325
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid declaration"
 msgid "invalid declarator"
 msgstr "Неисправна декларација"
 
-#: cp/parser.c:20336
+#: cp/parser.c:20333
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "неисправна употреба конструктора као шаблона"
 
-#: cp/parser.c:20338
+#: cp/parser.c:20335
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr "употреба %<%T::%D%> уместо %<%T::%D%> за именовање конструктора у одређеном имену"
@@ -51919,425 +51963,425 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:20410
+#: cp/parser.c:20407
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid declaration"
 msgid "qualified-id in declaration"
 msgstr "Неисправна декларација"
 
-#: cp/parser.c:20435
+#: cp/parser.c:20432
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "expected declarator"
 msgstr "очекивани су наводиоци декларације"
 
-#: cp/parser.c:20554
+#: cp/parser.c:20551
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD је именски простор"
 
-#: cp/parser.c:20556
+#: cp/parser.c:20553
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "стварање показивача на члан некласног типа %qT"
 
-#: cp/parser.c:20577
+#: cp/parser.c:20574
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected ptr-operator"
 msgstr "неочекиван операнд"
 
-#: cp/parser.c:20638
+#: cp/parser.c:20635
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "удвостручена кн-одредба"
 
-#: cp/parser.c:20692
+#: cp/parser.c:20689
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate cv-qualifier"
 msgid "multiple ref-qualifiers"
 msgstr "удвостручена кн-одредба"
 
-#: cp/parser.c:20729
+#: cp/parser.c:20726
 #, gcc-internal-format
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr ""
 
-#: cp/parser.c:20787
+#: cp/parser.c:20784
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate cv-qualifier"
 msgid "duplicate virt-specifier"
 msgstr "удвостручена кн-одредба"
 
-#: cp/parser.c:21025
+#: cp/parser.c:21022
 #, fuzzy, gcc-internal-format
 #| msgid "missing makefile target after %qs"
 msgid "missing template arguments after %qT"
 msgstr "недостаје справљачки циљ после %qs"
 
-#: cp/parser.c:21031 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2090
+#: cp/parser.c:21028 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2093
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qD"
 msgid "invalid use of %qT"
 msgstr "неисправна употреба %qD"
 
-#: cp/parser.c:21052
+#: cp/parser.c:21049
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in template arguments"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:21057
+#: cp/parser.c:21054
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<this%> in non-member function"
 msgid "invalid use of %<auto%> in template argument"
 msgstr "неисправна употреба %<this%> у нечланској функцији"
 
-#: cp/parser.c:21145
+#: cp/parser.c:21142
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier"
 msgid "expected type-specifier"
 msgstr "очекиван је идентификатор"
 
-#: cp/parser.c:21429
+#: cp/parser.c:21426
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<...%>"
 msgid "expected %<,%> or %<...%>"
 msgstr "очекивано је %<:%> или %<...%>"
 
-#: cp/parser.c:21504
+#: cp/parser.c:21501
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in parameter types"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:21678
+#: cp/parser.c:21675
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "подразумевани аргументи су дозвољени само за параметре функција"
 
-#: cp/parser.c:21696
+#: cp/parser.c:21693
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "%qD не може имати подразумеване аргументе"
 
-#: cp/parser.c:21702
+#: cp/parser.c:21699
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "template parameter pack cannot have a default argument"
 msgstr "шаблонски параметри не могу бити пријатељи"
 
-#: cp/parser.c:21704
+#: cp/parser.c:21701
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "parameter pack cannot have a default argument"
 msgstr "%qD не може имати подразумеване аргументе"
 
-#: cp/parser.c:22131
+#: cp/parser.c:22128
 #, gcc-internal-format
 msgid "C++ designated initializers only available with -std=c++2a or -std=gnu++2a"
 msgstr ""
 
-#: cp/parser.c:22151
+#: cp/parser.c:22148
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr "ИСО Ц++ не дозвољава утврђене успостављаче"
 
-#: cp/parser.c:22189
+#: cp/parser.c:22186
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ИСО Ц++ не дозвољава утврђене успостављаче"
 
-#: cp/parser.c:22203
+#: cp/parser.c:22200
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr ""
 
-#: cp/parser.c:22228
+#: cp/parser.c:22225
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "%<...%> not allowed in designated initializer list"
 msgstr "ИСО Ц++ не дозвољава утврђене успостављаче"
 
-#: cp/parser.c:22266
+#: cp/parser.c:22263
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr ""
 
-#: cp/parser.c:22322 cp/parser.c:22448
+#: cp/parser.c:22319 cp/parser.c:22445
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected class-name"
 msgstr "очекивано је име класе"
 
-#: cp/parser.c:22650
+#: cp/parser.c:22647
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "expected %<;%> after class definition"
 msgstr "%q+D декларисано уткано после своје дефиниције"
 
-#: cp/parser.c:22653
+#: cp/parser.c:22650
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "expected %<;%> after struct definition"
 msgstr "%q+D декларисано уткано после своје дефиниције"
 
-#: cp/parser.c:22656
+#: cp/parser.c:22653
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected junk after function declaration at %C"
 msgid "expected %<;%> after union definition"
 msgstr "Неочекивано смеће после декларације функције код %C"
 
-#: cp/parser.c:23012
+#: cp/parser.c:23009
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<{%> or %<:%>"
 msgstr "очекивано је %<,%> или %<;%>"
 
-#: cp/parser.c:23023
+#: cp/parser.c:23020
 #, fuzzy, gcc-internal-format
 #| msgid "cannot find file for class %s"
 msgid "cannot specify %<override%> for a class"
 msgstr "не могу да нађем датотеку за класу %s"
 
-#: cp/parser.c:23031
+#: cp/parser.c:23028
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:23038
+#: cp/parser.c:23035
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration does not name a class or function"
 msgid "qualified name does not name a class"
 msgstr "декларација пријатеља не именује ни класу ни функцију"
 
-#: cp/parser.c:23050
+#: cp/parser.c:23047
 #, fuzzy, gcc-internal-format
 #| msgid "keyword %<typename%> not allowed outside of templates"
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr "кључна реч %<typename%> није дозвољена изван шаблона"
 
-#: cp/parser.c:23056
+#: cp/parser.c:23053
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "неисправно име класе у декларацији %qD"
 
-#: cp/parser.c:23114
+#: cp/parser.c:23111
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "експлицитној специјализацији мора претходити %<template <>%>"
 
-#: cp/parser.c:23146
+#: cp/parser.c:23143
 #, fuzzy, gcc-internal-format
 #| msgid "non-template %qD used as template"
 msgid "function template %qD redeclared as a class template"
 msgstr "%qD употребљено као шаблон, а није"
 
-#: cp/parser.c:23182
+#: cp/parser.c:23179
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr ""
 
-#: cp/parser.c:23241
+#: cp/parser.c:23238
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+#T"
 msgid "previous definition of %q#T"
 msgstr "претходна дефиниција %q+#T"
 
-#: cp/parser.c:23331 cp/parser.c:28499
+#: cp/parser.c:23328 cp/parser.c:28496
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected class-key"
 msgstr "очекивано је име класе"
 
-#: cp/parser.c:23355
+#: cp/parser.c:23352
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:23359
+#: cp/parser.c:23356
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<class%> or %<typename%>"
 msgstr "очекивано је %<,%> или %<;%>"
 
-#: cp/parser.c:23605
+#: cp/parser.c:23602
 #, fuzzy, gcc-internal-format
 #| msgid "a class-key must be used when declaring a friend"
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr "при декларацији пријатеља мора бити употребљена кључна реч class"
 
-#: cp/parser.c:23623
+#: cp/parser.c:23620
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "декларација пријатеља не именује ни класу ни функцију"
 
-#: cp/parser.c:23641
+#: cp/parser.c:23638
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:23738
+#: cp/parser.c:23735
 #, gcc-internal-format
 msgid "default member initializers for bit-fields only available with -std=c++2a or -std=gnu++2a"
 msgstr ""
 
-#: cp/parser.c:23745
+#: cp/parser.c:23742
 #, gcc-internal-format
 msgid "default member initializer for unnamed bit-field"
 msgstr ""
 
-#: cp/parser.c:23758
+#: cp/parser.c:23755
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr ""
 
-#: cp/parser.c:23903
+#: cp/parser.c:23900
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr "наводилац pure на дефиницији функције"
 
-#: cp/parser.c:23923
+#: cp/parser.c:23920
 #, fuzzy, gcc-internal-format
 #| msgid "pure-specifier on function-definition"
 msgid "extra %<;%> after in-class function definition"
 msgstr "наводилац pure на дефиницији функције"
 
-#: cp/parser.c:23970
+#: cp/parser.c:23967
 #, fuzzy, gcc-internal-format
 #| msgid "cannot use %<::%> in parameter declaration"
 msgid "stray %<,%> at end of member declaration"
 msgstr "не може се користити %<::%> у декларацији параметра"
 
-#: cp/parser.c:23984
+#: cp/parser.c:23981
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<(%> or end of line"
 msgid "expected %<;%> at end of member declaration"
 msgstr "очекивано је %<(%> или крај линије"
 
-#: cp/parser.c:24058
+#: cp/parser.c:24055
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr ""
 
-#: cp/parser.c:24093
+#: cp/parser.c:24090
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr ""
 
-#: cp/parser.c:24223
+#: cp/parser.c:24220
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr ""
 
-#: cp/parser.c:24243
+#: cp/parser.c:24240
 #, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr ""
 
-#: cp/parser.c:24267
+#: cp/parser.c:24264
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "кључна реч %<typename%> није дозвољена изван шаблона"
 
-#: cp/parser.c:24270
+#: cp/parser.c:24267
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "кључна реч %<typename%> није дозвољена у овом контексту (основна класа је имплицитно тип)"
 
-#: cp/parser.c:24364 cp/parser.c:24442
+#: cp/parser.c:24361 cp/parser.c:24439
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in an exception-specification"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:24450
+#: cp/parser.c:24447
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "ИСО Ц++ не дозвољава утврђене успостављаче"
 
-#: cp/parser.c:24456
+#: cp/parser.c:24453
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr ""
 
-#: cp/parser.c:24500
+#: cp/parser.c:24497
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qD in linkage specification"
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "неисправна употреба %qD у одредници повезивости"
 
-#: cp/parser.c:24539
+#: cp/parser.c:24536
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:24650
+#: cp/parser.c:24647
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in exception-declarations"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:25203
+#: cp/parser.c:25200
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr "Атрибут %s коси се са атрибутом %s код %L"
 
-#: cp/parser.c:25217
+#: cp/parser.c:25214
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier or %<(%>"
 msgid "expected an identifier for the attribute name"
 msgstr "очекиван је идентификатор или %<(%>"
 
-#: cp/parser.c:25301
+#: cp/parser.c:25298
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:25305
+#: cp/parser.c:25302
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:25342
+#: cp/parser.c:25339
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<...%>"
 msgid "expected attribute before %<...%>"
 msgstr "очекивано је %<:%> или %<...%>"
 
-#: cp/parser.c:25403
+#: cp/parser.c:25400
 #, gcc-internal-format
 msgid "attribute using prefix only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:25721
+#: cp/parser.c:25718
 #, gcc-internal-format
 msgid "%<requires%> only available with -fconcepts"
 msgstr ""
 
-#: cp/parser.c:25753
+#: cp/parser.c:25750
 #, gcc-internal-format
 msgid "a requires expression cannot appear outside a template"
 msgstr ""
 
-#: cp/parser.c:26467
+#: cp/parser.c:26464
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:26472
+#: cp/parser.c:26469
 #, fuzzy, gcc-internal-format
 #| msgid "invalid redeclaration of %q+D"
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "неисправна поновљена декларација %q+D"
 
-#: cp/parser.c:26476
+#: cp/parser.c:26473
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "премало листа параметара шаблона"
@@ -52346,456 +52390,456 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:26483
+#: cp/parser.c:26480
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "превише листа шаблонских параметера"
 
-#: cp/parser.c:26832
+#: cp/parser.c:26829
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "именоване повратне вредности нису више подржане"
 
-#: cp/parser.c:26991
+#: cp/parser.c:26988
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr ""
 
-#: cp/parser.c:26996
+#: cp/parser.c:26993
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr ""
 
-#: cp/parser.c:27066
+#: cp/parser.c:27063
 #, fuzzy, gcc-internal-format
 #| msgid "Use media instructions"
 msgid "empty introduction-list"
 msgstr "Користи медија-инструкције"
 
-#: cp/parser.c:27090
+#: cp/parser.c:27087
 #, fuzzy, gcc-internal-format
 #| msgid "no matching template for %qD found"
 msgid "no matching concept for template-introduction"
 msgstr "поклапајући шаблон за %qD није нађен"
 
-#: cp/parser.c:27112
+#: cp/parser.c:27109
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "неисправна декларација чланског шаблона у локалној класи"
 
-#: cp/parser.c:27121
+#: cp/parser.c:27118
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "шаблон са Ц повезивошћу"
 
-#: cp/parser.c:27141
+#: cp/parser.c:27138
 #, fuzzy, gcc-internal-format
 #| msgid "invalid base-class specification"
 msgid "invalid explicit specialization"
 msgstr "неисправан навод основне класе"
 
-#: cp/parser.c:27245
+#: cp/parser.c:27242
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %qs"
 msgid "template declaration of %<typedef%>"
 msgstr "декларација шаблона %qs"
 
-#: cp/parser.c:27296
+#: cp/parser.c:27293
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "a class template declaration must not declare anything else"
 msgstr "декларација ништа не декларише"
 
-#: cp/parser.c:27342
+#: cp/parser.c:27339
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization in non-namespace scope %qD"
 msgid "explicit template specialization cannot have a storage class"
 msgstr "експлицитна специјализација у не-именскопросторном досегу %qD"
 
-#: cp/parser.c:27650
+#: cp/parser.c:27647
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<>>%> should be %<> >%> within a nested template argument list"
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%H%<>>%> треба да је %<> >%> унутар угњеждене листе шаблонских аргумената"
 
-#: cp/parser.c:27663
+#: cp/parser.c:27660
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "сувишно %<>>%>, користите %<>%> за затварање листе шаблонских аргумената"
 
-#: cp/parser.c:27958
+#: cp/parser.c:27955
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:28118
+#: cp/parser.c:28115
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "неисправна употреба %qD у одредници повезивости"
 
-#: cp/parser.c:28133
+#: cp/parser.c:28130
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> пре %qD"
 
-#: cp/parser.c:28267
+#: cp/parser.c:28264
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not support %<long long%>"
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ИСО Ц++ не подржава %<long long%>"
 
-#: cp/parser.c:28275
+#: cp/parser.c:28272
 #, fuzzy, gcc-internal-format
 #| msgid "both %<short%> and %<char%> in declaration specifiers"
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "и %<short%> и %<char%> у наводиоцима декларације"
 
-#: cp/parser.c:28280
+#: cp/parser.c:28277
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %qE"
 msgid "duplicate %qD"
 msgstr "удвостручено %qE"
 
-#: cp/parser.c:28304
+#: cp/parser.c:28301
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "удвостручено %qs"
 
-#: cp/parser.c:28356
+#: cp/parser.c:28353
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<new%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:28359
+#: cp/parser.c:28356
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<delete%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:28362
+#: cp/parser.c:28359
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<return%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:28368
+#: cp/parser.c:28365
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<extern%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:28371
+#: cp/parser.c:28368
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected %<static_assert%>"
 msgstr "очекивана је наредба"
 
-#: cp/parser.c:28374
+#: cp/parser.c:28371
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<decltype%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:28377
+#: cp/parser.c:28374
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<operator%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:28380
+#: cp/parser.c:28377
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<class%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:28383
+#: cp/parser.c:28380
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<template%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:28386
+#: cp/parser.c:28383
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<namespace%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:28389
+#: cp/parser.c:28386
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<using%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:28392
+#: cp/parser.c:28389
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<asm%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:28395
+#: cp/parser.c:28392
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<try%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:28398
+#: cp/parser.c:28395
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<catch%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:28401
+#: cp/parser.c:28398
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<throw%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:28404
+#: cp/parser.c:28401
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<__label__%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:28407
+#: cp/parser.c:28404
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@try%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:28410
+#: cp/parser.c:28407
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@synchronized%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:28413
+#: cp/parser.c:28410
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@throw%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:28416
+#: cp/parser.c:28413
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.c:28419
+#: cp/parser.c:28416
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<__transaction_relaxed%>"
 msgstr "очекивано је %<none%> или %<shared%>"
 
-#: cp/parser.c:28451
+#: cp/parser.c:28448
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<::%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:28463
+#: cp/parser.c:28460
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<...%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:28466
+#: cp/parser.c:28463
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<*%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:28469
+#: cp/parser.c:28466
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<~%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:28475
+#: cp/parser.c:28472
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<...%>"
 msgid "expected %<:%> or %<::%>"
 msgstr "очекивано је %<:%> или %<...%>"
 
-#: cp/parser.c:28502
+#: cp/parser.c:28499
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "очекивано је %<,%>, %<;%> или %<}%>"
 
-#: cp/parser.c:28772
+#: cp/parser.c:28769
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "ознака %qs употребљена при именовању %q#T"
 
-#: cp/parser.c:28777
+#: cp/parser.c:28774
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously declared here"
 msgid "%q#T was previously declared here"
 msgstr "%q+#D претходно декларисано овде"
 
-#: cp/parser.c:28798
+#: cp/parser.c:28795
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD поново декларисано са другачијим приступом"
 
-#: cp/parser.c:28819
+#: cp/parser.c:28816
 #, fuzzy, gcc-internal-format
 #| msgid "%<template%> (as a disambiguator) is only allowed within templates"
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "%<template%> (као разјашњење двосмислености) дозвољено је само унутар шаблона"
 
-#: cp/parser.c:29062
+#: cp/parser.c:29059
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "датотека се завршава подразумеваним аргументом"
 
-#: cp/parser.c:29303 cp/parser.c:30620 cp/parser.c:30808
+#: cp/parser.c:29300 cp/parser.c:30617 cp/parser.c:30805
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "конструкција %<@%D%> објективног Ц++а на погрешном месту"
 
-#: cp/parser.c:29372
+#: cp/parser.c:29369
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr ""
 
-#: cp/parser.c:29442
+#: cp/parser.c:29439
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:29473
+#: cp/parser.c:29470
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "%<@encode%> мора навести тип као аргумент"
 
-#: cp/parser.c:29883
+#: cp/parser.c:29880
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "неисправно име селектора објективног Ц++а"
 
-#: cp/parser.c:29958 cp/parser.c:29976
+#: cp/parser.c:29955 cp/parser.c:29973
 #, fuzzy, gcc-internal-format
 #| msgid "Class or interface declaration expected"
 msgid "objective-c++ method declaration is expected"
 msgstr "Очекивана је декларација класе или сучеља"
 
-#: cp/parser.c:29970 cp/parser.c:30035
+#: cp/parser.c:29967 cp/parser.c:30032
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsection attribute cannot be specified for local variables"
 msgid "method attributes must be specified at the end"
 msgstr "%Jатрибут одељка се не може навести за локалне променљиве"
 
-#: cp/parser.c:30078
+#: cp/parser.c:30075
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:30284 cp/parser.c:30291 cp/parser.c:30298
+#: cp/parser.c:30281 cp/parser.c:30288 cp/parser.c:30295
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid type for iteration variable %qE"
 msgid "invalid type for instance variable"
 msgstr "%Hнеисправан тип променљиве итерације %qE"
 
-#: cp/parser.c:30413
+#: cp/parser.c:30410
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "очекиван је идентификатор после %<@protocol%>"
 
-#: cp/parser.c:30585
+#: cp/parser.c:30582
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:30592
+#: cp/parser.c:30589
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored for %qE"
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "атрибут %qE се игнорише за %qE"
 
-#: cp/parser.c:30867 cp/parser.c:30874 cp/parser.c:30881
+#: cp/parser.c:30864 cp/parser.c:30871 cp/parser.c:30878
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "invalid type for property"
 msgstr "неисправан типски аргумент"
 
-#: cp/parser.c:32011
+#: cp/parser.c:32008
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<wait%> expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/parser.c:32724
+#: cp/parser.c:32721
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid reduction-identifier"
 msgstr "неисправан успостављач"
 
-#: cp/parser.c:34911
+#: cp/parser.c:34908
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:35231 cp/pt.c:16392
+#: cp/parser.c:35228 cp/pt.c:16414
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable %qs should not be reduction"
 msgid "iteration variable %qD should not be reduction"
 msgstr "не би требало да променљива итерације %qs буде свођена"
 
-#: cp/parser.c:35316
+#: cp/parser.c:35313
 #, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr ""
 
-#: cp/parser.c:37521
+#: cp/parser.c:37518
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer clause"
 msgstr "неисправан успостављач"
 
-#: cp/parser.c:37549
+#: cp/parser.c:37546
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "expected id-expression (arguments)"
 msgstr "очекиван је израз"
 
-#: cp/parser.c:37561
+#: cp/parser.c:37558
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:37662
+#: cp/parser.c:37659
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in declare reduction type list"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:37682 cp/semantics.c:5405
+#: cp/parser.c:37679 cp/semantics.c:5408
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37687 cp/semantics.c:5414
+#: cp/parser.c:37684 cp/semantics.c:5417
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37690 cp/pt.c:12944 cp/semantics.c:5420
+#: cp/parser.c:37687 cp/pt.c:12966 cp/semantics.c:5423
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37693 cp/semantics.c:5426
+#: cp/parser.c:37690 cp/semantics.c:5429
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:38047
+#: cp/parser.c:38044
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:38057
+#: cp/parser.c:38054
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qD does not refer to a namespace scope function"
@@ -52802,50 +52846,50 @@
 msgstr "%qD није чланска шаблонска функција"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:38392
+#: cp/parser.c:38389
 #, gcc-internal-format
 msgid "atomic_cancel"
 msgstr ""
 
-#: cp/parser.c:38435 cp/semantics.c:8575
+#: cp/parser.c:38432 cp/semantics.c:8578
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:38437 cp/semantics.c:8577
+#: cp/parser.c:38434 cp/semantics.c:8580
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:38631
+#: cp/parser.c:38628
 #, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "смеће на крају %<#pragma GCC pch_preprocess%>"
 
-#: cp/parser.c:38927
+#: cp/parser.c:38924
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC diagnostic not allowed inside functions"
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "#pragma GCC diagnostic није дозвољено унутар функција"
 
-#: cp/parser.c:38959
+#: cp/parser.c:38956
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC diagnostic not allowed inside functions"
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr "#pragma GCC diagnostic није дозвољено унутар функција"
 
-#: cp/parser.c:39039
+#: cp/parser.c:39036
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "унутармодулске оптимизације нису имплеметиране за Ц++"
 
-#: cp/parser.c:39295
+#: cp/parser.c:39292
 #, fuzzy, gcc-internal-format
 #| msgid "templates may not be %<virtual%>"
 msgid "implicit templates may not be %<virtual%>"
 msgstr "шаблони не могу бити виртуелни"
 
-#: cp/parser.c:39351
+#: cp/parser.c:39348
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
@@ -52936,7 +52980,7 @@
 msgid "specialization of %qD after instantiation"
 msgstr "специјализација %qD после извођења"
 
-#: cp/pt.c:1954 cp/semantics.c:5274
+#: cp/pt.c:1954 cp/semantics.c:5277
 #, fuzzy, gcc-internal-format
 #| msgid "%s %+#D"
 msgid "%s %#qD"
@@ -53117,116 +53161,116 @@
 msgid "argument to __integer_pack must be between 0 and %d"
 msgstr "Аргумент у ACOS код %L мора бити између -1 и 1"
 
-#: cp/pt.c:3942
+#: cp/pt.c:3955
 #, gcc-internal-format
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr ""
 
-#: cp/pt.c:4010
+#: cp/pt.c:4023
 #, gcc-internal-format
 msgid "expansion pattern %qT contains no argument packs"
 msgstr ""
 
-#: cp/pt.c:4012
+#: cp/pt.c:4025
 #, gcc-internal-format
 msgid "expansion pattern %qE contains no argument packs"
 msgstr ""
 
-#: cp/pt.c:4063
+#: cp/pt.c:4077
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr ""
 
-#: cp/pt.c:4080 cp/pt.c:4835
+#: cp/pt.c:4094 cp/pt.c:4849
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
 
-#: cp/pt.c:4082
+#: cp/pt.c:4096
 #, fuzzy, gcc-internal-format
 #| msgid "<anonymous>"
 msgid "        <anonymous>"
 msgstr "<анонимно>"
 
-#: cp/pt.c:4208
+#: cp/pt.c:4222
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr "декларација %q+D заклања параметар"
 
-#: cp/pt.c:4211
+#: cp/pt.c:4225
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of %q+#D shadows template parameter"
 msgstr "декларација %q+D заклања параметар"
 
-#: cp/pt.c:4213
+#: cp/pt.c:4227
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter type %qT declared %<friend%>"
 msgid "template parameter %qD declared here"
 msgstr "шаблонски параметарски тип %qT декларисан пријатељским"
 
-#: cp/pt.c:4771
+#: cp/pt.c:4785
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template %qT"
 msgid "specialization of variable concept %q#D"
 msgstr "експлицитна специјализација не-шаблонског %qT"
 
-#: cp/pt.c:4830
+#: cp/pt.c:4844
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "template parameters not deducible in partial specialization:"
 msgstr "шаблонски параметри неискоришћени у делимичној специјализацији:"
 
-#: cp/pt.c:4854
+#: cp/pt.c:4868
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr "делимична специјализација %qT не специјализује ниједан шаблонски аргумент"
 
-#: cp/pt.c:4858
+#: cp/pt.c:4872
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:4862 cp/pt.c:4873
+#: cp/pt.c:4876 cp/pt.c:4887
 #, gcc-internal-format
 msgid "primary template here"
 msgstr ""
 
-#: cp/pt.c:4870
+#: cp/pt.c:4884
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:4885
+#: cp/pt.c:4899
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "partial specialization %qD is not more specialized than"
 msgstr "делимична специјализација %qT не специјализује ниједан шаблонски аргумент"
 
-#: cp/pt.c:4887
+#: cp/pt.c:4901
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template %q#D"
 msgid "primary template %qD"
 msgstr "декларација шаблона %q#D"
 
-#: cp/pt.c:4934
+#: cp/pt.c:4948
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:4937
+#: cp/pt.c:4951
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:4958
+#: cp/pt.c:4972
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr "шаблонски аргумент %qE уплиће шаблонске параметре"
 
-#: cp/pt.c:5004
+#: cp/pt.c:5018
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT of template argument %qE depends on template parameter(s)"
 msgid "type %qT of template argument %qE depends on a template parameter"
@@ -53236,19 +53280,19 @@
 msgstr[2] "тип %qT шаблонског аргумента %qE зависи од шаблонских параметара"
 msgstr[3] "тип %qT шаблонског аргумента %qE зависи од шаблонских параметара"
 
-#: cp/pt.c:5066
+#: cp/pt.c:5080
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "двосмислено извођење шаблона класе за %q#T"
 
-#: cp/pt.c:5070
+#: cp/pt.c:5084
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %qD after instantiation"
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "специјализација %qD после извођења"
 
-#: cp/pt.c:5247
+#: cp/pt.c:5261
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "нема подразумеваног аргумента за %qD"
@@ -53256,53 +53300,53 @@
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5269
+#: cp/pt.c:5283
 #, fuzzy, gcc-internal-format
 #| msgid "%qD used without template parameters"
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "%qD употребљено без параметара шаблона"
 
-#: cp/pt.c:5305
+#: cp/pt.c:5319
 #, fuzzy, gcc-internal-format
 #| msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "подразумевани аргументи нису дозвољени у декларацији пријатељске специјализације шаблона %qD"
 
-#: cp/pt.c:5308
+#: cp/pt.c:5322
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "шаблонски параметри неискоришћени у делимичној специјализацији:"
 
-#: cp/pt.c:5311
+#: cp/pt.c:5325
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/pt.c:5314
+#: cp/pt.c:5328
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "default template arguments may not be used in partial specializations"
 msgstr "шаблонски параметри неискоришћени у делимичној специјализацији:"
 
-#: cp/pt.c:5317 cp/pt.c:5375
+#: cp/pt.c:5331 cp/pt.c:5389
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for parameter of type %qT has type %qT"
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "подразумевани аргумент за параметар типа %qT има тип %qT"
 
-#: cp/pt.c:5489
+#: cp/pt.c:5503
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD declared void"
 msgid "template %qD declared"
 msgstr "параметар %qD декларисан празним"
 
-#: cp/pt.c:5496
+#: cp/pt.c:5510
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "шаблонска класа без имена"
 
-#: cp/pt.c:5504
+#: cp/pt.c:5518
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "member template %qD may not have virt-specifiers"
@@ -53313,59 +53357,59 @@
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5526
+#: cp/pt.c:5540
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "неисправна декларација шаблона %qD"
 
-#: cp/pt.c:5669
+#: cp/pt.c:5683
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "шаблонска дефиниција нешаблонског %q#D"
 
-#: cp/pt.c:5712
+#: cp/pt.c:5726
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "очекивах %d нивоа шаблонских параметара за %q#D, добих %d"
 
-#: cp/pt.c:5726
+#: cp/pt.c:5740
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "добих %d шаблонских параметара за %q#D"
 
-#: cp/pt.c:5729
+#: cp/pt.c:5743
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "добих %d шаблонских параметара за %q#T"
 
-#: cp/pt.c:5731
+#: cp/pt.c:5745
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  а потребно је %d"
 
-#: cp/pt.c:5752
+#: cp/pt.c:5766
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters do not match template"
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "параметри шаблона се не поклапају са шаблоном"
 
-#: cp/pt.c:5755
+#: cp/pt.c:5769
 #, fuzzy, gcc-internal-format
 #| msgid "enclosing class templates are not explicitly specialized"
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "обухватајући шаблони класа не бивају експлицитно специјализовани"
 
-#: cp/pt.c:5882
+#: cp/pt.c:5896
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT није шаблонски тип"
 
-#: cp/pt.c:5895
+#: cp/pt.c:5909
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "наводиоци шаблона нису задати у декларацији %qD"
 
-#: cp/pt.c:5906
+#: cp/pt.c:5920
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qD used without template parameters"
 msgid "redeclared with %d template parameter"
@@ -53375,7 +53419,7 @@
 msgstr[2] "%qD употребљено без параметара шаблона"
 msgstr[3] "%qD употребљено без параметара шаблона"
 
-#: cp/pt.c:5910
+#: cp/pt.c:5924
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D here"
 msgid "previous declaration %qD used %d template parameter"
@@ -53385,12 +53429,12 @@
 msgstr[2] "претходном декларацијом %q+#D овде"
 msgstr[3] "претходном декларацијом %q+#D овде"
 
-#: cp/pt.c:5947
+#: cp/pt.c:5961
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "шаблонски параметар %q+#D"
 
-#: cp/pt.c:5948
+#: cp/pt.c:5962
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "поново декларисано овде као %q#D"
@@ -53399,132 +53443,132 @@
 #.
 #. A template-parameter may not be given default arguments
 #. by two different declarations in the same scope.
-#: cp/pt.c:5958
+#: cp/pt.c:5972
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "поновљена дефиниција подразумеваног аргумента за %q#D"
 
-#: cp/pt.c:5960
+#: cp/pt.c:5974
 #, fuzzy, gcc-internal-format
 #| msgid "%J  original definition appeared here"
 msgid "original definition appeared here"
 msgstr "%J  првобитна дефиниција налази се овде"
 
-#: cp/pt.c:5988
+#: cp/pt.c:6002
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qF throws different exceptions"
 msgid "redeclaration %q#D with different constraints"
 msgstr "декларација %qF баца различите изузетке"
 
-#: cp/pt.c:5991
+#: cp/pt.c:6005
 #, fuzzy, gcc-internal-format
 #| msgid "%J  original definition appeared here"
 msgid "original declaration appeared here"
 msgstr "%J  првобитна дефиниција налази се овде"
 
-#: cp/pt.c:6250 cp/pt.c:6318
+#: cp/pt.c:6264 cp/pt.c:6332
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%qE није исправан шаблонски аргумент за тип %qT јер је показивач"
 
-#: cp/pt.c:6253
+#: cp/pt.c:6267
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6256
+#: cp/pt.c:6270
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6268
+#: cp/pt.c:6282
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%qE није исправан шаблонски аргумент за тип %qT јер објекат %qD нема спољашњу повезивост"
 
-#: cp/pt.c:6272
+#: cp/pt.c:6286
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%qE није исправан шаблонски аргумент типа %qT јер %qD нема спољашњу повезивост"
 
-#: cp/pt.c:6321
+#: cp/pt.c:6335
 #, fuzzy, gcc-internal-format
 #| msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "(показивач на члан може бити формиран само помоћу %<&%E%>)"
 
-#: cp/pt.c:6323
+#: cp/pt.c:6337
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a member of %qT"
 msgid "because it is a member of %qT"
 msgstr "%qT није члан из %qT"
 
-#: cp/pt.c:6383
+#: cp/pt.c:6397
 #, fuzzy, gcc-internal-format
 #| msgid "got %d template parameters for %q#D"
 msgid "  couldn't deduce template parameter %qD"
 msgstr "добих %d шаблонских параметара за %q#D"
 
-#: cp/pt.c:6392
+#: cp/pt.c:6406
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.c:6401
+#: cp/pt.c:6415
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between types %q#T and %q#T"
 msgid "  mismatched types %qT and %qT"
 msgstr "поређење између типова %q#T и %q#T"
 
-#: cp/pt.c:6410
+#: cp/pt.c:6424
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr ""
 
-#: cp/pt.c:6421
+#: cp/pt.c:6435
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %qE involves template parameter(s)"
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "шаблонски аргумент %qE уплиће шаблонске параметре"
 
-#: cp/pt.c:6431
+#: cp/pt.c:6445
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "  %qE is not equivalent to %qE"
 msgstr "%qs није исправно за %qs"
 
-#: cp/pt.c:6440
+#: cp/pt.c:6454
 #, fuzzy, gcc-internal-format
 #| msgid "Inconsistent ranks for operator at %L and %L"
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr "Неусаглашени рангови за оператор код %L и %L"
 
-#: cp/pt.c:6452
+#: cp/pt.c:6466
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.c:6456
+#: cp/pt.c:6470
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.c:6467
+#: cp/pt.c:6481
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "делимична специјализација %qT не специјализује ниједан шаблонски аргумент"
 
-#: cp/pt.c:6478
+#: cp/pt.c:6492
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' at %L is not allowed as an actual argument"
 msgid "  member function type %qT is not a valid template argument"
 msgstr "Наредбена функција ‘%s’ код %L није дозвољена као стварни аргумент"
 
-#: cp/pt.c:6490
+#: cp/pt.c:6504
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
@@ -53533,322 +53577,322 @@
 msgstr[2] ""
 msgstr[3] ""
 
-#: cp/pt.c:6521
+#: cp/pt.c:6535
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert type %qT to type %qT"
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "не може се претворити из типа %qT у %qT"
 
-#: cp/pt.c:6534
+#: cp/pt.c:6548
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is an ambiguous base of %qT"
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "%qT је двосмислена основа за %qT"
 
-#: cp/pt.c:6538
+#: cp/pt.c:6552
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not derived from type %qT"
 msgid "  %qT is not derived from %qT"
 msgstr "тип %qT није изведен из типа %qT"
 
-#: cp/pt.c:6549
+#: cp/pt.c:6563
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.c:6559
+#: cp/pt.c:6573
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type %qT"
 msgid "  can't deduce a template for %qT from non-template type %qT"
 msgstr "не може се %s показивач на непотпуни тип %qT"
 
-#: cp/pt.c:6569
+#: cp/pt.c:6583
 #, fuzzy, gcc-internal-format
 #| msgid "argument of type %qT does not match %qT"
 msgid "  template argument %qE does not match %qE"
 msgstr "аргумент типа %qT не поклапа се са %qT"
 
-#: cp/pt.c:6609
+#: cp/pt.c:6623
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "%qE није исправан шаблонски аргумент за тип %qT јер се константне ниске не могу користити у овом контексту"
 
-#: cp/pt.c:6758
+#: cp/pt.c:6772
 #, fuzzy, gcc-internal-format
 #| msgid "template argument for %qD uses local type %qT"
 msgid "in template argument for type %qT"
 msgstr "шаблонски аргумент за %qD користи локални тип %qT"
 
-#: cp/pt.c:6772
+#: cp/pt.c:6786
 #, fuzzy, gcc-internal-format
 #| msgid "accumulator is not a constant integer"
 msgid "template argument %qE for type %qT not a constant integer"
 msgstr "акумулатор није целобројна константа"
 
-#: cp/pt.c:6833
+#: cp/pt.c:6847
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qD није исправан шаблонски аргумент јер је %qD променљива, а не адреса неке променљиве"
 
-#: cp/pt.c:6841
+#: cp/pt.c:6855
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qD није исправан шаблонски аргумент јер је %qD променљива, а не адреса неке променљиве"
 
-#: cp/pt.c:6857
+#: cp/pt.c:6871
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "%qE није исправан шаблонски аргумент типа %qT јер %qE није променљива"
 
-#: cp/pt.c:6864
+#: cp/pt.c:6878
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr "%qE није исправан шаблонски аргумент типа %qT јер %qD нема спољашњу повезивост"
 
-#: cp/pt.c:6873
+#: cp/pt.c:6887
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE није исправан шаблонски аргумент типа %qT јер %qE није променљива"
 
-#: cp/pt.c:6888
+#: cp/pt.c:6902
 #, fuzzy, gcc-internal-format
 #| msgid "the address of %qD will always evaluate as %<true%>"
 msgid "the address of %qD is not a valid template argument"
 msgstr "адреса за %qD ће увек бити израчуната као %<true%>"
 
-#: cp/pt.c:6897
+#: cp/pt.c:6911
 #, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6904
+#: cp/pt.c:6918
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "%qE није исправан шаблонски аргумент типа %qT јер %qD нема спољашњу повезивост"
 
-#: cp/pt.c:6933
+#: cp/pt.c:6947
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "%qE није исправан шаблонски аргумент за тип %qT јер се коси са кн-одредбом"
 
-#: cp/pt.c:6941
+#: cp/pt.c:6955
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE није исправан шаблонски аргумент за тип %qT јер није л-вредност"
 
-#: cp/pt.c:6959
+#: cp/pt.c:6973
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is a non-constant expression"
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%qE није исправан шаблонски аргумент за тип %qT јер није константан израз"
 
-#: cp/pt.c:6975
+#: cp/pt.c:6989
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgid "%qE is not a valid template argument for type %qT because it is not an object with linkage"
 msgstr "%qE није исправан шаблонски аргумент за тип %qT јер није л-вредност"
 
-#: cp/pt.c:6986
+#: cp/pt.c:7000
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "%qE is not a valid template argument for type %qT because object %qD does not have linkage"
 msgstr "%qE није исправан шаблонски аргумент за тип %qT јер објекат %qD нема спољашњу повезивост"
 
-#: cp/pt.c:7036
+#: cp/pt.c:7050
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE није исправан шаблонски аргумент за тип %qT јер је показивач"
 
-#: cp/pt.c:7038
+#: cp/pt.c:7052
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "покушајте са %qE уместо тога"
 
-#: cp/pt.c:7092
+#: cp/pt.c:7106
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE није исправан шаблонски аргумент за тип %qT јер је типа %qT"
 
-#: cp/pt.c:7654
+#: cp/pt.c:7668
 #, fuzzy, gcc-internal-format
 #| msgid "applying attributes to template parameters is not implemented"
 msgid "ignoring attributes on template argument %qT"
 msgstr "примењивање атрибута на шаблонске параметре није имплементирано"
 
-#: cp/pt.c:7670
+#: cp/pt.c:7684
 #, fuzzy, gcc-internal-format
 #| msgid "Ignoring statement label in empty statement at %C"
 msgid "ignoring attributes in template argument %qE"
 msgstr "Игноришем етикету наредбе у празној наредби код %C"
 
-#: cp/pt.c:7805
+#: cp/pt.c:7819
 #, fuzzy, gcc-internal-format
 #| msgid "name of class shadows template template parameter %qD"
 msgid "injected-class-name %qD used as template template argument"
 msgstr "име класе заклања шаблонски шаблонски параметар %qD"
 
-#: cp/pt.c:7834
+#: cp/pt.c:7848
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of destructor %qD as a type"
 msgid "invalid use of destructor %qE as a type"
 msgstr "неисправна употреба деструктора %qD као типа"
 
-#: cp/pt.c:7839
+#: cp/pt.c:7853
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "да упутите на тип шаблонског параметра, употребите %<typename %E%>"
 
-#: cp/pt.c:7855 cp/pt.c:7877 cp/pt.c:7931
+#: cp/pt.c:7869 cp/pt.c:7891 cp/pt.c:7945
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "неслагање типа/вредности код аргумента %d у листи шаблонских параметара за %qD"
 
-#: cp/pt.c:7860
+#: cp/pt.c:7874
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  очекивах константу типа %qT, добих %qT"
 
-#: cp/pt.c:7865
+#: cp/pt.c:7879
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  очекивах шаблон класе, добих %qE"
 
-#: cp/pt.c:7868
+#: cp/pt.c:7882
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  очекивах тип, добих %qE"
 
-#: cp/pt.c:7882
+#: cp/pt.c:7896
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr " очекивах тип, добих %qT"
 
-#: cp/pt.c:7885
+#: cp/pt.c:7899
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  очекивах шаблон класе, добих %qT"
 
-#: cp/pt.c:7935
+#: cp/pt.c:7949
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a template of type %qD, got %qD"
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  очекивах шаблон типа %qD, добих %qD"
 
-#: cp/pt.c:7949
+#: cp/pt.c:7963
 #, fuzzy, gcc-internal-format
 #| msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "неслагање типа/вредности код аргумента %d у листи шаблонских параметара за %qD"
 
-#: cp/pt.c:7952
+#: cp/pt.c:7966
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a type, got %qE"
 msgid "  expected %qD but got %qD"
 msgstr "  очекивах тип, добих %qE"
 
-#: cp/pt.c:8012
+#: cp/pt.c:8026
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert template argument %qE to %qT"
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "нисам могао да претворим шаблонски аргумент %qE у %qT"
 
-#: cp/pt.c:8149 cp/pt.c:8465
+#: cp/pt.c:8163 cp/pt.c:8479
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "неисправан шаблонски аргумент %d"
 
-#: cp/pt.c:8164 cp/pt.c:8298
+#: cp/pt.c:8178 cp/pt.c:8312
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "погрешан број шаблонских аргумената ((%d, а треба %d)"
 
-#: cp/pt.c:8294
+#: cp/pt.c:8308
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "погрешан број шаблонских аргумената ((%d, а треба %d)"
 
-#: cp/pt.c:8303
+#: cp/pt.c:8317
 #, fuzzy, gcc-internal-format
 #| msgid "provided for %q+D"
 msgid "provided for %qD"
 msgstr "дат за %q+D"
 
-#: cp/pt.c:8328
+#: cp/pt.c:8342
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:8332
+#: cp/pt.c:8346
 #, fuzzy, gcc-internal-format
 #| msgid "default argument given for parameter %d of %q#D"
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "подразумевани аргумент дат за параметар %d у %q#D"
 
-#: cp/pt.c:8431
+#: cp/pt.c:8445
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:9054
+#: cp/pt.c:9068
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%q#D is not a function template"
 msgstr "%qD није шаблон функције"
 
-#: cp/pt.c:9221
+#: cp/pt.c:9235
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "нешаблонски тип %qT употребљен као шаблон"
 
-#: cp/pt.c:9223
+#: cp/pt.c:9237
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "за декларацију шаблона %q+D"
 
-#: cp/pt.c:9346
+#: cp/pt.c:9360
 #, fuzzy, gcc-internal-format
 #| msgid "internal consistency failure"
 msgid "template constraint failure"
 msgstr "неуспех услед унутрашње неусаглашености"
 
-#: cp/pt.c:9697
+#: cp/pt.c:9718
 #, fuzzy, gcc-internal-format
 #| msgid "use of %qs in template"
 msgid "use of invalid variable template %qE"
 msgstr "употреба %qs у шаблону"
 
-#: cp/pt.c:10125
+#: cp/pt.c:10148
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating %qD"
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr "дубина извођења шаблона премашује максимум од %d (употребите -ftemplate-depth-NN да повећате дубину) извођења %qD"
 
-#: cp/pt.c:11202
+#: cp/pt.c:11225
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in union"
 msgid "flexible array member %qD in union"
 msgstr "%Jфлексибилан члански низ у унији"
 
-#: cp/pt.c:11691
+#: cp/pt.c:11713
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:12160
+#: cp/pt.c:12182
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr ""
 
-#: cp/pt.c:12163
+#: cp/pt.c:12185
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr ""
 
-#: cp/pt.c:12747
+#: cp/pt.c:12769
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for %q#D"
 msgid "  when instantiating default argument for call to %qD"
@@ -53867,294 +53911,294 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:13708
+#: cp/pt.c:13730
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "променљива %qD има функцијски тип"
 
-#: cp/pt.c:13881
+#: cp/pt.c:13903
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "неисправан тип параметра %qT"
 
-#: cp/pt.c:13883
+#: cp/pt.c:13905
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "у декларацији %q+D"
 
-#: cp/pt.c:14001
+#: cp/pt.c:14023
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "функција враћа низ"
 
-#: cp/pt.c:14003
+#: cp/pt.c:14025
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "функција враћа функцију"
 
-#: cp/pt.c:14043
+#: cp/pt.c:14065
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "стварање показивача на чланску функцију некласног типа %qT"
 
-#: cp/pt.c:14637
+#: cp/pt.c:14659
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "обликовање упућивача на празно"
 
-#: cp/pt.c:14639
+#: cp/pt.c:14661
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type %qT"
 msgid "forming pointer to reference type %qT"
 msgstr "обликовање %s на тип упућивача %qT"
 
-#: cp/pt.c:14641
+#: cp/pt.c:14663
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type %qT"
 msgid "forming reference to reference type %qT"
 msgstr "обликовање %s на тип упућивача %qT"
 
-#: cp/pt.c:14654
+#: cp/pt.c:14676
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring %qV qualifiers added to function type %qT"
 msgid "forming pointer to qualified function type %qT"
 msgstr "игнорисање %qV одредбе додате функцијском типу %qT"
 
-#: cp/pt.c:14657
+#: cp/pt.c:14679
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring %qV qualifiers added to function type %qT"
 msgid "forming reference to qualified function type %qT"
 msgstr "игнорисање %qV одредбе додате функцијском типу %qT"
 
-#: cp/pt.c:14705
+#: cp/pt.c:14727
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "стварање показивача на члан некласног типа %qT"
 
-#: cp/pt.c:14711
+#: cp/pt.c:14733
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "стварање показивача на члан упућивачког типа %qT"
 
-#: cp/pt.c:14717
+#: cp/pt.c:14739
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "стварање показивача на члан празног типа"
 
-#: cp/pt.c:14783
+#: cp/pt.c:14805
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "стварање низа типа %qT"
 
-#: cp/pt.c:14816
+#: cp/pt.c:14838
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT није тип класе, структуре, нити уније"
 
-#: cp/pt.c:14853
+#: cp/pt.c:14875
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT се разрешава до %qT, што није набројиви тип"
 
-#: cp/pt.c:14861
+#: cp/pt.c:14883
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr "%qT се разрешава до %qT, што није класни тип"
 
-#: cp/pt.c:14925
+#: cp/pt.c:14947
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.c:15000
+#: cp/pt.c:15022
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "употреба %qs у шаблону"
 
-#: cp/pt.c:15178
+#: cp/pt.c:15200
 #, fuzzy, gcc-internal-format
 #| msgid "qualified type %qT does not match destructor name ~%qT"
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "одређени тип %qT не поклапа се са именом деструктора ~%qT"
 
-#: cp/pt.c:15193
+#: cp/pt.c:15215
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "зависно име %qE рашчлањује се као не-тип, али извођење производи тип"
 
-#: cp/pt.c:15195
+#: cp/pt.c:15217
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "ставите %<typename %E%> ако мислите на тип"
 
-#: cp/pt.c:15394
+#: cp/pt.c:15416
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "употреба неисправног поља %qD"
 
-#: cp/pt.c:15883 cp/pt.c:17386
+#: cp/pt.c:15905 cp/pt.c:17408
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of void expression"
 msgid "invalid use of pack expansion expression"
 msgstr "неисправна употреба израза празног типа"
 
-#: cp/pt.c:15887 cp/pt.c:17390
+#: cp/pt.c:15909 cp/pt.c:17412
 #, fuzzy, gcc-internal-format
 #| msgid "%<...%> as arguments.)"
 msgid "use %<...%> to expand argument pack"
 msgstr "%<...%> за аргументе.)"
 
-#: cp/pt.c:18334
+#: cp/pt.c:18371
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:18362
+#: cp/pt.c:18399
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:18367
+#: cp/pt.c:18404
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.c:18370
+#: cp/pt.c:18407
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a type"
 msgid "use %<%T::%D%> instead"
 msgstr "%<%T::%D%> није тип"
 
-#: cp/pt.c:18375
+#: cp/pt.c:18412
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE undeclared here (not in a function)"
 msgid "%qD declared here, later in the translation unit"
 msgstr "%H%qE недекларисано овде (не у функцији)"
 
-#: cp/pt.c:18712
+#: cp/pt.c:18752
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT није ни класа ни именски простор"
 
-#: cp/pt.c:18715
+#: cp/pt.c:18755
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD није ни класа ни именски простор"
 
-#: cp/pt.c:19026
+#: cp/pt.c:19066
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is/uses anonymous type"
 msgid "%qT is/uses unnamed type"
 msgstr "%qT јесте/користи анонимни тип"
 
-#: cp/pt.c:19028
+#: cp/pt.c:19068
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "шаблонски аргумент за %qD користи локални тип %qT"
 
-#: cp/pt.c:19038
+#: cp/pt.c:19078
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT је променљиво измењив тип"
 
-#: cp/pt.c:19053
+#: cp/pt.c:19093
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "интегрални израз %qE није константа"
 
-#: cp/pt.c:19071
+#: cp/pt.c:19111
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  покушај извођења %qD"
 
-#: cp/pt.c:22972
+#: cp/pt.c:23050
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#T"
 msgstr "двосмислено извођење шаблона класе за %q#T"
 
-#: cp/pt.c:22974
+#: cp/pt.c:23052
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#D"
 msgstr "двосмислено извођење шаблона класе за %q#T"
 
-#: cp/pt.c:22980
+#: cp/pt.c:23058
 #, fuzzy
 #| msgid "%s %+#D"
 msgid "%s %#qS"
 msgstr "%s %+#D"
 
-#: cp/pt.c:23004 cp/pt.c:23091
+#: cp/pt.c:23082 cp/pt.c:23169
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "експлицитно извођење не-шаблона %q#D"
 
-#: cp/pt.c:23023
+#: cp/pt.c:23101
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D is not a non-static data member of %qT"
 msgid "%qD is not a static data member of a class template"
 msgstr "%q#D је нестатички члански податак у %qT"
 
-#: cp/pt.c:23029 cp/pt.c:23086
+#: cp/pt.c:23107 cp/pt.c:23164
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "поклапајући шаблон за %qD није нађен"
 
-#: cp/pt.c:23034
+#: cp/pt.c:23112
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type %qT"
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "експлицитно извођење нешаблонског типа %qT"
 
-#: cp/pt.c:23042
+#: cp/pt.c:23120
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "експлицитно извођење %q#D"
 
-#: cp/pt.c:23078
+#: cp/pt.c:23156
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "удвостручено експлицитно извођење %q#D"
 
-#: cp/pt.c:23101 cp/pt.c:23187
+#: cp/pt.c:23179 cp/pt.c:23265
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids the use of %<extern%> on explicit instantiations"
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ИСО Ц++ забрањује употребу %<extern%> на експлицитним извођењима"
 
-#: cp/pt.c:23106 cp/pt.c:23204
+#: cp/pt.c:23184 cp/pt.c:23282
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "складишна класа %qD примењена на извођење шаблона"
 
-#: cp/pt.c:23163
+#: cp/pt.c:23241
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template %q#D"
 msgid "explicit instantiation of non-class template %qD"
 msgstr "експлицитно извођење не-шаблона %q#D"
 
-#: cp/pt.c:23165
+#: cp/pt.c:23243
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "експлицитно извођење нешаблонског типа %qT"
 
-#: cp/pt.c:23174
+#: cp/pt.c:23252
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "експлицитно извођење %q#T пре дефиниције шаблона"
 
-#: cp/pt.c:23192
+#: cp/pt.c:23270
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ИСО Ц++ забрањује употребу %qE на експлицитним извођењима"
 
-#: cp/pt.c:23238
+#: cp/pt.c:23316
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "удвостручено експлицитно извођење %q#T"
 
-#: cp/pt.c:23536
+#: cp/pt.c:23614
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "exception specification of %qD depends on itself"
@@ -54167,119 +54211,119 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:23842
+#: cp/pt.c:23920
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "експлицитно извођење %qD али дефиниција није доступна"
 
-#: cp/pt.c:24043
+#: cp/pt.c:24121
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth-NN to increase the maximum)"
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr "дубина извођења шаблона премашује максимум од %d извођења %q+D, могуће услед стварања виртуелних табела (употребите -ftemplate-depth-NN да повећате максимум)"
 
-#: cp/pt.c:24418
+#: cp/pt.c:24496
 #, fuzzy, gcc-internal-format
 #| msgid "using template type parameter %qT after %qs"
 msgid "invalid template non-type parameter"
 msgstr "употреба параметра шаблонског типа %qT после %qs"
 
-#: cp/pt.c:24420
+#: cp/pt.c:24498
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a valid type for a template constant parameter"
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T није исправан тип за шаблонски константан параметар"
 
-#: cp/pt.c:25723
+#: cp/pt.c:25802
 #, fuzzy, gcc-internal-format
 #| msgid "keyword %<typename%> not allowed outside of templates"
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "кључна реч %<typename%> није дозвољена изван шаблона"
 
-#: cp/pt.c:25961
+#: cp/pt.c:26040
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/pt.c:26440
+#: cp/pt.c:26519
 #, fuzzy, gcc-internal-format
 #| msgid "non-template %qD used as template"
 msgid "non-class template %qT used without template arguments"
 msgstr "%qD употребљено као шаблон, а није"
 
-#: cp/pt.c:26586
+#: cp/pt.c:26665
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:26593
+#: cp/pt.c:26672
 #, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr ""
 
-#: cp/pt.c:26607
+#: cp/pt.c:26686
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "class template argument deduction failed:"
 msgstr "неисправан шаблонски аргумент %d"
 
-#: cp/pt.c:26614
+#: cp/pt.c:26693
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "функција се не разматра за уткивање"
 
-#: cp/pt.c:26676
+#: cp/pt.c:26755
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:26679
+#: cp/pt.c:26758
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:26711
+#: cp/pt.c:26790
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/pt.c:26746
+#: cp/pt.c:26825
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid method declaration, return type required"
 msgid "unable to deduce lambda return type from %qE"
 msgstr "Неисправна декларација метода, неопходан је повратни тип"
 
-#: cp/pt.c:26748
+#: cp/pt.c:26827
 #, fuzzy, gcc-internal-format
 #| msgid "unable to emulate %qs"
 msgid "unable to deduce %qT from %qE"
 msgstr "не могу да емулирам %qs"
 
-#: cp/pt.c:26781
+#: cp/pt.c:26860
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:26785
+#: cp/pt.c:26864
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "ија не задовољава своја ограничења:"
 
-#: cp/pt.c:26789
+#: cp/pt.c:26868
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "ија не задовољава своја ограничења:"
 
-#: cp/pt.c:26793
+#: cp/pt.c:26872
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "ија не задовољава своја ограничења:"
 
-#: cp/pt.c:26912
+#: cp/pt.c:26991
 #, fuzzy, gcc-internal-format
 #| msgid "use of %qs in template"
 msgid "invalid use of %qT in template argument"
@@ -54339,86 +54383,86 @@
 msgid "cannot dynamic_cast %qE (of type %q#T) to type %q#T (%s)"
 msgstr "не може се динамички претопити %qE (типа %q#T) у тип %q#T (%s)"
 
-#: cp/search.c:240
+#: cp/search.c:243
 #, gcc-internal-format
 msgid "%qT is an ambiguous base of %qT"
 msgstr "%qT је двосмислена основа за %qT"
 
-#: cp/search.c:256
+#: cp/search.c:259
 #, gcc-internal-format
 msgid "%qT is an inaccessible base of %qT"
 msgstr "%qT је неприступачна основа за %qT"
 
-#: cp/search.c:1905
+#: cp/search.c:1908
 #, fuzzy, gcc-internal-format
 #| msgid "invalid covariant return type for %q+#D"
 msgid "invalid covariant return type for %q#D"
 msgstr "неисправан коваријантни повратни тип за %q+#D"
 
-#: cp/search.c:1907 cp/search.c:1922 cp/search.c:1928 cp/search.c:1957
+#: cp/search.c:1910 cp/search.c:1925 cp/search.c:1931 cp/search.c:1960
 #, fuzzy, gcc-internal-format
 #| msgid "shadowing %s function %q#D"
 msgid "overridden function is %q#D"
 msgstr "заклањање %s функције %q#D"
 
-#: cp/search.c:1920
+#: cp/search.c:1923
 #, gcc-internal-format
 msgid "invalid covariant return type for %q+#D"
 msgstr "неисправан коваријантни повратни тип за %q+#D"
 
-#: cp/search.c:1926
+#: cp/search.c:1929
 #, gcc-internal-format
 msgid "conflicting return type specified for %q+#D"
 msgstr "сукобљен повратни тип наведен за %q+#D"
 
-#: cp/search.c:1942
+#: cp/search.c:1945
 #, gcc-internal-format
 msgid "looser throw specifier for %q+#F"
 msgstr "губитнички наводилац бацања за %q+#F"
 
-#: cp/search.c:1944
+#: cp/search.c:1947
 #, fuzzy, gcc-internal-format
 #| msgid "  overriding %q+#F"
 msgid "overridden function is %q#F"
 msgstr "  потискивање %q+#F"
 
-#: cp/search.c:1955
+#: cp/search.c:1958
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting return type specified for %q+#D"
 msgid "conflicting type attributes specified for %q+#D"
 msgstr "сукобљен повратни тип наведен за %q+#D"
 
-#: cp/search.c:1972
+#: cp/search.c:1975
 #, fuzzy, gcc-internal-format
 #| msgid "%qD was declared %<extern%> and later %<static%>"
 msgid "%qD declared %<transaction_safe_dynamic%>"
 msgstr "%qD је прво декларисано као %<extern%> а касније %<static%>"
 
-#: cp/search.c:1974
+#: cp/search.c:1977
 #, fuzzy, gcc-internal-format
 #| msgid "variable %q+D declared %<inline%>"
 msgid "overriding %qD declared %<transaction_safe%>"
 msgstr "променљива %q+D декларисана као %<inline%>"
 
-#: cp/search.c:1981
+#: cp/search.c:1984
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "deleted function %q+D overriding non-deleted function"
 msgstr "уграђена функција %q+D декларисана као нефункција"
 
-#: cp/search.c:1984 cp/search.c:1992 cp/search.c:2000
+#: cp/search.c:1987 cp/search.c:1995 cp/search.c:2003
 #, fuzzy, gcc-internal-format
 #| msgid "In function %qs:"
 msgid "overridden function is %qD"
 msgstr "У функцији %qs:"
 
-#: cp/search.c:1989
+#: cp/search.c:1992
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "non-deleted function %q+D overriding deleted function"
 msgstr "уграђена функција %q+D декларисана као нефункција"
 
-#: cp/search.c:1998
+#: cp/search.c:2001
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "virtual function %q+D overriding final function"
@@ -54426,12 +54470,12 @@
 
 #. A static member function cannot match an inherited
 #. virtual member function.
-#: cp/search.c:2082
+#: cp/search.c:2085
 #, gcc-internal-format
 msgid "%q+#D cannot be declared"
 msgstr "%q+#D се не може декларисати"
 
-#: cp/search.c:2083
+#: cp/search.c:2086
 #, gcc-internal-format
 msgid "  since %q+#D declared in base class"
 msgstr "  пошто је %q+#D декларисано у основној класи"
@@ -54475,158 +54519,158 @@
 msgid "invalid use of member %qD in static member function"
 msgstr "неисправна употреба члана %q+D у статичкој чланској функцији"
 
-#: cp/semantics.c:2153
+#: cp/semantics.c:2156
 #, gcc-internal-format
 msgid "a statement expression is an insufficient context for overload resolution"
 msgstr ""
 
-#: cp/semantics.c:2540
+#: cp/semantics.c:2543
 #, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr "аргументи нису дозвољени у деструктору"
 
-#: cp/semantics.c:2622
+#: cp/semantics.c:2625
 #, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr "%<this%> није доступно за статичке чланске функције"
 
-#: cp/semantics.c:2624
+#: cp/semantics.c:2627
 #, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr "неисправна употреба %<this%> у нечланској функцији"
 
-#: cp/semantics.c:2626
+#: cp/semantics.c:2629
 #, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr "неисправна употреба %<this%> на највишем нивоу"
 
-#: cp/semantics.c:2648
+#: cp/semantics.c:2651
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "неисправан одредбени досег у имену псеудодеструктора"
 
-#: cp/semantics.c:2656 cp/typeck.c:2604
+#: cp/semantics.c:2659 cp/typeck.c:2604
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "одређени тип %qT не поклапа се са именом деструктора ~%qT"
 
-#: cp/semantics.c:2678
+#: cp/semantics.c:2681
 #, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr "%qE није типа %qT"
 
-#: cp/semantics.c:2751
+#: cp/semantics.c:2754
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr "сложени дословни необјектног типа %qT"
 
-#: cp/semantics.c:2892
+#: cp/semantics.c:2895
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr "типски параметри шаблона морају користити кључну реч %<class%> или %<typename%>"
 
-#: cp/semantics.c:2942
+#: cp/semantics.c:2945
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr "неисправна употреба типа %qT као подразумеване вредности за шаблонски шаблонски параметар"
 
-#: cp/semantics.c:2945
+#: cp/semantics.c:2948
 #, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr "неисправан подразумевани аргумент за шаблонски шаблонски параметар"
 
-#: cp/semantics.c:2962
+#: cp/semantics.c:2965
 #, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr "дефиниција %q#T унутар листе шаблонских параметара"
 
-#: cp/semantics.c:2993
+#: cp/semantics.c:2996
 #, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr "неисправна дефиниција одређеног типа %qT"
 
-#: cp/semantics.c:3263
+#: cp/semantics.c:3266
 #, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "неисправан навод основне класе"
 
-#: cp/semantics.c:3423
+#: cp/semantics.c:3426
 #, fuzzy, gcc-internal-format
 #| msgid "protected member %q+#D in anonymous union"
 msgid "cannot capture member %qD of anonymous union"
 msgstr "заштићени члан %q+#D у анонимној унији"
 
-#: cp/semantics.c:3443 cp/semantics.c:9269
+#: cp/semantics.c:3446 cp/semantics.c:9272
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a type"
 msgid "%qD is not captured"
 msgstr "%qD није тип"
 
-#: cp/semantics.c:3448
+#: cp/semantics.c:3451
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.c:3450
+#: cp/semantics.c:3453
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.c:3462
+#: cp/semantics.c:3465
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<auto%> variable from containing function"
 msgid "use of local variable with automatic storage from containing function"
 msgstr "употреба %<auto%> променљиве из обухватајуће функције"
 
-#: cp/semantics.c:3464
+#: cp/semantics.c:3467
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr "употреба параметра из обухватајуће вункције"
 
-#: cp/semantics.c:3596
+#: cp/semantics.c:3599
 #, fuzzy, gcc-internal-format
 #| msgid "use of parameter from containing function"
 msgid "use of parameter outside function body"
 msgstr "употреба параметра из обухватајуће вункције"
 
-#: cp/semantics.c:3606
+#: cp/semantics.c:3609
 #, fuzzy, gcc-internal-format
 #| msgid "parse error in template argument list"
 msgid "missing template arguments"
 msgstr "грешка у рашчлањивању листе шаблонских аргумената"
 
-#: cp/semantics.c:3633
+#: cp/semantics.c:3636
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr "шаблонски параметар %qD типа %qT није дозвољен у интегралном константном изразу јер није интегралног или набројивог типа"
 
-#: cp/semantics.c:3664
+#: cp/semantics.c:3667
 #, gcc-internal-format
 msgid "use of namespace %qD as expression"
 msgstr "употреба именског простора %qD као израза"
 
-#: cp/semantics.c:3669
+#: cp/semantics.c:3672
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr "употреба шаблона класе %qT као израза"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:3675
+#: cp/semantics.c:3678
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "захтев за члан %qD двосмислен је у вишеструком снопу наслеђивања"
 
-#: cp/semantics.c:3702
+#: cp/semantics.c:3705
 #, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "%qD се не може јавити у константном изразу"
 
-#: cp/semantics.c:3841
+#: cp/semantics.c:3844
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "тип за %qE није познат"
 
-#: cp/semantics.c:3870
+#: cp/semantics.c:3873
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a template type"
 msgid "%qT is not an enumeration type"
@@ -54633,483 +54677,499 @@
 msgstr "%qT није шаблонски тип"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4009
+#: cp/semantics.c:4012
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specifiers invalid in parameter declarations"
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr "наводиоци складишне класе нису исправни у декларацијама параметара"
 
-#: cp/semantics.c:4038
+#: cp/semantics.c:4041
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr "не може се применити %<offsetof%> на деструктор %<~%T%>"
 
-#: cp/semantics.c:4052
+#: cp/semantics.c:4055
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "не може се применити %<offsetof%> на чланску функцију %qD"
 
-#: cp/semantics.c:4056
+#: cp/semantics.c:4059
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply %<offsetof%> to member function %qD"
 msgid "cannot apply %<offsetof%> to member function"
 msgstr "не може се применити %<offsetof%> на чланску функцију %qD"
 
-#: cp/semantics.c:4061
+#: cp/semantics.c:4064
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply %<offsetof%> to member function %qD"
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr "не може се применити %<offsetof%> на чланску функцију %qD"
 
-#: cp/semantics.c:4072
+#: cp/semantics.c:4075
 #, gcc-internal-format
 msgid "offsetof within non-standard-layout type %qT is conditionally-supported"
 msgstr ""
 
-#: cp/semantics.c:4583 cp/semantics.c:6069 cp/semantics.c:6140
-#: cp/semantics.c:6183 cp/semantics.c:6533 cp/semantics.c:6632
-#: cp/semantics.c:6775
+#: cp/semantics.c:4586 cp/semantics.c:6072 cp/semantics.c:6143
+#: cp/semantics.c:6186 cp/semantics.c:6536 cp/semantics.c:6635
+#: cp/semantics.c:6778
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5271
+#: cp/semantics.c:5274
 #, fuzzy, gcc-internal-format
 #| msgid "reference to %qD is ambiguous"
 msgid "user defined reduction lookup is ambiguous"
 msgstr "двосмислено упућивање на %qD"
 
-#: cp/semantics.c:5544
+#: cp/semantics.c:5547
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: cp/semantics.c:5592
+#: cp/semantics.c:5595
 #, fuzzy, gcc-internal-format
 #| msgid "%qE has invalid type for %<reduction%>"
 msgid "%qE has const type for %<reduction%>"
 msgstr "%qE има неисправан тип за %<reduction%>"
 
-#: cp/semantics.c:5707
+#: cp/semantics.c:5710
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:5941
+#: cp/semantics.c:5944
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5955
+#: cp/semantics.c:5958
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5977
+#: cp/semantics.c:5980
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "linear step expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.c:6080
+#: cp/semantics.c:6083
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD није променљива у одредби %qs"
 
-#: cp/semantics.c:6152
+#: cp/semantics.c:6155
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %<firstprivate%>"
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "%qE није променљива у одредби %<firstprivate%>"
 
-#: cp/semantics.c:6195
+#: cp/semantics.c:6198
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %<lastprivate%>"
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "%qE није променљива у одредби %<lastprivate%>"
 
-#: cp/semantics.c:6240
+#: cp/semantics.c:6243
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<gang%> static expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.c:6254
+#: cp/semantics.c:6257
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<gang%> static value must be positive"
 msgstr "вредност %<num_threads%> мора бити позитивна"
 
-#: cp/semantics.c:6288
+#: cp/semantics.c:6291
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<gang%> num expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.c:6291
+#: cp/semantics.c:6294
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<vector%> length expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.c:6295
+#: cp/semantics.c:6298
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<worker%> num expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.c:6317
+#: cp/semantics.c:6320
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<gang%> num value must be positive"
 msgstr "вредност %<num_threads%> мора бити позитивна"
 
-#: cp/semantics.c:6321
+#: cp/semantics.c:6324
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<vector%> length value must be positive"
 msgstr "вредност %<num_threads%> мора бити позитивна"
 
-#: cp/semantics.c:6326
+#: cp/semantics.c:6329
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<worker%> num value must be positive"
 msgstr "вредност %<num_threads%> мора бити позитивна"
 
-#: cp/semantics.c:6376
+#: cp/semantics.c:6379
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr "израз за величину одломка при распоређивању мора бити интегрални"
 
-#: cp/semantics.c:6406
+#: cp/semantics.c:6409
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%qs length expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.c:6419
+#: cp/semantics.c:6422
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "листа израза %s узима се као сложени израз"
 
-#: cp/semantics.c:6438
+#: cp/semantics.c:6441
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<async%> expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.c:6466
+#: cp/semantics.c:6469
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<thread_limit%> expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.c:6495
+#: cp/semantics.c:6498
 #, fuzzy, gcc-internal-format
 #| msgid "%<continue%> must be in loop"
 msgid "%<device%> id must be integral"
 msgstr "%<continue%> мора бити у оквиру петље"
 
-#: cp/semantics.c:6516
+#: cp/semantics.c:6519
 #, fuzzy, gcc-internal-format
 #| msgid "schedule chunk size expression must be integral"
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr "израз за величину одломка при распоређивању мора бити интегрални"
 
-#: cp/semantics.c:6543
+#: cp/semantics.c:6546
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qD није променљива у одредби %qs"
 
-#: cp/semantics.c:6557
+#: cp/semantics.c:6560
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:6563
+#: cp/semantics.c:6566
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr "%qD се појављује више од једном у одредбама података"
 
-#: cp/semantics.c:6576
+#: cp/semantics.c:6579
 #, fuzzy, gcc-internal-format
 #| msgid "schedule chunk size expression must be integral"
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr "израз за величину одломка при распоређивању мора бити интегрални"
 
-#: cp/semantics.c:6625
+#: cp/semantics.c:6628
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr "%qD није променљива у одредби %qs"
 
-#: cp/semantics.c:6910
+#: cp/semantics.c:6913
 #, fuzzy, gcc-internal-format
 #| msgid "reimplementation of class %qs"
 msgid "template %qE in clause %qs"
 msgstr "поновљена имплементација класе %qs"
 
-#: cp/semantics.c:6914
+#: cp/semantics.c:6917
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6979
+#: cp/semantics.c:6982
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<grainsize%> expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.c:7008
+#: cp/semantics.c:7011
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<priority%> expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.c:7037
+#: cp/semantics.c:7040
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<num_tasks%> expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.c:7066
+#: cp/semantics.c:7069
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:7105
+#: cp/semantics.c:7108
 #, fuzzy, gcc-internal-format
 #| msgid "%<tree%> is not defined as a pointer type"
 msgid "%<tile%> argument needs integral type"
 msgstr "%<tree%> није дефинисано као показивачки тип"
 
-#: cp/semantics.c:7524
+#: cp/semantics.c:7527
 #, fuzzy, gcc-internal-format
 #| msgid "%<threadprivate%> %qE is not file, namespace or block scope variable"
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr "%<threadprivate%> %qE није датотека, именски простор нити променљива блоковског досега"
 
-#: cp/semantics.c:7538
+#: cp/semantics.c:7541
 #, fuzzy, gcc-internal-format
 #| msgid "%<threadprivate%> %qE has incomplete type"
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "нитно-локално %qE има непотпун тип"
 
-#: cp/semantics.c:7743
+#: cp/semantics.c:7746
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.c:8171
+#: cp/semantics.c:8174
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid type for iteration variable %qE"
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr "%Hнеисправан тип променљиве итерације %qE"
 
-#: cp/semantics.c:8398 cp/semantics.c:8408
+#: cp/semantics.c:8401 cp/semantics.c:8411
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.c:8702
+#: cp/semantics.c:8705
 #, fuzzy, gcc-internal-format
 #| msgid "CRIS-port assertion failed: "
 msgid "static assertion failed"
 msgstr "Тврдња КРИС-порта није прошла: "
 
-#: cp/semantics.c:8704
+#: cp/semantics.c:8707
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CRIS-port assertion failed: "
 msgid "static assertion failed: %s"
 msgstr "Тврдња КРИС-порта није прошла: "
 
-#: cp/semantics.c:8709
+#: cp/semantics.c:8712
 #, fuzzy, gcc-internal-format
 #| msgid "non-static declaration of %q+D follows static declaration"
 msgid "non-constant condition for static assertion"
 msgstr "нестатичка декларација %q+D прати статичку декларацију"
 
-#: cp/semantics.c:8739
+#: cp/semantics.c:8742
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgid "argument to decltype must be an expression"
 msgstr "Аргумент наредбе SELECT код %L мора бити скаларни израз"
 
-#: cp/semantics.c:8767
+#: cp/semantics.c:8770
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "decltype cannot resolve address of overloaded function"
 msgstr "%s не може да разреши адресу препуњене функције"
 
-#: cp/semantics.c:9308
+#: cp/semantics.c:9311
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "леви операнд зарез-израза нема ефекта"
 
-#: cp/semantics.c:9361
+#: cp/semantics.c:9364
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %qE involves template parameter(s)"
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "шаблонски аргумент %qE уплиће шаблонске параметре"
 
-#: cp/semantics.c:9363
+#: cp/semantics.c:9366
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:9381
+#: cp/semantics.c:9384
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %<__builtin_return_address%>"
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "неподржан аргумент за %<__builtin_return_address%>"
 
-#: cp/tree.c:1276
+#: cp/tree.c:1295
 #, gcc-internal-format
 msgid "%qV qualifiers cannot be applied to %qT"
 msgstr "%qV одредбе не могу се применити на %qT"
 
-#: cp/tree.c:1788
+#: cp/tree.c:1807
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "lambda-expression in a constant expression"
 msgstr "Лош тип у константном изразу"
 
-#: cp/tree.c:1792
+#: cp/tree.c:1811
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "statement-expression in a constant expression"
 msgstr "Лош тип у константном изразу"
 
-#: cp/tree.c:4050
+#: cp/tree.c:4083
 #, gcc-internal-format
-msgid "the calling convention for %qT changes in -fabi-version=12 (GCC 8)"
+msgid "-fabi-version=13 (GCC 8.2) fixes the calling convention for %qT, which was accidentally changed in 8.1"
 msgstr ""
 
-#: cp/tree.c:4055
+#: cp/tree.c:4087
 #, gcc-internal-format
+msgid "-fabi-version=12 (GCC 8.1) accidentally changes the calling convention for %qT"
+msgstr ""
+
+#: cp/tree.c:4090
+#, fuzzy, gcc-internal-format
+#| msgid "%q+D declared here"
+msgid " declared here"
+msgstr "%q+D декларисано овде"
+
+#: cp/tree.c:4094
+#, gcc-internal-format
+msgid "the calling convention for %qT changes in -fabi-version=13 (GCC 8.2)"
+msgstr ""
+
+#: cp/tree.c:4096
+#, gcc-internal-format
 msgid " because all of its copy and move constructors are deleted"
 msgstr ""
 
-#: cp/tree.c:4416
+#: cp/tree.c:4464
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to function types"
 msgid "%qE attribute applied to %qD with void return type"
 msgstr "атрибут %qs је примењив само на функцијске типове"
 
-#: cp/tree.c:4423
+#: cp/tree.c:4471
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr "атрибут %qE може се применити само на дефиниције класа"
 
-#: cp/tree.c:4475
+#: cp/tree.c:4523
 #, gcc-internal-format
 msgid "requested init_priority is not an integer constant"
 msgstr "захтевано init_priority није целобројна константа"
 
-#: cp/tree.c:4497
+#: cp/tree.c:4545
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr "атрибут %qE може се користити само уз дефиниције објеката класног типа у датотечном досегу"
 
-#: cp/tree.c:4505
+#: cp/tree.c:4553
 #, gcc-internal-format
 msgid "requested init_priority is out of range"
 msgstr "захтевано init_priority је ван опсега"
 
-#: cp/tree.c:4515
+#: cp/tree.c:4563
 #, gcc-internal-format
 msgid "requested init_priority is reserved for internal use"
 msgstr "захтевано init_priority резервисано је за унутрашњу употребу"
 
-#: cp/tree.c:4526
+#: cp/tree.c:4574
 #, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr "атрибут %qE није подржан на овој платформи"
 
-#: cp/tree.c:4553
+#: cp/tree.c:4601
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as %s"
 msgid "redeclaration of %qD adds abi tag %qE"
 msgstr "декларација %qD као %s"
 
-#: cp/tree.c:4573
+#: cp/tree.c:4621
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires a single NTBS argument"
 msgid "the %qE attribute requires arguments"
 msgstr "атрибут %qs захтева тачно један НТБС аргумент"
 
-#: cp/tree.c:4584
+#: cp/tree.c:4632
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "аргумент атрибута %qs није константна ниска"
 
-#: cp/tree.c:4597 cp/tree.c:4610
+#: cp/tree.c:4645 cp/tree.c:4658
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "аргумент атрибута %qs није константна ниска"
 
-#: cp/tree.c:4599
+#: cp/tree.c:4647
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a valid declarator"
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "%<%T::%D%> није исправан декларатор"
 
-#: cp/tree.c:4612
+#: cp/tree.c:4660
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a valid declarator"
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "%<%T::%D%> није исправан декларатор"
 
-#: cp/tree.c:4636
+#: cp/tree.c:4684
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "атрибут %qE се игнорише на не-класним типовима"
 
-#: cp/tree.c:4642
+#: cp/tree.c:4690
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "атрибут %qE може се применити само на дефиниције класа"
 
-#: cp/tree.c:4649
+#: cp/tree.c:4697
 #, fuzzy, gcc-internal-format
 #| msgid "attributes ignored on template instantiation"
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "атрибут се игнорише при извођењу шаблона"
 
-#: cp/tree.c:4656
+#: cp/tree.c:4704
 #, fuzzy, gcc-internal-format
 #| msgid "attributes ignored on template instantiation"
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "атрибут се игнорише при извођењу шаблона"
 
-#: cp/tree.c:4678
+#: cp/tree.c:4726
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qE attribute applies only to functions"
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "%Jатрибут %qE примењује се само на функције"
 
-#: cp/tree.c:4684
+#: cp/tree.c:4732
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qE attribute applies only to functions"
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "%Jатрибут %qE примењује се само на функције"
 
-#: cp/tree.c:5440
+#: cp/tree.c:5488
 #, fuzzy, gcc-internal-format
 #| msgid "array bound is not an integer constant"
 msgid "zero as null pointer constant"
 msgstr "граница низа није целобројна константа"
 
-#: cp/tree.c:5453
+#: cp/tree.c:5501
 #, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr "провера lang_*: крах у %s, код %s:%d"
@@ -56323,114 +56383,114 @@
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "скупина типа %qT не може се успостављати сложеном константном"
 
-#: cp/typeck2.c:1496 cp/typeck2.c:1523
+#: cp/typeck2.c:1499 cp/typeck2.c:1526
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "недостаје успостављач за члан %qD"
 
-#: cp/typeck2.c:1504
+#: cp/typeck2.c:1507
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "члан %qD је неуспостављен упућивач"
 
-#: cp/typeck2.c:1511
+#: cp/typeck2.c:1514
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD is uninitialized reference"
 msgid "member %qD with uninitialized reference fields"
 msgstr "члан %qD је неуспостављен упућивач"
 
-#: cp/typeck2.c:1587
+#: cp/typeck2.c:1590
 #, fuzzy, gcc-internal-format
 #| msgid "prototype for %q#D does not match any in class %qT"
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "прототип за %q#D не одговара ниједном у класи %qT"
 
-#: cp/typeck2.c:1660
+#: cp/typeck2.c:1663
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "поље %qD није нађено у унији која се успоставља"
 
-#: cp/typeck2.c:1671
+#: cp/typeck2.c:1674
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "индексна вредност уместо имена поља у успостављачу уније"
 
-#: cp/typeck2.c:1858
+#: cp/typeck2.c:1861
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "откривено кружно прослеђивање показивача"
 
-#: cp/typeck2.c:1872
+#: cp/typeck2.c:1875
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "основни операнд за %<->%> непоказивачког је типа %qT"
 
-#: cp/typeck2.c:1898
+#: cp/typeck2.c:1901
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "%<operator->()%> производи непоказивачки резултат"
 
-#: cp/typeck2.c:1900
+#: cp/typeck2.c:1903
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "основни операнд за %<->%> није показивач"
 
-#: cp/typeck2.c:1927
+#: cp/typeck2.c:1930
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE се не може користити као члански показивач, пошто је типа %qT"
 
-#: cp/typeck2.c:1936
+#: cp/typeck2.c:1939
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "члански показивач %qE не може се применити на %qE, које је некласног типа %qT"
 
-#: cp/typeck2.c:1958
+#: cp/typeck2.c:1961
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "тип показивача на члан %qT није сагласан са типом објекта %qT"
 
-#: cp/typeck2.c:2018
+#: cp/typeck2.c:2021
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "показивач на чланску функцију употребљен у аритметици"
 
-#: cp/typeck2.c:2029
+#: cp/typeck2.c:2032
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "показивач на чланску функцију употребљен у аритметици"
 
-#: cp/typeck2.c:2037
+#: cp/typeck2.c:2040
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++2a"
 msgstr ""
 
-#: cp/typeck2.c:2080
+#: cp/typeck2.c:2083
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type %qT"
 msgid "functional cast to array type %qT"
 msgstr "неисправно претапање у функцијски тип %qT"
 
-#: cp/typeck2.c:2096
+#: cp/typeck2.c:2099
 #, fuzzy, gcc-internal-format
 #| msgid "got %d template parameters for %q#T"
 msgid "cannot deduce template arguments for %qT from ()"
 msgstr "добих %d шаблонских параметара за %q#T"
 
-#: cp/typeck2.c:2114
+#: cp/typeck2.c:2117
 #, fuzzy, gcc-internal-format
 #| msgid "%Jdefault-initialization of %q#D, which has reference type"
 msgid "invalid value-initialization of reference type"
 msgstr "%Jподразумевано успостављање %q#D, које је упућивачког типа"
 
-#: cp/typeck2.c:2341
+#: cp/typeck2.c:2344
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "позив функције %qD која баца непотпун тип %q#T"
 
-#: cp/typeck2.c:2344
+#: cp/typeck2.c:2347
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "позив функције која баца непотпун тип %q#T"
@@ -56658,11 +56718,11 @@
 msgstr "Упућивач низа код %C не може имати више од %d димензија"
 
 #: fortran/array.c:221 fortran/array.c:661 fortran/check.c:2849
-#: fortran/check.c:5222 fortran/check.c:5260 fortran/check.c:5302
-#: fortran/check.c:5329 fortran/check.c:5529 fortran/match.c:1821
+#: fortran/check.c:5225 fortran/check.c:5263 fortran/check.c:5305
+#: fortran/check.c:5332 fortran/check.c:5532 fortran/match.c:1821
 #: fortran/match.c:3174 fortran/match.c:3516 fortran/match.c:3712
-#: fortran/simplify.c:2909 fortran/simplify.c:2939 fortran/simplify.c:5764
-#: fortran/simplify.c:7658
+#: fortran/simplify.c:2909 fortran/simplify.c:2939 fortran/simplify.c:5769
+#: fortran/simplify.c:7663
 #, gcc-internal-format
 msgid "Coarrays disabled at %C, use %<-fcoarray=%> to enable"
 msgstr ""
@@ -56808,127 +56868,133 @@
 msgid "DO-iterator %qs at %L is inside iterator of the same name"
 msgstr "DO-итератор ‘%s’ код %L је унутар истоименог итератора"
 
-#: fortran/array.c:1073 fortran/array.c:1255
+#: fortran/array.c:1073 fortran/array.c:1264
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in array constructor at %C"
 msgstr "Синтаксна грешка у конструктору низа код %C"
 
-#: fortran/array.c:1129
+#: fortran/array.c:1105
 #, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "ENTRY statement at %C cannot appear in a contained procedure"
+msgid "NULL() at %C cannot appear in an array constructor"
+msgstr "Наредба ENTRY код %C не може бити у садржаној процедури"
+
+#: fortran/array.c:1138
+#, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "New in Fortran 2003: [...] style array constructors at %C"
 msgid "[...] style array constructors at %C"
 msgstr "Ново у фортрану 2003: [...] конструктори низа код %C"
 
-#: fortran/array.c:1149
+#: fortran/array.c:1158
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in character length specification at %C"
 msgid "Array constructor including type specification at %C"
 msgstr "Синтаксна грешка у одредници знаковне дужине код %C"
 
-#: fortran/array.c:1155 fortran/match.c:4148
+#: fortran/array.c:1164 fortran/match.c:4148
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Type-spec at %L cannot contain a deferred type parameter"
 msgstr "Низ ‘%s’ код %L не може имати одложен облик"
 
-#: fortran/array.c:1163
+#: fortran/array.c:1172
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-spec at %L cannot contain an asterisk for a type parameter"
 msgstr ""
 
-#: fortran/array.c:1181
+#: fortran/array.c:1190
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty array constructor at %C is not allowed"
 msgstr "Празан конструктор низа код %C није дозвољен"
 
-#: fortran/array.c:1218 fortran/array.c:1228
+#: fortran/array.c:1227 fortran/array.c:1237
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Incompatible type for array. %s convert %qs to %qs"
 msgid "Incompatible typespec for array element at %L"
 msgstr "Несагласан тип за низ. %s претварање %qs у %qs"
 
-#: fortran/array.c:1302
+#: fortran/array.c:1311
 #, gcc-internal-format, gfc-internal-format
 msgid "Element in %s array constructor at %L is %s"
 msgstr "Елемент у конструктору низа %s код %L је %s"
 
-#: fortran/array.c:1633
+#: fortran/array.c:1642
 #, gcc-internal-format, gfc-internal-format
 msgid "Iterator step at %L cannot be zero"
 msgstr "Корак итератора код %L не може бити нула"
 
-#: fortran/array.c:1770
+#: fortran/array.c:1779
 #, gcc-internal-format
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit.   See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/array.c:1940
+#: fortran/array.c:1949
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "expression reference type error at %L"
 msgid "AC-IMPLIED-DO initial expression references control variable at %L"
 msgstr "грешка типа упућивача израза код %L"
 
-#: fortran/array.c:1947
+#: fortran/array.c:1956
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "expression reference type error at %L"
 msgid "AC-IMPLIED-DO final expression references control variable at %L"
 msgstr "грешка типа упућивача израза код %L"
 
-#: fortran/array.c:1954
+#: fortran/array.c:1963
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "expression reference type error at %L"
 msgid "AC-IMPLIED-DO step expression references control variable at %L"
 msgstr "грешка типа упућивача израза код %L"
 
-#: fortran/array.c:1966
+#: fortran/array.c:1975
 #, gcc-internal-format, gfc-internal-format
 msgid "Array constructor value at %L shall not be unlimited polymorphic [F2008: C4106]"
 msgstr ""
 
-#: fortran/array.c:2055
+#: fortran/array.c:2067
 #, gcc-internal-format, gfc-internal-format
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor at %L"
 msgstr ""
 
-#: fortran/array.c:2174
+#: fortran/array.c:2186
 #, gcc-internal-format
 msgid "spec_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2233
+#: fortran/array.c:2245
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2237
+#: fortran/array.c:2249
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad array reference at %L"
 msgid "Bad array dimension at %L"
 msgstr "Лош упућивач низа код %L"
 
-#: fortran/array.c:2264 fortran/data.c:552 fortran/data.c:571
-#: fortran/data.c:585 fortran/data.c:714
+#: fortran/array.c:2276 fortran/data.c:563 fortran/data.c:582
+#: fortran/data.c:596 fortran/data.c:725
 #, fuzzy, gcc-internal-format
 #| msgid "gimplification failed"
 msgid "Simplification error"
 msgstr "гимплификација није успела"
 
-#: fortran/array.c:2376
+#: fortran/array.c:2388
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimen_type"
 msgstr ""
 
-#: fortran/array.c:2427
+#: fortran/array.c:2439
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2472
+#: fortran/array.c:2484
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad EXPR_ARRAY expr"
 msgstr ""
 
-#: fortran/array.c:2620
+#: fortran/array.c:2632
 #, gcc-internal-format
 msgid "gfc_find_array_ref(): No ref found"
 msgstr ""
@@ -56987,7 +57053,7 @@
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or PROCEDURE"
 msgstr "Аргумент ‘%s’ сопственог ‘%s’ код %L мора бити целобројан или процедура"
 
-#: fortran/check.c:205 fortran/check.c:6658
+#: fortran/check.c:205 fortran/check.c:6661
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a constant"
 msgid "%qs argument of %qs intrinsic at %L must be a constant"
@@ -57122,7 +57188,7 @@
 msgid "Unequal character lengths (%ld/%ld) in %s at %L"
 msgstr "Различите знаковне дужине у додели показивача код %L"
 
-#: fortran/check.c:946 fortran/check.c:6602
+#: fortran/check.c:946 fortran/check.c:6605
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' and '%s' arguments of '%s' intrinsic at %L must have the same type"
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have the same type"
@@ -57380,9 +57446,9 @@
 msgstr "Аргумент ‘%s’ сопственог ‘%s’ код %L мора бити ранга 1 или 2"
 
 #: fortran/check.c:1939 fortran/check.c:2525 fortran/check.c:2628
-#: fortran/check.c:2835 fortran/check.c:2880 fortran/check.c:4256
-#: fortran/check.c:4390 fortran/check.c:4445 fortran/check.c:5515
-#: fortran/check.c:5644
+#: fortran/check.c:2835 fortran/check.c:2880 fortran/check.c:4259
+#: fortran/check.c:4393 fortran/check.c:4448 fortran/check.c:5518
+#: fortran/check.c:5647
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "%qs intrinsic with KIND argument at %L"
@@ -57609,7 +57675,7 @@
 msgid "NULL intrinsic with allocatable MOLD at %L"
 msgstr ""
 
-#: fortran/check.c:3768 fortran/check.c:5591
+#: fortran/check.c:3768 fortran/check.c:5594
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be the same type and kind as '%s'"
 msgid "%qs argument of %qs intrinsic at %L must provide at least as many elements as there are .TRUE. values in %qs (%ld/%d)"
@@ -57633,405 +57699,405 @@
 msgid "%qs argument of %qs intrinsic at %L must not be a subobject of %qs"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L не сме бити подобјекат од ‘%s’"
 
-#: fortran/check.c:3901
+#: fortran/check.c:3904
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a variable"
 msgid "The argument of the RANK intrinsic at %L must be a data object"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити променљива"
 
-#: fortran/check.c:4005
+#: fortran/check.c:4008
 #, fuzzy, gcc-internal-format
 #| msgid "'shape' argument of 'reshape' intrinsic at %L must be an array of constant size"
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L must be an array of constant size"
 msgstr "Аргумент ‘shape’ сопственог ‘reshape’ код %L мора бити низ константне величине"
 
-#: fortran/check.c:4015
+#: fortran/check.c:4018
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be %s"
 msgid "%qs argument of %qs intrinsic at %L is empty"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити %s"
 
-#: fortran/check.c:4022
+#: fortran/check.c:4025
 #, fuzzy, gcc-internal-format
 #| msgid "'shape' argument of 'reshape' intrinsic at %L has more than %d elements"
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L has more than %d elements"
 msgstr "Аргумент ‘shape’ сопственог ‘reshape’ код %L има више од %d елемената"
 
-#: fortran/check.c:4039
+#: fortran/check.c:4042
 #, fuzzy, gcc-internal-format
 #| msgid "'a%d' argument of '%s' intrinsic at %L must be %s(%d)"
 msgid "%qs argument of %qs intrinsic at %L has negative element (%d)"
 msgstr "Аргумент ‘a%d’ сопственог ‘%s’ код %L мора бити %s(%d)"
 
-#: fortran/check.c:4071
+#: fortran/check.c:4074
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Second argument of NEAREST at %L shall not be zero"
 msgid "Element %d of actual argument of RESHAPE at %L cannot be negative"
 msgstr "Други аргумент у NEAREST код %L не може бити нула"
 
-#: fortran/check.c:4109
+#: fortran/check.c:4112
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be of rank %d"
 msgid "%qs argument of %qs intrinsic at %L has wrong number of elements (%d/%d)"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити ранга %d"
 
-#: fortran/check.c:4127
+#: fortran/check.c:4130
 #, fuzzy, gcc-internal-format
 #| msgid "'dim' argument of %s intrinsic at %L is not a valid dimension index"
 msgid "%qs argument of %qs intrinsic at %L has out-of-range dimension (%d)"
 msgstr "Аргумент ‘dim’ за сопствено ‘%s’ код %L није исправан димензиони индекс"
 
-#: fortran/check.c:4136
+#: fortran/check.c:4139
 #, fuzzy, gcc-internal-format
 #| msgid "'dim' argument of %s intrinsic at %L is not a valid dimension index"
 msgid "%qs argument of %qs intrinsic at %L has invalid permutation of dimensions (dimension %qd duplicated)"
 msgstr "Аргумент ‘dim’ за сопствено ‘%s’ код %L није исправан димензиони индекс"
 
-#: fortran/check.c:4172
+#: fortran/check.c:4175
 #, gcc-internal-format, gfc-internal-format
 msgid "Without padding, there are not enough elements in the intrinsic RESHAPE source at %L to match the shape"
 msgstr "Без уметања нема довољно елемената да подрже облик у сопственом RESHAPE код %L"
 
-#: fortran/check.c:4189 fortran/check.c:4208
+#: fortran/check.c:4192 fortran/check.c:4211
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be %s"
 msgid "%qs argument of %qs intrinsic at %L cannot be of type %s"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити %s"
 
-#: fortran/check.c:4199 fortran/check.c:4218
+#: fortran/check.c:4202 fortran/check.c:4221
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a numeric type"
 msgid "%qs argument of %qs intrinsic at %L must be of an extensible type"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити бројевног типа"
 
-#: fortran/check.c:4317
+#: fortran/check.c:4320
 #, gcc-internal-format
 msgid "SELECTED_REAL_KIND with neither %<P%> nor %<R%> argument at %L"
 msgstr ""
 
-#: fortran/check.c:4348
+#: fortran/check.c:4351
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "%qs intrinsic with RADIX argument at %L"
 msgstr "Атрибут %s коси се са атрибутом %s код %L"
 
-#: fortran/check.c:4383
+#: fortran/check.c:4386
 #, fuzzy, gcc-internal-format
 #| msgid "'source' argument of 'shape' intrinsic at %L must not be an assumed size array"
 msgid "%<source%> argument of %<shape%> intrinsic at %L must not be an assumed size array"
 msgstr "Аргумент ‘source’ сопственог ‘shape’ код %L не сме бити низ претпостављене величине"
 
-#: fortran/check.c:4460 fortran/check.c:6641
+#: fortran/check.c:4463 fortran/check.c:6644
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a scalar"
 msgid "%qs argument of %qs intrinsic at %L shall not be a procedure"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити скалар"
 
-#: fortran/check.c:4473 fortran/check.c:4612 fortran/check.c:6633
+#: fortran/check.c:4476 fortran/check.c:4615 fortran/check.c:6636
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L cannot be INTENT(IN)"
 msgid "%qs argument of %qs intrinsic at %L shall not be TYPE(*)"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L не може бити намере-у"
 
-#: fortran/check.c:4484 fortran/check.c:4624
+#: fortran/check.c:4487 fortran/check.c:4627
 #, fuzzy, gcc-internal-format
 #| msgid "'source' argument of 'shape' intrinsic at %L must not be an assumed size array"
 msgid "%qs argument of %qs intrinsic at %L shall not be an assumed-size array"
 msgstr "Аргумент ‘source’ сопственог ‘shape’ код %L не сме бити низ претпостављене величине"
 
-#: fortran/check.c:4554
+#: fortran/check.c:4557
 #, gcc-internal-format
 msgid "is_c_interoperable(): gfc_simplify_expr failed"
 msgstr ""
 
-#: fortran/check.c:4603
+#: fortran/check.c:4606
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a non-derived type"
 msgid "%qs argument of %qs intrinsic at %L must be an interoperable data entity: %s"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити неизведени тип"
 
-#: fortran/check.c:4642
+#: fortran/check.c:4645
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_1 at %L to C_ASSOCIATED shall have the type TYPE(C_PTR) or TYPE(C_FUNPTR)"
 msgstr ""
 
-#: fortran/check.c:4656
+#: fortran/check.c:4659
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_2 at %L to C_ASSOCIATED shall have the same type as C_PTR_1: %s instead of %s"
 msgstr ""
 
-#: fortran/check.c:4680
+#: fortran/check.c:4683
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_POINTER shall have the type TYPE(C_PTR)"
 msgstr ""
 
-#: fortran/check.c:4692
+#: fortran/check.c:4695
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument dim at %L must be scalar"
 msgid "Argument FPTR at %L to C_F_POINTER must be a pointer"
 msgstr "Аргумент димензије код %L мора бити скалар"
 
-#: fortran/check.c:4699
+#: fortran/check.c:4702
 #, gcc-internal-format, gfc-internal-format
 msgid "FPTR argument at %L to C_F_POINTER shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:4706
+#: fortran/check.c:4709
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:4713
+#: fortran/check.c:4716
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected SHAPE argument at %L to C_F_POINTER with scalar FPTR"
 msgstr ""
 
-#: fortran/check.c:4719
+#: fortran/check.c:4722
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected SHAPE argument to C_F_POINTER with array FPTR at %L"
 msgstr ""
 
-#: fortran/check.c:4738
+#: fortran/check.c:4741
 #, gcc-internal-format, gfc-internal-format
 msgid "SHAPE argument at %L to C_F_POINTER must have the same size as the RANK of FPTR"
 msgstr ""
 
-#: fortran/check.c:4748
+#: fortran/check.c:4751
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic FPTR at %L to C_F_POINTER"
 msgstr ""
 
-#: fortran/check.c:4753
+#: fortran/check.c:4756
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array FPTR at %L to C_F_POINTER: %s"
 msgstr ""
 
-#: fortran/check.c:4769
+#: fortran/check.c:4772
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_PROCPOINTER shall have the type TYPE(C_FUNPTR)"
 msgstr ""
 
-#: fortran/check.c:4781
+#: fortran/check.c:4784
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall be a procedure pointer"
 msgstr ""
 
-#: fortran/check.c:4788
+#: fortran/check.c:4791
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:4794
+#: fortran/check.c:4797
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure pointer at %L to C_F_PROCPOINTER"
 msgstr ""
 
-#: fortran/check.c:4808
+#: fortran/check.c:4811
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:4823
+#: fortran/check.c:4826
 #, gcc-internal-format
 msgid "Function result %qs at %L is invalid as X argument to C_FUNLOC"
 msgstr ""
 
-#: fortran/check.c:4831
+#: fortran/check.c:4834
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall be a procedure or a procedure pointer"
 msgstr ""
 
-#: fortran/check.c:4837
+#: fortran/check.c:4840
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "User operator procedure '%s' at %L must be a FUNCTION"
 msgid "Noninteroperable procedure at %L to C_FUNLOC"
 msgstr "Процедура корисничког оператора ‘%s’ код %L мора бити функција"
 
-#: fortran/check.c:4851
+#: fortran/check.c:4854
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:4857
+#: fortran/check.c:4860
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Second argument of NEAREST at %L shall not be zero"
 msgid "X argument at %L to C_LOC shall not be polymorphic"
 msgstr "Други аргумент у NEAREST код %L не може бити нула"
 
-#: fortran/check.c:4868
+#: fortran/check.c:4871
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Component at %C must have the POINTER attribute"
 msgid "Argument X at %L to C_LOC shall have either the POINTER or the TARGET attribute"
 msgstr "Компонента код %C мора имати атрибут показивача"
 
-#: fortran/check.c:4876
+#: fortran/check.c:4879
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall be not be a zero-sized string"
 msgstr ""
 
-#: fortran/check.c:4885
+#: fortran/check.c:4888
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument at %L to C_LOC shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:4892
+#: fortran/check.c:4895
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array at %L as argument to C_LOC: %s"
 msgstr ""
 
-#: fortran/check.c:4903
+#: fortran/check.c:4906
 #, gcc-internal-format, gfc-internal-format
 msgid "Array of interoperable type at %L to C_LOC which is nonallocatable and neither assumed size nor explicit size"
 msgstr ""
 
-#: fortran/check.c:4908
+#: fortran/check.c:4911
 #, gcc-internal-format, gfc-internal-format
 msgid "Array section at %L to C_LOC"
 msgstr ""
 
-#: fortran/check.c:4936
+#: fortran/check.c:4939
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing arguments to %s intrinsic at %L"
 msgid "non double precision REAL argument to %s intrinsic at %L"
 msgstr "Недостају аргументи за сопствено %s код %L"
 
-#: fortran/check.c:4949
+#: fortran/check.c:4952
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be less than rank %d"
 msgid "%qs argument of %qs intrinsic at %L must be less than rank %d"
 msgstr "Аргумент ‘%s’ сопственог ‘%s’ код %L мора бити мање ранга од %d"
 
-#: fortran/check.c:4968
+#: fortran/check.c:4971
 #, fuzzy, gcc-internal-format
 #| msgid "'dim' argument of %s intrinsic at %L is not a valid dimension index"
 msgid "%qs argument of %qs intrinsic at %L is not a valid dimension index"
 msgstr "Аргумент ‘dim’ за сопствено ‘%s’ код %L није исправан димензиони индекс"
 
-#: fortran/check.c:5231
+#: fortran/check.c:5234
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "%s argument to IMAGE_INDEX must be a rank one array at %L"
 msgstr "Стварни аргумент за ‘%s’ код %L мора бити показивач"
 
-#: fortran/check.c:5242
+#: fortran/check.c:5245
 #, gcc-internal-format, gfc-internal-format
 msgid "The number of array elements of the SUB argument to IMAGE_INDEX at %L shall be %d (corank) not %d"
 msgstr ""
 
-#: fortran/check.c:5275
+#: fortran/check.c:5278
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to NUM_IMAGES at %L"
 msgstr ""
 
-#: fortran/check.c:5288
+#: fortran/check.c:5291
 #, gcc-internal-format, gfc-internal-format
 msgid "FAILED= argument to NUM_IMAGES at %L"
 msgstr ""
 
-#: fortran/check.c:5312
+#: fortran/check.c:5315
 #, gcc-internal-format, gfc-internal-format
 msgid "TEAM argument at %L to the intrinsic TEAM_NUMBER shall be of type TEAM_TYPE"
 msgstr ""
 
-#: fortran/check.c:5338
+#: fortran/check.c:5341
 #, gcc-internal-format, gfc-internal-format
 msgid "DIM argument without COARRAY argument not allowed for THIS_IMAGE intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:5345
+#: fortran/check.c:5348
 #, gcc-internal-format, gfc-internal-format
 msgid "The DISTANCE argument may not be specified together with the COARRAY or DIM argument in intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:5356
+#: fortran/check.c:5359
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk in formal argument list at %C"
 msgid "Unexpected DIM argument with noncoarray argument at %L"
 msgstr "Неочекивано смеће у формалној листи аргумената код %C"
 
-#: fortran/check.c:5374
+#: fortran/check.c:5377
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to THIS_IMAGE at %L"
 msgstr ""
 
-#: fortran/check.c:5454
+#: fortran/check.c:5457
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be %s"
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L must not be %s"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити %s"
 
-#: fortran/check.c:5483
+#: fortran/check.c:5486
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic TRANSFER at %L has partly undefined result: source size %ld < result size %ld"
 msgstr ""
 
-#: fortran/check.c:5605
+#: fortran/check.c:5608
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be the same kind as '%s'"
 msgid "%qs argument of %qs intrinsic at %L must have the same rank as %qs or be a scalar"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити исте врсте као ‘%s’"
 
-#: fortran/check.c:5618
+#: fortran/check.c:5621
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' and '%s' arguments of '%s' intrinsic at %L must have the same type"
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have identical shape."
 msgstr "Аргументи ‘%s’ и ‘%s’ сопственог ‘%s’ код %L морају бити истог типа"
 
-#: fortran/check.c:5861 fortran/check.c:5893
+#: fortran/check.c:5864 fortran/check.c:5896
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be %s"
 msgid "Size of %qs argument of %qs intrinsic at %L too small (%i/%i)"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити %s"
 
-#: fortran/check.c:5901
+#: fortran/check.c:5904
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many arguments to %s at %L"
 msgstr "Превише аргумената за %s код %L"
 
-#: fortran/check.c:5919
+#: fortran/check.c:5922
 #, gcc-internal-format
 msgid "fe_runtime_error string must be null terminated"
 msgstr ""
 
-#: fortran/check.c:5931
+#: fortran/check.c:5934
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "fe_runtime_error: Wrong number of arguments (%d instead of %d)"
 msgstr "погрешан број шаблонских аргумената ((%d, а треба %d)"
 
-#: fortran/check.c:5971
+#: fortran/check.c:5974
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:5990
+#: fortran/check.c:5993
 #, gcc-internal-format, gfc-internal-format
 msgid "Real COUNT_RATE argument to SYSTEM_CLOCK at %L"
 msgstr ""
 
-#: fortran/check.c:6000
+#: fortran/check.c:6003
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT_RATE argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:6017
+#: fortran/check.c:6020
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT_MAX argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:6234
+#: fortran/check.c:6237
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be of kind %d"
 msgid "%qs argument of %qs intrinsic at %L must be of a kind not wider than the default kind (%d)"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити врсте %d"
 
-#: fortran/check.c:6586 fortran/check.c:6594
+#: fortran/check.c:6589 fortran/check.c:6597
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be INTEGER or LOGICAL"
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or LOGICAL"
 msgstr "Аргумент ‘%s’ сопственог ‘%s’ код %L мора бити целобројан или логички"
 
-#: fortran/check.c:6625
+#: fortran/check.c:6628
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic function NULL at %L cannot be an actual argument to STORAGE_SIZE, because it returns a disassociated pointer"
 msgstr ""
@@ -58043,7 +58109,7 @@
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:727 fortran/decl.c:3636 fortran/decl.c:10066
+#: fortran/class.c:727 fortran/decl.c:3655 fortran/decl.c:10091
 #, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr ""
@@ -58071,47 +58137,53 @@
 msgid "non-constant array in DATA statement %L"
 msgstr "неконстантан низа у наредби DATA %L."
 
-#: fortran/data.c:137
+#: fortran/data.c:140
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "failure to simplify substring reference in DATAstatement at %L"
 msgid "failure to simplify substring reference in DATA statement at %L"
 msgstr "неуспех у упрошћавању упућивача подниске у наредби DATA код %L"
 
-#: fortran/data.c:170
+#: fortran/data.c:173
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "initialization string truncated to match variable at %L"
 msgid "Unused initialization string at %L because variable has zero length"
 msgstr "успостављачка ниска подсечена да одговара променљивој код %L"
 
-#: fortran/data.c:176
+#: fortran/data.c:179
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "initialization string truncated to match variable at %L"
 msgid "Initialization string at %L was truncated to fit the variable (%ld/%ld)"
 msgstr "успостављачка ниска подсечена да одговара променљивој код %L"
 
-#: fortran/data.c:265
+#: fortran/data.c:268
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %C is already defined at %L"
 msgid "%qs at %L already is initialized at %L"
 msgstr "Процедура ‘%s’ код %C већ је дефинисана код %L"
 
-#: fortran/data.c:289
+#: fortran/data.c:292
 #, gcc-internal-format, gfc-internal-format
 msgid "Data element below array lower bound at %L"
 msgstr ""
 
-#: fortran/data.c:306 fortran/data.c:395
+#: fortran/data.c:309 fortran/data.c:398
 #, gcc-internal-format, gfc-internal-format
 msgid "Data element above array upper bound at %L"
 msgstr ""
 
-#: fortran/data.c:336 fortran/data.c:505
+#: fortran/data.c:339 fortran/data.c:496
 #, fuzzy, gcc-internal-format
 #| msgid "Extension: re-initialization of '%s' at %L"
 msgid "re-initialization of %qs at %L"
 msgstr "Проширење: реуспостављање ‘%s’ код %L"
 
-#: fortran/data.c:727
+#: fortran/data.c:515
+#, fuzzy, gcc-internal-format
+#| msgid "Variable '%s' at %C with an initializer already appears in a DATA statement"
+msgid "Nonpointer object %qs with default initialization shall not appear in a DATA statement at %L"
+msgstr "Променљива ‘%s’ код %C са успостављачем већ се појављује у наредби DATA"
+
+#: fortran/data.c:738
 #, gcc-internal-format
 msgid "TODO: Vector sections in data statements"
 msgstr ""
@@ -58140,850 +58212,850 @@
 msgid "Invalid initializer %s in Data statement at %C"
 msgstr "Неисправна успостављачка наредба"
 
-#: fortran/decl.c:536
+#: fortran/decl.c:537
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C is not allowed in a PURE procedure"
 msgstr "Успостављање код %C није дозвољено у чистој процедури"
 
-#: fortran/decl.c:573
+#: fortran/decl.c:574
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgid "DATA statement at %C cannot appear within an INTERFACE"
 msgstr "Наредба ENTRY код %C не може бити унутар INTERFACE"
 
-#: fortran/decl.c:597
+#: fortran/decl.c:598
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Nonconstant array section at %L in DATA statement"
 msgid "Invalid substring in data-implied-do at %L in DATA statement"
 msgstr "Неконстантан одељак низа код %L у наредби DATA"
 
-#: fortran/decl.c:619
+#: fortran/decl.c:620
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %C is not allowed in a PURE procedure"
 msgstr "Наредба DATA код %C није дозвољена у чистој процедури"
 
-#: fortran/decl.c:664
+#: fortran/decl.c:662
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Old-style initialization at %C"
 msgid "Empty old style initializer list at %C"
 msgstr "Проширење: Старовремско успостављање код %C"
 
-#: fortran/decl.c:684
+#: fortran/decl.c:671
 #, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "Array component of structure at %C must have an explicit shape"
+msgid "Array in initializer list at %L must have an explicit shape"
+msgstr "Низовна компонента структуре код %C мора имати експлицитан облик"
+
+#: fortran/decl.c:694
+#, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "extra elements in scalar initializer"
 msgid "Repeat spec invalid in scalar initializer at %C"
 msgstr "сувишни елементи у скаларном инцијализатору"
 
-#: fortran/decl.c:689
+#: fortran/decl.c:699
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Cray pointer at %C must be an integer."
 msgid "Repeat spec must be an integer at %C"
 msgstr "Крејов показивач код %C мора бити целобројни."
 
-#: fortran/decl.c:698
+#: fortran/decl.c:710
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected alternate return label at %C"
 msgid "Expected data constant after repeat spec at %C"
 msgstr "Очекивана је етикета алтернативног повратка код %C"
 
-#: fortran/decl.c:729
+#: fortran/decl.c:742
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected scalar initialization expression at %C"
 msgid "End of scalar initializer expected at %C"
 msgstr "Очекиван је скаларни успостављачки израз код %C"
 
-#: fortran/decl.c:758
+#: fortran/decl.c:773
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "nonconstant array index in initializer"
-msgid "Expected constant array-spec in initializer list at %L"
-msgstr "неконстантан индекс низа у успостављачу"
-
-#: fortran/decl.c:767
-#, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "excess elements in array initializer"
 msgid "Not enough elements in array initializer at %C"
 msgstr "сувишни елементи у успостављачу низа"
 
-#: fortran/decl.c:769
+#: fortran/decl.c:775
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "excess elements in array initializer"
 msgid "Too many elements in array initializer at %C"
 msgstr "сувишни елементи у успостављачу низа"
 
-#: fortran/decl.c:790
+#: fortran/decl.c:795
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in OpenMP variable list at %C"
 msgid "Syntax error in old style initializer list at %C"
 msgstr "Синтаксна грешка у ОпенМП листи аргумената код %C"
 
-#: fortran/decl.c:812
+#: fortran/decl.c:821
 #, gcc-internal-format, gfc-internal-format
 msgid "The assumed-rank array at %C shall not have a codimension"
 msgstr ""
 
-#: fortran/decl.c:876
+#: fortran/decl.c:885
 #, gcc-internal-format, gfc-internal-format
 msgid "Sum of array rank %d and corank %d at %C exceeds maximum allowed dimensions of %d"
 msgstr ""
 
-#: fortran/decl.c:900
+#: fortran/decl.c:909
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad INTENT specification at %C"
 msgstr "Лоша одредница намере код %C"
 
-#: fortran/decl.c:921
+#: fortran/decl.c:930
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "using template type parameter %qT after %qs"
 msgid "deferred type parameter at %C"
 msgstr "употреба параметра шаблонског типа %qT после %qs"
 
-#: fortran/decl.c:1004 fortran/resolve.c:11705
+#: fortran/decl.c:1013 fortran/resolve.c:11725
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
 
-#: fortran/decl.c:1030
+#: fortran/decl.c:1039
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Illegal character in BOZ constant at %C"
 msgid "Old-style character length at %C"
 msgstr "Недозвољени знак у БОЗ константи код %C"
 
-#: fortran/decl.c:1061
+#: fortran/decl.c:1070
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in character length specification at %C"
 msgstr "Синтаксна грешка у одредници знаковне дужине код %C"
 
-#: fortran/decl.c:1212 fortran/decl.c:1217 fortran/decl.c:1266
+#: fortran/decl.c:1221 fortran/decl.c:1226 fortran/decl.c:1275
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %C is already defined at %L"
 msgid "Procedure %qs at %C is already defined at %L"
 msgstr "Процедура ‘%s’ код %C већ је дефинисана код %L"
 
-#: fortran/decl.c:1222
+#: fortran/decl.c:1231
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %C is already defined at %L"
 msgid "Contained procedure %qs at %C clashes with procedure defined at %L"
 msgstr "Процедура ‘%s’ код %C већ је дефинисана код %L"
 
-#: fortran/decl.c:1231
+#: fortran/decl.c:1240
 #, fuzzy, gcc-internal-format
 #| msgid "Global name '%s' at %L is already being used as a %s at %L"
 msgid "Name %qs at %C is already defined as a generic interface at %L"
 msgstr "Глобално име ‘%s’ код %L се већ користи као %s код %L"
 
-#: fortran/decl.c:1244
+#: fortran/decl.c:1253
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %C has an explicit interface and must not have attributes declared at %L"
 msgid "Procedure %qs at %C has an explicit interface from a previous declaration"
 msgstr "Процедура ‘%s’ код %C има експлицитно сучеље и не може имати атрибуте декларисане код %L"
 
-#: fortran/decl.c:1257
+#: fortran/decl.c:1266
 #, gcc-internal-format
 msgid "Procedure %qs defined in interface body at %L clashes with internal procedure defined at %C"
 msgstr ""
 
-#: fortran/decl.c:1335
+#: fortran/decl.c:1344
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgid "Procedure %qs at %L must have the BIND(C) attribute to be C interoperable"
 msgstr "Променљива изведеног типа ‘%s’ код %L мора имати атрибут SEQUENCE да би била објекат еквиваленције"
 
-#: fortran/decl.c:1362
+#: fortran/decl.c:1371
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because derived type %qs is not C interoperable"
 msgstr ""
 
-#: fortran/decl.c:1369
+#: fortran/decl.c:1378
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because it is polymorphic"
 msgstr ""
 
-#: fortran/decl.c:1376
+#: fortran/decl.c:1385
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument of the BIND(C) procedure %qs but may not be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:1391
+#: fortran/decl.c:1400
 #, gcc-internal-format
 msgid "Character argument %qs at %L must be length 1 because procedure %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1404
+#: fortran/decl.c:1413
 #, gcc-internal-format
 msgid "Variable %qs at %L with ALLOCATABLE attribute in procedure %qs with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1412
+#: fortran/decl.c:1421
 #, gcc-internal-format
 msgid "Variable %qs at %L with POINTER attribute in procedure %qs with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1421
+#: fortran/decl.c:1430
 #, gcc-internal-format
 msgid "Scalar variable %qs at %L with POINTER or ALLOCATABLE in procedure %qs with BIND(C) is not yet supported"
 msgstr ""
 
-#: fortran/decl.c:1430
+#: fortran/decl.c:1439
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the OPTIONAL and the VALUE attribute because procedure %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1437
+#: fortran/decl.c:1446
 #, gcc-internal-format
 msgid "Variable %qs at %L with OPTIONAL attribute in procedure %qs which is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1448
+#: fortran/decl.c:1457
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-shape array %qs at %L as dummy argument to the BIND(C) procedure %qs at %L"
 msgstr "Низ претпостављеног облика код %L мора бити лажни аргумент"
 
-#: fortran/decl.c:1516
+#: fortran/decl.c:1525
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L cannot have a type"
 msgid "Symbol %qs at %C also declared as a type at %L"
 msgstr "Симбол ‘%s’ код %L не може имати тип"
 
-#: fortran/decl.c:1575
+#: fortran/decl.c:1584
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %C must be declared with a C interoperable kind since common block %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1615
+#: fortran/decl.c:1624
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER length must be a constant at %L"
 msgstr ""
 
-#: fortran/decl.c:1630
+#: fortran/decl.c:1639
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CHARACTER expression at %L is being truncated (%d/%d)"
 msgid "CHARACTER expression at %L is being truncated (%ld/%ld)"
 msgstr "Знаковни израз код %L бива подсечен (%d/%d)"
 
-#: fortran/decl.c:1638
+#: fortran/decl.c:1647
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The CHARACTER elements of the array constructor at %L must have the same length (%d/%d)"
 msgid "The CHARACTER elements of the array constructor at %L must have the same length (%ld/%ld)"
 msgstr "Знаковни елементи конструктора низа код %L морају имати исту дужину (%d/%d)"
 
-#: fortran/decl.c:1729
+#: fortran/decl.c:1738
 #, fuzzy, gcc-internal-format
 #| msgid "Initializer not allowed for PARAMETER '%s' at %C"
 msgid "Initializer not allowed for PARAMETER %qs at %C"
 msgstr "Успостављач није дозвољен за параметар ‘%s’ код %C"
 
-#: fortran/decl.c:1739
+#: fortran/decl.c:1748
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER at %L is missing an initializer"
 msgstr "Недостаје успостављач за параметар код %L"
 
-#: fortran/decl.c:1749
+#: fortran/decl.c:1758
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %C with an initializer already appears in a DATA statement"
 msgid "Variable %qs at %C with an initializer already appears in a DATA statement"
 msgstr "Променљива ‘%s’ код %C са успостављачем већ се појављује у наредби DATA"
 
-#: fortran/decl.c:1792
+#: fortran/decl.c:1801
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot initialize parameter array at %L with variable length elements"
 msgstr ""
 
-#: fortran/decl.c:1861
+#: fortran/decl.c:1870
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot initialize multi-dimensional array with initializer"
 msgid "Can't initialize implied-shape array at %L with scalar"
 msgstr "у успостављачу се не могу успостављати вишедимензиони низови"
 
-#: fortran/decl.c:1896
+#: fortran/decl.c:1905
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in data declaration at %C"
 msgid "Non-constant lower bound in implied-shape declaration at %L"
 msgstr "Синтаксна грешка у декларацији података код %C"
 
-#: fortran/decl.c:1982 fortran/decl.c:1989
+#: fortran/decl.c:1991 fortran/decl.c:1998
 #, gcc-internal-format, gfc-internal-format
 msgid "Component at %C must have the POINTER attribute"
 msgstr "Компонента код %C мора имати атрибут показивача"
 
-#: fortran/decl.c:1998
+#: fortran/decl.c:2007
 #, gcc-internal-format
 msgid "Component %qs with CLASS at %C must be allocatable or pointer"
 msgstr ""
 
-#: fortran/decl.c:2007
+#: fortran/decl.c:2016
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr "Низовна компонента структуре код %C мора имати експлицитан или одложени облик"
 
-#: fortran/decl.c:2031 fortran/symbol.c:2230
+#: fortran/decl.c:2040 fortran/symbol.c:2244
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C already declared at %L"
 msgid "Component %qs at %C already declared at %L"
 msgstr "Компонента ‘%s’ код %C већ је декларисана код %L"
 
-#: fortran/decl.c:2079
+#: fortran/decl.c:2088
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer array component of structure at %C must have a deferred shape"
 msgstr "Показивачка низовна компонента структуре код %C мора имати одложен облик"
 
-#: fortran/decl.c:2088
+#: fortran/decl.c:2097
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component of structure at %C must have a deferred shape"
 msgstr "Резервљива компонента структуре код %C мора имати одложен облик"
 
-#: fortran/decl.c:2097
+#: fortran/decl.c:2106
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have an explicit shape"
 msgstr "Низовна компонента структуре код %C мора имати експлицитан облик"
 
-#: fortran/decl.c:2114
+#: fortran/decl.c:2123
 #, fuzzy, gcc-internal-format
 #| msgid "a parameter list with an ellipsis can%'t match an empty parameter name list declaration"
 msgid "Type parameter %qs at %C has no corresponding entry in the type parameter name list at %L"
 msgstr "листа параметара са тротачком не може поклопити декларацију празне листе имена параметара"
 
-#: fortran/decl.c:2171
+#: fortran/decl.c:2180
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C is ambiguous"
 msgstr "Двосмислено успостављање NULL() код %C"
 
-#: fortran/decl.c:2188
+#: fortran/decl.c:2197
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "NULL() initialization at %C is ambiguous"
 msgid "NULL() initialization at %C may not have MOLD"
 msgstr "Двосмислено успостављање NULL() код %C"
 
-#: fortran/decl.c:2205
+#: fortran/decl.c:2214
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of pointer at %C is not allowed in a PURE procedure"
 msgstr "Успостављање показивача код %C није дозвољена у чистој процедури"
 
-#: fortran/decl.c:2226
+#: fortran/decl.c:2235
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Old-style initialization at %C"
 msgid "Error in pointer initialization at %C"
 msgstr "Проширење: Старовремско успостављање код %C"
 
-#: fortran/decl.c:2233
+#: fortran/decl.c:2242
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Old-style initialization at %C"
 msgid "non-NULL pointer initialization at %C"
 msgstr "Проширење: Старовремско успостављање код %C"
 
-#: fortran/decl.c:2256
+#: fortran/decl.c:2265
 #, gcc-internal-format
 msgid "RESULT variable %qs at %L prohibits FUNCTION name %qs at %C from appearing in a specification statement"
 msgstr ""
 
-#: fortran/decl.c:2318
+#: fortran/decl.c:2327
 #, gcc-internal-format
 msgid "%qs not allowed outside STRUCTURE at %C"
 msgstr ""
 
-#: fortran/decl.c:2320
+#: fortran/decl.c:2329
 #, gcc-internal-format
 msgid "%qs at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr ""
 
-#: fortran/decl.c:2327
+#: fortran/decl.c:2336
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "%qs entity cannot have attributes at %C"
 msgstr "Атрибут %s коси се са атрибутом %s код %L"
 
-#: fortran/decl.c:2367
+#: fortran/decl.c:2376
 #, gcc-internal-format
 msgid "Non-PARAMETER symbol %qs at %L can't be implied-shape"
 msgstr ""
 
-#: fortran/decl.c:2377
+#: fortran/decl.c:2386
 #, gcc-internal-format, gfc-internal-format
 msgid "Implied-shape array at %L"
 msgstr ""
 
-#: fortran/decl.c:2422
+#: fortran/decl.c:2431
 #, gcc-internal-format, gfc-internal-format
 msgid "Explicit shaped array with nonconstant bounds at %C"
 msgstr ""
 
-#: fortran/decl.c:2501
+#: fortran/decl.c:2510
 #, gcc-internal-format
 msgid "%qs at %C is a redefinition of the declaration in the corresponding interface for MODULE PROCEDURE %qs"
 msgstr ""
 
-#: fortran/decl.c:2512
+#: fortran/decl.c:2521
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "%qs entity cannot have an initializer at %C"
 msgstr "Лажно ‘%s’ код %L не може имати успостављач"
 
-#: fortran/decl.c:2538 fortran/decl.c:8369
+#: fortran/decl.c:2547 fortran/decl.c:8388
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate array spec for Cray pointee at %C."
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr "Удвостручена одредница низа за Крејов показиваног код %C."
 
-#: fortran/decl.c:2546
+#: fortran/decl.c:2555
 #, gcc-internal-format
 msgid "Couldn't set pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:2609
+#: fortran/decl.c:2618
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Old-style initialization at %C"
 msgid "Old-style initialization at %C"
 msgstr "Проширење: Старовремско успостављање код %C"
 
-#: fortran/decl.c:2617
+#: fortran/decl.c:2626
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr "неисправно успостављање упућивача типа %qT изразом типа %qT"
 
-#: fortran/decl.c:2630
+#: fortran/decl.c:2639
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Old-style initialization at %C"
 msgid "Syntax error in old style initialization of %s at %C"
 msgstr "Проширење: Старовремско успостављање код %C"
 
-#: fortran/decl.c:2650 fortran/decl.c:6661
+#: fortran/decl.c:2659 fortran/decl.c:6680
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr "Успостављање код %C није за показивачку променљиву"
 
-#: fortran/decl.c:2663
+#: fortran/decl.c:2672
 #, fuzzy, gcc-internal-format
 #| msgid "Pointer initialization at %C requires '=>', not '='"
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr "Успостављање показивача код %C захтева ‘=>’, не ‘=’"
 
-#: fortran/decl.c:2672 fortran/decl.c:10240
+#: fortran/decl.c:2681 fortran/decl.c:10265
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr "Очекиван је успостављачки израз код %C"
 
-#: fortran/decl.c:2679
+#: fortran/decl.c:2688
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr "Успостављање променљиве код %C није дозвољена у чистој процедури"
 
-#: fortran/decl.c:2696
+#: fortran/decl.c:2705
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr "Успостављање резервљиве компоненте код %C није дозвољено"
 
-#: fortran/decl.c:2710
+#: fortran/decl.c:2719
 #, gcc-internal-format, gfc-internal-format
 msgid "The component with KIND or LEN attribute at %C does not not appear in the type parameter list at %L"
 msgstr ""
 
-#: fortran/decl.c:2718
+#: fortran/decl.c:2727
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C that appears in the type parameter list at %L has neither the KIND nor LEN attribute"
 msgstr ""
 
-#: fortran/decl.c:2726
+#: fortran/decl.c:2735
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The pointer component '%s' of '%s' at %L is a type that has not been declared"
 msgid "The component at %C which is a type parameter must be a scalar"
 msgstr "Показивачка компонента ‘%s’ у ‘%s’ код %L припада типу који није декларисан"
 
-#: fortran/decl.c:2789 fortran/decl.c:2825
+#: fortran/decl.c:2798 fortran/decl.c:2834
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr "Старовремска декларација типа %s*%d није подржана код %C"
 
-#: fortran/decl.c:2831
+#: fortran/decl.c:2840
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr "Нестандардна декларација типа %s*%d код %C"
 
-#: fortran/decl.c:2890 fortran/decl.c:2967
+#: fortran/decl.c:2899 fortran/decl.c:2976
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing right paren at %C"
 msgid "Missing right parenthesis at %C"
 msgstr "Недостаје лева заграда код %C"
 
-#: fortran/decl.c:2903 fortran/decl.c:3038
+#: fortran/decl.c:2912 fortran/decl.c:3047
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr "Очекиван је успостављачки израз код %C"
 
-#: fortran/decl.c:2911 fortran/decl.c:3044
+#: fortran/decl.c:2920 fortran/decl.c:3053
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr "Очекиван је скаларни успостављачки израз код %C"
 
-#: fortran/decl.c:2941 fortran/decl.c:3657
+#: fortran/decl.c:2950 fortran/decl.c:3676
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr "Врста %d није подржана за тип %s код %C"
 
-#: fortran/decl.c:2954
+#: fortran/decl.c:2963
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Different kind type parameters in pointer assignment at %L"
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr "Различите врсте типова параметара у додели показивача код %L"
 
-#: fortran/decl.c:2965
+#: fortran/decl.c:2974
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing right paren at %C"
 msgid "Missing right parenthesis or comma at %C"
 msgstr "Недостаје лева заграда код %C"
 
-#: fortran/decl.c:3070
+#: fortran/decl.c:3079
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Kind %d not supported for type %s at %C"
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr "Врста %d није подржана за тип %s код %C"
 
-#: fortran/decl.c:3202
+#: fortran/decl.c:3211
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr "Синтаксна грешка у декларацији CHARACTER код %C"
 
-#: fortran/decl.c:3291
+#: fortran/decl.c:3310
 #, gcc-internal-format, gfc-internal-format
 msgid "RECORD at %C is an extension, enable it with -fdec-structure"
 msgstr ""
 
-#: fortran/decl.c:3304
+#: fortran/decl.c:3323
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected after RECORD at %C"
 msgstr ""
 
-#: fortran/decl.c:3417
+#: fortran/decl.c:3436
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C cannot contain both ASSUMED and DEFERRED parameters"
 msgstr ""
 
-#: fortran/decl.c:3441
+#: fortran/decl.c:3460
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C does not contain enough parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3465
+#: fortran/decl.c:3484
 #, gcc-internal-format
 msgid "The derived parameter %qs at %C does not have a default value"
 msgstr ""
 
-#: fortran/decl.c:3497
+#: fortran/decl.c:3516
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression at %L must be of INTEGER type"
 msgid "The parameter expression at %C must be of INTEGER type and not %s type"
 msgstr "Израз код %L мора бити целобројног типа"
 
-#: fortran/decl.c:3525
+#: fortran/decl.c:3544
 #, gcc-internal-format
 msgid "The KIND parameter %qs at %C cannot either be ASSUMED or DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:3532
+#: fortran/decl.c:3551
 #, fuzzy, gcc-internal-format
 #| msgid "KIND parameter of %s at %L must be an initialization expression"
 msgid "The value for the KIND parameter %qs at %C does not reduce to a constant expression"
 msgstr "Параметар врсте за %s код %L мора бити инцијализовани израз"
 
-#: fortran/decl.c:3547
+#: fortran/decl.c:3566
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C contains too many parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3556
+#: fortran/decl.c:3575
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "reference to %qD is ambiguous"
 msgid "Parameterized derived type at %C is ambiguous"
 msgstr "двосмислено упућивање на %qD"
 
-#: fortran/decl.c:3819
+#: fortran/decl.c:3838
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: BYTE type at %C"
 msgid "BYTE type at %C"
 msgstr "Проширење: тип BYTE код %C"
 
-#: fortran/decl.c:3824
+#: fortran/decl.c:3843
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr "Тип BYTE употребљен код %C није доступан на циљној машини"
 
-#: fortran/decl.c:3846
+#: fortran/decl.c:3865
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument list function at %L is not allowed in this context"
 msgid "Assumed type at %C is not allowed for components"
 msgstr "Функција листе аргумената код %L није дозвољена у овом контексту"
 
-#: fortran/decl.c:3849
+#: fortran/decl.c:3868
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr ""
 
-#: fortran/decl.c:3872 fortran/decl.c:3903 fortran/decl.c:3932
-#: fortran/decl.c:4216
+#: fortran/decl.c:3891 fortran/decl.c:3922 fortran/decl.c:3951
+#: fortran/decl.c:4235
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr ""
 
-#: fortran/decl.c:3928
+#: fortran/decl.c:3947
 #, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr ""
 
-#: fortran/decl.c:3971 fortran/decl.c:4107 fortran/decl.c:4119
-#: fortran/decl.c:4133 fortran/decl.c:4611 fortran/decl.c:4619
+#: fortran/decl.c:3990 fortran/decl.c:4126 fortran/decl.c:4138
+#: fortran/decl.c:4152 fortran/decl.c:4630 fortran/decl.c:4638
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C is ambiguous"
 msgid "Type name %qs at %C is ambiguous"
 msgstr "Двосмислено име типа ‘%s’ код %C"
 
-#: fortran/decl.c:4066
+#: fortran/decl.c:4085
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected CASE statement at %C"
 msgid "CLASS statement at %C"
 msgstr "Неочекивана наредба CASE код %C"
 
-#: fortran/decl.c:4148
+#: fortran/decl.c:4167
 #, gcc-internal-format
 msgid "Type name %qs at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr ""
 
-#: fortran/decl.c:4287
+#: fortran/decl.c:4306
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr "Удвостручена наредба IMPLICIT NONE код %C"
 
-#: fortran/decl.c:4296
+#: fortran/decl.c:4315
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr ""
 
-#: fortran/decl.c:4355
+#: fortran/decl.c:4374
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr "Недостаје знаковни опсег за имплицитно код %C"
 
-#: fortran/decl.c:4401
+#: fortran/decl.c:4420
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr "Слова морају бити у алфабетском поретку у наредби IMPLICIT код %C"
 
-#: fortran/decl.c:4454
+#: fortran/decl.c:4473
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "SAVE statement at %C follows blanket SAVE statement"
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr "Наредба SAVE код %C прати покривачку наредбу SAVE"
 
-#: fortran/decl.c:4464
+#: fortran/decl.c:4483
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr "Празна наредба IMPLICIT код %C"
 
-#: fortran/decl.c:4570
+#: fortran/decl.c:4589
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr "Наредба ENTRY код %C не може бити унутар INTERFACE"
 
-#: fortran/decl.c:4577
+#: fortran/decl.c:4596
 #, gcc-internal-format, gfc-internal-format
 msgid "F2008: C1210 IMPORT statement at %C is not permitted in a module procedure interface body"
 msgstr ""
 
-#: fortran/decl.c:4582
+#: fortran/decl.c:4601
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "IMPORT statement at %C"
 msgstr "Празна наредба IMPLICIT код %C"
 
-#: fortran/decl.c:4596
+#: fortran/decl.c:4615
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting %s statement at %C"
 msgid "Expecting list of named entities at %C"
 msgstr "Очекивана је наредба %s код %C"
 
-#: fortran/decl.c:4625
+#: fortran/decl.c:4644
 #, gcc-internal-format
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr ""
 
-#: fortran/decl.c:4632
+#: fortran/decl.c:4651
 #, gcc-internal-format
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr ""
 
-#: fortran/decl.c:4673
+#: fortran/decl.c:4692
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in %s statement at %C"
 msgid "Syntax error in IMPORT statement at %C"
 msgstr "Синтаксна грешка у наредби %s код %C"
 
-#: fortran/decl.c:5010
+#: fortran/decl.c:5029
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing dimension specification at %C"
 msgid "Missing codimension specification at %C"
 msgstr "Недостаје одредница димензија код %C"
 
-#: fortran/decl.c:5012
+#: fortran/decl.c:5031
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr "Недостаје одредница димензија код %C"
 
-#: fortran/decl.c:5107
+#: fortran/decl.c:5126
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr "Удвостручени атрибут %s код %L"
 
-#: fortran/decl.c:5124
+#: fortran/decl.c:5143
 #, gcc-internal-format
 msgid "%s at %L is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:5141
+#: fortran/decl.c:5160
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr "Атрибут код %L није дозвољен у дефиницији типа"
 
-#: fortran/decl.c:5150
+#: fortran/decl.c:5169
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "KIND attribute at %C in a TYPE definition"
 msgstr "Атрибут код %L није дозвољен у дефиницији типа"
 
-#: fortran/decl.c:5158
+#: fortran/decl.c:5177
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be INTEGER"
 msgstr ""
 
-#: fortran/decl.c:5165
+#: fortran/decl.c:5184
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5174
+#: fortran/decl.c:5193
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "LEN attribute at %C in a TYPE definition"
 msgstr "Атрибут код %L није дозвољен у дефиницији типа"
 
-#: fortran/decl.c:5182
+#: fortran/decl.c:5201
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be INTEGER"
 msgstr ""
 
-#: fortran/decl.c:5189
+#: fortran/decl.c:5208
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5198
+#: fortran/decl.c:5217
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr "Атрибут код %L није дозвољен у дефиницији типа"
 
-#: fortran/decl.c:5216
+#: fortran/decl.c:5235
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr "Атрибут код %L није дозвољен у дефиницији типа"
 
-#: fortran/decl.c:5226
+#: fortran/decl.c:5245
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s attribute at %L is not allowed outside of a MODULE"
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr "Атрибут %s код %L није дозвољен изван модула"
 
-#: fortran/decl.c:5236
+#: fortran/decl.c:5255
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "Attribute at %L is not allowed outside a TYPE definition"
 msgstr "Атрибут код %L није дозвољен у дефиницији типа"
 
-#: fortran/decl.c:5249
+#: fortran/decl.c:5268
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5260
+#: fortran/decl.c:5279
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5315 fortran/decl.c:8673
+#: fortran/decl.c:5334 fortran/decl.c:8692
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:5321
+#: fortran/decl.c:5340
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate %s attribute at %L"
 msgid "PROTECTED attribute at %C"
 msgstr "Удвостручени атрибут %s код %L"
 
-#: fortran/decl.c:5355
+#: fortran/decl.c:5374
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Line truncated at %C"
 msgid "VALUE attribute at %C"
 msgstr "Линија одсечена код %C"
 
-#: fortran/decl.c:5362
+#: fortran/decl.c:5381
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5369
+#: fortran/decl.c:5388
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr ""
 
-#: fortran/decl.c:5410
+#: fortran/decl.c:5429
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:5508
+#: fortran/decl.c:5527
 #, gcc-internal-format
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:5530
+#: fortran/decl.c:5549
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5539
+#: fortran/decl.c:5558
 #, gcc-internal-format
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5543
+#: fortran/decl.c:5562
 #, gcc-internal-format
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5555
+#: fortran/decl.c:5574
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr ""
 
-#: fortran/decl.c:5569
+#: fortran/decl.c:5588
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of elemental procedure at %L cannot have the POINTER attribute"
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr "Аргумент ‘%s’ елементалне процедуре код %L не може имати атрибут показивача"
 
-#: fortran/decl.c:5577
+#: fortran/decl.c:5596
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr ""
 
-#: fortran/decl.c:5589
+#: fortran/decl.c:5608
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be array-valued"
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr "Функција типа CHARACTER(*) ‘%s’ код %L не може имати низовну вредност"
 
-#: fortran/decl.c:5597
+#: fortran/decl.c:5616
 #, fuzzy, gcc-internal-format
 #| msgid "Specification function '%s' at %L cannot be a statement function"
 msgid "Return type of BIND(C) function %qs at %L cannot be a character string"
@@ -58991,369 +59063,369 @@
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:5608
+#: fortran/decl.c:5627
 #, gcc-internal-format
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr ""
 
-#: fortran/decl.c:5682
+#: fortran/decl.c:5701
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5727
+#: fortran/decl.c:5746
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing generic specification in USE statement at %C"
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr "Недостаје генеричка одредница у наредби USE код %C"
 
-#: fortran/decl.c:5734
+#: fortran/decl.c:5753
 #, fuzzy, gcc-internal-format
 #| msgid "Missing name"
 msgid "Missing symbol"
 msgstr "недостаје име"
 
-#: fortran/decl.c:5763
+#: fortran/decl.c:5782
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "BIND(C) statement at %C"
 msgstr "Празна наредба IMPLICIT код %C"
 
-#: fortran/decl.c:5850
+#: fortran/decl.c:5869
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition."
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr "Изведени тип код %C није претходно дефинисан и зато се не може појавити у дефиницији изведеног типа."
 
-#: fortran/decl.c:5892
+#: fortran/decl.c:5911
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in data declaration at %C"
 msgid "Syntax error in anonymous structure declaration at %C"
 msgstr "Синтаксна грешка у декларацији података код %C"
 
-#: fortran/decl.c:5901
+#: fortran/decl.c:5920
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr "Синтаксна грешка у декларацији података код %C"
 
-#: fortran/decl.c:5951
+#: fortran/decl.c:5970
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C"
 msgstr ""
 
-#: fortran/decl.c:5996
+#: fortran/decl.c:6015
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "procedure name = %s"
 msgid "IMPURE procedure at %C"
 msgstr "име процедуре = %s"
 
-#: fortran/decl.c:6008
+#: fortran/decl.c:6027
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr ""
 
-#: fortran/decl.c:6054
+#: fortran/decl.c:6073
 #, gcc-internal-format, gfc-internal-format
 msgid "ELEMENTAL prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6061
+#: fortran/decl.c:6080
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6068
+#: fortran/decl.c:6087
 #, gcc-internal-format, gfc-internal-format
 msgid "RECURSIVE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6134 fortran/primary.c:1820
+#: fortran/decl.c:6153 fortran/primary.c:1820
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected alternate return label at %C"
 msgid "Alternate-return argument at %C"
 msgstr "Очекивана је етикета алтернативног повратка код %C"
 
-#: fortran/decl.c:6140 fortran/decl.c:6148
+#: fortran/decl.c:6159 fortran/decl.c:6167
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unused parameter %s declared at %L"
 msgid "A parameter name is required at %C"
 msgstr "Неупотребљен параметар %s декларисан код %L"
 
-#: fortran/decl.c:6188
+#: fortran/decl.c:6207
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is the name of the procedure"
 msgid "Name %qs at %C is the name of the procedure"
 msgstr "Име ‘%s’ код %C је име процедуре"
 
-#: fortran/decl.c:6201
+#: fortran/decl.c:6220
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected another dimension in array declaration at %C"
 msgid "Expected parameter list in type declaration at %C"
 msgstr "Очекивана је друга димензија у декларацији низа код %C"
 
-#: fortran/decl.c:6204
+#: fortran/decl.c:6223
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr "Неочекивано смеће у формалној листи аргумената код %C"
 
-#: fortran/decl.c:6222
+#: fortran/decl.c:6241
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate symbol '%s' in formal argument list at %C"
 msgid "Duplicate name %qs in parameter list at %C"
 msgstr "Удвостручени симбол ‘%s’ у формалној листи аргумената код %C"
 
-#: fortran/decl.c:6225
+#: fortran/decl.c:6244
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate symbol '%s' in formal argument list at %C"
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr "Удвостручени симбол ‘%s’ у формалној листи аргумената код %C"
 
-#: fortran/decl.c:6264
+#: fortran/decl.c:6283
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in MODULE PROCEDURE formal argument names (%s/%s) at %C"
 msgstr ""
 
-#: fortran/decl.c:6270
+#: fortran/decl.c:6289
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in number of MODULE PROCEDURE formal arguments at %C"
 msgstr ""
 
-#: fortran/decl.c:6309
+#: fortran/decl.c:6328
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr "Променљива RESULT код %C мора бити различита од имена функције"
 
-#: fortran/decl.c:6386
+#: fortran/decl.c:6405
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr "Неочекивано смеће после декларације функције код %C"
 
-#: fortran/decl.c:6396 fortran/decl.c:7494
+#: fortran/decl.c:6415 fortran/decl.c:7513
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "SAVE attribute at %L cannot be specified in a PURE procedure"
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr "Атрибут SAVE код %L не може бити наведен у чистој процедури"
 
-#: fortran/decl.c:6600
+#: fortran/decl.c:6619
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:6607
+#: fortran/decl.c:6626
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:6613
+#: fortran/decl.c:6632
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Dummy procedure '%s' at %C cannot have a generic interface"
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr "Лажна процедура ‘%s’ код %C не може имати генеричко сучеље"
 
-#: fortran/decl.c:6636
+#: fortran/decl.c:6655
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type name '%s' at %C already has a basic type of %s"
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr "Име изведеног типа ‘%s’ код %C већ има основни тип %s"
 
-#: fortran/decl.c:6682 fortran/decl.c:6870 fortran/decl.c:10723
+#: fortran/decl.c:6701 fortran/decl.c:6889 fortran/decl.c:10748
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr "Синтаксна грешка у наредби SAVE код %C"
 
-#: fortran/decl.c:6731 fortran/decl.c:10623
+#: fortran/decl.c:6750 fortran/decl.c:10648
 #, fuzzy, gcc-internal-format
 #| msgid "Expected terminating name at %C"
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr "Очекивано је завршно име код %C"
 
-#: fortran/decl.c:6738
+#: fortran/decl.c:6757
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr ""
 
-#: fortran/decl.c:6742
+#: fortran/decl.c:6761
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected structure component name at %C"
 msgid "Procedure pointer component at %C"
 msgstr "Очекивано је име компоненте структуре код %C"
 
-#: fortran/decl.c:6814
+#: fortran/decl.c:6833
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in structure constructor at %C"
 msgid "Syntax error in procedure pointer component at %C"
 msgstr "Синтаксна грешка у конструктору структуре код %C"
 
-#: fortran/decl.c:6832
+#: fortran/decl.c:6851
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr "MODULE PROCEDURE код %C мора бити у генеричком сучељу модула"
 
-#: fortran/decl.c:6841 fortran/decl.c:9392
+#: fortran/decl.c:6860 fortran/decl.c:9411
 #, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr ""
 
-#: fortran/decl.c:6911
+#: fortran/decl.c:6930
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Obsolete: PAUSE statement at %C"
 msgid "PROCEDURE statement at %C"
 msgstr "Застарело: наредба PAUSE код %C"
 
-#: fortran/decl.c:6983
+#: fortran/decl.c:7002
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr "Очекивана је формална листа аргумената у дефиницији функције код %C"
 
-#: fortran/decl.c:7007 fortran/decl.c:7011 fortran/decl.c:7266
-#: fortran/decl.c:7270 fortran/decl.c:7462 fortran/decl.c:7466
-#: fortran/symbol.c:1875
+#: fortran/decl.c:7026 fortran/decl.c:7030 fortran/decl.c:7285
+#: fortran/decl.c:7289 fortran/decl.c:7481 fortran/decl.c:7485
+#: fortran/symbol.c:1889
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr ""
 
-#: fortran/decl.c:7164
+#: fortran/decl.c:7183
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "ENTRY statement at %C"
 msgstr "Празна наредба IMPLICIT код %C"
 
-#: fortran/decl.c:7173
+#: fortran/decl.c:7192
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr "Наредба ENTRY код %C не може бити унутар PROGRAM"
 
-#: fortran/decl.c:7176
+#: fortran/decl.c:7195
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr "Наредба ENTRY код %C не може бити унутар MODULE"
 
-#: fortran/decl.c:7179
+#: fortran/decl.c:7198
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgid "ENTRY statement at %C cannot appear within a SUBMODULE"
 msgstr "Наредба ENTRY код %C не може бити унутар MODULE"
 
-#: fortran/decl.c:7182
+#: fortran/decl.c:7201
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr "Наредба ENTRY код %C не може бити унутар BLOCK DATA"
 
-#: fortran/decl.c:7186 fortran/decl.c:7231
+#: fortran/decl.c:7205 fortran/decl.c:7250
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr "Наредба ENTRY код %C не може бити унутар INTERFACE"
 
-#: fortran/decl.c:7190
+#: fortran/decl.c:7209
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgid "ENTRY statement at %C cannot appear within a STRUCTURE block"
 msgstr "Наредба ENTRY код %C не може бити унутар блока SELECT"
 
-#: fortran/decl.c:7194
+#: fortran/decl.c:7213
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr "Наредба ENTRY код %C не може бити унутар блока DERIVED TYPE"
 
-#: fortran/decl.c:7198
+#: fortran/decl.c:7217
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr "Наредба ENTRY код %C не може бити унутар блока IF-THEN"
 
-#: fortran/decl.c:7203
+#: fortran/decl.c:7222
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr "Наредба ENTRY код %C не може бити унутар блока DO"
 
-#: fortran/decl.c:7207
+#: fortran/decl.c:7226
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr "Наредба ENTRY код %C не може бити унутар блока SELECT"
 
-#: fortran/decl.c:7211
+#: fortran/decl.c:7230
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr "Наредба ENTRY код %C не може бити унутар блока FORALL"
 
-#: fortran/decl.c:7215
+#: fortran/decl.c:7234
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr "Наредба ENTRY код %C не може бити унутар блока WHERE"
 
-#: fortran/decl.c:7219
+#: fortran/decl.c:7238
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr "Наредба ENTRY код %C не може бити унутар садржаног потпрограма"
 
-#: fortran/decl.c:7223
+#: fortran/decl.c:7242
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected END statement at %C"
 msgid "Unexpected ENTRY statement at %C"
 msgstr "Неочекивана наредба END код %C"
 
-#: fortran/decl.c:7244
+#: fortran/decl.c:7263
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr "Наредба ENTRY код %C не може бити у садржаној процедури"
 
-#: fortran/decl.c:7295 fortran/decl.c:7501
+#: fortran/decl.c:7314 fortran/decl.c:7520
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7563 fortran/decl.c:7570
+#: fortran/decl.c:7582 fortran/decl.c:7589
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Period required in format specifier at %C"
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr "Потребна тачка у наводиоцу формата код %C"
 
-#: fortran/decl.c:7610
+#: fortran/decl.c:7629
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CASE-specification at %C"
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr "Синтаксна грешка у одредници CASE код %C"
 
-#: fortran/decl.c:7626
+#: fortran/decl.c:7645
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr "Недостаје или неисправан константан израз"
 
-#: fortran/decl.c:7634
+#: fortran/decl.c:7653
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr ""
 
-#: fortran/decl.c:7653
+#: fortran/decl.c:7672
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing format label at %C"
 msgid "Missing closing paren for binding label at %C"
 msgstr "Недостаје етикета формата код %C"
 
-#: fortran/decl.c:7659
+#: fortran/decl.c:7678
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Function name '%s' not allowed at %C"
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr "Име функције ‘%s’ није дозвољено код %C"
 
-#: fortran/decl.c:7665
+#: fortran/decl.c:7684
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7694
+#: fortran/decl.c:7713
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr ""
 
-#: fortran/decl.c:7939
+#: fortran/decl.c:7958
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr "Неочекивана наредба END код %C"
 
-#: fortran/decl.c:7948
+#: fortran/decl.c:7967
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement at %C cannot follow %s statement at %L"
 msgid "END statement instead of %s statement at %L"
@@ -59360,176 +59432,176 @@
 msgstr "Наредба %s код %C не може пратити наредбу %s код %L"
 
 #. We would have required END [something].
-#: fortran/decl.c:7957
+#: fortran/decl.c:7976
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr "Очекивана је наредба %s код %L"
 
-#: fortran/decl.c:7968
+#: fortran/decl.c:7987
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting %s statement at %C"
 msgid "Expecting %s statement at %L"
 msgstr "Очекивана је наредба %s код %C"
 
-#: fortran/decl.c:7988
+#: fortran/decl.c:8007
 #, fuzzy, gcc-internal-format
 #| msgid "Expected block name of '%s' in %s statement at %C"
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr "Очекивано је име блока за ‘%s’ у наредби %s код %C"
 
-#: fortran/decl.c:8005
+#: fortran/decl.c:8024
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr "Очекивано је завршно име код %C"
 
-#: fortran/decl.c:8019 fortran/decl.c:8027
+#: fortran/decl.c:8038 fortran/decl.c:8046
 #, fuzzy, gcc-internal-format
 #| msgid "Expected label '%s' for %s statement at %C"
 msgid "Expected label %qs for %s statement at %C"
 msgstr "Очекивана је етикета ‘%s’ за наредбу %s код %C"
 
-#: fortran/decl.c:8126
+#: fortran/decl.c:8145
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr "Недостаје одредница низа код %L у наредби DIMENSION"
 
-#: fortran/decl.c:8134
+#: fortran/decl.c:8153
 #, gcc-internal-format, gfc-internal-format
 msgid "Dimensions specified for %s at %L after its initialization"
 msgstr ""
 
-#: fortran/decl.c:8142
+#: fortran/decl.c:8161
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing array specification at %L in DIMENSION statement"
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr "Недостаје одредница низа код %L у наредби DIMENSION"
 
-#: fortran/decl.c:8151
+#: fortran/decl.c:8170
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr "Одредница низа мора бити одложена код %L"
 
-#: fortran/decl.c:8249
+#: fortran/decl.c:8268
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr "Неочекиван знак у листи променљивих код %C"
 
-#: fortran/decl.c:8286
+#: fortran/decl.c:8305
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "Expected %<(%> at %C"
 msgstr "Очекивано је ‘(’ код %C"
 
-#: fortran/decl.c:8300 fortran/decl.c:8340
+#: fortran/decl.c:8319 fortran/decl.c:8359
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr "Очекивано је име променљиве код %C"
 
-#: fortran/decl.c:8316
+#: fortran/decl.c:8335
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Cray pointer at %C must be an integer."
 msgid "Cray pointer at %C must be an integer"
 msgstr "Крејов показивач код %C мора бити целобројни."
 
-#: fortran/decl.c:8320
+#: fortran/decl.c:8339
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes."
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr "Крејов показивач код %C има %d бајтова тачности; меморијска адреса захтева %d бајтова."
 
-#: fortran/decl.c:8326
+#: fortran/decl.c:8345
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr "Очекивано је ‘,’ код %C"
 
-#: fortran/decl.c:8365
+#: fortran/decl.c:8384
 #, gcc-internal-format
 msgid "Couldn't set Cray pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:8389
+#: fortran/decl.c:8408
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr "Очекивано је ‘)’ код %C"
 
-#: fortran/decl.c:8401
+#: fortran/decl.c:8420
 #, fuzzy, gcc-internal-format
 #| msgid "Expected \",\" or end of statement at %C"
 msgid "Expected %<,%> or end of statement at %C"
 msgstr "Очекивано је ‘,’ или крај наредбе код %C"
 
-#: fortran/decl.c:8427
+#: fortran/decl.c:8446
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:8459
+#: fortran/decl.c:8478
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:8478
+#: fortran/decl.c:8497
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Cray pointer declaration at %C requires -fcray-pointer flag."
 msgid "Cray pointer declaration at %C requires -fcray-pointer flag"
 msgstr "Декларација Крејовог показивача код %C захтева заставицу -fcray-pointer."
 
-#: fortran/decl.c:8517
+#: fortran/decl.c:8536
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Obsolete: PAUSE statement at %C"
 msgid "CONTIGUOUS statement at %C"
 msgstr "Застарело: наредба PAUSE код %C"
 
-#: fortran/decl.c:8623
+#: fortran/decl.c:8642
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr "Одредница приступа оператора %s код %C је већ наведена"
 
-#: fortran/decl.c:8640
+#: fortran/decl.c:8659
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr "Одредница приступа оператора .%s. код %C је већ наведена"
 
-#: fortran/decl.c:8679
+#: fortran/decl.c:8698
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "PROTECTED statement at %C"
 msgstr "Празна наредба IMPLICIT код %C"
 
-#: fortran/decl.c:8717
+#: fortran/decl.c:8736
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr "Синтаксна грешка у наредби SAVE код %C"
 
-#: fortran/decl.c:8741
+#: fortran/decl.c:8760
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "DATA statement at %C is not allowed in a PURE procedure"
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr "Наредба DATA код %C није дозвољена у чистој процедури"
 
-#: fortran/decl.c:8778
+#: fortran/decl.c:8797
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "DATA statement at %C is not allowed in a PURE procedure"
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr "Наредба DATA код %C није дозвољена у чистој процедури"
 
-#: fortran/decl.c:8806
+#: fortran/decl.c:8825
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr "Очекивано је име променљиве код %C у наредби PARAMETER"
 
-#: fortran/decl.c:8813
+#: fortran/decl.c:8832
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr "Очекиван је знак = у наредби PARAMETER код %C"
 
-#: fortran/decl.c:8819
+#: fortran/decl.c:8838
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr "Очекиван је израз код %C у наредби PARAMETER"
 
-#: fortran/decl.c:8839
+#: fortran/decl.c:8858
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Initializer not allowed for COMMON variable '%s' at %C"
 msgid "Initializing already initialized variable at %C"
@@ -59536,502 +59608,508 @@
 msgstr "Успостављач није дозвољен за заједничку променљиву ‘%s’ код %C"
 
 #. With legacy PARAMETER statements, don't expect a terminating ')'.
-#: fortran/decl.c:8864
+#: fortran/decl.c:8883
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER without '()' at %C"
 msgstr ""
 
-#: fortran/decl.c:8880
+#: fortran/decl.c:8899
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr "Неочекивани знакови у наредби PARAMETER код %C"
 
-#: fortran/decl.c:8899 fortran/decl.c:8955
+#: fortran/decl.c:8918 fortran/decl.c:8974
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:8934
+#: fortran/decl.c:8953
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected variable in READ statement at %C"
 msgid "Expected entity-list in AUTOMATIC statement at %C"
 msgstr "Очекивана је променљива у наредби READ код %C"
 
-#: fortran/decl.c:8941
+#: fortran/decl.c:8960
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in AUTOMATIC statement at %C"
 msgstr "Синтаксна грешка у наредби SAVE код %C"
 
-#: fortran/decl.c:8990
+#: fortran/decl.c:9009
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected variable in READ statement at %C"
 msgid "Expected entity-list in STATIC statement at %C"
 msgstr "Очекивана је променљива у наредби READ код %C"
 
-#: fortran/decl.c:8997
+#: fortran/decl.c:9016
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in STATIC statement at %C"
 msgstr "Синтаксна грешка у наредби SAVE код %C"
 
-#: fortran/decl.c:9016
+#: fortran/decl.c:9035
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr "Покривачка наредба SAVE код %C прати претходну наредбу SAVE"
 
-#: fortran/decl.c:9027
+#: fortran/decl.c:9046
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr "Наредба SAVE код %C прати покривачку наредбу SAVE"
 
-#: fortran/decl.c:9073
+#: fortran/decl.c:9092
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr "Синтаксна грешка у наредби SAVE код %C"
 
-#: fortran/decl.c:9087
+#: fortran/decl.c:9106
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:9091
+#: fortran/decl.c:9110
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Obsolete: PAUSE statement at %C"
 msgid "VALUE statement at %C"
 msgstr "Застарело: наредба PAUSE код %C"
 
-#: fortran/decl.c:9129
+#: fortran/decl.c:9148
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in VALUE statement at %C"
 msgstr "Синтаксна грешка у наредби SAVE код %C"
 
-#: fortran/decl.c:9141
+#: fortran/decl.c:9160
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate PRIVATE statement at %C"
 msgid "VOLATILE statement at %C"
 msgstr "Удвостручена наредба PRIVATE код %C"
 
-#: fortran/decl.c:9168
+#: fortran/decl.c:9187
 #, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr ""
 
-#: fortran/decl.c:9193
+#: fortran/decl.c:9212
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr "Синтаксна грешка у наредби SAVE код %C"
 
-#: fortran/decl.c:9205
+#: fortran/decl.c:9224
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Obsolete: PAUSE statement at %C"
 msgid "ASYNCHRONOUS statement at %C"
 msgstr "Застарело: наредба PAUSE код %C"
 
-#: fortran/decl.c:9249
+#: fortran/decl.c:9268
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr "Синтаксна грешка у наредби SAVE код %C"
 
-#: fortran/decl.c:9274
+#: fortran/decl.c:9293
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:9367
+#: fortran/decl.c:9386
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr "MODULE PROCEDURE код %C мора бити у генеричком сучељу модула"
 
-#: fortran/decl.c:9425
+#: fortran/decl.c:9444
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr ""
 
-#: fortran/decl.c:9474
+#: fortran/decl.c:9493
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected :: in TYPE definition at %C"
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr "Очекивано је :: у дефиницији TYPE код %C"
 
-#: fortran/decl.c:9483
+#: fortran/decl.c:9502
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C has already been host associated"
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr "Симбол ‘%s’ код %C је већ придружен домаћину"
 
-#: fortran/decl.c:9489
+#: fortran/decl.c:9508
 #, gcc-internal-format
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr ""
 
-#: fortran/decl.c:9496
+#: fortran/decl.c:9515
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:9503
+#: fortran/decl.c:9522
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be thread-local because it has non-POD type %qT"
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr "%qD не може бити нитно-локално зато што је не-ПОД типа %qT"
 
-#: fortran/decl.c:9526
+#: fortran/decl.c:9545
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Derived type at %C can only be PRIVATE within a MODULE"
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr "Изведени тип код %C може бити само приватан унутар модула"
 
-#: fortran/decl.c:9538
+#: fortran/decl.c:9557
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Derived type at %C can only be PUBLIC within a MODULE"
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr "Изведени тип код %C може бити само јаван унутар модула"
 
-#: fortran/decl.c:9559
+#: fortran/decl.c:9578
 #, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
 msgstr ""
 
-#: fortran/decl.c:9605
+#: fortran/decl.c:9624
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate construct label '%s' at %C"
 msgid "Failed to create structure type '%s' at %C"
 msgstr "Удвостручена етикета конструкције ‘%s’ код %C"
 
-#: fortran/decl.c:9611
+#: fortran/decl.c:9630
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type definition of '%s' at %C has already been defined"
 msgid "Type definition of %qs at %C was already defined at %L"
 msgstr "Дефиниција изведеног типа ‘%s’ код %C је већ учињена"
 
-#: fortran/decl.c:9658
+#: fortran/decl.c:9677
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after ELSE statement at %C"
 msgid "Junk after MAP statement at %C"
 msgstr "Неочекивано смеће после наредбе ELSE код %C"
 
-#: fortran/decl.c:9691
+#: fortran/decl.c:9710
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after ELSE statement at %C"
 msgid "Junk after UNION statement at %C"
 msgstr "Неочекивано смеће после наредбе ELSE код %C"
 
-#: fortran/decl.c:9726
+#: fortran/decl.c:9745
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr ""
 
-#: fortran/decl.c:9740
+#: fortran/decl.c:9759
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after function declaration at %C"
 msgid "Structure name expected in non-nested structure declaration at %C"
 msgstr "Неочекивано смеће после декларације функције код %C"
 
-#: fortran/decl.c:9758
+#: fortran/decl.c:9777
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected CASE statement at %C"
 msgid "Junk after non-nested STRUCTURE statement at %C"
 msgstr "Неочекивана наредба CASE код %C"
 
-#: fortran/decl.c:9765
+#: fortran/decl.c:9784
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C cannot be the same as an intrinsic type"
 msgid "Structure name %qs at %C cannot be the same as an intrinsic type"
 msgstr "Име типа ‘%s’ код %C не може бити исто као сопственог типа"
 
-#: fortran/decl.c:9926
+#: fortran/decl.c:9947
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr "Очекивано је :: у дефиницији TYPE код %C"
 
-#: fortran/decl.c:9954
+#: fortran/decl.c:9975
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C cannot be the same as an intrinsic type"
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr "Име типа ‘%s’ код %C не може бити исто као сопственог типа"
 
-#: fortran/decl.c:9964
+#: fortran/decl.c:9986
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type name '%s' at %C already has a basic type of %s"
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr "Име изведеног типа ‘%s’ код %C већ има основни тип %s"
 
-#: fortran/decl.c:9981
+#: fortran/decl.c:9989
 #, fuzzy, gcc-internal-format
+#| msgid "Derived type name '%s' at %C already has a basic type of %s"
+msgid "Derived type name %qs at %C already has a basic type"
+msgstr "Име изведеног типа ‘%s’ код %C већ има основни тип %s"
+
+#: fortran/decl.c:10006
+#, fuzzy, gcc-internal-format
 #| msgid "Derived type definition of '%s' at %C has already been defined"
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr "Дефиниција изведеног типа ‘%s’ код %C је већ учињена"
 
-#: fortran/decl.c:10042
+#: fortran/decl.c:10067
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CHARACTER declaration at %C"
 msgid "Garbage after PARAMETERIZED TYPE declaration at %C"
 msgstr "Синтаксна грешка у декларацији CHARACTER код %C"
 
-#: fortran/decl.c:10126
+#: fortran/decl.c:10151
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr "Крејов показивани код %C не може бити низ претпостављеног облика"
 
-#: fortran/decl.c:10146
+#: fortran/decl.c:10171
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "New in Fortran 2003: ENUM and ENUMERATOR at %C"
 msgid "ENUM and ENUMERATOR at %C"
 msgstr "Ново у фортрану 2003: ENUM и ENUMERATOR код %C"
 
-#: fortran/decl.c:10178
+#: fortran/decl.c:10203
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr "Набрајач премашује Ц-ов целобројни тип код %C"
 
-#: fortran/decl.c:10257
+#: fortran/decl.c:10282
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr "Набрајач %L није успостављен целобројним изразом"
 
-#: fortran/decl.c:10305
+#: fortran/decl.c:10330
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr "Очекивана је наредба дефиниције ENUM пре %C"
 
-#: fortran/decl.c:10341
+#: fortran/decl.c:10366
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr "Синтаксна грешка у дефиницији ENUMERATOR код %C"
 
-#: fortran/decl.c:10388 fortran/decl.c:10403
+#: fortran/decl.c:10413 fortran/decl.c:10428
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate %s specification at %C"
 msgid "Duplicate access-specifier at %C"
 msgstr "Удвостручена одредница %s код %C"
 
-#: fortran/decl.c:10423
+#: fortran/decl.c:10448
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10443
+#: fortran/decl.c:10468
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10470
+#: fortran/decl.c:10495
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate %s attribute at %L"
 msgid "Duplicate POINTER attribute at %C"
 msgstr "Удвостручени атрибут %s код %L"
 
-#: fortran/decl.c:10488
+#: fortran/decl.c:10513
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected VARIABLE at %C"
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr "Очекивано је VARIABLE код %C"
 
-#: fortran/decl.c:10504
+#: fortran/decl.c:10529
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate SEQUENCE statement at %C"
 msgid "Duplicate DEFERRED at %C"
 msgstr "Удвостручена наредба SEQUENCE код %C"
 
-#: fortran/decl.c:10517
+#: fortran/decl.c:10542
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected a nameless interface at %C"
 msgid "Expected access-specifier at %C"
 msgstr "Очекивано је безимено сучеље код %C"
 
-#: fortran/decl.c:10519
+#: fortran/decl.c:10544
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected terminating name at %C"
 msgid "Expected binding attribute at %C"
 msgstr "Очекивано је завршно име код %C"
 
-#: fortran/decl.c:10527
+#: fortran/decl.c:10552
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED can't both appear at %C"
 msgstr ""
 
-#: fortran/decl.c:10539
+#: fortran/decl.c:10564
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:10581
+#: fortran/decl.c:10606
 #, fuzzy, gcc-internal-format
 #| msgid "identifier expected after %<@protocol%>"
 msgid "Interface-name expected after %<(%> at %C"
 msgstr "очекиван је идентификатор после %<@protocol%>"
 
-#: fortran/decl.c:10587
+#: fortran/decl.c:10612
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "%<)%> expected at %C"
 msgstr "Очекивано је ‘(’ код %C"
 
-#: fortran/decl.c:10607
+#: fortran/decl.c:10632
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:10612
+#: fortran/decl.c:10637
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:10635
+#: fortran/decl.c:10660
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected terminating name at %C"
 msgid "Expected binding name at %C"
 msgstr "Очекивано је завршно име код %C"
 
-#: fortran/decl.c:10639
+#: fortran/decl.c:10664
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
 msgstr ""
 
-#: fortran/decl.c:10651
+#: fortran/decl.c:10676
 #, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:10657
+#: fortran/decl.c:10682
 #, gcc-internal-format
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr ""
 
-#: fortran/decl.c:10667
+#: fortran/decl.c:10692
 #, fuzzy, gcc-internal-format
 #| msgid "Expected terminating name at %C"
 msgid "Expected binding target after %<=>%> at %C"
 msgstr "Очекивано је завршно име код %C"
 
-#: fortran/decl.c:10684
+#: fortran/decl.c:10709
 #, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr ""
 
-#: fortran/decl.c:10695
+#: fortran/decl.c:10720
 #, gcc-internal-format
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:10746
+#: fortran/decl.c:10771
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr ""
 
-#: fortran/decl.c:10766
+#: fortran/decl.c:10791
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "Expected %<::%> at %C"
 msgstr "Очекивано је ‘(’ код %C"
 
-#: fortran/decl.c:10778
+#: fortran/decl.c:10803
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected array subscript at %C"
 msgid "Expected generic name or operator descriptor at %C"
 msgstr "Очекиван је индекс низа код %C"
 
-#: fortran/decl.c:10799
+#: fortran/decl.c:10824
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid form of PROGRAM statement at %C"
 msgid "Malformed GENERIC statement at %C"
 msgstr "Неисправан облик наредбе PROGRAM код %C"
 
-#: fortran/decl.c:10810
+#: fortran/decl.c:10835
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "Expected %<=>%> at %C"
 msgstr "Очекивано је ‘(’ код %C"
 
-#: fortran/decl.c:10846
+#: fortran/decl.c:10871
 #, gcc-internal-format
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:10854
+#: fortran/decl.c:10879
 #, gcc-internal-format
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr ""
 
-#: fortran/decl.c:10902
+#: fortran/decl.c:10927
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected terminating name at %C"
 msgid "Expected specific binding name at %C"
 msgstr "Очекивано је завршно име код %C"
 
-#: fortran/decl.c:10912
+#: fortran/decl.c:10937
 #, fuzzy, gcc-internal-format
 #| msgid "There is no specific function for the generic '%s' at %L"
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr "Нема одређене функције за генеричко ‘%s’ код %L"
 
-#: fortran/decl.c:10930
+#: fortran/decl.c:10955
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr ""
 
-#: fortran/decl.c:10965
+#: fortran/decl.c:10990
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr ""
 
-#: fortran/decl.c:10976
+#: fortran/decl.c:11001
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr ""
 
-#: fortran/decl.c:10998
+#: fortran/decl.c:11023
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected VARIABLE at %C"
 msgid "Empty FINAL at %C"
 msgstr "Очекивано је VARIABLE код %C"
 
-#: fortran/decl.c:11005
+#: fortran/decl.c:11030
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected a procedure for argument '%s' at %L"
 msgid "Expected module procedure name at %C"
 msgstr "Очекивана је процедура за аргумент ‘%s’ код %L"
 
-#: fortran/decl.c:11015
+#: fortran/decl.c:11040
 #, fuzzy, gcc-internal-format
 #| msgid "Expected \",\" at %C"
 msgid "Expected %<,%> at %C"
 msgstr "Очекивано је ‘,’ код %C"
 
-#: fortran/decl.c:11021
+#: fortran/decl.c:11046
 #, fuzzy, gcc-internal-format
 #| msgid "procedure name = %s"
 msgid "Unknown procedure name %qs at %C"
 msgstr "име процедуре = %s"
 
-#: fortran/decl.c:11034
+#: fortran/decl.c:11059
 #, fuzzy, gcc-internal-format
 #| msgid "%s procedure at %L is already declared as %s procedure"
 msgid "%qs at %C is already defined as FINAL procedure"
 msgstr "Процедура %s код %L је већ декларисана као процедура %s"
 
-#: fortran/decl.c:11104
+#: fortran/decl.c:11129
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected characters in PARAMETER statement at %C"
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr "Неочекивани знакови у наредби PARAMETER код %C"
 
-#: fortran/decl.c:11150
+#: fortran/decl.c:11175
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr "Синтаксна грешка у наредби SAVE код %C"
 
-#: fortran/decl.c:11170
+#: fortran/decl.c:11195
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive requires a non-negative integral constant less than or equal to %u at %C"
 msgstr ""
 
-#: fortran/decl.c:11184
+#: fortran/decl.c:11209
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in FORALL iterator at %C"
 msgid "Syntax error in !GCC$ UNROLL directive at %C"
@@ -60399,27 +60477,27 @@
 msgid "BOZ literal at %L used to initialize non-integer variable %qs"
 msgstr ""
 
-#: fortran/expr.c:3369 fortran/resolve.c:10197
+#: fortran/expr.c:3369 fortran/resolve.c:10210
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal at %L outside a DATA statement and outside INT/REAL/DBLE/CMPLX"
 msgstr ""
 
-#: fortran/expr.c:3380 fortran/resolve.c:10208
+#: fortran/expr.c:3380 fortran/resolve.c:10221
 #, gcc-internal-format
 msgid "BOZ literal at %L is bitwise transferred non-integer symbol %qs"
 msgstr ""
 
-#: fortran/expr.c:3388 fortran/resolve.c:10217
+#: fortran/expr.c:3388 fortran/resolve.c:10230
 #, gcc-internal-format
 msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3392 fortran/resolve.c:10221
+#: fortran/expr.c:3392 fortran/resolve.c:10234
 #, gcc-internal-format
 msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3396 fortran/resolve.c:10225
+#: fortran/expr.c:3396 fortran/resolve.c:10238
 #, gcc-internal-format
 msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
@@ -60429,163 +60507,163 @@
 msgid "The assignment to a KIND or LEN component of a parameterized type at %L is not allowed"
 msgstr ""
 
-#: fortran/expr.c:3426
+#: fortran/expr.c:3429
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Incompatible types in assignment at %L, %s to %s"
 msgid "Incompatible types in DATA statement at %L; attempted conversion of %s to %s"
 msgstr "Несагласни типови у додели код %L, %s у %s"
 
-#: fortran/expr.c:3465
+#: fortran/expr.c:3468
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is not a POINTER at %L"
 msgstr "Циљ доделе показивача није показивач код %L"
 
-#: fortran/expr.c:3473
+#: fortran/expr.c:3476
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgid "%qs in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgstr "‘%s’ у додели показивача код %L не може бити л-вредност јер је процедура"
 
-#: fortran/expr.c:3496
+#: fortran/expr.c:3499
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate %s specification at %C"
 msgid "Expected bounds specification for %qs at %L"
 msgstr "Удвостручена одредница %s код %C"
 
-#: fortran/expr.c:3501
+#: fortran/expr.c:3504
 #, fuzzy, gcc-internal-format
 #| msgid "Different types in pointer assignment at %L"
 msgid "Bounds specification for %qs in pointer assignment at %L"
 msgstr "Различити типови у додели показивача код %L"
 
-#: fortran/expr.c:3514
+#: fortran/expr.c:3517
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower bound has to be present at %L"
 msgstr ""
 
-#: fortran/expr.c:3520
+#: fortran/expr.c:3523
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "stack size must not be greater than 64k"
 msgid "Stride must not be present at %L"
 msgstr "величина стека не сме бити већа од 64k"
 
-#: fortran/expr.c:3532
+#: fortran/expr.c:3535
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the upper bounds must be specified at %L"
 msgstr ""
 
-#: fortran/expr.c:3558
+#: fortran/expr.c:3561
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "External object '%s' at %L may not have an initializer"
 msgid "Pointer object at %L shall not have a coindex"
 msgstr "Спољашњи објекат ‘%s’ код %L не може имати успостављач"
 
-#: fortran/expr.c:3579
+#: fortran/expr.c:3582
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Different types in pointer assignment at %L"
 msgid "Invalid procedure pointer assignment at %L"
 msgstr "Различити типови у додели показивача код %L"
 
-#: fortran/expr.c:3603
+#: fortran/expr.c:3606
 #, fuzzy, gcc-internal-format
 #| msgid "Different kind type parameters in pointer assignment at %L"
 msgid "Function result %qs is invalid as proc-target in procedure pointer assignment at %L"
 msgstr "Различите врсте типова параметара у додели показивача код %L"
 
-#: fortran/expr.c:3612
+#: fortran/expr.c:3615
 #, fuzzy, gcc-internal-format
 #| msgid "Different kind type parameters in pointer assignment at %L"
 msgid "Abstract interface %qs is invalid in procedure pointer assignment at %L"
 msgstr "Различите врсте типова параметара у додели показивача код %L"
 
-#: fortran/expr.c:3622
+#: fortran/expr.c:3625
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' requires argument list at %C"
 msgid "Statement function %qs is invalid in procedure pointer assignment at %L"
 msgstr "Наредбена функција ‘%s’ захтева листу аргумената код %C"
 
-#: fortran/expr.c:3628
+#: fortran/expr.c:3631
 #, fuzzy, gcc-internal-format
 #| msgid "Internal procedure '%s' is not allowed as an actual argument at %L"
 msgid "Internal procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "Унутрашња процедура ‘%s’ код %L није дозвољена као стварни аргумент"
 
-#: fortran/expr.c:3635
+#: fortran/expr.c:3638
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L is not allowed as an actual argument"
 msgid "Intrinsic %qs at %L is invalid in procedure pointer assignment"
 msgstr "Сопствено ‘%s’ код %L није дозвољено као стварни аргумент"
 
-#: fortran/expr.c:3643
+#: fortran/expr.c:3646
 #, gcc-internal-format
 msgid "Nonintrinsic elemental procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3666
+#: fortran/expr.c:3669
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in the procedure pointer assignment at %L: mismatch in the calling convention"
 msgstr ""
 
-#: fortran/expr.c:3719
+#: fortran/expr.c:3722
 #, gcc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %qs is not a subroutine"
 msgstr ""
 
-#: fortran/expr.c:3729 fortran/expr.c:3744
+#: fortran/expr.c:3732 fortran/expr.c:3747
 #, fuzzy, gcc-internal-format
 #| msgid "Expected a procedure for argument '%s' at %L"
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr "Очекивана је процедура за аргумент ‘%s’ код %L"
 
-#: fortran/expr.c:3735 fortran/expr.c:3750 fortran/resolve.c:2566
+#: fortran/expr.c:3738 fortran/expr.c:3753 fortran/resolve.c:2566
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate interface declaration for class %qs"
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr "удвостручена декларација сучеља за класу %qs"
 
-#: fortran/expr.c:3762
+#: fortran/expr.c:3765
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Different character lengths in pointer assignment at %L"
 msgid "Interface mismatch in procedure pointer assignment at %L: %s"
 msgstr "Различите знаковне дужине у додели показивача код %L"
 
-#: fortran/expr.c:3771
+#: fortran/expr.c:3774
 #, gcc-internal-format
 msgid "Procedure pointer target %qs at %L must be either an intrinsic, host or use associated, referenced or have the EXTERNAL attribute"
 msgstr ""
 
-#: fortran/expr.c:3788
+#: fortran/expr.c:3791
 #, gcc-internal-format, gfc-internal-format
 msgid "Data-pointer-object at %L must be unlimited polymorphic, or of a type with the BIND or SEQUENCE attribute, to be compatible with an unlimited polymorphic target"
 msgstr ""
 
-#: fortran/expr.c:3793
+#: fortran/expr.c:3796
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Different types in pointer assignment at %L"
 msgid "Different types in pointer assignment at %L; attempted assignment of %s to %s"
 msgstr "Различити типови у додели показивача код %L"
 
-#: fortran/expr.c:3802
+#: fortran/expr.c:3805
 #, gcc-internal-format, gfc-internal-format
 msgid "Different kind type parameters in pointer assignment at %L"
 msgstr "Различите врсте типова параметара у додели показивача код %L"
 
-#: fortran/expr.c:3809
+#: fortran/expr.c:3812
 #, gcc-internal-format, gfc-internal-format
 msgid "Different ranks in pointer assignment at %L"
 msgstr "Различити рангови у додели показивача код %L"
 
-#: fortran/expr.c:3828
+#: fortran/expr.c:3831
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is smaller than size of the pointer (%ld < %ld) at %L"
 msgstr ""
 
-#: fortran/expr.c:3841
+#: fortran/expr.c:3844
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target must be rank 1 or simply contiguous at %L"
 msgstr ""
 
-#: fortran/expr.c:3845
+#: fortran/expr.c:3848
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer assignment target is not a POINTER at %L"
 msgid "Rank remapping target is not rank 1 at %L"
@@ -60594,155 +60672,160 @@
 #. The test above might need to be extend when F08, Note 5.4 has to be
 #. interpreted in the way that target and pointer with the same coindex
 #. are allowed.
-#: fortran/expr.c:3877 fortran/expr.c:3925
+#: fortran/expr.c:3880 fortran/expr.c:3928
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components"
 msgid "Data target at %L shall not have a coindex"
 msgstr "Елемент преноса података код %L не може имати показивачке компоненте"
 
-#: fortran/expr.c:3880
+#: fortran/expr.c:3883
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr "Изборни израз у рачунском GOTO код %L мора бити скаларни целобројан израз"
 
-#: fortran/expr.c:3888
+#: fortran/expr.c:3891
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr "Циљ доделе показивача није ни циљ ни показивач код %L"
 
-#: fortran/expr.c:3895
+#: fortran/expr.c:3898
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr "Лош циљ у додели показивача у чистој процедури код %L"
 
-#: fortran/expr.c:3904
+#: fortran/expr.c:3907
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr "Додела показивача са векторским индексом на десној страни код %L"
 
-#: fortran/expr.c:3912
+#: fortran/expr.c:3915
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer assignment target is not a POINTER at %L"
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr "Циљ доделе показивача није показивач код %L"
 
-#: fortran/expr.c:3936
+#: fortran/expr.c:3939
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to contiguous pointer from non-contiguous target at %L"
 msgstr ""
 
-#: fortran/expr.c:3975
+#: fortran/expr.c:3978
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr ""
 
-#: fortran/expr.c:4051 fortran/resolve.c:1452
+#: fortran/expr.c:4054 fortran/resolve.c:1452
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer initialization at %C requires '=>', not '='"
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr "Успостављање показивача код %C захтева ‘=>’, не ‘=’"
 
-#: fortran/expr.c:4057
+#: fortran/expr.c:4060
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Component at %C must have the POINTER attribute"
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr "Компонента код %C мора имати атрибут показивача"
 
-#: fortran/expr.c:4072 fortran/resolve.c:1458
+#: fortran/expr.c:4075 fortran/resolve.c:1458
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Object '%s' at %L must have the SAVE attribute %s"
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr "Објекат ‘%s’ код %L мора имати атрибут %s за SAVE"
 
-#: fortran/expr.c:4084
+#: fortran/expr.c:4087
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr ""
 
-#: fortran/expr.c:5512
+#: fortran/expr.c:4557
+#, gcc-internal-format
+msgid "generate_isocbinding_initializer(): bad iso_c_binding type, expected %<c_ptr%> or %<c_funptr%>"
+msgstr ""
+
+#: fortran/expr.c:5568
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5520
+#: fortran/expr.c:5576
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5528
+#: fortran/expr.c:5584
 #, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5537
+#: fortran/expr.c:5593
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr "%qE није исправан шаблонски аргумент типа %qT јер %qE није променљива"
 
-#: fortran/expr.c:5548
+#: fortran/expr.c:5604
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5557
+#: fortran/expr.c:5613
 #, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5570
+#: fortran/expr.c:5626
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5583
+#: fortran/expr.c:5639
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5613
+#: fortran/expr.c:5669
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5621
+#: fortran/expr.c:5677
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5634
+#: fortran/expr.c:5690
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' cannot appear in the expression at %L"
 msgid "Variable %qs is PROTECTED and can not appear in a pointer association context (%s) at %L"
 msgstr "Променљива ‘%s’ се не може јавити у изразу код %L"
 
-#: fortran/expr.c:5642
+#: fortran/expr.c:5698
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5654
+#: fortran/expr.c:5710
 #, gcc-internal-format
 msgid "Variable %qs can not appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr ""
 
-#: fortran/expr.c:5713
+#: fortran/expr.c:5769
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:5717
+#: fortran/expr.c:5773
 #, gcc-internal-format
 msgid "%qs at %L associated to expression can not be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:5728
+#: fortran/expr.c:5784
 #, gcc-internal-format
 msgid "Associate-name %qs can not appear in a variable definition context (%s) at %L because its target at %L can not, either"
 msgstr ""
 
-#: fortran/expr.c:5770
+#: fortran/expr.c:5826
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr ""
@@ -60752,24 +60835,24 @@
 msgid "can't open input file: %s"
 msgstr "не могу да отворим улазну датотеку: %s"
 
-#: fortran/frontend-passes.c:190
+#: fortran/frontend-passes.c:192
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid init statement"
 msgid "No location in statement"
 msgstr "Неисправна успостављачка наредба"
 
-#: fortran/frontend-passes.c:205
+#: fortran/frontend-passes.c:207
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected exponent in expression at %C"
 msgid "No location in expression near %L"
 msgstr "Очекиван је изложилац у изразу код %C"
 
-#: fortran/frontend-passes.c:409
+#: fortran/frontend-passes.c:414
 #, gcc-internal-format
 msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
-#: fortran/frontend-passes.c:817 fortran/trans-array.c:1182
+#: fortran/frontend-passes.c:822 fortran/trans-array.c:1182
 #: fortran/trans-array.c:6440 fortran/trans-array.c:7864
 #: fortran/trans-intrinsic.c:7307
 #, fuzzy, gcc-internal-format, gfc-internal-format
@@ -60777,75 +60860,75 @@
 msgid "Creating array temporary at %L"
 msgstr "стварање низа типа %qT"
 
-#: fortran/frontend-passes.c:842 fortran/frontend-passes.c:846
+#: fortran/frontend-passes.c:847 fortran/frontend-passes.c:851
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "Removing call to function %qs at %L"
 msgstr "позив не-функције %qD"
 
-#: fortran/frontend-passes.c:1273 fortran/frontend-passes.c:1312
+#: fortran/frontend-passes.c:1278 fortran/frontend-passes.c:1317
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "bad expression"
 msgstr "очекиван је израз"
 
-#: fortran/frontend-passes.c:1308
+#: fortran/frontend-passes.c:1313
 #, gcc-internal-format
 msgid "bad op"
 msgstr ""
 
-#: fortran/frontend-passes.c:2161
+#: fortran/frontend-passes.c:2166
 #, gcc-internal-format
 msgid "illegal OP in optimize_comparison"
 msgstr ""
 
-#: fortran/frontend-passes.c:2407
+#: fortran/frontend-passes.c:2412
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgid "Variable %qs at %L set to undefined value inside loop  beginning at %L as INTENT(OUT) argument to subroutine %qs"
 msgstr "Променљива ‘%s’ код %C не може се редефинисати унутар петље која почиње код %L"
 
-#: fortran/frontend-passes.c:2414
+#: fortran/frontend-passes.c:2419
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to subroutine %qs"
 msgstr "Променљива ‘%s’ код %C не може се редефинисати унутар петље која почиње код %L"
 
-#: fortran/frontend-passes.c:2637 fortran/frontend-passes.c:2661
+#: fortran/frontend-passes.c:2642 fortran/frontend-passes.c:2666
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Array reference at %L out of bounds (%ld < %ld) in loop beginning at %L"
 msgstr "Упућивач низа код %L је изван граница"
 
-#: fortran/frontend-passes.c:2646 fortran/frontend-passes.c:2670
+#: fortran/frontend-passes.c:2651 fortran/frontend-passes.c:2675
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Array reference at %L out of bounds (%ld > %ld) in loop beginning at %L"
 msgstr "Упућивач низа код %L је изван граница"
 
-#: fortran/frontend-passes.c:2730
+#: fortran/frontend-passes.c:2735
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgid "Variable %qs at %L set to undefined value inside loop beginning at %L as INTENT(OUT) argument to function %qs"
 msgstr "Променљива ‘%s’ код %C не може се редефинисати унутар петље која почиње код %L"
 
-#: fortran/frontend-passes.c:2736
+#: fortran/frontend-passes.c:2741
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr "Променљива ‘%s’ код %C не може се редефинисати унутар петље која почиње код %L"
 
-#: fortran/frontend-passes.c:3128 fortran/trans-expr.c:1581
+#: fortran/frontend-passes.c:3133 fortran/trans-expr.c:1581
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr ""
 
-#: fortran/frontend-passes.c:3637
+#: fortran/frontend-passes.c:3642
 #, gcc-internal-format
 msgid "Scalarization using DIMEN_RANGE unimplemented"
 msgstr ""
 
-#: fortran/frontend-passes.c:4429
+#: fortran/frontend-passes.c:4434
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Incompatible ranks in %s at %L"
 msgid "Interchanging loops at %L"
@@ -60975,12 +61058,12 @@
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "Други аргумент дефинисане доделе код %L мора бити намере-у"
 
-#: fortran/interface.c:970 fortran/resolve.c:16351
+#: fortran/interface.c:970 fortran/resolve.c:16378
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "Први аргумент сучеља оператора код %L мора бити намере-у"
 
-#: fortran/interface.c:977 fortran/resolve.c:16369
+#: fortran/interface.c:977 fortran/resolve.c:16396
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "Други аргумент сучеља оператора код %L мора бити намере-у"
@@ -62300,7 +62383,7 @@
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.c:3369 fortran/resolve.c:14263
+#: fortran/io.c:3369 fortran/resolve.c:14283
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' at %L cannot have ALLOCATABLE components"
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
@@ -62480,7 +62563,7 @@
 msgid "Integer too large at %C"
 msgstr "Цео број превелик код %C"
 
-#: fortran/match.c:580 fortran/parse.c:1132
+#: fortran/match.c:580 fortran/parse.c:1136
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many digits in statement label at %C"
 msgstr "Превише цифара у етикети наредбе код %C"
@@ -63315,62 +63398,62 @@
 msgid "Expected block name %qs of SELECT construct at %C"
 msgstr "Очекивано је име блока за ‘%s’ у наредби %s код %C"
 
-#: fortran/match.c:6186
+#: fortran/match.c:6201
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "parse error in SELECT TYPE statement at %C"
 msgstr "Синтаксна грешка у наредби SAVE код %C"
 
-#: fortran/match.c:6211
+#: fortran/match.c:6226
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr ""
 
-#: fortran/match.c:6249
+#: fortran/match.c:6264
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr "Неочекивана наредба CASE код %C"
 
-#: fortran/match.c:6301
+#: fortran/match.c:6316
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CASE-specification at %C"
 msgid "Syntax error in CASE specification at %C"
 msgstr "Синтаксна грешка у одредници CASE код %C"
 
-#: fortran/match.c:6319
+#: fortran/match.c:6334
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected END statement at %C"
 msgid "Unexpected TYPE IS statement at %C"
 msgstr "Неочекивана наредба END код %C"
 
-#: fortran/match.c:6351
+#: fortran/match.c:6366
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr ""
 
-#: fortran/match.c:6362
+#: fortran/match.c:6377
 #, gcc-internal-format, gfc-internal-format
 msgid "All the LEN type parameters in the TYPE IS statement at %C must be ASSUMED"
 msgstr ""
 
-#: fortran/match.c:6373
+#: fortran/match.c:6388
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CASE-specification at %C"
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr "Синтаксна грешка у одредници CASE код %C"
 
-#: fortran/match.c:6449
+#: fortran/match.c:6464
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CASE-specification at %C"
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr "Синтаксна грешка у одредници CASE код %C"
 
-#: fortran/match.c:6572
+#: fortran/match.c:6587
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr "Наредба ELSEWHERE код %C није обухваћена блоком WHERE"
 
-#: fortran/match.c:6610
+#: fortran/match.c:6625
 #, fuzzy, gcc-internal-format
 #| msgid "Label '%s' at %C doesn't match WHERE label '%s'"
 msgid "Label %qs at %C doesn't match WHERE label %qs"
@@ -63534,199 +63617,199 @@
 msgid "mio_array_ref(): Unknown array ref"
 msgstr ""
 
-#: fortran/module.c:3716
+#: fortran/module.c:3718
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Namelist %s cannot be renamed by USE association to %s."
 msgid "Namelist %s cannot be renamed by USE association to %s"
 msgstr "Листа имена %s не може се преименовати у %s придружењем USE."
 
-#: fortran/module.c:4832
+#: fortran/module.c:4834
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4835
+#: fortran/module.c:4837
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:5029
+#: fortran/module.c:5031
 #, gcc-internal-format
 msgid "%qs of module %qs, imported at %C, is also the name of the current program unit"
 msgstr ""
 
-#: fortran/module.c:5381
+#: fortran/module.c:5383
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' referenced at %L not found in module '%s'"
 msgid "Symbol %qs referenced at %L not found in module %qs"
 msgstr "Симбол ‘%s’ поменут код %L није нађен у модулу ‘%s’"
 
-#: fortran/module.c:5388
+#: fortran/module.c:5390
 #, fuzzy, gcc-internal-format
 #| msgid "User operator '%s' referenced at %L not found in module '%s'"
 msgid "User operator %qs referenced at %L not found in module %qs"
 msgstr "Кориснички оператор ‘%s’ поменут код %L није нађен у модулу ‘%s’"
 
-#: fortran/module.c:5393
+#: fortran/module.c:5395
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic operator '%s' referenced at %L not found in module '%s'"
 msgid "Intrinsic operator %qs referenced at %L not found in module %qs"
 msgstr "Сопствени оператор ‘%s’ поменут код %L није нађен у модулу ‘%s’"
 
-#: fortran/module.c:5628
+#: fortran/module.c:5630
 #, gcc-internal-format
 msgid "write_symbol(): bad module symbol %qs"
 msgstr ""
 
-#: fortran/module.c:5961
+#: fortran/module.c:5963
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr ""
 
-#: fortran/module.c:6148
+#: fortran/module.c:6150
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open module file '%s' for writing at %C: %s"
 msgid "Can't open module file %qs for writing at %C: %s"
 msgstr "Не могу да отворим датотеку модула ‘%s’ за писање код %C: %s"
 
-#: fortran/module.c:6169
+#: fortran/module.c:6171
 #, fuzzy, gcc-internal-format
 #| msgid "Error writing module file '%s' for writing: %s"
 msgid "Error writing module file %qs for writing: %s"
 msgstr "Грешка при отварању датотеке модула ‘%s’ за писање: %s"
 
-#: fortran/module.c:6180
+#: fortran/module.c:6182
 #, fuzzy, gcc-internal-format
 #| msgid "%s: can't delete file '%s': %s\n"
 msgid "Can't delete module file %qs: %s"
 msgstr "%s: не могу да обришем датотеку ‘%s’: %s\n"
 
-#: fortran/module.c:6183
+#: fortran/module.c:6185
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open module file '%s' for writing at %C: %s"
 msgid "Can't rename module file %qs to %qs: %s"
 msgstr "Не могу да отворим датотеку модула ‘%s’ за писање код %C: %s"
 
-#: fortran/module.c:6189
+#: fortran/module.c:6191
 #, fuzzy, gcc-internal-format
 #| msgid "%s: can't delete aux info file '%s': %s\n"
 msgid "Can't delete temporary module file %qs: %s"
 msgstr "%s: не могу да обришем помоћну инфотеку ‘%s’: %s\n"
 
-#: fortran/module.c:6246
+#: fortran/module.c:6248
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C already declared at %L"
 msgid "Symbol %qs at %C already declared"
 msgstr "Компонента ‘%s’ код %C већ је декларисана код %L"
 
-#: fortran/module.c:6317
+#: fortran/module.c:6319
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr ""
 
-#: fortran/module.c:6425 fortran/module.c:6769
+#: fortran/module.c:6427 fortran/module.c:6771
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L is not included in the selected standard"
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr "Сопствено ‘%s’ код %L није укључено у изабрани стандард"
 
-#: fortran/module.c:6553
+#: fortran/module.c:6555
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' referenced at %L not found in module '%s'"
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr "Симбол ‘%s’ поменут код %L није нађен у модулу ‘%s’"
 
-#: fortran/module.c:6574 fortran/module.c:6607 fortran/module.c:6649
+#: fortran/module.c:6576 fortran/module.c:6609 fortran/module.c:6651
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C already declared at %L"
 msgid "Symbol %qs already declared"
 msgstr "Компонента ‘%s’ код %C већ је декларисана код %L"
 
-#: fortran/module.c:6754
+#: fortran/module.c:6756
 #, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:6776
+#: fortran/module.c:6778
 #, gcc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr ""
 
-#: fortran/module.c:6844
+#: fortran/module.c:6846
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr ""
 
-#: fortran/module.c:6898
+#: fortran/module.c:6900
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' referenced at %L not found in module '%s'"
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr "Симбол ‘%s’ поменут код %L није нађен у модулу ‘%s’"
 
-#: fortran/module.c:6924
+#: fortran/module.c:6926
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement at %C is not within a loop"
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr "Наредба %s код %C није унутар петље"
 
-#: fortran/module.c:6953
+#: fortran/module.c:6955
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr ""
 
-#: fortran/module.c:6965
+#: fortran/module.c:6967
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
 msgstr ""
 
-#: fortran/module.c:6978
+#: fortran/module.c:6980
 #, gcc-internal-format
 msgid "Can't find an intrinsic module named %qs at %C"
 msgstr ""
 
-#: fortran/module.c:6984
+#: fortran/module.c:6986
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr ""
 
-#: fortran/module.c:6990
+#: fortran/module.c:6992
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr ""
 
-#: fortran/module.c:6996
+#: fortran/module.c:6998
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr ""
 
-#: fortran/module.c:7006
+#: fortran/module.c:7008
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open module file '%s' for reading at %C: %s"
 msgid "Can't open module file %qs for reading at %C: %s"
 msgstr "Не могу да отворим датотеку модула ‘%s’ за читање код %C: %s"
 
-#: fortran/module.c:7009
+#: fortran/module.c:7011
 #, gcc-internal-format
 msgid "Module file %qs has not been generated, either because the module does not contain a MODULE PROCEDURE or there is an error in the module."
 msgstr ""
 
-#: fortran/module.c:7020
+#: fortran/module.c:7022
 #, gcc-internal-format
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:7043
+#: fortran/module.c:7045
 #, fuzzy, gcc-internal-format
 #| msgid "File '%s' opened at %C is not a GFORTRAN module file"
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr "Датотека ‘%s’ отворена код %C није модул Гфортрана"
 
-#: fortran/module.c:7051
+#: fortran/module.c:7053
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr ""
 
-#: fortran/module.c:7066
+#: fortran/module.c:7068
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Can't USE the same module we're building!"
 msgid "Can't USE the same %smodule we're building"
@@ -63733,7 +63816,7 @@
 msgstr "Не може USE за исти модул који градимо!"
 
 #: fortran/openmp.c:296 fortran/openmp.c:397 fortran/openmp.c:692
-#: fortran/openmp.c:3167
+#: fortran/openmp.c:3166
 #, gcc-internal-format, gfc-internal-format
 msgid "COMMON block /%s/ not found at %C"
 msgstr "Заједнички блок /%s/ није нађен код %C"
@@ -63817,536 +63900,536 @@
 #: fortran/openmp.c:2180
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid third argument of IBITS at %L"
-msgid "Invalid argument to !$ACC WAIT at %L"
+msgid "Invalid argument to !$ACC WAIT at %C"
 msgstr "Неисправан трећи аргумент у IBITS код %L"
 
-#: fortran/openmp.c:2188
+#: fortran/openmp.c:2187
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "NUM_THREADS clause at %L requires a scalar INTEGER expression"
 msgid "WAIT clause at %L requires a scalar INTEGER expression"
 msgstr "Одредба NUM_THREADS код %L захтева скаларни целобројни израз"
 
-#: fortran/openmp.c:2221
+#: fortran/openmp.c:2220
 #, gcc-internal-format, gfc-internal-format
 msgid "ACC CACHE directive must be inside of loop %C"
 msgstr ""
 
-#: fortran/openmp.c:2252
+#: fortran/openmp.c:2251
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for typename"
 msgid "Multiple loop axes specified for routine"
 msgstr "складишна класа наведена за име типа"
 
-#: fortran/openmp.c:2278
+#: fortran/openmp.c:2277
 #, gcc-internal-format, gfc-internal-format
 msgid "Only the !$ACC ROUTINE form without list is allowed in interface block at %C"
 msgstr ""
 
-#: fortran/openmp.c:2306
+#: fortran/openmp.c:2305
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$ACC ROUTINE ( NAME ) at %C, invalid function name %s"
 msgstr ""
 
-#: fortran/openmp.c:2315
+#: fortran/openmp.c:2314
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in !$OMP THREADPRIVATE list at %C"
 msgid "Syntax error in !$ACC ROUTINE ( NAME ) at %C"
 msgstr "Синтаксна грешка у листи !$OMP THREADPRIVATE код %C"
 
-#: fortran/openmp.c:2322
+#: fortran/openmp.c:2321
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$ACC ROUTINE ( NAME ) at %C, expecting ')' after NAME"
 msgstr ""
 
-#: fortran/openmp.c:2457 fortran/openmp.c:2481
+#: fortran/openmp.c:2456 fortran/openmp.c:2480
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after ELSE statement at %C"
 msgid "Unexpected junk after $OMP CRITICAL statement at %C"
 msgstr "Неочекивано смеће после наредбе ELSE код %C"
 
-#: fortran/openmp.c:2548
+#: fortran/openmp.c:2547
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after ELSE statement at %C"
 msgid "Unexpected junk after $OMP FLUSH statement at %C"
 msgstr "Неочекивано смеће после наредбе ELSE код %C"
 
-#: fortran/openmp.c:2942 fortran/openmp.c:6225
+#: fortran/openmp.c:2941 fortran/openmp.c:6230
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined %s !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2946 fortran/openmp.c:6229
+#: fortran/openmp.c:2945 fortran/openmp.c:6234
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2951
+#: fortran/openmp.c:2950
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2953
+#: fortran/openmp.c:2952
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2973
+#: fortran/openmp.c:2972
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after ELSE statement at %C"
 msgid "Unexpected junk after !$OMP DECLARE REDUCTION at %C"
 msgstr "Неочекивано смеће после наредбе ELSE код %C"
 
-#: fortran/openmp.c:3010
+#: fortran/openmp.c:3009
 #, gcc-internal-format, gfc-internal-format
 msgid "Only the !$OMP DECLARE TARGET form without clauses is allowed in interface block at %C"
 msgstr ""
 
-#: fortran/openmp.c:3025
+#: fortran/openmp.c:3024
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after ELSE statement at %C"
 msgid "Unexpected junk after !$OMP DECLARE TARGET at %C"
 msgstr "Неочекивано смеће после наредбе ELSE код %C"
 
-#: fortran/openmp.c:3048
+#: fortran/openmp.c:3047
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Threadprivate variable at %C is an element of a COMMON block"
 msgid "OMP DECLARE TARGET variable at %L is an element of a COMMON block"
 msgstr "Нитно-приватна променљива код %C елемент је заједничког блока"
 
-#: fortran/openmp.c:3053
+#: fortran/openmp.c:3052
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET variable at %L previously mentioned in LINK clause and later in TO clause"
 msgstr ""
 
-#: fortran/openmp.c:3059
+#: fortran/openmp.c:3058
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET variable at %L previously mentioned in TO clause and later in LINK clause"
 msgstr ""
 
-#: fortran/openmp.c:3063
+#: fortran/openmp.c:3062
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable at %L mentioned multiple times in clauses of the same OMP DECLARE TARGET directive"
 msgstr ""
 
-#: fortran/openmp.c:3078
+#: fortran/openmp.c:3077
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET COMMON at %L previously mentioned in LINK clause and later in TO clause"
 msgstr ""
 
-#: fortran/openmp.c:3084
+#: fortran/openmp.c:3083
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET COMMON at %L previously mentioned in TO clause and later in LINK clause"
 msgstr ""
 
-#: fortran/openmp.c:3088
+#: fortran/openmp.c:3087
 #, gcc-internal-format, gfc-internal-format
 msgid "COMMON at %L mentioned multiple times in clauses of the same OMP DECLARE TARGET directive"
 msgstr ""
 
-#: fortran/openmp.c:3115
+#: fortran/openmp.c:3114
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in !$OMP THREADPRIVATE list at %C"
 msgid "Syntax error in !$OMP DECLARE TARGET list at %C"
 msgstr "Синтаксна грешка у листи !$OMP THREADPRIVATE код %C"
 
-#: fortran/openmp.c:3147
+#: fortran/openmp.c:3146
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate variable at %C is an element of a COMMON block"
 msgstr "Нитно-приватна променљива код %C елемент је заједничког блока"
 
-#: fortran/openmp.c:3184
+#: fortran/openmp.c:3183
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after ELSE statement at %C"
 msgid "Unexpected junk after OMP THREADPRIVATE at %C"
 msgstr "Неочекивано смеће после наредбе ELSE код %C"
 
-#: fortran/openmp.c:3191
+#: fortran/openmp.c:3190
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$OMP THREADPRIVATE list at %C"
 msgstr "Синтаксна грешка у листи !$OMP THREADPRIVATE код %C"
 
-#: fortran/openmp.c:3405
+#: fortran/openmp.c:3404
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after ELSE statement at %C"
 msgid "Unexpected junk after TASKWAIT clause at %C"
 msgstr "Неочекивано смеће после наредбе ELSE код %C"
 
-#: fortran/openmp.c:3419
+#: fortran/openmp.c:3418
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after ELSE statement at %C"
 msgid "Unexpected junk after TASKYIELD clause at %C"
 msgstr "Неочекивано смеће после наредбе ELSE код %C"
 
-#: fortran/openmp.c:3478
+#: fortran/openmp.c:3477
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after ELSE statement at %C"
 msgid "Unexpected junk after $OMP WORKSHARE statement at %C"
 msgstr "Неочекивано смеће после наредбе ELSE код %C"
 
-#: fortran/openmp.c:3492
+#: fortran/openmp.c:3491
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after ELSE statement at %C"
 msgid "Unexpected junk after $OMP MASTER statement at %C"
 msgstr "Неочекивано смеће после наредбе ELSE код %C"
 
-#: fortran/openmp.c:3551
+#: fortran/openmp.c:3550
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after ELSE IF statement at %C"
 msgid "Unexpected junk after $OMP ATOMIC statement at %C"
 msgstr "Неочекивано смеће после наредбе ELSE IF код %C"
 
-#: fortran/openmp.c:3578
+#: fortran/openmp.c:3577
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after ELSE statement at %C"
 msgid "Unexpected junk after $OMP BARRIER statement at %C"
 msgstr "Неочекивано смеће после наредбе ELSE код %C"
 
-#: fortran/openmp.c:3592
+#: fortran/openmp.c:3591
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after ELSE statement at %C"
 msgid "Unexpected junk after $OMP TASKGROUP statement at %C"
 msgstr "Неочекивано смеће после наредбе ELSE код %C"
 
-#: fortran/openmp.c:3642
+#: fortran/openmp.c:3641
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after ELSE IF statement at %C"
 msgid "Unexpected junk after $OMP CANCELLATION POINT statement at %C"
 msgstr "Неочекивано смеће после наредбе ELSE IF код %C"
 
-#: fortran/openmp.c:3662
+#: fortran/openmp.c:3661
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after ELSE statement at %C"
 msgid "Unexpected junk after NOWAIT clause at %C"
 msgstr "Неочекивано смеће после наредбе ELSE код %C"
 
-#: fortran/openmp.c:3704
+#: fortran/openmp.c:3703
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "NUM_THREADS clause at %L requires a scalar INTEGER expression"
 msgid "%s clause at %L requires a scalar INTEGER expression"
 msgstr "Одредба NUM_THREADS код %L захтева скаларни целобројни израз"
 
-#: fortran/openmp.c:3715
+#: fortran/openmp.c:3714
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in CASE statement at %L must be of type %s"
 msgid "INTEGER expression of %s clause at %L must be positive"
 msgstr "Израз у наредби CASE код %L мора бити типа %s"
 
-#: fortran/openmp.c:3726
+#: fortran/openmp.c:3725
 #, gcc-internal-format, gfc-internal-format
 msgid "INTEGER expression of %s clause at %L must be non-negative"
 msgstr ""
 
-#: fortran/openmp.c:3737
+#: fortran/openmp.c:3736
 #, fuzzy, gcc-internal-format
 #| msgid "POINTER object '%s' in %s clause at %L"
 msgid "POINTER object %qs of derived type in %s clause at %L"
 msgstr "Показивачки објекат ‘%s’ у одредби %s код %L"
 
-#: fortran/openmp.c:3740
+#: fortran/openmp.c:3739
 #, fuzzy, gcc-internal-format
 #| msgid "Cray pointer '%s' in %s clause at %L"
 msgid "Cray pointer object %qs of derived type in %s clause at %L"
 msgstr "Крејов показивач ‘%s’ у одредби %s код %L"
 
-#: fortran/openmp.c:3743
+#: fortran/openmp.c:3742
 #, fuzzy, gcc-internal-format
 #| msgid "Cray pointee '%s' in %s clause at %L"
 msgid "Cray pointee object %qs of derived type in %s clause at %L"
 msgstr "Крејов показивани ‘%s’ у одредби %s код %L"
 
-#: fortran/openmp.c:3749 fortran/openmp.c:4687
+#: fortran/openmp.c:3748 fortran/openmp.c:4686
 #, fuzzy, gcc-internal-format
 #| msgid "POINTER object '%s' in %s clause at %L"
 msgid "POINTER object %qs of polymorphic type in %s clause at %L"
 msgstr "Показивачки објекат ‘%s’ у одредби %s код %L"
 
-#: fortran/openmp.c:3754
+#: fortran/openmp.c:3753
 #, fuzzy, gcc-internal-format
 #| msgid "Cray pointer '%s' in %s clause at %L"
 msgid "Cray pointer object %qs of polymorphic type in %s clause at %L"
 msgstr "Крејов показивач ‘%s’ у одредби %s код %L"
 
-#: fortran/openmp.c:3759
+#: fortran/openmp.c:3758
 #, fuzzy, gcc-internal-format
 #| msgid "Cray pointee '%s' in %s clause at %L"
 msgid "Cray pointee object %qs of polymorphic type in %s clause at %L"
 msgstr "Крејов показивани ‘%s’ у одредби %s код %L"
 
-#: fortran/openmp.c:3769 fortran/openmp.c:4385 fortran/openmp.c:4490
+#: fortran/openmp.c:3768 fortran/openmp.c:4384 fortran/openmp.c:4489
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed size array '%s' in %s clause at %L"
 msgid "Assumed size array %qs in %s clause at %L"
 msgstr "Низ претпостављене величине ‘%s’ у одредби ‘%s’ код %L"
 
-#: fortran/openmp.c:3772
+#: fortran/openmp.c:3771
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed size array '%s' in %s clause at %L"
 msgid "Assumed rank array %qs in %s clause at %L"
 msgstr "Низ претпостављене величине ‘%s’ у одредби ‘%s’ код %L"
 
-#: fortran/openmp.c:3776
+#: fortran/openmp.c:3775
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed size array '%s' in %s clause at %L"
 msgid "Noncontiguous deferred shape array %qs in %s clause at %L"
 msgstr "Низ претпостављене величине ‘%s’ у одредби ‘%s’ код %L"
 
-#: fortran/openmp.c:3784
+#: fortran/openmp.c:3783
 #, fuzzy, gcc-internal-format
 #| msgid "POINTER object '%s' in %s clause at %L"
 msgid "ALLOCATABLE object %qs of derived type in %s clause at %L"
 msgstr "Показивачки објекат ‘%s’ у одредби %s код %L"
 
-#: fortran/openmp.c:3789
+#: fortran/openmp.c:3788
 #, fuzzy, gcc-internal-format
 #| msgid "POINTER object '%s' in %s clause at %L"
 msgid "ALLOCATABLE object %qs of polymorphic type in %s clause at %L"
 msgstr "Показивачки објекат ‘%s’ у одредби %s код %L"
 
-#: fortran/openmp.c:3801 fortran/openmp.c:4480
+#: fortran/openmp.c:3800 fortran/openmp.c:4479
 #, fuzzy, gcc-internal-format
 #| msgid "POINTER object '%s' in %s clause at %L"
 msgid "POINTER object %qs in %s clause at %L"
 msgstr "Показивачки објекат ‘%s’ у одредби %s код %L"
 
-#: fortran/openmp.c:3806 fortran/openmp.c:4691
+#: fortran/openmp.c:3805 fortran/openmp.c:4690
 #, fuzzy, gcc-internal-format
 #| msgid "Cray pointer '%s' in %s clause at %L"
 msgid "Cray pointer object %qs in %s clause at %L"
 msgstr "Крејов показивач ‘%s’ у одредби %s код %L"
 
-#: fortran/openmp.c:3811 fortran/openmp.c:4694
+#: fortran/openmp.c:3810 fortran/openmp.c:4693
 #, fuzzy, gcc-internal-format
 #| msgid "Cray pointee '%s' in %s clause at %L"
 msgid "Cray pointee object %qs in %s clause at %L"
 msgstr "Крејов показивани ‘%s’ у одредби %s код %L"
 
-#: fortran/openmp.c:3816 fortran/openmp.c:4682
+#: fortran/openmp.c:3815 fortran/openmp.c:4681
 #, fuzzy, gcc-internal-format
 #| msgid "POINTER object '%s' in %s clause at %L"
 msgid "ALLOCATABLE object %qs in %s clause at %L"
 msgstr "Показивачки објекат ‘%s’ у одредби %s код %L"
 
-#: fortran/openmp.c:3819
+#: fortran/openmp.c:3818
 #, fuzzy, gcc-internal-format
 #| msgid "POINTER object '%s' in %s clause at %L"
 msgid "VALUE object %qs in %s clause at %L"
 msgstr "Показивачки објекат ‘%s’ у одредби %s код %L"
 
-#: fortran/openmp.c:3862
+#: fortran/openmp.c:3861
 #, gcc-internal-format, gfc-internal-format
 msgid "Implicitly declared function %s used in !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:3911
+#: fortran/openmp.c:3910
 #, gcc-internal-format, gfc-internal-format
 msgid "Implicitly declared subroutine %s used in !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:3944
+#: fortran/openmp.c:3943
 #, gcc-internal-format, gfc-internal-format
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:3952 fortran/openmp.c:3963 fortran/resolve.c:10028
-#: fortran/resolve.c:11295
+#: fortran/openmp.c:3951 fortran/openmp.c:3962 fortran/resolve.c:10041
+#: fortran/resolve.c:11315
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "Одредба IF код %L захтева скаларни логички израз"
 
-#: fortran/openmp.c:3967
+#: fortran/openmp.c:3966
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause without modifier at %L used together with IF clauses with modifiers"
 msgstr ""
 
-#: fortran/openmp.c:4044
+#: fortran/openmp.c:4043
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause modifier %s at %L not appropriate for the current OpenMP construct"
 msgstr ""
 
-#: fortran/openmp.c:4054
+#: fortran/openmp.c:4053
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgid "FINAL clause at %L requires a scalar LOGICAL expression"
 msgstr "Одредба IF код %L захтева скаларни логички израз"
 
-#: fortran/openmp.c:4064
+#: fortran/openmp.c:4063
 #, gcc-internal-format, gfc-internal-format
 msgid "SCHEDULE clause's chunk_size at %L requires a scalar INTEGER expression"
 msgstr "Величина одломка у одредби SCHEDULE код %L захтева скаларни целобројни израз"
 
-#: fortran/openmp.c:4069
+#: fortran/openmp.c:4068
 #, gcc-internal-format, gfc-internal-format
 msgid "INTEGER expression of SCHEDULE clause's chunk_size at %L must be positive"
 msgstr ""
 
-#: fortran/openmp.c:4084
+#: fortran/openmp.c:4083
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' has not been assigned a target label at %L"
 msgid "Variable %qs is not a dummy argument at %L"
 msgstr "Променљивој ‘%s’ није додељена циљна етикета код %L"
 
-#: fortran/openmp.c:4116
+#: fortran/openmp.c:4115 fortran/openmp.c:5998
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "Object %qs is not a variable at %L"
 msgstr "%qE није променљива у одредби %qs"
 
-#: fortran/openmp.c:4132 fortran/openmp.c:4143 fortran/openmp.c:4151
-#: fortran/openmp.c:4162 fortran/openmp.c:4174 fortran/openmp.c:4189
-#: fortran/openmp.c:6023
+#: fortran/openmp.c:4131 fortran/openmp.c:4142 fortran/openmp.c:4150
+#: fortran/openmp.c:4161 fortran/openmp.c:4173 fortran/openmp.c:4188
+#: fortran/openmp.c:6028
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' present on multiple clauses at %L"
 msgid "Symbol %qs present on multiple clauses at %L"
 msgstr "Симбол ‘%s’ присутан у више одредби код %L"
 
-#: fortran/openmp.c:4196
+#: fortran/openmp.c:4195
 #, gcc-internal-format
 msgid "Array %qs is not permitted in reduction at %L"
 msgstr ""
 
-#: fortran/openmp.c:4209
+#: fortran/openmp.c:4208
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' present on multiple clauses at %L"
 msgid "Symbol %qs present on both FROM and TO clauses at %L"
 msgstr "Симбол ‘%s’ присутан у више одредби код %L"
 
-#: fortran/openmp.c:4231
+#: fortran/openmp.c:4230
 #, fuzzy, gcc-internal-format
 #| msgid "Non-THREADPRIVATE object '%s' in COPYIN clause at %L"
 msgid "Non-THREADPRIVATE object %qs in COPYIN clause at %L"
 msgstr "Не-нитно-приватан објекат ‘%s’ у одредби COPYIN код %L"
 
-#: fortran/openmp.c:4239
+#: fortran/openmp.c:4238
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed size array '%s' in COPYPRIVATE clause at %L"
 msgid "Assumed size array %qs in COPYPRIVATE clause at %L"
 msgstr "Низ претпостављене величине ‘%s’ у одредби COPYPRIVATE код %L"
 
-#: fortran/openmp.c:4242
+#: fortran/openmp.c:4241
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed size array '%s' in COPYPRIVATE clause at %L"
 msgid "INTENT(IN) POINTER %qs in COPYPRIVATE clause at %L"
 msgstr "Низ претпостављене величине ‘%s’ у одредби COPYPRIVATE код %L"
 
-#: fortran/openmp.c:4250
+#: fortran/openmp.c:4249
 #, fuzzy, gcc-internal-format
 #| msgid "THREADPRIVATE object '%s' in SHARED clause at %L"
 msgid "THREADPRIVATE object %qs in SHARED clause at %L"
 msgstr "Нитно-приватан објекат ‘%s’ у одредби SHARED код %L"
 
-#: fortran/openmp.c:4253
+#: fortran/openmp.c:4252
 #, fuzzy, gcc-internal-format
 #| msgid "Cray pointee '%s' in SHARED clause at %L"
 msgid "Cray pointee %qs in SHARED clause at %L"
 msgstr "Крејов показивани ‘%s’ у одредби SHARED код %L"
 
-#: fortran/openmp.c:4256
+#: fortran/openmp.c:4255
 #, fuzzy, gcc-internal-format
 #| msgid "THREADPRIVATE object '%s' in SHARED clause at %L"
 msgid "ASSOCIATE name %qs in SHARED clause at %L"
 msgstr "Нитно-приватан објекат ‘%s’ у одредби SHARED код %L"
 
-#: fortran/openmp.c:4271
+#: fortran/openmp.c:4270
 #, gcc-internal-format
 msgid "%qs in ALIGNED clause must be POINTER, ALLOCATABLE, Cray pointer or C_PTR at %L"
 msgstr ""
 
-#: fortran/openmp.c:4283
+#: fortran/openmp.c:4282
 #, fuzzy, gcc-internal-format
 #| msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgid "%qs in ALIGNED clause at %L requires a scalar positive constant integer alignment expression"
 msgstr "Одредба IF код %L захтева скаларни логички израз"
 
-#: fortran/openmp.c:4302
+#: fortran/openmp.c:4301
 #, gcc-internal-format, gfc-internal-format
 msgid "SINK dependence type only allowed on ORDERED directive at %L"
 msgstr ""
 
-#: fortran/openmp.c:4306
+#: fortran/openmp.c:4305
 #, gcc-internal-format, gfc-internal-format
 msgid "DEPEND SINK used together with DEPEND SOURCE on the same construct at %L"
 msgstr ""
 
-#: fortran/openmp.c:4316
+#: fortran/openmp.c:4315
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "accumulator is not a constant integer"
 msgid "SINK addend not a constant integer at %L"
 msgstr "акумулатор није целобројна константа"
 
-#: fortran/openmp.c:4322
+#: fortran/openmp.c:4321
 #, gcc-internal-format, gfc-internal-format
 msgid "Only SOURCE or SINK dependence types are allowed on ORDERED directive at %L"
 msgstr ""
 
-#: fortran/openmp.c:4333 fortran/openmp.c:4354
+#: fortran/openmp.c:4332 fortran/openmp.c:4353
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' in %s statement at %C is not a loop name"
 msgid "%qs in %s clause at %L is not a proper array section"
 msgstr "Име ‘%s’ у наредби %s код %C није име петље"
 
-#: fortran/openmp.c:4337
+#: fortran/openmp.c:4336
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Cray pointee '%s' in %s clause at %L"
 msgid "Coarrays not supported in %s clause at %L"
 msgstr "Крејов показивани ‘%s’ у одредби %s код %L"
 
-#: fortran/openmp.c:4346
+#: fortran/openmp.c:4345
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed size array '%s' in %s clause at %L"
 msgid "Stride should not be specified for array section in %s clause at %L"
 msgstr "Низ претпостављене величине ‘%s’ у одредби ‘%s’ код %L"
 
-#: fortran/openmp.c:4367
+#: fortran/openmp.c:4366
 #, gcc-internal-format
 msgid "%qs in DEPEND clause at %L is a zero size array section"
 msgstr ""
 
-#: fortran/openmp.c:4403
+#: fortran/openmp.c:4402
 #, gcc-internal-format, gfc-internal-format
 msgid "TARGET%s with map-type other than TO, FROM, TOFROM, or ALLOC on MAP clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4419
+#: fortran/openmp.c:4418
 #, gcc-internal-format, gfc-internal-format
 msgid "TARGET ENTER DATA with map-type other than TO, or ALLOC on MAP clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4434
+#: fortran/openmp.c:4433
 #, gcc-internal-format, gfc-internal-format
 msgid "TARGET EXIT DATA with map-type other than FROM, RELEASE, or DELETE on MAP clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4450 fortran/openmp.c:4466
+#: fortran/openmp.c:4449 fortran/openmp.c:4465
 #, fuzzy, gcc-internal-format
 #| msgid "THREADPRIVATE object '%s' in %s clause at %L"
 msgid "THREADPRIVATE object %qs in %s clause at %L"
 msgstr "Нитно-приватан објекат ‘%s’ у одредби %s код %L"
 
-#: fortran/openmp.c:4453 fortran/openmp.c:4469
+#: fortran/openmp.c:4452 fortran/openmp.c:4468
 #, fuzzy, gcc-internal-format
 #| msgid "Cray pointee '%s' in %s clause at %L"
 msgid "Cray pointee %qs in %s clause at %L"
 msgstr "Крејов показивани ‘%s’ у одредби %s код %L"
 
-#: fortran/openmp.c:4472
+#: fortran/openmp.c:4471
 #, fuzzy, gcc-internal-format
 #| msgid "POINTER object '%s' in %s clause at %L"
 msgid "ASSOCIATE name %qs in %s clause at %L"
 msgstr "Показивачки објекат ‘%s’ у одредби %s код %L"
 
-#: fortran/openmp.c:4477
+#: fortran/openmp.c:4476
 #, fuzzy, gcc-internal-format
 #| msgid "Cray pointer '%s' in %s clause at %L"
 msgid "Procedure pointer %qs in %s clause at %L"
 msgstr "Крејов показивач ‘%s’ у одредби %s код %L"
 
-#: fortran/openmp.c:4483
+#: fortran/openmp.c:4482
 #, fuzzy, gcc-internal-format
 #| msgid "Cray pointer '%s' in %s clause at %L"
 msgid "Cray pointer %qs in %s clause at %L"
 msgstr "Крејов показивач ‘%s’ у одредби %s код %L"
 
-#: fortran/openmp.c:4493
+#: fortran/openmp.c:4492
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' in %s clause is used in NAMELIST statement at %L"
 msgid "Variable %qs in %s clause is used in NAMELIST statement at %L"
@@ -64353,413 +64436,413 @@
 msgstr "Променљива ‘%s’ у одредби %s употребљена је у листи имена код %L"
 
 #. case OMP_LIST_REDUCTION:
-#: fortran/openmp.c:4503
+#: fortran/openmp.c:4502
 #, fuzzy, gcc-internal-format
 #| msgid "POINTER object '%s' in %s clause at %L"
 msgid "INTENT(IN) POINTER %qs in %s clause at %L"
 msgstr "Показивачки објекат ‘%s’ у одредби %s код %L"
 
-#: fortran/openmp.c:4596
+#: fortran/openmp.c:4595
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP DECLARE REDUCTION %s not found for type %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:4622
+#: fortran/openmp.c:4621
 #, gcc-internal-format, gfc-internal-format
 msgid "LINEAR clause modifier used on DO or SIMD construct at %L"
 msgstr ""
 
-#: fortran/openmp.c:4627
+#: fortran/openmp.c:4626
 #, gcc-internal-format, gfc-internal-format
 msgid "LINEAR clause specified together with ORDERED clause with argument at %L"
 msgstr ""
 
-#: fortran/openmp.c:4632
+#: fortran/openmp.c:4631
 #, fuzzy, gcc-internal-format
 #| msgid "%s REDUCTION variable '%s' must be INTEGER at %L"
 msgid "LINEAR variable %qs must be INTEGER at %L"
 msgstr "Променљива %s-свођења ‘%s’ мора бити целобројна код %L"
 
-#: fortran/openmp.c:4637
+#: fortran/openmp.c:4636
 #, gcc-internal-format
 msgid "LINEAR dummy argument %qs with VALUE attribute with %s modifier at %L"
 msgstr ""
 
-#: fortran/openmp.c:4648
+#: fortran/openmp.c:4647
 #, fuzzy, gcc-internal-format
 #| msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgid "%qs in LINEAR clause at %L requires a scalar integer linear-step expression"
 msgstr "Одредба IF код %L захтева скаларни логички израз"
 
-#: fortran/openmp.c:4665
+#: fortran/openmp.c:4664
 #, gcc-internal-format
 msgid "%qs in LINEAR clause at %L requires a constant integer linear-step expression or dummy argument specified in UNIFORM clause"
 msgstr ""
 
-#: fortran/openmp.c:4699
+#: fortran/openmp.c:4698
 #, gcc-internal-format
 msgid "%s clause variable %qs at %L is neither a POINTER nor an array"
 msgstr ""
 
-#: fortran/openmp.c:4731
+#: fortran/openmp.c:4730
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "SCHEDULE clause's chunk_size at %L requires a scalar INTEGER expression"
 msgid "DIST_SCHEDULE clause's chunk_size at %L requires a scalar INTEGER expression"
 msgstr "Величина одломка у одредби SCHEDULE код %L захтева скаларни целобројни израз"
 
-#: fortran/openmp.c:4763
+#: fortran/openmp.c:4762
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Incompatible ranks in %s at %L"
 msgid "Incompatible use of TILE and COLLAPSE at %L"
 msgstr "Несагласни рангови у %s код %L"
 
-#: fortran/openmp.c:4765
+#: fortran/openmp.c:4764
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE dependence type only allowed on ORDERED directive at %L"
 msgstr ""
 
-#: fortran/openmp.c:4778
+#: fortran/openmp.c:4777
 #, gcc-internal-format, gfc-internal-format
 msgid "%s must contain at least one MAP clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4875
+#: fortran/openmp.c:4874
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected exponent in expression at %C"
 msgid "unexpected !$OMP ATOMIC expression at %L"
 msgstr "Очекиван је изложилац у изразу код %C"
 
-#: fortran/openmp.c:4904
+#: fortran/openmp.c:4903
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC statement must set a scalar variable of intrinsic type at %L"
 msgstr "Наредба !$OMP ATOMIC мора поставити скаларну променљиву сопственог типа код %L"
 
-#: fortran/openmp.c:4929
+#: fortran/openmp.c:4928
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "!$OMP ATOMIC statement must set a scalar variable of intrinsic type at %L"
 msgid "!$OMP ATOMIC READ statement must read from a scalar variable of intrinsic type at %L"
 msgstr "Наредба !$OMP ATOMIC мора поставити скаларну променљиву сопственог типа код %L"
 
-#: fortran/openmp.c:4934
+#: fortran/openmp.c:4933
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "expr in !$OMP ATOMIC assignment var = var op expr must be scalar and cannot reference var at %L"
 msgid "expr in !$OMP ATOMIC WRITE assignment var = expr must be scalar and cannot reference var at %L"
 msgstr "„израз“ у додели у !$OMP ATOMIC типа „пром = пром оп израз“ мора бити скаларан и не може садржати „пром“ код %L"
 
-#: fortran/openmp.c:4956 fortran/openmp.c:5247
+#: fortran/openmp.c:4955 fortran/openmp.c:5246
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "!$OMP ATOMIC statement must set a scalar variable of intrinsic type at %L"
 msgid "!$OMP ATOMIC CAPTURE capture statement must read from a scalar variable of intrinsic type at %L"
 msgstr "Наредба !$OMP ATOMIC мора поставити скаларну променљиву сопственог типа код %L"
 
-#: fortran/openmp.c:4971
+#: fortran/openmp.c:4970
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "!$OMP ATOMIC statement must set a scalar variable of intrinsic type at %L"
 msgid "!$OMP ATOMIC CAPTURE update statement must set a scalar variable of intrinsic type at %L"
 msgstr "Наредба !$OMP ATOMIC мора поставити скаларну променљиву сопственог типа код %L"
 
-#: fortran/openmp.c:4978 fortran/openmp.c:5254
+#: fortran/openmp.c:4977 fortran/openmp.c:5253
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE capture statement reads from different variable than update statement writes into at %L"
 msgstr ""
 
-#: fortran/openmp.c:4994
+#: fortran/openmp.c:4993
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC with ALLOCATABLE variable at %L"
 msgstr ""
 
-#: fortran/openmp.c:5036
+#: fortran/openmp.c:5035
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "!$OMP ATOMIC assignment operator must be +, *, -, /, .AND., .OR., .EQV. or .NEQV. at %L"
 msgid "!$OMP ATOMIC assignment operator must be binary +, *, -, /, .AND., .OR., .EQV. or .NEQV. at %L"
 msgstr "Оператор доделе у !$OMP ATOMIC мора бити једно од +, *, -, /, .AND., .OR., .EQV., .NEQV. код %L"
 
-#: fortran/openmp.c:5084
+#: fortran/openmp.c:5083
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment must be var = var op expr or var = expr op var at %L"
 msgstr "Додела у !$OMP ATOMIC мора бити „пром = пром оп израз“, или „пром = израз оп пром“ код %L"
 
-#: fortran/openmp.c:5098
+#: fortran/openmp.c:5097
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC var = var op expr not mathematically equivalent to var = var op (expr) at %L"
 msgstr "„пром = пром оп израз“ у !$OMP ATOMIC није математички истоветан са „пром = пром оп (израз)“ код %L"
 
-#: fortran/openmp.c:5130
+#: fortran/openmp.c:5129
 #, gcc-internal-format, gfc-internal-format
 msgid "expr in !$OMP ATOMIC assignment var = var op expr must be scalar and cannot reference var at %L"
 msgstr "„израз“ у додели у !$OMP ATOMIC типа „пром = пром оп израз“ мора бити скаларан и не може садржати „пром“ код %L"
 
-#: fortran/openmp.c:5154
+#: fortran/openmp.c:5153
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "!$OMP ATOMIC assignment intrinsic IAND, IORor IEOR must have two arguments at %L"
 msgid "!$OMP ATOMIC assignment intrinsic IAND, IOR or IEOR must have two arguments at %L"
 msgstr "У додели у !$OMP ATOMIC сопствени IAND, IOR, IEORl морају имати два аргумента код %L"
 
-#: fortran/openmp.c:5161
+#: fortran/openmp.c:5160
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment intrinsic must be MIN, MAX, IAND, IOR or IEOR at %L"
 msgstr "Сопствени доделе у !$OMP ATOMIC мора бити MIN, MAX, IAND, IOR или IEOR код %L"
 
-#: fortran/openmp.c:5178
+#: fortran/openmp.c:5177
 #, fuzzy, gcc-internal-format
 #| msgid "!$OMP ATOMIC intrinsic arguments except one must not reference '%s' at %L"
 msgid "!$OMP ATOMIC intrinsic arguments except one must not reference %qs at %L"
 msgstr "Аргументи сопственог уз !$OMP ATOMIC, сви осим једног, не могу садржати ‘%s’ код %L"
 
-#: fortran/openmp.c:5185
+#: fortran/openmp.c:5184
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC intrinsic arguments must be scalar at %L"
 msgstr "Аргументи сопственог уз !$OMP ATOMIC морају бити скаларни код %L"
 
-#: fortran/openmp.c:5193
+#: fortran/openmp.c:5192
 #, fuzzy, gcc-internal-format
 #| msgid "First or last !$OMP ATOMIC intrinsic argument must be '%s' at %L"
 msgid "First or last !$OMP ATOMIC intrinsic argument must be %qs at %L"
 msgstr "Први или последњи аргумент сопственог уз !$OMP ATOMIC мора бити ‘%s’ код %L"
 
-#: fortran/openmp.c:5211
+#: fortran/openmp.c:5210
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment must have an operator or intrinsic on right hand side at %L"
 msgstr "Додела у !$OMP ATOMIC мора имати оператор или сопствени на десној страни код %L"
 
-#: fortran/openmp.c:5225
+#: fortran/openmp.c:5224
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "!$OMP ATOMIC statement must set a scalar variable of intrinsic type at %L"
 msgid "!$OMP ATOMIC CAPTURE capture statement must set a scalar variable of intrinsic type at %L"
 msgstr "Наредба !$OMP ATOMIC мора поставити скаларну променљиву сопственог типа код %L"
 
-#: fortran/openmp.c:5544
+#: fortran/openmp.c:5543
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "!$OMP DO cannot be a DO WHILE or DO without loop control at %L"
 msgid "%s cannot be a DO WHILE or DO without loop control at %L"
 msgstr "!$OMP DO не може бити DO WHILE или DO без контроле петље код %L"
 
-#: fortran/openmp.c:5550
+#: fortran/openmp.c:5549
 #, gcc-internal-format, gfc-internal-format
 msgid "%s cannot be a DO CONCURRENT loop at %L"
 msgstr ""
 
-#: fortran/openmp.c:5556
+#: fortran/openmp.c:5555
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "!$OMP DO iteration variable must be of type integer at %L"
 msgid "%s iteration variable must be of type integer at %L"
 msgstr "Променљива итерације у !$OMP DO мора бити целобројног типа код %L"
 
-#: fortran/openmp.c:5560
+#: fortran/openmp.c:5559
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "!$OMP DO iteration variable must not be THREADPRIVATE at %L"
 msgid "%s iteration variable must not be THREADPRIVATE at %L"
 msgstr "Променљива итерације у !$OMP DO не може бити нитно-локална код %L"
 
-#: fortran/openmp.c:5573
+#: fortran/openmp.c:5572
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "!$OMP DO iteration variable present on clause other than PRIVATE or LASTPRIVATE at %L"
 msgid "%s iteration variable present on clause other than PRIVATE or LASTPRIVATE at %L"
 msgstr "Променљива итерације у !$OMP DO присутна у одредби која није ни PRIVATE ни LASTPRIVATE код %L"
 
-#: fortran/openmp.c:5577
+#: fortran/openmp.c:5576
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "!$OMP DO iteration variable present on clause other than PRIVATE or LASTPRIVATE at %L"
 msgid "%s iteration variable present on clause other than LASTPRIVATE at %L"
 msgstr "Променљива итерације у !$OMP DO присутна у одредби која није ни PRIVATE ни LASTPRIVATE код %L"
 
-#: fortran/openmp.c:5581
+#: fortran/openmp.c:5580
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "!$OMP DO iteration variable present on clause other than PRIVATE or LASTPRIVATE at %L"
 msgid "%s iteration variable present on clause other than LINEAR at %L"
 msgstr "Променљива итерације у !$OMP DO присутна у одредби која није ни PRIVATE ни LASTPRIVATE код %L"
 
-#: fortran/openmp.c:5599
+#: fortran/openmp.c:5598
 #, gcc-internal-format, gfc-internal-format
 msgid "%s collapsed loops don't form rectangular iteration space at %L"
 msgstr ""
 
-#: fortran/openmp.c:5611
+#: fortran/openmp.c:5610
 #, gcc-internal-format, gfc-internal-format
 msgid "collapsed %s loops not perfectly nested at %L"
 msgstr ""
 
-#: fortran/openmp.c:5620 fortran/openmp.c:5628
+#: fortran/openmp.c:5619 fortran/openmp.c:5627
 #, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for collapsed %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:5712 fortran/openmp.c:5725
+#: fortran/openmp.c:5711 fortran/openmp.c:5724
 #, gcc-internal-format, gfc-internal-format
 msgid "The %s directive cannot be specified within a %s region at %L"
 msgstr ""
 
-#: fortran/openmp.c:5744
+#: fortran/openmp.c:5743
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "!$OMP DO cannot be a DO WHILE or DO without loop control at %L"
 msgid "!$ACC LOOP cannot be a DO WHILE or DO without loop control at %L"
 msgstr "!$OMP DO не може бити DO WHILE или DO без контроле петље код %L"
 
-#: fortran/openmp.c:5750
+#: fortran/openmp.c:5749
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "!$OMP DO iteration variable must be of type integer at %L"
 msgid "!$ACC LOOP iteration variable must be of type integer at %L"
 msgstr "Променљива итерације у !$OMP DO мора бити целобројног типа код %L"
 
-#: fortran/openmp.c:5766
+#: fortran/openmp.c:5765
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s loops don't form rectangular iteration space at %L"
 msgstr ""
 
-#: fortran/openmp.c:5778
+#: fortran/openmp.c:5777
 #, gcc-internal-format, gfc-internal-format
 msgid "%s !$ACC LOOP loops not perfectly nested at %L"
 msgstr ""
 
-#: fortran/openmp.c:5788 fortran/openmp.c:5797
+#: fortran/openmp.c:5787 fortran/openmp.c:5796
 #, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for %s !$ACC LOOP at %L"
 msgstr ""
 
-#: fortran/openmp.c:5812 fortran/openmp.c:5819
+#: fortran/openmp.c:5811 fortran/openmp.c:5818
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s in PARALLEL region doesn't allow %s arguments at %L"
 msgstr ""
 
-#: fortran/openmp.c:5841
+#: fortran/openmp.c:5840
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside another loop parallelized across gangs at %L"
 msgstr ""
 
-#: fortran/openmp.c:5845 fortran/openmp.c:5849
+#: fortran/openmp.c:5844 fortran/openmp.c:5848
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside loop parallelized across workers at %L"
 msgstr ""
 
-#: fortran/openmp.c:5856
+#: fortran/openmp.c:5855
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across workers at %L"
 msgstr ""
 
-#: fortran/openmp.c:5860
+#: fortran/openmp.c:5859
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across vectors at %L"
 msgstr ""
 
-#: fortran/openmp.c:5866
+#: fortran/openmp.c:5865
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across vectors is not allowed inside another loop parallelized across vectors at %L"
 msgstr ""
 
-#: fortran/openmp.c:5878
+#: fortran/openmp.c:5877
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgid "Clause SEQ conflicts with INDEPENDENT at %L"
 msgstr "Намера-%s коси се са намером-%s код %L"
 
-#: fortran/openmp.c:5880
+#: fortran/openmp.c:5879
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "Clause SEQ conflicts with GANG at %L"
 msgstr "Атрибут %s коси се са атрибутом %s код %L"
 
-#: fortran/openmp.c:5882
+#: fortran/openmp.c:5881
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with WORKER at %L"
 msgstr ""
 
-#: fortran/openmp.c:5884
+#: fortran/openmp.c:5883
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgid "Clause SEQ conflicts with VECTOR at %L"
 msgstr "Намера-%s коси се са намером-%s код %L"
 
-#: fortran/openmp.c:5886
+#: fortran/openmp.c:5885
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "Clause SEQ conflicts with AUTO at %L"
 msgstr "Атрибут %s коси се са атрибутом %s код %L"
 
-#: fortran/openmp.c:5891
+#: fortran/openmp.c:5890
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "Clause AUTO conflicts with GANG at %L"
 msgstr "Атрибут %s коси се са атрибутом %s код %L"
 
-#: fortran/openmp.c:5893
+#: fortran/openmp.c:5892
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with WORKER at %L"
 msgstr ""
 
-#: fortran/openmp.c:5895
+#: fortran/openmp.c:5894
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgid "Clause AUTO conflicts with VECTOR at %L"
 msgstr "Намера-%s коси се са намером-%s код %L"
 
-#: fortran/openmp.c:5899
+#: fortran/openmp.c:5898
 #, gcc-internal-format, gfc-internal-format
 msgid "Tiled loop cannot be parallelized across gangs, workers and vectors at the same time at %L"
 msgstr ""
 
-#: fortran/openmp.c:5934
+#: fortran/openmp.c:5933
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "LOGICAL operands are required in expression at %L"
 msgid "TILE requires constant expression at %L"
 msgstr "Неопходни су логички операнди у изразу код %L"
 
-#: fortran/openmp.c:5999
+#: fortran/openmp.c:6004
 #, fuzzy, gcc-internal-format
 #| msgid "POINTER object '%s' in %s clause at %L"
 msgid "PARAMETER object %qs is not allowed at %L"
 msgstr "Показивачки објекат ‘%s’ у одредби %s код %L"
 
-#: fortran/openmp.c:6006
+#: fortran/openmp.c:6011
 #, gcc-internal-format
 msgid "Array sections: %qs not allowed in !$ACC DECLARE at %L"
 msgstr ""
 
-#: fortran/openmp.c:6133
+#: fortran/openmp.c:6138
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP TARGET UPDATE at %L requires at least one TO or FROM clause"
 msgstr ""
 
-#: fortran/openmp.c:6155
+#: fortran/openmp.c:6160
 #, gcc-internal-format
 msgid "!$OMP DECLARE SIMD should refer to containing procedure %qs at %L"
 msgstr ""
 
-#: fortran/openmp.c:6179
+#: fortran/openmp.c:6184
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_PRIV or OMP_ORIG used in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6187
+#: fortran/openmp.c:6192
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_OUT or OMP_IN used in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6216
+#: fortran/openmp.c:6221
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid operator for !$OMP DECLARE REDUCTION %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:6238
+#: fortran/openmp.c:6243
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER length in !$OMP DECLARE REDUCTION %s not constant at %L"
 msgstr ""
 
-#: fortran/openmp.c:6254
+#: fortran/openmp.c:6259
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6269
+#: fortran/openmp.c:6274
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6279
+#: fortran/openmp.c:6284
 #, gcc-internal-format, gfc-internal-format
 msgid "One of actual subroutine arguments in INITIALIZER clause of !$OMP DECLARE REDUCTION must be OMP_PRIV at %L"
 msgstr ""
 
-#: fortran/openmp.c:6287
+#: fortran/openmp.c:6292
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing INITIALIZER clause for !$OMP DECLARE REDUCTION of derived type without default initializer at %L"
 msgstr ""
@@ -64880,531 +64963,531 @@
 msgid "Unclassifiable statement at %C"
 msgstr "Неразврстљива наредба код %C"
 
-#: fortran/parse.c:629
+#: fortran/parse.c:631
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "OpenMP directives at %C may not appear in PURE or ELEMENTAL procedures"
 msgid "OpenACC directives at %C may not appear in PURE procedures"
 msgstr "ОпенМП директиве код %C не могу се јављати у чистим или елементалним процедурама"
 
-#: fortran/parse.c:705
+#: fortran/parse.c:707
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unclassifiable OpenMP directive at %C"
 msgid "Unclassifiable OpenACC directive at %C"
 msgstr "Неразврстљива ОпенМП директива код %C"
 
-#: fortran/parse.c:831 fortran/parse.c:1040
+#: fortran/parse.c:835 fortran/parse.c:1044
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "OpenMP directives at %C may not appear in PURE or ELEMENTAL procedures"
 msgid "OpenMP directives other than SIMD or DECLARE TARGET at %C may not appear in PURE or ELEMENTAL procedures"
 msgstr "ОпенМП директиве код %C не могу се јављати у чистим или елементалним процедурама"
 
-#: fortran/parse.c:1024
+#: fortran/parse.c:1028
 #, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable OpenMP directive at %C"
 msgstr "Неразврстљива ОпенМП директива код %C"
 
-#: fortran/parse.c:1076
+#: fortran/parse.c:1080
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unclassifiable OpenMP directive at %C"
 msgid "Unclassifiable GCC directive at %C"
 msgstr "Неразврстљива ОпенМП директива код %C"
 
-#: fortran/parse.c:1135 fortran/parse.c:1362
+#: fortran/parse.c:1139 fortran/parse.c:1366
 #, gcc-internal-format, gfc-internal-format
 msgid "Zero is not a valid statement label at %C"
 msgstr "Нула није исправна етикета наредбе код %C"
 
-#: fortran/parse.c:1142 fortran/parse.c:1354
+#: fortran/parse.c:1146 fortran/parse.c:1358
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-numeric character in statement label at %C"
 msgstr "Небројевни знак у етикети наредбе код %C"
 
-#: fortran/parse.c:1154 fortran/parse.c:1403
+#: fortran/parse.c:1158 fortran/parse.c:1407
 #, gcc-internal-format, gfc-internal-format
 msgid "Semicolon at %C needs to be preceded by statement"
 msgstr "Тачки-зарез код %C мора претходити наредба"
 
-#: fortran/parse.c:1161 fortran/parse.c:1418
+#: fortran/parse.c:1165 fortran/parse.c:1422
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Ignoring statement label in empty statement at %C"
 msgid "Statement label without statement at %L"
 msgstr "Игноришем етикету наредбе у празној наредби код %C"
 
-#: fortran/parse.c:1224 fortran/parse.c:1405
+#: fortran/parse.c:1228 fortran/parse.c:1409
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Semicolon at %C needs to be preceded by statement"
 msgid "Fortran 2008: Semicolon at %C without preceding statement"
 msgstr "Тачки-зарез код %C мора претходити наредба"
 
-#: fortran/parse.c:1247 fortran/parse.c:1381
+#: fortran/parse.c:1251 fortran/parse.c:1385
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad continuation line at %C"
 msgstr "Лоше настављање линије код %C"
 
-#: fortran/parse.c:1679
+#: fortran/parse.c:1683
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT statement at %L does not have a statement label"
 msgstr "Наредба FORMAT код %L нема етикету наредбе"
 
-#: fortran/parse.c:2435
+#: fortran/parse.c:2439
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_ascii_statement(): Bad statement code"
 msgstr "gfc_trans_code(): лош кôд наредбе"
 
-#: fortran/parse.c:2577
+#: fortran/parse.c:2581
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement at %C"
 msgstr "Неочекивана наредба %s код %C"
 
-#: fortran/parse.c:2732
+#: fortran/parse.c:2736
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot follow %s statement at %L"
 msgstr "Наредба %s код %C не може пратити наредбу %s код %L"
 
-#: fortran/parse.c:2749
+#: fortran/parse.c:2753
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of file in '%s'"
 msgid "Unexpected end of file in %qs"
 msgstr "Неочекиван крај датотеке у ‘%s’"
 
-#: fortran/parse.c:2784
+#: fortran/parse.c:2788
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected %s statement in CONTAINS section at %C"
 msgid "Derived-type %qs with SEQUENCE must not have a CONTAINS section at %C"
 msgstr "Неочекивана наредба %s у одељку CONTAINS код %C"
 
-#: fortran/parse.c:2787
+#: fortran/parse.c:2791
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected %s statement in CONTAINS section at %C"
 msgid "Derived-type %qs with BIND(C) must not have a CONTAINS section at %C"
 msgstr "Неочекивана наредба %s у одељку CONTAINS код %C"
 
-#: fortran/parse.c:2807
+#: fortran/parse.c:2811
 #, gcc-internal-format, gfc-internal-format
 msgid "Components in TYPE at %C must precede CONTAINS"
 msgstr ""
 
-#: fortran/parse.c:2811
+#: fortran/parse.c:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound procedure at %C"
 msgstr ""
 
-#: fortran/parse.c:2819
+#: fortran/parse.c:2823
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC binding at %C"
 msgstr ""
 
-#: fortran/parse.c:2827
+#: fortran/parse.c:2831
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "previous declaration of %qs"
 msgid "FINAL procedure declaration at %C"
 msgstr "претходна декларација %qs"
 
-#: fortran/parse.c:2839
+#: fortran/parse.c:2843
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Derived type definition at %C has no components"
 msgid "Derived type definition at %C with empty CONTAINS section"
 msgstr "Дефиниција изведеног типа код %C нема компонената"
 
-#: fortran/parse.c:2849 fortran/parse.c:3304
+#: fortran/parse.c:2853 fortran/parse.c:3308
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement in TYPE at %C must be inside a MODULE"
 msgstr "Наредба PRIVATE у TYPE код %C мора бити унутар модула"
 
-#: fortran/parse.c:2856
+#: fortran/parse.c:2860
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PRIVATE statement at %C must precede structure components"
 msgid "PRIVATE statement at %C must precede procedure bindings"
 msgstr "Наредба PRIVATE код %C мора претходити компонентама структуре"
 
-#: fortran/parse.c:2863 fortran/parse.c:3317
+#: fortran/parse.c:2867 fortran/parse.c:3321
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PRIVATE statement at %C"
 msgstr "Удвостручена наредба PRIVATE код %C"
 
-#: fortran/parse.c:2873
+#: fortran/parse.c:2877
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "SEQUENCE statement at %C must precede structure components"
 msgid "SEQUENCE statement at %C must precede CONTAINS"
 msgstr "Наредба SEQUENCE код %C мора претходити компонентама структуре"
 
-#: fortran/parse.c:2877
+#: fortran/parse.c:2881
 #, gcc-internal-format, gfc-internal-format
 msgid "Already inside a CONTAINS block at %C"
 msgstr ""
 
-#: fortran/parse.c:2996
+#: fortran/parse.c:3000
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s at %L of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray, which is not possible as the component has the pointer attribute"
 msgstr ""
 
-#: fortran/parse.c:3002
+#: fortran/parse.c:3006
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer component %s at %L has a noncoarray subcomponent of type LOCK_TYPE, which must have a codimension or be a subcomponent of a coarray"
 msgstr ""
 
-#: fortran/parse.c:3007
+#: fortran/parse.c:3011
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Allocatable component of structure at %C must have a deferred shape"
 msgid "Allocatable component %s at %L of type LOCK_TYPE must have a codimension"
 msgstr "Резервљива компонента структуре код %C мора имати одложен облик"
 
-#: fortran/parse.c:3011
+#: fortran/parse.c:3015
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L must have a codimension as it has a noncoarray subcomponent of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/parse.c:3016
+#: fortran/parse.c:3020
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as already a coarray subcomponent exists)"
 msgstr ""
 
-#: fortran/parse.c:3023
+#: fortran/parse.c:3027
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as %s at %L has a codimension or a coarray subcomponent)"
 msgstr ""
 
-#: fortran/parse.c:3033
+#: fortran/parse.c:3037
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s at %L of type EVENT_TYPE must have a codimension or be a subcomponent of a coarray, which is not possible as the component has the pointer attribute"
 msgstr ""
 
-#: fortran/parse.c:3039
+#: fortran/parse.c:3043
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer component %s at %L has a noncoarray subcomponent of type EVENT_TYPE, which must have a codimension or be a subcomponent of a coarray"
 msgstr ""
 
-#: fortran/parse.c:3044
+#: fortran/parse.c:3048
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Allocatable component of structure at %C must have a deferred shape"
 msgid "Allocatable component %s at %L of type EVENT_TYPE must have a codimension"
 msgstr "Резервљива компонента структуре код %C мора имати одложен облик"
 
-#: fortran/parse.c:3048
+#: fortran/parse.c:3052
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L must have a codimension as it has a noncoarray subcomponent of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/parse.c:3053
+#: fortran/parse.c:3057
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as already a coarray subcomponent exists)"
 msgstr ""
 
-#: fortran/parse.c:3060
+#: fortran/parse.c:3064
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as %s at %L has a codimension or a coarray subcomponent)"
 msgstr ""
 
-#: fortran/parse.c:3112
+#: fortran/parse.c:3116
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to create map component '%s'"
 msgstr ""
 
-#: fortran/parse.c:3145
+#: fortran/parse.c:3149
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "failed to find class '%s'"
 msgid "failed to create union component '%s'"
 msgstr "класа ‘%s’ није нађена"
 
-#: fortran/parse.c:3200
+#: fortran/parse.c:3204
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in data declaration at %C"
 msgid "Syntax error in nested structure declaration at %C"
 msgstr "Синтаксна грешка у декларацији података код %C"
 
-#: fortran/parse.c:3287
+#: fortran/parse.c:3291
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENUM declaration at %C has no ENUMERATORS"
 msgid "FINAL declaration at %C must be inside CONTAINS"
 msgstr "Декларација ENUM код %C не садржи набрајаче"
 
-#: fortran/parse.c:3295
+#: fortran/parse.c:3299
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Derived type definition at %C has no components"
 msgid "Derived type definition at %C without components"
 msgstr "Дефиниција изведеног типа код %C нема компонената"
 
-#: fortran/parse.c:3311
+#: fortran/parse.c:3315
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede structure components"
 msgstr "Наредба PRIVATE код %C мора претходити компонентама структуре"
 
-#: fortran/parse.c:3328
+#: fortran/parse.c:3332
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede structure components"
 msgstr "Наредба SEQUENCE код %C мора претходити компонентама структуре"
 
-#: fortran/parse.c:3334
+#: fortran/parse.c:3338
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE attribute at %C already specified in TYPE statement"
 msgstr "Атрибут SEQUENCE код %C је већ наведен у наредби TYPE"
 
-#: fortran/parse.c:3339
+#: fortran/parse.c:3343
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SEQUENCE statement at %C"
 msgstr "Удвостручена наредба SEQUENCE код %C"
 
-#: fortran/parse.c:3349
+#: fortran/parse.c:3353
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS block in derived type definition at %C"
 msgstr ""
 
-#: fortran/parse.c:3407
+#: fortran/parse.c:3411
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM declaration at %C has no ENUMERATORS"
 msgstr "Декларација ENUM код %C не садржи набрајаче"
 
-#: fortran/parse.c:3494
+#: fortran/parse.c:3498
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in INTERFACE block at %C"
 msgstr "Неочекивана наредба %s у блоку INTERFACE код %C"
 
-#: fortran/parse.c:3518
+#: fortran/parse.c:3522
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C cannot be the same as an intrinsic type"
 msgid "Name %qs of ABSTRACT INTERFACE at %C cannot be the same as an intrinsic type"
 msgstr "Име типа ‘%s’ код %C не може бити исто као сопственог типа"
 
-#: fortran/parse.c:3552
+#: fortran/parse.c:3556
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement at %C in INTERFACE body"
 msgstr "Неочекивана наредба %s код %C у телу сучеља"
 
-#: fortran/parse.c:3570
+#: fortran/parse.c:3574
 #, fuzzy, gcc-internal-format
 #| msgid "INTERFACE procedure '%s' at %L has the same name as the enclosing procedure"
 msgid "INTERFACE procedure %qs at %L has the same name as the enclosing procedure"
 msgstr "Процедура сучеља ‘%s’ код %L има исто име као и обухватајућа процедура"
 
-#: fortran/parse.c:3700
+#: fortran/parse.c:3704
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement not allowed in PURE procedure at %C"
 msgid "%s statement is not allowed inside of BLOCK at %C"
 msgstr "Наредба %s није дозвољена у чистој процедури код %C"
 
-#: fortran/parse.c:3732
+#: fortran/parse.c:3736
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement not allowed in PURE procedure at %C"
 msgid "%s statement is not allowed inside of BLOCK DATA at %C"
 msgstr "Наредба %s није дозвољена у чистој процедури код %C"
 
-#: fortran/parse.c:3822
+#: fortran/parse.c:3826
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement must appear in a MODULE"
 msgstr "Наредба %s се мора појавити у модулу"
 
-#: fortran/parse.c:3830
+#: fortran/parse.c:3834
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C follows another accessibility specification"
 msgstr "Наредба %s код %C прати другачију одредницу приступа"
 
-#: fortran/parse.c:3882
+#: fortran/parse.c:3886
 #, fuzzy, gcc-internal-format
 #| msgid "invalid storage class for function %qs"
 msgid "Bad kind expression for function %qs at %L"
 msgstr "неисправна складишна класа за функцију %qs"
 
-#: fortran/parse.c:3886
+#: fortran/parse.c:3890
 #, fuzzy, gcc-internal-format
 #| msgid "Alternate return specifier in function '%s' at %L is not allowed"
 msgid "The type for function %qs at %L is not accessible"
 msgstr "Наводилац алтернативног повратка није дозвољен у функцији ‘%s’ код %L"
 
-#: fortran/parse.c:3946
+#: fortran/parse.c:3950
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C follows previous unmasked ELSEWHERE"
 msgstr "Наредба ELSEWHERE код %C прати претходно демаскирано ELSEWHERE"
 
-#: fortran/parse.c:3968
+#: fortran/parse.c:3972
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in WHERE block at %C"
 msgstr "Неочекивана наредба %s у блоку WHERE код %C"
 
-#: fortran/parse.c:4027
+#: fortran/parse.c:4031
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in FORALL block at %C"
 msgstr "Неочекивана наредба %s у блоку FORALL код %C"
 
-#: fortran/parse.c:4078
+#: fortran/parse.c:4082
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSE IF statement at %C cannot follow ELSE statement at %L"
 msgstr "Наредба ELSE IF код %C не може пратити наредбу ELSE код %L"
 
-#: fortran/parse.c:4096
+#: fortran/parse.c:4100
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ELSE statements at %L and %C"
 msgstr "Удвостручене наредбе ELSE код %L и %C"
 
-#: fortran/parse.c:4157
+#: fortran/parse.c:4161
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected a CASE or END SELECT statement following SELECT CASE at %C"
 msgstr "Очекивана је наредба CASE или END SELECT после SELECT CASE код %C"
 
-#: fortran/parse.c:4241
+#: fortran/parse.c:4245
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected a CASE or END SELECT statement following SELECT CASE at %C"
 msgid "Expected TYPE IS, CLASS IS or END SELECT statement following SELECT TYPE at %C"
 msgstr "Очекивана је наредба CASE или END SELECT после SELECT CASE код %C"
 
-#: fortran/parse.c:4303
+#: fortran/parse.c:4307
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgid "Variable %qs at %C cannot be redefined inside loop beginning at %L"
 msgstr "Променљива ‘%s’ код %C не може се редефинисати унутар петље која почиње код %L"
 
-#: fortran/parse.c:4336
+#: fortran/parse.c:4340
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is within another block"
 msgstr "Крај неблоковске наредбе DO код %C је унутар другог блока"
 
-#: fortran/parse.c:4346
+#: fortran/parse.c:4350
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is interwoven with another DO loop"
 msgstr "Крај неблоковске наредбе DO код %C је уплетена са другом DO петљом"
 
-#: fortran/parse.c:4372
+#: fortran/parse.c:4376
 #, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL block inside of OpenACC region at %C"
 msgstr ""
 
-#: fortran/parse.c:4373
+#: fortran/parse.c:4377
 #, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL block inside of OpenMP region at %C"
 msgstr ""
 
-#: fortran/parse.c:4399
+#: fortran/parse.c:4403
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Statement label in ENDDO at %C doesn't match DO label"
 msgid "Statement label in END CRITICAL at %C does not match CRITICAL label"
 msgstr "Етикета наредбе у ENDDO код %C не одговара етикети DO"
 
-#: fortran/parse.c:4468
+#: fortran/parse.c:4472
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Constructor can't be %s"
 msgid "BLOCK construct at %C"
 msgstr "Конструктор не може бити %s"
 
-#: fortran/parse.c:4502
+#: fortran/parse.c:4506
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSOCIATE construct at %C"
 msgstr ""
 
-#: fortran/parse.c:4690
+#: fortran/parse.c:4694
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label in ENDDO at %C doesn't match DO label"
 msgstr "Етикета наредбе у ENDDO код %C не одговара етикети DO"
 
-#: fortran/parse.c:4706
+#: fortran/parse.c:4710
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "named block DO at %L requires matching ENDDO name"
 msgid "Named block DO at %L requires matching ENDDO name"
 msgstr "именовани блок DO код %L захтева поклапајуће име уз ENDDO"
 
-#: fortran/parse.c:4897
+#: fortran/parse.c:4901
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing !$OMP END ATOMIC after !$OMP ATOMIC CAPTURE at %C"
 msgstr ""
 
-#: fortran/parse.c:4913 fortran/parse.c:4972
+#: fortran/parse.c:4917 fortran/parse.c:4976
 #, gcc-internal-format, gfc-internal-format
 msgid "OpenACC directive inside of CRITICAL block at %C"
 msgstr ""
 
-#: fortran/parse.c:4947
+#: fortran/parse.c:4951
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting %s statement at %C"
 msgid "Expecting %s at %C"
 msgstr "Очекивана је наредба %s код %C"
 
-#: fortran/parse.c:4991
+#: fortran/parse.c:4995
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "Expected DO loop at %C"
 msgstr "Очекивано је ‘(’ код %C"
 
-#: fortran/parse.c:5011
+#: fortran/parse.c:5015
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant !$ACC END LOOP at %C"
 msgstr ""
 
-#: fortran/parse.c:5225
+#: fortran/parse.c:5229
 #, gcc-internal-format, gfc-internal-format
 msgid "Name after !$omp critical and !$omp end critical does not match at %C"
 msgstr "Не слаже се име после !$omp critical и !$omp end critical код %C"
 
-#: fortran/parse.c:5283
+#: fortran/parse.c:5287
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot terminate a non-block DO loop"
 msgstr "Наредба %s код %C не може окончати неблоковску петљу DO"
 
-#: fortran/parse.c:5297
+#: fortran/parse.c:5301
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORMAT statement at %L does not have a statement label"
 msgid "DATA statement at %C after the first executable statement"
 msgstr "Наредба FORMAT код %L нема етикету наредбе"
 
-#: fortran/parse.c:5423
+#: fortran/parse.c:5427
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive does not commence a loop at %C"
 msgstr ""
 
-#: fortran/parse.c:5538
+#: fortran/parse.c:5542
 #, fuzzy, gcc-internal-format
 #| msgid "Contained procedure '%s' at %C is already ambiguous"
 msgid "Contained procedure %qs at %C is already ambiguous"
 msgstr "Садржана процедура ‘%s’ код %C је већ двосмислена"
 
-#: fortran/parse.c:5595
+#: fortran/parse.c:5599
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in CONTAINS section at %C"
 msgstr "Неочекивана наредба %s у одељку CONTAINS код %C"
 
-#: fortran/parse.c:5620
+#: fortran/parse.c:5624
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS statement without FUNCTION or SUBROUTINE statement at %L"
 msgstr ""
 
-#: fortran/parse.c:5732
+#: fortran/parse.c:5736
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS statement at %C is already in a contained program unit"
 msgstr "Наредба CONTAINS код %C је већ у садржаној програмској јединици"
 
-#: fortran/parse.c:5784
+#: fortran/parse.c:5788
 #, fuzzy, gcc-internal-format
 #| msgid "Global name '%s' at %L is already being used as a %s at %L"
 msgid "Global binding name %qs at %L is already being used as a %s at %L"
 msgstr "Глобално име ‘%s’ код %L се већ користи као %s код %L"
 
-#: fortran/parse.c:5788
+#: fortran/parse.c:5792
 #, fuzzy, gcc-internal-format
 #| msgid "Global name '%s' at %L is already being used as a %s at %L"
 msgid "Global name %qs at %L is already being used as a %s at %L"
 msgstr "Глобално име ‘%s’ код %L се већ користи као %s код %L"
 
-#: fortran/parse.c:5794
+#: fortran/parse.c:5798
 #, fuzzy, gcc-internal-format
 #| msgid "Global name '%s' at %L is already being used as a %s at %L"
 msgid "Global binding name %qs at %L is already being used at %L"
 msgstr "Глобално име ‘%s’ код %L се већ користи као %s код %L"
 
-#: fortran/parse.c:5797
+#: fortran/parse.c:5801
 #, fuzzy, gcc-internal-format
 #| msgid "Global name '%s' at %L is already being used as a %s at %L"
 msgid "Global name %qs at %L is already being used at %L"
 msgstr "Глобално име ‘%s’ код %L се већ користи као %s код %L"
 
-#: fortran/parse.c:5819
+#: fortran/parse.c:5823
 #, gcc-internal-format, gfc-internal-format
 msgid "Blank BLOCK DATA at %C conflicts with prior BLOCK DATA at %L"
 msgstr "Празно BLOCK DATA код %C коси се са претходним BLOCK DATA код %L"
 
-#: fortran/parse.c:5845
+#: fortran/parse.c:5849
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in BLOCK DATA at %C"
 msgstr "Неочекивана наредба %s у BLOCK DATA код %C"
 
-#: fortran/parse.c:5949
+#: fortran/parse.c:5953
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in MODULE at %C"
 msgstr "Неочекивана наредба %s у модулу код %C"
@@ -65412,7 +65495,7 @@
 #. If we see a duplicate main program, shut down.  If the second
 #. instance is an implied main program, i.e. data decls or executable
 #. statements, we're in for lots of errors.
-#: fortran/parse.c:6333
+#: fortran/parse.c:6337
 #, gcc-internal-format, gfc-internal-format
 msgid "Two main PROGRAMs at %L and %C"
 msgstr "Два главна програма, код %L и %C"
@@ -66236,7 +66319,7 @@
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.c:1893 fortran/resolve.c:9560 fortran/resolve.c:11225
+#: fortran/resolve.c:1893 fortran/resolve.c:9573 fortran/resolve.c:11245
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "Етикета %d поменута код %L није дефинисана"
@@ -66361,7 +66444,7 @@
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "Функција ‘%s’ код %L нема имплицитан тип"
 
-#: fortran/resolve.c:2905 fortran/resolve.c:16283
+#: fortran/resolve.c:2905 fortran/resolve.c:16310
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Function %qs at %L has no IMPLICIT type"
@@ -66501,212 +66584,212 @@
 msgid "logical_to_bitwise(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:4059
+#: fortran/resolve.c:4065
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:4229 fortran/resolve.c:4252
+#: fortran/resolve.c:4235 fortran/resolve.c:4258
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:4347
+#: fortran/resolve.c:4353
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Упућивач низа код %L је изван граница"
 
-#: fortran/resolve.c:4352
+#: fortran/resolve.c:4358
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr "Упућивач низа код %L је изван граница"
 
-#: fortran/resolve.c:4362
+#: fortran/resolve.c:4368
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Упућивач низа код %L је изван граница"
 
-#: fortran/resolve.c:4367
+#: fortran/resolve.c:4373
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr "Упућивач низа код %L је изван граница"
 
-#: fortran/resolve.c:4387
+#: fortran/resolve.c:4393
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr "Недозвољен нулти корак код %L"
 
-#: fortran/resolve.c:4404
+#: fortran/resolve.c:4410
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Упућивач низа код %L је изван граница"
 
-#: fortran/resolve.c:4412
+#: fortran/resolve.c:4418
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Упућивач низа код %L је изван граница"
 
-#: fortran/resolve.c:4428
+#: fortran/resolve.c:4434
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Упућивач низа код %L је изван граница"
 
-#: fortran/resolve.c:4437
+#: fortran/resolve.c:4443
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Упућивач низа код %L је изван граница"
 
-#: fortran/resolve.c:4453
+#: fortran/resolve.c:4459
 #, fuzzy, gcc-internal-format
 #| msgid "subscript missing in array reference"
 msgid "check_dimension(): Bad array reference"
 msgstr "недостаје индекс у упућивачу низа"
 
-#: fortran/resolve.c:4476
+#: fortran/resolve.c:4482
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr "Није наведена десна горња граница низа претпостављене величине код %L"
 
-#: fortran/resolve.c:4486
+#: fortran/resolve.c:4492
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr "Неслагање рангова у упућивачу низа код %L (%d/%d)"
 
-#: fortran/resolve.c:4494
+#: fortran/resolve.c:4500
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr "Неслагање рангова у упућивачу низа код %L (%d/%d)"
 
-#: fortran/resolve.c:4510
+#: fortran/resolve.c:4516
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "index in dimension %d is out of bounds at %L"
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr "Индекс у димензији %d је ван граница код %L"
 
-#: fortran/resolve.c:4538
+#: fortran/resolve.c:4544
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr "Индекс низа код %L мора бити скалар"
 
-#: fortran/resolve.c:4544
+#: fortran/resolve.c:4550
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array index at %L must be of INTEGER type"
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr "Индекс низа код %L мора бити целобројни"
 
-#: fortran/resolve.c:4550
+#: fortran/resolve.c:4556
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: REAL array index at %L"
 msgid "REAL array index at %L"
 msgstr "Проширење: реални индекс низа код %L"
 
-#: fortran/resolve.c:4589
+#: fortran/resolve.c:4595
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr "Аргумент димензије код %L мора бити скалар"
 
-#: fortran/resolve.c:4596
+#: fortran/resolve.c:4602
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr "Аргумент димензије код %L мора целобројни"
 
-#: fortran/resolve.c:4641
+#: fortran/resolve.c:4647
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr ""
 
-#: fortran/resolve.c:4652
+#: fortran/resolve.c:4658
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.c:4663
+#: fortran/resolve.c:4669
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.c:4706
+#: fortran/resolve.c:4712
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr "Индекс низа код %L је низ ранга %d"
 
-#: fortran/resolve.c:4804
+#: fortran/resolve.c:4810
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr "Индекс почетка подниске код %L мора бити целобројни"
 
-#: fortran/resolve.c:4811
+#: fortran/resolve.c:4817
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr "Индекс почетка подниске код %L мора бити скалар"
 
-#: fortran/resolve.c:4820
+#: fortran/resolve.c:4826
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr "Индекс почетка подниске код %L је мањи од један"
 
-#: fortran/resolve.c:4833
+#: fortran/resolve.c:4839
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr "Индекс краја подниске код %L мора бити целобројни"
 
-#: fortran/resolve.c:4840
+#: fortran/resolve.c:4846
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr "Индекс краја подниске код %L мора бити скалар"
 
-#: fortran/resolve.c:4850
+#: fortran/resolve.c:4856
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr "Индекс краја подниске код %L премашује дужину ниске"
 
-#: fortran/resolve.c:4860
+#: fortran/resolve.c:4866
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Substring end index at %L must be scalar"
 msgid "Substring end index at %L is too large"
 msgstr "Индекс краја подниске код %L мора бити скалар"
 
-#: fortran/resolve.c:5013
+#: fortran/resolve.c:5019
 #, fuzzy, gcc-internal-format
 #| msgid "Bad array reference at %L"
 msgid "resolve_ref(): Bad array reference"
 msgstr "Лош упућивач низа код %L"
 
-#: fortran/resolve.c:5027
+#: fortran/resolve.c:5033
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr "Компонента десно од делимичног упућивача са ненултим рангом не сме имати атрибут показивача код %L"
 
-#: fortran/resolve.c:5037
+#: fortran/resolve.c:5043
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr "Компонента десно од делимичног упућивача са ненултим рангом не сме имати атрибут резервљивости код %L"
 
-#: fortran/resolve.c:5056
+#: fortran/resolve.c:5062
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr "Два или више делимична упућивача са ненултим рангом не смеју бити наведени код %L"
 
-#: fortran/resolve.c:5154
+#: fortran/resolve.c:5160
 #, gcc-internal-format
 msgid "expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.c:5236
+#: fortran/resolve.c:5242
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr ""
 
-#: fortran/resolve.c:5246
+#: fortran/resolve.c:5252
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
@@ -66716,12 +66799,12 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5256
+#: fortran/resolve.c:5262
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5271
+#: fortran/resolve.c:5277
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
@@ -66731,65 +66814,65 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5281
+#: fortran/resolve.c:5287
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5292
+#: fortran/resolve.c:5298
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5301
+#: fortran/resolve.c:5307
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5316
+#: fortran/resolve.c:5322
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5478
+#: fortran/resolve.c:5484
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s',used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr "Променљива ‘%s’, употребљена у одредничком изразу, користи се код %L пре наредбе ENTRY у којој је параметар"
 
-#: fortran/resolve.c:5483
+#: fortran/resolve.c:5489
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' is used at %L before the ENTRY statement in which it is a parameter"
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr "Променљива ‘%s’ употребљена је код %L пре наредбе ENTRY у којој је параметар"
 
-#: fortran/resolve.c:5553
+#: fortran/resolve.c:5559
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.c:5566
+#: fortran/resolve.c:5572
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.c:5919
+#: fortran/resolve.c:5925
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s tag at %L must be scalar"
 msgid "Passed-object at %L must be scalar"
 msgstr "Ознака %s код %L мора бити скалар"
 
-#: fortran/resolve.c:5926
+#: fortran/resolve.c:5932
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5961
+#: fortran/resolve.c:5967
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5970
+#: fortran/resolve.c:5976
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument '%s' of elemental procedure at %L must be scalar"
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
@@ -66796,220 +66879,220 @@
 msgstr "Аргумент ‘%s’ елементалне процедуре код %L мора бити скалар"
 
 #. Nothing matching found!
-#: fortran/resolve.c:6158
+#: fortran/resolve.c:6164
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:6185
+#: fortran/resolve.c:6191
 #, fuzzy, gcc-internal-format
 #| msgid "%s at %L must be INTEGER"
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "%s код %L мора бити целобројно"
 
-#: fortran/resolve.c:6236
+#: fortran/resolve.c:6242
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:6786
+#: fortran/resolve.c:6792
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "Очекиван је тип израза"
 
-#: fortran/resolve.c:6812
+#: fortran/resolve.c:6818
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s код %L мора бити скалар"
 
-#: fortran/resolve.c:6822
+#: fortran/resolve.c:6828
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s at %L must be a scalar"
 msgid "%s at %L must be integer"
 msgstr "%s код %L мора бити скалар"
 
-#: fortran/resolve.c:6826 fortran/resolve.c:6833
+#: fortran/resolve.c:6832 fortran/resolve.c:6839
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s код %L мора бити целобројно"
 
-#: fortran/resolve.c:6875
+#: fortran/resolve.c:6881
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "Израз за корак у петљи DO код %L не може бити нула"
 
-#: fortran/resolve.c:6911
+#: fortran/resolve.c:6917
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.c:6928
+#: fortran/resolve.c:6934
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.c:6934
+#: fortran/resolve.c:6940
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.c:6995
+#: fortran/resolve.c:7001
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "Индекс-име у FORALL код %L мора бити скларни целобројан"
 
-#: fortran/resolve.c:7000
+#: fortran/resolve.c:7006
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "Израз за почетак у FORALL код %L мора бити скаларни целобројан"
 
-#: fortran/resolve.c:7007
+#: fortran/resolve.c:7013
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "Израз за крај у FORALL код %L мора бити скаларни целобројан"
 
-#: fortran/resolve.c:7015
+#: fortran/resolve.c:7021
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "Израз за корак у FORALL код %L мора бити скаларни %s"
 
-#: fortran/resolve.c:7020
+#: fortran/resolve.c:7026
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "Израз за корак у FORALL код %L не може бити нула"
 
-#: fortran/resolve.c:7033
+#: fortran/resolve.c:7039
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' cannot appear in the expression at %L"
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "Променљива ‘%s’ се не може јавити у изразу код %L"
 
-#: fortran/resolve.c:7136 fortran/resolve.c:7428
+#: fortran/resolve.c:7142 fortran/resolve.c:7434
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in ALLOCATE statement at %L must be ALLOCATABLE or a POINTER"
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "Израз у наредби ALLOCATE код %L мора бити резервљив или показивач"
 
-#: fortran/resolve.c:7144 fortran/resolve.c:7393
+#: fortran/resolve.c:7150 fortran/resolve.c:7399
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7250
+#: fortran/resolve.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7281
+#: fortran/resolve.c:7287
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.c:7439
+#: fortran/resolve.c:7445
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.c:7451
+#: fortran/resolve.c:7457
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.c:7465
+#: fortran/resolve.c:7471
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7480
+#: fortran/resolve.c:7486
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7493
+#: fortran/resolve.c:7499
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.c:7511
+#: fortran/resolve.c:7517
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.c:7592 fortran/resolve.c:7607
+#: fortran/resolve.c:7598 fortran/resolve.c:7613
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "Потребна је одредница низа у наредби ALLOCATE код %L"
 
-#: fortran/resolve.c:7599
+#: fortran/resolve.c:7605
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array specification required in ALLOCATE statement at %L"
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "Потребна је одредница низа у наредби ALLOCATE код %L"
 
-#: fortran/resolve.c:7622
+#: fortran/resolve.c:7628
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array specification required in ALLOCATE statement at %L"
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "Потребна је одредница низа у наредби ALLOCATE код %L"
 
-#: fortran/resolve.c:7649
+#: fortran/resolve.c:7655
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "Лоша одредница низа у наредби ALLOCATE код %L"
 
-#: fortran/resolve.c:7668
+#: fortran/resolve.c:7674
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' must not appear an the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr "‘%s’ не може да се јави у одредници низа код %L у истој наредби резервисања где се и само резервише"
 
-#: fortran/resolve.c:7683
+#: fortran/resolve.c:7689
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad array specification in ALLOCATE statement at %L"
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr "Лоша одредница низа у наредби ALLOCATE код %L"
 
-#: fortran/resolve.c:7694
+#: fortran/resolve.c:7700
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad array specification in ALLOCATE statement at %L"
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "Лоша одредница низа у наредби ALLOCATE код %L"
 
-#: fortran/resolve.c:7726
+#: fortran/resolve.c:7732
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "ASSIGN код %L захтева скаларну подразумевану целобројну променљиву"
 
-#: fortran/resolve.c:7749
+#: fortran/resolve.c:7755
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "Етикета код %L није у истом блоку као наредба GOTO код %L"
 
-#: fortran/resolve.c:7760
+#: fortran/resolve.c:7766
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.c:7771
+#: fortran/resolve.c:7782
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "UNIT specification at %L must be an INTEGER expression or a CHARACTER variable"
-msgid "Errmsg-variable at %L must be a scalar CHARACTER variable"
-msgstr "Одредница UNIT код %L мора бити целобројни израз или знаковна променљива"
+#| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
+msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
+msgstr "ASSIGN код %L захтева скаларну подразумевану целобројну променљиву"
 
-#: fortran/resolve.c:7794
+#: fortran/resolve.c:7805
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:7824
+#: fortran/resolve.c:7835
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.c:7830 fortran/resolve.c:7836
+#: fortran/resolve.c:7841 fortran/resolve.c:7847
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -67018,257 +67101,257 @@
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8064
+#: fortran/resolve.c:8075
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "Етикета CASE код %L преклапа етикету CASE код %L"
 
-#: fortran/resolve.c:8115
+#: fortran/resolve.c:8126
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "Израз у наредби CASE код %L мора бити типа %s"
 
-#: fortran/resolve.c:8126
+#: fortran/resolve.c:8137
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in CASE statement at %L must be kind %d"
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "Израз у наредби CASE код %L мора бити врста %d"
 
-#: fortran/resolve.c:8139
+#: fortran/resolve.c:8150
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "Израз у наредби CASE код %L мора бити скалар"
 
-#: fortran/resolve.c:8185
+#: fortran/resolve.c:8196
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "Изборни израз у рачунском GOTO код %L мора бити скаларни целобројан израз"
 
-#: fortran/resolve.c:8204
+#: fortran/resolve.c:8215
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "Аргумент наредбе SELECT код %L не може бити %s"
 
-#: fortran/resolve.c:8214
+#: fortran/resolve.c:8225
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "Аргумент наредбе SELECT код %L мора бити скаларни израз"
 
-#: fortran/resolve.c:8232 fortran/resolve.c:8240
+#: fortran/resolve.c:8243 fortran/resolve.c:8251
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in CASE statement at %L must be of type %s"
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "Израз у наредби CASE код %L мора бити типа %s"
 
-#: fortran/resolve.c:8302 fortran/resolve.c:8873
+#: fortran/resolve.c:8313 fortran/resolve.c:8884
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "DEFAULT CASE код %L не може бити праћен другим DEFAULT CASE код %L"
 
-#: fortran/resolve.c:8328
+#: fortran/resolve.c:8339
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "Логички опсег у наредби CASE код %L није дозвољен"
 
-#: fortran/resolve.c:8340
+#: fortran/resolve.c:8351
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "constant logical value in CASE statement is repeated at %L"
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "константна логичка вредност у наредби CASE поновљена је код %L"
 
-#: fortran/resolve.c:8355
+#: fortran/resolve.c:8366
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "Одредница опсега код %L не може никако бити поклопљена"
 
-#: fortran/resolve.c:8458
+#: fortran/resolve.c:8469
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "Блок логичког SELECT CASE код %L има више од два случаја"
 
-#: fortran/resolve.c:8518
+#: fortran/resolve.c:8529
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Iterator step at %L cannot be zero"
 msgid "Selector at %L cannot be NULL()"
 msgstr "Корак итератора код %L не може бити нула"
 
-#: fortran/resolve.c:8523
+#: fortran/resolve.c:8534
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Selector at %L has no type"
 msgstr "Функција ‘%s’ код %L нема имплицитан тип"
 
-#: fortran/resolve.c:8545
+#: fortran/resolve.c:8556
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.c:8556
+#: fortran/resolve.c:8567
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:8763
+#: fortran/resolve.c:8774
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in EQUIVALENCE statement at %L"
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "Синтаксна грешка у наредби EQUIVALENCE код %L"
 
-#: fortran/resolve.c:8783 fortran/resolve.c:8795
+#: fortran/resolve.c:8794 fortran/resolve.c:8806
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.c:8824
+#: fortran/resolve.c:8835
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CASE label at %L overlaps with CASE label at %L"
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "Етикета CASE код %L преклапа етикету CASE код %L"
 
-#: fortran/resolve.c:8836
+#: fortran/resolve.c:8847
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %C is being used before it is defined"
 msgid "Derived type %qs at %L must be extensible"
 msgstr "Изведени тип ‘%s’ код %C користи се пре него што је дефинисан"
 
-#: fortran/resolve.c:8848
+#: fortran/resolve.c:8859
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type name '%s' at %C already has a basic type of %s"
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "Име изведеног типа ‘%s’ код %C већ има основни тип %s"
 
-#: fortran/resolve.c:8851
+#: fortran/resolve.c:8862
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected %s statement at %C"
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "Неочекивана наредба %s код %C"
 
-#: fortran/resolve.c:8861
+#: fortran/resolve.c:8872
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.c:9108
+#: fortran/resolve.c:9119
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9204
+#: fortran/resolve.c:9215
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "Неисправна врста за %s код %L"
 
-#: fortran/resolve.c:9257
+#: fortran/resolve.c:9268
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument '%s' of elemental procedure at %L must be scalar"
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "Аргумент ‘%s’ елементалне процедуре код %L мора бити скалар"
 
-#: fortran/resolve.c:9267
+#: fortran/resolve.c:9278
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9280
+#: fortran/resolve.c:9291
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components"
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "Елемент преноса података код %L не може имати показивачке компоненте"
 
-#: fortran/resolve.c:9289
+#: fortran/resolve.c:9300
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components"
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "Елемент преноса података код %L не може имати показивачке компоненте"
 
-#: fortran/resolve.c:9296
+#: fortran/resolve.c:9307
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have ALLOCATABLE components"
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "Елемент преноса података код %L не може имати резервљиве компоненте"
 
-#: fortran/resolve.c:9307
+#: fortran/resolve.c:9318
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "Елемент преноса података код %L не може имати приватне компоненте"
 
-#: fortran/resolve.c:9313
+#: fortran/resolve.c:9324
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have PRIVATE components"
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr "Елемент преноса података код %L не може имати приватне компоненте"
 
-#: fortran/resolve.c:9328
+#: fortran/resolve.c:9339
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "Елемент преноса података код %L не може бити пун упућивач на низ претпостављене величине"
 
-#: fortran/resolve.c:9388
+#: fortran/resolve.c:9399
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "Индекс-име у FORALL код %L мора бити скларни целобројан"
 
-#: fortran/resolve.c:9398
+#: fortran/resolve.c:9409
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:9402
+#: fortran/resolve.c:9413
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "By-value argument at %L cannot be an array or an array section"
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "Аргумент-по-вредности код %L не може бити низ или одељак низа"
 
-#: fortran/resolve.c:9405
+#: fortran/resolve.c:9416
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "By-value argument at %L cannot be an array or an array section"
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "Аргумент-по-вредности код %L не може бити низ или одељак низа"
 
-#: fortran/resolve.c:9412 fortran/resolve.c:9533
+#: fortran/resolve.c:9423 fortran/resolve.c:9545
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "ASSIGN код %L захтева скаларну подразумевану целобројну променљиву"
 
-#: fortran/resolve.c:9424 fortran/resolve.c:9540
+#: fortran/resolve.c:9435 fortran/resolve.c:9553
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "ASSIGN код %L захтева скаларну подразумевану целобројну променљиву"
 
-#: fortran/resolve.c:9436
+#: fortran/resolve.c:9447
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument dim at %L must be scalar"
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "Аргумент димензије код %L мора бити скалар"
 
-#: fortran/resolve.c:9449
+#: fortran/resolve.c:9460
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "NUM_THREADS clause at %L requires a scalar INTEGER expression"
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "Одредба NUM_THREADS код %L захтева скаларни целобројни израз"
 
-#: fortran/resolve.c:9510
+#: fortran/resolve.c:9521
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "Аргумент наредбе SELECT код %L мора бити скаларни израз"
 
-#: fortran/resolve.c:9514 fortran/resolve.c:9524
+#: fortran/resolve.c:9525 fortran/resolve.c:9535
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of ACOS at %L must be between -1 and 1"
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "Аргумент у ACOS код %L мора бити између -1 и 1"
 
-#: fortran/resolve.c:9567
+#: fortran/resolve.c:9580
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "Наредба код %L није исправна наредба циља гранања за наредбу гранања код %L"
 
-#: fortran/resolve.c:9577
+#: fortran/resolve.c:9590
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Branch at %L causes an infinite loop"
 msgid "Branch at %L may result in an infinite loop"
@@ -67276,12 +67359,12 @@
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:9594 fortran/resolve.c:9617
+#: fortran/resolve.c:9607 fortran/resolve.c:9630
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.c:9598 fortran/resolve.c:9623
+#: fortran/resolve.c:9611 fortran/resolve.c:9636
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -67289,114 +67372,114 @@
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:9638
+#: fortran/resolve.c:9651
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "Етикета код %L није у истом блоку као наредба GOTO код %L"
 
-#: fortran/resolve.c:9710
+#: fortran/resolve.c:9723
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "Маска у WHERE код %L има неусаглашен облик"
 
-#: fortran/resolve.c:9726
+#: fortran/resolve.c:9739
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "Циљ доделе у WHERE код %L има неусаглашен облик"
 
-#: fortran/resolve.c:9734 fortran/resolve.c:9821
+#: fortran/resolve.c:9747 fortran/resolve.c:9834
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:9744 fortran/resolve.c:9831
+#: fortran/resolve.c:9757 fortran/resolve.c:9844
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "Неподржана наредба унутар WHERE код %L"
 
-#: fortran/resolve.c:9775
+#: fortran/resolve.c:9788
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "Додела у индексну променљиву за FORALL код %L"
 
-#: fortran/resolve.c:9784
+#: fortran/resolve.c:9797
 #, fuzzy, gcc-internal-format
 #| msgid "The FORALL with index '%s' cause more than one assignment to this object at %L"
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "FORALL са индексом ‘%s’ изазива више од једне доделе овом објекту код %L"
 
-#: fortran/resolve.c:9949
+#: fortran/resolve.c:9962
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "Индекс-име у FORALL код %L мора бити скларни целобројан"
 
-#: fortran/resolve.c:9959
+#: fortran/resolve.c:9972
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "Спољашња конструкција FORALL већ има индекс са овим именом %L"
 
-#: fortran/resolve.c:10036
+#: fortran/resolve.c:10049
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "Одредба WHERE/ELSEWHERE код %L захтева логички низ"
 
-#: fortran/resolve.c:10138
+#: fortran/resolve.c:10151
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:10251
+#: fortran/resolve.c:10264
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CHARACTER expression at %L is being truncated (%d/%d)"
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr "Знаковни израз код %L бива подсечен (%d/%d)"
 
-#: fortran/resolve.c:10283
+#: fortran/resolve.c:10296
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Right side of assignment at %L is a derived type containing a POINTER in a PURE procedure"
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "Десна страна доделе код %L је изведени тип који садржи показивач у чистој процедури"
 
-#: fortran/resolve.c:10288
+#: fortran/resolve.c:10301
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Right side of assignment at %L is a derived type containing a POINTER in a PURE procedure"
 msgid "The impure variable at %L is assigned to a derived type variable with a POINTER component in a PURE procedure (12.6)"
 msgstr "Десна страна доделе код %L је изведени тип који садржи показивач у чистој процедури"
 
-#: fortran/resolve.c:10298
+#: fortran/resolve.c:10311
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assignment to a FORALL index variable at %L"
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "Додела у индексну променљиву за FORALL код %L"
 
-#: fortran/resolve.c:10330
+#: fortran/resolve.c:10343
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:10334
+#: fortran/resolve.c:10347
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assignment to a FORALL index variable at %L"
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "Додела у индексну променљиву за FORALL код %L"
 
-#: fortran/resolve.c:10339
+#: fortran/resolve.c:10352
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.c:10346
+#: fortran/resolve.c:10359
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr ""
 
-#: fortran/resolve.c:10357
+#: fortran/resolve.c:10370
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:10663
+#: fortran/resolve.c:10683
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
@@ -67403,73 +67486,73 @@
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:10905
+#: fortran/resolve.c:10925
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Different types in pointer assignment at %L"
 msgid "Pointer procedure assignment at %L"
 msgstr "Различити типови у додели показивача код %L"
 
-#: fortran/resolve.c:10917
+#: fortran/resolve.c:10937
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr ""
 
-#: fortran/resolve.c:11157
+#: fortran/resolve.c:11177
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgstr "Наредба ASSIGNED GOTO код %L захтева целобројну променљиву"
 
-#: fortran/resolve.c:11160
+#: fortran/resolve.c:11180
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' has not been assigned a target label at %L"
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "Променљивој ‘%s’ није додељена циљна етикета код %L"
 
-#: fortran/resolve.c:11171
+#: fortran/resolve.c:11191
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "Алтернативна наредба повратка код %L захтева скаларни целобројни наводилац повратка"
 
-#: fortran/resolve.c:11233
+#: fortran/resolve.c:11253
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "ASSIGN код %L захтева скаларну подразумевану целобројну променљиву"
 
-#: fortran/resolve.c:11278
+#: fortran/resolve.c:11298
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Invalid NULL at %L"
 msgstr "Неисправна врста за %s код %L"
 
-#: fortran/resolve.c:11282
+#: fortran/resolve.c:11302
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Arithmetic IF statement at %L requires a numeric expression"
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr "Аритметичко IF код %L захтева бројевни израз"
 
-#: fortran/resolve.c:11339
+#: fortran/resolve.c:11359
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:11344
+#: fortran/resolve.c:11364
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "Излазни услов из петље DO WHILE код %L мора бити скаларни логички израз"
 
-#: fortran/resolve.c:11428
+#: fortran/resolve.c:11448
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL mask clause at %L requires a LOGICAL expression"
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "Одредба маске у FORALL код %L захтева логички израз"
 
-#: fortran/resolve.c:11507
+#: fortran/resolve.c:11527
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_trans_code(): лош кôд наредбе"
 
-#: fortran/resolve.c:11617
+#: fortran/resolve.c:11637
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
@@ -67476,7 +67559,7 @@
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:11630
+#: fortran/resolve.c:11650
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr ""
@@ -67484,63 +67567,63 @@
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:11647
+#: fortran/resolve.c:11667
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.c:11732
+#: fortran/resolve.c:11752
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "String length at %L is too large"
 msgstr "величина низа %qs је превелика"
 
-#: fortran/resolve.c:11961
+#: fortran/resolve.c:11981
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable array '%s' at %L must have a deferred shape"
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "Резервљиви низ ‘%s’ код %L мора имати одложени облик"
 
-#: fortran/resolve.c:11965
+#: fortran/resolve.c:11985
 #, fuzzy, gcc-internal-format
 #| msgid "Scalar object '%s' at %L may not be ALLOCATABLE"
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "Скаларни објекат ‘%s’ код %L не може бити резервљив"
 
-#: fortran/resolve.c:11973
+#: fortran/resolve.c:11993
 #, fuzzy, gcc-internal-format
 #| msgid "Array pointer '%s' at %L must have a deferred shape"
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "Низовни показивач ‘%s’ код %L мора имати одложен облик"
 
-#: fortran/resolve.c:11983
+#: fortran/resolve.c:12003
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "Низ ‘%s’ код %L не може имати одложен облик"
 
-#: fortran/resolve.c:11998
+#: fortran/resolve.c:12018
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.c:12010
+#: fortran/resolve.c:12030
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.c:12041
+#: fortran/resolve.c:12061
 #, fuzzy, gcc-internal-format
 #| msgid "The type %s cannot be host associated at %L because it is blocked by an incompatible object of the same name at %L"
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr "Тип %s не може бити придружен домаћину код %L зато што га блокира несагласан објекат истог имена код %L"
 
-#: fortran/resolve.c:12063
+#: fortran/resolve.c:12083
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
 
-#: fortran/resolve.c:12090
+#: fortran/resolve.c:12110
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
@@ -67547,119 +67630,119 @@
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12131
+#: fortran/resolve.c:12151
 #, fuzzy, gcc-internal-format
 #| msgid "The module or main program array '%s' at %L must have constant shape"
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "Низ модула или главног програма ‘%s’ код %L мора имати константан облик"
 
-#: fortran/resolve.c:12150
+#: fortran/resolve.c:12170
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "Ентитет са претпостављеном знаковном дужином код %L мора бити лажни аргумент или параметар"
 
-#: fortran/resolve.c:12171
+#: fortran/resolve.c:12191
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "%qs at %L must have constant character length in this context"
 msgstr "‘%s’ код %L мора имати константну знаковну дужину у овом контексту"
 
-#: fortran/resolve.c:12178
+#: fortran/resolve.c:12198
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "‘%s’ код %L мора имати константну знаковну дужину у овом контексту"
 
-#: fortran/resolve.c:12225
+#: fortran/resolve.c:12245
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable '%s' at %L cannot have an initializer"
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "Резервљиво ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.c:12228
+#: fortran/resolve.c:12248
 #, fuzzy, gcc-internal-format
 #| msgid "External '%s' at %L cannot have an initializer"
 msgid "External %qs at %L cannot have an initializer"
 msgstr "Спољашње ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.c:12232
+#: fortran/resolve.c:12252
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "Лажно ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.c:12235
+#: fortran/resolve.c:12255
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L cannot have an initializer"
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "Сопствено ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.c:12238
+#: fortran/resolve.c:12258
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L cannot have an initializer"
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "Резултат функцији ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.c:12241
+#: fortran/resolve.c:12261
 #, fuzzy, gcc-internal-format
 #| msgid "Automatic array '%s' at %L cannot have an initializer"
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "Аутоматски низ ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.c:12283
+#: fortran/resolve.c:12303
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "in %s, at %s:%d"
 msgid "%s at %L"
 msgstr "у %s, код %s:%d"
 
-#: fortran/resolve.c:12310
+#: fortran/resolve.c:12330
 #, fuzzy, gcc-internal-format
 #| msgid "Character-valued statement function '%s' at %L must have constant length"
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "Наредбена функција знаковне вредности ‘%s’ код %L мора имати константну дужину"
 
-#: fortran/resolve.c:12332
+#: fortran/resolve.c:12352
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' is of a PRIVATE type and cannot be a dummy argument of '%s', which is PUBLIC at %L"
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "‘%s’ је приватног типа и не може бити лажни аргумент у ‘%s’, који је јаван код %L"
 
-#: fortran/resolve.c:12354
+#: fortran/resolve.c:12374
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.c:12372
+#: fortran/resolve.c:12392
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L cannot have an initializer"
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "Резултат функцији ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.c:12381
+#: fortran/resolve.c:12401
 #, fuzzy, gcc-internal-format
 #| msgid "External object '%s' at %L may not have an initializer"
 msgid "External object %qs at %L may not have an initializer"
 msgstr "Спољашњи објекат ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.c:12389
+#: fortran/resolve.c:12409
 #, fuzzy, gcc-internal-format
 #| msgid "ELEMENTAL function '%s' at %L must have a scalar result"
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "Елементална функција ‘%s’ код %L мора имати скаларни резултат"
 
-#: fortran/resolve.c:12399
+#: fortran/resolve.c:12419
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' at %L is not allowed as an actual argument"
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "Наредбена функција ‘%s’ код %L није дозвољена као стварни аргумент"
 
-#: fortran/resolve.c:12418
+#: fortran/resolve.c:12438
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be array-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "Функција типа CHARACTER(*) ‘%s’ код %L не може имати низовну вредност"
 
-#: fortran/resolve.c:12422
+#: fortran/resolve.c:12442
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pointer-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
@@ -67666,13 +67749,13 @@
 msgstr "Функција типа CHARACTER(*) ‘%s’ код %L не може имати показивачку вредност"
 
 # no-c-format
-#: fortran/resolve.c:12426
+#: fortran/resolve.c:12446
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "Функција типа CHARACTER(*) ‘%s’ код %L не може бити чиста"
 
-#: fortran/resolve.c:12430
+#: fortran/resolve.c:12450
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be recursive"
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
@@ -67679,849 +67762,855 @@
 msgstr "Функција типа CHARACTER(*) ‘%s’ код %L не може бити рекурзивна"
 
 # no-c-format
-#: fortran/resolve.c:12443
+#: fortran/resolve.c:12463
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "Функција типа CHARACTER(*) ‘%s’ код %L не може бити чиста"
 
-#: fortran/resolve.c:12452
+#: fortran/resolve.c:12472
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:12458
+#: fortran/resolve.c:12478
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy procedure '%s' at %C cannot have a generic interface"
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "Лажна процедура ‘%s’ код %C не може имати генеричко сучеље"
 
-#: fortran/resolve.c:12470
+#: fortran/resolve.c:12490
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:12527
+#: fortran/resolve.c:12547
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "Атрибут процедуре коси се са атрибутом листе имена у ‘%s’ код %L"
 
-#: fortran/resolve.c:12533
+#: fortran/resolve.c:12553
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "Атрибут процедуре коси се са атрибутом листе имена у ‘%s’ код %L"
 
-#: fortran/resolve.c:12539
+#: fortran/resolve.c:12559
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "Атрибут процедуре коси се са атрибутом листе имена у ‘%s’ код %L"
 
-#: fortran/resolve.c:12547
+#: fortran/resolve.c:12567
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute in '%s' at %L"
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "Атрибут %s коси се са атрибутом %s у ‘%s’ код %L"
 
-#: fortran/resolve.c:12553
+#: fortran/resolve.c:12573
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.c:12596
+#: fortran/resolve.c:12616
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12604
+#: fortran/resolve.c:12624
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12612
+#: fortran/resolve.c:12632
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12621
+#: fortran/resolve.c:12641
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.c:12705
+#: fortran/resolve.c:12725
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:12714
+#: fortran/resolve.c:12734
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "Процедура корисничког оператора ‘%s’ код %L мора имати бар један аргумент"
 
-#: fortran/resolve.c:12723
+#: fortran/resolve.c:12743
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ICHAR at %L must be of length one"
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "Аргумент у ICHAR код %L мора бити дужине један"
 
-#: fortran/resolve.c:12731
+#: fortran/resolve.c:12751
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a POINTER"
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити показивач"
 
-#: fortran/resolve.c:12737
+#: fortran/resolve.c:12757
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be ALLOCATABLE"
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити резервљив"
 
-#: fortran/resolve.c:12743
+#: fortran/resolve.c:12763
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must not be OPTIONAL"
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L не сме бити опциони"
 
-#: fortran/resolve.c:12751
+#: fortran/resolve.c:12771
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "Први аргумент сучеља оператора код %L мора бити намере-у"
 
-#: fortran/resolve.c:12760
+#: fortran/resolve.c:12780
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "Процедура корисничког оператора ‘%s’ код %L мора имати бар један аргумент"
 
-#: fortran/resolve.c:12782
+#: fortran/resolve.c:12802
 #, fuzzy, gcc-internal-format
 #| msgid "INTERFACE procedure '%s' at %L has the same name as the enclosing procedure"
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "Процедура сучеља ‘%s’ код %L има исто име као и обухватајућа процедура"
 
-#: fortran/resolve.c:12819
+#: fortran/resolve.c:12839
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr ""
 
-#: fortran/resolve.c:12859
+#: fortran/resolve.c:12879
 #, gcc-internal-format
 msgid "%qs and %qs can't be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12895
+#: fortran/resolve.c:12915
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.c:12954
+#: fortran/resolve.c:12974
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12966
+#: fortran/resolve.c:12986
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.c:12994
+#: fortran/resolve.c:13014
 #, gcc-internal-format
 msgid "GENERIC %qs at %L can't overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.c:13050
+#: fortran/resolve.c:13070
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L can't be NOPASS"
 msgstr ""
 
-#: fortran/resolve.c:13242
+#: fortran/resolve.c:13262
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "Процедура ‘%s’ позвана са имплицитним сучељем код %L"
 
-#: fortran/resolve.c:13284
+#: fortran/resolve.c:13304
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:13298
+#: fortran/resolve.c:13318
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "Процедура корисничког оператора ‘%s’ код %L мора имати бар један аргумент"
 
-#: fortran/resolve.c:13312 fortran/resolve.c:13778
+#: fortran/resolve.c:13332 fortran/resolve.c:13798
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13320
+#: fortran/resolve.c:13340
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a non-derived type"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити неизведени тип"
 
-#: fortran/resolve.c:13329
+#: fortran/resolve.c:13349
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a scalar"
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити скалар"
 
-#: fortran/resolve.c:13335
+#: fortran/resolve.c:13355
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be ALLOCATABLE"
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити резервљив"
 
-#: fortran/resolve.c:13341
+#: fortran/resolve.c:13361
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a POINTER"
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити показивач"
 
-#: fortran/resolve.c:13370
+#: fortran/resolve.c:13390
 #, fuzzy, gcc-internal-format
 #| msgid "INTERFACE procedure '%s' at %L has the same name as the enclosing procedure"
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "Процедура сучеља ‘%s’ код %L има исто име као и обухватајућа процедура"
 
-#: fortran/resolve.c:13380
+#: fortran/resolve.c:13400
 #, fuzzy, gcc-internal-format
 #| msgid "INTERFACE procedure '%s' at %L has the same name as the enclosing procedure"
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "Процедура сучеља ‘%s’ код %L има исто име као и обухватајућа процедура"
 
-#: fortran/resolve.c:13472
+#: fortran/resolve.c:13492
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.c:13574
+#: fortran/resolve.c:13594
 #, fuzzy, gcc-internal-format
 #| msgid "Array pointer '%s' at %L must have a deferred shape"
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "Низовни показивач ‘%s’ код %L мора имати одложен облик"
 
-#: fortran/resolve.c:13583
+#: fortran/resolve.c:13603
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13593
+#: fortran/resolve.c:13613
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.c:13602
+#: fortran/resolve.c:13622
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.c:13613
+#: fortran/resolve.c:13633
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ICHAR at %L must be of length one"
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "Аргумент у ICHAR код %L мора бити дужине један"
 
-#: fortran/resolve.c:13711
+#: fortran/resolve.c:13731
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:13725
+#: fortran/resolve.c:13745
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "Процедура корисничког оператора ‘%s’ код %L мора имати бар један аргумент"
 
-#: fortran/resolve.c:13741
+#: fortran/resolve.c:13761
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a non-derived type"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити неизведени тип"
 
-#: fortran/resolve.c:13751
+#: fortran/resolve.c:13771
 #, fuzzy, gcc-internal-format
 #| msgid "Argument dim at %L must be scalar"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "Аргумент димензије код %L мора бити скалар"
 
-#: fortran/resolve.c:13760
+#: fortran/resolve.c:13780
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of elemental procedure at %L cannot have the POINTER attribute"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "Аргумент ‘%s’ елементалне процедуре код %L не може имати атрибут показивача"
 
-#: fortran/resolve.c:13769
+#: fortran/resolve.c:13789
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be ALLOCATABLE"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "Аргумент ‘%s’ за сопствено ‘%s’ код %L мора бити резервљив"
 
-#: fortran/resolve.c:13811
+#: fortran/resolve.c:13831
 #, fuzzy, gcc-internal-format
 #| msgid "INTERFACE procedure '%s' at %L has the same name as the enclosing procedure"
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "Процедура сучеља ‘%s’ код %L има исто име као и обухватајућа процедура"
 
-#: fortran/resolve.c:13824
+#: fortran/resolve.c:13844
 #, fuzzy, gcc-internal-format
 #| msgid "Character length of component '%s' needs to be a constant specification expression at %L."
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "Знаковна дужина компоненте ‘%s’ мора бити константан одреднички израз код %L."
 
-#: fortran/resolve.c:13835
+#: fortran/resolve.c:13855
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13868
+#: fortran/resolve.c:13888
 #, fuzzy, gcc-internal-format
 #| msgid "The component '%s' is a PRIVATE type and cannot be a component of '%s', which is PUBLIC at %L"
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "Компонента ‘%s’ је приватни тип и не може бити компонента у ‘%s’, која је јавна код %L"
 
-#: fortran/resolve.c:13876
+#: fortran/resolve.c:13896
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.c:13885
+#: fortran/resolve.c:13905
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "Компонента %s типа SEQUENCE декларисаног код %L нема атрибут SEQUENCE"
 
-#: fortran/resolve.c:13903 fortran/resolve.c:13915
+#: fortran/resolve.c:13923 fortran/resolve.c:13935
 #, fuzzy, gcc-internal-format
 #| msgid "The pointer component '%s' of '%s' at %L is a type that has not been declared"
 msgid "The pointer component %qs of %qs at %L is a type that has not been declared"
 msgstr "Показивачка компонента ‘%s’ у ‘%s’ код %L припада типу који није декларисан"
 
-#: fortran/resolve.c:13989
+#: fortran/resolve.c:14009
 #, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr ""
 
-#: fortran/resolve.c:14034
+#: fortran/resolve.c:14054
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.c:14047
+#: fortran/resolve.c:14067
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr ""
 
-#: fortran/resolve.c:14111
+#: fortran/resolve.c:14131
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14144
+#: fortran/resolve.c:14164
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.c:14216
+#: fortran/resolve.c:14236
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed size array '%s' in namelist '%s'at %C is not allowed."
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "Низ претпостављене величине ‘%s’ у листи имена ‘%s’ код %C није дозвољен."
 
-#: fortran/resolve.c:14222
+#: fortran/resolve.c:14242
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14228
+#: fortran/resolve.c:14248
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14236
+#: fortran/resolve.c:14256
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14253
+#: fortran/resolve.c:14273
 #, fuzzy, gcc-internal-format
 #| msgid "PRIVATE symbol '%s' cannot be member of PUBLIC namelist at %L"
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "Приватни симбол ‘%s’ не може бити члан јавне листе имена код %L"
 
-#: fortran/resolve.c:14275
+#: fortran/resolve.c:14295
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14286
+#: fortran/resolve.c:14306
 #, fuzzy, gcc-internal-format
 #| msgid "PRIVATE symbol '%s' cannot be member of PUBLIC namelist at %L"
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "Приватни симбол ‘%s’ не може бити члан јавне листе имена код %L"
 
-#: fortran/resolve.c:14313
+#: fortran/resolve.c:14333
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "Атрибут процедуре коси се са атрибутом листе имена у ‘%s’ код %L"
 
-#: fortran/resolve.c:14337
+#: fortran/resolve.c:14357
 #, fuzzy, gcc-internal-format
 #| msgid "Parameter array '%s' at %L cannot be automatic or assumed shape"
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "Параметарски низ ‘%s’ код %L не може бити аутоматског или претпостављеног облика"
 
-#: fortran/resolve.c:14353
+#: fortran/resolve.c:14373
 #, fuzzy, gcc-internal-format
 #| msgid "Implicitly typed PARAMETER '%s' at %L doesn't match a later IMPLICIT type"
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "Имплицитно типски параметар ‘%s’ код %L не одговара каснијем имплицитном типу"
 
-#: fortran/resolve.c:14364
+#: fortran/resolve.c:14384
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "Несагласан изведени тип у параметру код %L"
 
-#: fortran/resolve.c:14372
+#: fortran/resolve.c:14392
 #, fuzzy, gcc-internal-format
 #| msgid "Object '%s' at %L must have the SAVE attribute %s"
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "Објекат ‘%s’ код %L мора имати атрибут %s за SAVE"
 
-#: fortran/resolve.c:14423
+#: fortran/resolve.c:14443
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr ""
 
-#: fortran/resolve.c:14434
+#: fortran/resolve.c:14454
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.c:14441
+#: fortran/resolve.c:14461
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.c:14480
+#: fortran/resolve.c:14500
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:14544
+#: fortran/resolve.c:14564
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "Атрибут процедуре коси се са атрибутом листе имена у ‘%s’ код %L"
 
-#: fortran/resolve.c:14547
+#: fortran/resolve.c:14567
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "Атрибут процедуре коси се са атрибутом листе имена у ‘%s’ код %L"
 
-#: fortran/resolve.c:14643
+#: fortran/resolve.c:14663
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:14664
+#: fortran/resolve.c:14684
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad specification for assumed size array at %C"
 msgid "Bad specification for assumed size array at %L"
 msgstr "Лоша одредница за низ претпостављене величине код %C"
 
-#: fortran/resolve.c:14677
+#: fortran/resolve.c:14697
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "Низ претпостављене величине код %L мора бити лажни аргумент"
 
-#: fortran/resolve.c:14680
+#: fortran/resolve.c:14700
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "Низ претпостављеног облика код %L мора бити лажни аргумент"
 
-#: fortran/resolve.c:14688
+#: fortran/resolve.c:14708
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "Низ претпостављеног облика код %L мора бити лажни аргумент"
 
-#: fortran/resolve.c:14695
+#: fortran/resolve.c:14715
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:14708
+#: fortran/resolve.c:14728
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "Симбол код %L није лажна променљива"
 
-#: fortran/resolve.c:14714
+#: fortran/resolve.c:14734
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14724
+#: fortran/resolve.c:14744
 #, fuzzy, gcc-internal-format
 #| msgid "Character-valued statement function '%s' at %L must have constant length"
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "Наредбена функција знаковне вредности ‘%s’ код %L мора имати константну дужину"
 
-#: fortran/resolve.c:14733
+#: fortran/resolve.c:14753
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.c:14746 fortran/resolve.c:14923
+#: fortran/resolve.c:14766 fortran/resolve.c:14943
 #, fuzzy, gcc-internal-format
 #| msgid "The derived type '%s' at %L is of type '%s', which has not been defined."
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "Изведени тип ‘%s’ код %L је типа ‘%s’, који није дефинисан."
 
-#: fortran/resolve.c:14760
+#: fortran/resolve.c:14780
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14769
+#: fortran/resolve.c:14789
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:14778
+#: fortran/resolve.c:14798
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14786
+#: fortran/resolve.c:14806
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:14793
+#: fortran/resolve.c:14813
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:14813
+#: fortran/resolve.c:14833
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.c:14820
+#: fortran/resolve.c:14840
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14827
+#: fortran/resolve.c:14847
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Derived type variable in COMMON at %C does not have the SEQUENCE attribute"
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "Променљива изведеног типа у заједничком код %C нема атрибут SEQUENCE"
 
-#: fortran/resolve.c:14834
+#: fortran/resolve.c:14854
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:14860
+#: fortran/resolve.c:14880
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:14870
+#: fortran/resolve.c:14890
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "Аргумент за %s код %L мора бити дужине један"
 
-#: fortran/resolve.c:14949
+#: fortran/resolve.c:14969
 #, fuzzy, gcc-internal-format
 #| msgid "PUBLIC function '%s' at %L cannot be of PRIVATE type '%s'"
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "Јавна функција ‘%s’ код %L не може бити приватног типа ‘%s’"
 
-#: fortran/resolve.c:14964
+#: fortran/resolve.c:14984
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14977
+#: fortran/resolve.c:14997
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14995
+#: fortran/resolve.c:15015
 #, fuzzy, gcc-internal-format
 #| msgid "The INTENT(OUT) dummy argument '%s' at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "Лажни аргумент намере-из ‘%s’ код %L је претпостављене величине и зато не може имати подразумевани успостављач"
 
-#: fortran/resolve.c:15007
+#: fortran/resolve.c:15027
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "Лажни аргумент ‘%s’ код %L не може бити намере-из"
 
-#: fortran/resolve.c:15016
+#: fortran/resolve.c:15036
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "Лажни аргумент ‘%s’ код %L не може бити намере-из"
 
-#: fortran/resolve.c:15028
+#: fortran/resolve.c:15048
 #, fuzzy, gcc-internal-format
 #| msgid "By-value argument at %L cannot be an array or an array section"
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "Аргумент-по-вредности код %L не може бити низ или одељак низа"
 
-#: fortran/resolve.c:15037
+#: fortran/resolve.c:15057
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15049
+#: fortran/resolve.c:15069
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15065
+#: fortran/resolve.c:15085
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15073
+#: fortran/resolve.c:15093
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "Низ ‘%s’ код %L не може имати одложен облик"
 
-#: fortran/resolve.c:15080
+#: fortran/resolve.c:15100
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable array '%s' at %L must have a deferred shape"
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "Резервљиви низ ‘%s’ код %L мора имати одложени облик"
 
-#: fortran/resolve.c:15092
+#: fortran/resolve.c:15112
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.c:15101
+#: fortran/resolve.c:15121
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy procedure at %L not allowed in ELEMENTAL procedure"
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "Лажна процедура код %L није дозвољена у елементалној процедури"
 
-#: fortran/resolve.c:15117
+#: fortran/resolve.c:15137
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15123
+#: fortran/resolve.c:15143
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15148
+#: fortran/resolve.c:15168
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist %s cannot be renamed by USE association to %s."
 msgid "Namelist %qs can not be an argument to subroutine or function at %L"
 msgstr "Листа имена %s не може се преименовати у %s придружењем USE."
 
-#: fortran/resolve.c:15218
+#: fortran/resolve.c:15238
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "Нитно-приватно код %L не снима се"
 
-#: fortran/resolve.c:15229
+#: fortran/resolve.c:15249
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:15333
+#: fortran/resolve.c:15353
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:15339
+#: fortran/resolve.c:15359
 #, fuzzy, gcc-internal-format
 #| msgid "BLOCK DATA element '%s' at %L must be in COMMON"
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "BLOCK DATA елемент ‘%s’ код %L мора бити у заједничком"
 
-#: fortran/resolve.c:15345
+#: fortran/resolve.c:15365
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.c:15354
+#: fortran/resolve.c:15374
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "Лажно ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.c:15368
+#: fortran/resolve.c:15388
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:15414
+#: fortran/resolve.c:15434
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "Неконстантан одељак низа код %L у наредби DATA"
 
-#: fortran/resolve.c:15427
+#: fortran/resolve.c:15447
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "Наредба DATA код %L има више променљивих него вредности"
 
-#: fortran/resolve.c:15526
+#: fortran/resolve.c:15546
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15534
+#: fortran/resolve.c:15554
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15542
+#: fortran/resolve.c:15562
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15667
+#: fortran/resolve.c:15687
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "Наредба DATA код %L има више вредности него променљивих"
 
-#: fortran/resolve.c:15832
+#: fortran/resolve.c:15852
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "Ознака %d код %L дефинисана али неупотребљена"
 
-#: fortran/resolve.c:15838
+#: fortran/resolve.c:15858
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "Ознака %d код %L дефинисана али не може бити употребљена"
 
-#: fortran/resolve.c:15922
+#: fortran/resolve.c:15942
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "Променљива изведеног типа ‘%s’ код %L мора имати атрибут SEQUENCE да би била објекат еквиваленције"
 
-#: fortran/resolve.c:15931
+#: fortran/resolve.c:15951
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "Променљива изведеног типа ‘%s’ код %L не може имати резервљиве компоненте како би била објекат еквиваленције"
 
-#: fortran/resolve.c:15939
+#: fortran/resolve.c:15959
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with default initializer cannot be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "Променљива изведеног типа ‘%s’ код %L са подразумеваним успостављачем не може бити објекат еквиваленције"
 
-#: fortran/resolve.c:15955
+#: fortran/resolve.c:15975
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "Променљива изведеног типа ‘%s’ код %L са показивачким компонентама не може бити објекат еквиваленције"
 
-#: fortran/resolve.c:16058
+#: fortran/resolve.c:16078
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "Синтаксна грешка у наредби EQUIVALENCE код %L"
 
-#: fortran/resolve.c:16073
+#: fortran/resolve.c:16093
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:16098
+#: fortran/resolve.c:16118
 #, fuzzy, gcc-internal-format
 #| msgid "Common block member '%s' at %L cannot be an EQUIVALENCE object in the pure procedure '%s'"
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "Члан заједничког блока ‘%s’ код %L не може бити објекат еквиваленције у чистој процедури ‘%s’"
 
-#: fortran/resolve.c:16107
+#: fortran/resolve.c:16127
 #, fuzzy, gcc-internal-format
 #| msgid "Named constant '%s' at %L cannot be an EQUIVALENCE object"
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Именована константа ‘%s’ код %L не може бити објекат еквиваленције"
 
-#: fortran/resolve.c:16180
+#: fortran/resolve.c:16200
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "Низ ‘%s’ код %L са неконстантним границама не може бити објекат еквиваленције"
 
-#: fortran/resolve.c:16191
+#: fortran/resolve.c:16211
 #, fuzzy, gcc-internal-format
 #| msgid "Structure component '%s' at %L cannot be an EQUIVALENCE object"
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Компонената структуре ‘%s’ код %L не може бити објекат еквиваленције"
 
-#: fortran/resolve.c:16202
+#: fortran/resolve.c:16222
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "Подниска код %L има нулту дужину"
 
-#: fortran/resolve.c:16293
+#: fortran/resolve.c:16253
 #, fuzzy, gcc-internal-format
+#| msgid "Different character lengths in pointer assignment at %L"
+msgid "Self reference in character length expression for %qs at %L"
+msgstr "Различите знаковне дужине у додели показивача код %L"
+
+#: fortran/resolve.c:16320
+#, fuzzy, gcc-internal-format
 #| msgid "PUBLIC function '%s' at %L cannot be of PRIVATE type '%s'"
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "Јавна функција ‘%s’ код %L не може бити приватног типа ‘%s’"
 
-#: fortran/resolve.c:16306
+#: fortran/resolve.c:16333
 #, fuzzy, gcc-internal-format
 #| msgid "ENTRY '%s' at %L has no IMPLICIT type"
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "Унос ‘%s’ код %L нема имплицитан тип"
 
-#: fortran/resolve.c:16326
+#: fortran/resolve.c:16353
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must be a FUNCTION"
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "Процедура корисничког оператора ‘%s’ код %L мора бити функција"
 
-#: fortran/resolve.c:16336
+#: fortran/resolve.c:16363
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L cannot be assumed character length"
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "Процедура корисничког оператора ‘%s’ код %L не може бити претпостављене знаковне дужине"
 
-#: fortran/resolve.c:16344
+#: fortran/resolve.c:16371
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "Процедура корисничког оператора ‘%s’ код %L мора имати бар један аргумент"
 
-#: fortran/resolve.c:16358
+#: fortran/resolve.c:16385
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "Први аргумент сучеља оператора код %L не може бити опциони"
 
-#: fortran/resolve.c:16376
+#: fortran/resolve.c:16403
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "Други аргумент сучеља оператора код %L не може бити опциони"
 
-#: fortran/resolve.c:16383
+#: fortran/resolve.c:16410
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "Сучеље оператора код %L мора имати, највише, два аргумента"
 
-#: fortran/resolve.c:16461
+#: fortran/resolve.c:16488
 #, fuzzy, gcc-internal-format
 #| msgid "Contained procedure '%s' at %L of a PURE procedure must also be PURE"
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
@@ -68866,19 +68955,13 @@
 msgid "simplify_min_max(): Bad type in arglist"
 msgstr ""
 
-#. Result is processor-dependent.
-#: fortran/simplify.c:5472
-#, gcc-internal-format, gfc-internal-format
-msgid "Second argument MOD at %L is zero"
-msgstr "Други аргумент у MOD код %L је нула"
+#: fortran/simplify.c:5470 fortran/simplify.c:5478
+#, fuzzy, gcc-internal-format
+#| msgid "Second argument of NEAREST at %L shall not be zero"
+msgid "Argument %qs of MOD at %L shall not be zero"
+msgstr "Други аргумент у NEAREST код %L не може бити нула"
 
-#. Result is processor-dependent.
-#: fortran/simplify.c:5483
-#, gcc-internal-format, gfc-internal-format
-msgid "Second argument of MOD at %L is zero"
-msgstr "Други аргумент у MOD код %L је нула"
-
-#: fortran/simplify.c:5494
+#: fortran/simplify.c:5484
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_simplify_mod(): Bad arguments"
@@ -68887,104 +68970,104 @@
 #. Result is processor-dependent. This processor just opts
 #. to not handle it at all.
 #. Result is processor-dependent.
-#: fortran/simplify.c:5520 fortran/simplify.c:5532
+#: fortran/simplify.c:5525 fortran/simplify.c:5537
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of MODULO at %L is zero"
 msgstr "Други аргумент у MODULO код %L је нула"
 
-#: fortran/simplify.c:5552
+#: fortran/simplify.c:5557
 #, gcc-internal-format
 msgid "gfc_simplify_modulo(): Bad arguments"
 msgstr ""
 
-#: fortran/simplify.c:5600
+#: fortran/simplify.c:5605
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Result of %s is NaN at %L"
 msgid "Result of NEAREST is NaN at %L"
 msgstr "Резултат %s јесте NaN код %L"
 
-#: fortran/simplify.c:6081
+#: fortran/simplify.c:6086
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument NCOPIES of REPEAT intrinsic is negative"
 msgid "Argument NCOPIES of REPEAT intrinsic is negative at %L"
 msgstr "Аргумент NCOPIES уз сопствено REPEAT негативан је"
 
-#: fortran/simplify.c:6137
+#: fortran/simplify.c:6142
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument NCOPIES of REPEAT intrinsic is negative"
 msgid "Argument NCOPIES of REPEAT intrinsic is too large at %L"
 msgstr "Аргумент NCOPIES уз сопствено REPEAT негативан је"
 
-#: fortran/simplify.c:6174
+#: fortran/simplify.c:6179
 #, gcc-internal-format, gfc-internal-format
 msgid "Evaluation of string longer than 2**28 at %L deferred to runtime, expect bugs"
 msgstr ""
 
-#: fortran/simplify.c:6302
+#: fortran/simplify.c:6307
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Integer too large at %C"
 msgid "Reshaped array too large at %C"
 msgstr "Цео број превелик код %C"
 
-#: fortran/simplify.c:6416
+#: fortran/simplify.c:6421
 #, gcc-internal-format, gfc-internal-format
 msgid "Result of SCALE overflows its kind at %L"
 msgstr "Резултат SCALE прелива своју врсту код %L"
 
-#: fortran/simplify.c:6995
+#: fortran/simplify.c:7000
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "Bad type in gfc_simplify_sign"
 msgstr "Лош тип у константном изразу"
 
-#: fortran/simplify.c:7024
+#: fortran/simplify.c:7029
 #, gcc-internal-format
 msgid "in gfc_simplify_sin(): Bad type"
 msgstr ""
 
-#: fortran/simplify.c:7151 fortran/simplify.c:7431
+#: fortran/simplify.c:7156 fortran/simplify.c:7436
 #, gcc-internal-format
 msgid "Failure getting length of a constant array."
 msgstr ""
 
-#: fortran/simplify.c:7161
+#: fortran/simplify.c:7166
 #, gcc-internal-format
 msgid "The number of elements (%d) in the array constructor at %L requires an increase of the allowed %d upper limit.  See %<-fmax-array-constructor%> option."
 msgstr ""
 
-#: fortran/simplify.c:7227
+#: fortran/simplify.c:7232
 #, gcc-internal-format, gfc-internal-format
 msgid "Simplification of SPREAD at %C not yet implemented"
 msgstr ""
 
-#: fortran/simplify.c:7251
+#: fortran/simplify.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SQRT at %L has a negative value"
 msgstr "Аргумент у SQRT код %L има негативну вредност"
 
-#: fortran/simplify.c:7267
+#: fortran/simplify.c:7272
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid second argument of IBSET at %L"
 msgid "invalid argument of SQRT at %L"
 msgstr "Неисправан други аргумент у IBSET код %L"
 
-#: fortran/simplify.c:7598
+#: fortran/simplify.c:7603
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY lower bound is %ld)"
 msgstr ""
 
-#: fortran/simplify.c:7621
+#: fortran/simplify.c:7626
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY upper bound is %ld)"
 msgstr ""
 
-#: fortran/simplify.c:7993
+#: fortran/simplify.c:7998
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_conv_constant_to_tree(): invalid type: %s"
 msgid "gfc_convert_constant(): Unexpected type"
 msgstr "gfc_conv_constant_to_tree(): неисправан тип: %s"
 
-#: fortran/simplify.c:8078
+#: fortran/simplify.c:8083
 #, gcc-internal-format
 msgid "Character %qs in string at %L cannot be converted into character kind %d"
 msgstr ""
@@ -69097,7 +69180,7 @@
 msgid "BIND(C) applied to %s %s at %L"
 msgstr ""
 
-#: fortran/symbol.c:901 fortran/symbol.c:912 fortran/symbol.c:1762
+#: fortran/symbol.c:901 fortran/symbol.c:912 fortran/symbol.c:1776
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute conflicts with %s attribute at %L"
 msgstr "Атрибут %s коси се са атрибутом %s код %L"
@@ -69179,19 +69262,25 @@
 msgid "Duplicate VOLATILE attribute specified at %L"
 msgstr "Удвостручени атрибут SAVE наведен код %L"
 
-#: fortran/symbol.c:1367
+#: fortran/symbol.c:1360
 #, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "SAVE attribute at %L cannot be specified in a PURE procedure"
+msgid "VOLATILE attribute at %L cannot be specified in a PURE procedure"
+msgstr "Атрибут SAVE код %L не може бити наведен у чистој процедури"
+
+#: fortran/symbol.c:1381
+#, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate SAVE attribute specified at %L"
 msgid "Duplicate ASYNCHRONOUS attribute specified at %L"
 msgstr "Удвостручени атрибут SAVE наведен код %L"
 
-#: fortran/symbol.c:1758
+#: fortran/symbol.c:1772
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "%s attribute of %qs conflicts with %s attribute at %L"
 msgstr "Атрибут %s коси се са атрибутом %s код %L"
 
-#: fortran/symbol.c:1794
+#: fortran/symbol.c:1808
 #, gcc-internal-format, gfc-internal-format
 msgid ""
 "%s procedure at %L is already declared as %s procedure. \n"
@@ -69198,161 +69287,161 @@
 "F2008: A pointer function assignment is ambiguous if it is the first executable statement after the specification block. Please add any other kind of executable statement before it. FIXME"
 msgstr ""
 
-#: fortran/symbol.c:1802
+#: fortran/symbol.c:1816
 #, gcc-internal-format, gfc-internal-format
 msgid "%s procedure at %L is already declared as %s procedure"
 msgstr "Процедура %s код %L је већ декларисана као процедура %s"
 
-#: fortran/symbol.c:1837
+#: fortran/symbol.c:1851
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgstr "Намера-%s коси се са намером-%s код %L"
 
-#: fortran/symbol.c:1861
+#: fortran/symbol.c:1875
 #, gcc-internal-format, gfc-internal-format
 msgid "ACCESS specification at %L was already specified"
 msgstr "Одредница ACCESS код %L је већ наведена "
 
-#: fortran/symbol.c:1878
+#: fortran/symbol.c:1892
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate %s attribute specified at %L"
 msgid "Duplicate BIND attribute specified at %L"
 msgstr "Удвостручени атрибут %S наведен код %L"
 
-#: fortran/symbol.c:1885
+#: fortran/symbol.c:1899
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) at %L"
 msgstr ""
 
-#: fortran/symbol.c:1901
+#: fortran/symbol.c:1915
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate SAVE attribute specified at %L"
 msgid "Duplicate EXTENDS attribute specified at %L"
 msgstr "Удвостручени атрибут SAVE наведен код %L"
 
-#: fortran/symbol.c:1905
+#: fortran/symbol.c:1919
 #, gcc-internal-format, gfc-internal-format
 msgid "EXTENDS at %L"
 msgstr ""
 
-#: fortran/symbol.c:1931
+#: fortran/symbol.c:1945
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L already has an explicit interface"
 msgid "Symbol %qs at %L already has an explicit interface"
 msgstr "Симбол ‘%s’ код %L већ има експлицитно сучеље"
 
-#: fortran/symbol.c:1938
+#: fortran/symbol.c:1952
 #, gcc-internal-format
 msgid "%qs at %L has attributes specified outside its INTERFACE body"
 msgstr ""
 
-#: fortran/symbol.c:1976
+#: fortran/symbol.c:1990
 #, gcc-internal-format
 msgid "Symbol %qs at %L conflicts with symbol from module %qs, use-associated at %L"
 msgstr ""
 
-#: fortran/symbol.c:1980
+#: fortran/symbol.c:1994
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %C already has a type of %s"
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr "Функција ‘%s’ код %C већ има тип %s"
 
-#: fortran/symbol.c:1987
+#: fortran/symbol.c:2001
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type name '%s' at %C already has a basic type of %s"
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr "Име изведеног типа ‘%s’ код %C већ има основни тип %s"
 
-#: fortran/symbol.c:1999
+#: fortran/symbol.c:2013
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L cannot have a type"
 msgid "Symbol %qs at %L cannot have a type"
 msgstr "Симбол ‘%s’ код %L не може имати тип"
 
-#: fortran/symbol.c:2242
+#: fortran/symbol.c:2256
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C already declared at %L"
 msgid "Component %qs at %C already in the parent type at %L"
 msgstr "Компонента ‘%s’ код %C већ је декларисана код %L"
 
-#: fortran/symbol.c:2327
+#: fortran/symbol.c:2341
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C is ambiguous"
 msgid "Symbol %qs at %C is ambiguous"
 msgstr "Двосмислен симбол ‘%s’ код %C"
 
-#: fortran/symbol.c:2359
+#: fortran/symbol.c:2373
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %C is being used before it is defined"
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr "Изведени тип ‘%s’ код %C користи се пре него што је дефинисан"
 
-#: fortran/symbol.c:2508
+#: fortran/symbol.c:2522
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C is a PRIVATE component of '%s'"
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr "Компонента ‘%s’ код %C је приватна компонента у ‘%s’"
 
-#: fortran/symbol.c:2529
+#: fortran/symbol.c:2543
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is not a member of the '%s' structure"
 msgid "%qs at %C is not a member of the %qs structure; did you mean %qs?"
 msgstr "‘%s’ код %C није члан структуре ‘%s’"
 
-#: fortran/symbol.c:2533
+#: fortran/symbol.c:2547
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is not a member of the '%s' structure"
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr "‘%s’ код %C није члан структуре ‘%s’"
 
-#: fortran/symbol.c:2697
+#: fortran/symbol.c:2711
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr "Удвостручена етикета наредбе %d код %L и %L"
 
-#: fortran/symbol.c:2708
+#: fortran/symbol.c:2722
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr "Етикета %d код %C је већ поменута као циљ гранања"
 
-#: fortran/symbol.c:2718
+#: fortran/symbol.c:2732
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr "Етикета %d код %C је већ поменута код етикета формата"
 
-#: fortran/symbol.c:2724
+#: fortran/symbol.c:2738
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:2766
+#: fortran/symbol.c:2780
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr "Етикета %d код %C је претходно употребљена као етикета формата"
 
-#: fortran/symbol.c:2775
+#: fortran/symbol.c:2789
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr "Етикета %d код %C је претходно употребљена као циљ гранања"
 
-#: fortran/symbol.c:2781
+#: fortran/symbol.c:2795
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected terminating name at %C"
 msgid "Shared DO termination label %d at %C"
 msgstr "Очекивано је завршно име код %C"
 
-#: fortran/symbol.c:3110
+#: fortran/symbol.c:3124
 #, gcc-internal-format
 msgid "new_symbol(): Symbol name too long"
 msgstr ""
 
-#: fortran/symbol.c:3135
+#: fortran/symbol.c:3149
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is an ambiguous reference to '%s' from module '%s'"
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr "Име ‘%s’ код %C је двосмислен упућивач на ‘%s’ из модула ‘%s’"
 
-#: fortran/symbol.c:3138
+#: fortran/symbol.c:3152
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is an ambiguous reference to '%s' from current program unit"
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
@@ -69359,65 +69448,65 @@
 msgstr "Име ‘%s’ код %C је двосмислен упућивач на ‘%s’ из текуће програмске јединице"
 
 #. Symbol is from another namespace.
-#: fortran/symbol.c:3381
+#: fortran/symbol.c:3395
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C has already been host associated"
 msgid "Symbol %qs at %C has already been host associated"
 msgstr "Симбол ‘%s’ код %C је већ придружен домаћину"
 
-#: fortran/symbol.c:4397
+#: fortran/symbol.c:4411
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr ""
 
-#: fortran/symbol.c:4410
+#: fortran/symbol.c:4424
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr "Променљива изведеног типа ‘%s’ код %L мора имати атрибут SEQUENCE да би била објекат еквиваленције"
 
-#: fortran/symbol.c:4428
+#: fortran/symbol.c:4442
 #, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr ""
 
-#: fortran/symbol.c:4449
+#: fortran/symbol.c:4463
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:4459
+#: fortran/symbol.c:4473
 #, gcc-internal-format
 msgid "Procedure pointer component %qs at %L cannot be a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:4470
+#: fortran/symbol.c:4484
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:4509
+#: fortran/symbol.c:4523
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.c:4519
+#: fortran/symbol.c:4533
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/symbol.c:4533
+#: fortran/symbol.c:4547
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot be declared with both PRIVATE and BIND(C) attributes"
 msgstr ""
 
-#: fortran/symbol.c:4541
+#: fortran/symbol.c:4555
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr "Променљива изведеног типа ‘%s’ код %L мора имати атрибут SEQUENCE да би била објекат еквиваленције"
 
-#: fortran/symbol.c:5018 fortran/symbol.c:5023
+#: fortran/symbol.c:5032 fortran/symbol.c:5037
 #, gcc-internal-format
 msgid "Symbol %qs is used before it is typed at %L"
 msgstr ""
@@ -69467,7 +69556,7 @@
 msgid "Creating array temporary at %L for argument %qs"
 msgstr ""
 
-#: fortran/trans-array.c:10693
+#: fortran/trans-array.c:10724
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr "лош тип израза током хода (%d)"
@@ -69695,12 +69784,12 @@
 msgid "%<dim%> argument of %s intrinsic at %L is not a valid dimension index"
 msgstr "Аргумент ‘dim’ за сопствено ‘%s’ код %L није исправан димензиони индекс"
 
-#: fortran/trans-intrinsic.c:10572 fortran/trans-stmt.c:1050
+#: fortran/trans-intrinsic.c:10574 fortran/trans-stmt.c:1050
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, the event component of derived type at %L is not yet supported"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:10579
+#: fortran/trans-intrinsic.c:10581
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "iteration variable %qs should not be reduction"
 msgid "The event variable at %L shall not be coindexed"
@@ -69743,7 +69832,7 @@
 msgid "Sorry, only support for integer kind %d implemented for image-set at %L"
 msgstr ""
 
-#: fortran/trans-stmt.c:3346
+#: fortran/trans-stmt.c:3343
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_trans_select(): Bad type for case expr."
@@ -69889,7 +69978,7 @@
 msgid "two or more sections for %s"
 msgstr "два или више типова података у декларацији %qs"
 
-#: lto/lto-partition.c:516
+#: lto/lto-partition.c:570
 #, gcc-internal-format
 msgid "min partition size cannot be greater than max partition size"
 msgstr ""
@@ -70044,64 +70133,64 @@
 msgid "Cannot read %s"
 msgstr "не могу да отворим %s"
 
-#: lto/lto.c:2369
+#: lto/lto.c:2337
 #, gcc-internal-format
 msgid "lto_obj_file_open() failed"
 msgstr ""
 
-#: lto/lto.c:2394
+#: lto/lto.c:2362
 #, fuzzy, gcc-internal-format
 #| msgid "pex_init failed"
 msgid "waitpid failed"
 msgstr "pex_init није прошло"
 
-#: lto/lto.c:2397
+#: lto/lto.c:2365
 #, fuzzy, gcc-internal-format
 #| msgid "renaming .rpo file"
 msgid "streaming subprocess failed"
 msgstr "преименујем .rpo датотеку"
 
-#: lto/lto.c:2400
+#: lto/lto.c:2368
 #, gcc-internal-format
 msgid "streaming subprocess was killed by signal"
 msgstr ""
 
-#: lto/lto.c:2476
+#: lto/lto.c:2445
 #, gcc-internal-format
 msgid "no LTRANS output list filename provided"
 msgstr ""
 
-#: lto/lto.c:2564
+#: lto/lto.c:2525
 #, fuzzy, gcc-internal-format
 #| msgid "opening output file %s: %m"
 msgid "opening LTRANS output list %s: %m"
 msgstr "отварам улазну датотеку %s: %m"
 
-#: lto/lto.c:2570
+#: lto/lto.c:2532
 #, fuzzy, gcc-internal-format
 #| msgid "when writing output to %s: %m"
 msgid "writing to LTRANS output list %s: %m"
 msgstr "када уписујем излаз у %s: %m"
 
-#: lto/lto.c:2581
+#: lto/lto.c:2542
 #, fuzzy, gcc-internal-format
 #| msgid "opening output file %s: %m"
 msgid "closing LTRANS output list %s: %m"
 msgstr "отварам улазну датотеку %s: %m"
 
-#: lto/lto.c:2833
+#: lto/lto.c:2794
 #, fuzzy, gcc-internal-format
 #| msgid "%s:could not open output file '%s'\n"
 msgid "could not open symbol resolution file: %m"
 msgstr "%s:нисам могао да отворим излазну датотеку ‘%s’\n"
 
-#: lto/lto.c:2954
+#: lto/lto.c:2915
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing braces around initializer for %qT"
 msgid "missing resolution data for %s"
 msgstr "недостају витичасте заграде око успостављача за %qT"
 
-#: lto/lto.c:2986
+#: lto/lto.c:2947
 #, gcc-internal-format
 msgid "errors during merging of translation units"
 msgstr ""
@@ -73283,6 +73372,9 @@
 #~ msgid "Trace the parsing process"
 #~ msgstr "Прати поступак рашчлањивања"
 
+#~ msgid "Warn if the loop cannot be optimized due to nontrivial assumptions."
+#~ msgstr "Упозори ако се петља не може оптимизовати услед нетривијалних претпоставки."
+
 #~ msgid "Warn about code that will never be executed"
 #~ msgstr "Упозори на кôд који се никад не извршава"
 
Index: gcc/po/da.po
===================================================================
--- gcc/po/da.po	(.../tags/gcc_8_2_0_release)
+++ gcc/po/da.po	(.../branches/gcc-8-branch)
@@ -137,7 +137,7 @@
 msgstr ""
 "Project-Id-Version: gcc-8.1-b20180128\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2018-05-01 20:30+0000\n"
+"POT-Creation-Date: 2018-07-25 14:25+0000\n"
 "PO-Revision-Date: 2018-04-02 11:00+0200\n"
 "Last-Translator: Joe Hansen <joedalton2@yahoo.dk>\n"
 "Language-Team: Danish <dansk@dansk-gruppen.dk>\n"
@@ -169,12 +169,12 @@
 msgid "[cannot find %s]"
 msgstr "[kan ikke finde %s]"
 
-#: collect2.c:1557
+#: collect2.c:1585
 #, c-format
 msgid "collect2 version %s\n"
 msgstr "collect2-version %s\n"
 
-#: collect2.c:1664
+#: collect2.c:1692
 #, c-format
 msgid "%d constructor found\n"
 msgid_plural "%d constructors found\n"
@@ -181,7 +181,7 @@
 msgstr[0] "%d konstruktionsfunktion fundet\n"
 msgstr[1] "%d konstruktionsfunktioner fundet\n"
 
-#: collect2.c:1668
+#: collect2.c:1696
 #, c-format
 msgid "%d destructor found\n"
 msgid_plural "%d destructors found\n"
@@ -188,7 +188,7 @@
 msgstr[0] "%d destruktionsfunktion fundet\n"
 msgstr[1] "%d destruktionsfunktioner fundet\n"
 
-#: collect2.c:1672
+#: collect2.c:1700
 #, c-format
 msgid "%d frame table found\n"
 msgid_plural "%d frame tables found\n"
@@ -195,12 +195,12 @@
 msgstr[0] "%d rammetabel fundet\n"
 msgstr[1] "%d rammetabeller fundet\n"
 
-#: collect2.c:1836
+#: collect2.c:1864
 #, c-format
 msgid "[Leaving %s]\n"
 msgstr "[Efterlader %s]\n"
 
-#: collect2.c:2068
+#: collect2.c:2094
 #, c-format
 msgid ""
 "\n"
@@ -209,7 +209,7 @@
 "\n"
 "write_c_file - uddatanavnet er %s, præfikset er %s\n"
 
-#: collect2.c:2584
+#: collect2.c:2610
 #, c-format
 msgid ""
 "\n"
@@ -232,7 +232,7 @@
 msgid "%s: some warnings being treated as errors"
 msgstr "%s: nogle advarsler bliver opfattet som fejl"
 
-#: diagnostic.c:324 input.c:222 input.c:1834 c-family/c-opts.c:1377
+#: diagnostic.c:324 input.c:222 input.c:1834 c-family/c-opts.c:1392
 #: fortran/cpp.c:576 fortran/error.c:1008 fortran/error.c:1028
 msgid "<built-in>"
 msgstr "<indbygget>"
@@ -324,13 +324,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:4164 config/arc/arc.c:5784 config/i386/i386.c:17302
+#: final.c:4164 config/arc/arc.c:5775 config/i386/i386.c:17305
 #: config/pdp11/pdp11.c:1715
 #, c-format
 msgid "floating constant misused"
 msgstr "kommatalskonstant misbrugt"
 
-#: final.c:4222 config/arc/arc.c:5881 config/i386/i386.c:17393
+#: final.c:4222 config/arc/arc.c:5872 config/i386/i386.c:17396
 #: config/pdp11/pdp11.c:1756
 #, c-format
 msgid "invalid expression as operand"
@@ -1244,7 +1244,7 @@
 msgid "GCSE disabled"
 msgstr "GCSE deaktiveret"
 
-#: gimple-ssa-isolate-paths.c:542 c/c-typeck.c:10240
+#: gimple-ssa-isolate-paths.c:542 c/c-typeck.c:10245
 #, gcc-internal-format
 msgid "function returns address of local variable"
 msgstr "funktion returnerer adressen på en lokal variabel"
@@ -1546,7 +1546,7 @@
 msgid "options enabled: "
 msgstr "tilvalg slået til: "
 
-#: tree-diagnostic.c:299 c/c-decl.c:5419 c/c-typeck.c:7259 cp/error.c:1042
+#: tree-diagnostic.c:299 c/c-decl.c:5439 c/c-typeck.c:7264 cp/error.c:1042
 #: c-family/c-pretty-print.c:413
 #, gcc-internal-format
 msgid "<anonymous>"
@@ -3021,67 +3021,67 @@
 msgstr "længdemodifikation i strfmon-formatering"
 
 #. Handle deferred options from command-line.
-#: c-family/c-opts.c:1402 fortran/cpp.c:590
+#: c-family/c-opts.c:1417 fortran/cpp.c:590
 msgid "<command-line>"
 msgstr "<kommandolinje>"
 
-#: config/aarch64/aarch64.c:6613
+#: config/aarch64/aarch64.c:6629
 #, fuzzy, c-format
 #| msgid "Unsupported operand for code '%c'"
 msgid "unsupported operand for code '%c'"
 msgstr "Ikke understøttet operand for koden »%c«"
 
-#: config/aarch64/aarch64.c:6624 config/aarch64/aarch64.c:6640
-#: config/aarch64/aarch64.c:6652 config/aarch64/aarch64.c:6663
-#: config/aarch64/aarch64.c:6673 config/aarch64/aarch64.c:6694
-#: config/aarch64/aarch64.c:6764 config/aarch64/aarch64.c:6775
-#: config/aarch64/aarch64.c:6789 config/aarch64/aarch64.c:7011
-#: config/aarch64/aarch64.c:7029
+#: config/aarch64/aarch64.c:6640 config/aarch64/aarch64.c:6656
+#: config/aarch64/aarch64.c:6668 config/aarch64/aarch64.c:6679
+#: config/aarch64/aarch64.c:6689 config/aarch64/aarch64.c:6710
+#: config/aarch64/aarch64.c:6780 config/aarch64/aarch64.c:6791
+#: config/aarch64/aarch64.c:6805 config/aarch64/aarch64.c:7027
+#: config/aarch64/aarch64.c:7045
 #, c-format
 msgid "invalid operand for '%%%c'"
 msgstr "ugyldig operand for »%%%c«"
 
-#: config/aarch64/aarch64.c:6709 config/aarch64/aarch64.c:6720
-#: config/aarch64/aarch64.c:6871 config/aarch64/aarch64.c:6882
+#: config/aarch64/aarch64.c:6725 config/aarch64/aarch64.c:6736
+#: config/aarch64/aarch64.c:6887 config/aarch64/aarch64.c:6898
 #, fuzzy, c-format
 #| msgid "invalid constant"
 msgid "invalid vector constant"
 msgstr "ugyldig konstant:"
 
-#: config/aarch64/aarch64.c:6732 config/aarch64/aarch64.c:6744
-#: config/aarch64/aarch64.c:6755
+#: config/aarch64/aarch64.c:6748 config/aarch64/aarch64.c:6760
+#: config/aarch64/aarch64.c:6771
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6823 config/arm/arm.c:22704
+#: config/aarch64/aarch64.c:6839 config/arm/arm.c:22704
 #, c-format
 msgid "missing operand"
 msgstr "manglende operand"
 
-#: config/aarch64/aarch64.c:6908
+#: config/aarch64/aarch64.c:6924
 #, c-format
 msgid "invalid constant"
 msgstr "ugyldig konstant:"
 
-#: config/aarch64/aarch64.c:6911
+#: config/aarch64/aarch64.c:6927
 #, c-format
 msgid "invalid operand"
 msgstr "ugyldig operand"
 
-#: config/aarch64/aarch64.c:7040 config/aarch64/aarch64.c:7045
+#: config/aarch64/aarch64.c:7056 config/aarch64/aarch64.c:7061
 #, c-format
 msgid "invalid operand prefix '%%%c'"
 msgstr "ugyldig operandpræfiks »%%%c«"
 
-#: config/aarch64/aarch64.c:7062
+#: config/aarch64/aarch64.c:7078
 #, fuzzy, c-format
 #| msgid "invalid addressing mode"
 msgid "invalid address mode"
 msgstr "ugyldig adresseringstilstand"
 
-#: config/alpha/alpha.c:5125 config/i386/i386.c:18558
-#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21798
+#: config/alpha/alpha.c:5125 config/i386/i386.c:18561
+#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21875
 #: config/sparc/sparc.c:9290
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
@@ -3098,7 +3098,7 @@
 msgstr "ugyldig %%r-værdi"
 
 #: config/alpha/alpha.c:5223 config/ia64/ia64.c:5534
-#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21506
+#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21583
 #: config/xtensa/xtensa.c:2429
 #, c-format
 msgid "invalid %%R value"
@@ -3105,13 +3105,13 @@
 msgstr "ugyldig %%R-værdi"
 
 #: config/alpha/alpha.c:5229 config/powerpcspe/powerpcspe.c:23933
-#: config/rs6000/rs6000.c:21426 config/xtensa/xtensa.c:2396
+#: config/rs6000/rs6000.c:21503 config/xtensa/xtensa.c:2396
 #, c-format
 msgid "invalid %%N value"
 msgstr "ugyldig %%N-værdi"
 
 #: config/alpha/alpha.c:5237 config/powerpcspe/powerpcspe.c:23961
-#: config/rs6000/rs6000.c:21454
+#: config/rs6000/rs6000.c:21531
 #, c-format
 msgid "invalid %%P value"
 msgstr "ugyldig %%P-værdi"
@@ -3142,7 +3142,7 @@
 msgstr "ugyldig %%U-værdi"
 
 #: config/alpha/alpha.c:5323 config/powerpcspe/powerpcspe.c:24021
-#: config/rs6000/rs6000.c:21514
+#: config/rs6000/rs6000.c:21591
 #, c-format
 msgid "invalid %%s value"
 msgstr "ugyldig %%s-værdi"
@@ -3153,7 +3153,7 @@
 msgstr "ugyldig %%C-værdi"
 
 #: config/alpha/alpha.c:5371 config/powerpcspe/powerpcspe.c:23797
-#: config/rs6000/rs6000.c:21290
+#: config/rs6000/rs6000.c:21367
 #, c-format
 msgid "invalid %%E value"
 msgstr "ugyldig %%E-værdi"
@@ -3164,7 +3164,7 @@
 msgstr "ukendt relokaliserings-unspec"
 
 #: config/alpha/alpha.c:5405 config/cr16/cr16.c:1569
-#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21803
+#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21880
 #: config/spu/spu.c:1458
 #, c-format
 msgid "invalid %%xn code"
@@ -3175,58 +3175,58 @@
 msgid "invalid operand address"
 msgstr "ugyldig operandadresse"
 
-#: config/arc/arc.c:3810
+#: config/arc/arc.c:3808
 #, c-format
 msgid "invalid operand to %%Z code"
 msgstr "ugyldig operand til %%Z-koden"
 
-#: config/arc/arc.c:3818
+#: config/arc/arc.c:3816
 #, c-format
 msgid "invalid operand to %%z code"
 msgstr "ugyldig operand til %%z-koden"
 
-#: config/arc/arc.c:3826
+#: config/arc/arc.c:3824
 #, fuzzy, c-format
 #| msgid "invalid operand to %%Z code"
 msgid "invalid operands to %%c code"
 msgstr "ugyldig operand til %%Z-koden"
 
-#: config/arc/arc.c:3834
+#: config/arc/arc.c:3832
 #, c-format
 msgid "invalid operand to %%M code"
 msgstr "ugyldig operand til %%M-koden"
 
-#: config/arc/arc.c:3842 config/m32r/m32r.c:2100
+#: config/arc/arc.c:3840 config/m32r/m32r.c:2100
 #, c-format
 msgid "invalid operand to %%p code"
 msgstr "ugyldig operand til %%p-koden"
 
-#: config/arc/arc.c:3853 config/m32r/m32r.c:2093
+#: config/arc/arc.c:3851 config/m32r/m32r.c:2093
 #, c-format
 msgid "invalid operand to %%s code"
 msgstr "ugyldig operand til %%s-koden"
 
-#: config/arc/arc.c:4001 config/m32r/m32r.c:2126
+#: config/arc/arc.c:3999 config/m32r/m32r.c:2126
 #, c-format
 msgid "invalid operand to %%R code"
 msgstr "ugyldig operand til %%R-koden"
 
-#: config/arc/arc.c:4077 config/m32r/m32r.c:2149
+#: config/arc/arc.c:4075 config/m32r/m32r.c:2149
 #, c-format
 msgid "invalid operand to %%H/%%L code"
 msgstr "ugyldig operand til %%H/%%L-koden"
 
-#: config/arc/arc.c:4145 config/m32r/m32r.c:2220
+#: config/arc/arc.c:4143 config/m32r/m32r.c:2220
 #, c-format
 msgid "invalid operand to %%U code"
 msgstr "ugyldig operand til %%U-koden"
 
-#: config/arc/arc.c:4157
+#: config/arc/arc.c:4155
 #, c-format
 msgid "invalid operand to %%V code"
 msgstr "ugyldig operand til %%V-koden"
 
-#: config/arc/arc.c:4214
+#: config/arc/arc.c:4212
 #, c-format
 msgid "invalid operand to %%O code"
 msgstr "ugyldig operand til %%O-koden"
@@ -3233,18 +3233,18 @@
 
 #. Unknown flag.
 #. Undocumented flag.
-#: config/arc/arc.c:4240 config/epiphany/epiphany.c:1305
-#: config/m32r/m32r.c:2247 config/nds32/nds32.c:3079 config/sparc/sparc.c:9569
+#: config/arc/arc.c:4238 config/epiphany/epiphany.c:1305
+#: config/m32r/m32r.c:2247 config/nds32/nds32.c:3080 config/sparc/sparc.c:9569
 #, c-format
 msgid "invalid operand output code"
 msgstr "ugyldig operand-uddatakode"
 
-#: config/arc/arc.c:5869
+#: config/arc/arc.c:5860
 #, c-format
 msgid "invalid UNSPEC as operand: %d"
 msgstr "ugyldig UNSPEC som operand: %d"
 
-#: config/arc/arc.c:6158 config/cris/cris.c:2568
+#: config/arc/arc.c:6149 config/cris/cris.c:2568
 msgid "unrecognized supposed constant"
 msgstr "ukendt formodet konstant"
 
@@ -3281,7 +3281,7 @@
 #: config/arm/arm.c:22685 config/arm/arm.c:22692 config/bfin/bfin.c:1441
 #: config/bfin/bfin.c:1448 config/bfin/bfin.c:1455 config/bfin/bfin.c:1462
 #: config/bfin/bfin.c:1471 config/bfin/bfin.c:1478 config/bfin/bfin.c:1485
-#: config/bfin/bfin.c:1492 config/nds32/nds32.c:3098
+#: config/bfin/bfin.c:1492 config/nds32/nds32.c:3099
 #, c-format
 msgid "invalid operand for code '%c'"
 msgstr "ugyldig operand for koden »%c«"
@@ -3630,100 +3630,100 @@
 msgid "bad output_condmove_single operand"
 msgstr "ugyldig output_condmove_single-operand"
 
-#: config/i386/i386.c:17387
+#: config/i386/i386.c:17390
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "ugyldig UNSPEC som operand"
 
-#: config/i386/i386.c:17925
+#: config/i386/i386.c:17928
 #, fuzzy, c-format
 #| msgid "invalid use of `restrict'"
 msgid "invalid use of register '%s'"
 msgstr "ugyldig brug af 'restrict'"
 
-#: config/i386/i386.c:17930
+#: config/i386/i386.c:17933
 #, c-format
 msgid "invalid use of asm flag output"
 msgstr "ugyldig brug af asm-flaguddata"
 
-#: config/i386/i386.c:18160
+#: config/i386/i386.c:18163
 #, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr "ugyldig operandstørrelse for operandkoden »O«"
 
-#: config/i386/i386.c:18195
+#: config/i386/i386.c:18198
 #, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr "ugyldig operandstørrelse for operandkoden »z«"
 
-#: config/i386/i386.c:18264
+#: config/i386/i386.c:18267
 #, c-format
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "ugyldig operandtype brugt med operandkoden »Z«"
 
-#: config/i386/i386.c:18269
+#: config/i386/i386.c:18272
 #, c-format
 msgid "invalid operand size for operand code 'Z'"
 msgstr "ugyldig operandstørrelse for operandkoden »Z«"
 
-#: config/i386/i386.c:18346
+#: config/i386/i386.c:18349
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "operand er ikke en betingelseskode, ugyldig operandkode »Y«"
 
-#: config/i386/i386.c:18425
+#: config/i386/i386.c:18428
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "operand er ikke en betingelseskode, ugyldig operandkode »D«"
 
-#: config/i386/i386.c:18443
+#: config/i386/i386.c:18446
 #, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "operand er ikke en betingelseskode, ugyldig operandkode »%c«"
 
-#: config/i386/i386.c:18456
+#: config/i386/i386.c:18459
 #, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "operand er ikke en offsettable-hukommelsesreference, ugyldig operandkode »H«"
 
-#: config/i386/i386.c:18471
+#: config/i386/i386.c:18474
 #, c-format
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr "operand er ikke et heltal, ugyldig operandkode »K«"
 
-#: config/i386/i386.c:18499
+#: config/i386/i386.c:18502
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr "operand er ikke et specifikt heltal, ugyldig operandkode »r«"
 
-#: config/i386/i386.c:18517
+#: config/i386/i386.c:18520
 #, c-format
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr "operand er ikke et heltal, ugyldig operandkode »R«"
 
-#: config/i386/i386.c:18540
+#: config/i386/i386.c:18543
 #, fuzzy, c-format
 #| msgid "operand is not a specific integer, invalid operand code 'r'"
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "operand er ikke et specifikt heltal, ugyldig operandkode »r«"
 
-#: config/i386/i386.c:18626
+#: config/i386/i386.c:18629
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "ugyldig operandkode »%c«"
 
-#: config/i386/i386.c:18688
+#: config/i386/i386.c:18691
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "ugyldige begrænsninger for operand"
 
-#: config/i386/i386.c:18738
+#: config/i386/i386.c:18741
 #, fuzzy, c-format
 #| msgid "invalid constant"
 msgid "invalid vector immediate"
 msgstr "ugyldig konstant:"
 
-#: config/i386/i386.c:29572
+#: config/i386/i386.c:29575
 msgid "unknown insn mode"
 msgstr "ukendt instruktionstilstand"
 
@@ -3761,7 +3761,7 @@
 msgstr "ugyldig %%P-operand"
 
 #: config/iq2000/iq2000.c:3185 config/powerpcspe/powerpcspe.c:23951
-#: config/rs6000/rs6000.c:21444
+#: config/rs6000/rs6000.c:21521
 #, c-format
 msgid "invalid %%p value"
 msgstr "ugyldig %%p-værdi"
@@ -3815,7 +3815,7 @@
 msgstr "postfiks forøgelsesadresse er ikke et register"
 
 #: config/m32r/m32r.c:2350 config/m32r/m32r.c:2365
-#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33292
+#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33348
 msgid "bad address"
 msgstr "ugyldig adresse"
 
@@ -3935,189 +3935,189 @@
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4411 config/rs6000/rs6000.c:4258
+#: config/powerpcspe/powerpcspe.c:4411 config/rs6000/rs6000.c:4278
 msgid "-maltivec=le not allowed for big-endian targets"
 msgstr "-maltivec=le er ikke tilladt for storendede mål"
 
-#: config/powerpcspe/powerpcspe.c:4423 config/rs6000/rs6000.c:4273
+#: config/powerpcspe/powerpcspe.c:4423 config/rs6000/rs6000.c:4293
 msgid "-mvsx requires hardware floating point"
 msgstr "-mvsx kræver udstyrskommatal"
 
-#: config/powerpcspe/powerpcspe.c:4431 config/rs6000/rs6000.c:4281
+#: config/powerpcspe/powerpcspe.c:4431 config/rs6000/rs6000.c:4301
 msgid "-mvsx and -mpaired are incompatible"
 msgstr "-mvsx og -mpaired er indbyrdes uforenelige"
 
-#: config/powerpcspe/powerpcspe.c:4433 config/rs6000/rs6000.c:4283
+#: config/powerpcspe/powerpcspe.c:4433 config/rs6000/rs6000.c:4303
 msgid "-mvsx needs indexed addressing"
 msgstr "-mvsx kræver indekseret adressering"
 
-#: config/powerpcspe/powerpcspe.c:4438 config/rs6000/rs6000.c:4288
+#: config/powerpcspe/powerpcspe.c:4438 config/rs6000/rs6000.c:4308
 msgid "-mvsx and -mno-altivec are incompatible"
 msgstr "-mvsx og -mno-altivec er indbyrdes uforenelige"
 
-#: config/powerpcspe/powerpcspe.c:4440 config/rs6000/rs6000.c:4290
+#: config/powerpcspe/powerpcspe.c:4440 config/rs6000/rs6000.c:4310
 msgid "-mno-altivec disables vsx"
 msgstr "-mno-altivec deaktiverer vsx"
 
-#: config/powerpcspe/powerpcspe.c:4648 config/rs6000/rs6000.c:4416
+#: config/powerpcspe/powerpcspe.c:4648 config/rs6000/rs6000.c:4436
 msgid "-mquad-memory requires 64-bit mode"
 msgstr "-mquad-memory kræver 64-bit tilstand"
 
-#: config/powerpcspe/powerpcspe.c:4651 config/rs6000/rs6000.c:4419
+#: config/powerpcspe/powerpcspe.c:4651 config/rs6000/rs6000.c:4439
 msgid "-mquad-memory-atomic requires 64-bit mode"
 msgstr "-mquad-memory-atomic kræver 64-bit tilstand"
 
-#: config/powerpcspe/powerpcspe.c:4663 config/rs6000/rs6000.c:4431
+#: config/powerpcspe/powerpcspe.c:4663 config/rs6000/rs6000.c:4451
 msgid "-mquad-memory is not available in little endian mode"
 msgstr "-mquad-memory er ikke tilgængelig i lilleendet tilstand"
 
-#: config/powerpcspe/powerpcspe.c:4735 config/rs6000/rs6000.c:4512
+#: config/powerpcspe/powerpcspe.c:4735 config/rs6000/rs6000.c:4532
 #, fuzzy
 #| msgid "-mquad-memory requires 64-bit mode"
 msgid "-mtoc-fusion requires 64-bit"
 msgstr "-mquad-memory kræver 64-bit tilstand"
 
-#: config/powerpcspe/powerpcspe.c:4742 config/rs6000/rs6000.c:4519
+#: config/powerpcspe/powerpcspe.c:4742 config/rs6000/rs6000.c:4539
 msgid "-mtoc-fusion requires medium/large code model"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10915
+#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10947
 #, fuzzy
 #| msgid "bad operand"
 msgid "bad move"
 msgstr "ugyldig operand"
 
-#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21087
+#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21164
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21278
+#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21355
 #, c-format
 msgid "invalid %%e value"
 msgstr "ugyldig %%e-værdi"
 
-#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21299
+#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21376
 #, c-format
 msgid "invalid %%f value"
 msgstr "ugyldig %%f-værdi"
 
-#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21308
+#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21385
 #, c-format
 msgid "invalid %%F value"
 msgstr "ugyldig %%F-værdi"
 
-#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21317
+#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21394
 #, c-format
 msgid "invalid %%G value"
 msgstr "ugyldig %%G-værdi"
 
-#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21352
+#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21429
 #, c-format
 msgid "invalid %%j code"
 msgstr "ugyldig %%j-kode"
 
-#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21362
+#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21439
 #, c-format
 msgid "invalid %%J code"
 msgstr "ugyldig %%J-kode"
 
-#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21372
+#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21449
 #, c-format
 msgid "invalid %%k value"
 msgstr "ugyldig %%k-værdi"
 
-#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21387
+#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21464
 #: config/xtensa/xtensa.c:2415
 #, c-format
 msgid "invalid %%K value"
 msgstr "ugyldig %%K-værdi"
 
-#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21434
+#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21511
 #, c-format
 msgid "invalid %%O value"
 msgstr "ugyldig %%O-værdi"
 
-#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21481
+#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21558
 #, c-format
 msgid "invalid %%q value"
 msgstr "ugyldig %%q-værdi"
 
-#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21534
+#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21611
 #, c-format
 msgid "invalid %%T value"
 msgstr "ugyldig %%T-værdi"
 
-#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21546
+#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21623
 #, c-format
 msgid "invalid %%u value"
 msgstr "ugyldig %%u-værdi"
 
-#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21560
+#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21637
 #: config/xtensa/xtensa.c:2384
 #, c-format
 msgid "invalid %%v value"
 msgstr "ugyldig %%v-værdi"
 
-#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21627
+#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21704
 #: config/xtensa/xtensa.c:2436
 #, c-format
 msgid "invalid %%x value"
 msgstr "ugyldig %%x-værdi"
 
-#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21747
+#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21824
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "ugyldig %%y-værdi, prøv at brug »Z«-begrænsningen"
 
-#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22282
+#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22359
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr "__float128 og __ibm128 kan ikke bruges i det samme udtryk"
 
-#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22288
+#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22365
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr "__ibm128 og lang dobbelt kan ikke bruges i det samme udtryk"
 
-#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22294
+#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22371
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr "__float128 og lang dobbelt kan ikke bruges i det samme udtryk"
 
-#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36572
+#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36628
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "AltiVec-parameter sendt til funktion uden prototype"
 
-#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38739
+#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38795
 msgid "Could not generate addis value for fusion"
 msgstr "Kunne ikke generere addis-værdi for fusion"
 
-#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38809
+#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38865
 msgid "Unable to generate load/store offset for fusion"
 msgstr "Kunne ikke generere indlæsning/lagring af forskydning for fusion"
 
-#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38908
+#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38964
 msgid "Bad GPR fusion"
 msgstr "Ugyldig GPR-fusion"
 
-#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39126
+#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39182
 msgid "emit_fusion_p9_load, bad reg #1"
 msgstr "emit_fusion_p9_load, ugyldig reg #1"
 
-#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39172
+#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39228
 msgid "emit_fusion_p9_load, bad reg #2"
 msgstr "emit_fusion_p9_load, ugyldig reg #2"
 
-#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39175
+#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39231
 msgid "emit_fusion_p9_load not MEM"
 msgstr "emit_fusion_p9_load ikke MEM"
 
-#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39213
+#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39269
 msgid "emit_fusion_p9_store, bad reg #1"
 msgstr "emit_fusion_p9_store, ugyldig reg #1"
 
-#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39259
+#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39315
 msgid "emit_fusion_p9_store, bad reg #2"
 msgstr "emit_fusion_p9_store, ugyldig reg #2"
 
-#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39262
+#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39318
 msgid "emit_fusion_p9_store not MEM"
 msgstr "emit_fusion_p9_store ikke MEM"
 
@@ -4494,14 +4494,14 @@
 #: c/gimple-parser.c:188 c/gimple-parser.c:197 c/gimple-parser.c:226
 #: c/gimple-parser.c:1375 c/gimple-parser.c:1404 c/gimple-parser.c:1484
 #: c/gimple-parser.c:1511 c/c-parser.c:3204 c/c-parser.c:9967
-#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27841
-#: cp/parser.c:28430
+#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27838
+#: cp/parser.c:28427
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "%<;%> forventet"
 
 #: c/c-parser.c:2431 c/c-parser.c:7573 c/c-parser.c:8015 c/c-parser.c:8058
-#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27839 cp/parser.c:28448
+#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27836 cp/parser.c:28445
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "%<,%> forventet"
@@ -4516,7 +4516,7 @@
 #: c/gimple-parser.c:821 c/gimple-parser.c:837 c/gimple-parser.c:853
 #: c/gimple-parser.c:880 c/gimple-parser.c:915 c/gimple-parser.c:1038
 #: c/gimple-parser.c:1209 c/gimple-parser.c:1220 c/gimple-parser.c:1342
-#: c/gimple-parser.c:1441 cp/parser.c:28478
+#: c/gimple-parser.c:1441 cp/parser.c:28475
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "%<)%> forventet"
@@ -4524,7 +4524,7 @@
 #: c/c-parser.c:3824 c/c-parser.c:4733 c/c-parser.c:4769 c/c-parser.c:6441
 #: c/c-parser.c:8125 c/c-parser.c:8983 c/c-parser.c:9127 c/c-parser.c:11588
 #: c/c-parser.c:18220 c/c-parser.c:18222 c/gimple-parser.c:1015
-#: cp/parser.c:28442
+#: cp/parser.c:28439
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "%<]%> forventet"
@@ -4538,7 +4538,7 @@
 #: c/c-parser.c:17792 c/gimple-parser.c:363 c/gimple-parser.c:811
 #: c/gimple-parser.c:873 c/gimple-parser.c:911 c/gimple-parser.c:1198
 #: c/gimple-parser.c:1339 c/gimple-parser.c:1438 c/c-parser.c:11911
-#: cp/parser.c:28433
+#: cp/parser.c:28430
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "%<(%> forventet"
@@ -4545,7 +4545,7 @@
 
 #: c/c-parser.c:4903 c/c-parser.c:10310 c/c-parser.c:16212 c/c-parser.c:18449
 #: c/gimple-parser.c:141 c/gimple-parser.c:1444 c/c-parser.c:3018
-#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18155 cp/parser.c:28439
+#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18152 cp/parser.c:28436
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "%<{%> forventet"
@@ -4555,13 +4555,13 @@
 #: c/c-parser.c:12351 c/c-parser.c:12493 c/c-parser.c:12864 c/c-parser.c:12957
 #: c/c-parser.c:13566 c/c-parser.c:17636 c/c-parser.c:17695
 #: c/gimple-parser.c:431 c/gimple-parser.c:1492 c/gimple-parser.c:1519
-#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28472 cp/parser.c:29597
-#: cp/parser.c:32279
+#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28469 cp/parser.c:29594
+#: cp/parser.c:32276
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "%<:%> forventet"
 
-#: c/c-parser.c:5974 cp/parser.c:28365
+#: c/c-parser.c:5974 cp/parser.c:28362
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "%<while%> forventet"
@@ -4570,18 +4570,18 @@
 msgid "expected %<.%>"
 msgstr "%<.%> forventet"
 
-#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30172
-#: cp/parser.c:30246
+#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30169
+#: cp/parser.c:30243
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "%<@end%> forventet"
 
-#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28457
+#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28454
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "%<>%> forventet"
 
-#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28481
+#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28478
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "%<,%> eller %<)%> forventet"
@@ -4589,32 +4589,32 @@
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15190 c/c-parser.c:15234 c/c-parser.c:15466 c/c-parser.c:15701
 #: c/c-parser.c:17833 c/gimple-parser.c:286 c/c-parser.c:4792
-#: cp/parser.c:28460
+#: cp/parser.c:28457
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "%<=%> forventet"
 
-#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28436
-#: cp/parser.c:30389
+#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28433
+#: cp/parser.c:30386
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "%<}%> forventet"
 
-#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35674
+#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35671
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "%<#pragma omp section%> eller %<}%> forventet"
 
-#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28445 cp/parser.c:31535
+#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28442 cp/parser.c:31532
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "%<[%> forventet"
 
-#: c/c-typeck.c:7847
+#: c/c-typeck.c:7852
 msgid "(anonymous)"
 msgstr "(anonym)"
 
-#: c/gimple-parser.c:795 cp/parser.c:15791 cp/parser.c:28454
+#: c/gimple-parser.c:795 cp/parser.c:15788 cp/parser.c:28451
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "%<<%> forventet"
@@ -4896,12 +4896,12 @@
 msgid "%r%s:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr ""
 
-#: cp/pt.c:1949 cp/semantics.c:5268
+#: cp/pt.c:1949 cp/semantics.c:5271
 #, fuzzy
 msgid "candidates are:"
 msgstr "candidate%s: %+#D"
 
-#: cp/pt.c:1951 cp/pt.c:22975
+#: cp/pt.c:1951 cp/pt.c:23053
 #, fuzzy
 msgid "candidate is:"
 msgid_plural "candidates are:"
@@ -4964,27 +4964,27 @@
 msgid "source type is not polymorphic"
 msgstr ""
 
-#: cp/typeck.c:6083 c/c-typeck.c:4261
+#: cp/typeck.c:6083 c/c-typeck.c:4266
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "forkert parametertype til unært minus"
 
-#: cp/typeck.c:6084 c/c-typeck.c:4248
+#: cp/typeck.c:6084 c/c-typeck.c:4253
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "forkert parametertype til unært plus"
 
-#: cp/typeck.c:6111 c/c-typeck.c:4302
+#: cp/typeck.c:6111 c/c-typeck.c:4307
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "forkert parametertype til bitkomplement"
 
-#: cp/typeck.c:6128 c/c-typeck.c:4310
+#: cp/typeck.c:6128 c/c-typeck.c:4315
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "forkert parametertype til abs"
 
-#: cp/typeck.c:6140 c/c-typeck.c:4322
+#: cp/typeck.c:6140 c/c-typeck.c:4327
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "forkert parametertype til konjugation"
@@ -5261,87 +5261,87 @@
 msgid "Expected attribute bit name"
 msgstr "packed-egenskab er unødvendig"
 
-#: fortran/module.c:3223
+#: fortran/module.c:3225
 #, fuzzy
 #| msgid "section pointer missing"
 msgid "Expected integer string"
 msgstr "sektionshenvisning mangler"
 
-#: fortran/module.c:3227
+#: fortran/module.c:3229
 msgid "Error converting integer"
 msgstr ""
 
-#: fortran/module.c:3249
+#: fortran/module.c:3251
 #, fuzzy
 #| msgid "unterminated format string"
 msgid "Expected real string"
 msgstr "uafsluttet formateringsstreng"
 
-#: fortran/module.c:3474
+#: fortran/module.c:3476
 #, fuzzy
 #| msgid "unexpected address expression"
 msgid "Expected expression type"
 msgstr "uventet adresseudtryk"
 
-#: fortran/module.c:3554
+#: fortran/module.c:3556
 #, fuzzy
 #| msgid "bad operand"
 msgid "Bad operator"
 msgstr "ugyldig operand"
 
-#: fortran/module.c:3671
+#: fortran/module.c:3673
 #, fuzzy
 #| msgid "overflow in constant expression"
 msgid "Bad type in constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: fortran/module.c:7038
+#: fortran/module.c:7040
 #, fuzzy
 #| msgid "unexpected PIC symbol"
 msgid "Unexpected end of module"
 msgstr "uventet PIC-symbol"
 
-#: fortran/parse.c:1757
+#: fortran/parse.c:1761
 msgid "arithmetic IF"
 msgstr ""
 
-#: fortran/parse.c:1766
+#: fortran/parse.c:1770
 #, fuzzy
 #| msgid "Invalid declaration"
 msgid "attribute declaration"
 msgstr "Ugyldig erklæring"
 
-#: fortran/parse.c:1802
+#: fortran/parse.c:1806
 #, fuzzy
 #| msgid "empty declaration"
 msgid "data declaration"
 msgstr "tom erklæring"
 
-#: fortran/parse.c:1820
+#: fortran/parse.c:1824
 #, fuzzy
 #| msgid "empty declaration"
 msgid "derived type declaration"
 msgstr "tom erklæring"
 
-#: fortran/parse.c:1947
+#: fortran/parse.c:1951
 msgid "block IF"
 msgstr ""
 
-#: fortran/parse.c:1956
+#: fortran/parse.c:1960
 msgid "implied END DO"
 msgstr ""
 
-#: fortran/parse.c:2050 fortran/resolve.c:11199
+#: fortran/parse.c:2054 fortran/resolve.c:11219
 msgid "assignment"
 msgstr "tildeling"
 
-#: fortran/parse.c:2053 fortran/resolve.c:11250 fortran/resolve.c:11253
+#: fortran/parse.c:2057 fortran/resolve.c:11270 fortran/resolve.c:11273
 #, fuzzy
 #| msgid "assignment"
 msgid "pointer assignment"
 msgstr "tildeling"
 
-#: fortran/parse.c:2071
+#: fortran/parse.c:2075
 msgid "simple IF"
 msgstr ""
 
@@ -5461,112 +5461,117 @@
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:3878
+#: fortran/resolve.c:3879
 #, c-format
+msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
+msgstr ""
+
+#: fortran/resolve.c:3884
+#, c-format
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3893
+#: fortran/resolve.c:3899
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3926
+#: fortran/resolve.c:3932
 #, c-format
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3949
+#: fortran/resolve.c:3955
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:3963
+#: fortran/resolve.c:3969
 #, fuzzy
 #| msgid "`%V' qualifiers cannot be applied to `%T'"
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "modifikationerne '%V' kan ikke anvendes på '%T'"
 
-#: fortran/resolve.c:4015
+#: fortran/resolve.c:4021
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr ""
 
-#: fortran/resolve.c:4021
+#: fortran/resolve.c:4027
 #, c-format
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4034
+#: fortran/resolve.c:4040
 #, fuzzy, c-format
 #| msgid "unknown register name: %s"
 msgid "Unknown operator %%<%s%%> at %%L; did you mean '%s'?"
 msgstr "ukendt registernavn: %s"
 
-#: fortran/resolve.c:4037
+#: fortran/resolve.c:4043
 #, fuzzy, c-format
 #| msgid "unknown register name: %s"
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr "ukendt registernavn: %s"
 
-#: fortran/resolve.c:4040
+#: fortran/resolve.c:4046
 #, c-format
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:4044
+#: fortran/resolve.c:4050
 #, c-format
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4132
+#: fortran/resolve.c:4138
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr ""
 
-#: fortran/resolve.c:6849
+#: fortran/resolve.c:6855
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.c:6853
+#: fortran/resolve.c:6859
 msgid "iterator variable"
 msgstr ""
 
-#: fortran/resolve.c:6857
+#: fortran/resolve.c:6863
 msgid "Start expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:6861
+#: fortran/resolve.c:6867
 #, fuzzy
 #| msgid "invalid expression as operand"
 msgid "End expression in DO loop"
 msgstr "ugyldigt udtryk som operand"
 
-#: fortran/resolve.c:6865
+#: fortran/resolve.c:6871
 msgid "Step expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:7150 fortran/resolve.c:7153
+#: fortran/resolve.c:7156 fortran/resolve.c:7159
 msgid "DEALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.c:7525 fortran/resolve.c:7528
+#: fortran/resolve.c:7531 fortran/resolve.c:7534
 msgid "ALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.c:7720 fortran/resolve.c:9417
+#: fortran/resolve.c:7726 fortran/resolve.c:9428
 msgid "STAT variable"
 msgstr ""
 
-#: fortran/resolve.c:7764 fortran/resolve.c:9429
+#: fortran/resolve.c:7770 fortran/resolve.c:9440
 msgid "ERRMSG variable"
 msgstr ""
 
-#: fortran/resolve.c:9219
+#: fortran/resolve.c:9230
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.c:9441
+#: fortran/resolve.c:9452
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
@@ -5599,7 +5604,7 @@
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:10154
+#: fortran/trans-expr.c:10157
 msgid "Assignment of scalar to unallocated array"
 msgstr ""
 
@@ -5608,12 +5613,12 @@
 msgid "Unequal character lengths (%ld/%ld) in %s"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:8088
+#: fortran/trans-intrinsic.c:8090
 #, c-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative (its value is %ld)"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:8120
+#: fortran/trans-intrinsic.c:8122
 msgid "Argument NCOPIES of REPEAT intrinsic is too large"
 msgstr ""
 
@@ -5638,17 +5643,17 @@
 msgid "Invalid image number %d in SYNC IMAGES"
 msgstr ""
 
-#: fortran/trans-stmt.c:2180
+#: fortran/trans-stmt.c:2177
 msgid "Loop iterates infinitely"
 msgstr ""
 
-#: fortran/trans-stmt.c:2200 fortran/trans-stmt.c:2456
+#: fortran/trans-stmt.c:2197 fortran/trans-stmt.c:2453
 #, fuzzy
 #| msgid "output pipe has been closed"
 msgid "Loop variable has been modified"
 msgstr "uddataledningen er blevet lukket"
 
-#: fortran/trans-stmt.c:2309
+#: fortran/trans-stmt.c:2306
 msgid "DO step value is zero"
 msgstr ""
 
@@ -6309,10 +6314,10 @@
 msgid "Allow dollar signs in entity names."
 msgstr ""
 
-#: fortran/lang.opt:485 config/alpha/alpha.opt:31 common.opt:783
-#: common.opt:985 common.opt:989 common.opt:993 common.opt:997 common.opt:1532
-#: common.opt:1588 common.opt:1712 common.opt:1716 common.opt:1946
-#: common.opt:2116 common.opt:2792
+#: fortran/lang.opt:485 config/alpha/alpha.opt:31 common.opt:649
+#: common.opt:783 common.opt:989 common.opt:993 common.opt:997 common.opt:1001
+#: common.opt:1536 common.opt:1592 common.opt:1716 common.opt:1720
+#: common.opt:1950 common.opt:2120 common.opt:2796
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr ""
 
@@ -6554,12 +6559,12 @@
 msgstr "Tilføj aldrig en anden understreg til eksterne variable"
 
 #: fortran/lang.opt:751 c-family/c.opt:1356 c-family/c.opt:1384
-#: c-family/c.opt:1634 config/pa/pa.opt:42 config/pa/pa.opt:70 common.opt:1154
-#: common.opt:1333 common.opt:1408 common.opt:1676 common.opt:1799
-#: common.opt:2169 common.opt:2205 common.opt:2298 common.opt:2302
-#: common.opt:2407 common.opt:2498 common.opt:2506 common.opt:2514
-#: common.opt:2522 common.opt:2623 common.opt:2675 common.opt:2755
-#: common.opt:2893 common.opt:2897 common.opt:2901 common.opt:2905
+#: c-family/c.opt:1634 config/pa/pa.opt:42 config/pa/pa.opt:70 common.opt:1158
+#: common.opt:1337 common.opt:1412 common.opt:1680 common.opt:1803
+#: common.opt:2173 common.opt:2209 common.opt:2302 common.opt:2306
+#: common.opt:2411 common.opt:2502 common.opt:2510 common.opt:2518
+#: common.opt:2526 common.opt:2627 common.opt:2679 common.opt:2759
+#: common.opt:2897 common.opt:2901 common.opt:2905 common.opt:2909
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr ""
 
@@ -6609,7 +6614,7 @@
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:220 c-family/c.opt:224
 #: c-family/c.opt:236 c-family/c.opt:1855 c-family/c.opt:1863 brig/lang.opt:39
-#: config/darwin.opt:56 common.opt:338 common.opt:341 common.opt:3046
+#: config/darwin.opt:56 common.opt:338 common.opt:341 common.opt:3050
 #, fuzzy, c-format
 msgid "missing filename after %qs"
 msgstr "et filnavn mangler efter '-%s'"
@@ -7318,7 +7323,7 @@
 #: c-family/c.opt:1525 c-family/c.opt:1528 c-family/c.opt:1569
 #: c-family/c.opt:1704 c-family/c.opt:1731 c-family/c.opt:1771
 #: c-family/c.opt:1802 c-family/c.opt:1806 c-family/c.opt:1822
-#: config/ia64/ia64.opt:167 config/ia64/ia64.opt:170 c-family/c-opts.c:434
+#: config/ia64/ia64.opt:167 config/ia64/ia64.opt:170 c-family/c-opts.c:432
 #, fuzzy, gcc-internal-format
 #| msgid "switch \"%s\" is no longer supported"
 msgid "switch %qs is no longer supported"
@@ -16410,10 +16415,6 @@
 msgid "Warn if dereferencing a NULL pointer may lead to erroneous or undefined behavior."
 msgstr ""
 
-#: common.opt:649
-msgid "Warn if the loop cannot be optimized due to nontrivial assumptions."
-msgstr ""
-
 #: common.opt:656
 msgid "Warn about some C++ One Definition Rule violations during link time optimization."
 msgstr ""
@@ -16639,91 +16640,91 @@
 msgid "-dumpdir <dir>\tSet the directory name to be used for dumps."
 msgstr "  -dumpbase <fil>         Basisnavn til brug for dump fra specifikke faser\n"
 
-#: common.opt:946
+#: common.opt:950
 msgid "The version of the C++ ABI in use."
 msgstr ""
 
-#: common.opt:950
+#: common.opt:954
 msgid "Aggressively optimize loops using language constraints."
 msgstr ""
 
-#: common.opt:954
+#: common.opt:958
 #, fuzzy
 #| msgid "Align the start of functions"
 msgid "Align the start of functions."
 msgstr "Justér begyndelsen af funktioner"
 
-#: common.opt:964
+#: common.opt:968
 #, fuzzy
 #| msgid "Align labels which are only reached by jumping"
 msgid "Align labels which are only reached by jumping."
 msgstr "Justér etiketter som kun nås ved spring"
 
-#: common.opt:971
+#: common.opt:975
 #, fuzzy
 #| msgid "Align all labels"
 msgid "Align all labels."
 msgstr "Justér alle etiketter"
 
-#: common.opt:978
+#: common.opt:982
 #, fuzzy
 #| msgid "Align the start of loops"
 msgid "Align the start of loops."
 msgstr "Justér begyndelsen af løkker"
 
-#: common.opt:1001
+#: common.opt:1005
 msgid "Select what to sanitize."
 msgstr ""
 
-#: common.opt:1005
+#: common.opt:1009
 msgid "Select type of coverage sanitization."
 msgstr ""
 
-#: common.opt:1009
+#: common.opt:1013
 msgid "-fasan-shadow-offset=<number>\tUse custom shadow memory offset."
 msgstr ""
 
-#: common.opt:1013
+#: common.opt:1017
 msgid "-fsanitize-sections=<sec1,sec2,...>\tSanitize global variables in user-defined sections."
 msgstr ""
 
-#: common.opt:1018
+#: common.opt:1022
 msgid "After diagnosing undefined behavior attempt to continue execution."
 msgstr ""
 
-#: common.opt:1022
+#: common.opt:1026
 #, fuzzy
 msgid "This switch is deprecated; use -fsanitize-recover= instead."
 msgstr "Angiv klassesti (forældet: benyt --classpath i stedet)"
 
-#: common.opt:1029
+#: common.opt:1033
 msgid "Use trap instead of a library function for undefined behavior sanitization."
 msgstr ""
 
-#: common.opt:1033
+#: common.opt:1037
 #, fuzzy
 msgid "Generate unwind tables that are exact at each instruction boundary."
 msgstr "Generér afvindingstabeller eksakt for hver instruktionsgrænse"
 
-#: common.opt:1037
+#: common.opt:1041
 #, fuzzy
 #| msgid "Generate char instructions"
 msgid "Generate auto-inc/dec instructions."
 msgstr "Generér char-instruktioner"
 
-#: common.opt:1041
+#: common.opt:1045
 #, fuzzy
 #| msgid "Use profiling information for branch probabilities"
 msgid "Use sample profile information for call graph node weights. The default profile file is fbdata.afdo in 'pwd'."
 msgstr "Benyt profileringsoplysninger til forgreningssandsynligheder"
 
-#: common.opt:1046
+#: common.opt:1050
 #, fuzzy
 #| msgid "Use profiling information for branch probabilities"
 msgid "Use sample profile information for call graph node weights. The profile file is specified in the argument."
 msgstr "Benyt profileringsoplysninger til forgreningssandsynligheder"
 
-#: common.opt:1055
+#: common.opt:1059
 #, fuzzy
 #| msgid "Generate code to check bounds before indexing arrays"
 msgid "Generate code to check bounds before indexing arrays."
@@ -16730,105 +16731,105 @@
 msgstr "Generér kode til at kontrollere grænserne før tabeller indekseres"
 
 # RETMIG: rigtig?
-#: common.opt:1059
+#: common.opt:1063
 #, fuzzy
 #| msgid "Replace add, compare, branch with branch on count register"
 msgid "Replace add, compare, branch with branch on count register."
 msgstr "Erstat tilføj, sammenlign, forgrening med forgrening på tælleregister"
 
-#: common.opt:1063
+#: common.opt:1067
 #, fuzzy
 #| msgid "Use profiling information for branch probabilities"
 msgid "Use profiling information for branch probabilities."
 msgstr "Benyt profileringsoplysninger til forgreningssandsynligheder"
 
-#: common.opt:1067
+#: common.opt:1071
 msgid "Perform branch target load optimization before prologue / epilogue threading."
 msgstr ""
 
-#: common.opt:1071
+#: common.opt:1075
 msgid "Perform branch target load optimization after prologue / epilogue threading."
 msgstr ""
 
-#: common.opt:1075
+#: common.opt:1079
 msgid "Restrict target load migration not to re-use registers in any basic block."
 msgstr ""
 
-#: common.opt:1079
+#: common.opt:1083
 #, fuzzy
 #| msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions"
 msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions."
 msgstr "-fcall-saved-<register>\tMarker <register> som værende bevaret over funktioner"
 
-#: common.opt:1083
+#: common.opt:1087
 #, fuzzy
 #| msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls"
 msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls."
 msgstr "-fcall-used-<register>\tMarker <register> som værende benyttet af funktionskald"
 
-#: common.opt:1090
+#: common.opt:1094
 #, fuzzy
 #| msgid "Save registers around function calls"
 msgid "Save registers around function calls."
 msgstr "Gem registre omkring funktionskald"
 
-#: common.opt:1094
+#: common.opt:1098
 #, fuzzy
 msgid "This switch is deprecated; do not use."
 msgstr "Angiv klassesti (forældet: benyt --classpath i stedet)"
 
-#: common.opt:1098
+#: common.opt:1102
 #, fuzzy
 #| msgid "Check the return value of new in C++"
 msgid "Check the return value of new in C++."
 msgstr "Kontroller returværdien for new i C++"
 
-#: common.opt:1102 common.opt:1106
+#: common.opt:1106 common.opt:1110
 #, fuzzy
 #| msgid "internal gcc abort"
 msgid "Perform internal consistency checkings."
 msgstr "intern GCC-afbrydelse"
 
-#: common.opt:1110
+#: common.opt:1114
 #, fuzzy
 #| msgid "Enable aggressive SSA dead code elimination"
 msgid "Enable code hoisting."
 msgstr "Aktivér aggressiv SSA-eliminering af ubrugt kode"
 
-#: common.opt:1114
+#: common.opt:1118
 msgid "Looks for opportunities to reduce stack adjustments and stack references."
 msgstr ""
 
-#: common.opt:1118
+#: common.opt:1122
 #, fuzzy
 #| msgid "Do not put uninitialized globals in the common section"
 msgid "Do not put uninitialized globals in the common section."
 msgstr "Anbring ikke uklargjorte globale variabler i den fælles sektion"
 
-#: common.opt:1126
+#: common.opt:1130
 msgid "-fcompare-debug[=<opts>]\tCompile with and without e.g. -gtoggle, and compare the final-insns dump."
 msgstr ""
 
-#: common.opt:1130
+#: common.opt:1134
 msgid "Run only the second compilation of -fcompare-debug."
 msgstr ""
 
-#: common.opt:1134
+#: common.opt:1138
 #, fuzzy
 #| msgid "Reschedule instructions after register allocation"
 msgid "Perform comparison elimination after register allocation has finished."
 msgstr "Omplanlæg instruktioner efter registerallokering"
 
-#: common.opt:1138
+#: common.opt:1142
 msgid "Do not perform optimizations increasing noticeably stack usage."
 msgstr ""
 
-#: common.opt:1142
+#: common.opt:1146
 #, fuzzy
 msgid "Perform a register copy-propagation optimization pass."
 msgstr "Foretag registerkopipropageringsoptimering"
 
-#: common.opt:1146
+#: common.opt:1150
 #, fuzzy
 #| msgid "Perform cross-jumping optimization"
 msgid "Perform cross-jumping optimization."
@@ -16835,1887 +16836,1887 @@
 msgstr "Udfør krydsspringsoptimering"
 
 # RETMIG: hvad er CSE?
-#: common.opt:1150
+#: common.opt:1154
 #, fuzzy
 #| msgid "When running CSE, follow jumps to their targets"
 msgid "When running CSE, follow jumps to their targets."
 msgstr "Ved kørsel af CSE følg spring til deres mål"
 
-#: common.opt:1158
+#: common.opt:1162
 msgid "Omit range reduction step when performing complex division."
 msgstr ""
 
-#: common.opt:1162
+#: common.opt:1166
 msgid "Complex multiplication and division follow Fortran rules."
 msgstr ""
 
-#: common.opt:1166
+#: common.opt:1170
 #, fuzzy
 msgid "Place data items into their own section."
 msgstr "placér dataelementer i deres egen sektion"
 
-#: common.opt:1170
+#: common.opt:1174
 msgid "List all available debugging counters with their limits and counts."
 msgstr ""
 
-#: common.opt:1174
+#: common.opt:1178
 msgid "-fdbg-cnt=<counter>:<limit>[,<counter>:<limit>,...]\tSet the debug counter limit."
 msgstr ""
 
-#: common.opt:1178
+#: common.opt:1182
 msgid "-fdebug-prefix-map=<old>=<new> Map one directory name to another in debug information."
 msgstr ""
 
-#: common.opt:1182
+#: common.opt:1186
 msgid "-ffile-prefix-map=<old>=<new> Map one directory name to another in compilation result."
 msgstr ""
 
-#: common.opt:1186
+#: common.opt:1190
 msgid "Output .debug_types section when using DWARF v4 debuginfo."
 msgstr ""
 
-#: common.opt:1192
+#: common.opt:1196
 #, fuzzy
 #| msgid "Defer popping functions args from stack until later"
 msgid "Defer popping functions args from stack until later."
 msgstr "Vent med fjernelse af funktionsparametre fra stakken til senere"
 
-#: common.opt:1196
+#: common.opt:1200
 #, fuzzy
 #| msgid "Attempt to fill delay slots of branch instructions"
 msgid "Attempt to fill delay slots of branch instructions."
 msgstr "Forsøg at udfylde ventepladser med forgreningsinstruktioner"
 
-#: common.opt:1200
+#: common.opt:1204
 msgid "Delete dead instructions that may throw exceptions."
 msgstr ""
 
-#: common.opt:1204
+#: common.opt:1208
 #, fuzzy
 #| msgid "Delete useless null pointer checks"
 msgid "Delete useless null pointer checks."
 msgstr "Fjern ubrugelige nul-henvisningstjek"
 
-#: common.opt:1208
+#: common.opt:1212
 msgid "Stream extra data to support more aggressive devirtualization in LTO local transformation mode."
 msgstr ""
 
-#: common.opt:1212
+#: common.opt:1216
 #, fuzzy
 #| msgid "Perform superblock formation via tail duplication"
 msgid "Perform speculative devirtualization."
 msgstr "Udfør superbloksformering vha. haleduplikering"
 
-#: common.opt:1216
+#: common.opt:1220
 msgid "Try to convert virtual calls to direct ones."
 msgstr ""
 
-#: common.opt:1220
+#: common.opt:1224
 #, fuzzy
 msgid "-fdiagnostics-show-location=[once|every-line]\tHow often to emit source location at the beginning of line-wrapped diagnostics."
 msgstr "  -fdiagnostics-show-location=[once | every-line] Indikerer hvor ofte kildeplaceringsoplysninger skal udsendes som præfiks til begyndelsen af meddelelserne ved linjeombrydning\n"
 
-#: common.opt:1237
+#: common.opt:1241
 msgid "Show the source line with a caret indicating the column."
 msgstr ""
 
-#: common.opt:1245
+#: common.opt:1249
 msgid "-fdiagnostics-color=[never|always|auto]\tColorize diagnostics."
 msgstr ""
 
-#: common.opt:1265
+#: common.opt:1269
 msgid "Print fix-it hints in machine-readable form."
 msgstr ""
 
-#: common.opt:1269
+#: common.opt:1273
 msgid "Print fix-it hints to stderr in unified diff format."
 msgstr ""
 
-#: common.opt:1273
+#: common.opt:1277
 msgid "Amend appropriate diagnostic messages with the command line option that controls them."
 msgstr ""
 
-#: common.opt:1277
+#: common.opt:1281
 msgid "-fdisable-[tree|rtl|ipa]-<pass>=range1+range2 disables an optimization pass."
 msgstr ""
 
-#: common.opt:1281
+#: common.opt:1285
 msgid "-fenable-[tree|rtl|ipa]-<pass>=range1+range2 enables an optimization pass."
 msgstr ""
 
-#: common.opt:1285
+#: common.opt:1289
 msgid "-fdump-<type>\tDump various compiler internals to a file."
 msgstr ""
 
-#: common.opt:1292
+#: common.opt:1296
 msgid "-fdump-final-insns=filename\tDump to filename the insns at the end of translation."
 msgstr ""
 
-#: common.opt:1296
+#: common.opt:1300
 msgid "-fdump-go-spec=filename\tWrite all declarations to file as Go code."
 msgstr ""
 
-#: common.opt:1300
+#: common.opt:1304
 #, fuzzy
 #| msgid "Suppress output of instruction numbers and line number notes in debugging dumps"
 msgid "Suppress output of addresses in debugging dumps."
 msgstr "Undtryk udskrift af instruktionstal og linjenummernoter i fejlfindingsdump"
 
-#: common.opt:1304
+#: common.opt:1308
 msgid "Collect and dump debug information into temporary file if ICE in C/C++ compiler occurred."
 msgstr ""
 
-#: common.opt:1309
+#: common.opt:1313
 msgid "Dump detailed information on GCC's internal representation of source code locations."
 msgstr ""
 
-#: common.opt:1313
+#: common.opt:1317
 #, fuzzy
 msgid "Dump optimization passes."
 msgstr "Udfør løkkeoptimeringerne"
 
-#: common.opt:1317
+#: common.opt:1321
 #, fuzzy
 #| msgid "Suppress output of instruction numbers and line number notes in debugging dumps"
 msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps."
 msgstr "Undtryk udskrift af instruktionstal og linjenummernoter i fejlfindingsdump"
 
-#: common.opt:1321
+#: common.opt:1325
 #, fuzzy
 #| msgid "Suppress output of instruction numbers and line number notes in debugging dumps"
 msgid "Suppress output of previous and next insn numbers in debugging dumps."
 msgstr "Undtryk udskrift af instruktionstal og linjenummernoter i fejlfindingsdump"
 
-#: common.opt:1325
+#: common.opt:1329
 msgid "Enable CFI tables via GAS assembler directives."
 msgstr ""
 
-#: common.opt:1329
+#: common.opt:1333
 #, fuzzy
 msgid "Perform early inlining."
 msgstr "Udfør løkkeoptimeringerne"
 
-#: common.opt:1337
+#: common.opt:1341
 #, fuzzy
 #| msgid "Enable SSA conditional constant propagation"
 msgid "Perform interprocedural reduction of aggregates."
 msgstr "Aktivér betinget konstant SSA-propagering"
 
-#: common.opt:1341
+#: common.opt:1345
 msgid "Perform unused symbol elimination in debug info."
 msgstr ""
 
-#: common.opt:1345
+#: common.opt:1349
 msgid "Perform unused type elimination in debug info."
 msgstr ""
 
-#: common.opt:1349
+#: common.opt:1353
 msgid "Do not suppress C++ class debug information."
 msgstr ""
 
-#: common.opt:1353
+#: common.opt:1357
 #, fuzzy
 #| msgid "Enable exception handling"
 msgid "Enable exception handling."
 msgstr "Aktivér undtagelseshåndtering"
 
-#: common.opt:1357
+#: common.opt:1361
 #, fuzzy
 #| msgid "Perform a number of minor, expensive optimizations"
 msgid "Perform a number of minor, expensive optimizations."
 msgstr "Udfør et antal mindre, dyre optimeringer"
 
-#: common.opt:1361
+#: common.opt:1365
 msgid "-fexcess-precision=[fast|standard]\tSpecify handling of excess floating-point precision."
 msgstr ""
 
-#: common.opt:1364
+#: common.opt:1368
 #, fuzzy, c-format
 #| msgid "unknown string token %s\n"
 msgid "unknown excess precision style %qs"
 msgstr "ukendt strengsymbol %s\n"
 
-#: common.opt:1376
+#: common.opt:1380
 msgid "-fpermitted-flt-eval-methods=[c11|ts-18661]\tSpecify which values of FLT_EVAL_METHOD are permitted."
 msgstr ""
 
-#: common.opt:1379
+#: common.opt:1383
 #, c-format
 msgid "unknown specification for the set of FLT_EVAL_METHOD values to permit %qs"
 msgstr ""
 
-#: common.opt:1392
+#: common.opt:1396
 msgid "Output lto objects containing both the intermediate language and binary output."
 msgstr ""
 
-#: common.opt:1396
+#: common.opt:1400
 #, fuzzy
 msgid "Assume no NaNs or infinities are generated."
 msgstr "Antag at ingen NaN eller +-Inf bliver genereret"
 
-#: common.opt:1400
+#: common.opt:1404
 #, fuzzy
 msgid "-ffixed-<register>\tMark <register> as being unavailable to the compiler."
 msgstr "  -ffixed-<register>      Markér <register> som værende utilgængeligt for oversætteren\n"
 
-#: common.opt:1404
+#: common.opt:1408
 #, fuzzy
 #| msgid "Control allocation order of integer registers"
 msgid "Don't allocate floats and doubles in extended-precision registers."
 msgstr "Kontrollér tildelingsordenen for heltalsregistrene"
 
-#: common.opt:1412
+#: common.opt:1416
 #, fuzzy
 msgid "Perform a forward propagation pass on RTL."
 msgstr "Foretag registerkopipropageringsoptimering"
 
-#: common.opt:1416
+#: common.opt:1420
 msgid "-ffp-contract=[off|on|fast]\tPerform floating-point expression contraction."
 msgstr ""
 
-#: common.opt:1419
+#: common.opt:1423
 #, fuzzy, c-format
 #| msgid "Use hardware floating point instructions"
 msgid "unknown floating point contraction style %qs"
 msgstr "Benyt hardware-kommatalsinstruktioner"
 
-#: common.opt:1433
+#: common.opt:1437
 msgid "Allow built-in functions ceil, floor, round, trunc to raise \"inexact\" exceptions."
 msgstr ""
 
-#: common.opt:1440
+#: common.opt:1444
 #, fuzzy
 #| msgid "Allow function addresses to be held in registers"
 msgid "Allow function addresses to be held in registers."
 msgstr "Tillad funktionsadresser at blive opbevaret i registre"
 
-#: common.opt:1444
+#: common.opt:1448
 #, fuzzy
 msgid "Place each function into its own section."
 msgstr "placér hver funktion i dens egen sektion"
 
-#: common.opt:1448
+#: common.opt:1452
 #, fuzzy
 msgid "Perform global common subexpression elimination."
 msgstr "Udfør global eliminering af fælles underudtryk"
 
-#: common.opt:1452
+#: common.opt:1456
 #, fuzzy
 msgid "Perform enhanced load motion during global common subexpression elimination."
 msgstr "Udfør forbedret indlæsningsbevægelse under eliminering af fælles underudtryk"
 
-#: common.opt:1456
+#: common.opt:1460
 #, fuzzy
 msgid "Perform store motion after global common subexpression elimination."
 msgstr "Udfør lagringsbevægelse efter eliminering af fælles underudtryk"
 
-#: common.opt:1460
+#: common.opt:1464
 #, fuzzy
 msgid "Perform redundant load after store elimination in global common subexpression elimination."
 msgstr "Udfør forbedret indlæsningsbevægelse under eliminering af fælles underudtryk"
 
-#: common.opt:1465
+#: common.opt:1469
 #, fuzzy
 msgid "Perform global common subexpression elimination after register allocation has finished."
 msgstr "Udfør global eliminering af fælles underudtryk"
 
-#: common.opt:1482
+#: common.opt:1486
 msgid "-fgnat-encodings=[all|gdb|minimal]\tSelect the balance between GNAT encodings and standard DWARF emitted in the debug information"
 msgstr ""
 
-#: common.opt:1487
+#: common.opt:1491
 #, fuzzy
 #| msgid "Enable automatic template instantiation"
 msgid "Enable in and out of Graphite representation."
 msgstr "Aktivér automatisk skabelonsinstantiering"
 
-#: common.opt:1491
+#: common.opt:1495
 #, fuzzy
 #| msgid "Emit call graph information"
 msgid "Enable Graphite Identity transformation."
 msgstr "Udsend kaldegrafinfo"
 
-#: common.opt:1495
+#: common.opt:1499
 #, fuzzy
 #| msgid "Enable use of conditional move instructions"
 msgid "Enable hoisting adjacent loads to encourage generating conditional move instructions."
 msgstr "Aktivér brug af betingede flytteinstruktioner"
 
-#: common.opt:1504
+#: common.opt:1508
 msgid "Mark all loops as parallel."
 msgstr ""
 
-#: common.opt:1508 common.opt:1516 common.opt:2587
+#: common.opt:1512 common.opt:1520 common.opt:2591
 msgid "Enable loop nest transforms.  Same as -floop-nest-optimize."
 msgstr ""
 
-#: common.opt:1512
+#: common.opt:1516
 #, fuzzy
 #| msgid "Enable linker optimizations"
 msgid "Enable loop interchange on trees."
 msgstr "Aktivér sammenkæderoptimeringer"
 
-#: common.opt:1520
+#: common.opt:1524
 #, fuzzy
 #| msgid "Perform loop unrolling for all loops"
 msgid "Perform unroll-and-jam on loops."
 msgstr "Udfør løkkeudrulning for alle løkker"
 
-#: common.opt:1524
+#: common.opt:1528
 msgid "Enable support for GNU transactional memory."
 msgstr ""
 
-#: common.opt:1528
+#: common.opt:1532
 msgid "Use STB_GNU_UNIQUE if supported by the assembler."
 msgstr ""
 
-#: common.opt:1536
+#: common.opt:1540
 #, fuzzy
 #| msgid "Run the loop optimizer twice"
 msgid "Enable the loop nest optimizer."
 msgstr "Kør løkkeoptimeringen to gange"
 
-#: common.opt:1540
+#: common.opt:1544
 msgid "Force bitfield accesses to match their type width."
 msgstr ""
 
-#: common.opt:1544
+#: common.opt:1548
 msgid "Merge adjacent stores."
 msgstr ""
 
-#: common.opt:1548
+#: common.opt:1552
 #, fuzzy
 msgid "Enable guessing of branch probabilities."
 msgstr "Aktivér gæt af forgreningssandsynligheder"
 
-#: common.opt:1556
+#: common.opt:1560
 #, fuzzy
 #| msgid "Process #ident directives"
 msgid "Process #ident directives."
 msgstr "Behandl #ident-direktiver"
 
-#: common.opt:1560
+#: common.opt:1564
 #, fuzzy
 #| msgid "Perform conversion of conditional jumps to branchless equivalents"
 msgid "Perform conversion of conditional jumps to branchless equivalents."
 msgstr "Udfør konvertering af betingede spring til forgreningsløse ækvivalenter"
 
-#: common.opt:1564
+#: common.opt:1568
 #, fuzzy
 #| msgid "Perform conversion of conditional jumps to conditional execution"
 msgid "Perform conversion of conditional jumps to conditional execution."
 msgstr "Udfør konvertering af betingede spring til betinget udførsel"
 
-#: common.opt:1568
+#: common.opt:1572
 msgid "-fstack-reuse=[all|named_vars|none]\tSet stack reuse level for local variables."
 msgstr ""
 
-#: common.opt:1571
+#: common.opt:1575
 #, c-format
 msgid "unknown Stack Reuse Level %qs"
 msgstr ""
 
-#: common.opt:1584
+#: common.opt:1588
 #, fuzzy
 #| msgid "Perform conversion of conditional jumps to branchless equivalents"
 msgid "Convert conditional jumps in innermost loops to branchless equivalents."
 msgstr "Udfør konvertering af betingede spring til forgreningsløse ækvivalenter"
 
-#: common.opt:1596
+#: common.opt:1600
 #, fuzzy
 #| msgid "Do not generate .size directives"
 msgid "Do not generate .size directives."
 msgstr "Generér ikke .size-direktiver"
 
-#: common.opt:1600
+#: common.opt:1604
 #, fuzzy
 msgid "Perform indirect inlining."
 msgstr "Udfør løkkeoptimeringerne"
 
-#: common.opt:1606
+#: common.opt:1610
 msgid "Enable inlining of function declared \"inline\", disabling disables all inlining."
 msgstr ""
 
-#: common.opt:1610
+#: common.opt:1614
 #, fuzzy
 #| msgid "Integrate simple functions into their callers"
 msgid "Integrate functions into their callers when code size is known not to grow."
 msgstr "Integrér simple funktioner i deres kaldere"
 
-#: common.opt:1614
+#: common.opt:1618
 #, fuzzy
 #| msgid "Integrate simple functions into their callers"
 msgid "Integrate functions not declared \"inline\" into their callers when profitable."
 msgstr "Integrér simple funktioner i deres kaldere"
 
-#: common.opt:1618
+#: common.opt:1622
 #, fuzzy
 #| msgid "Integrate simple functions into their callers"
 msgid "Integrate functions only required by their single caller."
 msgstr "Integrér simple funktioner i deres kaldere"
 
-#: common.opt:1625
+#: common.opt:1629
 #, fuzzy
 msgid "-finline-limit=<number>\tLimit the size of inlined functions to <number>."
 msgstr "  -finline-limit=<str>    Begræns størrelsen af inlie funktion til <str>\n"
 
-#: common.opt:1629
+#: common.opt:1633
 msgid "Inline __atomic operations when a lock free instruction sequence is available."
 msgstr ""
 
-#: common.opt:1636
+#: common.opt:1640
 msgid "-fcf-protection=[full|branch|return|none]\tInstrument functions with checks to verify jump/call/return control-flow transfer instructions have valid targets."
 msgstr ""
 
-#: common.opt:1640
+#: common.opt:1644
 #, c-format
 msgid "unknown Control-Flow Protection Level %qs"
 msgstr ""
 
-#: common.opt:1656
+#: common.opt:1660
 #, fuzzy
 msgid "Instrument function entry and exit with profiling calls."
 msgstr "Instrumentér funktionsindgange/-afslutninger med profileringskald"
 
-#: common.opt:1660
+#: common.opt:1664
 msgid "-finstrument-functions-exclude-function-list=name,...  Do not instrument listed functions."
 msgstr ""
 
-#: common.opt:1664
+#: common.opt:1668
 msgid "-finstrument-functions-exclude-file-list=filename,...  Do not instrument functions listed in files."
 msgstr ""
 
-#: common.opt:1668
+#: common.opt:1672
 #, fuzzy
 #| msgid "Enable SSA conditional constant propagation"
 msgid "Perform interprocedural constant propagation."
 msgstr "Aktivér betinget konstant SSA-propagering"
 
-#: common.opt:1672
+#: common.opt:1676
 #, fuzzy
 #| msgid "how much can given compilation unit grow because of the inlining (in percent)"
 msgid "Perform cloning to make Interprocedural constant propagation stronger."
 msgstr "Hvor meget en oversættelsesenhed kan vokse pga. indlejring (i procent)"
 
-#: common.opt:1680
+#: common.opt:1684
 #, fuzzy
 #| msgid "Enable SSA conditional constant propagation"
 msgid "Perform interprocedural bitwise constant propagation."
 msgstr "Aktivér betinget konstant SSA-propagering"
 
-#: common.opt:1684
+#: common.opt:1688
 #, fuzzy
 #| msgid "Enable SSA conditional constant propagation"
 msgid "Perform interprocedural profile propagation."
 msgstr "Aktivér betinget konstant SSA-propagering"
 
-#: common.opt:1688
+#: common.opt:1692
 #, fuzzy
 #| msgid "Enable SSA conditional constant propagation"
 msgid "Perform interprocedural points-to analysis."
 msgstr "Aktivér betinget konstant SSA-propagering"
 
-#: common.opt:1692
+#: common.opt:1696
 #, fuzzy
 #| msgid "Discard unused virtual functions"
 msgid "Discover pure and const functions."
 msgstr "Kassér ubrugte virtuelle funktioner"
 
-#: common.opt:1696
+#: common.opt:1700
 #, fuzzy
 #| msgid "Perform loop unrolling for all loops"
 msgid "Perform Identical Code Folding for functions and read-only variables."
 msgstr "Udfør løkkeudrulning for alle løkker"
 
-#: common.opt:1700
+#: common.opt:1704
 #, fuzzy
 #| msgid "Perform loop unrolling for all loops"
 msgid "Perform Identical Code Folding for functions."
 msgstr "Udfør løkkeudrulning for alle løkker"
 
-#: common.opt:1704
+#: common.opt:1708
 #, fuzzy
 #| msgid "Perform loop unrolling for all loops"
 msgid "Perform Identical Code Folding for variables."
 msgstr "Udfør løkkeudrulning for alle løkker"
 
-#: common.opt:1708
+#: common.opt:1712
 msgid "Discover readonly and non addressable static variables."
 msgstr ""
 
-#: common.opt:1720
+#: common.opt:1724
 #, fuzzy
 msgid "Perform IPA Value Range Propagation."
 msgstr "Foretag registerkopipropageringsoptimering"
 
-#: common.opt:1724
+#: common.opt:1728
 msgid "-fira-algorithm=[CB|priority]\tSet the used IRA algorithm."
 msgstr ""
 
-#: common.opt:1727
+#: common.opt:1731
 #, fuzzy, c-format
 #| msgid "unknown register name: %s"
 msgid "unknown IRA algorithm %qs"
 msgstr "ukendt registernavn: %s"
 
-#: common.opt:1737
+#: common.opt:1741
 msgid "-fira-region=[one|all|mixed]\tSet regions for IRA."
 msgstr ""
 
-#: common.opt:1740
+#: common.opt:1744
 #, fuzzy, c-format
 #| msgid "unknown register name: %s"
 msgid "unknown IRA region %qs"
 msgstr "ukendt registernavn: %s"
 
-#: common.opt:1753
+#: common.opt:1757
 msgid "Use IRA based register pressure calculation in RTL hoist optimizations."
 msgstr ""
 
-#: common.opt:1758
+#: common.opt:1762
 msgid "Use IRA based register pressure calculation in RTL loop optimizations."
 msgstr ""
 
-#: common.opt:1763
+#: common.opt:1767
 #, fuzzy
 #| msgid "Store locals in argument registers"
 msgid "Share slots for saving different hard registers."
 msgstr "Gem lokale variable i parameterregistre"
 
-#: common.opt:1767
+#: common.opt:1771
 msgid "Share stack slots for spilled pseudo-registers."
 msgstr ""
 
-#: common.opt:1771
+#: common.opt:1775
 msgid "-fira-verbose=<number>\tControl IRA's level of diagnostic messages."
 msgstr ""
 
-#: common.opt:1775
+#: common.opt:1779
 #, fuzzy
 #| msgid "Strength reduce all loop general induction variables"
 msgid "Optimize induction variables on trees."
 msgstr "Styrkereducér alle generelle løkkeinduktionsvariabler"
 
-#: common.opt:1779
+#: common.opt:1783
 #, fuzzy
 #| msgid "case label not within a switch statement"
 msgid "Use jump tables for sufficiently large switch statements."
 msgstr "case-etiket befinder sig ikke inden i en switch-sætning"
 
-#: common.opt:1783
+#: common.opt:1787
 #, fuzzy
 msgid "Generate code for functions even if they are fully inlined."
 msgstr "Generér kode for funktioner selv hvis de indlejres helt"
 
-#: common.opt:1787
+#: common.opt:1791
 #, fuzzy
 msgid "Generate code for static functions even if they are never called."
 msgstr "Generér kode for funktioner selv hvis de indlejres helt"
 
-#: common.opt:1791
+#: common.opt:1795
 #, fuzzy
 #| msgid "Emit static const variables even if they are not used"
 msgid "Emit static const variables even if they are not used."
 msgstr "Konstruér statiske, konstante variabler selv hvis de ikke bruges"
 
-#: common.opt:1795
+#: common.opt:1799
 #, fuzzy
 msgid "Give external symbols a leading underscore."
 msgstr "Eksterne symboler har indledende understreg"
 
-#: common.opt:1803
+#: common.opt:1807
 msgid "Do CFG-sensitive rematerialization in LRA."
 msgstr ""
 
-#: common.opt:1807
+#: common.opt:1811
 #, fuzzy
 #| msgid "Enable linker optimizations"
 msgid "Enable link-time optimization."
 msgstr "Aktivér sammenkæderoptimeringer"
 
-#: common.opt:1811
+#: common.opt:1815
 msgid "Link-time optimization with number of parallel jobs or jobserver."
 msgstr ""
 
-#: common.opt:1814
+#: common.opt:1818
 #, fuzzy, c-format
 #| msgid "unknown machine mode `%s'"
 msgid "unknown LTO partitioning model %qs"
 msgstr "ukendt maskintilstand '%s'"
 
-#: common.opt:1833
+#: common.opt:1837
 msgid "Specify the algorithm to partition symbols and vars at linktime."
 msgstr ""
 
-#: common.opt:1838
+#: common.opt:1842
 msgid "-flto-compression-level=<number>\tUse zlib compression level <number> for IL."
 msgstr ""
 
-#: common.opt:1842
+#: common.opt:1846
 msgid "Merge C++ types using One Definition Rule."
 msgstr ""
 
-#: common.opt:1846
+#: common.opt:1850
 #, fuzzy
 msgid "Report various link-time optimization statistics."
 msgstr "Foretag registeromdøbningsoptimering"
 
-#: common.opt:1850
+#: common.opt:1854
 #, fuzzy
 msgid "Report various link-time optimization statistics for WPA only."
 msgstr "Foretag registeromdøbningsoptimering"
 
-#: common.opt:1854
+#: common.opt:1858
 #, fuzzy
 #| msgid "Set errno after built-in math functions"
 msgid "Set errno after built-in math functions."
 msgstr "Sæt errno efter indbyggede matematikfunktioner"
 
-#: common.opt:1858
+#: common.opt:1862
 msgid "-fmax-errors=<number>\tMaximum number of errors to report."
 msgstr ""
 
-#: common.opt:1862
+#: common.opt:1866
 #, fuzzy
 msgid "Report on permanent memory allocation."
 msgstr "Rapportér om permanente hukommelsesallokering ved afslutningen af kørslen"
 
-#: common.opt:1866
+#: common.opt:1870
 #, fuzzy
 msgid "Report on permanent memory allocation in WPA only."
 msgstr "Rapportér om permanente hukommelsesallokering ved afslutningen af kørslen"
 
-#: common.opt:1873
+#: common.opt:1877
 #, fuzzy
 #| msgid "Attempt to merge identical constants and constant variables"
 msgid "Attempt to merge identical constants and constant variables."
 msgstr "Forsøg at forene identiske konstanter og konstante variabler"
 
-#: common.opt:1877
+#: common.opt:1881
 #, fuzzy
 #| msgid "Attempt to merge identical constants across compilation units"
 msgid "Attempt to merge identical constants across compilation units."
 msgstr "Forsøg at forene identiske konstanter over forskellige oversættelsesenheder"
 
-#: common.opt:1881
+#: common.opt:1885
 #, fuzzy
 #| msgid "Attempt to merge identical constants across compilation units"
 msgid "Attempt to merge identical debug strings across compilation units."
 msgstr "Forsøg at forene identiske konstanter over forskellige oversættelsesenheder"
 
-#: common.opt:1885
+#: common.opt:1889
 #, fuzzy
 msgid "-fmessage-length=<number>\tLimit diagnostics to <number> characters per line.  0 suppresses line-wrapping."
 msgstr "  -fmessage-length=<antal>  Begræns længden af diagnosticeringmeddelelser til længden <antal> tegn/linje. 0 undertrykker linjeombrydning\n"
 
-#: common.opt:1889
+#: common.opt:1893
 msgid "Perform SMS based modulo scheduling before the first scheduling pass."
 msgstr ""
 
-#: common.opt:1893
+#: common.opt:1897
 msgid "Perform SMS based modulo scheduling with register moves allowed."
 msgstr ""
 
-#: common.opt:1897
+#: common.opt:1901
 #, fuzzy
 #| msgid "Force all loop invariant computations out of loops"
 msgid "Move loop invariant computations out of loops."
 msgstr "Tving alle løkkeinvariansberegninger ud af løkker"
 
-#: common.opt:1901
+#: common.opt:1905
 #, fuzzy
 #| msgid "Enable aggressive SSA dead code elimination"
 msgid "Use the RTL dead code elimination pass."
 msgstr "Aktivér aggressiv SSA-eliminering af ubrugt kode"
 
-#: common.opt:1905
+#: common.opt:1909
 #, fuzzy
 msgid "Use the RTL dead store elimination pass."
 msgstr "Foretag en komplet registerflytningsoptimering"
 
-#: common.opt:1909
+#: common.opt:1913
 msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling."
 msgstr ""
 
-#: common.opt:1913
+#: common.opt:1917
 #, fuzzy
 #| msgid "Support synchronous non-call exceptions"
 msgid "Support synchronous non-call exceptions."
 msgstr "Understøt synkrone ikke-kaldende undtagelser"
 
-#: common.opt:1916
+#: common.opt:1920
 #, fuzzy, c-format
 #| msgid "target missing after %s"
 msgid "options or targets missing after %qs"
 msgstr "et mål mangler efter %s"
 
-#: common.opt:1917
+#: common.opt:1921
 msgid "-foffload=<targets>=<options>  Specify offloading targets and options for them."
 msgstr ""
 
-#: common.opt:1921
+#: common.opt:1925
 msgid "-foffload-abi=[lp64|ilp32]     Set the ABI to use in an offload compiler."
 msgstr ""
 
-#: common.opt:1924
+#: common.opt:1928
 #, fuzzy, c-format
 msgid "unknown offload ABI %qs"
 msgstr "'%s': ukendt tls-model-tilvalg"
 
-#: common.opt:1934
+#: common.opt:1938
 #, fuzzy
 #| msgid "When possible do not generate stack frames"
 msgid "When possible do not generate stack frames."
 msgstr "Generér ikke stakrammer når det kan undgås"
 
-#: common.opt:1938
+#: common.opt:1942
 #, fuzzy
 #| msgid "Enable linker optimizations"
 msgid "Enable all optimization info dumps on stderr."
 msgstr "Aktivér sammenkæderoptimeringer"
 
-#: common.opt:1942
+#: common.opt:1946
 msgid "-fopt-info[-<type>=filename]\tDump compiler optimization details."
 msgstr ""
 
-#: common.opt:1950
+#: common.opt:1954
 #, fuzzy
 #| msgid "Optimize sibling and tail recursive calls"
 msgid "Optimize sibling and tail recursive calls."
 msgstr "Optimér søskende- og halerekursive kald"
 
-#: common.opt:1954
+#: common.opt:1958
 #, fuzzy
 msgid "Perform partial inlining."
 msgstr "Udfør løkkeoptimeringerne"
 
-#: common.opt:1958 common.opt:1962
+#: common.opt:1962 common.opt:1966
 msgid "Report on memory allocation before interprocedural optimization."
 msgstr ""
 
-#: common.opt:1966
+#: common.opt:1970
 #, fuzzy
 #| msgid "Pack structure members together without holes"
 msgid "Pack structure members together without holes."
 msgstr "Pak strukturmedlemmer sammen uden mellemrum"
 
-#: common.opt:1970
+#: common.opt:1974
 msgid "-fpack-struct=<number>\tSet initial maximum structure member alignment."
 msgstr ""
 
-#: common.opt:1974
+#: common.opt:1978
 #, fuzzy
 msgid "Return small aggregates in memory, not registers."
 msgstr "Returnér små sammensatte værdier i hukommelsen, ikke i registre"
 
-#: common.opt:1978
+#: common.opt:1982
 #, fuzzy
 msgid "Perform loop peeling."
 msgstr "Udfør løkkeoptimeringerne"
 
-#: common.opt:1982
+#: common.opt:1986
 #, fuzzy
 #| msgid "Enable machine specific peephole optimizations"
 msgid "Enable machine specific peephole optimizations."
 msgstr "Aktivér maskinspecifikke kighulsoptimeringer"
 
-#: common.opt:1986
+#: common.opt:1990
 #, fuzzy
 msgid "Enable an RTL peephole pass before sched2."
 msgstr "Aktivér en RTL-kikhulsfase før sched2"
 
-#: common.opt:1990
+#: common.opt:1994
 #, fuzzy
 msgid "Generate position-independent code if possible (large mode)."
 msgstr "Generér placeringsuafhængig kode, om muligt"
 
-#: common.opt:1994
+#: common.opt:1998
 #, fuzzy
 msgid "Generate position-independent code for executables if possible (large mode)."
 msgstr "Generér placeringsuafhængig kode, om muligt"
 
-#: common.opt:1998
+#: common.opt:2002
 #, fuzzy
 msgid "Generate position-independent code if possible (small mode)."
 msgstr "Generér placeringsuafhængig kode, om muligt"
 
-#: common.opt:2002
+#: common.opt:2006
 #, fuzzy
 msgid "Generate position-independent code for executables if possible (small mode)."
 msgstr "Generér placeringsuafhængig kode, om muligt"
 
-#: common.opt:2006
+#: common.opt:2010
 msgid "Use PLT for PIC calls (-fno-plt: load the address from GOT at call site)."
 msgstr ""
 
-#: common.opt:2010
+#: common.opt:2014
 msgid "Specify a plugin to load."
 msgstr ""
 
-#: common.opt:2014
+#: common.opt:2018
 msgid "-fplugin-arg-<name>-<key>[=<value>]\tSpecify argument <key>=<value> for plugin <name>."
 msgstr ""
 
-#: common.opt:2018
+#: common.opt:2022
 #, fuzzy
 #| msgid "Enables a register move optimization"
 msgid "Run predictive commoning optimization."
 msgstr "Aktivér en registerflytningsoptimering"
 
-#: common.opt:2022
+#: common.opt:2026
 #, fuzzy
 #| msgid "Generate prefetch instructions, if available, for arrays in loops"
 msgid "Generate prefetch instructions, if available, for arrays in loops."
 msgstr "Generér præhentningsinstruktioner, hvis tilgængelige, for tabeller i løkker"
 
-#: common.opt:2026
+#: common.opt:2030
 #, fuzzy
 #| msgid "Enable basic program profiling code"
 msgid "Enable basic program profiling code."
 msgstr "Aktivér basal programprofileringskode"
 
-#: common.opt:2030
+#: common.opt:2034
 #, fuzzy
 #| msgid "Generate code for near calls"
 msgid "Generate absolute source path names for gcov."
 msgstr "Generér kode til nære kald"
 
-#: common.opt:2034
+#: common.opt:2038
 #, fuzzy
 msgid "Insert arc-based program profiling code."
 msgstr "Indsæt buebaseret programprofileringskode"
 
-#: common.opt:2038
+#: common.opt:2042
 msgid "Set the top-level directory for storing the profile data. The default is 'pwd'."
 msgstr ""
 
-#: common.opt:2043
+#: common.opt:2047
 #, fuzzy
 #| msgid "Enable SSA conditional constant propagation"
 msgid "Enable correction of flow inconsistent profile data input."
 msgstr "Aktivér betinget konstant SSA-propagering"
 
-#: common.opt:2047
+#: common.opt:2051
 msgid "-fprofile-update=[single|atomic|prefer-atomic]\tSet the profile update method."
 msgstr ""
 
-#: common.opt:2050
+#: common.opt:2054
 #, fuzzy, c-format
 msgid "unknown profile update method %qs"
 msgstr "'%s': ukendt tls-model-tilvalg"
 
-#: common.opt:2063
+#: common.opt:2067
 msgid "Enable common options for generating profile info for profile feedback directed optimizations."
 msgstr ""
 
-#: common.opt:2067
+#: common.opt:2071
 msgid "Enable common options for generating profile info for profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr ""
 
-#: common.opt:2071
+#: common.opt:2075
 msgid "Enable common options for performing profile feedback directed optimizations."
 msgstr ""
 
-#: common.opt:2075
+#: common.opt:2079
 msgid "Enable common options for performing profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr ""
 
-#: common.opt:2079
+#: common.opt:2083
 msgid "Insert code to profile values of expressions."
 msgstr ""
 
-#: common.opt:2083
+#: common.opt:2087
 #, fuzzy
 #| msgid "internal gcc abort"
 msgid "Report on consistency of profile."
 msgstr "intern GCC-afbrydelse"
 
-#: common.opt:2087
+#: common.opt:2091
 #, fuzzy
 #| msgid "Reorder functions to improve code placement"
 msgid "Enable function reordering that improves code placement."
 msgstr "Omordn funktioner for at forbedre kodeplacering"
 
-#: common.opt:2091
+#: common.opt:2095
 #, fuzzy
 #| msgid "Generate cld instruction in the function prologue."
 msgid "Insert NOP instructions at each function entry."
 msgstr "Opret cld-instruktion i en funktions begyndelse."
 
-#: common.opt:2098
+#: common.opt:2102
 msgid "-frandom-seed=<string>\tMake compile reproducible using <string>."
 msgstr ""
 
-#: common.opt:2108
+#: common.opt:2112
 msgid "Record gcc command line switches in the object file."
 msgstr ""
 
-#: common.opt:2112
+#: common.opt:2116
 #, fuzzy
 msgid "Return small aggregates in registers."
 msgstr "Returnér små sammensatte værdier i registre"
 
-#: common.opt:2120
+#: common.opt:2124
 msgid "Tell DSE that the storage for a C++ object is dead when the constructor starts and when the destructor finishes."
 msgstr ""
 
-#: common.opt:2128
+#: common.opt:2132
 msgid "Relief of register pressure through live range shrinkage."
 msgstr ""
 
-#: common.opt:2132
+#: common.opt:2136
 #, fuzzy
 msgid "Perform a register renaming optimization pass."
 msgstr "Foretag registeromdøbningsoptimering"
 
-#: common.opt:2136
+#: common.opt:2140
 #, fuzzy
 msgid "Perform a target dependent instruction fusion optimization pass."
 msgstr "Foretag registeromdøbningsoptimering"
 
-#: common.opt:2140
+#: common.opt:2144
 #, fuzzy
 #| msgid "Reorder basic blocks to improve code placement"
 msgid "Reorder basic blocks to improve code placement."
 msgstr "Omordn basisblokke for at forbedre kodeplacering"
 
-#: common.opt:2144
+#: common.opt:2148
 msgid "-freorder-blocks-algorithm=[simple|stc]\tSet the used basic block reordering algorithm."
 msgstr ""
 
-#: common.opt:2147
+#: common.opt:2151
 #, fuzzy, c-format
 #| msgid "unknown register name: %s"
 msgid "unknown basic block reordering algorithm %qs"
 msgstr "ukendt registernavn: %s"
 
-#: common.opt:2157
+#: common.opt:2161
 #, fuzzy
 #| msgid "Reorder basic blocks to improve code placement"
 msgid "Reorder basic blocks and partition into hot and cold sections."
 msgstr "Omordn basisblokke for at forbedre kodeplacering"
 
-#: common.opt:2161
+#: common.opt:2165
 #, fuzzy
 #| msgid "Reorder functions to improve code placement"
 msgid "Reorder functions to improve code placement."
 msgstr "Omordn funktioner for at forbedre kodeplacering"
 
-#: common.opt:2165
+#: common.opt:2169
 #, fuzzy
 msgid "Add a common subexpression elimination pass after loop optimizations."
 msgstr "Kør CSE-fase efter løkkeoptimeringer"
 
-#: common.opt:2173
+#: common.opt:2177
 msgid "Disable optimizations that assume default FP rounding behavior."
 msgstr ""
 
-#: common.opt:2177
+#: common.opt:2181
 #, fuzzy
 #| msgid "Enable scheduling across basic blocks"
 msgid "Enable scheduling across basic blocks."
 msgstr "Aktivér planlægning over basisblokke"
 
-#: common.opt:2181
+#: common.opt:2185
 msgid "Enable register pressure sensitive insn scheduling."
 msgstr ""
 
-#: common.opt:2185
+#: common.opt:2189
 #, fuzzy
 #| msgid "Allow speculative motion of non-loads"
 msgid "Allow speculative motion of non-loads."
 msgstr "Tillad spekulativ bevægelse af ikke-indlæsninger"
 
-#: common.opt:2189
+#: common.opt:2193
 #, fuzzy
 #| msgid "Allow speculative motion of some loads"
 msgid "Allow speculative motion of some loads."
 msgstr "Tillad spekulativ bevægelse af nogle indlæsninger"
 
-#: common.opt:2193
+#: common.opt:2197
 #, fuzzy
 #| msgid "Allow speculative motion of more loads"
 msgid "Allow speculative motion of more loads."
 msgstr "Tillad spekulativ bevægelse af flere indlæsninger"
 
-#: common.opt:2197
+#: common.opt:2201
 #, fuzzy
 msgid "-fsched-verbose=<number>\tSet the verbosity level of the scheduler."
 msgstr "  -fsched-verbose=<tal>    Angiv hvor meget planlæggeren skal fortælle\n"
 
-#: common.opt:2201
+#: common.opt:2205
 msgid "If scheduling post reload, do superblock scheduling."
 msgstr ""
 
-#: common.opt:2209
+#: common.opt:2213
 #, fuzzy
 #| msgid "Reschedule instructions before register allocation"
 msgid "Reschedule instructions before register allocation."
 msgstr "Omplanlæg instruktioner før registerallokering"
 
-#: common.opt:2213
+#: common.opt:2217
 #, fuzzy
 #| msgid "Reschedule instructions after register allocation"
 msgid "Reschedule instructions after register allocation."
 msgstr "Omplanlæg instruktioner efter registerallokering"
 
-#: common.opt:2220
+#: common.opt:2224
 msgid "Schedule instructions using selective scheduling algorithm."
 msgstr ""
 
-#: common.opt:2224
+#: common.opt:2228
 msgid "Run selective scheduling after reload."
 msgstr ""
 
-#: common.opt:2228
+#: common.opt:2232
 msgid "Run self-tests, using the given path to locate test files."
 msgstr ""
 
-#: common.opt:2232
+#: common.opt:2236
 msgid "Perform software pipelining of inner loops during selective scheduling."
 msgstr ""
 
-#: common.opt:2236
+#: common.opt:2240
 msgid "Perform software pipelining of outer loops during selective scheduling."
 msgstr ""
 
-#: common.opt:2240
+#: common.opt:2244
 msgid "Reschedule pipelined regions without pipelining."
 msgstr ""
 
-#: common.opt:2244
+#: common.opt:2248
 msgid "Allow interposing function (or variables) by ones with different semantics (or initializer) respectively by dynamic linker."
 msgstr ""
 
-#: common.opt:2250
+#: common.opt:2254
 msgid "Allow premature scheduling of queued insns."
 msgstr ""
 
-#: common.opt:2254
+#: common.opt:2258
 msgid "-fsched-stalled-insns=<number>\tSet number of queued insns that can be prematurely scheduled."
 msgstr ""
 
-#: common.opt:2262
+#: common.opt:2266
 msgid "Set dependence distance checking in premature scheduling of queued insns."
 msgstr ""
 
-#: common.opt:2266
+#: common.opt:2270
 msgid "-fsched-stalled-insns-dep=<number>\tSet dependence distance checking in premature scheduling of queued insns."
 msgstr ""
 
-#: common.opt:2270
+#: common.opt:2274
 #, fuzzy
 #| msgid "Enable the group heuristic in the scheduler"
 msgid "Enable the group heuristic in the scheduler."
 msgstr "Aktiver gruppeheuristikken i planlæggeren"
 
-#: common.opt:2274
+#: common.opt:2278
 #, fuzzy
 #| msgid "Enable the group heuristic in the scheduler"
 msgid "Enable the critical path heuristic in the scheduler."
 msgstr "Aktiver gruppeheuristikken i planlæggeren"
 
-#: common.opt:2278
+#: common.opt:2282
 #, fuzzy
 #| msgid "Enable the group heuristic in the scheduler"
 msgid "Enable the speculative instruction heuristic in the scheduler."
 msgstr "Aktiver gruppeheuristikken i planlæggeren"
 
-#: common.opt:2282
+#: common.opt:2286
 #, fuzzy
 #| msgid "Enable the group heuristic in the scheduler"
 msgid "Enable the rank heuristic in the scheduler."
 msgstr "Aktiver gruppeheuristikken i planlæggeren"
 
-#: common.opt:2286
+#: common.opt:2290
 #, fuzzy
 #| msgid "Enable the group heuristic in the scheduler"
 msgid "Enable the last instruction heuristic in the scheduler."
 msgstr "Aktiver gruppeheuristikken i planlæggeren"
 
-#: common.opt:2290
+#: common.opt:2294
 #, fuzzy
 #| msgid "Enable the group heuristic in the scheduler"
 msgid "Enable the dependent count heuristic in the scheduler."
 msgstr "Aktiver gruppeheuristikken i planlæggeren"
 
-#: common.opt:2294
+#: common.opt:2298
 msgid "Access data in the same section from shared anchor points."
 msgstr ""
 
-#: common.opt:2306
+#: common.opt:2310
 msgid "Turn on Redundant Extensions Elimination pass."
 msgstr ""
 
-#: common.opt:2310
+#: common.opt:2314
 msgid "Show column numbers in diagnostics, when available.  Default on."
 msgstr ""
 
-#: common.opt:2314
+#: common.opt:2318
 msgid "Emit function prologues only before parts of the function that need it, rather than at the top of the function."
 msgstr ""
 
-#: common.opt:2319
+#: common.opt:2323
 msgid "Shrink-wrap parts of the prologue and epilogue separately."
 msgstr ""
 
-#: common.opt:2323
+#: common.opt:2327
 #, fuzzy
 #| msgid "Disable optimizations observable by IEEE signaling NaNs"
 msgid "Disable optimizations observable by IEEE signaling NaNs."
 msgstr "Deaktivér optimeringer som kan opdages ved IEEE-signalerende NaN'er"
 
-#: common.opt:2327
+#: common.opt:2331
 msgid "Disable floating point optimizations that ignore the IEEE signedness of zero."
 msgstr ""
 
-#: common.opt:2331
+#: common.opt:2335
 #, fuzzy
 msgid "Convert floating point constants to single precision constants."
 msgstr "Konvertér kommatalskonstanter til enkeltpræcisionskonstanter"
 
-#: common.opt:2335
+#: common.opt:2339
 #, fuzzy
 #| msgid "Strength reduce all loop general induction variables"
 msgid "Split lifetimes of induction variables when loops are unrolled."
 msgstr "Styrkereducér alle generelle løkkeinduktionsvariabler"
 
-#: common.opt:2339
+#: common.opt:2343
 #, fuzzy
 #| msgid "Generate APCS conformant stack frames"
 msgid "Generate discontiguous stack frames."
 msgstr "Generér APCS-overholdende stakrammer"
 
-#: common.opt:2343
+#: common.opt:2347
 msgid "Split wide types into independent registers."
 msgstr ""
 
-#: common.opt:2347
+#: common.opt:2351
 msgid "Enable backward propagation of use properties at the SSA level."
 msgstr ""
 
-#: common.opt:2351
+#: common.opt:2355
 msgid "Optimize conditional patterns using SSA PHI nodes."
 msgstr ""
 
-#: common.opt:2355
+#: common.opt:2359
 #, fuzzy
 #| msgid "Number of registers used to pass integer arguments"
 msgid "Optimize amount of stdarg registers saved to stack at start of function."
 msgstr "Antallet af registre der skal bruges til at overbringe heltalsparametre"
 
-#: common.opt:2359
+#: common.opt:2363
 msgid "Apply variable expansion when loops are unrolled."
 msgstr ""
 
-#: common.opt:2363
+#: common.opt:2367
 #, fuzzy
 #| msgid "Insert stack checking code into the program"
 msgid "-fstack-check=[no|generic|specific]\tInsert stack checking code into the program."
 msgstr "Indsæt stakkontrolleringskode i programmet"
 
-#: common.opt:2367
+#: common.opt:2371
 #, fuzzy
 #| msgid "Insert stack checking code into the program"
 msgid "Insert stack checking code into the program.  Same as -fstack-check=specific."
 msgstr "Indsæt stakkontrolleringskode i programmet"
 
-#: common.opt:2371
+#: common.opt:2375
 msgid "Insert code to probe each page of stack space as it is allocated to protect from stack-clash style attacks."
 msgstr ""
 
-#: common.opt:2379
+#: common.opt:2383
 msgid "-fstack-limit-register=<register>\tTrap if the stack goes past <register>."
 msgstr ""
 
-#: common.opt:2383
+#: common.opt:2387
 msgid "-fstack-limit-symbol=<name>\tTrap if the stack goes past symbol <name>."
 msgstr ""
 
-#: common.opt:2387
+#: common.opt:2391
 #, fuzzy
 #| msgid "Enable stack probing"
 msgid "Use propolice as a stack protection method."
 msgstr "Aktivér stakprøvning"
 
-#: common.opt:2391
+#: common.opt:2395
 msgid "Use a stack protection method for every function."
 msgstr ""
 
-#: common.opt:2395
+#: common.opt:2399
 msgid "Use a smart stack protection method for certain functions."
 msgstr ""
 
-#: common.opt:2399
+#: common.opt:2403
 msgid "Use stack protection method only for functions with the stack_protect attribute."
 msgstr ""
 
-#: common.opt:2403
+#: common.opt:2407
 #, fuzzy
 #| msgid "Reuse r30 on a per function basis"
 msgid "Output stack usage information on a per-function basis."
 msgstr "Genbrug r30 på et pr. funktionsgrundlag"
 
-#: common.opt:2415
+#: common.opt:2419
 #, fuzzy
 #| msgid "Assume strict aliasing rules apply"
 msgid "Assume strict aliasing rules apply."
 msgstr "Antag at strenge aliasregler skal anvendes"
 
-#: common.opt:2419
+#: common.opt:2423
 #, fuzzy
 #| msgid "Set Windows defines"
 msgid "Treat signed overflow as undefined.  Negated as -fwrapv -fwrapv-pointer."
 msgstr "Angiv Windows-definitioner"
 
-#: common.opt:2423
+#: common.opt:2427
 msgid "Implement __atomic operations via libcalls to legacy __sync functions."
 msgstr ""
 
-#: common.opt:2427
+#: common.opt:2431
 #, fuzzy
 #| msgid "Check for syntax errors, then stop"
 msgid "Check for syntax errors, then stop."
 msgstr "Kontroller for syntaksfejl og stop derefter"
 
-#: common.opt:2431
+#: common.opt:2435
 #, fuzzy
 #| msgid "Create data files needed by \"gcov\""
 msgid "Create data files needed by \"gcov\"."
 msgstr "Opret datafiler som »gcov« har brug for"
 
-#: common.opt:2435
+#: common.opt:2439
 #, fuzzy
 #| msgid "Perform jump threading optimizations"
 msgid "Perform jump threading optimizations."
 msgstr "Udfør springtrådningsoptimeringer"
 
-#: common.opt:2439
+#: common.opt:2443
 #, fuzzy
 #| msgid "Report the time taken by each compiler pass"
 msgid "Report the time taken by each compiler pass."
 msgstr "Rapporter den tid det tager for hvert kompilergennemløb"
 
-#: common.opt:2443
+#: common.opt:2447
 msgid "Record times taken by sub-phases separately."
 msgstr ""
 
-#: common.opt:2447
+#: common.opt:2451
 #, fuzzy
 msgid "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tSet the default thread-local storage code generation model."
 msgstr "  -ftls-model=[global-dynamic | local-dynamic | initial-exec | local-exec] Indikerer den forvalgte tråd-lokale lagringsmodel for kodegenerering\n"
 
-#: common.opt:2450
+#: common.opt:2454
 #, c-format
 msgid "unknown TLS model %qs"
 msgstr "ukendt tls-model %qs"
 
-#: common.opt:2466
+#: common.opt:2470
 msgid "Reorder top level functions, variables, and asms."
 msgstr ""
 
-#: common.opt:2470
+#: common.opt:2474
 #, fuzzy
 #| msgid "Perform superblock formation via tail duplication"
 msgid "Perform superblock formation via tail duplication."
 msgstr "Udfør superbloksformering vha. haleduplikering"
 
-#: common.opt:2474
+#: common.opt:2478
 msgid "For targets that normally need trampolines for nested functions, always generate them instead of using descriptors."
 msgstr ""
 
-#: common.opt:2482
+#: common.opt:2486
 #, fuzzy
 msgid "Assume floating-point operations can trap."
 msgstr "Kommatalsoperationer kan fange"
 
-#: common.opt:2486
+#: common.opt:2490
 #, fuzzy
 msgid "Trap for signed overflow in addition, subtraction and multiplication."
 msgstr "Opsæt fælde for overløb med fortegn i addition/subtraktion/multiplikation"
 
-#: common.opt:2490
+#: common.opt:2494
 #, fuzzy
 #| msgid "Enable SSA optimizations"
 msgid "Enable SSA-CCP optimization on trees."
 msgstr "Aktivér SSA-optimeringer"
 
-#: common.opt:2494
+#: common.opt:2498
 #, fuzzy
 #| msgid "Enable SSA-BIT-CCP optimization on trees"
 msgid "Enable SSA-BIT-CCP optimization on trees."
 msgstr "Aktiver SSA-BIT-CCP-optimering på træer"
 
-#: common.opt:2502
+#: common.opt:2506
 #, fuzzy
 #| msgid "Enable linker optimizations"
 msgid "Enable loop header copying on trees."
 msgstr "Aktivér sammenkæderoptimeringer"
 
-#: common.opt:2510
+#: common.opt:2514
 #, fuzzy
 #| msgid "Enable SSA code sinking on trees"
 msgid "Enable SSA coalescing of user variables."
 msgstr "Aktiver SSA-kodesinking på træer"
 
-#: common.opt:2518
+#: common.opt:2522
 #, fuzzy
 msgid "Enable copy propagation on trees."
 msgstr "Aktivér stakprøvning"
 
-#: common.opt:2526
+#: common.opt:2530
 #, fuzzy
 #| msgid "Perform conversion of conditional jumps to conditional execution"
 msgid "Transform condition stores into unconditional ones."
 msgstr "Udfør konvertering af betingede spring til betinget udførsel"
 
-#: common.opt:2530
+#: common.opt:2534
 #, fuzzy
 #| msgid "Perform conversion of conditional jumps to conditional execution"
 msgid "Perform conversions of switch initializations."
 msgstr "Udfør konvertering af betingede spring til betinget udførsel"
 
-#: common.opt:2534
+#: common.opt:2538
 #, fuzzy
 #| msgid "Enable aggressive SSA dead code elimination"
 msgid "Enable SSA dead code elimination optimization on trees."
 msgstr "Aktivér aggressiv SSA-eliminering af ubrugt kode"
 
-#: common.opt:2538
+#: common.opt:2542
 #, fuzzy
 #| msgid "Enable linker optimizations"
 msgid "Enable dominator optimizations."
 msgstr "Aktivér sammenkæderoptimeringer"
 
-#: common.opt:2542
+#: common.opt:2546
 #, fuzzy
 #| msgid "Enable most warning messages"
 msgid "Enable tail merging on trees."
 msgstr "Aktivér de fleste advarselsbeskeder"
 
-#: common.opt:2546
+#: common.opt:2550
 #, fuzzy
 #| msgid "Enable aggressive SSA dead code elimination"
 msgid "Enable dead store elimination."
 msgstr "Aktivér aggressiv SSA-eliminering af ubrugt kode"
 
-#: common.opt:2550
+#: common.opt:2554
 #, fuzzy
 msgid "Enable forward propagation on trees."
 msgstr "Aktivér stakprøvning"
 
-#: common.opt:2554
+#: common.opt:2558
 #, fuzzy
 #| msgid "Force all loop invariant computations out of loops"
 msgid "Enable Full Redundancy Elimination (FRE) on trees."
 msgstr "Tving alle løkkeinvariansberegninger ud af løkker"
 
-#: common.opt:2558
+#: common.opt:2562
 #, fuzzy
 #| msgid "Enable linker optimizations"
 msgid "Enable string length optimizations on trees."
 msgstr "Aktivér sammenkæderoptimeringer"
 
-#: common.opt:2562
+#: common.opt:2566
 msgid "Detect paths that trigger erroneous or undefined behavior due to dereferencing a null pointer.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
-#: common.opt:2568
+#: common.opt:2572
 msgid "Detect paths that trigger erroneous or undefined behavior due to a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
-#: common.opt:2575
+#: common.opt:2579
 #, fuzzy
 #| msgid "Enable parallel instructions"
 msgid "Enable loop distribution on trees."
 msgstr "Aktivér parallelle instruktioner"
 
-#: common.opt:2579
+#: common.opt:2583
 #, fuzzy
 #| msgid "Enable parallel instructions"
 msgid "Enable loop distribution for patterns transformed into a library call."
 msgstr "Aktivér parallelle instruktioner"
 
-#: common.opt:2583
+#: common.opt:2587
 #, fuzzy
 #| msgid "Force all loop invariant computations out of loops"
 msgid "Enable loop invariant motion on trees."
 msgstr "Tving alle løkkeinvariansberegninger ud af løkker"
 
-#: common.opt:2591
+#: common.opt:2595
 #, fuzzy
 #| msgid "Strength reduce all loop general induction variables"
 msgid "Create canonical induction variables in loops."
 msgstr "Styrkereducér alle generelle løkkeinduktionsvariabler"
 
-#: common.opt:2595
+#: common.opt:2599
 #, fuzzy
 #| msgid "Enable linker optimizations"
 msgid "Enable loop optimizations on tree level."
 msgstr "Aktivér sammenkæderoptimeringer"
 
-#: common.opt:2599
+#: common.opt:2603
 #, fuzzy
 #| msgid "Enable automatic template instantiation"
 msgid "-ftree-parallelize-loops=<number>\tEnable automatic parallelization of loops."
 msgstr "Aktivér automatisk skabelonsinstantiering"
 
-#: common.opt:2603
+#: common.opt:2607
 #, fuzzy
 #| msgid "Enable use of conditional move instructions"
 msgid "Enable hoisting loads from conditional pointers."
 msgstr "Aktivér brug af betingede flytteinstruktioner"
 
-#: common.opt:2607
+#: common.opt:2611
 #, fuzzy
 #| msgid "Enable SSA optimizations"
 msgid "Enable SSA-PRE optimization on trees."
 msgstr "Aktivér SSA-optimeringer"
 
-#: common.opt:2611
+#: common.opt:2615
 msgid "In SSA-PRE optimization on trees, enable partial-partial redundancy elimination."
 msgstr ""
 
-#: common.opt:2615
+#: common.opt:2619
 msgid "Perform function-local points-to analysis on trees."
 msgstr ""
 
-#: common.opt:2619
+#: common.opt:2623
 #, fuzzy
 #| msgid "Enable linker optimizations"
 msgid "Enable reassociation on tree level."
 msgstr "Aktivér sammenkæderoptimeringer"
 
-#: common.opt:2627
+#: common.opt:2631
 #, fuzzy
 #| msgid "Enable SSA code sinking on trees"
 msgid "Enable SSA code sinking on trees."
 msgstr "Aktiver SSA-kodesinking på træer"
 
-#: common.opt:2631
+#: common.opt:2635
 #, fuzzy
 #| msgid "Perform strength reduction optimizations"
 msgid "Perform straight-line strength reduction."
 msgstr "Udfør styrkereduceringsoptimeringer"
 
-#: common.opt:2635
+#: common.opt:2639
 msgid "Perform scalar replacement of aggregates."
 msgstr ""
 
-#: common.opt:2639
+#: common.opt:2643
 msgid "Replace temporary expressions in the SSA->normal pass."
 msgstr ""
 
-#: common.opt:2643
+#: common.opt:2647
 msgid "Perform live range splitting during the SSA->normal pass."
 msgstr ""
 
-#: common.opt:2647
+#: common.opt:2651
 #, fuzzy
 msgid "Perform Value Range Propagation on trees."
 msgstr "Foretag registerkopipropageringsoptimering"
 
-#: common.opt:2651
+#: common.opt:2655
 msgid "Split paths leading to loop backedges."
 msgstr ""
 
-#: common.opt:2655
+#: common.opt:2659
 msgid "Assume common declarations may be overridden with ones with a larger trailing array."
 msgstr ""
 
-#: common.opt:2660
+#: common.opt:2664
 #, fuzzy
 msgid "Compile whole compilation unit at a time."
 msgstr "Anbring hele oversættelsesenheden i en fil"
 
-#: common.opt:2664
+#: common.opt:2668
 #, fuzzy
 #| msgid "Perform loop unrolling when iteration count is known"
 msgid "Perform loop unrolling when iteration count is known."
 msgstr "Udfør løkkeudrulning når iterationsantallet er kendt"
 
-#: common.opt:2668
+#: common.opt:2672
 #, fuzzy
 #| msgid "Perform loop unrolling for all loops"
 msgid "Perform loop unrolling for all loops."
 msgstr "Udfør løkkeudrulning for alle løkker"
 
-#: common.opt:2679
+#: common.opt:2683
 msgid "Allow optimization for floating-point arithmetic which may change the result of the operation due to rounding."
 msgstr ""
 
-#: common.opt:2684
+#: common.opt:2688
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr ""
 
-#: common.opt:2692
+#: common.opt:2696
 #, fuzzy
 msgid "Allow math optimizations that may violate IEEE or ISO standards."
 msgstr "Tillad matematikoptimeringer der kan overtræde IEEE- eller ANSI-standarderne"
 
-#: common.opt:2696
+#: common.opt:2700
 #, fuzzy
 msgid "Perform loop unswitching."
 msgstr "Udfør løkkeoptimeringerne"
 
-#: common.opt:2700
+#: common.opt:2704
 #, fuzzy
 msgid "Perform loop splitting."
 msgstr "Udfør løkkeoptimeringerne"
 
-#: common.opt:2704
+#: common.opt:2708
 #, fuzzy
 #| msgid "Just generate unwind tables for exception handling"
 msgid "Just generate unwind tables for exception handling."
 msgstr "Generér blot afvindingstabeller for undtagelseshåndtering"
 
-#: common.opt:2708
+#: common.opt:2712
 #, fuzzy
 #| msgid "Use hardware quad fp instructions"
 msgid "Use the bfd linker instead of the default linker."
 msgstr "Benyt hardware quad-kommatalsinstruktioner"
 
-#: common.opt:2712
+#: common.opt:2716
 #, fuzzy
 #| msgid "Use hardware quad fp instructions"
 msgid "Use the gold linker instead of the default linker."
 msgstr "Benyt hardware quad-kommatalsinstruktioner"
 
-#: common.opt:2724
+#: common.opt:2728
 #, fuzzy
 #| msgid "Perform tail call optimization"
 msgid "Perform variable tracking."
 msgstr "Udfør halekaldsoptimering"
 
-#: common.opt:2732
+#: common.opt:2736
 #, fuzzy
 msgid "Perform variable tracking by annotating assignments."
 msgstr "Foretag registeromdøbningsoptimering"
 
-#: common.opt:2738
+#: common.opt:2742
 msgid "Toggle -fvar-tracking-assignments."
 msgstr ""
 
-#: common.opt:2746
+#: common.opt:2750
 #, fuzzy
 msgid "Perform variable tracking and also tag variables that are uninitialized."
 msgstr "Foretag registeromdøbningsoptimering"
 
-#: common.opt:2751
+#: common.opt:2755
 #, fuzzy
 msgid "Enable vectorization on trees."
 msgstr "Aktivér stakprøvning"
 
-#: common.opt:2759
+#: common.opt:2763
 #, fuzzy
 #| msgid "Enable linker optimizations"
 msgid "Enable loop vectorization on trees."
 msgstr "Aktivér sammenkæderoptimeringer"
 
-#: common.opt:2763
+#: common.opt:2767
 #, fuzzy
 #| msgid "Enable linker optimizations"
 msgid "Enable basic block vectorization (SLP) on trees."
 msgstr "Aktivér sammenkæderoptimeringer"
 
-#: common.opt:2767
+#: common.opt:2771
 msgid "Specifies the cost model for vectorization. -fvect-cost-model=[unlimited|dynamic|cheap]\tSpecifies the cost model for vectorization."
 msgstr ""
 
-#: common.opt:2772
+#: common.opt:2776
 #, fuzzy
 #| msgid "Specify alternate name for bss section"
 msgid "-fsimd-cost-model=[unlimited|dynamic|cheap]\tSpecifies the vectorization cost model for code marked with a simd directive."
 msgstr "Angiv alternativt navn til bss-sektionen"
 
-#: common.opt:2775
+#: common.opt:2779
 #, fuzzy, c-format
 #| msgid "unknown machine mode `%s'"
 msgid "unknown vectorizer cost model %qs"
 msgstr "ukendt maskintilstand '%s'"
 
-#: common.opt:2788
+#: common.opt:2792
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr ""
 
-#: common.opt:2796
+#: common.opt:2800
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr ""
 
-#: common.opt:2806
+#: common.opt:2810
 #, fuzzy
 #| msgid "Add extra commentary to assembler output"
 msgid "Add extra commentary to assembler output."
 msgstr "Tilføj ekstra kommentarer til menneskeligt læsbar maskinkodeuddata"
 
-#: common.opt:2810
+#: common.opt:2814
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility."
 msgstr ""
 
-#: common.opt:2813
+#: common.opt:2817
 #, c-format
 msgid "unrecognized visibility value %qs"
 msgstr "ikke genkendt synlighedsværdi %qs"
 
-#: common.opt:2829
+#: common.opt:2833
 msgid "Validate vtable pointers before using them."
 msgstr ""
 
-#: common.opt:2832
+#: common.opt:2836
 #, fuzzy, c-format
 #| msgid "(near initialization for `%s')"
 msgid "unknown vtable verify initialization priority %qs"
 msgstr "(i nærheden af klargøringen af '%s')"
 
-#: common.opt:2845
+#: common.opt:2849
 msgid "Output vtable verification counters."
 msgstr ""
 
-#: common.opt:2849
+#: common.opt:2853
 msgid "Output vtable verification pointer sets information."
 msgstr ""
 
-#: common.opt:2853
+#: common.opt:2857
 #, fuzzy
 msgid "Use expression value profiles in optimizations."
 msgstr "Aktivér sammenkæderoptimeringer"
 
-#: common.opt:2857
+#: common.opt:2861
 msgid "Construct webs and split unrelated uses of single variable."
 msgstr ""
 
-#: common.opt:2861
+#: common.opt:2865
 #, fuzzy
 #| msgid "Enable use of conditional move instructions"
 msgid "Enable conditional dead code elimination for builtin calls."
 msgstr "Aktivér brug af betingede flytteinstruktioner"
 
-#: common.opt:2865
+#: common.opt:2869
 #, fuzzy
 msgid "Perform whole program optimizations."
 msgstr "Udfør løkkeoptimeringerne"
 
-#: common.opt:2869
+#: common.opt:2873
 #, fuzzy
 #| msgid "Set Windows defines"
 msgid "Assume pointer overflow wraps around."
 msgstr "Angiv Windows-definitioner"
 
-#: common.opt:2873
+#: common.opt:2877
 msgid "Assume signed arithmetic overflow wraps around."
 msgstr ""
 
-#: common.opt:2877
+#: common.opt:2881
 #, fuzzy
 #| msgid "Put zero initialized data in the bss section"
 msgid "Put zero initialized data in the bss section."
 msgstr "Anbring nul-klargjorte data i bss-sektionen"
 
-#: common.opt:2881
+#: common.opt:2885
 #, fuzzy
 msgid "Generate debug information in default format."
 msgstr "Generér fejlfindingsinfo i standardformat"
 
-#: common.opt:2885
+#: common.opt:2889
 msgid "Assume assembler support for (DWARF2+) .loc directives"
 msgstr ""
 
-#: common.opt:2889
+#: common.opt:2893
 msgid "Assume assembler support for view in (DWARF2+) .loc directives"
 msgstr ""
 
-#: common.opt:2892 common.opt:2896 common.opt:2900 common.opt:2904
+#: common.opt:2896 common.opt:2900 common.opt:2904 common.opt:2908
 #, fuzzy, c-format
 #| msgid "switch \"%s\" is no longer supported"
 msgid "switch %qs no longer supported"
 msgstr "tilvalget '%s' understøttes ikke længere"
 
-#: common.opt:2909
+#: common.opt:2913
 msgid "Record DW_AT_decl_column and DW_AT_call_column in DWARF."
 msgstr ""
 
-#: common.opt:2913
+#: common.opt:2917
 #, fuzzy
 msgid "Generate debug information in default version of DWARF format."
 msgstr "Generér fejlfindingsinfo i standardformat"
 
-#: common.opt:2917
+#: common.opt:2921
 #, fuzzy
 msgid "Generate debug information in DWARF v2 (or later) format."
 msgstr "Generér fejlfindingsinfo i standardformat"
 
-#: common.opt:2921
+#: common.opt:2925
 #, fuzzy
 msgid "Generate debug information in default extended format."
 msgstr "Generér fejlfindingsinfo i udvidet standardformat"
 
-#: common.opt:2925
+#: common.opt:2929
 #, fuzzy
 #| msgid "Generate a single exit point for each function"
 msgid "Generate extended entry point information for inlined functions"
 msgstr "Generér et enkelt afslutningspunkt for hver funktion"
 
-#: common.opt:2929
+#: common.opt:2933
 msgid "Compute locview reset points based on insn length estimates"
 msgstr ""
 
-#: common.opt:2937
+#: common.opt:2941
 #, fuzzy
 #| msgid "Don't generate fused multiply/add instructions"
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr "Generér ikke sammensatte gang/addér-instruktioner"
 
-#: common.opt:2941
+#: common.opt:2945
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr "Opret sektioner for DWARF-pubnavne og pubtyper."
 
-#: common.opt:2945
+#: common.opt:2949
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr "Opret sektioner for DWARF-pubnavne og pubtyper med GNU-udvidelser."
 
-#: common.opt:2949
+#: common.opt:2953
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr ""
 
-#: common.opt:2953
+#: common.opt:2957
 #, fuzzy
 #| msgid "Generate debug information in separate .dwo files"
 msgid "Generate debug information in separate .dwo files."
 msgstr "Opret fejlsøgningsinformation i separate .dwo-filer"
 
-#: common.opt:2957
+#: common.opt:2961
 #, fuzzy
 #| msgid "Generate debug information in STABS format"
 msgid "Generate debug information in STABS format."
 msgstr "Opret fejlsøgningsinformation i STABS-format"
 
-#: common.opt:2961
+#: common.opt:2965
 #, fuzzy
 #| msgid "Generate debug information in extended STABS format"
 msgid "Generate debug information in extended STABS format."
 msgstr "Opret fejlsøgningsinformation i udvidet STABS-format"
 
-#: common.opt:2965
+#: common.opt:2969
 msgid "Emit progressive recommended breakpoint locations."
 msgstr ""
 
-#: common.opt:2969
+#: common.opt:2973
 msgid "Don't emit DWARF additions beyond selected version."
 msgstr ""
 
-#: common.opt:2973
+#: common.opt:2977
 #, fuzzy
 msgid "Toggle debug information generation."
 msgstr "Generér fejlfindingsinfo i standardformat"
 
-#: common.opt:2977
+#: common.opt:2981
 msgid "Augment variable location lists with progressive views."
 msgstr ""
 
-#: common.opt:2984
+#: common.opt:2988
 #, fuzzy
 #| msgid "Generate debug information in VMS format"
 msgid "Generate debug information in VMS format."
 msgstr "Opret fejlsøgningsinformation i VMS-format"
 
-#: common.opt:2988
+#: common.opt:2992
 #, fuzzy
 #| msgid "Generate debug information in XCOFF format"
 msgid "Generate debug information in XCOFF format."
 msgstr "Opret fejlsøgningsinformation i XCOFF-format"
 
-#: common.opt:2992
+#: common.opt:2996
 #, fuzzy
 #| msgid "Generate debug information in extended XCOFF format"
 msgid "Generate debug information in extended XCOFF format."
 msgstr "Opret fejlsøgningsinformation i udvidet XCOFF-format"
 
-#: common.opt:3010
+#: common.opt:3014
 #, fuzzy
 #| msgid "Generate compressed debug sections"
 msgid "Generate compressed debug sections."
 msgstr "Opret komprimeret fejlsøgningssektioner"
 
-#: common.opt:3014
+#: common.opt:3018
 #, fuzzy
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>."
 msgstr "Generér fejlfindingsinfo i standardformat"
 
-#: common.opt:3021
+#: common.opt:3025
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory."
 msgstr ""
 
-#: common.opt:3025
+#: common.opt:3029
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory."
 msgstr ""
 
-#: common.opt:3047
+#: common.opt:3051
 #, fuzzy
 msgid "-o <file>\tPlace output into <file>."
 msgstr "  -o <fil>                Anbring uddata i <fil>\n"
 
-#: common.opt:3051
+#: common.opt:3055
 #, fuzzy
 msgid "Enable function profiling."
 msgstr "MIPS16-funktionsprofilering"
 
-#: common.opt:3061
+#: common.opt:3065
 msgid "Like -pedantic but issue them as errors."
 msgstr ""
 
-#: common.opt:3101
+#: common.opt:3105
 #, fuzzy
 #| msgid "Do not display functions compiled or elapsed time"
 msgid "Do not display functions compiled or elapsed time."
 msgstr "Vis ikke funktioner der oversættes eller forløbet tid"
 
-#: common.opt:3133
+#: common.opt:3137
 #, fuzzy
 #| msgid "Enable verbose output"
 msgid "Enable verbose output."
 msgstr "Aktiver uddybende uddata"
 
-#: common.opt:3137
+#: common.opt:3141
 #, fuzzy
 #| msgid "Display the compiler's version"
 msgid "Display the compiler's version."
 msgstr "Vis oversætterens version"
 
-#: common.opt:3141
+#: common.opt:3145
 #, fuzzy
 #| msgid "Suppress warnings"
 msgid "Suppress warnings."
 msgstr "Undertryk advarsler"
 
-#: common.opt:3151
+#: common.opt:3155
 #, fuzzy
 #| msgid "Create a shared library"
 msgid "Create a shared library."
 msgstr "Opret et delt bibliotek"
 
-#: common.opt:3196
+#: common.opt:3200
 #, fuzzy
 #| msgid "Create a position independent executable"
 msgid "Don't create a dynamically linked position independent executable."
 msgstr "Opret en placeringsuafhængig kørbar fil"
 
-#: common.opt:3200
+#: common.opt:3204
 #, fuzzy
 #| msgid "Create a position independent executable"
 msgid "Create a dynamically linked position independent executable."
 msgstr "Opret en placeringsuafhængig kørbar fil"
 
-#: common.opt:3204
+#: common.opt:3208
 #, fuzzy
 #| msgid "Create a position independent executable"
 msgid "Create a static position independent executable."
 msgstr "Opret en placeringsuafhængig kørbar fil"
 
-#: common.opt:3211
+#: common.opt:3215
 msgid "Use caller save register across calls if possible."
 msgstr ""
 
-#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:598 cp/cvt.c:1308
+#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:599 cp/cvt.c:1308
 #: cp/cvt.c:1561
 #, gcc-internal-format
 msgid "value computed is not used"
@@ -18744,7 +18745,7 @@
 msgstr "forventet boolesk type"
 
 #: go/gofrontend/expressions.cc:4331 c/c-parser.c:13477 c/c-parser.c:13484
-#: cp/parser.c:33264 cp/parser.c:33271
+#: cp/parser.c:33261 cp/parser.c:33268
 #, fuzzy, gcc-internal-format
 msgid "expected integer"
 msgstr "uventet operand"
@@ -19218,8 +19219,8 @@
 msgid "ignoring attribute %qE because it conflicts with attribute %qs"
 msgstr "dataområdet '%s' er i modstrid med tidligere erklæring"
 
-#: attribs.c:449 c-family/c-attribs.c:1894 cp/decl.c:13690 cp/friend.c:302
-#: cp/tree.c:4559
+#: attribs.c:449 c-family/c-attribs.c:1905 cp/decl.c:13714 cp/friend.c:302
+#: cp/tree.c:4607
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration `%#D' here"
 msgid "previous declaration here"
@@ -19226,7 +19227,7 @@
 msgstr "tidligere erklæring af '%#D' her"
 
 #. Warn about and ignore all others for now, but store them.
-#: attribs.c:564 c-family/c-attribs.c:2717 objc/objc-act.c:4963
+#: attribs.c:564 c-family/c-attribs.c:2728 objc/objc-act.c:4963
 #: objc/objc-act.c:6932 objc/objc-act.c:8119 objc/objc-act.c:8170
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute directive ignored"
@@ -19248,18 +19249,18 @@
 #. This is a c++11 attribute that appertains to a
 #. type-specifier, outside of the definition of, a class
 #. type.  Ignore it.
-#: attribs.c:590 cp/decl.c:10999
+#: attribs.c:590 cp/decl.c:11023
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored"
 msgid "attribute ignored"
 msgstr "egenskaben '%s' ignoreret"
 
-#: attribs.c:592 cp/decl.c:11000
+#: attribs.c:592 cp/decl.c:11024
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
 
-#: attribs.c:610 c-family/c-attribs.c:3219
+#: attribs.c:610 c-family/c-attribs.c:3230
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute does not apply to types"
 msgid "%qE attribute does not apply to types"
@@ -19277,40 +19278,40 @@
 msgstr "egenskaben '%s' kan kun anvendes med klassedefinitioner"
 
 #: attribs.c:691 attribs.c:1622 attribs.c:1632 attribs.c:1642
-#: c-family/c-attribs.c:540 c-family/c-attribs.c:559 c-family/c-attribs.c:577
-#: c-family/c-attribs.c:607 c-family/c-attribs.c:628 c-family/c-attribs.c:649
-#: c-family/c-attribs.c:690 c-family/c-attribs.c:717 c-family/c-attribs.c:733
-#: c-family/c-attribs.c:750 c-family/c-attribs.c:766 c-family/c-attribs.c:792
-#: c-family/c-attribs.c:807 c-family/c-attribs.c:835 c-family/c-attribs.c:852
-#: c-family/c-attribs.c:870 c-family/c-attribs.c:893 c-family/c-attribs.c:931
-#: c-family/c-attribs.c:954 c-family/c-attribs.c:971 c-family/c-attribs.c:1000
-#: c-family/c-attribs.c:1021 c-family/c-attribs.c:1042
-#: c-family/c-attribs.c:1069 c-family/c-attribs.c:1099
-#: c-family/c-attribs.c:1136 c-family/c-attribs.c:1189
-#: c-family/c-attribs.c:1255 c-family/c-attribs.c:1313
-#: c-family/c-attribs.c:1402 c-family/c-attribs.c:1432
-#: c-family/c-attribs.c:1483 c-family/c-attribs.c:1998
-#: c-family/c-attribs.c:2035 c-family/c-attribs.c:2096
-#: c-family/c-attribs.c:2152 c-family/c-attribs.c:2230
-#: c-family/c-attribs.c:2312 c-family/c-attribs.c:2371
-#: c-family/c-attribs.c:2390 c-family/c-attribs.c:2498
-#: c-family/c-attribs.c:2514 c-family/c-attribs.c:2530
-#: c-family/c-attribs.c:2551 c-family/c-attribs.c:2608
-#: c-family/c-attribs.c:2635 c-family/c-attribs.c:2690
-#: c-family/c-attribs.c:2870 c-family/c-attribs.c:2891
-#: c-family/c-attribs.c:3004 c-family/c-attribs.c:3031
-#: c-family/c-attribs.c:3221 c-family/c-attribs.c:3239
-#: c-family/c-attribs.c:3262 c-family/c-attribs.c:3301
-#: c-family/c-attribs.c:3383 c-family/c-attribs.c:3439
-#: c-family/c-attribs.c:3455 c-family/c-attribs.c:3549
-#: c-family/c-common.c:5600 config/darwin.c:2072 config/arm/arm.c:6868
+#: c-family/c-attribs.c:547 c-family/c-attribs.c:566 c-family/c-attribs.c:584
+#: c-family/c-attribs.c:614 c-family/c-attribs.c:635 c-family/c-attribs.c:656
+#: c-family/c-attribs.c:697 c-family/c-attribs.c:728 c-family/c-attribs.c:744
+#: c-family/c-attribs.c:761 c-family/c-attribs.c:777 c-family/c-attribs.c:803
+#: c-family/c-attribs.c:818 c-family/c-attribs.c:846 c-family/c-attribs.c:863
+#: c-family/c-attribs.c:881 c-family/c-attribs.c:904 c-family/c-attribs.c:942
+#: c-family/c-attribs.c:965 c-family/c-attribs.c:982 c-family/c-attribs.c:1011
+#: c-family/c-attribs.c:1032 c-family/c-attribs.c:1053
+#: c-family/c-attribs.c:1080 c-family/c-attribs.c:1110
+#: c-family/c-attribs.c:1147 c-family/c-attribs.c:1200
+#: c-family/c-attribs.c:1266 c-family/c-attribs.c:1324
+#: c-family/c-attribs.c:1413 c-family/c-attribs.c:1443
+#: c-family/c-attribs.c:1494 c-family/c-attribs.c:2009
+#: c-family/c-attribs.c:2046 c-family/c-attribs.c:2107
+#: c-family/c-attribs.c:2163 c-family/c-attribs.c:2241
+#: c-family/c-attribs.c:2323 c-family/c-attribs.c:2382
+#: c-family/c-attribs.c:2401 c-family/c-attribs.c:2509
+#: c-family/c-attribs.c:2525 c-family/c-attribs.c:2541
+#: c-family/c-attribs.c:2562 c-family/c-attribs.c:2619
+#: c-family/c-attribs.c:2646 c-family/c-attribs.c:2701
+#: c-family/c-attribs.c:2881 c-family/c-attribs.c:2902
+#: c-family/c-attribs.c:3015 c-family/c-attribs.c:3042
+#: c-family/c-attribs.c:3232 c-family/c-attribs.c:3250
+#: c-family/c-attribs.c:3273 c-family/c-attribs.c:3312
+#: c-family/c-attribs.c:3394 c-family/c-attribs.c:3450
+#: c-family/c-attribs.c:3466 c-family/c-attribs.c:3560
+#: c-family/c-common.c:5598 config/darwin.c:2072 config/arm/arm.c:6868
 #: config/arm/arm.c:6896 config/arm/arm.c:6913 config/avr/avr.c:9698
-#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6497
-#: config/i386/i386.c:41520 config/ia64/ia64.c:788
-#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33056
-#: config/spu/spu.c:3743 ada/gcc-interface/utils.c:6244
-#: ada/gcc-interface/utils.c:6261 ada/gcc-interface/utils.c:6277
-#: ada/gcc-interface/utils.c:6303 brig/brig-lang.c:476 lto/lto-lang.c:283
+#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6500
+#: config/i386/i386.c:41514 config/ia64/ia64.c:788
+#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33112
+#: config/spu/spu.c:3743 ada/gcc-interface/utils.c:6249
+#: ada/gcc-interface/utils.c:6266 ada/gcc-interface/utils.c:6282
+#: ada/gcc-interface/utils.c:6308 brig/brig-lang.c:476 lto/lto-lang.c:283
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored"
 msgid "%qE attribute ignored"
@@ -19715,98 +19716,117 @@
 msgid "%Kattempt to free a non-heap object"
 msgstr ""
 
-#: calls.c:1434
+#: calls.c:1291 file-prefix-map.c:50
 #, fuzzy, gcc-internal-format
+#| msgid "invalid type argument"
+msgid "invalid argument %qs to %qs"
+msgstr "ugyldig typeparameter"
+
+#: calls.c:1452
+#, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "%Kargument %i value %qE is negative"
 msgstr "højreskiftsantal er negativ"
 
-#: calls.c:1452
+#: calls.c:1470
 #, fuzzy, gcc-internal-format
 #| msgid "argument is a structure"
 msgid "%Kargument %i value is zero"
 msgstr "parameter er en struktur"
 
-#: calls.c:1469
+#: calls.c:1487
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "%Kargument %i value %qE exceeds maximum object size %E"
 msgstr "højreskiftsantal er negativ"
 
-#: calls.c:1483
+#: calls.c:1501
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "%Kargument %i range [%E, %E] is negative"
 msgstr "højreskiftsantal er negativ"
 
-#: calls.c:1490
+#: calls.c:1508
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "%Kargument %i range [%E, %E] exceeds maximum object size %E"
 msgstr "højreskiftsantal er negativ"
 
-#: calls.c:1520
+#: calls.c:1538
 #, gcc-internal-format
 msgid "%Kproduct %<%E * %E%> of arguments %i and %i exceeds %<SIZE_MAX%>"
 msgstr ""
 
-#: calls.c:1526
+#: calls.c:1544
 #, gcc-internal-format
 msgid "%Kproduct %<%E * %E%> of arguments %i and %i exceeds maximum object size %E"
 msgstr ""
 
-#: calls.c:1537 calls.c:1540
+#: calls.c:1555 calls.c:1558
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "argument %i in the range [%E, %E]"
 msgstr "3. parameter skal være en 4 bit-konstant uden fortegn"
 
-#: calls.c:1551
+#: calls.c:1569
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function `%D'"
 msgid "in a call to built-in allocation function %qD"
 msgstr "kald af ikke-funktion '%D'"
 
-#: calls.c:1554
+#: calls.c:1572
 #, fuzzy, gcc-internal-format
 msgid "in a call to allocation function %qD declared here"
 msgstr "Ugyldig erklæring"
 
-#: calls.c:1711
-#, gcc-internal-format
-msgid "%qD argument %i declared attribute %<nonstring%> is smaller than the specified bound %E"
-msgstr ""
+#: calls.c:1835
+#, fuzzy, gcc-internal-format
+#| msgid "`%D' was not declared in this scope"
+msgid "%qD argument %i declared attribute %<nonstring%> is smaller than the specified bound %wu"
+msgstr "'%D' blev ikke erklæret i dette virkefelt"
 
-#: calls.c:1716
+#: calls.c:1841
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' was not declared in this scope"
+msgid "%qD argument %i declared attribute %<nonstring%> is smaller than the specified bound [%E, %E]"
+msgstr "'%D' blev ikke erklæret i dette virkefelt"
+
+#: calls.c:1847
+#, fuzzy, gcc-internal-format
+#| msgid "`%D' was not declared in this scope"
+msgid "%qD argument %i declared attribute %<nonstring%> may be smaller than the specified bound [%E, %E]"
+msgstr "'%D' blev ikke erklæret i dette virkefelt"
+
+#: calls.c:1857
+#, fuzzy, gcc-internal-format
+#| msgid "`%D' was not declared in this scope"
 msgid "%qD argument %i declared attribute %<nonstring%>"
 msgstr "'%D' blev ikke erklæret i dette virkefelt"
 
-#: calls.c:1721
+#: calls.c:1862
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "argument %qD declared here"
 msgstr "  '%#D' erklæret her"
 
-#: calls.c:1735
+#: calls.c:1876
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "[cannot find %s]"
 msgid "cannot tail-call: %s"
 msgstr "[kan ikke finde %s]"
 
-#: calls.c:3365
+#: calls.c:3506
 #, gcc-internal-format
 msgid "function call has aggregate value"
 msgstr "funktionskald har en sammensat værdi"
 
-#: calls.c:4059
+#: calls.c:4200
 #, fuzzy, gcc-internal-format
 #| msgid "Pass all arguments on stack"
 msgid "passing too large argument on stack"
 msgstr "Overbring alle parametre på stakken"
 
-#: cfgexpand.c:1665 function.c:1002 varasm.c:2231
+#: cfgexpand.c:1665 function.c:1002 varasm.c:2242
 #, fuzzy, gcc-internal-format
 msgid "size of variable %q+D is too large"
 msgstr "størrelsen af variablen '%s' er for stor"
@@ -20435,246 +20455,246 @@
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr "antallet af basisbloknoter i instruktionskæden (%d) != n_basic_blocks (%d)"
 
-#: cgraph.c:3051
+#: cgraph.c:3056
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count is negative"
 msgid "caller edge count invalid"
 msgstr "venstreskiftsantal er negativ"
 
-#: cgraph.c:3135
+#: cgraph.c:3140
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr ""
 
-#: cgraph.c:3142
+#: cgraph.c:3147
 #, gcc-internal-format
 msgid "cgraph count invalid"
 msgstr ""
 
-#: cgraph.c:3147
+#: cgraph.c:3152
 #, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr ""
 
-#: cgraph.c:3152
+#: cgraph.c:3157
 #, fuzzy, gcc-internal-format
 #| msgid "no symbol table found"
 msgid "local symbols must be defined"
 msgstr "ingen symboltabel fundet"
 
-#: cgraph.c:3157
+#: cgraph.c:3162
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr ""
 
-#: cgraph.c:3162
+#: cgraph.c:3167
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr ""
 
-#: cgraph.c:3167
+#: cgraph.c:3172
 #, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr ""
 
-#: cgraph.c:3174
+#: cgraph.c:3179
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for indirect edge from %s"
 msgstr ""
 
-#: cgraph.c:3181
+#: cgraph.c:3186
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr ""
 
-#: cgraph.c:3196
+#: cgraph.c:3201
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr ""
 
-#: cgraph.c:3206
+#: cgraph.c:3211
 #, fuzzy, gcc-internal-format
 #| msgid "section pointer missing"
 msgid "inlined_to pointer is wrong"
 msgstr "sektionshenvisning mangler"
 
-#: cgraph.c:3211
+#: cgraph.c:3216
 #, fuzzy, gcc-internal-format
 #| msgid "multiple `virtual' specifiers"
 msgid "multiple inline callers"
 msgstr "mere end én 'virtual'-angivelse"
 
-#: cgraph.c:3218
+#: cgraph.c:3223
 #, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr ""
 
-#: cgraph.c:3239
+#: cgraph.c:3244
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count is negative"
 msgid "caller edge count does not match BB count"
 msgstr "venstreskiftsantal er negativ"
 
-#: cgraph.c:3261
+#: cgraph.c:3266
 #, gcc-internal-format
 msgid "indirect call count does not match BB count"
 msgstr ""
 
-#: cgraph.c:3272
+#: cgraph.c:3277
 #, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr ""
 
-#: cgraph.c:3277
+#: cgraph.c:3282
 #, fuzzy, gcc-internal-format
 #| msgid "invalid pointer to bit-field `%D'"
 msgid "inlined_to pointer refers to itself"
 msgstr "ugyldig henvisning til bitfeltet '%D'"
 
-#: cgraph.c:3289
+#: cgraph.c:3294
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr ""
 
-#: cgraph.c:3301
+#: cgraph.c:3306
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr ""
 
-#: cgraph.c:3307
+#: cgraph.c:3312
 #, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr ""
 
-#: cgraph.c:3312
+#: cgraph.c:3317
 #, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr ""
 
-#: cgraph.c:3317
+#: cgraph.c:3322
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr ""
 
-#: cgraph.c:3329
+#: cgraph.c:3334
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr ""
 
-#: cgraph.c:3337
+#: cgraph.c:3342
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr ""
 
-#: cgraph.c:3342
+#: cgraph.c:3347
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr ""
 
-#: cgraph.c:3349
+#: cgraph.c:3354
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr ""
 
-#: cgraph.c:3358
+#: cgraph.c:3363
 #, gcc-internal-format
 msgid "Instrumentation clone does not reference original node"
 msgstr ""
 
-#: cgraph.c:3365
+#: cgraph.c:3370
 #, gcc-internal-format
 msgid "Not instrumented node has non-NULL original declaration"
 msgstr ""
 
-#: cgraph.c:3375
+#: cgraph.c:3380
 #, gcc-internal-format
 msgid "Instrumented node has wrong original declaration"
 msgstr ""
 
-#: cgraph.c:3393
+#: cgraph.c:3398
 #, gcc-internal-format
 msgid "Node has more than one chkp reference"
 msgstr ""
 
-#: cgraph.c:3398
+#: cgraph.c:3403
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare references to references"
 msgid "Wrong node is referenced with chkp reference"
 msgstr "kan ikke erklære referencer til referencer"
 
-#: cgraph.c:3406
+#: cgraph.c:3411
 #, gcc-internal-format
 msgid "Analyzed node has no reference to instrumented version"
 msgstr ""
 
-#: cgraph.c:3420
+#: cgraph.c:3425
 #, gcc-internal-format
 msgid "Alias chain for instrumented node is broken"
 msgstr ""
 
-#: cgraph.c:3429
+#: cgraph.c:3434
 #, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3434
+#: cgraph.c:3439
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3439
+#: cgraph.c:3444
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr ""
 
-#: cgraph.c:3445
+#: cgraph.c:3450
 #, gcc-internal-format
 msgid "Instrumentation thunk has wrong edge callee"
 msgstr ""
 
-#: cgraph.c:3481
+#: cgraph.c:3486
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr ""
 
-#: cgraph.c:3489
+#: cgraph.c:3494
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' used prior to declaration"
 msgid "edge points to wrong declaration:"
 msgstr "'%s' benyttes før erklæringen"
 
-#: cgraph.c:3498
+#: cgraph.c:3503
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr ""
 
-#: cgraph.c:3508
+#: cgraph.c:3513
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr ""
 
-#: cgraph.c:3518
+#: cgraph.c:3523
 #, gcc-internal-format
 msgid "reference to dead statement"
 msgstr ""
 
-#: cgraph.c:3531
+#: cgraph.c:3536
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3543
+#: cgraph.c:3548
 #, gcc-internal-format, gfc-internal-format
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3554
+#: cgraph.c:3559
 #, fuzzy, gcc-internal-format
 #| msgid "verify_flow_info failed"
 msgid "verify_cgraph_node failed"
 msgstr "verify_flow_info mislykkedes"
 
-#: cgraph.c:3661 varpool.c:306
+#: cgraph.c:3666 varpool.c:306
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "string section missing"
 msgid "%s: section %s is missing"
@@ -20708,12 +20728,12 @@
 msgstr ""
 
 #. include_self=
-#: cgraphunit.c:981 c/c-decl.c:11282
+#: cgraphunit.c:981 c/c-decl.c:11302
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F brugt, men aldrig defineret"
 
-#: cgraphunit.c:983 c/c-decl.c:11291
+#: cgraphunit.c:983 c/c-decl.c:11311
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "%q+F erklæret %<static%>, men aldrig defineret"
@@ -20842,12 +20862,12 @@
 msgid "cannot find '%s'"
 msgstr "kan ikke finde '%s'"
 
-#: collect-utils.c:183 collect2.c:2361 collect2.c:2560 gcc.c:3080 gcc.c:6856
+#: collect-utils.c:183 collect2.c:2387 collect2.c:2586 gcc.c:3080 gcc.c:6856
 #, fuzzy, gcc-internal-format
 msgid "pex_init failed: %m"
 msgstr "åbner uddatafilen %s"
 
-#: collect-utils.c:192 collect2.c:2370 collect2.c:2568 gcc.c:8498
+#: collect-utils.c:192 collect2.c:2396 collect2.c:2594 gcc.c:8498
 #, fuzzy, gcc-internal-format
 #| msgid "%s: %s"
 msgid "%s: %m"
@@ -20858,100 +20878,100 @@
 msgid "COLLECT_LTO_WRAPPER must be set"
 msgstr ""
 
-#: collect2.c:966 gcc.c:7382 lto-wrapper.c:1666
+#: collect2.c:969 gcc.c:7382 lto-wrapper.c:1692
 #: config/i386/intelmic-mkoffload.c:556 config/nvptx/mkoffload.c:405
 #, gcc-internal-format
 msgid "atexit failed"
 msgstr ""
 
-#: collect2.c:1064
+#: collect2.c:1067
 #, gcc-internal-format
 msgid "no arguments"
 msgstr "ingen parametre"
 
-#: collect2.c:1303 opts.c:904
+#: collect2.c:1311 opts.c:904
 #, fuzzy, gcc-internal-format
 msgid "LTO support has not been enabled in this configuration"
 msgstr "%s understøttes ikke af denne konfiguration"
 
-#: collect2.c:1344
+#: collect2.c:1352
 #, gcc-internal-format
 msgid "can't open %s: %m"
 msgstr "kan ikke åbne %s: %m"
 
-#: collect2.c:1450
+#: collect2.c:1472
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unknown machine mode `%s'"
 msgid "unknown demangling style '%s'"
 msgstr "ukendt maskintilstand '%s'"
 
-#: collect2.c:1546 collect2.c:1729 collect2.c:1769
+#: collect2.c:1574 collect2.c:1757 collect2.c:1797
 #, fuzzy, gcc-internal-format
 #| msgid "fopen %s"
 msgid "fopen %s: %m"
 msgstr "fopen %s"
 
-#: collect2.c:1549 collect2.c:1734 collect2.c:1772
+#: collect2.c:1577 collect2.c:1762 collect2.c:1800
 #, fuzzy, gcc-internal-format
 #| msgid "fclose %s"
 msgid "fclose %s: %m"
 msgstr "fclose %s"
 
-#: collect2.c:2335
+#: collect2.c:2361
 #, fuzzy, gcc-internal-format
 #| msgid "cannot find `nm'"
 msgid "cannot find 'nm'"
 msgstr "kan ikke finde 'nm'"
 
-#: collect2.c:2383
+#: collect2.c:2409
 #, fuzzy, gcc-internal-format
 #| msgid "can't open output file `%s'"
 msgid "can't open nm output: %m"
 msgstr "kan ikke åbne uddatafilen '%s'"
 
-#: collect2.c:2467
+#: collect2.c:2493
 #, gcc-internal-format, gfc-internal-format
 msgid "init function found in object %s"
 msgstr "klargøringsfunktion fundet i objekt %s"
 
-#: collect2.c:2478
+#: collect2.c:2504
 #, gcc-internal-format, gfc-internal-format
 msgid "fini function found in object %s"
 msgstr "afslutningsfunktion fundet i objekt %s"
 
-#: collect2.c:2535
+#: collect2.c:2561
 #, fuzzy, gcc-internal-format
 #| msgid "cannot find `ldd'"
 msgid "cannot find 'ldd'"
 msgstr "kan ikke finde 'ldd'"
 
-#: collect2.c:2581
+#: collect2.c:2607
 #, fuzzy, gcc-internal-format
 #| msgid "can't open output file `%s'"
 msgid "can't open ldd output: %m"
 msgstr "kan ikke åbne uddatafilen '%s'"
 
-#: collect2.c:2599
+#: collect2.c:2625
 #, gcc-internal-format, gfc-internal-format
 msgid "dynamic dependency %s not found"
 msgstr "dynamisk afhængighed %s ikke fundet"
 
-#: collect2.c:2611
+#: collect2.c:2637
 #, gcc-internal-format, gfc-internal-format
 msgid "unable to open dynamic dependency '%s'"
 msgstr "kan ikke åbne den dynamiske afhængighed '%s'"
 
-#: collect2.c:2765
+#: collect2.c:2791
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: not a COFF file"
 msgstr "%s: ikke en COFF-fil"
 
-#: collect2.c:2930
+#: collect2.c:2961
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: cannot open as COFF file"
 msgstr "%s: kan ikke åbnes som en COFF-fil"
 
-#: collect2.c:2989
+#: collect2.c:3020
 #, gcc-internal-format, gfc-internal-format
 msgid "library lib%s not found"
 msgstr "biblioteket lib%s ikke fundet"
@@ -21172,12 +21192,12 @@
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr ""
 
-#: dwarf2out.c:10901
+#: dwarf2out.c:10909
 #, gcc-internal-format
 msgid "-gdwarf-6 is output as version 5 with incompatibilities"
 msgstr ""
 
-#: dwarf2out.c:14415
+#: dwarf2out.c:14423
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
@@ -21303,12 +21323,6 @@
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr "funktionen '%s' omerklæret med egenskaben noinline"
 
-#: file-prefix-map.c:50
-#, fuzzy, gcc-internal-format
-#| msgid "invalid type argument"
-msgid "invalid argument %qs to %qs"
-msgstr "ugyldig typeparameter"
-
 #: final.c:1868
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsize of '%D' is larger than %d bytes"
@@ -21333,45 +21347,45 @@
 msgid "large fixed-point constant implicitly truncated to fixed-point type"
 msgstr "stort heltal forkortes underforstået til type uden fortegn"
 
-#: fold-const.c:4151 fold-const.c:4161
+#: fold-const.c:4157 fold-const.c:4167
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d due to width of bit-field"
 msgstr "sammenligning er altid %d på grund af den begrænsede rækkevidde af bitfeltet"
 
-#: fold-const.c:5478 tree-ssa-reassoc.c:2374 tree-ssa-reassoc.c:3214
+#: fold-const.c:5484 tree-ssa-reassoc.c:2379 tree-ssa-reassoc.c:3219
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
 
-#: fold-const.c:5928 fold-const.c:5942
+#: fold-const.c:5934 fold-const.c:5948
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr "sammenligning er altid %d"
 
 # RETMIG: det giver ikke mening
-#: fold-const.c:6085
+#: fold-const.c:6091
 #, fuzzy, gcc-internal-format
 #| msgid "`or' of unmatched not-equal tests is always 1"
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr "'or' af uafbalancerede sammenligninger med forskellig fra er altid 1"
 
-#: fold-const.c:6090
+#: fold-const.c:6096
 #, fuzzy, gcc-internal-format
 #| msgid "`and' of mutually exclusive equal-tests is always 0"
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr "'and' af udtryk der hver for sig udelukker hinanden, er altid 0"
 
-#: fold-const.c:8310
+#: fold-const.c:8316
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr ""
 
-#: fold-const.c:8710
+#: fold-const.c:8716
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr ""
 
-#: fold-const.c:12063
+#: fold-const.c:12069
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr ""
@@ -21382,7 +21396,7 @@
 msgid "total size of local objects too large"
 msgstr "størrelsen af tabellen '%s' er for stor"
 
-#: function.c:1776 gimplify.c:6270
+#: function.c:1776 gimplify.c:6273
 #, fuzzy, gcc-internal-format
 #| msgid "impossible constraint in `asm'"
 msgid "impossible constraint in %<asm%>"
@@ -21707,7 +21721,7 @@
 msgid "%s: linker input file unused because linking not done"
 msgstr "%s: sammenkæderinddatafil ikke benyttet eftersom sammenkædning ikke blev foretaget"
 
-#: gcc.c:8420 c-family/c-opts.c:770
+#: gcc.c:8420 c-family/c-opts.c:768
 #, gcc-internal-format
 msgid "cannot use %<-%> as input filename for a precompiled header"
 msgstr ""
@@ -21956,7 +21970,7 @@
 msgid "%G%qD destination unchanged after copying no bytes"
 msgstr ""
 
-#: gimple-fold.c:2052 tree-ssa-strlen.c:2050
+#: gimple-fold.c:2052 tree-ssa-strlen.c:2074
 msgid "%G%qD specified bound %E equals destination size"
 msgstr ""
 
@@ -21980,12 +21994,12 @@
 msgid "null pointer dereference"
 msgstr "henvisning"
 
-#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12451
-#: tree.c:12488 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10147
-#: c/c-typeck.c:10164 c/gimple-parser.c:1616 c/gimple-parser.c:1624
+#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12455
+#: tree.c:12492 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10152
+#: c/c-typeck.c:10169 c/gimple-parser.c:1616 c/gimple-parser.c:1624
 #: cp/call.c:6493 cp/call.c:8098 cp/constexpr.c:820 cp/constexpr.c:2309
-#: cp/cvt.c:1015 cp/cvt.c:1042 cp/decl.c:7334 cp/decl2.c:5256 cp/pt.c:8334
-#: cp/semantics.c:1836 cp/semantics.c:4053 cp/typeck.c:1700 cp/typeck.c:1895
+#: cp/cvt.c:1015 cp/cvt.c:1042 cp/decl.c:7355 cp/decl2.c:5246 cp/pt.c:8348
+#: cp/semantics.c:1836 cp/semantics.c:4056 cp/typeck.c:1700 cp/typeck.c:1895
 #: cp/typeck.c:3837
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
@@ -21997,27 +22011,27 @@
 msgid "nonnull argument %qD compared to NULL"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2517 gimple-ssa-sprintf.c:2637
+#: gimple-ssa-sprintf.c:2555 gimple-ssa-sprintf.c:2675
 #, gcc-internal-format
 msgid "%qE output may be truncated before the last format character"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2519 gimple-ssa-sprintf.c:2639
+#: gimple-ssa-sprintf.c:2557 gimple-ssa-sprintf.c:2677
 #, gcc-internal-format
 msgid "%qE output truncated before the last format character"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2522 gimple-ssa-sprintf.c:2642
+#: gimple-ssa-sprintf.c:2560 gimple-ssa-sprintf.c:2680
 #, gcc-internal-format
 msgid "%qE may write a terminating nul past the end of the destination"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2524 gimple-ssa-sprintf.c:2644
+#: gimple-ssa-sprintf.c:2562 gimple-ssa-sprintf.c:2682
 #, gcc-internal-format
 msgid "%qE writing a terminating nul past the end of the destination"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2534
+#: gimple-ssa-sprintf.c:2572
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size %wu"
@@ -22024,7 +22038,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.c:2541
+#: gimple-ssa-sprintf.c:2579
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size %wu"
@@ -22031,7 +22045,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.c:2548
+#: gimple-ssa-sprintf.c:2586
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size %wu"
@@ -22038,67 +22052,67 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.c:2559
+#: gimple-ssa-sprintf.c:2597
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2562
+#: gimple-ssa-sprintf.c:2600
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2564
+#: gimple-ssa-sprintf.c:2602
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2576
+#: gimple-ssa-sprintf.c:2614
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2579
+#: gimple-ssa-sprintf.c:2617
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2582
+#: gimple-ssa-sprintf.c:2620
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2591
+#: gimple-ssa-sprintf.c:2629
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2594
+#: gimple-ssa-sprintf.c:2632
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2597
+#: gimple-ssa-sprintf.c:2635
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2606
+#: gimple-ssa-sprintf.c:2644
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2609
+#: gimple-ssa-sprintf.c:2647
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2611
+#: gimple-ssa-sprintf.c:2649
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2653
+#: gimple-ssa-sprintf.c:2691
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size between %wu and %wu"
@@ -22105,7 +22119,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.c:2660
+#: gimple-ssa-sprintf.c:2698
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size between %wu and %wu"
@@ -22112,7 +22126,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.c:2668
+#: gimple-ssa-sprintf.c:2706
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size between %wu and %wu"
@@ -22119,103 +22133,103 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.c:2680
+#: gimple-ssa-sprintf.c:2718
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2683
+#: gimple-ssa-sprintf.c:2721
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2686
+#: gimple-ssa-sprintf.c:2724
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2699
+#: gimple-ssa-sprintf.c:2737
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2702
+#: gimple-ssa-sprintf.c:2740
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2705
+#: gimple-ssa-sprintf.c:2743
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2715
+#: gimple-ssa-sprintf.c:2753
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2718
+#: gimple-ssa-sprintf.c:2756
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2721
+#: gimple-ssa-sprintf.c:2759
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2730
+#: gimple-ssa-sprintf.c:2768
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2733
+#: gimple-ssa-sprintf.c:2771
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2736
+#: gimple-ssa-sprintf.c:2774
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2825
+#: gimple-ssa-sprintf.c:2863
 #, fuzzy, gcc-internal-format
 #| msgid "wrong type argument to %s"
 msgid "%<%.*s%> directive argument is null"
 msgstr "forkert parametertype til %s"
 
-#: gimple-ssa-sprintf.c:2890
+#: gimple-ssa-sprintf.c:2928
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes exceeds minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2897
+#: gimple-ssa-sprintf.c:2935
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may exceed minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2900
+#: gimple-ssa-sprintf.c:2938
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes exceeds minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2929
+#: gimple-ssa-sprintf.c:2967
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2936
+#: gimple-ssa-sprintf.c:2974
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2939
+#: gimple-ssa-sprintf.c:2977
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may cause result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2949
+#: gimple-ssa-sprintf.c:2987
 #, gcc-internal-format
 msgid "assuming directive output of %wu byte"
 msgid_plural "assuming directive output of %wu bytes"
@@ -22222,80 +22236,80 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.c:2956
+#: gimple-ssa-sprintf.c:2994
 #, fuzzy, gcc-internal-format
 #| msgid "wrong type argument to %s"
 msgid "directive argument %qE"
 msgstr "forkert parametertype til %s"
 
-#: gimple-ssa-sprintf.c:2958
+#: gimple-ssa-sprintf.c:2996
 #, fuzzy, gcc-internal-format
 #| msgid "disable pass %s for functions in the range of [%u, %u]"
 msgid "directive argument in the range [%E, %E]"
 msgstr "deaktiver videregivelse %s for funktioner i intervallet [%u, %u]"
 
-#: gimple-ssa-sprintf.c:2962
+#: gimple-ssa-sprintf.c:3000
 #, gcc-internal-format
 msgid "using the range [%E, %E] for directive argument"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2982
+#: gimple-ssa-sprintf.c:3020
 #, gcc-internal-format
 msgid "%qE output %wu byte into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2983
+#: gimple-ssa-sprintf.c:3021
 #, gcc-internal-format
 msgid "%qE output %wu bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2987
+#: gimple-ssa-sprintf.c:3025
 #, gcc-internal-format
 msgid "%qE output between %wu and %wu bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2992
+#: gimple-ssa-sprintf.c:3030
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes (assuming %wu) into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2997
+#: gimple-ssa-sprintf.c:3035
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3368
+#: gimple-ssa-sprintf.c:3406
 #, gcc-internal-format
 msgid "%<%.*s%> directive width out of range"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3402
+#: gimple-ssa-sprintf.c:3440
 #, gcc-internal-format
 msgid "%<%.*s%> directive precision out of range"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3893
+#: gimple-ssa-sprintf.c:3931
 #, gcc-internal-format
 msgid "specified bound %wu exceeds maximum object size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3899
+#: gimple-ssa-sprintf.c:3937
 #, gcc-internal-format
 msgid "specified bound %wu exceeds %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3949
+#: gimple-ssa-sprintf.c:3987
 #, fuzzy, gcc-internal-format
 #| msgid "pointer"
 msgid "null destination pointer"
 msgstr "henvisning"
 
-#: gimple-ssa-sprintf.c:3966
+#: gimple-ssa-sprintf.c:4004
 #, gcc-internal-format
 msgid "specified bound %wu exceeds the size %wu of the destination object"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3978
+#: gimple-ssa-sprintf.c:4016
 #, fuzzy, gcc-internal-format
 #| msgid "null format string"
 msgid "null format string"
@@ -22522,10 +22536,10 @@
 msgstr "tabelindeks er ikke et heltal"
 
 #: gimple-ssa-warn-restrict.c:1678 c/c-decl.c:3603 c/c-decl.c:3874
-#: c/c-typeck.c:8345 cp/class.c:1346 cp/class.c:3098 cp/decl.c:3979
-#: cp/decl.c:10753 cp/decl.c:11151 cp/decl.c:11160 cp/friend.c:384
+#: c/c-typeck.c:8350 cp/class.c:1346 cp/class.c:3102 cp/decl.c:3979
+#: cp/decl.c:10777 cp/decl.c:11175 cp/decl.c:11184 cp/friend.c:384
 #: cp/friend.c:393 cp/parser.c:3275 cp/parser.c:3372 cp/parser.c:3422
-#: cp/parser.c:6327 cp/parser.c:21027
+#: cp/parser.c:6330 cp/parser.c:21024
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "%qD declared here"
@@ -22602,235 +22616,235 @@
 msgid "using result of function returning %<void%>"
 msgstr "ingen return-sætning i en funktion der ikke returnerer void"
 
-#: gimplify.c:6128
+#: gimplify.c:6131
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid lvalue in asm statement"
 msgid "invalid lvalue in asm output %d"
 msgstr "ugyldig venstreværdi i asm-sætning"
 
-#: gimplify.c:6271
+#: gimplify.c:6274
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr ""
 
-#: gimplify.c:6311 gimplify.c:6320
+#: gimplify.c:6314 gimplify.c:6323
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "output number %d not directly addressable"
 msgid "memory input %d is not directly addressable"
 msgstr "uddata nr. %d kan ikke adresseres direkte"
 
-#: gimplify.c:6928
+#: gimplify.c:6931
 #, fuzzy, gcc-internal-format
 #| msgid "register variable `%s' used in nested function"
 msgid "threadprivate variable %qE used in target region"
 msgstr "registervariabel '%s' benyttet i indlejret funktion"
 
-#: gimplify.c:6930
+#: gimplify.c:6933
 #, gcc-internal-format
 msgid "enclosing target region"
 msgstr ""
 
-#: gimplify.c:6942
+#: gimplify.c:6945
 #, fuzzy, gcc-internal-format
 #| msgid "register variable `%s' used in nested function"
 msgid "threadprivate variable %qE used in untied task"
 msgstr "registervariabel '%s' benyttet i indlejret funktion"
 
-#: gimplify.c:6944
+#: gimplify.c:6947
 #, gcc-internal-format
 msgid "enclosing task"
 msgstr ""
 
-#: gimplify.c:7016
+#: gimplify.c:7019
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' not declared"
 msgid "%qE not specified in enclosing %qs"
 msgstr "'%D' ikke erklæret"
 
-#: gimplify.c:7018
+#: gimplify.c:7021
 #, fuzzy, gcc-internal-format
 #| msgid "error closing %s: %m"
 msgid "enclosing %qs"
 msgstr "fejl ved lukning af %s: %m"
 
-#: gimplify.c:7143
+#: gimplify.c:7146
 #, gcc-internal-format
 msgid "%qE not specified in enclosing OpenACC %qs construct"
 msgstr ""
 
-#: gimplify.c:7145
+#: gimplify.c:7148
 #, fuzzy, gcc-internal-format
 #| msgid "In construct"
 msgid "enclosing OpenACC %qs construct"
 msgstr "I konstruktionen"
 
-#: gimplify.c:7198
+#: gimplify.c:7201
 #, gcc-internal-format
 msgid "%qE with %<link%> clause used in %<routine%> function"
 msgstr ""
 
-#: gimplify.c:7206
+#: gimplify.c:7209
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' undeclared (first use in this function)"
 msgid "%qE requires a %<declare%> directive for use in a %<routine%> function"
 msgstr "'%s' er ikke erklæret (først benyttet i denne funktion)"
 
-#: gimplify.c:7272 gimplify.c:7872
+#: gimplify.c:7275 gimplify.c:7875
 #, fuzzy, gcc-internal-format
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr "variablen '%s' er erklæret 'inline'"
 
-#: gimplify.c:7293
+#: gimplify.c:7296
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr ""
 
-#: gimplify.c:7411 gimplify.c:7443
+#: gimplify.c:7414 gimplify.c:7446
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable `%s' is declared private"
 msgid "iteration variable %qE is predetermined linear"
 msgstr "instansvariablen '%s' er erklæret privat"
 
-#: gimplify.c:7414
+#: gimplify.c:7417
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable `%s' is declared private"
 msgid "iteration variable %qE should be private"
 msgstr "instansvariablen '%s' er erklæret privat"
 
-#: gimplify.c:7428
+#: gimplify.c:7431
 #, gcc-internal-format
 msgid "iteration variable %qE should not be firstprivate"
 msgstr ""
 
-#: gimplify.c:7431
+#: gimplify.c:7434
 #, fuzzy, gcc-internal-format
 #| msgid "register variable `%s' used in nested function"
 msgid "iteration variable %qE should not be reduction"
 msgstr "registervariabel '%s' benyttet i indlejret funktion"
 
-#: gimplify.c:7434
+#: gimplify.c:7437
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable `%s' is declared private"
 msgid "iteration variable %qE should not be linear"
 msgstr "instansvariablen '%s' er erklæret privat"
 
-#: gimplify.c:7437
+#: gimplify.c:7440
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable `%s' is declared private"
 msgid "iteration variable %qE should not be lastprivate"
 msgstr "instansvariablen '%s' er erklæret privat"
 
-#: gimplify.c:7440
+#: gimplify.c:7443
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable `%s' is declared private"
 msgid "iteration variable %qE should not be private"
 msgstr "instansvariablen '%s' er erklæret privat"
 
-#: gimplify.c:7742
+#: gimplify.c:7745
 #, gcc-internal-format
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr ""
 
-#: gimplify.c:7949
+#: gimplify.c:7952
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr ""
 
-#: gimplify.c:8160
+#: gimplify.c:8163
 #, gcc-internal-format
 msgid "%qE appears more than once in map clauses"
 msgstr ""
 
-#: gimplify.c:8464
+#: gimplify.c:8467
 #, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr ""
 
-#: gimplify.c:8484
+#: gimplify.c:8487
 #, fuzzy, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr "'%D' blev ikke erklæret i dette virkefelt"
 
-#: gimplify.c:8510
+#: gimplify.c:8513
 #, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr ""
 
-#: gimplify.c:8775
+#: gimplify.c:8778
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr ""
 
-#: gimplify.c:8808
+#: gimplify.c:8811
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:9000
+#: gimplify.c:9003
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:9051
+#: gimplify.c:9054
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr ""
 
-#: gimplify.c:9133
+#: gimplify.c:9136
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to present_or_copy"
 msgstr ""
 
-#: gimplify.c:9278
+#: gimplify.c:9281
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member template declaration `%D'"
 msgid "invalid private reduction on %qE"
 msgstr "ugyldig medlemsskabelonerklæring '%D'"
 
-#: gimplify.c:11103 omp-low.c:2791
+#: gimplify.c:11106 omp-low.c:2791
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: gimplify.c:11121
+#: gimplify.c:11124
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr ""
 
-#: gimplify.c:11134
+#: gimplify.c:11137
 #, fuzzy, gcc-internal-format
 #| msgid "number of results does not match number of values"
 msgid "number of variables in %<depend(sink)%> clause does not match number of iteration variables"
 msgstr "antallet af resultater matcher ikke antallet af værdier"
 
-#: gimplify.c:11147
+#: gimplify.c:11150
 #, gcc-internal-format
 msgid "more than one %<depend(source)%> clause on an %<ordered%> construct"
 msgstr ""
 
-#: gimplify.c:11158
+#: gimplify.c:11161
 #, gcc-internal-format
 msgid "%<depend(source)%> clause specified together with %<depend(sink:)%> clauses on the same construct"
 msgstr ""
 
-#: gimplify.c:12393
+#: gimplify.c:12396
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr ""
 
-#: gimplify.c:12936
+#: gimplify.c:12939
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is promoted to `%s' when passed through `...'"
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr "'%s' forfremmes til '%s' ved overbringelse gennem '...'"
 
-#: gimplify.c:12941
+#: gimplify.c:12944
 #, fuzzy, gcc-internal-format
 #| msgid "(so you should pass `%s' not `%s' to `va_arg')"
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr "(så du skal overbring '%s' ikke '%s' til 'va_arg')"
 
-#: gimplify.c:12948
+#: gimplify.c:12951
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr ""
@@ -23339,48 +23353,48 @@
 msgid "Max. number of generated reload insns per insn is achieved (%d)\n"
 msgstr ""
 
-#: lto-cgraph.c:1294
+#: lto-cgraph.c:1296
 #, gcc-internal-format, gfc-internal-format
 msgid "bytecode stream: found multiple instances of cgraph node with uid %d"
 msgstr ""
 
-#: lto-cgraph.c:1472
+#: lto-cgraph.c:1474
 #, gcc-internal-format
 msgid "bytecode stream: no caller found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1478
+#: lto-cgraph.c:1480
 #, gcc-internal-format
 msgid "bytecode stream: no callee found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1552
+#: lto-cgraph.c:1554
 #, gcc-internal-format
 msgid "bytecode stream: found empty cgraph node"
 msgstr ""
 
-#: lto-cgraph.c:1730
+#: lto-cgraph.c:1732
 #, gcc-internal-format, gfc-internal-format
 msgid "At most %i profile runs is supported. Perhaps corrupted profile?"
 msgstr ""
 
-#: lto-cgraph.c:1817
+#: lto-cgraph.c:1819
 #, gcc-internal-format, gfc-internal-format
 msgid "Profile information in %s corrupted"
 msgstr ""
 
-#: lto-cgraph.c:1855
+#: lto-cgraph.c:1857
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot find class `%s'"
 msgid "cannot find LTO cgraph in %s"
 msgstr "kan ikke finde klassen '%s'"
 
-#: lto-cgraph.c:1865
+#: lto-cgraph.c:1867
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO section refs in %s"
 msgstr "kan ikke finde kilden %s"
 
-#: lto-cgraph.c:1946
+#: lto-cgraph.c:1948
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid rotate insn"
 msgid "invalid offload table in %s"
@@ -23457,89 +23471,95 @@
 msgid "bytecode stream in file %qs generated with LTO version %d.%d instead of the expected %d.%d"
 msgstr ""
 
-#: lto-wrapper.c:117
+#: lto-wrapper.c:118
 #, fuzzy, gcc-internal-format
 msgid "deleting LTRANS file %s: %m"
 msgstr "åbner uddatafilen %s"
 
-#: lto-wrapper.c:154
+#: lto-wrapper.c:155
 #, gcc-internal-format
 msgid "malformed COLLECT_GCC_OPTIONS"
 msgstr ""
 
-#: lto-wrapper.c:308
+#: lto-wrapper.c:309
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "created and used with differing settings of `-m%s'"
 msgid "Option %s with different values"
 msgstr "oprettet og brugt med en anden indstilling af '-m%s'"
 
-#: lto-wrapper.c:392
+#: lto-wrapper.c:393
 #, gcc-internal-format, gfc-internal-format
 msgid "Option %s not used consistently in all LTO input files"
 msgstr ""
 
-#: lto-wrapper.c:832
+#: lto-wrapper.c:833
 #, gcc-internal-format, gfc-internal-format
 msgid "problem with building target image for %s\n"
 msgstr ""
 
-#: lto-wrapper.c:852
+#: lto-wrapper.c:853
 #, fuzzy, gcc-internal-format
 #| msgid "no input files"
 msgid "reading input file"
 msgstr "ingen inddatafiler"
 
-#: lto-wrapper.c:857
+#: lto-wrapper.c:858
 #, fuzzy, gcc-internal-format
 msgid "writing output file"
 msgstr "Fejl ved skrivning af uddatafilen %s.\n"
 
-#: lto-wrapper.c:889
+#: lto-wrapper.c:890
 #, gcc-internal-format
 msgid "installation error, can't find crtoffloadtable.o"
 msgstr ""
 
-#: lto-wrapper.c:1000 lto-wrapper.c:1012
+#: lto-wrapper.c:1001 lto-wrapper.c:1013
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s: %s"
 msgid "%s: %s\n"
 msgstr "%s: %s"
 
-#: lto-wrapper.c:1056
+#: lto-wrapper.c:1064
 #, fuzzy, gcc-internal-format
 #| msgid "environment variable DJGPP not defined"
 msgid "environment variable COLLECT_GCC must be set"
 msgstr "miljøvariablen DJGPP er ikke defineret"
 
-#: lto-wrapper.c:1060 config/nvptx/mkoffload.c:363
+#: lto-wrapper.c:1068 config/nvptx/mkoffload.c:363
 #, fuzzy, gcc-internal-format
 #| msgid "environment variable DJGPP not defined"
 msgid "environment variable COLLECT_GCC_OPTIONS must be set"
 msgstr "miljøvariablen DJGPP er ikke defineret"
 
-#: lto-wrapper.c:1229 lto-wrapper.c:1285
+#: lto-wrapper.c:1237 lto-wrapper.c:1293
 #, fuzzy, gcc-internal-format
 #| msgid "can't open %s: %m"
 msgid "cannot open %s: %m"
 msgstr "kan ikke åbne %s: %m"
 
-#: lto-wrapper.c:1232 lto-wrapper.c:1291
+#: lto-wrapper.c:1240 lto-wrapper.c:1299
 #, fuzzy, gcc-internal-format
 msgid "cannot read %s: %m"
 msgstr "kan ikke udfolde %s"
 
-#: lto-wrapper.c:1259
+#: lto-wrapper.c:1267
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid option %s"
 msgid "invalid format of %s"
 msgstr "ugyldigt tilvalg %s"
 
-#: lto-wrapper.c:1482
+#: lto-wrapper.c:1491
 #, fuzzy, gcc-internal-format
 #| msgid "fopen %s"
 msgid "fopen: %s: %m"
 msgstr "fopen %s"
 
+#: lto-wrapper.c:1508
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "Could not open output file '%s'\n"
+msgid "Corrupted ltrans output file %s"
+msgstr "Kunne ikke åbne uddatafilen »%s«.\n"
+
 #: multiple_target.c:76
 #, fuzzy, gcc-internal-format
 #| msgid "Profiling is not supported on this target."
@@ -23909,13 +23929,13 @@
 msgid "unrecognized argument in option %qs"
 msgstr "ignorerer kommandolinjetilvalget '%s'"
 
-#: opts-common.c:1198 config/i386/i386.c:3206
+#: opts-common.c:1198 config/i386/i386.c:3209
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
-#: opts-common.c:1201 config/i386/i386.c:3209
+#: opts-common.c:1201 config/i386/i386.c:3212
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "valid arguments to %qs are: %s"
@@ -24538,22 +24558,22 @@
 msgid "output operand %d must use %<&%> constraint"
 msgstr "uddataoperand %d skal bruge %<&%>-begrænsningen"
 
-#: regcprop.c:1187
+#: regcprop.c:1193
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad next_regno for empty chain (%u)"
 msgstr "validate_value_data: [%u] Ugyldig next_regno til tom kæde (%u)"
 
-#: regcprop.c:1199
+#: regcprop.c:1205
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: Loop in regno chain (%u)"
 msgstr "validate_value_data: Løkke i registertalskæde (%u)"
 
-#: regcprop.c:1202
+#: regcprop.c:1208
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad oldest_regno (%u)"
 msgstr "validate_value_data: [%u] Ugyldig oldest_regno (%u)"
 
-#: regcprop.c:1214
+#: regcprop.c:1220
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Non-empty reg in chain (%s %u %i)"
 msgstr "validate_value_data: [%u] Ikke-tomt register i kæde (%s %u %i)"
@@ -24597,7 +24617,7 @@
 msgstr "register for %qD brugt til flere globale registervariabler"
 
 #: reginfo.c:789 config/powerpcspe/powerpcspe.c:32259
-#: config/rs6000/rs6000.c:29453
+#: config/rs6000/rs6000.c:29530
 #, gcc-internal-format
 msgid "conflicts with %qD"
 msgstr "er i konflikt med %qD"
@@ -24844,156 +24864,161 @@
 msgid "function symbol is not function"
 msgstr "funktionsymbol er ikke en funktion"
 
-#: symtab.c:1006
+#: symtab.c:1005
 #, gcc-internal-format
+msgid "inconsistent `ifunc' attribute"
+msgstr ""
+
+#: symtab.c:1013
+#, gcc-internal-format
 msgid "variable symbol is not variable"
 msgstr "variabelsymbol er ikke en variabel"
 
-#: symtab.c:1012
+#: symtab.c:1019
 #, gcc-internal-format
 msgid "node has unknown type"
 msgstr "node har ukendt type"
 
-#: symtab.c:1021
+#: symtab.c:1028
 #, gcc-internal-format
 msgid "node not found node->decl->decl_with_vis.symtab_node"
 msgstr "node blev ikke fundet node->decl->decl_with_vis.symtab_node"
 
-#: symtab.c:1029
+#: symtab.c:1036
 #, gcc-internal-format
 msgid "node differs from node->decl->decl_with_vis.symtab_node"
 msgstr "node er forskellig fra node->decl->decl_with_vis.symtab_node"
 
-#: symtab.c:1038
+#: symtab.c:1045
 #, gcc-internal-format
 msgid "assembler name hash list corrupted"
 msgstr "maskinekodenavn på hashliste er ødelagt"
 
-#: symtab.c:1051
+#: symtab.c:1058
 #, gcc-internal-format
 msgid "node not found in symtab assembler name hash"
 msgstr "node blev ikke fundet i symtabs maskinkodehash"
 
-#: symtab.c:1058
+#: symtab.c:1065
 #, gcc-internal-format
 msgid "double linked list of assembler names corrupted"
 msgstr "dobbelt lænket liste på maskinekodenavne er ødelagt"
 
-#: symtab.c:1063
+#: symtab.c:1070
 #, gcc-internal-format
 msgid "node has body_removed but is definition"
 msgstr "node har body_removed men er en definition"
 
-#: symtab.c:1068
+#: symtab.c:1075
 #, fuzzy, gcc-internal-format
 #| msgid "node is analyzed byt it is not a definition"
 msgid "node is analyzed but it is not a definition"
 msgstr "node er analyseret byt, det er ikke en definition"
 
-#: symtab.c:1073
+#: symtab.c:1080
 #, gcc-internal-format
 msgid "node is alias but not implicit alias"
 msgstr "node er alias men ikke implicit alias"
 
-#: symtab.c:1078
+#: symtab.c:1085
 #, gcc-internal-format
 msgid "node is alias but not definition"
 msgstr "node er alias men ikke definition"
 
-#: symtab.c:1083
+#: symtab.c:1090
 #, fuzzy, gcc-internal-format
 #| msgid "node is weakref but not an alias"
 msgid "node is weakref but not an transparent_alias"
 msgstr "node er weakref men ikke et alias"
 
-#: symtab.c:1088
+#: symtab.c:1095
 #, fuzzy, gcc-internal-format
 #| msgid "node is weakref but not an alias"
 msgid "node is transparent_alias but not an alias"
 msgstr "node er weakref men ikke et alias"
 
-#: symtab.c:1097
+#: symtab.c:1104
 #, gcc-internal-format
 msgid "node is in same_comdat_group list but has no comdat_group"
 msgstr "node er i same_comdat_grooup-liste men har ingen comdat_group"
 
-#: symtab.c:1102
+#: symtab.c:1109
 #, gcc-internal-format
 msgid "same_comdat_group list across different groups"
 msgstr "same_comdat_group-liste over forskellige grupper"
 
-#: symtab.c:1107
+#: symtab.c:1114
 #, gcc-internal-format
 msgid "mixing different types of symbol in same comdat groups is not supported"
 msgstr "blanding af forskellige symboltyper i samme comdata-gruppe er ikke understøttet"
 
-#: symtab.c:1112
+#: symtab.c:1119
 #, gcc-internal-format
 msgid "node is alone in a comdat group"
 msgstr "node er alene i en comdat-gruppe"
 
-#: symtab.c:1119
+#: symtab.c:1126
 #, gcc-internal-format
 msgid "same_comdat_group is not a circular list"
 msgstr "same_comdat_group er ikke en cirkulær liste"
 
-#: symtab.c:1134
+#: symtab.c:1141
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local symbol referred to by %s outside its comdat"
 msgstr "comdat-local-symbol refereret ti laf %s uden for dets comdat"
 
-#: symtab.c:1144
+#: symtab.c:1151
 #, gcc-internal-format
 msgid "implicit_section flag is set but section isn't"
 msgstr "implicit_section-flag er angivet men sektion er ikke"
 
-#: symtab.c:1151
+#: symtab.c:1158
 #, gcc-internal-format
 msgid "Both section and comdat group is set"
 msgstr "Både sektion og comdat-gruppe er angivet"
 
-#: symtab.c:1163
+#: symtab.c:1170
 #, gcc-internal-format
 msgid "Alias and target's section differs"
 msgstr "Alias og måls sektion er forskellige"
 
-#: symtab.c:1170
+#: symtab.c:1177
 #, gcc-internal-format
 msgid "Alias and target's comdat groups differs"
 msgstr "Alias og måls comdat-grupper er forskellige"
 
-#: symtab.c:1185
+#: symtab.c:1192
 #, fuzzy, gcc-internal-format
 #| msgid "Alias and target's section differs"
 msgid "Transparent alias and target's assembler names differs"
 msgstr "Alias og måls sektion er forskellige"
 
-#: symtab.c:1193
+#: symtab.c:1200
 #, gcc-internal-format
 msgid "Chained transparent aliases"
 msgstr ""
 
-#: symtab.c:1216 symtab.c:1253
+#: symtab.c:1223 symtab.c:1260
 #, gcc-internal-format
 msgid "symtab_node::verify failed"
 msgstr "symtab_node::verify mislykkedes"
 
-#: symtab.c:1249
+#: symtab.c:1256
 #, gcc-internal-format
 msgid "Two symbols with same comdat_group are not linked by the same_comdat_group list."
 msgstr "To symboler med samme comdat_group er ikke lænket af same_comdat_group-listen."
 
-#: symtab.c:1658
+#: symtab.c:1665
 #, gcc-internal-format
 msgid "function %q+D part of alias cycle"
 msgstr "funktion %q+D del af aliascyklus"
 
-#: symtab.c:1660
+#: symtab.c:1667
 #, gcc-internal-format
 msgid "variable %q+D part of alias cycle"
 msgstr "variabel %q+D del af aliascyklus"
 
-#: symtab.c:1688
+#: symtab.c:1695
 #, gcc-internal-format
 msgid "section of alias %q+D must match section of its target"
 msgstr "sektion for alias %q+D skal matche sektion for dens målarkitektur"
@@ -25854,7 +25879,7 @@
 msgid "the first argument of a VEC_COND_EXPR must be of a boolean vector type of the same number of elements as the result"
 msgstr ""
 
-#: tree-cfg.c:4395 c/c-typeck.c:5212
+#: tree-cfg.c:4395 c/c-typeck.c:5217
 #, gcc-internal-format
 msgid "type mismatch in conditional expression"
 msgstr "typerne i betingelsesudtrykket passer ikke sammen"
@@ -26240,7 +26265,7 @@
 msgid "missing edge %i->%i"
 msgstr "manglende felt '%s' i '%s'"
 
-#: tree-cfg.c:9379
+#: tree-cfg.c:9388
 #, fuzzy, gcc-internal-format
 #| msgid "`noreturn' function does return"
 msgid "%<noreturn%> function does return"
@@ -26247,18 +26272,18 @@
 msgstr "funktion med egenskaben 'noreturn' returnerer"
 
 # RETMIG: dette må kunne gøres bedre
-#: tree-cfg.c:9400 tree-cfg.c:9432
+#: tree-cfg.c:9409 tree-cfg.c:9441
 #, gcc-internal-format
 msgid "control reaches end of non-void function"
 msgstr "kontrol når til slutningen af ikke-void funktion"
 
-#: tree-cfg.c:9498 cp/cvt.c:1039
+#: tree-cfg.c:9507 cp/cvt.c:1039
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of `%D', declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgstr "%Hignorerer returværdi for '%D' erklæret med egenskaben warn_unused_result"
 
-#: tree-cfg.c:9503 cp/cvt.c:1046
+#: tree-cfg.c:9512 cp/cvt.c:1046
 #, gcc-internal-format
 msgid "ignoring return value of function declared with attribute warn_unused_result"
 msgstr ""
@@ -26538,47 +26563,47 @@
 msgid "stmt volatile flag not up-to-date"
 msgstr ""
 
-#: tree-ssa-strlen.c:1975
+#: tree-ssa-strlen.c:1999
 msgid "%G%qD output truncated before terminating nul copying %E byte from a string of the same length"
 msgid_plural "%G%qD output truncated before terminating nul copying %E bytes from a string of the same length"
 msgstr[0] ""
 msgstr[1] ""
 
-#: tree-ssa-strlen.c:1989
+#: tree-ssa-strlen.c:2013
 msgid "%G%qD output truncated copying %E byte from a string of length %wu"
 msgid_plural "%G%qD output truncated copying %E bytes from a string of length %wu"
 msgstr[0] ""
 msgstr[1] ""
 
-#: tree-ssa-strlen.c:1996
+#: tree-ssa-strlen.c:2020
 msgid "%G%qD output truncated copying between %wu and %wu bytes from a string of length %wu"
 msgstr ""
 
-#: tree-ssa-strlen.c:2008
+#: tree-ssa-strlen.c:2032
 msgid "%G%qD output may be truncated copying %E byte from a string of length %wu"
 msgid_plural "%G%qD output may be truncated copying %E bytes from a string of length %wu"
 msgstr[0] ""
 msgstr[1] ""
 
-#: tree-ssa-strlen.c:2015 tree-ssa-strlen.c:2029
+#: tree-ssa-strlen.c:2039 tree-ssa-strlen.c:2053
 msgid "%G%qD output may be truncated copying between %wu and %wu bytes from a string of length %wu"
 msgstr ""
 
-#: tree-ssa-strlen.c:2150
+#: tree-ssa-strlen.c:2174
 msgid "%G%qD output truncated before terminating nul copying as many bytes from a string as its length"
 msgstr ""
 
-#: tree-ssa-strlen.c:2156
+#: tree-ssa-strlen.c:2180
 msgid "%G%qD specified bound depends on the length of the source argument"
 msgstr ""
 
-#: tree-ssa-strlen.c:2163
+#: tree-ssa-strlen.c:2187
 #, fuzzy, gcc-internal-format
 #| msgid "length modifier"
 msgid "length computed here"
 msgstr "længdetilpasning"
 
-#: tree-ssa-uninit.c:191 varasm.c:331
+#: tree-ssa-uninit.c:191 varasm.c:342
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "%qD was declared here"
@@ -26760,27 +26785,27 @@
 msgid "target specific builtin not available"
 msgstr ""
 
-#: tree-vect-generic.c:287
+#: tree-vect-generic.c:283
 #, gcc-internal-format
 msgid "vector operation will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-generic.c:290
+#: tree-vect-generic.c:286
 #, gcc-internal-format
 msgid "vector operation will be expanded in parallel"
 msgstr ""
 
-#: tree-vect-generic.c:341
+#: tree-vect-generic.c:337
 #, gcc-internal-format
 msgid "vector operation will be expanded with a single scalar operation"
 msgstr ""
 
-#: tree-vect-generic.c:941
+#: tree-vect-generic.c:937
 #, gcc-internal-format
 msgid "vector condition will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-generic.c:1373
+#: tree-vect-generic.c:1369
 #, gcc-internal-format
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr ""
@@ -26790,31 +26815,31 @@
 msgid "vectorization did not happen for a simd loop"
 msgstr ""
 
-#: tree-vrp.c:4930 tree-vrp.c:4974
+#: tree-vrp.c:4931 tree-vrp.c:4975
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "array subscript %E is above array bounds of %qT"
 msgstr "tabelindeks er ikke et heltal"
 
-#: tree-vrp.c:4956
+#: tree-vrp.c:4957
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "array subscript [%E, %E] is outside array bounds of %qT"
 msgstr "tabelindeks er ikke et heltal"
 
-#: tree-vrp.c:4988
+#: tree-vrp.c:4989
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "array subscript %E is below array bounds of %qT"
 msgstr "tabelindeks er ikke et heltal"
 
-#: tree-vrp.c:5046
+#: tree-vrp.c:5047
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "array subscript %wi is below array bounds of %qT"
 msgstr "tabelindeks er ikke et heltal"
 
-#: tree-vrp.c:5060
+#: tree-vrp.c:5061
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "array subscript %wu is above array bounds of %qT"
@@ -26830,92 +26855,92 @@
 msgid "side-effects element in no-side-effects CONSTRUCTOR"
 msgstr ""
 
-#: tree.c:7852
+#: tree.c:7856
 #, gcc-internal-format
 msgid "arrays of functions are not meaningful"
 msgstr "en tabel af funktioner giver ikke mening"
 
-#: tree.c:8019
+#: tree.c:8023
 #, gcc-internal-format
 msgid "function return type cannot be function"
 msgstr "en funktions returtype kan ikke være en funktion"
 
-#: tree.c:9327 tree.c:9412 tree.c:9473
+#: tree.c:9331 tree.c:9416 tree.c:9477
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: %s, have %s in %s, at %s:%d"
 msgstr "træ-kontrol: %s, har %s i %s, ved %s:%d"
 
-#: tree.c:9364
+#: tree.c:9368
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected none of %s, have %s in %s, at %s:%d"
 msgstr "træ-kontrol: forventede ingen af %s, har %s i %s, ved %s:%d"
 
-#: tree.c:9377
+#: tree.c:9381
 #, gcc-internal-format
 msgid "tree check: expected class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "træ-kontrol: forventede klasse %qs, har %qs (%s) i %s, ved %s:%d"
 
-#: tree.c:9426
+#: tree.c:9430
 #, gcc-internal-format
 msgid "tree check: did not expect class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "træ-kontrol: forventede ikke klasse %qs, har %qs (%s) i %s, ved %s:%d"
 
-#: tree.c:9439
+#: tree.c:9443
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected omp_clause %s, have %s in %s, at %s:%d"
 msgstr "træ-kontrol: forventede omp_clause %s, har %s i %s, ved %s:%d"
 
-#: tree.c:9499
+#: tree.c:9503
 #, gcc-internal-format
 msgid "tree check: expected tree that contains %qs structure, have %qs in %s, at %s:%d"
 msgstr "træ-kontrol: forventede træ som indeholder %qs-struktur, har %qs i %s, ved %s:%d"
 
-#: tree.c:9513
+#: tree.c:9517
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_int_cst with %d elts in %s, at %s:%d"
 msgstr "trækontrol: tilgik udtrykstræ %d af tree_int_cst med %d udtrykstræer i %s, ved %s:%d"
 
-#: tree.c:9525
+#: tree.c:9529
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_vec with %d elts in %s, at %s:%d"
 msgstr "trækontrol: tilgik udtrykstræ %d af tree_vec med %d udtrykstræer i %s, ved %s:%d"
 
-#: tree.c:9538
+#: tree.c:9542
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of %s with %d operands in %s, at %s:%d"
 msgstr "trækontrol: tilgik operand %d af %s med %d operander i %s, ved %s:%d"
 
-#: tree.c:9551
+#: tree.c:9555
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of omp_clause %s with %d operands in %s, at %s:%d"
 msgstr "trækontrol: tilgik operand %d af omp_clause %s med %d operander i %s, ved %s:%d"
 
-#: tree.c:12446
+#: tree.c:12450
 #, gcc-internal-format
 msgid "%qD is deprecated: %s"
 msgstr "%qD er forældet: %s"
 
-#: tree.c:12449
+#: tree.c:12453
 #, gcc-internal-format
 msgid "%qD is deprecated"
 msgstr "%qD  er forældet"
 
-#: tree.c:12473 tree.c:12495
+#: tree.c:12477 tree.c:12499
 #, gcc-internal-format
 msgid "%qE is deprecated: %s"
 msgstr "%qE er forældet: %s"
 
-#: tree.c:12476 tree.c:12498
+#: tree.c:12480 tree.c:12502
 #, gcc-internal-format
 msgid "%qE is deprecated"
 msgstr "%qE er forældet"
 
-#: tree.c:12482 tree.c:12503
+#: tree.c:12486 tree.c:12507
 #, gcc-internal-format, gfc-internal-format
 msgid "type is deprecated: %s"
 msgstr "type er forældet: %s"
 
-#: tree.c:12485 tree.c:12506
+#: tree.c:12489 tree.c:12510
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr "type er forældet"
@@ -26940,242 +26965,242 @@
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.c:13043
+#: tree.c:13047
 #, gcc-internal-format, gfc-internal-format
 msgid "type variant differs by %s"
 msgstr ""
 
-#: tree.c:13084
+#: tree.c:13088
 #, gcc-internal-format
 msgid "type variant has different TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13086
+#: tree.c:13090
 #, gcc-internal-format
 msgid "type variant's TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13088
+#: tree.c:13092
 #, gcc-internal-format
 msgid "type's TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13108
+#: tree.c:13112
 #, gcc-internal-format
 msgid "type variant with TYPE_ALIAS_SET_KNOWN_P"
 msgstr ""
 
-#: tree.c:13121
+#: tree.c:13125
 #, gcc-internal-format
 msgid "type variant has different TYPE_VFIELD"
 msgstr ""
 
-#: tree.c:13157
+#: tree.c:13161
 #, gcc-internal-format
 msgid "type variant has different TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13159
+#: tree.c:13163
 #, gcc-internal-format
 msgid "type variant's TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13161
+#: tree.c:13165
 #, gcc-internal-format
 msgid "type's TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13199
+#: tree.c:13203
 #, gcc-internal-format
 msgid "type variant has different TYPE_FIELDS"
 msgstr ""
 
-#: tree.c:13201
+#: tree.c:13205
 #, gcc-internal-format
 msgid "first mismatch is field"
 msgstr ""
 
-#: tree.c:13203
+#: tree.c:13207
 #, gcc-internal-format
 msgid "and field"
 msgstr "og felt"
 
-#: tree.c:13220
+#: tree.c:13224
 #, gcc-internal-format
 msgid "type variant has different TREE_TYPE"
 msgstr ""
 
-#: tree.c:13222 tree.c:13233
+#: tree.c:13226 tree.c:13237
 #, gcc-internal-format
 msgid "type variant's TREE_TYPE"
 msgstr "typevariants TREE_TYPE"
 
-#: tree.c:13224 tree.c:13235
+#: tree.c:13228 tree.c:13239
 #, gcc-internal-format
 msgid "type's TREE_TYPE"
 msgstr "types TREE_TYPE"
 
-#: tree.c:13231
+#: tree.c:13235
 #, gcc-internal-format
 msgid "type is not compatible with its variant"
 msgstr "type er ikke forenelig med dens variant"
 
-#: tree.c:13534
+#: tree.c:13538
 #, gcc-internal-format
 msgid "Main variant is not defined"
 msgstr "Hovedvariant er ikke defineret"
 
-#: tree.c:13539
+#: tree.c:13543
 #, gcc-internal-format
 msgid "TYPE_MAIN_VARIANT has different TYPE_MAIN_VARIANT"
 msgstr ""
 
-#: tree.c:13551
+#: tree.c:13555
 #, gcc-internal-format
 msgid "TYPE_CANONICAL has different TYPE_CANONICAL"
 msgstr ""
 
-#: tree.c:13569
+#: tree.c:13573
 #, gcc-internal-format
 msgid "TYPE_CANONICAL is not compatible"
 msgstr ""
 
-#: tree.c:13577
+#: tree.c:13581
 #, gcc-internal-format
 msgid "TYPE_MODE of TYPE_CANONICAL is not compatible"
 msgstr ""
 
-#: tree.c:13583
+#: tree.c:13587
 #, gcc-internal-format
 msgid "TYPE_CANONICAL of main variant is not main variant"
 msgstr ""
 
-#: tree.c:13599
+#: tree.c:13603
 #, gcc-internal-format
 msgid "TYPE_VFIELD is not FIELD_DECL nor TREE_LIST"
 msgstr ""
 
-#: tree.c:13609
+#: tree.c:13613
 #, gcc-internal-format
 msgid "TYPE_NEXT_PTR_TO is not POINTER_TYPE"
 msgstr ""
 
-#: tree.c:13619
+#: tree.c:13623
 #, gcc-internal-format
 msgid "TYPE_NEXT_REF_TO is not REFERENCE_TYPE"
 msgstr ""
 
-#: tree.c:13640
+#: tree.c:13644
 #, gcc-internal-format
 msgid "TYPE_BINFO is not TREE_BINFO"
 msgstr ""
 
-#: tree.c:13646
+#: tree.c:13650
 #, gcc-internal-format
 msgid "TYPE_BINFO type is not TYPE_MAIN_VARIANT"
 msgstr ""
 
-#: tree.c:13657
+#: tree.c:13661
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not record nor union"
 msgstr ""
 
-#: tree.c:13668
+#: tree.c:13672
 #, gcc-internal-format
 msgid "TYPE_OFFSET_BASETYPE is not record nor union"
 msgstr ""
 
-#: tree.c:13686
+#: tree.c:13690
 #, gcc-internal-format
 msgid "TYPE_ARRAY_MAX_SIZE not INTEGER_CST"
 msgstr ""
 
-#: tree.c:13693
+#: tree.c:13697
 #, gcc-internal-format
 msgid "TYPE_MAX_VALUE_RAW non-NULL"
 msgstr ""
 
-#: tree.c:13700
+#: tree.c:13704
 #, gcc-internal-format
 msgid "TYPE_LANG_SLOT_1 (binfo) field is non-NULL"
 msgstr ""
 
-#: tree.c:13716
+#: tree.c:13720
 #, gcc-internal-format
 msgid "Enum value is not CONST_DECL or INTEGER_CST"
 msgstr ""
 
-#: tree.c:13724
+#: tree.c:13728
 #, gcc-internal-format
 msgid "Enum value type is not INTEGER_TYPE nor convertible to the enum"
 msgstr ""
 
-#: tree.c:13731
+#: tree.c:13735
 #, gcc-internal-format
 msgid "Enum value name is not IDENTIFIER_NODE"
 msgstr ""
 
-#: tree.c:13741
+#: tree.c:13745
 #, gcc-internal-format
 msgid "Array TYPE_DOMAIN is not integer type"
 msgstr "Tabellen TYPE_DOMAIN er ikke af en heltalstype"
 
-#: tree.c:13750
+#: tree.c:13754
 #, gcc-internal-format
 msgid "TYPE_FIELDS defined in incomplete type"
 msgstr "TYPE_FIELDS er defineret i en ufuldstændig type"
 
-#: tree.c:13772
+#: tree.c:13776
 #, gcc-internal-format
 msgid "Wrong tree in TYPE_FIELDS list"
 msgstr "Forkert træ i TYPE_FIELDS-liste"
 
-#: tree.c:13787
+#: tree.c:13791
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is %i while TYPE_CACHED_VALUES is %p"
 msgstr ""
 
-#: tree.c:13793
+#: tree.c:13797
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES is not TREE_VEC"
 msgstr ""
 
-#: tree.c:13806
+#: tree.c:13810
 #, gcc-internal-format
 msgid "wrong TYPE_CACHED_VALUES entry"
 msgstr ""
 
-#: tree.c:13819
+#: tree.c:13823
 #, gcc-internal-format
 msgid "TREE_PURPOSE is non-NULL in TYPE_ARG_TYPES list"
 msgstr ""
 
-#: tree.c:13825
+#: tree.c:13829
 #, gcc-internal-format
 msgid "Wrong entry in TYPE_ARG_TYPES list"
 msgstr ""
 
-#: tree.c:13832
+#: tree.c:13836
 #, gcc-internal-format
 msgid "TYPE_VALUES_RAW field is non-NULL"
 msgstr ""
 
-#: tree.c:13844
+#: tree.c:13848
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is set while it should not"
 msgstr ""
 
-#: tree.c:13850
+#: tree.c:13854
 #, gcc-internal-format
 msgid "TYPE_STRING_FLAG is set on wrong type code"
 msgstr ""
 
-#: tree.c:13860
+#: tree.c:13864
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not main variant"
 msgstr ""
 
-#: tree.c:13867
+#: tree.c:13871
 #, gcc-internal-format
 msgid "verify_type failed"
 msgstr "verify_type mislykkedes"
@@ -27200,197 +27225,197 @@
 msgid "corrupted value profile: %s profile counter (%d out of %d) inconsistent with basic-block count (%d)"
 msgstr ""
 
-#: var-tracking.c:7166
+#: var-tracking.c:7184
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded with -fvar-tracking-assignments, retrying without"
 msgstr ""
 
-#: var-tracking.c:7170
+#: var-tracking.c:7188
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded"
 msgstr ""
 
-#: varasm.c:326
+#: varasm.c:337
 #, fuzzy, gcc-internal-format
 #| msgid "%+D causes a section type conflict with %D"
 msgid "%+qD causes a section type conflict with %qD"
 msgstr "%+D forårsager en sektionstypekonflikt med %D"
 
-#: varasm.c:329
+#: varasm.c:340
 #, fuzzy, gcc-internal-format
 #| msgid "section type conflict with %D"
 msgid "section type conflict with %qD"
 msgstr "afsnitstypekonflikt med %D"
 
-#: varasm.c:334
+#: varasm.c:345
 #, gcc-internal-format
 msgid "%+qD causes a section type conflict"
 msgstr "%+qD forårsager en sektionstypekonflikt"
 
-#: varasm.c:336
+#: varasm.c:347
 #, gcc-internal-format
 msgid "section type conflict"
 msgstr "sektionstypekonflikt"
 
-#: varasm.c:1019
+#: varasm.c:1030
 #, gcc-internal-format
 msgid "alignment of %q+D is greater than maximum object file alignment %d"
 msgstr "justering af %q+D er større end den maksimale objektfilsjustering %d"
 
-#: varasm.c:1172
+#: varasm.c:1183
 #, gcc-internal-format
 msgid "only zero initializers are allowed in section %qs"
 msgstr "kun nulstartværdier er tilladte i sektion %qs"
 
-#: varasm.c:1378 varasm.c:1387
+#: varasm.c:1389 varasm.c:1398
 #, gcc-internal-format
 msgid "register name not specified for %q+D"
 msgstr "registernavn ikke angivet for %q+D"
 
-#: varasm.c:1389
+#: varasm.c:1400
 #, gcc-internal-format
 msgid "invalid register name for %q+D"
 msgstr "ugyldigt registernavn for %q+D"
 
-#: varasm.c:1391
+#: varasm.c:1402
 #, gcc-internal-format
 msgid "data type of %q+D isn%'t suitable for a register"
 msgstr "datatypen for %q+D passer ikke med et register"
 
-#: varasm.c:1394
+#: varasm.c:1405
 #, gcc-internal-format
 msgid "the register specified for %q+D cannot be accessed by the current target"
 msgstr ""
 
-#: varasm.c:1397
+#: varasm.c:1408
 #, gcc-internal-format
 msgid "the register specified for %q+D is not general enough to be used as a register variable"
 msgstr "registeret specificeret for %q+D er ikke generelt nok til at blive brugt som en registervariabel"
 
-#: varasm.c:1400
+#: varasm.c:1411
 #, fuzzy, gcc-internal-format
 #| msgid "%Jregister specified for '%D' isn't suitable for data type"
 msgid "register specified for %q+D isn%'t suitable for data type"
 msgstr "%Jregisteret som er angivet for '%D' passer ikke med datatypen"
 
-#: varasm.c:1410
+#: varasm.c:1421
 #, gcc-internal-format
 msgid "global register variable has initial value"
 msgstr "global registervariabel har en startværdi"
 
-#: varasm.c:1414
+#: varasm.c:1425
 #, gcc-internal-format
 msgid "optimization may eliminate reads and/or writes to register variables"
 msgstr ""
 
-#: varasm.c:1460
+#: varasm.c:1471
 #, fuzzy, gcc-internal-format
 #| msgid "%Jregister name given for non-register variable '%D'"
 msgid "register name given for non-register variable %q+D"
 msgstr "%Jregisternavn givet for ikke-registervariablen '%D'"
 
-#: varasm.c:1870
+#: varasm.c:1881
 #, fuzzy, gcc-internal-format
 #| msgid "Use alternate leaf function entries"
 msgid "Patchable function entry > size"
 msgstr "Benyt alternative elementer til yderste funktioner"
 
-#: varasm.c:2069
+#: varasm.c:2080
 #, gcc-internal-format
 msgid "thread-local COMMON data not implemented"
 msgstr "tråd-lokal COMMON-data er ikke implementeret"
 
-#: varasm.c:2102
+#: varasm.c:2113
 #, fuzzy, gcc-internal-format
 #| msgid "%Jrequested alignment for '%D' is greater than implemented alignment of %d"
 msgid "requested alignment for %q+D is greater than implemented alignment of %wu"
 msgstr "%Jforespurgt justering for '%D' er større end den implementerede justering på %d"
 
-#: varasm.c:2205 c/c-decl.c:5027 c/c-parser.c:1534
+#: varasm.c:2216 c/c-decl.c:5027 c/c-parser.c:1534
 #, fuzzy, gcc-internal-format
 #| msgid "storage size of `%D' isn't known"
 msgid "storage size of %q+D isn%'t known"
 msgstr "lagringsstørrelsen af '%D' er ikke kendt"
 
-#: varasm.c:4910
+#: varasm.c:4921
 #, fuzzy, gcc-internal-format
 #| msgid "initializer for integer value is too complicated"
 msgid "initializer for integer/fixed-point value is too complicated"
 msgstr "startværdien for heltallet er for kompliceret"
 
-#: varasm.c:4915
+#: varasm.c:4926
 #, gcc-internal-format
 msgid "initializer for floating value is not a floating constant"
 msgstr "startværdien for kommatal er ikke en kommatalskonstant"
 
-#: varasm.c:5227
+#: varasm.c:5238
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initial value for member `%s'"
 msgid "invalid initial value for member %qE"
 msgstr "ugyldig startværdi for medlemmet '%s'"
 
-#: varasm.c:5487
+#: varasm.c:5498
 #, fuzzy, gcc-internal-format
 msgid "%+qD declared weak after being used"
 msgstr "'%s' er erklæret inline efter at være blevet kaldt"
 
-#: varasm.c:5539
+#: varasm.c:5550
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D' outside of class is not definition"
 msgid "weak declaration of %q+D being applied to a already existing, static definition"
 msgstr "erklæring af '%#D' uden for en klasse er ikke en definition"
 
-#: varasm.c:5575
+#: varasm.c:5586
 #, fuzzy, gcc-internal-format
 #| msgid "%Jweak declaration of '%D' must be public"
 msgid "weak declaration of %q+D must be public"
 msgstr "%Jsvag erklæring af '%D' skal være public"
 
-#: varasm.c:5579
+#: varasm.c:5590
 #, fuzzy, gcc-internal-format
 #| msgid "%Jweak declaration of '%D' not supported"
 msgid "weak declaration of %q+D not supported"
 msgstr "%Jsvag erklæring af '%D' ikke understøttet"
 
-#: varasm.c:5608 varasm.c:5912
+#: varasm.c:5619 varasm.c:5926
 #, gcc-internal-format
 msgid "only weak aliases are supported in this configuration"
 msgstr "kun svage aliaser understøttes i denne konfiguration"
 
-#: varasm.c:5802
+#: varasm.c:5813
 #, fuzzy, gcc-internal-format
 msgid "weakref is not supported in this configuration"
 msgstr "%s understøttes ikke af denne konfiguration"
 
-#: varasm.c:5834
+#: varasm.c:5846
 #, fuzzy, gcc-internal-format
 #| msgid "Profiling is not supported on this target."
 msgid "ifunc is not supported on this target"
 msgstr "Profilering er ikke understøttet på målarkitekturen."
 
-#: varasm.c:5892
+#: varasm.c:5904
 #, gcc-internal-format
 msgid "weakref %q+D ultimately targets itself"
 msgstr ""
 
-#: varasm.c:5894
+#: varasm.c:5906
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member function `%D' to have static linkage"
 msgid "weakref %q+D must have static linkage"
 msgstr "kan ikke erklære medlemsfunktion '%D' til at have statisk kædning"
 
-#: varasm.c:5901
+#: varasm.c:5913
 #, fuzzy, gcc-internal-format
 #| msgid "alias definitions not supported in this configuration; ignored"
 msgid "alias definitions not supported in this configuration"
 msgstr "aliasdefinitioner er ikke understøttet i denne konfiguration; ignoreret"
 
-#: varasm.c:5909
+#: varasm.c:5923
 #, fuzzy, gcc-internal-format
 msgid "ifunc is not supported in this configuration"
 msgstr "%s understøttes ikke af denne konfiguration"
 
-#: varasm.c:6127 config/sol2.c:159 config/i386/winnt.c:265
+#: varasm.c:6141 config/sol2.c:159 config/i386/winnt.c:265
 #, gcc-internal-format
 msgid "visibility attribute not supported in this configuration; ignored"
 msgstr "synlighedsegenskab er ikke understøttet i denne konfiguration; ignoreret"
@@ -27469,514 +27494,520 @@
 msgid "bytecode stream: tag %s is not in the expected range [%s, %s]"
 msgstr ""
 
-#: c-family/c-attribs.c:529
+#: c-family/c-attribs.c:524
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored for `%s'"
+msgid "%qE attribute ignored for type %qT"
+msgstr "'%s'-egenskaben ignoreret for '%s'"
+
+#: c-family/c-attribs.c:536
+#, fuzzy, gcc-internal-format
+#| msgid "`%s' attribute ignored for `%s'"
 msgid "%qE attribute ignored for field of type %qT"
 msgstr "'%s'-egenskaben ignoreret for '%s'"
 
-#: c-family/c-attribs.c:696
+#: c-family/c-attribs.c:706
 #, fuzzy, gcc-internal-format
 #| msgid "visibility arg not a string"
 msgid "no_sanitize argument not a string"
 msgstr "synlighedsparameter er ikke en streng"
 
-#: c-family/c-attribs.c:826 ada/gcc-interface/utils.c:6235
+#: c-family/c-attribs.c:837 ada/gcc-interface/utils.c:6240
 #, gcc-internal-format
 msgid "%qE attribute ignored due to conflict with attribute %qs"
 msgstr ""
 
-#: c-family/c-attribs.c:875
+#: c-family/c-attribs.c:886
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored for `%s'"
 msgid "%qE attribute ignored. Use -fcf-protection option to enable it"
 msgstr "'%s'-egenskaben ignoreret for '%s'"
 
-#: c-family/c-attribs.c:914 c-family/c-attribs.c:920 c-family/c-attribs.c:3388
-#: c-family/c-attribs.c:3423 c-family/c-attribs.c:3429
+#: c-family/c-attribs.c:925 c-family/c-attribs.c:931 c-family/c-attribs.c:3399
+#: c-family/c-attribs.c:3434 c-family/c-attribs.c:3440
 #, gcc-internal-format
 msgid "%qE attribute ignored due to conflict with %qs attribute"
 msgstr ""
 
-#: c-family/c-attribs.c:976 brig/brig-lang.c:482 lto/lto-lang.c:288
+#: c-family/c-attribs.c:987 brig/brig-lang.c:482 lto/lto-lang.c:288
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute has no effect on unit local functions"
 msgstr "'%s'-egenskaben kan kun anvendes sammen med funktioner"
 
-#: c-family/c-attribs.c:1130
+#: c-family/c-attribs.c:1141
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute have effect only on public objects"
 msgstr "'%s'-egenskaben kan kun anvendes sammen med funktioner"
 
-#: c-family/c-attribs.c:1159
+#: c-family/c-attribs.c:1170
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to variables"
 msgid "%qE attribute only affects top level objects"
 msgstr "egenskaben '%s' kan kun anvendes på variabler"
 
-#: c-family/c-attribs.c:1198 c-family/c-attribs.c:2682
+#: c-family/c-attribs.c:1209 c-family/c-attribs.c:2693
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "%qE attribute on function returning %<void%>"
 msgstr "ingen return-sætning i en funktion der ikke returnerer void"
 
-#: c-family/c-attribs.c:1221 c-family/c-pragma.c:419
+#: c-family/c-attribs.c:1232 c-family/c-pragma.c:419
 #, gcc-internal-format
 msgid "scalar_storage_order is not supported because endianness is not uniform"
 msgstr ""
 
-#: c-family/c-attribs.c:1238
+#: c-family/c-attribs.c:1249
 #, gcc-internal-format
 msgid "scalar_storage_order argument must be one of \"big-endian\" or \"little-endian\""
 msgstr ""
 
-#: c-family/c-attribs.c:1334
+#: c-family/c-attribs.c:1345
 #, fuzzy, gcc-internal-format
 #| msgid "trampolines not supported"
 msgid "destructor priorities are not supported"
 msgstr "trampoliner understøttes ikke"
 
-#: c-family/c-attribs.c:1336
+#: c-family/c-attribs.c:1347
 #, fuzzy, gcc-internal-format
 #| msgid "trampolines not supported"
 msgid "constructor priorities are not supported"
 msgstr "trampoliner understøttes ikke"
 
-#: c-family/c-attribs.c:1358
+#: c-family/c-attribs.c:1369
 #, gcc-internal-format, gfc-internal-format
 msgid "destructor priorities from 0 to %d are reserved for the implementation"
 msgstr ""
 
-#: c-family/c-attribs.c:1363
+#: c-family/c-attribs.c:1374
 #, gcc-internal-format, gfc-internal-format
 msgid "constructor priorities from 0 to %d are reserved for the implementation"
 msgstr ""
 
-#: c-family/c-attribs.c:1371
+#: c-family/c-attribs.c:1382
 #, gcc-internal-format, gfc-internal-format
 msgid "destructor priorities must be integers from 0 to %d inclusive"
 msgstr ""
 
-#: c-family/c-attribs.c:1374
+#: c-family/c-attribs.c:1385
 #, gcc-internal-format, gfc-internal-format
 msgid "constructor priorities must be integers from 0 to %d inclusive"
 msgstr ""
 
-#: c-family/c-attribs.c:1527
+#: c-family/c-attribs.c:1538
 #, fuzzy, gcc-internal-format
 #| msgid "unknown machine mode `%s'"
 msgid "unknown machine mode %qE"
 msgstr "ukendt maskintilstand '%s'"
 
-#: c-family/c-attribs.c:1557
+#: c-family/c-attribs.c:1568
 #, gcc-internal-format
 msgid "specifying vector types with __attribute__ ((mode)) is deprecated"
 msgstr ""
 
-#: c-family/c-attribs.c:1560
+#: c-family/c-attribs.c:1571
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute directive ignored"
 msgid "use __attribute__ ((vector_size)) instead"
 msgstr "egenskabsdirektivet '%s' ignoreret"
 
-#: c-family/c-attribs.c:1569
+#: c-family/c-attribs.c:1580
 #, fuzzy, gcc-internal-format
 #| msgid "unable to emulate '%s'"
 msgid "unable to emulate %qs"
 msgstr "kunne ikke emulere '%s'"
 
-#: c-family/c-attribs.c:1582
+#: c-family/c-attribs.c:1593
 #, fuzzy, gcc-internal-format
 #| msgid "invalid pointer mode `%s'"
 msgid "invalid pointer mode %qs"
 msgstr "ugyldig henvisningstilstand '%s'"
 
-#: c-family/c-attribs.c:1599
+#: c-family/c-attribs.c:1610
 #, fuzzy, gcc-internal-format
 #| msgid "#-lines for entering and leaving files don't match"
 msgid "signedness of type and machine mode %qs don%'t match"
 msgstr "#-linjer til at træde ind og ud af filer passer ikke"
 
-#: c-family/c-attribs.c:1610
+#: c-family/c-attribs.c:1621
 #, fuzzy, gcc-internal-format
 #| msgid "no data type for mode `%s'"
 msgid "no data type for mode %qs"
 msgstr "ingen datatype til tilstanden '%s'"
 
-#: c-family/c-attribs.c:1620
+#: c-family/c-attribs.c:1631
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert to a pointer type"
 msgid "cannot use mode %qs for enumeral types"
 msgstr "kan ikke konverteres til en henvisningstype"
 
-#: c-family/c-attribs.c:1647
+#: c-family/c-attribs.c:1658
 #, fuzzy, gcc-internal-format
 #| msgid "`sigof' applied to non-aggregate type"
 msgid "mode %qs applied to inappropriate type"
 msgstr "'sigof' benyttet på en type der ikke er sammensat"
 
-#: c-family/c-attribs.c:1669
+#: c-family/c-attribs.c:1680
 #, fuzzy, gcc-internal-format
 msgid "section attributes are not supported for this target"
 msgstr "sektionsegenskaber understøttes ikke på denne målarkitektur"
 
-#: c-family/c-attribs.c:1675
+#: c-family/c-attribs.c:1686
 #, fuzzy, gcc-internal-format
 msgid "section attribute not allowed for %q+D"
 msgstr "sektionsegenskaben er ikke tilladt for '%s'"
 
-#: c-family/c-attribs.c:1681
+#: c-family/c-attribs.c:1692
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute argument not a string constant"
 msgid "section attribute argument not a string constant"
 msgstr "parameteren til egenskaben '%s' er ikke en strengkonstant"
 
-#: c-family/c-attribs.c:1690
+#: c-family/c-attribs.c:1701
 #, fuzzy, gcc-internal-format
 msgid "section attribute cannot be specified for local variables"
 msgstr "sektionsegenskaben kan ikke angives for lokale variabler"
 
-#: c-family/c-attribs.c:1700 config/bfin/bfin.c:4806 config/bfin/bfin.c:4857
+#: c-family/c-attribs.c:1711 config/bfin/bfin.c:4806 config/bfin/bfin.c:4857
 #: config/bfin/bfin.c:4883 config/bfin/bfin.c:4896
 #, fuzzy, gcc-internal-format
 msgid "section of %q+D conflicts with previous declaration"
 msgstr "sektionen '%s' strider mod tidligere erklæring"
 
-#: c-family/c-attribs.c:1708
+#: c-family/c-attribs.c:1719
 #, fuzzy, gcc-internal-format
 #| msgid "function `%D' cannot be declared friend"
 msgid "section of %q+D cannot be overridden"
 msgstr "funktionen '%D' kan ikke erklæres friend"
 
-#: c-family/c-attribs.c:1773
+#: c-family/c-attribs.c:1784
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "requested alignment is too large"
 msgid "requested alignment %d is larger than %d"
 msgstr "angivet justering er for stor"
 
-#: c-family/c-attribs.c:1866
+#: c-family/c-attribs.c:1877
 #, fuzzy, gcc-internal-format
 msgid "alignment may not be specified for %q+D"
 msgstr "justering må ikke angives for '%s'"
 
-#: c-family/c-attribs.c:1886
+#: c-family/c-attribs.c:1897
 #, fuzzy, gcc-internal-format
 msgid "ignoring attribute %<%E (%u)%> because it conflicts with attribute %<%E (%u)%>"
 msgstr "dataområdet '%s' er i modstrid med tidligere erklæring"
 
 #. Do not error out for attribute warn_if_not_aligned.
-#: c-family/c-attribs.c:1891 c-family/c-attribs.c:1920
+#: c-family/c-attribs.c:1902 c-family/c-attribs.c:1931
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 of `%s' must be a 2-bit literal"
 msgid "alignment for %q+D must be at least %d"
 msgstr "parameter til '%s' skal være en 2 bit-konstant"
 
-#: c-family/c-attribs.c:1916
+#: c-family/c-attribs.c:1927
 #, gcc-internal-format
 msgid "alignment for %q+D was previously specified as %d and may not be decreased"
 msgstr ""
 
-#: c-family/c-attribs.c:1943
+#: c-family/c-attribs.c:1954
 #, fuzzy, gcc-internal-format
 msgid "%<warn_if_not_aligned%> may not be specified for %q+D"
 msgstr "justering må ikke angives for '%s'"
 
-#: c-family/c-attribs.c:1986
+#: c-family/c-attribs.c:1997
 #, fuzzy, gcc-internal-format
 msgid "inline function %q+D declared weak"
 msgstr "Ugyldig erklæring"
 
-#: c-family/c-attribs.c:1991
+#: c-family/c-attribs.c:2002
 #, fuzzy, gcc-internal-format
 #| msgid "function `%D' cannot be declared friend"
 msgid "indirect function %q+D cannot be declared weak"
 msgstr "funktionen '%D' kan ikke erklæres friend"
 
-#: c-family/c-attribs.c:2015
+#: c-family/c-attribs.c:2026
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to functions"
 msgid "%qE attribute is only applicable on functions"
 msgstr "egenskaben '%s' kan kun anvendes sammen med funktioner"
 
-#: c-family/c-attribs.c:2046
+#: c-family/c-attribs.c:2057
 #, fuzzy, gcc-internal-format
 msgid "%q+D defined both normally and as %qE attribute"
 msgstr "'%s' er defineret både normalt og som et alias"
 
-#: c-family/c-attribs.c:2054
+#: c-family/c-attribs.c:2065
 #, fuzzy, gcc-internal-format
 #| msgid "`%#D' cannot be declared"
 msgid "weak %q+D cannot be defined %qE"
 msgstr "'%#D' kan ikke erklæres"
 
-#: c-family/c-attribs.c:2071 c-family/c-attribs.c:2582
+#: c-family/c-attribs.c:2082 c-family/c-attribs.c:2593
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute argument not a string constant"
 msgid "attribute %qE argument not a string"
 msgstr "parameteren til egenskaben '%s' er ikke en strengkonstant"
 
-#: c-family/c-attribs.c:2106
+#: c-family/c-attribs.c:2117
 #, fuzzy, gcc-internal-format
 msgid "%+qD declared alias after being used"
 msgstr "'%s' er erklæret inline efter at være blevet kaldt"
 
-#: c-family/c-attribs.c:2108
+#: c-family/c-attribs.c:2119
 #, fuzzy, gcc-internal-format
 msgid "%+qD declared ifunc after being used"
 msgstr "'%s' er erklæret inline efter at være blevet kaldt"
 
-#: c-family/c-attribs.c:2159
+#: c-family/c-attribs.c:2170
 #, fuzzy, gcc-internal-format
 #| msgid "function `%D' cannot be declared friend"
 msgid "indirect function %q+D cannot be declared weakref"
 msgstr "funktionen '%D' kan ikke erklæres friend"
 
-#: c-family/c-attribs.c:2181
+#: c-family/c-attribs.c:2192
 #, gcc-internal-format
 msgid "weakref attribute must appear before alias attribute"
 msgstr ""
 
-#: c-family/c-attribs.c:2193
+#: c-family/c-attribs.c:2204
 #, fuzzy, gcc-internal-format
 msgid "%+qD declared weakref after being used"
 msgstr "'%s' er erklæret inline efter at være blevet kaldt"
 
-#: c-family/c-attribs.c:2217
+#: c-family/c-attribs.c:2228
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored for `%s'"
 msgid "%qE attribute ignored on non-class types"
 msgstr "'%s'-egenskaben ignoreret for '%s'"
 
-#: c-family/c-attribs.c:2223
+#: c-family/c-attribs.c:2234
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute ignored because %qT is already defined"
 msgstr "'%s' brugt, men aldrig defineret"
 
-#: c-family/c-attribs.c:2236
+#: c-family/c-attribs.c:2247
 #, fuzzy, gcc-internal-format
 #| msgid "visibility arg not a string"
 msgid "visibility argument not a string"
 msgstr "synlighedsparameter er ikke en streng"
 
-#: c-family/c-attribs.c:2248
+#: c-family/c-attribs.c:2259
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored for `%s'"
 msgid "%qE attribute ignored on types"
 msgstr "'%s'-egenskaben ignoreret for '%s'"
 
-#: c-family/c-attribs.c:2264
+#: c-family/c-attribs.c:2275
 #, fuzzy, gcc-internal-format
 #| msgid "visibility arg must be one of \"default\", \"hidden\", \"protected\" or \"internal\""
 msgid "visibility argument must be one of \"default\", \"hidden\", \"protected\" or \"internal\""
 msgstr "synlighedsparameter skal være en af \"default\", \"hidden\", \"protected\" eller \"internal\""
 
-#: c-family/c-attribs.c:2275
+#: c-family/c-attribs.c:2286
 #, fuzzy, gcc-internal-format
 msgid "%qD redeclared with different visibility"
 msgstr "'%#D' omerklæret som en anden form for symbol"
 
-#: c-family/c-attribs.c:2278 c-family/c-attribs.c:2282
+#: c-family/c-attribs.c:2289 c-family/c-attribs.c:2293
 #, gcc-internal-format
 msgid "%qD was declared %qs which implies default visibility"
 msgstr ""
 
-#: c-family/c-attribs.c:2320
+#: c-family/c-attribs.c:2331
 #, fuzzy, gcc-internal-format
 #| msgid "tls_model arg not a string"
 msgid "tls_model argument not a string"
 msgstr "tls_model-parameter er ikke en streng"
 
-#: c-family/c-attribs.c:2333
+#: c-family/c-attribs.c:2344
 #, fuzzy, gcc-internal-format
 #| msgid "tls_model arg must be one of \"local-exec\", \"initial-exec\", \"local-dynamic\" or \"global-dynamic\""
 msgid "tls_model argument must be one of \"local-exec\", \"initial-exec\", \"local-dynamic\" or \"global-dynamic\""
 msgstr "tls_model-parameter skal være en af \"local-exec\", \"initial-exec\", \"local-dynamic\" eller \"global-dynamic\""
 
-#: c-family/c-attribs.c:2353 c-family/c-attribs.c:2656
-#: c-family/c-attribs.c:3497 config/m32c/m32c.c:2944
+#: c-family/c-attribs.c:2364 c-family/c-attribs.c:2667
+#: c-family/c-attribs.c:3508 config/m32c/m32c.c:2944
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applies only to functions"
 msgstr "'%s'-egenskaben kan kun anvendes sammen med funktioner"
 
-#: c-family/c-attribs.c:2417
+#: c-family/c-attribs.c:2428
 #, gcc-internal-format
 msgid "alloc_size parameter outside range"
 msgstr ""
 
-#: c-family/c-attribs.c:2443
+#: c-family/c-attribs.c:2454
 #, gcc-internal-format
 msgid "alloc_align parameter outside range"
 msgstr ""
 
-#: c-family/c-attribs.c:2467
+#: c-family/c-attribs.c:2478
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute argument not an integer constant"
 msgid "assume_aligned parameter not integer constant"
 msgstr "parameteren til egenskaben '%s' er ikke en heltalskonstant"
 
-#: c-family/c-attribs.c:2595
+#: c-family/c-attribs.c:2606
 #, gcc-internal-format
 msgid "only %<inbranch%> and %<notinbranch%> flags are allowed for %<__simd__%> attribute"
 msgstr ""
 
-#: c-family/c-attribs.c:2662 c-family/c-attribs.c:3503
+#: c-family/c-attribs.c:2673 c-family/c-attribs.c:3514
 #, fuzzy, gcc-internal-format
 msgid "can%'t set %qE attribute after definition"
 msgstr "kan ikke angive '%s'-egenskaben efter definitionen"
 
-#: c-family/c-attribs.c:2727
+#: c-family/c-attribs.c:2738
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored"
 msgid "%qE attribute duplicated"
 msgstr "egenskaben '%s' ignoreret"
 
-#: c-family/c-attribs.c:2729
+#: c-family/c-attribs.c:2740
 #, gcc-internal-format
 msgid "%qE attribute follows %qE"
 msgstr ""
 
-#: c-family/c-attribs.c:2828
+#: c-family/c-attribs.c:2839
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' previously declared here"
 msgid "type was previously declared %qE"
 msgstr "'%s' tidligere erklæret her"
 
-#: c-family/c-attribs.c:2841 cp/class.c:4397
+#: c-family/c-attribs.c:2852 cp/class.c:4401
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified for functions"
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
 msgstr "'%D' kan kun angives for funktioner"
 
-#: c-family/c-attribs.c:2899
+#: c-family/c-attribs.c:2910
 #, fuzzy, gcc-internal-format
 msgid "%qE argument not an identifier"
 msgstr "'defined' optræder uden et kaldenavn"
 
-#: c-family/c-attribs.c:2910
+#: c-family/c-attribs.c:2921
 #, fuzzy, gcc-internal-format
 msgid "%qD is not compatible with %qD"
 msgstr "-march=%s er ikke forenelig med den valgte ABI"
 
-#: c-family/c-attribs.c:2913
+#: c-family/c-attribs.c:2924
 #, fuzzy, gcc-internal-format
 #| msgid "no arguments for spec function"
 msgid "%qE argument is not a function"
 msgstr "ingen parametre til specifikationsfunktion"
 
-#: c-family/c-attribs.c:2961
+#: c-family/c-attribs.c:2972
 #, fuzzy, gcc-internal-format
 #| msgid "second token after #line is not a string"
 msgid "deprecated message is not a string"
 msgstr "det andet symbol efter #line er ikke en streng"
 
-#: c-family/c-attribs.c:3002
+#: c-family/c-attribs.c:3013
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored for `%s'"
 msgid "%qE attribute ignored for %qE"
 msgstr "'%s'-egenskaben ignoreret for '%s'"
 
-#: c-family/c-attribs.c:3065
+#: c-family/c-attribs.c:3076
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute `%s'"
 msgid "invalid vector type for attribute %qE"
 msgstr "ugyldig vektortype for egenskaben '%s'"
 
-#: c-family/c-attribs.c:3071 ada/gcc-interface/utils.c:3896
+#: c-family/c-attribs.c:3082 ada/gcc-interface/utils.c:3899
 #, gcc-internal-format
 msgid "vector size not an integral multiple of component size"
 msgstr ""
 
-#: c-family/c-attribs.c:3077 ada/gcc-interface/utils.c:3903
+#: c-family/c-attribs.c:3088 ada/gcc-interface/utils.c:3906
 #, gcc-internal-format
 msgid "zero vector size"
 msgstr ""
 
-#: c-family/c-attribs.c:3085
+#: c-family/c-attribs.c:3096
 #, gcc-internal-format
 msgid "number of components of the vector not a power of two"
 msgstr ""
 
-#: c-family/c-attribs.c:3118 ada/gcc-interface/utils.c:6092
+#: c-family/c-attribs.c:3129 ada/gcc-interface/utils.c:6098
 #, gcc-internal-format
 msgid "nonnull attribute without arguments on a non-prototype"
 msgstr "ikke-nul egenskab uden parametre til en ikke-prototype"
 
-#: c-family/c-attribs.c:3137 ada/gcc-interface/utils.c:6106
+#: c-family/c-attribs.c:3148 ada/gcc-interface/utils.c:6112
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "nonnull argument has invalid operand number (arg %lu)"
 msgid "nonnull argument has invalid operand number (argument %lu)"
 msgstr "ikke-nul parameter har ugyldig operandnummer (parameter %lu)"
 
-#: c-family/c-attribs.c:3159 ada/gcc-interface/utils.c:6128
+#: c-family/c-attribs.c:3170 ada/gcc-interface/utils.c:6134
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "nonnull argument with out-of-range operand number (arg %lu, operand %lu)"
 msgid "nonnull argument with out-of-range operand number (argument %lu, operand %lu)"
 msgstr "ikke-nul parameter med operandnummer uden for det gyldig interval (parameter %lu, operand %lu)"
 
-#: c-family/c-attribs.c:3168 ada/gcc-interface/utils.c:6137
+#: c-family/c-attribs.c:3179 ada/gcc-interface/utils.c:6143
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "nonnull argument references non-pointer operand (arg %lu, operand %lu)"
 msgid "nonnull argument references non-pointer operand (argument %lu, operand %lu)"
 msgstr "ikke-nul parameter refererer til ikke-henvisningsoperand (parameter %lu, operand %lu)"
 
-#: c-family/c-attribs.c:3208
+#: c-family/c-attribs.c:3219
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored for `%s'"
 msgid "%qE attribute ignored on objects of type %qT"
 msgstr "'%s'-egenskaben ignoreret for '%s'"
 
-#: c-family/c-attribs.c:3216
+#: c-family/c-attribs.c:3227
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to functions"
 msgid "%qE attribute does not apply to functions"
 msgstr "egenskaben '%s' kan kun anvendes sammen med funktioner"
 
-#: c-family/c-attribs.c:3273
+#: c-family/c-attribs.c:3284
 #, fuzzy, gcc-internal-format
 msgid "cleanup argument not an identifier"
 msgstr "'defined' optræder uden et kaldenavn"
 
-#: c-family/c-attribs.c:3280
+#: c-family/c-attribs.c:3291
 #, fuzzy, gcc-internal-format
 msgid "cleanup argument not a function"
 msgstr "det kaldte objekt er ikke en funktion"
 
-#: c-family/c-attribs.c:3317
+#: c-family/c-attribs.c:3328
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute requires an integer constant argument"
 msgid "%qE attribute requires prototypes with named arguments"
 msgstr "egenskaben '%s' kræver en heltalskonstant som parameter"
 
-#: c-family/c-attribs.c:3325
+#: c-family/c-attribs.c:3336
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to functions"
 msgid "%qE attribute only applies to variadic functions"
 msgstr "egenskaben '%s' kan kun anvendes sammen med funktioner"
 
-#: c-family/c-attribs.c:3341 ada/gcc-interface/utils.c:6179
+#: c-family/c-attribs.c:3352 ada/gcc-interface/utils.c:6185
 #, fuzzy, gcc-internal-format
 #| msgid "requested init_priority is not an integer constant"
 msgid "requested position is not an integer constant"
 msgstr "den udbedte init_priority er ikke en heltalskonstant"
 
-#: c-family/c-attribs.c:3349 ada/gcc-interface/utils.c:6186
+#: c-family/c-attribs.c:3360 ada/gcc-interface/utils.c:6192
 #, gcc-internal-format
 msgid "requested position is less than zero"
 msgstr ""
 
-#: c-family/c-attribs.c:3404
+#: c-family/c-attribs.c:3415
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_trap not supported by this target"
 msgid "empty string in attribute %<target%>"
 msgstr "__builtin_trap understøttes ikke på denne målarkitektur"
 
-#: c-family/c-attribs.c:3520
+#: c-family/c-attribs.c:3531
 #, fuzzy, gcc-internal-format
 #| msgid "`return' with no value, in function returning non-void"
 msgid "returns_nonnull attribute on a function not returning a pointer"
 msgstr "'return' uden nogen værdi i en funktion der ikke returnerer void"
 
-#: c-family/c-attribs.c:3535
+#: c-family/c-attribs.c:3546
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to function types"
 msgid "%qE attribute is only valid on %<struct%> type"
@@ -28026,13 +28057,13 @@
 msgid "__builtin_shuffle argument vector(s) inner type must have the same size as inner type of the mask"
 msgstr ""
 
-#: c-family/c-common.c:1262 c-family/c-warn.c:1194
+#: c-family/c-common.c:1262 c-family/c-warn.c:1202
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from `%T' to `%T' discards qualifiers"
 msgid "unsigned conversion from %qT to %qT changes value from %qE to %qE"
 msgstr "konvertering fra '%T' til '%T' forkaster modifikationer"
 
-#: c-family/c-common.c:1267 c-family/c-warn.c:1202
+#: c-family/c-common.c:1267 c-family/c-warn.c:1210
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from `%T' to `%T' is ambiguous"
 msgid "unsigned conversion from %qT to %qT changes the value of %qE"
@@ -28173,7 +28204,7 @@
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "foreslår paranteser omkring tildeling der er benyttet som boolsk værdi"
 
-#: c-family/c-common.c:3518 c/c-decl.c:4325 c/c-decl.c:6430 c/c-typeck.c:14177
+#: c-family/c-common.c:3518 c/c-decl.c:4325 c/c-decl.c:6450 c/c-typeck.c:14182
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `restrict'"
 msgid "invalid use of %<restrict%>"
@@ -28264,7 +28295,7 @@
 msgid "duplicate case value"
 msgstr "case-værdi optræder mere end én gang"
 
-#: c-family/c-common.c:4867 c-family/c-warn.c:2216
+#: c-family/c-common.c:4867 c-family/c-warn.c:2225
 #, fuzzy, gcc-internal-format
 #| msgid "%Jpreviously used here"
 msgid "previously used here"
@@ -28315,35 +28346,35 @@
 msgid "missing sentinel in function call"
 msgstr "Forbyd PC-relative funktionskald"
 
-#: c-family/c-common.c:5411
+#: c-family/c-common.c:5409
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "null argument where non-null required (arg %lu)"
 msgid "null argument where non-null required (argument %lu)"
 msgstr "nulparameter hvor ikke-nul er påkrævet (parameter %lu)"
 
-#: c-family/c-common.c:5506 c-family/c-common.c:5553
+#: c-family/c-common.c:5504 c-family/c-common.c:5551
 #, gcc-internal-format
 msgid "bad option %qs to attribute %<optimize%>"
 msgstr ""
 
-#: c-family/c-common.c:5509 c-family/c-common.c:5557
+#: c-family/c-common.c:5507 c-family/c-common.c:5555
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand for 'p' modifier"
 msgid "bad option %qs to pragma %<optimize%>"
 msgstr "ugyldig operand til 'p'-ændring"
 
-#: c-family/c-common.c:5589
+#: c-family/c-common.c:5587
 #, gcc-internal-format
 msgid "%<fallthrough%> attribute specified multiple times"
 msgstr ""
 
-#: c-family/c-common.c:5593
+#: c-family/c-common.c:5591
 #, fuzzy, gcc-internal-format
 #| msgid "default argument given for parameter %d of `%#D'"
 msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr "standardparameter givet til %d. parameter for '%#D'"
 
-#: c-family/c-common.c:5733 c-family/c-common.c:6485 c-family/c-common.c:6558
+#: c-family/c-common.c:5731 c-family/c-common.c:6477 c-family/c-common.c:6550
 #: c/c-typeck.c:3555
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function"
@@ -28350,186 +28381,186 @@
 msgid "too few arguments to function %qE"
 msgstr "for få parametre til funktionen"
 
-#: c-family/c-common.c:5738 c-family/c-common.c:6584 c/c-typeck.c:3284
+#: c-family/c-common.c:5736 c-family/c-common.c:6576 c/c-typeck.c:3284
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function"
 msgid "too many arguments to function %qE"
 msgstr "for mange parametre til funktionen"
 
-#: c-family/c-common.c:5769
+#: c-family/c-common.c:5767
 #, fuzzy, gcc-internal-format
 #| msgid "third arg to `__builtin_prefetch' must be a constant"
 msgid "third argument to function %qE must be a constant integer"
 msgstr "en tredje parameter til '__builtin_prefetch' skal være en konstant"
 
-#: c-family/c-common.c:5794
+#: c-family/c-common.c:5792
 #, gcc-internal-format
 msgid "second argument to function %qE must be a constant integer power of 2 between %qi and %qu bits"
 msgstr ""
 
-#: c-family/c-common.c:5815 c-family/c-common.c:5859
+#: c-family/c-common.c:5813 c-family/c-common.c:5857
 #, fuzzy, gcc-internal-format
 #| msgid "non-floating-point argument to function `%s'"
 msgid "non-floating-point argument in call to function %qE"
 msgstr "parameter der ikke er et kommatal, til funktionen '%s'"
 
-#: c-family/c-common.c:5838
+#: c-family/c-common.c:5836
 #, fuzzy, gcc-internal-format
 #| msgid "non-floating-point argument to function `%s'"
 msgid "non-floating-point arguments in call to function %qE"
 msgstr "parameter der ikke er et kommatal, til funktionen '%s'"
 
-#: c-family/c-common.c:5852
+#: c-family/c-common.c:5850
 #, fuzzy, gcc-internal-format
 #| msgid "non-floating-point argument to function `%s'"
 msgid "non-const integer argument %u in call to function %qE"
 msgstr "parameter der ikke er et kommatal, til funktionen '%s'"
 
-#: c-family/c-common.c:5872
+#: c-family/c-common.c:5870
 #, fuzzy, gcc-internal-format
 #| msgid "non-floating-point argument to function `%s'"
 msgid "non-integer argument 3 in call to function %qE"
 msgstr "parameter der ikke er et kommatal, til funktionen '%s'"
 
-#: c-family/c-common.c:5889 c-family/c-common.c:5925
+#: c-family/c-common.c:5887 c-family/c-common.c:5923
 #, gcc-internal-format
 msgid "argument %u in call to function %qE does not have integral type"
 msgstr ""
 
-#: c-family/c-common.c:5896
+#: c-family/c-common.c:5894
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "argument 3 in call to function %qE does not have pointer to integral type"
 msgstr "størrelse i tabel-new skal være en heltalstype"
 
-#: c-family/c-common.c:5902
+#: c-family/c-common.c:5900
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `asm' is not a constant string"
 msgid "argument 3 in call to function %qE has pointer to enumerated type"
 msgstr "parameteren til 'asm' er ikke en konstant streng"
 
-#: c-family/c-common.c:5908
+#: c-family/c-common.c:5906
 #, fuzzy, gcc-internal-format
 #| msgid "non-floating-point argument to function `%s'"
 msgid "argument 3 in call to function %qE has pointer to boolean type"
 msgstr "parameter der ikke er et kommatal, til funktionen '%s'"
 
-#: c-family/c-common.c:5931
+#: c-family/c-common.c:5929
 #, fuzzy, gcc-internal-format
 #| msgid "non-floating-point argument to function `%s'"
 msgid "argument 3 in call to function %qE has enumerated type"
 msgstr "parameter der ikke er et kommatal, til funktionen '%s'"
 
-#: c-family/c-common.c:5937
+#: c-family/c-common.c:5935
 #, fuzzy, gcc-internal-format
 #| msgid "non-floating-point argument to function `%s'"
 msgid "argument 3 in call to function %qE has boolean type"
 msgstr "parameter der ikke er et kommatal, til funktionen '%s'"
 
-#: c-family/c-common.c:6184
+#: c-family/c-common.c:6183
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to static data member %qD"
 msgstr "ugyldig brug af ikke-statisk felt '%D'"
 
-#: c-family/c-common.c:6189
+#: c-family/c-common.c:6188
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> when %<operator[]%> is overloaded"
 msgstr ""
 
-#: c-family/c-common.c:6196
+#: c-family/c-common.c:6195
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to a non constant address"
 msgstr ""
 
-#: c-family/c-common.c:6209
+#: c-family/c-common.c:6208
 #, fuzzy, gcc-internal-format
 #| msgid "attempt to take address of bit-field structure member `%D'"
 msgid "attempt to take address of bit-field structure member %qD"
 msgstr "forsøg på at finde adressen af bitfeltstrukturmedlemmet '%D'"
 
-#: c-family/c-common.c:6261
+#: c-family/c-common.c:6260
 #, gcc-internal-format
 msgid "index %E denotes an offset greater than size of %qT"
 msgstr ""
 
-#: c-family/c-common.c:6427 cp/init.c:3004 cp/init.c:3023
+#: c-family/c-common.c:6419 cp/init.c:3020 cp/init.c:3039
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%s' is too large"
 msgid "size of array is too large"
 msgstr "størrelsen af tabellen '%s' er for stor"
 
-#: c-family/c-common.c:6517
+#: c-family/c-common.c:6509
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible type for argument %d of `%s'"
 msgid "operand type %qT is incompatible with argument %d of %qE"
 msgstr "typen af den %d. parameter i '%s' passer ikke"
 
-#: c-family/c-common.c:6651
+#: c-family/c-common.c:6643
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function `%s'"
 msgid "incorrect number of arguments to function %qE"
 msgstr "for få parametre til funktionen '%s'"
 
-#: c-family/c-common.c:6665
+#: c-family/c-common.c:6657
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 of `%s' must be a 2-bit literal"
 msgid "argument 1 of %qE must be a non-void pointer type"
 msgstr "parameter til '%s' skal være en 2 bit-konstant"
 
-#: c-family/c-common.c:6674
+#: c-family/c-common.c:6666
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `asm' is not a constant string"
 msgid "argument 1 of %qE must be a pointer to a constant size type"
 msgstr "parameteren til 'asm' er ikke en konstant streng"
 
-#: c-family/c-common.c:6685
+#: c-family/c-common.c:6677
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 of `%s' must be a 2-bit literal"
 msgid "argument 1 of %qE must be a pointer to a nonzero size object"
 msgstr "parameter til '%s' skal være en 2 bit-konstant"
 
-#: c-family/c-common.c:6706
+#: c-family/c-common.c:6698
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 of `%s' must be a 2-bit literal"
 msgid "argument %d of %qE must be a pointer type"
 msgstr "parameter til '%s' skal være en 2 bit-konstant"
 
-#: c-family/c-common.c:6714
+#: c-family/c-common.c:6706
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `asm' is not a constant string"
 msgid "argument %d of %qE must be a pointer to a constant size type"
 msgstr "parameteren til 'asm' er ikke en konstant streng"
 
-#: c-family/c-common.c:6720
+#: c-family/c-common.c:6712
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 of `%s' must be a 2-bit literal"
 msgid "argument %d of %qE must not be a pointer to a function"
 msgstr "parameter til '%s' skal være en 2 bit-konstant"
 
-#: c-family/c-common.c:6728
+#: c-family/c-common.c:6720
 #, fuzzy, gcc-internal-format
 #| msgid "in passing argument %P of `%+D'"
 msgid "size mismatch in argument %d of %qE"
 msgstr "i overbringelse af parameter %P af '%+D'"
 
-#: c-family/c-common.c:6740
+#: c-family/c-common.c:6732
 #, gcc-internal-format
 msgid "non-integer memory model argument %d of %qE"
 msgstr ""
 
-#: c-family/c-common.c:6753
+#: c-family/c-common.c:6745
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument of `%s'"
 msgid "invalid memory model argument %d of %qE"
 msgstr "ugyldig typeparameter '%s'"
 
-#: c-family/c-common.c:7672
+#: c-family/c-common.c:7664
 #, fuzzy, gcc-internal-format
 #| msgid "accumulator number is out of bounds"
 msgid "index value is out of bound"
 msgstr "akkumulatortal er uden for det gyldig interval"
 
-#: c-family/c-common.c:7714 c-family/c-common.c:7763 c-family/c-common.c:7779
+#: c-family/c-common.c:7706 c-family/c-common.c:7755 c-family/c-common.c:7771
 #, gcc-internal-format
 msgid "conversion of scalar %qT to vector %qT involves truncation"
 msgstr ""
@@ -28536,24 +28567,24 @@
 
 #. Reject arguments that are built-in functions with
 #. no library fallback.
-#: c-family/c-common.c:7867
+#: c-family/c-common.c:7859
 #, fuzzy, gcc-internal-format
 msgid "built-in function %qE must be directly called"
 msgstr "den indbyggede funktion '%s' er erklæret som noget der ikke er en funktion"
 
-#: c-family/c-common.c:7889 c/c-decl.c:6177
+#: c-family/c-common.c:7881 c/c-decl.c:6197
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%s' is too large"
 msgid "size of array %qE is too large"
 msgstr "størrelsen af tabellen '%s' er for stor"
 
-#: c-family/c-common.c:7891 c/c-decl.c:6180
+#: c-family/c-common.c:7883 c/c-decl.c:6200
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%s' is too large"
 msgid "size of unnamed array is too large"
 msgstr "størrelsen af tabellen '%s' er for stor"
 
-#: c-family/c-common.c:7921
+#: c-family/c-common.c:7913
 #, gcc-internal-format
 msgid "environment variable SOURCE_DATE_EPOCH must expand to a non-negative integer less than or equal to %wd"
 msgstr ""
@@ -29121,7 +29152,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr ""
 
-#: c-family/c-omp.c:557 cp/semantics.c:8186
+#: c-family/c-omp.c:557 cp/semantics.c:8189
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute `%s'"
 msgid "invalid type for iteration variable %qE"
@@ -29139,25 +29170,25 @@
 msgid "%qE is not initialized"
 msgstr "manglende startværdi"
 
-#: c-family/c-omp.c:599 cp/semantics.c:8076
+#: c-family/c-omp.c:599 cp/semantics.c:8079
 #, fuzzy, gcc-internal-format
 #| msgid "missing '(' after predicate"
 msgid "missing controlling predicate"
 msgstr "manglende '(' efter udsagn"
 
-#: c-family/c-omp.c:704 cp/semantics.c:7732
+#: c-family/c-omp.c:704 cp/semantics.c:7735
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid control expression"
 msgid "invalid controlling predicate"
 msgstr "Ugyldigt kontroludtryk"
 
-#: c-family/c-omp.c:711 cp/semantics.c:8082
+#: c-family/c-omp.c:711 cp/semantics.c:8085
 #, fuzzy, gcc-internal-format
 #| msgid "missing ')' in expression"
 msgid "missing increment expression"
 msgstr "manglende ')' i udtryk"
 
-#: c-family/c-omp.c:775 cp/semantics.c:7847
+#: c-family/c-omp.c:775 cp/semantics.c:7850
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid control expression"
 msgid "invalid increment expression"
@@ -29218,116 +29249,131 @@
 msgid "%<-Wabi=1%> is not supported, using =2"
 msgstr "-traditional understøttes ikke i C++"
 
-#: c-family/c-opts.c:612 fortran/cpp.c:350
+#: c-family/c-opts.c:610 fortran/cpp.c:350
 #, gcc-internal-format
 msgid "output filename specified twice"
 msgstr "uddatafilnavnet er angivet to gange"
 
-#: c-family/c-opts.c:799
+#: c-family/c-opts.c:797
 #, gcc-internal-format
 msgid "-fexcess-precision=standard for C++"
 msgstr ""
 
-#: c-family/c-opts.c:834
+#: c-family/c-opts.c:832
 #, fuzzy, gcc-internal-format
 msgid "-fno-gnu89-inline is only supported in GNU99 or C99 mode"
 msgstr "-g er kun understøttet ved brug af GAS på denne processor,"
 
-#: c-family/c-opts.c:880
+#: c-family/c-opts.c:878
 #, gcc-internal-format
 msgid "-Wformat-y2k ignored without -Wformat"
 msgstr "-Wformat-y2k ignoreret uden -Wformat"
 
-#: c-family/c-opts.c:882
+#: c-family/c-opts.c:880
 #, gcc-internal-format
 msgid "-Wformat-extra-args ignored without -Wformat"
 msgstr "-Wformat-extra-args ignoreret uden -Wformat"
 
-#: c-family/c-opts.c:884
+#: c-family/c-opts.c:882
 #, gcc-internal-format
 msgid "-Wformat-zero-length ignored without -Wformat"
 msgstr "-Wformat-zero-length ignoreret uden -Wformat"
 
-#: c-family/c-opts.c:886
+#: c-family/c-opts.c:884
 #, gcc-internal-format
 msgid "-Wformat-nonliteral ignored without -Wformat"
 msgstr "-Wformat-nonliteral ignoreret uden -Wformat"
 
-#: c-family/c-opts.c:888
+#: c-family/c-opts.c:886
 #, fuzzy, gcc-internal-format
 #| msgid "-Wformat-nonliteral ignored without -Wformat"
 msgid "-Wformat-contains-nul ignored without -Wformat"
 msgstr "-Wformat-nonliteral ignoreret uden -Wformat"
 
-#: c-family/c-opts.c:890
+#: c-family/c-opts.c:888
 #, gcc-internal-format
 msgid "-Wformat-security ignored without -Wformat"
 msgstr "-Wformat-security ignoreret uden -Wformat"
 
-#: c-family/c-opts.c:928
+#: c-family/c-opts.c:918
 #, fuzzy, gcc-internal-format
 #| msgid "-traditional is not supported in C++"
 msgid "%<-fabi-compat-version=1%> is not supported, using =2"
 msgstr "-traditional understøttes ikke i C++"
 
-#: c-family/c-opts.c:988
+#: c-family/c-opts.c:944
+#, gcc-internal-format
+msgid "-Wabi won't warn about anything"
+msgstr ""
+
+#: c-family/c-opts.c:946
+#, gcc-internal-format
+msgid "-Wabi warns about differences from the most up-to-date ABI, which is also used by default"
+msgstr ""
+
+#: c-family/c-opts.c:949
+#, gcc-internal-format
+msgid "use e.g. -Wabi=11 to warn about changes from GCC 7"
+msgstr ""
+
+#: c-family/c-opts.c:1003
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "external TLS initialization functions not supported on this target"
 msgstr "stakgrænser understøttes ikke på målarkitekturen"
 
-#: c-family/c-opts.c:1001
+#: c-family/c-opts.c:1016
 #, gcc-internal-format, gfc-internal-format
 msgid "too many filenames given.  Type %s --help for usage"
 msgstr "for mange filnavne angivet - vejledning i brug kan fås med '%s --help'"
 
-#: c-family/c-opts.c:1016
+#: c-family/c-opts.c:1031
 #, fuzzy, gcc-internal-format
 msgid "opening output file %s: %m"
 msgstr "åbner uddatafilen %s"
 
-#: c-family/c-opts.c:1036
+#: c-family/c-opts.c:1051
 #, gcc-internal-format, gfc-internal-format
 msgid "the \"%s\" debug format cannot be used with pre-compiled headers"
 msgstr ""
 
-#: c-family/c-opts.c:1190
+#: c-family/c-opts.c:1205
 #, fuzzy, gcc-internal-format
 msgid "opening dependency file %s: %m"
 msgstr "åbner afhængighedsfilen %s"
 
-#: c-family/c-opts.c:1201
+#: c-family/c-opts.c:1216
 #, fuzzy, gcc-internal-format
 msgid "closing dependency file %s: %m"
 msgstr "lukker afhængighedsfilen %s"
 
-#: c-family/c-opts.c:1204
+#: c-family/c-opts.c:1219
 #, fuzzy, gcc-internal-format
 msgid "when writing output to %s: %m"
 msgstr "ved skrivning af uddata til %s"
 
-#: c-family/c-opts.c:1284
+#: c-family/c-opts.c:1299
 #, gcc-internal-format
 msgid "to generate dependencies you must specify either -M or -MM"
 msgstr "for at generere afhængigheder skal du angive enten -M eller -MM"
 
-#: c-family/c-opts.c:1307
+#: c-family/c-opts.c:1322
 #, fuzzy, gcc-internal-format
 #| msgid "-mn is used without -mh or -ms"
 msgid "-MG may only be used with -M or -MM"
 msgstr "-mn benyttet uden -mh eller -ms"
 
-#: c-family/c-opts.c:1340
+#: c-family/c-opts.c:1355
 #, gcc-internal-format
 msgid "-fdirectives-only is incompatible with -Wunused_macros"
 msgstr ""
 
-#: c-family/c-opts.c:1342
+#: c-family/c-opts.c:1357
 #, gcc-internal-format
 msgid "-fdirectives-only is incompatible with -traditional"
 msgstr ""
 
-#: c-family/c-opts.c:1534
+#: c-family/c-opts.c:1549
 #, gcc-internal-format
 msgid "too late for # directive to set debug directory"
 msgstr ""
@@ -29753,382 +29799,382 @@
 msgid "wrong type argument to %s"
 msgstr "forkert parametertype til %s"
 
-#: c-family/c-warn.c:53 c-family/c-warn.c:66 cp/constexpr.c:1847
+#: c-family/c-warn.c:54 c-family/c-warn.c:67 cp/constexpr.c:1847
 #: cp/constexpr.c:4099
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: c-family/c-warn.c:93
+#: c-family/c-warn.c:94
 #, fuzzy, gcc-internal-format
 #| msgid "integer overflow in preprocessor expression"
 msgid "integer overflow in expression %qE of type %qT results in %qE"
 msgstr "heltallet løber over i præprocessorudtrykket"
 
-#: c-family/c-warn.c:95
+#: c-family/c-warn.c:96
 #, fuzzy, gcc-internal-format
 #| msgid "integer overflow in preprocessor expression"
 msgid "integer overflow in expression of type %qT results in %qE"
 msgstr "heltallet løber over i præprocessorudtrykket"
 
-#: c-family/c-warn.c:101
+#: c-family/c-warn.c:102
 #, fuzzy, gcc-internal-format
 #| msgid "floating point overflow in expression"
 msgid "floating point overflow in expression %qE of type %qT results in %qE"
 msgstr "kommatalsoverløb i udtryk"
 
-#: c-family/c-warn.c:103
+#: c-family/c-warn.c:104
 #, fuzzy, gcc-internal-format
 #| msgid "floating point overflow in expression"
 msgid "floating point overflow in expression of type %qT results in %qE"
 msgstr "kommatalsoverløb i udtryk"
 
-#: c-family/c-warn.c:109
+#: c-family/c-warn.c:110
 #, fuzzy, gcc-internal-format
 #| msgid "floating point overflow in expression"
 msgid "fixed-point overflow in expression %qE of type %qT results in %qE"
 msgstr "kommatalsoverløb i udtryk"
 
-#: c-family/c-warn.c:111
+#: c-family/c-warn.c:112
 #, fuzzy, gcc-internal-format
 #| msgid "floating point overflow in expression"
 msgid "fixed-point overflow in expression of type %qT results in %qE"
 msgstr "kommatalsoverløb i udtryk"
 
-#: c-family/c-warn.c:117
+#: c-family/c-warn.c:118
 #, fuzzy, gcc-internal-format
 #| msgid "vector overflow in expression"
 msgid "vector overflow in expression %qE of type %qT results in %qE"
 msgstr "vektoroverløb i udtryk"
 
-#: c-family/c-warn.c:119
+#: c-family/c-warn.c:120
 #, fuzzy, gcc-internal-format
 #| msgid "vector overflow in expression"
 msgid "vector overflow in expression of type %qT results in %qE"
 msgstr "vektoroverløb i udtryk"
 
-#: c-family/c-warn.c:126
+#: c-family/c-warn.c:127
 #, fuzzy, gcc-internal-format
 #| msgid "integer overflow in expression"
 msgid "complex integer overflow in expression %qE of type %qT results in %qE"
 msgstr "heltalsoverløb i udtryk"
 
-#: c-family/c-warn.c:128
+#: c-family/c-warn.c:129
 #, fuzzy, gcc-internal-format
 #| msgid "integer overflow in expression"
 msgid "complex integer overflow in expression of type %qT results in %qE"
 msgstr "heltalsoverløb i udtryk"
 
-#: c-family/c-warn.c:132
+#: c-family/c-warn.c:133
 #, fuzzy, gcc-internal-format
 #| msgid "floating point overflow in expression"
 msgid "complex floating point overflow in expression %qE of type %qT results in %qE"
 msgstr "kommatalsoverløb i udtryk"
 
-#: c-family/c-warn.c:134
+#: c-family/c-warn.c:135
 #, fuzzy, gcc-internal-format
 #| msgid "floating point overflow in expression"
 msgid "complex floating point overflow in expression of type %qT results in %qE"
 msgstr "kommatalsoverløb i udtryk"
 
-#: c-family/c-warn.c:216
+#: c-family/c-warn.c:217
 #, gcc-internal-format
 msgid "logical %<or%> applied to non-boolean constant"
 msgstr ""
 
-#: c-family/c-warn.c:219
+#: c-family/c-warn.c:220
 #, gcc-internal-format
 msgid "logical %<and%> applied to non-boolean constant"
 msgstr ""
 
-#: c-family/c-warn.c:289
+#: c-family/c-warn.c:290
 #, gcc-internal-format
 msgid "logical %<or%> of collectively exhaustive tests is always true"
 msgstr ""
 
-#: c-family/c-warn.c:293
+#: c-family/c-warn.c:294
 #, fuzzy, gcc-internal-format
 #| msgid "`and' of mutually exclusive equal-tests is always 0"
 msgid "logical %<and%> of mutually exclusive tests is always false"
 msgstr "'and' af udtryk der hver for sig udelukker hinanden, er altid 0"
 
-#: c-family/c-warn.c:303
+#: c-family/c-warn.c:304
 #, fuzzy, gcc-internal-format
 #| msgid "invalid token in expression"
 msgid "logical %<or%> of equal expressions"
 msgstr "ugyldigt symbol udtryk"
 
-#: c-family/c-warn.c:306
+#: c-family/c-warn.c:307
 #, fuzzy, gcc-internal-format
 #| msgid "`and' of mutually exclusive equal-tests is always 0"
 msgid "logical %<and%> of equal expressions"
 msgstr "'and' af udtryk der hver for sig udelukker hinanden, er altid 0"
 
-#: c-family/c-warn.c:384
+#: c-family/c-warn.c:385
 #, fuzzy, gcc-internal-format
 #| msgid "user-defined `%D' always evaluates both arguments"
 msgid "bitwise comparison always evaluates to false"
 msgstr "brugerdefineret '%D' evaluerer altid begge parametre"
 
-#: c-family/c-warn.c:387
+#: c-family/c-warn.c:388
 #, fuzzy, gcc-internal-format
 #| msgid "user-defined `%D' always evaluates both arguments"
 msgid "bitwise comparison always evaluates to true"
 msgstr "brugerdefineret '%D' evaluerer altid begge parametre"
 
-#: c-family/c-warn.c:441
+#: c-family/c-warn.c:442
 #, fuzzy, gcc-internal-format
 #| msgid "user-defined `%D' always evaluates both arguments"
 msgid "self-comparison always evaluates to true"
 msgstr "brugerdefineret '%D' evaluerer altid begge parametre"
 
-#: c-family/c-warn.c:444
+#: c-family/c-warn.c:445
 #, fuzzy, gcc-internal-format
 #| msgid "user-defined `%D' always evaluates both arguments"
 msgid "self-comparison always evaluates to false"
 msgstr "brugerdefineret '%D' evaluerer altid begge parametre"
 
-#: c-family/c-warn.c:494
+#: c-family/c-warn.c:495
 #, gcc-internal-format
 msgid "logical not is only applied to the left hand side of comparison"
 msgstr ""
 
-#: c-family/c-warn.c:502
+#: c-family/c-warn.c:503
 #, gcc-internal-format
 msgid "add parentheses around left hand side expression to silence this warning"
 msgstr ""
 
-#: c-family/c-warn.c:636
+#: c-family/c-warn.c:637
 #, gcc-internal-format
 msgid "type-punning to incomplete type might break strict-aliasing rules"
 msgstr "typeomtvingning af ufuldstændig type bryder muligvis strenge aliasregler"
 
-#: c-family/c-warn.c:654
+#: c-family/c-warn.c:655
 #, gcc-internal-format
 msgid "dereferencing type-punned pointer will break strict-aliasing rules"
 msgstr "følgning af en typeomtvunget henvisning vil bryde strenge aliasregler"
 
-#: c-family/c-warn.c:662 c-family/c-warn.c:680
+#: c-family/c-warn.c:663 c-family/c-warn.c:681
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing type-punned pointer will break strict-aliasing rules"
 msgid "dereferencing type-punned pointer might break strict-aliasing rules"
 msgstr "følgning af en typeomtvunget henvisning vil bryde strenge aliasregler"
 
-#: c-family/c-warn.c:803
+#: c-family/c-warn.c:811
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to use the size of the destination?"
 msgstr ""
 
-#: c-family/c-warn.c:834
+#: c-family/c-warn.c:842
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the destination; did you mean to remove the addressof?"
 msgstr ""
 
-#: c-family/c-warn.c:841
+#: c-family/c-warn.c:849
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the destination; did you mean to provide an explicit length?"
 msgstr ""
 
-#: c-family/c-warn.c:846
+#: c-family/c-warn.c:854
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the destination; did you mean to dereference it?"
 msgstr ""
 
-#: c-family/c-warn.c:858
+#: c-family/c-warn.c:866
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the destination; expected %qT or an explicit length"
 msgstr ""
 
-#: c-family/c-warn.c:874
+#: c-family/c-warn.c:882
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to remove the addressof?"
 msgstr ""
 
-#: c-family/c-warn.c:881
+#: c-family/c-warn.c:889
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to provide an explicit length?"
 msgstr ""
 
-#: c-family/c-warn.c:886
+#: c-family/c-warn.c:894
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to dereference it?"
 msgstr ""
 
-#: c-family/c-warn.c:898
+#: c-family/c-warn.c:906
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the source; expected %qT or an explicit length"
 msgstr ""
 
-#: c-family/c-warn.c:914
+#: c-family/c-warn.c:922
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the first source; did you mean to remove the addressof?"
 msgstr ""
 
-#: c-family/c-warn.c:921
+#: c-family/c-warn.c:929
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the first source; did you mean to provide an explicit length?"
 msgstr ""
 
-#: c-family/c-warn.c:926
+#: c-family/c-warn.c:934
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the first source; did you mean to dereference it?"
 msgstr ""
 
-#: c-family/c-warn.c:938
+#: c-family/c-warn.c:946
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the first source; expected %qT or an explicit length"
 msgstr ""
 
-#: c-family/c-warn.c:954
+#: c-family/c-warn.c:962
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the second source; did you mean to remove the addressof?"
 msgstr ""
 
-#: c-family/c-warn.c:961
+#: c-family/c-warn.c:969
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the second source; did you mean to provide an explicit length?"
 msgstr ""
 
-#: c-family/c-warn.c:966
+#: c-family/c-warn.c:974
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the second source; did you mean to dereference it?"
 msgstr ""
 
-#: c-family/c-warn.c:978
+#: c-family/c-warn.c:986
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the second source; expected %qT or an explicit length"
 msgstr ""
 
-#: c-family/c-warn.c:1007 c-family/c-warn.c:1014
+#: c-family/c-warn.c:1015 c-family/c-warn.c:1022
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter type `%T'"
 msgid "%<_Atomic%>-qualified parameter type %qT of %q+D"
 msgstr "ugyldig parametertype '%T'"
 
-#: c-family/c-warn.c:1024
+#: c-family/c-warn.c:1032
 #, fuzzy, gcc-internal-format
 msgid "first argument of %q+D should be %<int%>"
 msgstr "den første parameter til '%s' skal være 'int'"
 
-#: c-family/c-warn.c:1033
+#: c-family/c-warn.c:1041
 #, fuzzy, gcc-internal-format
 msgid "second argument of %q+D should be %<char **%>"
 msgstr "den anden parameter til '%s' skal være 'char **'"
 
-#: c-family/c-warn.c:1042
+#: c-family/c-warn.c:1050
 #, fuzzy, gcc-internal-format
 msgid "third argument of %q+D should probably be %<char **%>"
 msgstr "den tredje parameter til '%s' skal sandsynligvis være 'char **'"
 
-#: c-family/c-warn.c:1053
+#: c-family/c-warn.c:1061
 #, fuzzy, gcc-internal-format
 msgid "%q+D takes only zero or two arguments"
 msgstr "'%s' tager kun mod to eller ingen parametre"
 
-#: c-family/c-warn.c:1057
+#: c-family/c-warn.c:1065
 #, fuzzy, gcc-internal-format
 #| msgid "field `%s' declared as a function"
 msgid "%q+D declared as variadic function"
 msgstr "feltet '%s' er erklæret som en funktion"
 
-#: c-family/c-warn.c:1099
+#: c-family/c-warn.c:1107
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to incomplete type"
 msgid "conversion to %qT from boolean expression"
 msgstr "konvertering til en ufuldstændig type"
 
-#: c-family/c-warn.c:1117 c-family/c-warn.c:1192
+#: c-family/c-warn.c:1125 c-family/c-warn.c:1200
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from `%T' to `%T' discards qualifiers"
 msgid "conversion from %qT to %qT changes value from %qE to %qE"
 msgstr "konvertering fra '%T' til '%T' forkaster modifikationer"
 
-#: c-family/c-warn.c:1121 c-family/c-warn.c:1200
+#: c-family/c-warn.c:1129 c-family/c-warn.c:1208
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from `%T' to `%T' is ambiguous"
 msgid "conversion from %qT to %qT changes the value of %qE"
 msgstr "konvertering fra '%T' til '%T' er tvetydigt"
 
-#: c-family/c-warn.c:1141
+#: c-family/c-warn.c:1149
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from `%T' to `%T' discards qualifiers"
 msgid "conversion from %qT to %qT discards imaginary component"
 msgstr "konvertering fra '%T' til '%T' forkaster modifikationer"
 
-#: c-family/c-warn.c:1153
+#: c-family/c-warn.c:1161
 #, fuzzy, gcc-internal-format
 #| msgid "conversion of `%E' from `%T' to `%T' is ambiguous"
 msgid "conversion from %qT to %qT may change value"
 msgstr "konvertering af '%E' fra '%T' til '%T' er tvetydigt"
 
-#: c-family/c-warn.c:1213 c-family/c-warn.c:1230 c-family/c-warn.c:1247
+#: c-family/c-warn.c:1221 c-family/c-warn.c:1238 c-family/c-warn.c:1255
 #, fuzzy, gcc-internal-format
 #| msgid "conversion of `%E' from `%T' to `%T' is ambiguous"
 msgid "overflow in conversion from %qT to %qT changes value from %qE to %qE"
 msgstr "konvertering af '%E' fra '%T' til '%T' er tvetydigt"
 
-#: c-family/c-warn.c:1218 c-family/c-warn.c:1235 c-family/c-warn.c:1252
+#: c-family/c-warn.c:1226 c-family/c-warn.c:1243 c-family/c-warn.c:1260
 #, fuzzy, gcc-internal-format
 #| msgid "conversion of `%E' from `%T' to `%T' is ambiguous"
 msgid "overflow in conversion from %qT to %qT changes the value of %qE"
 msgstr "konvertering af '%E' fra '%T' til '%T' er tvetydigt"
 
-#: c-family/c-warn.c:1282
+#: c-family/c-warn.c:1290
 #, fuzzy, gcc-internal-format
 #| msgid "case value `%ld' not in enumerated type"
 msgid "case value %qs not in enumerated type"
 msgstr "case-værdien '%ld' eksisterer ikke i enum-type"
 
-#: c-family/c-warn.c:1287
+#: c-family/c-warn.c:1295
 #, fuzzy, gcc-internal-format
 #| msgid "case value `%ld' not in enumerated type"
 msgid "case value %qs not in enumerated type %qT"
 msgstr "case-værdien '%ld' eksisterer ikke i enum-type"
 
-#: c-family/c-warn.c:1348
+#: c-family/c-warn.c:1356
 #, gcc-internal-format
 msgid "switch missing default case"
 msgstr "switch-konstruktion mangler default"
 
-#: c-family/c-warn.c:1393
+#: c-family/c-warn.c:1401
 #, fuzzy, gcc-internal-format
 #| msgid "the conditional began here"
 msgid "switch condition has boolean value"
 msgstr "betingelsen begyndte her"
 
-#: c-family/c-warn.c:1466
+#: c-family/c-warn.c:1474
 #, fuzzy, gcc-internal-format
 #| msgid "enumeration value `%s' not handled in switch"
 msgid "enumeration value %qE not handled in switch"
 msgstr "enum-værdien '%s' håndteres ikke i switch-sætning"
 
-#: c-family/c-warn.c:1494
+#: c-family/c-warn.c:1502
 #, gcc-internal-format
 msgid "the omitted middle operand in ?: will always be %<true%>, suggest explicit middle operand"
 msgstr ""
 
-#: c-family/c-warn.c:1515
+#: c-family/c-warn.c:1523
 #, gcc-internal-format
 msgid "assignment of member %qD in read-only object"
 msgstr ""
 
-#: c-family/c-warn.c:1517
+#: c-family/c-warn.c:1525
 #, gcc-internal-format
 msgid "increment of member %qD in read-only object"
 msgstr ""
 
-#: c-family/c-warn.c:1519
+#: c-family/c-warn.c:1527
 #, gcc-internal-format
 msgid "decrement of member %qD in read-only object"
 msgstr ""
 
-#: c-family/c-warn.c:1521
+#: c-family/c-warn.c:1529
 #, gcc-internal-format
 msgid "member %qD in read-only object used as %<asm%> output"
 msgstr ""
 
 # RETMIG: lettere klodset konstruktion
-#: c-family/c-warn.c:1525
+#: c-family/c-warn.c:1533
 #, fuzzy, gcc-internal-format
 #| msgid "%s of read-only member `%s'"
 msgid "assignment of read-only member %qD"
@@ -30135,7 +30181,7 @@
 msgstr "%s af medlemmet '%s' der kun må læses"
 
 # RETMIG: lettere klodset konstruktion
-#: c-family/c-warn.c:1526
+#: c-family/c-warn.c:1534
 #, fuzzy, gcc-internal-format
 #| msgid "%s of read-only member `%s'"
 msgid "increment of read-only member %qD"
@@ -30142,42 +30188,42 @@
 msgstr "%s af medlemmet '%s' der kun må læses"
 
 # RETMIG: lettere klodset konstruktion
-#: c-family/c-warn.c:1527
+#: c-family/c-warn.c:1535
 #, fuzzy, gcc-internal-format
 #| msgid "%s of read-only member `%s'"
 msgid "decrement of read-only member %qD"
 msgstr "%s af medlemmet '%s' der kun må læses"
 
-#: c-family/c-warn.c:1528
+#: c-family/c-warn.c:1536
 #, gcc-internal-format
 msgid "read-only member %qD used as %<asm%> output"
 msgstr ""
 
-#: c-family/c-warn.c:1532
+#: c-family/c-warn.c:1540
 #, fuzzy, gcc-internal-format
 #| msgid "%s of read-only variable `%s'"
 msgid "assignment of read-only variable %qD"
 msgstr "%s af variablen '%s' der kun må læses"
 
-#: c-family/c-warn.c:1533
+#: c-family/c-warn.c:1541
 #, fuzzy, gcc-internal-format
 #| msgid "%s of read-only variable `%s'"
 msgid "increment of read-only variable %qD"
 msgstr "%s af variablen '%s' der kun må læses"
 
-#: c-family/c-warn.c:1534
+#: c-family/c-warn.c:1542
 #, fuzzy, gcc-internal-format
 #| msgid "%s of read-only variable `%s'"
 msgid "decrement of read-only variable %qD"
 msgstr "%s af variablen '%s' der kun må læses"
 
-#: c-family/c-warn.c:1535
+#: c-family/c-warn.c:1543
 #, gcc-internal-format
 msgid "read-only variable %qD used as %<asm%> output"
 msgstr ""
 
 # RETMIG: lettere klodset konstruktion
-#: c-family/c-warn.c:1538
+#: c-family/c-warn.c:1546
 #, fuzzy, gcc-internal-format
 #| msgid "%s of read-only member `%s'"
 msgid "assignment of read-only parameter %qD"
@@ -30184,7 +30230,7 @@
 msgstr "%s af medlemmet '%s' der kun må læses"
 
 # RETMIG: lettere klodset konstruktion
-#: c-family/c-warn.c:1539
+#: c-family/c-warn.c:1547
 #, fuzzy, gcc-internal-format
 #| msgid "%s of read-only member `%s'"
 msgid "increment of read-only parameter %qD"
@@ -30191,279 +30237,279 @@
 msgstr "%s af medlemmet '%s' der kun må læses"
 
 # RETMIG: lettere klodset konstruktion
-#: c-family/c-warn.c:1540
+#: c-family/c-warn.c:1548
 #, fuzzy, gcc-internal-format
 #| msgid "%s of read-only member `%s'"
 msgid "decrement of read-only parameter %qD"
 msgstr "%s af medlemmet '%s' der kun må læses"
 
-#: c-family/c-warn.c:1541
+#: c-family/c-warn.c:1549
 #, gcc-internal-format
 msgid "read-only parameter %qD use as %<asm%> output"
 msgstr ""
 
-#: c-family/c-warn.c:1546
+#: c-family/c-warn.c:1554
 #, gcc-internal-format
 msgid "assignment of read-only named return value %qD"
 msgstr ""
 
-#: c-family/c-warn.c:1548
+#: c-family/c-warn.c:1556
 #, gcc-internal-format
 msgid "increment of read-only named return value %qD"
 msgstr ""
 
-#: c-family/c-warn.c:1550
+#: c-family/c-warn.c:1558
 #, gcc-internal-format
 msgid "decrement of read-only named return value %qD"
 msgstr ""
 
-#: c-family/c-warn.c:1552
+#: c-family/c-warn.c:1560
 #, gcc-internal-format
 msgid "read-only named return value %qD used as %<asm%>output"
 msgstr ""
 
-#: c-family/c-warn.c:1557
+#: c-family/c-warn.c:1565
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function `%s'"
 msgid "assignment of function %qD"
 msgstr "for få parametre til funktionen '%s'"
 
-#: c-family/c-warn.c:1558
+#: c-family/c-warn.c:1566
 #, fuzzy, gcc-internal-format
 #| msgid "In statement function"
 msgid "increment of function %qD"
 msgstr "I sætningsfunktion"
 
-#: c-family/c-warn.c:1559
+#: c-family/c-warn.c:1567
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function `%s'"
 msgid "decrement of function %qD"
 msgstr "for få parametre til funktionen '%s'"
 
-#: c-family/c-warn.c:1560
+#: c-family/c-warn.c:1568
 #, gcc-internal-format
 msgid "function %qD used as %<asm%> output"
 msgstr ""
 
-#: c-family/c-warn.c:1563 c/c-typeck.c:4762
+#: c-family/c-warn.c:1571 c/c-typeck.c:4767
 #, fuzzy, gcc-internal-format
 #| msgid "%s of read-only location"
 msgid "assignment of read-only location %qE"
 msgstr "%s af placering der kun må læses"
 
-#: c-family/c-warn.c:1564 c/c-typeck.c:4765
+#: c-family/c-warn.c:1572 c/c-typeck.c:4770
 #, fuzzy, gcc-internal-format
 #| msgid "%s of read-only location"
 msgid "increment of read-only location %qE"
 msgstr "%s af placering der kun må læses"
 
-#: c-family/c-warn.c:1565 c/c-typeck.c:4768
+#: c-family/c-warn.c:1573 c/c-typeck.c:4773
 #, fuzzy, gcc-internal-format
 #| msgid "%s of read-only location"
 msgid "decrement of read-only location %qE"
 msgstr "%s af placering der kun må læses"
 
-#: c-family/c-warn.c:1566
+#: c-family/c-warn.c:1574
 #, gcc-internal-format
 msgid "read-only location %qE used as %<asm%> output"
 msgstr ""
 
-#: c-family/c-warn.c:1580
+#: c-family/c-warn.c:1588
 #, fuzzy, gcc-internal-format
 #| msgid "invalid lvalue in assignment"
 msgid "lvalue required as left operand of assignment"
 msgstr "ugyldig venstreværdi i tildeling"
 
-#: c-family/c-warn.c:1583
+#: c-family/c-warn.c:1591
 #, gcc-internal-format
 msgid "lvalue required as increment operand"
 msgstr ""
 
-#: c-family/c-warn.c:1586
+#: c-family/c-warn.c:1594
 #, gcc-internal-format
 msgid "lvalue required as decrement operand"
 msgstr ""
 
-#: c-family/c-warn.c:1589
+#: c-family/c-warn.c:1597
 #, gcc-internal-format
 msgid "lvalue required as unary %<&%> operand"
 msgstr ""
 
-#: c-family/c-warn.c:1592
+#: c-family/c-warn.c:1600
 #, fuzzy, gcc-internal-format
 #| msgid "invalid lvalue in asm statement"
 msgid "lvalue required in asm statement"
 msgstr "ugyldig venstreværdi i asm-sætning"
 
-#: c-family/c-warn.c:1609
+#: c-family/c-warn.c:1617
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "invalid type argument (have %qT)"
 msgstr "ugyldig typeparameter"
 
-#: c-family/c-warn.c:1613
+#: c-family/c-warn.c:1621
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument of `%s'"
 msgid "invalid type argument of array indexing (have %qT)"
 msgstr "ugyldig typeparameter '%s'"
 
-#: c-family/c-warn.c:1618
+#: c-family/c-warn.c:1626
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument of `%s'"
 msgid "invalid type argument of unary %<*%> (have %qT)"
 msgstr "ugyldig typeparameter '%s'"
 
-#: c-family/c-warn.c:1623
+#: c-family/c-warn.c:1631
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument of `%s'"
 msgid "invalid type argument of %<->%> (have %qT)"
 msgstr "ugyldig typeparameter '%s'"
 
-#: c-family/c-warn.c:1628
+#: c-family/c-warn.c:1636
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument of `%s'"
 msgid "invalid type argument of %<->*%> (have %qT)"
 msgstr "ugyldig typeparameter '%s'"
 
-#: c-family/c-warn.c:1633
+#: c-family/c-warn.c:1641
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument of `%s'"
 msgid "invalid type argument of implicit conversion (have %qT)"
 msgstr "ugyldig typeparameter '%s'"
 
-#: c-family/c-warn.c:1654
+#: c-family/c-warn.c:1662
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript has type `char'"
 msgid "array subscript has type %<char%>"
 msgstr "tabelindeks er af typen 'char'"
 
-#: c-family/c-warn.c:1689 c-family/c-warn.c:1692
+#: c-family/c-warn.c:1697 c-family/c-warn.c:1700
 #, fuzzy, gcc-internal-format
 #| msgid "suggest parentheses around + or - inside shift"
 msgid "suggest parentheses around %<+%> inside %<<<%>"
 msgstr "foreslår paranteser omkring + eller - inden i skifteoperation"
 
-#: c-family/c-warn.c:1695 c-family/c-warn.c:1698
+#: c-family/c-warn.c:1703 c-family/c-warn.c:1706
 #, fuzzy, gcc-internal-format
 #| msgid "suggest parentheses around + or - inside shift"
 msgid "suggest parentheses around %<-%> inside %<<<%>"
 msgstr "foreslår paranteser omkring + eller - inden i skifteoperation"
 
-#: c-family/c-warn.c:1704 c-family/c-warn.c:1707
+#: c-family/c-warn.c:1712 c-family/c-warn.c:1715
 #, fuzzy, gcc-internal-format
 #| msgid "suggest parentheses around + or - inside shift"
 msgid "suggest parentheses around %<+%> inside %<>>%>"
 msgstr "foreslår paranteser omkring + eller - inden i skifteoperation"
 
-#: c-family/c-warn.c:1710 c-family/c-warn.c:1713
+#: c-family/c-warn.c:1718 c-family/c-warn.c:1721
 #, fuzzy, gcc-internal-format
 #| msgid "suggest parentheses around + or - inside shift"
 msgid "suggest parentheses around %<-%> inside %<>>%>"
 msgstr "foreslår paranteser omkring + eller - inden i skifteoperation"
 
-#: c-family/c-warn.c:1719 c-family/c-warn.c:1722
+#: c-family/c-warn.c:1727 c-family/c-warn.c:1730
 #, fuzzy, gcc-internal-format
 #| msgid "suggest parentheses around && within ||"
 msgid "suggest parentheses around %<&&%> within %<||%>"
 msgstr "foreslår paranteser omkring && inden i ||"
 
-#: c-family/c-warn.c:1729 c-family/c-warn.c:1733
+#: c-family/c-warn.c:1737 c-family/c-warn.c:1741
 #, fuzzy, gcc-internal-format
 #| msgid "suggest parentheses around arithmetic in operand of |"
 msgid "suggest parentheses around arithmetic in operand of %<|%>"
 msgstr "foreslår paranteser omkring beregning i operand til |"
 
-#: c-family/c-warn.c:1737 c-family/c-warn.c:1740
+#: c-family/c-warn.c:1745 c-family/c-warn.c:1748
 #, fuzzy, gcc-internal-format
 #| msgid "suggest parentheses around comparison in operand of |"
 msgid "suggest parentheses around comparison in operand of %<|%>"
 msgstr "foreslår paranteser omkring sammenligning i operand til |"
 
-#: c-family/c-warn.c:1745
+#: c-family/c-warn.c:1753
 #, gcc-internal-format
 msgid "suggest parentheses around operand of %<!%> or change %<|%> to %<||%> or %<!%> to %<~%>"
 msgstr ""
 
-#: c-family/c-warn.c:1753 c-family/c-warn.c:1757
+#: c-family/c-warn.c:1761 c-family/c-warn.c:1765
 #, fuzzy, gcc-internal-format
 #| msgid "suggest parentheses around arithmetic in operand of ^"
 msgid "suggest parentheses around arithmetic in operand of %<^%>"
 msgstr "foreslår paranteser omkring beregning i operand til ^"
 
-#: c-family/c-warn.c:1761 c-family/c-warn.c:1764
+#: c-family/c-warn.c:1769 c-family/c-warn.c:1772
 #, fuzzy, gcc-internal-format
 #| msgid "suggest parentheses around comparison in operand of ^"
 msgid "suggest parentheses around comparison in operand of %<^%>"
 msgstr "foreslår paranteser omkring sammenligning i operand til ^"
 
-#: c-family/c-warn.c:1770 c-family/c-warn.c:1773
+#: c-family/c-warn.c:1778 c-family/c-warn.c:1781
 #, fuzzy, gcc-internal-format
 #| msgid "suggest parentheses around + or - in operand of &"
 msgid "suggest parentheses around %<+%> in operand of %<&%>"
 msgstr "foreslår paranteser omkring + eller - i operand til &"
 
-#: c-family/c-warn.c:1776 c-family/c-warn.c:1779
+#: c-family/c-warn.c:1784 c-family/c-warn.c:1787
 #, fuzzy, gcc-internal-format
 #| msgid "suggest parentheses around + or - in operand of &"
 msgid "suggest parentheses around %<-%> in operand of %<&%>"
 msgstr "foreslår paranteser omkring + eller - i operand til &"
 
-#: c-family/c-warn.c:1783 c-family/c-warn.c:1786
+#: c-family/c-warn.c:1791 c-family/c-warn.c:1794
 #, fuzzy, gcc-internal-format
 #| msgid "suggest parentheses around comparison in operand of &"
 msgid "suggest parentheses around comparison in operand of %<&%>"
 msgstr "foreslår paranteser omkring sammenligning i operand til &"
 
-#: c-family/c-warn.c:1791
+#: c-family/c-warn.c:1799
 #, gcc-internal-format
 msgid "suggest parentheses around operand of %<!%> or change %<&%> to %<&&%> or %<!%> to %<~%>"
 msgstr ""
 
-#: c-family/c-warn.c:1798 c-family/c-warn.c:1801
+#: c-family/c-warn.c:1806 c-family/c-warn.c:1809
 #, fuzzy, gcc-internal-format
 #| msgid "suggest parentheses around comparison in operand of |"
 msgid "suggest parentheses around comparison in operand of %<==%>"
 msgstr "foreslår paranteser omkring sammenligning i operand til |"
 
-#: c-family/c-warn.c:1806 c-family/c-warn.c:1809
+#: c-family/c-warn.c:1814 c-family/c-warn.c:1817
 #, fuzzy, gcc-internal-format
 #| msgid "suggest parentheses around comparison in operand of |"
 msgid "suggest parentheses around comparison in operand of %<!=%>"
 msgstr "foreslår paranteser omkring sammenligning i operand til |"
 
-#: c-family/c-warn.c:1819 c-family/c-warn.c:1825
+#: c-family/c-warn.c:1827 c-family/c-warn.c:1833
 #, fuzzy, gcc-internal-format
 #| msgid "comparisons like X<=Y<=Z do not have their mathematical meaning"
 msgid "comparisons like %<X<=Y<=Z%> do not have their mathematical meaning"
 msgstr "sammenligninger som 'x <= y <= z' følger ikke den matematiske betydning"
 
-#: c-family/c-warn.c:1841
+#: c-family/c-warn.c:1849
 #, fuzzy, gcc-internal-format
 #| msgid "label `%D' defined but not used"
 msgid "label %q+D defined but not used"
 msgstr "etiketten '%D' er defineret, men ikke benyttet"
 
-#: c-family/c-warn.c:1843
+#: c-family/c-warn.c:1851
 #, fuzzy, gcc-internal-format
 msgid "label %q+D declared but not defined"
 msgstr "etiketten '%D' er benyttet, men ikke defineret"
 
-#: c-family/c-warn.c:1866
+#: c-family/c-warn.c:1874
 #, gcc-internal-format
 msgid "division by zero"
 msgstr "division med nul"
 
-#: c-family/c-warn.c:1886
+#: c-family/c-warn.c:1894
 #, gcc-internal-format
 msgid "%<memset%> used with constant zero length parameter; this could be due to transposed parameters"
 msgstr ""
 
-#: c-family/c-warn.c:1909
+#: c-family/c-warn.c:1918
 #, gcc-internal-format
 msgid "%<memset%> used with length equal to number of elements without multiplication by element size"
 msgstr ""
 
-#: c-family/c-warn.c:1948 c/c-typeck.c:11499 c/c-typeck.c:11667
+#: c-family/c-warn.c:1957 c/c-typeck.c:11504 c/c-typeck.c:11672
 #: cp/typeck.c:5048
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between types `%#T' and `%#T'"
@@ -30470,76 +30516,76 @@
 msgid "comparison between types %qT and %qT"
 msgstr "sammenligning mellem typerne '%#T' og '%#T'"
 
-#: c-family/c-warn.c:1998
+#: c-family/c-warn.c:2007
 #, gcc-internal-format
 msgid "comparison of integer expressions of different signedness: %qT and %qT"
 msgstr ""
 
-#: c-family/c-warn.c:2051
+#: c-family/c-warn.c:2060
 #, gcc-internal-format
 msgid "promoted ~unsigned is always non-zero"
 msgstr ""
 
-#: c-family/c-warn.c:2054
+#: c-family/c-warn.c:2063
 #, gcc-internal-format
 msgid "comparison of promoted ~unsigned with constant"
 msgstr "sammenligning af forfremmet ~unsigned med konstant"
 
-#: c-family/c-warn.c:2064
+#: c-family/c-warn.c:2073
 #, gcc-internal-format
 msgid "comparison of promoted ~unsigned with unsigned"
 msgstr "sammenligning af forfremmet ~unsigned med unsigned"
 
-#: c-family/c-warn.c:2118
+#: c-family/c-warn.c:2127
 #, fuzzy, gcc-internal-format
 msgid "unused parameter %qD"
 msgstr "ubenyttet parameter '%s'"
 
-#: c-family/c-warn.c:2180
+#: c-family/c-warn.c:2189
 #, fuzzy, gcc-internal-format
 #| msgid "label `%D' defined but not used"
 msgid "typedef %qD locally defined but not used"
 msgstr "etiketten '%D' er defineret, men ikke benyttet"
 
-#: c-family/c-warn.c:2215
+#: c-family/c-warn.c:2224
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `const'"
 msgid "duplicated %<if%> condition"
 msgstr "'const' optræder mere end én gang"
 
-#: c-family/c-warn.c:2244
+#: c-family/c-warn.c:2253
 #, fuzzy, gcc-internal-format
 msgid "optimization attribute on %qD follows definition but the attribute doesn%'t match"
 msgstr "erklæring af '%s' der er en statisk variabel, i begyndelseserklæring i 'for'-løkke"
 
-#: c-family/c-warn.c:2254
+#: c-family/c-warn.c:2261
 #, fuzzy, gcc-internal-format
 msgid "inline declaration of %qD follows declaration with attribute %qs"
 msgstr "tidligere erklæring af funktionen '%s' med egenskaben noinline"
 
-#: c-family/c-warn.c:2259
+#: c-family/c-warn.c:2266
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q+D with attribute %qs follows inline declaration"
 msgstr "erklæring af '%s' der er en statisk variabel, i begyndelseserklæring i 'for'-løkke"
 
-#: c-family/c-warn.c:2306
+#: c-family/c-warn.c:2313
 #, gcc-internal-format
 msgid "result of %qE requires %u bits to represent, but %qT only has %u bits"
 msgstr ""
 
-#: c-family/c-warn.c:2344 c-family/c-warn.c:2368
+#: c-family/c-warn.c:2351 c-family/c-warn.c:2375
 #, fuzzy, gcc-internal-format
 #| msgid "comparison of unsigned expression < 0 is always false"
 msgid "comparison of constant %qE with boolean expression is always false"
 msgstr "sammenligning med unsigned udtryk < 0 er altid falsk"
 
-#: c-family/c-warn.c:2347 c-family/c-warn.c:2365
+#: c-family/c-warn.c:2354 c-family/c-warn.c:2372
 #, fuzzy, gcc-internal-format
 #| msgid "comparison of unsigned expression >= 0 is always true"
 msgid "comparison of constant %qE with boolean expression is always true"
 msgstr "sammenligning med unsigned udtryk >= 0 er altid sand"
 
-#: c-family/c-warn.c:2415
+#: c-family/c-warn.c:2422
 #, fuzzy
 #| msgid "cast from `%T' to `%T' discards qualifiers from pointer target type"
 msgid "passing argument %i to restrict-qualified parameter aliases with argument %Z"
@@ -30547,18 +30593,18 @@
 msgstr[0] "typeomtvingning fra '%T' til '%T' kasserer modifikationer på henvisningsmålets type"
 msgstr[1] "typeomtvingning fra '%T' til '%T' kasserer modifikationer på henvisningsmålets type"
 
-#: c-family/c-warn.c:2480 c/c-typeck.c:5288 cp/call.c:5365
+#: c-family/c-warn.c:2487 c/c-typeck.c:5293 cp/call.c:5365
 #, fuzzy, gcc-internal-format
 #| msgid "the conditional began here"
 msgid "this condition has identical branches"
 msgstr "betingelsen begyndte her"
 
-#: c-family/c-warn.c:2586
+#: c-family/c-warn.c:2593
 #, gcc-internal-format
 msgid "macro expands to multiple statements"
 msgstr ""
 
-#: c-family/c-warn.c:2587
+#: c-family/c-warn.c:2594
 #, gcc-internal-format
 msgid "some parts of macro expansion are not guarded by this %qs clause"
 msgstr ""
@@ -30573,7 +30619,7 @@
 msgid "too many input files"
 msgstr "for mange inddatafiler"
 
-#: common/config/aarch64/aarch64-common.c:319 config/aarch64/aarch64.c:10686
+#: common/config/aarch64/aarch64-common.c:319 config/aarch64/aarch64.c:10702
 #, gcc-internal-format
 msgid "unknown value %qs for -mcpu"
 msgstr "ukendt værdi %qs for -mcpu"
@@ -30605,7 +30651,7 @@
 msgstr ""
 
 #: common/config/arm/arm-common.c:322 common/config/arm/arm-common.c:376
-#: common/config/arm/arm-common.c:423 config/aarch64/aarch64.c:10639
+#: common/config/arm/arm-common.c:423 config/aarch64/aarch64.c:10655
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "valid arguments are: %s; did you mean %qs?"
@@ -30612,7 +30658,7 @@
 msgstr "ugyldig parameter til egenskaben '%s'"
 
 #: common/config/arm/arm-common.c:325 common/config/arm/arm-common.c:379
-#: common/config/arm/arm-common.c:426 config/aarch64/aarch64.c:10642
+#: common/config/arm/arm-common.c:426 config/aarch64/aarch64.c:10658
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "valid arguments are: %s"
@@ -31117,12 +31163,12 @@
 msgid "profiler support for VxWorks"
 msgstr "function_profiler-understøttelse for MMIX"
 
-#: config/aarch64/aarch64-builtins.c:1109 config/arm/arm-builtins.c:2262
+#: config/aarch64/aarch64-builtins.c:1109 config/arm/arm-builtins.c:2272
 #, fuzzy, gcc-internal-format
 msgid "%Kargument %d must be a constant immediate"
 msgstr "parameteren til 'asm' er ikke en konstant streng"
 
-#: config/aarch64/aarch64-builtins.c:1180 config/arm/arm-builtins.c:2492
+#: config/aarch64/aarch64-builtins.c:1180 config/arm/arm-builtins.c:2502
 #, fuzzy, gcc-internal-format
 #| msgid "mask must be an immediate"
 msgid "%Klane index must be a constant immediate"
@@ -31134,200 +31180,200 @@
 msgid "%Ktotal size and element size must be a non-zero constant immediate"
 msgstr "maske skal være en umiddelbar værdi"
 
-#: config/aarch64/aarch64.c:1053
+#: config/aarch64/aarch64.c:1069
 #, fuzzy, gcc-internal-format
 #| msgid "%s from incompatible pointer type"
 msgid "%qs is incompatible with %s %s"
 msgstr "%s fra en henvisningstype der ikke er forenelig med målets"
 
-#: config/aarch64/aarch64.c:1055
+#: config/aarch64/aarch64.c:1071
 #, fuzzy, gcc-internal-format
 #| msgid "%s from incompatible pointer type"
 msgid "%qs feature modifier is incompatible with %s %s"
 msgstr "%s fra en henvisningstype der ikke er forenelig med målets"
 
-#: config/aarch64/aarch64.c:3772
+#: config/aarch64/aarch64.c:3788
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10287
+#: config/aarch64/aarch64.c:10303
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown flag passed in -moverride=%s (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10331
+#: config/aarch64/aarch64.c:10347
 #, gcc-internal-format, gfc-internal-format
 msgid "%s string ill-formed\n"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10388
+#: config/aarch64/aarch64.c:10404
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid range %s in option %s"
 msgid "tuning string missing in option (%s)"
 msgstr "ugyldigt interval %s i tilvalg %s"
 
-#: config/aarch64/aarch64.c:10406
+#: config/aarch64/aarch64.c:10422
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unknown spec function `%s'"
 msgid "unknown tuning option (%s)"
 msgstr "ukendt specifikationsfunktion '%s'"
 
-#: config/aarch64/aarch64.c:10683
+#: config/aarch64/aarch64.c:10699
 #, fuzzy, gcc-internal-format
 #| msgid "missing argument to \"-%s\""
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr "der mangler en parameter til tilvalget '-%s'"
 
-#: config/aarch64/aarch64.c:10690
+#: config/aarch64/aarch64.c:10706
 #, fuzzy, gcc-internal-format
 #| msgid "unknown machine mode `%s'"
 msgid "invalid feature modifier in %<-mcpu=%s%>"
 msgstr "ukendt maskintilstand '%s'"
 
-#: config/aarch64/aarch64.c:10717
+#: config/aarch64/aarch64.c:10733
 #, fuzzy, gcc-internal-format
 #| msgid "missing argument to \"-%s\""
 msgid "missing arch name in %<-march=%s%>"
 msgstr "der mangler en parameter til tilvalget '-%s'"
 
-#: config/aarch64/aarch64.c:10720
+#: config/aarch64/aarch64.c:10736
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "unknown value %qs for -march"
 msgstr "ugyldig værdi (%s) til tilvalget -march="
 
-#: config/aarch64/aarch64.c:10724
+#: config/aarch64/aarch64.c:10740
 #, fuzzy, gcc-internal-format
 msgid "invalid feature modifier in %<-march=%s%>"
 msgstr "et filnavn mangler efter '-%s'"
 
-#: config/aarch64/aarch64.c:10750
+#: config/aarch64/aarch64.c:10766
 #, fuzzy, gcc-internal-format
 #| msgid "missing argument to \"-%s\""
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr "der mangler en parameter til tilvalget '-%s'"
 
-#: config/aarch64/aarch64.c:10753
+#: config/aarch64/aarch64.c:10769
 #, gcc-internal-format
 msgid "unknown value %qs for -mtune"
 msgstr "ukendt værdi %qs for -mtune"
 
-#: config/aarch64/aarch64.c:10871 config/arm/arm.c:3173
+#: config/aarch64/aarch64.c:10887 config/arm/arm.c:3173
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "switch -mcpu=%s conflicts with -march= switch"
 msgid "switch -mcpu=%s conflicts with -march=%s switch"
 msgstr "tilvalget -mcpu=%s er i konflikt med tilvalget -march="
 
-#: config/aarch64/aarch64.c:10906
+#: config/aarch64/aarch64.c:10922
 #, fuzzy, gcc-internal-format
 msgid "assembler does not support -mabi=ilp32"
 msgstr "%s understøtter ikke %s"
 
-#: config/aarch64/aarch64.c:10913
+#: config/aarch64/aarch64.c:10929
 #, gcc-internal-format
 msgid "return address signing is only supported for -mabi=lp64"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10975
+#: config/aarch64/aarch64.c:10991
 #, gcc-internal-format
 msgid "code model %qs with -f%s"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11138
+#: config/aarch64/aarch64.c:11154
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr "ugyldig værdi (%s) til tilvalget -march="
 
-#: config/aarch64/aarch64.c:11141
+#: config/aarch64/aarch64.c:11157
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "invalid name (\"%s\") in %<target(\"arch=\")%> pragma or attribute"
 msgstr "ugyldig værdi (%s) til tilvalget -march="
 
-#: config/aarch64/aarch64.c:11145 config/aarch64/aarch64.c:11184
-#: config/aarch64/aarch64.c:11257
+#: config/aarch64/aarch64.c:11161 config/aarch64/aarch64.c:11200
+#: config/aarch64/aarch64.c:11273
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "invalid value (\"%s\") in %<target()%> pragma or attribute"
 msgstr "ugyldig værdi (%s) til tilvalget -march="
 
-#: config/aarch64/aarch64.c:11177
+#: config/aarch64/aarch64.c:11193
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr "ugyldig værdi (%s) til tilvalget -march="
 
-#: config/aarch64/aarch64.c:11180
+#: config/aarch64/aarch64.c:11196
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "invalid name (\"%s\") in %<target(\"cpu=\")%> pragma or attribute"
 msgstr "ugyldig værdi (%s) til tilvalget -march="
 
-#: config/aarch64/aarch64.c:11213
+#: config/aarch64/aarch64.c:11229
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -mtune= switch"
 msgid "invalid name (\"%s\") in %<target(\"tune=\")%> pragma or attribute"
 msgstr "ugyldig værdi (%s) til tilvalget -mcpu="
 
-#: config/aarch64/aarch64.c:11253
+#: config/aarch64/aarch64.c:11269
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr "ugyldig værdi (%s) til tilvalget -march="
 
-#: config/aarch64/aarch64.c:11306 config/aarch64/aarch64.c:11483
+#: config/aarch64/aarch64.c:11322 config/aarch64/aarch64.c:11499
 #, fuzzy, gcc-internal-format
 #| msgid "malformed spec function name"
 msgid "malformed %<target()%> pragma or attribute"
 msgstr "forkert udformet specifikationsfunktionsnavn"
 
-#: config/aarch64/aarch64.c:11354
+#: config/aarch64/aarch64.c:11370
 #, fuzzy, gcc-internal-format
 #| msgid "%s only accepts 1 argument"
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr "%s accepterer kun 1 parameter"
 
-#: config/aarch64/aarch64.c:11362
+#: config/aarch64/aarch64.c:11378
 #, fuzzy, gcc-internal-format
 #| msgid "target system does not support the %qs debug format"
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr "målarkitektursystem understøtter ikke %qs-fejlsøgningsformatet"
 
-#: config/aarch64/aarch64.c:11416
+#: config/aarch64/aarch64.c:11432
 #, fuzzy, gcc-internal-format
 #| msgid "\"%s\" is not defined"
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr "\"%s\" er ikke defineret"
 
-#: config/aarch64/aarch64.c:11473 config/arm/arm.c:30742
-#: config/i386/i386.c:5440 config/powerpcspe/powerpcspe.c:39760
-#: config/rs6000/rs6000.c:36904 config/s390/s390.c:15746
+#: config/aarch64/aarch64.c:11489 config/arm/arm.c:30742
+#: config/i386/i386.c:5443 config/powerpcspe/powerpcspe.c:39760
+#: config/rs6000/rs6000.c:36960 config/s390/s390.c:15746
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute argument not a string constant"
 msgid "attribute %<target%> argument not a string"
 msgstr "parameteren til egenskaben '%s' er ikke en strengkonstant"
 
-#: config/aarch64/aarch64.c:11500
+#: config/aarch64/aarch64.c:11516
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute argument not a string constant"
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr "parameteren til egenskaben '%s' er ikke en strengkonstant"
 
-#: config/aarch64/aarch64.c:11509
+#: config/aarch64/aarch64.c:11525
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr "ugyldig værdi (%s) til tilvalget -march="
 
-#: config/aarch64/aarch64.c:13571
+#: config/aarch64/aarch64.c:13587
 #, fuzzy, gcc-internal-format
 #| msgid "line number out of range"
 msgid "%Klane %wd out of range %wd - %wd"
 msgstr "linjenummer er uden for det gyldige interval"
 
-#: config/aarch64/aarch64.c:13573
+#: config/aarch64/aarch64.c:13589
 #, fuzzy, gcc-internal-format
 #| msgid "line number out of range"
 msgid "lane %wd out of range %wd - %wd"
@@ -31395,8 +31441,8 @@
 msgid "bad value %qs for -mmemory-latency"
 msgstr "ugyldig værdi '%s' for -mmemory-latency"
 
-#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6526
-#: config/arc/arc.c:6800 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
+#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6517
+#: config/arc/arc.c:6791 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
 #: config/tilepro/tilepro.c:3108
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -31513,11 +31559,11 @@
 #: config/arm/arm.c:7029 config/avr/avr.c:9718 config/avr/avr.c:9734
 #: config/bfin/bfin.c:4705 config/bfin/bfin.c:4766 config/bfin/bfin.c:4795
 #: config/epiphany/epiphany.c:491 config/h8300/h8300.c:5459
-#: config/i386/i386.c:6452 config/i386/i386.c:12479 config/i386/i386.c:41424
-#: config/i386/i386.c:41474 config/i386/i386.c:41544 config/m68k/m68k.c:780
+#: config/i386/i386.c:6455 config/i386/i386.c:12482 config/i386/i386.c:41418
+#: config/i386/i386.c:41468 config/i386/i386.c:41538 config/m68k/m68k.c:780
 #: config/mcore/mcore.c:3070 config/nvptx/nvptx.c:4611
 #: config/powerpcspe/powerpcspe.c:35785 config/riscv/riscv.c:2698
-#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:32982
+#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:33038
 #: config/rx/rx.c:2719 config/rx/rx.c:2745 config/s390/s390.c:1056
 #: config/s390/s390.c:1143 config/sh/sh.c:8428 config/sh/sh.c:8446
 #: config/sh/sh.c:8470 config/sh/sh.c:8541 config/sh/sh.c:8564
@@ -31528,129 +31574,129 @@
 msgid "%qE attribute only applies to functions"
 msgstr "egenskaben '%s' kan kun anvendes sammen med funktioner"
 
-#: config/arc/arc.c:6425
+#: config/arc/arc.c:6416
 #, fuzzy, gcc-internal-format
 #| msgid "`__builtin_next_arg' called without an argument"
 msgid "__builtin_arc_aligned with non-constant alignment"
 msgstr "`__builtin_next_arg' kaldt uden en parameter"
 
-#: config/arc/arc.c:6433
+#: config/arc/arc.c:6424
 #, fuzzy, gcc-internal-format
 #| msgid "invalid arg to `__builtin_frame_address'"
 msgid "invalid alignment value for __builtin_arc_aligned"
 msgstr "ugyldig parameter til '__builtin_frame_address'"
 
-#: config/arc/arc.c:6596
+#: config/arc/arc.c:6587
 #, fuzzy, gcc-internal-format
 #| msgid "Specify yes/no if isel instructions should be generated"
 msgid "operand 1 should be an unsigned 3-bit immediate"
 msgstr "Angiv yes/no hvis isel-instruktioner skal genereres"
 
-#: config/arc/arc.c:6637 config/arc/arc.c:6734
+#: config/arc/arc.c:6628 config/arc/arc.c:6725
 #, fuzzy, gcc-internal-format
 #| msgid "Specify yes/no if isel instructions should be generated"
 msgid "operand 2 should be an unsigned 3-bit value (I0-I7)"
 msgstr "Angiv yes/no hvis isel-instruktioner skal genereres"
 
-#: config/arc/arc.c:6670 config/arc/arc.c:6702
+#: config/arc/arc.c:6661 config/arc/arc.c:6693
 #, fuzzy, gcc-internal-format
 #| msgid "Specify yes/no if isel instructions should be generated"
 msgid "operand 1 should be an unsigned 3-bit value (I0-I7)"
 msgstr "Angiv yes/no hvis isel-instruktioner skal genereres"
 
-#: config/arc/arc.c:6674 config/arc/arc.c:6706
+#: config/arc/arc.c:6665 config/arc/arc.c:6697
 #, fuzzy, gcc-internal-format
 #| msgid "Specify yes/no if isel instructions should be generated"
 msgid "operand 2 should be an unsigned 8-bit value"
 msgstr "Angiv yes/no hvis isel-instruktioner skal genereres"
 
-#: config/arc/arc.c:6738
+#: config/arc/arc.c:6729
 #, fuzzy, gcc-internal-format
 #| msgid "Specify yes/no if isel instructions should be generated"
 msgid "operand 3 should be an unsigned 8-bit value"
 msgstr "Angiv yes/no hvis isel-instruktioner skal genereres"
 
-#: config/arc/arc.c:6771
+#: config/arc/arc.c:6762
 #, fuzzy, gcc-internal-format
 #| msgid "Specify yes/no if isel instructions should be generated"
 msgid "operand 4 should be an unsigned 8-bit value (0-255)"
 msgstr "Angiv yes/no hvis isel-instruktioner skal genereres"
 
-#: config/arc/arc.c:6775
+#: config/arc/arc.c:6766
 #, fuzzy, gcc-internal-format
 #| msgid "Specify yes/no if isel instructions should be generated"
 msgid "operand 3 should be an unsigned 3-bit value (I0-I7)"
 msgstr "Angiv yes/no hvis isel-instruktioner skal genereres"
 
-#: config/arc/arc.c:6782
+#: config/arc/arc.c:6773
 #, fuzzy, gcc-internal-format
 #| msgid "Specify yes/no if isel instructions should be generated"
 msgid "operand 2 should be an unsigned 3-bit value (subreg 0-7)"
 msgstr "Angiv yes/no hvis isel-instruktioner skal genereres"
 
-#: config/arc/arc.c:6785
+#: config/arc/arc.c:6776
 #, gcc-internal-format
 msgid "operand 2 should be an even 3-bit value (subreg 0,2,4,6)"
 msgstr ""
 
-#: config/arc/arc.c:6832
+#: config/arc/arc.c:6823
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "long long constant not a valid immediate operand"
 msgid "builtin requires an immediate for operand %d"
 msgstr "long long-konstant er ikke en gyldig umiddelbar operand"
 
-#: config/arc/arc.c:6837
+#: config/arc/arc.c:6828
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Specify yes/no if isel instructions should be generated"
 msgid "operand %d should be a 6 bit unsigned immediate"
 msgstr "Angiv yes/no hvis isel-instruktioner skal genereres"
 
-#: config/arc/arc.c:6841
+#: config/arc/arc.c:6832
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Specify yes/no if isel instructions should be generated"
 msgid "operand %d should be a 8 bit unsigned immediate"
 msgstr "Angiv yes/no hvis isel-instruktioner skal genereres"
 
-#: config/arc/arc.c:6845
+#: config/arc/arc.c:6836
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Specify yes/no if isel instructions should be generated"
 msgid "operand %d should be a 3 bit unsigned immediate"
 msgstr "Angiv yes/no hvis isel-instruktioner skal genereres"
 
-#: config/arc/arc.c:6848
+#: config/arc/arc.c:6839
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown builtin immediate operand type for operand %d"
 msgstr ""
 
-#: config/arc/arc.c:6899
+#: config/arc/arc.c:6890
 #, gcc-internal-format
 msgid "register number must be a compile-time constant. Try giving higher optimization levels"
 msgstr ""
 
-#: config/arc/arc.c:7685
+#: config/arc/arc.c:7747
 #, gcc-internal-format
 msgid "Insn addresses not set after shorten_branches"
 msgstr ""
 
-#: config/arc/arc.c:7894
+#: config/arc/arc.c:7956
 #, fuzzy, gcc-internal-format
 #| msgid "pre-increment address is not a register"
 msgid "insn addresses not freed"
 msgstr "præfiks forøgelsesadresse er ikke et register"
 
-#: config/arc/arc.c:10682
+#: config/arc/arc.c:10670
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to variables"
 msgid "%qE attribute only valid for ARCv2 architecture"
 msgstr "egenskaben '%s' kan kun anvendes på variabler"
 
-#: config/arc/arc.c:10690 config/arc/arc.c:10729
+#: config/arc/arc.c:10678 config/arc/arc.c:10717
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `%s' attribute is not \"ilink1\" or \"ilink2\""
 msgid "argument of %qE attribute is missing"
 msgstr "parameteren til egenskaben '%s er ikke \"ilink1\" eller \"ilink2\""
 
-#: config/arc/arc.c:10701 config/arc/arc.c:10740 config/arc/arc.c:10842
+#: config/arc/arc.c:10689 config/arc/arc.c:10728 config/arc/arc.c:10830
 #: config/avr/avr.c:9790
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute requires an integer constant argument"
@@ -31657,25 +31703,25 @@
 msgid "%qE attribute allows only an integer constant argument"
 msgstr "egenskaben '%s' kræver en heltalskonstant som parameter"
 
-#: config/arc/arc.c:10721
+#: config/arc/arc.c:10709
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to function types"
 msgid "%qE attribute only valid for ARC EM architecture"
 msgstr "egenskaben '%s' kan kun anvendes sammen med funktionstyper"
 
-#: config/arc/arc.c:10776
+#: config/arc/arc.c:10764
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to function types"
 msgid "%qE attribute only applies to types"
 msgstr "egenskaben '%s' kan kun anvendes sammen med funktionstyper"
 
-#: config/arc/arc.c:10782
+#: config/arc/arc.c:10770
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `%s' attribute is not \"ilink1\" or \"ilink2\""
 msgid "argument of %qE attribute ignored"
 msgstr "parameteren til egenskaben '%s er ikke \"ilink1\" eller \"ilink2\""
 
-#: config/arc/arc.c:10832 config/avr/avr.c:9777 config/bfin/bfin.c:4827
+#: config/arc/arc.c:10820 config/avr/avr.c:9777 config/bfin/bfin.c:4827
 #: config/i386/winnt.c:63 config/msp430/msp430.c:2018
 #: config/nvptx/nvptx.c:4634
 #, fuzzy, gcc-internal-format
@@ -31683,175 +31729,175 @@
 msgid "%qE attribute only applies to variables"
 msgstr "egenskaben '%s' kan kun anvendes på variabler"
 
-#: config/arm/arm-builtins.c:2370
+#: config/arm/arm-builtins.c:2380
 #, fuzzy, gcc-internal-format
 #| msgid "Profiling is not supported on this target."
 msgid "this builtin is not supported for this target"
 msgstr "Profilering er ikke understøttet på målarkitekturen."
 
-#: config/arm/arm-builtins.c:2475
+#: config/arm/arm-builtins.c:2485
 #, gcc-internal-format
 msgid "You must enable NEON instructions (e.g. -mfloat-abi=softfp -mfpu=neon) to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2513
+#: config/arm/arm-builtins.c:2523
 #, gcc-internal-format
 msgid "You must enable VFP instructions to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2573
+#: config/arm/arm-builtins.c:2583
 #, gcc-internal-format
 msgid "You must enable crypto instructions (e.g. include -mfloat-abi=softfp -mfpu=crypto-neon...) to use these intrinsics."
 msgstr ""
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:2633 config/arm/arm-builtins.c:2737
+#: config/arm/arm-builtins.c:2643 config/arm/arm-builtins.c:2747
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr "vælger skal være en umiddelbar værdi"
 
-#: config/arm/arm-builtins.c:2641 config/arm/arm-builtins.c:2686
-#: config/arm/arm-builtins.c:2744 config/arm/arm-builtins.c:2753
+#: config/arm/arm-builtins.c:2651 config/arm/arm-builtins.c:2696
+#: config/arm/arm-builtins.c:2754 config/arm/arm-builtins.c:2763
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2646 config/arm/arm-builtins.c:2755
+#: config/arm/arm-builtins.c:2656 config/arm/arm-builtins.c:2765
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2651 config/arm/arm-builtins.c:2757
+#: config/arm/arm-builtins.c:2661 config/arm/arm-builtins.c:2767
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2823
+#: config/arm/arm-builtins.c:2833
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr "maske skal være en umiddelbar værdi"
 
-#: config/arm/arm-builtins.c:2828
+#: config/arm/arm-builtins.c:2838
 #, gcc-internal-format
 msgid "the range of mask should be in 0 to 255"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3016
+#: config/arm/arm-builtins.c:3026
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3018
+#: config/arm/arm-builtins.c:3028
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3020
+#: config/arm/arm-builtins.c:3030
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3022
+#: config/arm/arm-builtins.c:3032
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3028
+#: config/arm/arm-builtins.c:3038
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3030
+#: config/arm/arm-builtins.c:3040
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3035
+#: config/arm/arm-builtins.c:3045
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3037
+#: config/arm/arm-builtins.c:3047
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3039
+#: config/arm/arm-builtins.c:3049
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3041
+#: config/arm/arm-builtins.c:3051
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3043
+#: config/arm/arm-builtins.c:3053
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3045
+#: config/arm/arm-builtins.c:3055
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3047
+#: config/arm/arm-builtins.c:3057
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3049
+#: config/arm/arm-builtins.c:3059
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3051
+#: config/arm/arm-builtins.c:3061
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3053
+#: config/arm/arm-builtins.c:3063
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3055
+#: config/arm/arm-builtins.c:3065
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3057
+#: config/arm/arm-builtins.c:3067
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3059
+#: config/arm/arm-builtins.c:3069
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3061
+#: config/arm/arm-builtins.c:3071
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3063
+#: config/arm/arm-builtins.c:3073
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3065
+#: config/arm/arm-builtins.c:3075
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3067
+#: config/arm/arm-builtins.c:3077
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3069
+#: config/arm/arm-builtins.c:3079
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr ""
@@ -32818,578 +32864,578 @@
 msgid "can%'t set position in PCH file: %m"
 msgstr "kan ikke angive position i PCH-filen: %m"
 
-#: config/i386/i386.c:3177
+#: config/i386/i386.c:3180
 #, gcc-internal-format
 msgid "wrong argument %qs to option %qs"
 msgstr "forkert parameter %qs for tilvalget %qs"
 
-#: config/i386/i386.c:3183
+#: config/i386/i386.c:3186
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr ""
 
-#: config/i386/i386.c:3193
+#: config/i386/i386.c:3196
 #, gcc-internal-format
 msgid "wrong strategy name %qs specified for option %qs"
 msgstr "forkert strateginavn %qs er angivet for tilvalget %qs"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3219
+#: config/i386/i386.c:3222
 #, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr "strateginavnet %qs angivet for tilvalget %qs er ikke understøttet for 32-bit kode"
 
-#: config/i386/i386.c:3232
+#: config/i386/i386.c:3235
 #, gcc-internal-format
 msgid "unknown alignment %qs specified for option %qs"
 msgstr "ukendt justering %qs angivet for tilvalget %qs"
 
-#: config/i386/i386.c:3242
+#: config/i386/i386.c:3245
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr ""
 
-#: config/i386/i386.c:3249
+#: config/i386/i386.c:3252
 #, fuzzy, gcc-internal-format
 msgid "too many size ranges specified in option %qs"
 msgstr "intet klassenavn angivet med '-%s'"
 
-#: config/i386/i386.c:3302
+#: config/i386/i386.c:3305
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown parameter to option -mtune-ctrl: %s"
 msgstr "Ukendt processor: -mcpu=%s"
 
-#: config/i386/i386.c:3726
+#: config/i386/i386.c:3729
 #, fuzzy, gcc-internal-format
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "kodemodellen %s er ikke understøttet i PIC-tilstand"
 
-#: config/i386/i386.c:3775
+#: config/i386/i386.c:3778
 #, fuzzy, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "Angiv klassesti (forældet: benyt --classpath i stedet)"
 
-#: config/i386/i386.c:3777
+#: config/i386/i386.c:3780
 #, fuzzy, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr "Angiv klassesti (forældet: benyt --classpath i stedet)"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3804
+#: config/i386/i386.c:3807
 #, gcc-internal-format
 msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386.c:3821
+#: config/i386/i386.c:3824
 #, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "adressetilstanden %qs er ikke understøttet i %s bit-tilstand"
 
-#: config/i386/i386.c:3833
+#: config/i386/i386.c:3836
 #, fuzzy, gcc-internal-format
 #| msgid "-traditional is not supported in C++"
 msgid "-mabi=ms not supported with X32 ABI"
 msgstr "-traditional understøttes ikke i C++"
 
-#: config/i386/i386.c:3851 config/i386/i386.c:3860 config/i386/i386.c:3872
-#: config/i386/i386.c:3883 config/i386/i386.c:3894
+#: config/i386/i386.c:3854 config/i386/i386.c:3863 config/i386/i386.c:3875
+#: config/i386/i386.c:3886 config/i386/i386.c:3897
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "kodemodellen %qs er ikke understøttet i %s bit-tilstand"
 
-#: config/i386/i386.c:3863 config/i386/i386.c:3875
+#: config/i386/i386.c:3866 config/i386/i386.c:3878
 #, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "kodemodellen %qs er ikke understøttet i x32-tilstand"
 
-#: config/i386/i386.c:3881 config/i386/i386.c:3890 config/i386/i386.c:5213
+#: config/i386/i386.c:3884 config/i386/i386.c:3893 config/i386/i386.c:5216
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "kodemodellen %s understøtter ikke PIC-tilstand"
 
-#: config/i386/i386.c:3918
+#: config/i386/i386.c:3921
 #, gcc-internal-format
 msgid "-masm=intel not supported in this configuration"
 msgstr "-masm=intel understøttes ikke af denne konfiguration"
 
-#: config/i386/i386.c:3923
+#: config/i386/i386.c:3926
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "%i bit-tilstand er ikke oversat med ind"
 
-#: config/i386/i386.c:3932
+#: config/i386/i386.c:3935
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386.c:3934
+#: config/i386/i386.c:3937
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386.c:3941
+#: config/i386/i386.c:3944
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386.c:3943
+#: config/i386/i386.c:3946
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386.c:3951 config/i386/i386.c:4265
+#: config/i386/i386.c:3954 config/i386/i386.c:4268
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "den valgte processor understøtter ikke x86-64-instruktionssættet"
 
-#: config/i386/i386.c:4197 config/i386/i386.c:4200
+#: config/i386/i386.c:4200 config/i386/i386.c:4203
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support APCS-32"
 msgid "Intel MPX does not support x32"
 msgstr "målprocessoren understøtter ikke APCS-32"
 
-#: config/i386/i386.c:4205
+#: config/i386/i386.c:4208
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "bad value (%qs) for %<-march=%> switch"
 msgstr "ugyldig værdi (%s) til tilvalget -march="
 
-#: config/i386/i386.c:4206
+#: config/i386/i386.c:4209
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "bad value (%qs) for %<target(\"arch=\")%> attribute"
 msgstr "ugyldig værdi (%s) til tilvalget -march="
 
-#: config/i386/i386.c:4228
+#: config/i386/i386.c:4231
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
-#: config/i386/i386.c:4230
+#: config/i386/i386.c:4233
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
-#: config/i386/i386.c:4235
+#: config/i386/i386.c:4238
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
-#: config/i386/i386.c:4236
+#: config/i386/i386.c:4239
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
-#: config/i386/i386.c:4284
+#: config/i386/i386.c:4287
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -mtune= switch"
 msgid "bad value (%qs) for %<-mtune=%> switch"
 msgstr "ugyldig værdi (%s) til tilvalget -mcpu="
 
-#: config/i386/i386.c:4285
+#: config/i386/i386.c:4288
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -mtune= switch"
 msgid "bad value (%qs) for %<target(\"tune=\")%> attribute"
 msgstr "ugyldig værdi (%s) til tilvalget -mcpu="
 
-#: config/i386/i386.c:4305
+#: config/i386/i386.c:4308
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
-#: config/i386/i386.c:4307
+#: config/i386/i386.c:4310
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
-#: config/i386/i386.c:4312
+#: config/i386/i386.c:4315
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
-#: config/i386/i386.c:4313
+#: config/i386/i386.c:4316
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
-#: config/i386/i386.c:4379
+#: config/i386/i386.c:4382
 #, gcc-internal-format
 msgid "-mregparm is ignored in 64-bit mode"
 msgstr ""
 
-#: config/i386/i386.c:4381
+#: config/i386/i386.c:4384
 #, gcc-internal-format
 msgid "-mregparm is ignored for Intel MCU psABI"
 msgstr ""
 
-#: config/i386/i386.c:4384
+#: config/i386/i386.c:4387
 #, gcc-internal-format, gfc-internal-format
 msgid "-mregparm=%d is not between 0 and %d"
 msgstr "-mregparm=%d er ikke mellem 0 og %d"
 
-#: config/i386/i386.c:4417
+#: config/i386/i386.c:4420
 #, fuzzy, gcc-internal-format
 #| msgid "type defaults to `int' in declaration of `%s'"
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "typen antages at være 'int' i erklæringen af '%s'"
 
-#: config/i386/i386.c:4418
+#: config/i386/i386.c:4421
 #, fuzzy, gcc-internal-format
 #| msgid "type defaults to `int' in declaration of `%s'"
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "typen antages at være 'int' i erklæringen af '%s'"
 
-#: config/i386/i386.c:4497
+#: config/i386/i386.c:4500
 #, fuzzy, gcc-internal-format
 #| msgid "-fprefetch-loop-arrays not supported for this target"
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "-fprefetch-loop-arrays understøttes ikke på målarkitekturen"
 
-#: config/i386/i386.c:4500
+#: config/i386/i386.c:4503
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and 12"
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d er ikke mellem %d og 12"
 
-#: config/i386/i386.c:4523
+#: config/i386/i386.c:4526
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and 12"
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr "-mpreferred-stack-boundary=%d er ikke mellem %d og 12"
 
-#: config/i386/i386.c:4536
+#: config/i386/i386.c:4539
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "-march=%s er ikke forenelig med den valgte ABI"
 
-#: config/i386/i386.c:4539
+#: config/i386/i386.c:4542
 #, gcc-internal-format
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr ""
 
-#: config/i386/i386.c:4545
+#: config/i386/i386.c:4548
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386.c:4546
+#: config/i386/i386.c:4549
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386.c:4556
+#: config/i386/i386.c:4559
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "SSE-instruktionssæt deaktiveret, bruger 387-beregninger"
 
-#: config/i386/i386.c:4563
+#: config/i386/i386.c:4566
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "387-instruktionssæt deaktiveret, bruger SSE-beregninger"
 
-#: config/i386/i386.c:4613
+#: config/i386/i386.c:4616
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr ""
 
-#: config/i386/i386.c:4615
+#: config/i386/i386.c:4618
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr ""
 
-#: config/i386/i386.c:4629
+#: config/i386/i386.c:4632
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr ""
 
-#: config/i386/i386.c:4631
+#: config/i386/i386.c:4634
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr ""
 
-#: config/i386/i386.c:4741
+#: config/i386/i386.c:4744
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr ""
 
-#: config/i386/i386.c:4744
+#: config/i386/i386.c:4747
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr ""
 
-#: config/i386/i386.c:4748
+#: config/i386/i386.c:4751
 #, gcc-internal-format
 msgid "-mcall-ms2sysv-xlogues isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386.c:4813 config/powerpcspe/powerpcspe.c:5663
+#: config/i386/i386.c:4816 config/powerpcspe/powerpcspe.c:5663
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unknown cpu: -mcpu=%s"
 msgid "unknown option for -mrecip=%s"
 msgstr "Ukendt processor: -mcpu=%s"
 
-#: config/i386/i386.c:4870 config/powerpcspe/powerpcspe.c:5339
+#: config/i386/i386.c:4873 config/powerpcspe/powerpcspe.c:5339
 #, gcc-internal-format
 msgid "%qs is not a valid number in -mstack-protector-guard-offset="
 msgstr ""
 
-#: config/i386/i386.c:4875 config/powerpcspe/powerpcspe.c:5344
+#: config/i386/i386.c:4878 config/powerpcspe/powerpcspe.c:5344
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid option to the preprocessor"
 msgid "%qs is not a valid offset in -mstack-protector-guard-offset="
 msgstr "%qs er ikke et gyldigt tilvalg til præprocessoren"
 
-#: config/i386/i386.c:4907 config/powerpcspe/powerpcspe.c:5356
+#: config/i386/i386.c:4910 config/powerpcspe/powerpcspe.c:5356
 #, gcc-internal-format
 msgid "%qs is not a valid base register in -mstack-protector-guard-reg="
 msgstr ""
 
-#: config/i386/i386.c:5506 config/i386/i386.c:5553 config/s390/s390.c:15812
+#: config/i386/i386.c:5509 config/i386/i386.c:5556 config/s390/s390.c:15812
 #: config/s390/s390.c:15862 config/s390/s390.c:15879
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr ""
 
-#: config/i386/i386.c:5534
+#: config/i386/i386.c:5537
 #, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr ""
 
-#: config/i386/i386.c:5837
+#: config/i386/i386.c:5840
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and cdecl attributes are not compatible"
 msgid "interrupt and naked attributes are not compatible"
 msgstr "stdcall og cdecl er indbyrdes uforenelige"
 
-#: config/i386/i386.c:5852
+#: config/i386/i386.c:5855
 #, gcc-internal-format
 msgid "Only DWARF debug format is supported for interrupt service routine."
 msgstr ""
 
-#: config/i386/i386.c:5901
+#: config/i386/i386.c:5904
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s og -mcall-%s er indbyrdes uforenelige"
 
-#: config/i386/i386.c:5913
+#: config/i386/i386.c:5916
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mindirect-branch=thunk-extern%>, %<-fcf-protection=branch%> and %<-fcheck-pointer-bounds%> are not compatible"
 msgstr "-msdata=%s og -mcall-%s er indbyrdes uforenelige"
 
-#: config/i386/i386.c:5949
+#: config/i386/i386.c:5952
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s og -mcall-%s er indbyrdes uforenelige"
 
-#: config/i386/i386.c:6047
+#: config/i386/i386.c:6050
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in %s service routine"
 msgstr "%s-instruktioner er ikke tilladt i %s-tjenesterutinen"
 
-#: config/i386/i386.c:6051
+#: config/i386/i386.c:6054
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in function with no_caller_saved_registers attribute"
 msgstr ""
 
-#: config/i386/i386.c:6465 config/i386/i386.c:6516
+#: config/i386/i386.c:6468 config/i386/i386.c:6519
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "fastcall og regparm er indbyrdes uforenelige"
 
-#: config/i386/i386.c:6470
+#: config/i386/i386.c:6473
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "regparam og thiscall er indbyrdes uforenelige"
 
-#: config/i386/i386.c:6477 config/i386/i386.c:41444
+#: config/i386/i386.c:6480 config/i386/i386.c:41438
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "%qE-egenskaben kræver en heltalskonstant som parameter"
 
-#: config/i386/i386.c:6483
+#: config/i386/i386.c:6486
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "parameter til %qE-egenskaben er større end %d"
 
-#: config/i386/i386.c:6508 config/i386/i386.c:6551
+#: config/i386/i386.c:6511 config/i386/i386.c:6554
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "fastcall og cdecl er indbyrdes uforenelige"
 
-#: config/i386/i386.c:6512
+#: config/i386/i386.c:6515
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "fastcall og stdcall er indbyrdes uforenelige"
 
-#: config/i386/i386.c:6520 config/i386/i386.c:6569
+#: config/i386/i386.c:6523 config/i386/i386.c:6572
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "fastcall og thiscall er indbyrdes uforenelige"
 
-#: config/i386/i386.c:6530 config/i386/i386.c:6547
+#: config/i386/i386.c:6533 config/i386/i386.c:6550
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "stdcall og cdecl er indbyrdes uforenelige"
 
-#: config/i386/i386.c:6534
+#: config/i386/i386.c:6537
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "stdcall og fastcall er indbyrdes uforenelige"
 
-#: config/i386/i386.c:6538 config/i386/i386.c:6565
+#: config/i386/i386.c:6541 config/i386/i386.c:6568
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "stdcall og thiscall er indbyrdes uforenelige"
 
-#: config/i386/i386.c:6555 config/i386/i386.c:6573
+#: config/i386/i386.c:6558 config/i386/i386.c:6576
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "cdecl og thiscall er indbyrdes uforenelige"
 
-#: config/i386/i386.c:6561
+#: config/i386/i386.c:6564
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "%qE-egenskaben bruges til ikke-klasse metode"
 
-#: config/i386/i386.c:6805
+#: config/i386/i386.c:6808
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:6808
+#: config/i386/i386.c:6811
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:7126
+#: config/i386/i386.c:7129
 #, gcc-internal-format
 msgid "X32 does not support ms_abi attribute"
 msgstr "X32 understøtter ikke egenskaben ms_abi"
 
-#: config/i386/i386.c:7160
+#: config/i386/i386.c:7163
 #, gcc-internal-format
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr "ms_hook_prologue er ikke forenelig med den indlejrede funktion"
 
-#: config/i386/i386.c:7502
+#: config/i386/i386.c:7505
 #, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7508
+#: config/i386/i386.c:7511
 #, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7522
+#: config/i386/i386.c:7525
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7528
+#: config/i386/i386.c:7531
 #, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7544
+#: config/i386/i386.c:7547
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7550
+#: config/i386/i386.c:7553
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7566
+#: config/i386/i386.c:7569
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7572
+#: config/i386/i386.c:7575
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7754
+#: config/i386/i386.c:7757
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:7871
+#: config/i386/i386.c:7874
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:7989
+#: config/i386/i386.c:7992
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:8152
+#: config/i386/i386.c:8155
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.c:8158
+#: config/i386/i386.c:8161
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.c:8174
+#: config/i386/i386.c:8177
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr ""
 
-#: config/i386/i386.c:8471 config/i386/i386.c:8750 config/i386/i386.c:9276
+#: config/i386/i386.c:8474 config/i386/i386.c:8753 config/i386/i386.c:9279
 #, gcc-internal-format
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:8473 config/i386/i386.c:8752 config/i386/i386.c:9278
+#: config/i386/i386.c:8476 config/i386/i386.c:8755 config/i386/i386.c:9281
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr ""
 
-#: config/i386/i386.c:9178
+#: config/i386/i386.c:9181
 #, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr ""
 
-#: config/i386/i386.c:11601
+#: config/i386/i386.c:11604
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "-mcall-ms2sysv-xlogues is not compatible with %s"
 msgstr "-march=%s er ikke forenelig med den valgte ABI"
 
-#: config/i386/i386.c:13593
+#: config/i386/i386.c:13596
 #, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr ""
 
-#: config/i386/i386.c:13683
+#: config/i386/i386.c:13686
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr ""
 
-#: config/i386/i386.c:14970
+#: config/i386/i386.c:14973
 #, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr ""
 
-#: config/i386/i386.c:14990
+#: config/i386/i386.c:14993
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
 msgstr ""
@@ -33396,352 +33442,352 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:15001
+#: config/i386/i386.c:15004
 #, fuzzy, gcc-internal-format
 #| msgid "-mips%d does not support 64 bit fp registers"
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr "-mips%d understøtter ikke 64-bit kommatalsregistre"
 
-#: config/i386/i386.c:17939
+#: config/i386/i386.c:17942
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported size for integer register"
 msgid "'V' modifier on non-integer register"
 msgstr "størrelse er ikke understøttet for heltalsregister"
 
-#: config/i386/i386.c:17950 config/i386/i386.c:17964
+#: config/i386/i386.c:17953 config/i386/i386.c:17967
 #, gcc-internal-format
 msgid "unsupported size for integer register"
 msgstr "størrelse er ikke understøttet for heltalsregister"
 
-#: config/i386/i386.c:17996
+#: config/i386/i386.c:17999
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr "udvidede registre har ikke høje halvdele"
 
-#: config/i386/i386.c:18011
+#: config/i386/i386.c:18014
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr "ikke-understøttet operandstørrelse for udvidede registre"
 
-#: config/i386/i386.c:18202
+#: config/i386/i386.c:18205
 #, gcc-internal-format
 msgid "non-integer operand used with operand code 'z'"
 msgstr ""
 
-#: config/i386/i386.c:28467
+#: config/i386/i386.c:28470
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine can't be called directly"
 msgstr "afbrydelsesservicerutiner kan ikke kodes i Thumb-tilstand"
 
-#: config/i386/i386.c:29995
+#: config/i386/i386.c:29998
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in -fabi-version=12 (GCC 8)"
 msgstr ""
 
-#: config/i386/i386.c:32435
+#: config/i386/i386.c:32438
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr ""
 
-#: config/i386/i386.c:32485
+#: config/i386/i386.c:32488
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "No case for %s"
 msgid "No dispatcher found for %s"
 msgstr "Ingen case for %s"
 
-#: config/i386/i386.c:32495
+#: config/i386/i386.c:32498
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr ""
 
-#: config/i386/i386.c:32657
+#: config/i386/i386.c:32660
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386.c:32662 config/i386/i386.c:32938
-#: config/rs6000/rs6000.c:37850
+#: config/i386/i386.c:32665 config/i386/i386.c:32941
+#: config/rs6000/rs6000.c:37906
 #, fuzzy, gcc-internal-format
 #| msgid "stack limit expression is not supported"
 msgid "Virtual function multiversioning not supported"
 msgstr "stakgrænseudtryk understøttes ikke"
 
-#: config/i386/i386.c:32795 config/rs6000/rs6000.c:37607
+#: config/i386/i386.c:32798 config/rs6000/rs6000.c:37663
 #, fuzzy, gcc-internal-format
 #| msgid "Profiling is not supported on this target."
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "Profilering er ikke understøttet på målarkitekturen."
 
-#: config/i386/i386.c:33207
+#: config/i386/i386.c:33210
 #, fuzzy, gcc-internal-format
 #| msgid "argument to dss must be a 2-bit unsigned literal"
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr "parameter til dss skal være en 2 bit-konstant uden fortegn"
 
-#: config/i386/i386.c:33232 config/i386/i386.c:33282
+#: config/i386/i386.c:33235 config/i386/i386.c:33285
 #, gcc-internal-format, gfc-internal-format
 msgid "Parameter to builtin not valid: %s"
 msgstr ""
 
-#: config/i386/i386.c:33975 config/i386/i386.c:35415
+#: config/i386/i386.c:33978 config/i386/i386.c:35418
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 2-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386.c:34370
+#: config/i386/i386.c:34373
 #, fuzzy, gcc-internal-format
 #| msgid "shift must be an immediate"
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "skifteværdi skal være en umiddelbar værdi"
 
-#: config/i386/i386.c:34465
+#: config/i386/i386.c:34468
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the third argument must be an 8-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386.c:35346
+#: config/i386/i386.c:35349
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be an 1-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386.c:35361
+#: config/i386/i386.c:35364
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 3-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386.c:35394
+#: config/i386/i386.c:35397
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "the last argument must be a 4-bit immediate"
 msgstr "3. parameter skal være en 4 bit-konstant uden fortegn"
 
-#: config/i386/i386.c:35434
+#: config/i386/i386.c:35437
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 1-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386.c:35447
+#: config/i386/i386.c:35450
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 5-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386.c:35457
+#: config/i386/i386.c:35460
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386.c:35462 config/i386/i386.c:36249
+#: config/i386/i386.c:35465 config/i386/i386.c:36252
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be an 8-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386.c:35596
+#: config/i386/i386.c:35599
 #, fuzzy, gcc-internal-format
 #| msgid "third arg to `__builtin_prefetch' must be a constant"
 msgid "the third argument must be comparison constant"
 msgstr "en tredje parameter til '__builtin_prefetch' skal være en konstant"
 
-#: config/i386/i386.c:35601
+#: config/i386/i386.c:35604
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect comparison mode"
 msgstr "ukorrekt instruktion:"
 
-#: config/i386/i386.c:35607 config/i386/i386.c:35814
+#: config/i386/i386.c:35610 config/i386/i386.c:35817
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect rounding operand"
 msgstr "ukorrekt instruktion:"
 
-#: config/i386/i386.c:35796
+#: config/i386/i386.c:35799
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "3. parameter skal være en 4 bit-konstant uden fortegn"
 
-#: config/i386/i386.c:35802
+#: config/i386/i386.c:35805
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386.c:35805
+#: config/i386/i386.c:35808
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386.c:36247
+#: config/i386/i386.c:36250
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 32-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386.c:36329 config/powerpcspe/powerpcspe.c:16219
-#: config/rs6000/rs6000.c:15304
+#: config/i386/i386.c:36332 config/powerpcspe/powerpcspe.c:16219
+#: config/rs6000/rs6000.c:15348
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr ""
 
-#: config/i386/i386.c:36539
+#: config/i386/i386.c:36542
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr ""
 
-#: config/i386/i386.c:36543
+#: config/i386/i386.c:36546
 #, fuzzy, gcc-internal-format
 #| msgid "invalid option %s"
 msgid "%qE needs isa option %s"
 msgstr "ugyldigt tilvalg %s"
 
-#: config/i386/i386.c:37381
+#: config/i386/i386.c:37375
 #, fuzzy, gcc-internal-format
 #| msgid "mask must be an immediate"
 msgid "last argument must be an immediate"
 msgstr "maske skal være en umiddelbar værdi"
 
-#: config/i386/i386.c:38108 config/i386/i386.c:38290
+#: config/i386/i386.c:38102 config/i386/i386.c:38284
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386.c:38343
+#: config/i386/i386.c:38337
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386.c:38349
+#: config/i386/i386.c:38343
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect hint operand"
 msgstr "ukorrekt instruktion:"
 
-#: config/i386/i386.c:38368
+#: config/i386/i386.c:38362
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386.c:41431
+#: config/i386/i386.c:41425
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to variables"
 msgid "%qE attribute only available for 32-bit"
 msgstr "egenskaben '%s' kan kun anvendes på variabler"
 
-#: config/i386/i386.c:41452
+#: config/i386/i386.c:41446
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `%s' attribute is not a string constant"
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "parameteren til egenskaben '%s er ikke en strengkonstant"
 
-#: config/i386/i386.c:41485 config/i386/i386.c:41494
+#: config/i386/i386.c:41479 config/i386/i386.c:41488
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr "fastcall og stdcall er indbyrdes uforenelige"
 
-#: config/i386/i386.c:41530 config/powerpcspe/powerpcspe.c:35868
-#: config/rs6000/rs6000.c:33065
+#: config/i386/i386.c:41524 config/powerpcspe/powerpcspe.c:35868
+#: config/rs6000/rs6000.c:33121
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' incompatible attribute ignored"
 msgid "%qE incompatible attribute ignored"
 msgstr "uforenelig egenskab '%s' ignoreret"
 
-#: config/i386/i386.c:41555 config/i386/i386.c:41577 config/ia64/ia64.c:815
+#: config/i386/i386.c:41549 config/i386/i386.c:41571 config/ia64/ia64.c:815
 #: config/s390/s390.c:1153
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "%qE-egenskaben kræver et strengkonstant som parameter"
 
-#: config/i386/i386.c:41565 config/i386/i386.c:41587 config/s390/s390.c:1182
+#: config/i386/i386.c:41559 config/i386/i386.c:41581 config/s390/s390.c:1182
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `%s' attribute is not \"ilink1\" or \"ilink2\""
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "parameteren til egenskaben '%s er ikke \"ilink1\" eller \"ilink2\""
 
-#: config/i386/i386.c:41619
+#: config/i386/i386.c:41613
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386.c:41626
+#: config/i386/i386.c:41620
 #, gcc-internal-format, gfc-internal-format
 msgid "interrupt service routine should have unsigned %sint as the second argument"
 msgstr ""
 
-#: config/i386/i386.c:41636
+#: config/i386/i386.c:41630
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386.c:41639
+#: config/i386/i386.c:41633
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine can't have non-void return value"
 msgstr "afbrydelsesservicerutiner kan ikke kodes i Thumb-tilstand"
 
-#: config/i386/i386.c:44676
+#: config/i386/i386.c:44670
 #, fuzzy, gcc-internal-format
 #| msgid "Statement at %0 invalid in this context"
 msgid "alternatives not allowed in asm flag output"
 msgstr "Sætning ved %0 er ugyldig i denne kontekst"
 
-#: config/i386/i386.c:44740
+#: config/i386/i386.c:44734
 #, fuzzy, gcc-internal-format
 #| msgid "unknown register name: %s"
 msgid "unknown asm flag output %qs"
 msgstr "ukendt registernavn: %s"
 
-#: config/i386/i386.c:44769
+#: config/i386/i386.c:44763
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type for make function"
 msgid "invalid type for asm flag output"
 msgstr "ugyldig type for make-funktion"
 
-#: config/i386/i386.c:50634
+#: config/i386/i386.c:50628
 #, fuzzy, gcc-internal-format
 #| msgid "Tune alignment for the specified chip or CPU version"
 msgid "unknown architecture specific memory model"
 msgstr "Finjustér justering til en given chip- eller processorversion"
 
-#: config/i386/i386.c:50641
+#: config/i386/i386.c:50635
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50647
+#: config/i386/i386.c:50641
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50671 config/i386/i386.c:50787
+#: config/i386/i386.c:50665 config/i386/i386.c:50781
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unsupported version"
 msgid "unsupported simdlen %d"
 msgstr "versionen er ikke understøttet"
 
-#: config/i386/i386.c:50690
+#: config/i386/i386.c:50684
 #, fuzzy, gcc-internal-format
 #| msgid "unused arguments in $-style format"
 msgid "unsupported return type %qT for simd"
 msgstr "ubenyttede parametre i formatering med $"
 
-#: config/i386/i386.c:50712
+#: config/i386/i386.c:50706
 #, fuzzy, gcc-internal-format
 #| msgid "unused arguments in $-style format"
 msgid "unsupported argument type %qT for simd"
 msgstr "ubenyttede parametre i formatering med $"
 
-#: config/i386/i386.c:51033
+#: config/i386/i386.c:51027
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr ""
@@ -33971,7 +34017,7 @@
 msgstr "interrupt_thread er kun tilgængelig på fido"
 
 #: config/m68k/m68k.c:1128 config/powerpcspe/powerpcspe.c:28512
-#: config/rs6000/rs6000.c:25791
+#: config/rs6000/rs6000.c:25868
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "stakgrænseudtryk understøttes ikke"
@@ -34589,10 +34635,10 @@
 
 #. Trampoline is not supported on reduced-set registers yet.
 #: config/nds32/nds32.c:2327 config/nds32/nds32.c:2381
-#: config/nds32/nds32.c:3127 config/nds32/nds32.c:3201
-#: config/nds32/nds32.c:3216 config/nds32/nds32.c:3222
-#: config/nds32/nds32.c:3284 config/nds32/nds32.c:3290
-#: config/nds32/nds32.c:3322
+#: config/nds32/nds32.c:3128 config/nds32/nds32.c:3202
+#: config/nds32/nds32.c:3217 config/nds32/nds32.c:3223
+#: config/nds32/nds32.c:3285 config/nds32/nds32.c:3291
+#: config/nds32/nds32.c:3323
 #, fuzzy, gcc-internal-format
 #| msgid "inline functions not supported for this return value type"
 msgid "a nested function is not supported for reduced registers"
@@ -34599,55 +34645,55 @@
 msgstr "integrerede funktioner understøttes ikke for denne returværditype"
 
 #. The enum index value for array size is out of range.
-#: config/nds32/nds32.c:3025
+#: config/nds32/nds32.c:3026
 #, fuzzy, gcc-internal-format
 #| msgid "integer constant out of range"
 msgid "intrinsic register index is out of range"
 msgstr "heltalskonstanten er uden for det gyldige interval"
 
-#: config/nds32/nds32.c:3041 config/nds32/nds32.c:3048
-#: config/nds32/nds32.c:3055 config/nds32/nds32.c:3062
-#: config/nds32/nds32.c:3069
+#: config/nds32/nds32.c:3042 config/nds32/nds32.c:3049
+#: config/nds32/nds32.c:3056 config/nds32/nds32.c:3063
+#: config/nds32/nds32.c:3070
 #, fuzzy, gcc-internal-format
 #| msgid "integer constant out of range"
 msgid "CCTL intrinsic function subtype out of range!"
 msgstr "heltalskonstanten er uden for det gyldige interval"
 
-#: config/nds32/nds32.c:3508
+#: config/nds32/nds32.c:3509
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute `%s'"
 msgid "invalid id value for interrupt/exception attribute"
 msgstr "ugyldig vektortype for egenskaben '%s'"
 
-#: config/nds32/nds32.c:3536
+#: config/nds32/nds32.c:3537
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "invalid id value for reset attribute"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
-#: config/nds32/nds32.c:3552
+#: config/nds32/nds32.c:3553
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "invalid nmi function for reset attribute"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
-#: config/nds32/nds32.c:3565
+#: config/nds32/nds32.c:3566
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "invalid warm function for reset attribute"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
-#: config/nds32/nds32.c:3638
+#: config/nds32/nds32.c:3639
 #, gcc-internal-format
 msgid "Disable FPU ISA, the ABI option must be enable '-mfloat-abi=soft'"
 msgstr ""
 
-#: config/nds32/nds32.c:3641
+#: config/nds32/nds32.c:3642
 #, gcc-internal-format
 msgid "'-mabi=2fp+' option only support when FPU available, must be enable '-mext-fpu-sp' or '-mext-fpu-dp'"
 msgstr ""
 
-#: config/nds32/nds32.c:3647
+#: config/nds32/nds32.c:3648
 #, fuzzy, gcc-internal-format
 msgid "position-independent code not supported"
 msgstr "Generér placeringsuafhængig kode, om muligt"
@@ -35003,12 +35049,12 @@
 msgid "junk at end of #pragma longcall"
 msgstr "ragelse i slutningen af #pragma longcall"
 
-#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6154
+#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6152
 #, gcc-internal-format
 msgid "vec_lvsl is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr "vec_lvsl er forældet for lilleendet; brug opgave for ikke justerede indlæsninger og lagre"
 
-#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6158
+#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6156
 #, gcc-internal-format
 msgid "vec_lvsr is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr "vec_lvsr er forældet for lilleendet; brug opgave for ikke justerede indlæsninger og lagre"
@@ -35062,7 +35108,7 @@
 msgid "vec_insert only accepts 3 arguments"
 msgstr "vec_insert accepterer kun 3 parametre"
 
-#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6868
+#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6866
 #, fuzzy, gcc-internal-format
 #| msgid "cast from `%T' to `%T' discards qualifiers from pointer target type"
 msgid "passing arg %d of %qE discards qualifiers from pointer target type"
@@ -35153,7 +35199,7 @@
 msgid "target attribute or pragma changes SPE ABI"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4351 config/rs6000/rs6000.c:4223
+#: config/powerpcspe/powerpcspe.c:4351 config/rs6000/rs6000.c:4243
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "AltiVec not supported in this target"
@@ -35317,7 +35363,7 @@
 msgid "-mvsx-small-integer requires -mpower8-vector, -mupper-regs-di, and -mdirect-move"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4959 config/rs6000/rs6000.c:4601
+#: config/powerpcspe/powerpcspe.c:4959 config/rs6000/rs6000.c:4628
 #, gcc-internal-format
 msgid "target attribute or pragma changes long double size"
 msgstr ""
@@ -35358,22 +35404,22 @@
 msgstr ""
 
 #: config/powerpcspe/powerpcspe.c:5140 config/powerpcspe/powerpcspe.c:5155
-#: config/rs6000/rs6000.c:4766 config/rs6000/rs6000.c:4781
+#: config/rs6000/rs6000.c:4791 config/rs6000/rs6000.c:4806
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:5168 config/rs6000/rs6000.c:4794
+#: config/powerpcspe/powerpcspe.c:5168 config/rs6000/rs6000.c:4819
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:5234 config/rs6000/rs6000.c:4828
+#: config/powerpcspe/powerpcspe.c:5234 config/rs6000/rs6000.c:4853
 #, gcc-internal-format
 msgid "target attribute or pragma changes single precision floating point"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:5237 config/rs6000/rs6000.c:4831
+#: config/powerpcspe/powerpcspe.c:5237 config/rs6000/rs6000.c:4856
 #, gcc-internal-format
 msgid "target attribute or pragma changes double precision floating point"
 msgstr ""
@@ -35383,12 +35429,12 @@
 msgid "-mstack-protector-guard=tls needs a valid base register"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:8415 config/rs6000/rs6000.c:7925
+#: config/powerpcspe/powerpcspe.c:8415 config/rs6000/rs6000.c:7950
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11237
+#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11269
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
@@ -35398,7 +35444,7 @@
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11595
+#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11633
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr ""
@@ -35408,12 +35454,12 @@
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12604
+#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12648
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12779
+#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12823
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
@@ -35423,30 +35469,30 @@
 msgid "internal error: builtin function %s already processed"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:13971
+#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:14015
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "argument 1 must be an 8-bit field value"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14015
+#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14059
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
 #: config/powerpcspe/powerpcspe.c:14934 config/powerpcspe/powerpcspe.c:16803
-#: config/rs6000/rs6000.c:14101
+#: config/rs6000/rs6000.c:14145
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "2. parameter skal være en 5 bit-konstant uden fortegn"
 
-#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14119
+#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14163
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "2. parameter skal være en 5 bit-konstant uden fortegn"
 
-#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14135
+#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14179
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 7-bit unsigned literal"
@@ -35467,13 +35513,13 @@
 msgid "builtin %s is only valid in 64-bit mode"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14791
+#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14835
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument %d must be an unsigned literal"
 msgstr "2. parameter skal være en 5 bit-konstant uden fortegn"
 
-#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14793
+#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14837
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument %d is an unsigned literal that is out of range"
@@ -35499,61 +35545,61 @@
 msgid "hwcap %s is an invalid argument to builtin %s"
 msgstr "#%s med ugyldig parameter"
 
-#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15065
+#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15109
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "3. parameter skal være en 4 bit-konstant uden fortegn"
 
-#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15090
+#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15134
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "3. parameter skal være en 4 bit-konstant uden fortegn"
 
-#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15110
+#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15154
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "3. parameter skal være en 4 bit-konstant uden fortegn"
 
-#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15122
+#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15166
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "argument 1 must be 0 or 2"
 msgstr "tal skal enten være 0 eller 1"
 
-#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15134
+#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15178
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "2. parameter skal være en 5 bit-konstant uden fortegn"
 
-#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15148
+#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15192
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "2. parameter skal være en 5 bit-konstant uden fortegn"
 
-#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15160
+#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15204
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "argument 2 must be 0 or 1"
 msgstr "tal skal enten være 0 eller 1"
 
-#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15168
+#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15212
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "argument 3 must be in the range 0..15"
 msgstr "3. parameter skal være en 4 bit-konstant uden fortegn"
 
-#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15237
-#: config/rs6000/rs6000.c:15569
+#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15281
+#: config/rs6000/rs6000.c:15613
 #, fuzzy, gcc-internal-format
 #| msgid "argument to `%s' must be a 2-bit unsigned literal"
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "parameter til '%s' skal være en 2 bit-konstant uden fortegn"
 
-#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15394
+#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15438
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr ""
@@ -35693,7 +35739,7 @@
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25758
+#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25835
 #, fuzzy, gcc-internal-format
 #| msgid "stack frame too big"
 msgid "stack frame too large"
@@ -35705,13 +35751,13 @@
 msgid "-fsplit-stack uses register r29"
 msgstr "-mips%d understøtter ikke 64-bit kommatalsregistre"
 
-#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29459
+#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29536
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC target is not supported for this machine"
 msgid "Stack frame larger than 2G is not supported for -fsplit-stack"
 msgstr "#pragma GCC-målarkitektur er ikke understøttet på denne maskine"
 
-#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30447
+#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30524
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "ingen profilering af 64 bit-kode for denne ABI"
@@ -35721,22 +35767,22 @@
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32830
+#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32907
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32832
+#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32909
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32834
+#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32911
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32836
+#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32913
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr ""
@@ -35746,7 +35792,7 @@
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32845
+#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32922
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr ""
@@ -36305,80 +36351,80 @@
 "Please use an explicit cpu name.  Valid cpu names are: %s"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6168 config/rs6000/rs6000-c.c:6219
-#: config/rs6000/rs6000-c.c:6489 config/rs6000/rs6000-c.c:6555
-#: config/rs6000/rs6000-c.c:6916 config/rs6000/rs6000-c.c:6963
+#: config/rs6000/rs6000-c.c:6166 config/rs6000/rs6000-c.c:6217
+#: config/rs6000/rs6000-c.c:6487 config/rs6000/rs6000-c.c:6553
+#: config/rs6000/rs6000-c.c:6914 config/rs6000/rs6000-c.c:6961
 #, fuzzy, gcc-internal-format
 #| msgid "%s only accepts 1 argument"
 msgid "builtin %qs only accepts 2 arguments"
 msgstr "%s accepterer kun 1 parameter"
 
-#: config/rs6000/rs6000-c.c:6292 config/rs6000/rs6000-c.c:6375
-#: config/rs6000/rs6000-c.c:6736
+#: config/rs6000/rs6000-c.c:6290 config/rs6000/rs6000-c.c:6373
+#: config/rs6000/rs6000-c.c:6734
 #, fuzzy, gcc-internal-format
 #| msgid "%s only accepts 1 argument"
 msgid "builtin %qs only accepts 3 arguments"
 msgstr "%s accepterer kun 1 parameter"
 
-#: config/rs6000/rs6000-c.c:6484
+#: config/rs6000/rs6000-c.c:6482
 #, fuzzy, gcc-internal-format
 #| msgid "%s only accepts 1 argument"
 msgid "builtin %qs only accepts 1 argument"
 msgstr "%s accepterer kun 1 parameter"
 
-#: config/rs6000/rs6000-c.c:7054
+#: config/rs6000/rs6000-c.c:7052
 #, fuzzy, gcc-internal-format
 #| msgid "a -ifile option requires a -map option"
 msgid "builtin %qs requires builtin %qs"
 msgstr "et '-ifile'-tilvalg kræver et '-map'-tilvalg"
 
-#: config/rs6000/rs6000-c.c:7058
+#: config/rs6000/rs6000-c.c:7056
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs not supported in this compiler configuration"
 msgstr "%s understøttes ikke af denne konfiguration"
 
-#: config/rs6000/rs6000-c.c:7068
+#: config/rs6000/rs6000-c.c:7066
 #, fuzzy, gcc-internal-format
 #| msgid "invalid register in the instruction"
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr "ugyldigt register i instruktionen"
 
-#: config/rs6000/rs6000.c:3754 config/rs6000/rs6000.c:3757
-#: config/rs6000/rs6000.c:3760
+#: config/rs6000/rs6000.c:3772 config/rs6000/rs6000.c:3775
+#: config/rs6000/rs6000.c:3778
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid reference type"
 msgid "%qs requires %qs or %qs"
 msgstr "Ugyldig referencetype"
 
-#: config/rs6000/rs6000.c:3861
+#: config/rs6000/rs6000.c:3879
 #, fuzzy, gcc-internal-format
 #| msgid "-maix64 requires PowerPC64 architecture remain enabled"
 msgid "%qs requires PowerPC64 architecture, enabling"
 msgstr "-maix64 kræver at PowerPC64-arkitekturen forbliver aktiveret"
 
-#: config/rs6000/rs6000.c:4037
+#: config/rs6000/rs6000.c:4057
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is deprecated"
 msgid "%qs command-line option is deprecated"
 msgstr "'%s' er forældet"
 
-#: config/rs6000/rs6000.c:4048
+#: config/rs6000/rs6000.c:4068
 #, gcc-internal-format
 msgid "%qs is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4147
+#: config/rs6000/rs6000.c:4167
 #, gcc-internal-format
 msgid "will not generate %qs instructions because assembler lacks %qs support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4240
+#: config/rs6000/rs6000.c:4260
 #, fuzzy, gcc-internal-format
 #| msgid "-mstring is not supported on little endian systems"
 msgid "%qs is not supported on little endian systems"
 msgstr "-mstring er ikke understøttet på lilleendede systemer"
 
-#: config/rs6000/rs6000.c:4333
+#: config/rs6000/rs6000.c:4353
 #, gcc-internal-format
 msgid "power9 target option is incompatible with %<%s=<xxx>%> for <xxx> less than power9"
 msgstr ""
@@ -36385,7 +36431,7 @@
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:4341
+#: config/rs6000/rs6000.c:4361
 #, fuzzy, gcc-internal-format
 #| msgid "Emit code compatible with TI tools"
 msgid "%qs incompatible with explicitly disabled options"
@@ -36395,122 +36441,122 @@
 #. error messages.  However, if users have managed to select
 #. power9-fusion without selecting power8-fusion, they
 #. already know about undocumented flags.
-#: config/rs6000/rs6000.c:4366 config/rs6000/rs6000.c:4373
-#: config/rs6000/rs6000.c:4380 config/rs6000/rs6000.c:4388
-#: config/rs6000/rs6000.c:4407 config/rs6000/rs6000.c:4464
-#: config/rs6000/rs6000.c:4468 config/rs6000/rs6000.c:4485
-#: config/rs6000/rs6000.c:4538 config/rs6000/rs6000.c:4565
-#: config/rs6000/rs6000.c:4580 config/rs6000/rs6000.c:4588
-#: config/rs6000/rs6000.c:4684
+#: config/rs6000/rs6000.c:4386 config/rs6000/rs6000.c:4393
+#: config/rs6000/rs6000.c:4400 config/rs6000/rs6000.c:4408
+#: config/rs6000/rs6000.c:4427 config/rs6000/rs6000.c:4484
+#: config/rs6000/rs6000.c:4488 config/rs6000/rs6000.c:4505
+#: config/rs6000/rs6000.c:4558 config/rs6000/rs6000.c:4585
+#: config/rs6000/rs6000.c:4600 config/rs6000/rs6000.c:4608
+#: config/rs6000/rs6000.c:4709
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "%qs requires %qs"
 msgstr "--resource påkræver -o"
 
-#: config/rs6000/rs6000.c:4625
+#: config/rs6000/rs6000.c:4650
 #, gcc-internal-format
 msgid "Using IEEE extended precision long double"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4627
+#: config/rs6000/rs6000.c:4652
 #, gcc-internal-format
 msgid "Using IBM extended precision long double"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4644
+#: config/rs6000/rs6000.c:4669
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "%qs requires VSX support"
 msgstr "%s understøtter ikke %s"
 
-#: config/rs6000/rs6000.c:4653
+#: config/rs6000/rs6000.c:4678
 #, gcc-internal-format
 msgid "The -mfloat128 option may not be fully supported"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4676
+#: config/rs6000/rs6000.c:4701
 #, gcc-internal-format
 msgid "%qs requires full ISA 3.0 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4743
+#: config/rs6000/rs6000.c:4768
 #, gcc-internal-format
 msgid "unknown vectorization library ABI type (%qs) for %qs switch"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4930
+#: config/rs6000/rs6000.c:4955
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr "%s understøtter ikke %s"
 
-#: config/rs6000/rs6000.c:4935
+#: config/rs6000/rs6000.c:4960
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr "%s understøtter ikke %s"
 
-#: config/rs6000/rs6000.c:4947
+#: config/rs6000/rs6000.c:4972
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qs is not a valid base register in %qs"
 msgstr "'%s' er et ugyldigt klassenavn"
 
-#: config/rs6000/rs6000.c:4955
+#: config/rs6000/rs6000.c:4980
 #, fuzzy, gcc-internal-format
 #| msgid "can%'t use %qs as a call-used register"
 msgid "%qs needs a valid base register"
 msgstr "kan ikke bruge %qs som et kald-brugt register"
 
-#: config/rs6000/rs6000.c:5253
+#: config/rs6000/rs6000.c:5278
 #, fuzzy, gcc-internal-format
 #| msgid "Unknown cpu: -mcpu=%s"
 msgid "unknown option for %<%s=%s%>"
 msgstr "Ukendt processor: -mcpu=%s"
 
-#: config/rs6000/rs6000.c:5290
+#: config/rs6000/rs6000.c:5315
 #, fuzzy, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr "%s har ingen %s"
 
-#: config/rs6000/rs6000.c:11401
+#: config/rs6000/rs6000.c:11439
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11862
+#: config/rs6000/rs6000.c:11906
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13572
+#: config/rs6000/rs6000.c:13616
 #, fuzzy, gcc-internal-format
 #| msgid "internal error - use of undefined type"
 msgid "internal error: builtin function %qs already processed"
 msgstr "intern fejl - brug af ikke-defineret type"
 
-#: config/rs6000/rs6000.c:14150
+#: config/rs6000/rs6000.c:14194
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 1-bit unsigned literal"
 msgstr "2. parameter skal være en 5 bit-konstant uden fortegn"
 
-#: config/rs6000/rs6000.c:14189
+#: config/rs6000/rs6000.c:14233
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 of `%s' must be a 2-bit literal"
 msgid "argument 1 of %qs must be a constant"
 msgstr "parameter til '%s' skal være en 2 bit-konstant"
 
-#: config/rs6000/rs6000.c:14247 config/rs6000/rs6000.c:15898
+#: config/rs6000/rs6000.c:14291 config/rs6000/rs6000.c:15942
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument 1 of %qs is out of range"
 msgstr "1. parameter til __builtin_spe_predicate er uden for det gyldige interval"
 
-#: config/rs6000/rs6000.c:14742
+#: config/rs6000/rs6000.c:14786
 #, gcc-internal-format
 msgid "builtin %qs is only valid in 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14939
+#: config/rs6000/rs6000.c:14983
 #, fuzzy, gcc-internal-format
 #| msgid "%s only accepts 1 argument"
 msgid "builtin %qs only accepts a string argument"
@@ -36517,7 +36563,7 @@
 msgstr "%s accepterer kun 1 parameter"
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000.c:14958
+#: config/rs6000/rs6000.c:15002
 #, fuzzy, gcc-internal-format
 #| msgid "#%s with invalid argument"
 msgid "cpu %qs is an invalid argument to builtin %qs"
@@ -36524,140 +36570,141 @@
 msgstr "#%s med ugyldig parameter"
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000.c:14986
+#: config/rs6000/rs6000.c:15030
 #, fuzzy, gcc-internal-format
 #| msgid "#%s with invalid argument"
 msgid "%s %qs is an invalid argument to builtin %qs"
 msgstr "#%s med ugyldig parameter"
 
-#: config/rs6000/rs6000.c:15012
+#: config/rs6000/rs6000.c:15056
 #, gcc-internal-format
 msgid "builtin %qs needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15616
+#: config/rs6000/rs6000.c:15660
 #, fuzzy, gcc-internal-format
 #| msgid "third arg to `__builtin_prefetch' must be a constant"
 msgid "second argument to %qs must be 0..12"
 msgstr "en tredje parameter til '__builtin_prefetch' skal være en konstant"
 
-#: config/rs6000/rs6000.c:15631
+#: config/rs6000/rs6000.c:15675
 #, fuzzy, gcc-internal-format
 #| msgid "third arg to `__builtin_prefetch' must be a constant"
 msgid "third argument to %qs must be 0..12"
 msgstr "en tredje parameter til '__builtin_prefetch' skal være en konstant"
 
-#: config/rs6000/rs6000.c:15850
+#: config/rs6000/rs6000.c:15894
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 3 of `%s' must be a 2-bit literal"
 msgid "argument 1 of %s must be a constant"
 msgstr "parameter til '%s' skal være en 2 bit-konstant"
 
-#: config/rs6000/rs6000.c:15932
+#: config/rs6000/rs6000.c:15976
 #, fuzzy, gcc-internal-format
 #| msgid "this media function is only available on the fr400"
 msgid "builtin function %qs is only valid for the cell processor"
 msgstr "denne mediafunktion er kun tilgængelig på fr400"
 
-#: config/rs6000/rs6000.c:15934 config/rs6000/rs6000.c:15936
-#: config/rs6000/rs6000.c:15938 config/rs6000/rs6000.c:15940
-#: config/rs6000/rs6000.c:15946 config/rs6000/rs6000.c:15948
-#: config/rs6000/rs6000.c:15955 config/rs6000/rs6000.c:15962
-#: config/rs6000/rs6000.c:15969 config/rs6000/rs6000.c:15975
+#: config/rs6000/rs6000.c:15978 config/rs6000/rs6000.c:15980
+#: config/rs6000/rs6000.c:15982 config/rs6000/rs6000.c:15984
+#: config/rs6000/rs6000.c:15990 config/rs6000/rs6000.c:15992
+#: config/rs6000/rs6000.c:15999 config/rs6000/rs6000.c:16006
+#: config/rs6000/rs6000.c:16011 config/rs6000/rs6000.c:16014
+#: config/rs6000/rs6000.c:16018 config/rs6000/rs6000.c:16024
 #, fuzzy, gcc-internal-format
 #| msgid "a -ifile option requires a -map option"
 msgid "builtin function %qs requires the %qs option"
 msgstr "et '-ifile'-tilvalg kræver et '-map'-tilvalg"
 
-#: config/rs6000/rs6000.c:15943 config/rs6000/rs6000.c:15952
-#: config/rs6000/rs6000.c:15959 config/rs6000/rs6000.c:15966
+#: config/rs6000/rs6000.c:15987 config/rs6000/rs6000.c:15996
+#: config/rs6000/rs6000.c:16003
 #, fuzzy, gcc-internal-format
 #| msgid "a -ifile option requires a -map option"
 msgid "builtin function %qs requires the %qs and %qs options"
 msgstr "et '-ifile'-tilvalg kræver et '-map'-tilvalg"
 
-#: config/rs6000/rs6000.c:15972
+#: config/rs6000/rs6000.c:16021
 #, fuzzy, gcc-internal-format
 #| msgid "a -ifile option requires a -map option"
 msgid "builtin function %qs requires ISA 3.0 IEEE 128-bit floating point"
 msgstr "et '-ifile'-tilvalg kræver et '-map'-tilvalg"
 
-#: config/rs6000/rs6000.c:15978
+#: config/rs6000/rs6000.c:16027
 #, fuzzy, gcc-internal-format
 #| msgid "a -ifile option requires a -map option"
 msgid "builtin function %qs requires the %qs (or newer), and %qs or %qs options"
 msgstr "et '-ifile'-tilvalg kræver et '-map'-tilvalg"
 
-#: config/rs6000/rs6000.c:15982
+#: config/rs6000/rs6000.c:16031
 #, fuzzy, gcc-internal-format
 #| msgid "inline functions not supported for this return value type"
 msgid "builtin function %qs is not supported with the current options"
 msgstr "integrerede funktioner understøttes ikke for denne returværditype"
 
-#: config/rs6000/rs6000.c:18218
+#: config/rs6000/rs6000.c:18290
 #, fuzzy, gcc-internal-format
 #| msgid "internal error - use of undefined type"
 msgid "internal error: builtin function %qs had an unexpected return type %qs"
 msgstr "intern fejl - brug af ikke-defineret type"
 
-#: config/rs6000/rs6000.c:18235
+#: config/rs6000/rs6000.c:18307
 #, fuzzy, gcc-internal-format
 #| msgid "internal error - use of undefined type"
 msgid "internal error: builtin function %qs, argument %d had unexpected argument type %qs"
 msgstr "intern fejl - brug af ikke-defineret type"
 
-#: config/rs6000/rs6000.c:29451
+#: config/rs6000/rs6000.c:29528
 #, fuzzy, gcc-internal-format
 #| msgid "-mips%d does not support 64 bit fp registers"
 msgid "%qs uses register r29"
 msgstr "-mips%d understøtter ikke 64-bit kommatalsregistre"
 
-#: config/rs6000/rs6000.c:32748
+#: config/rs6000/rs6000.c:32825
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take the address of `this', which is an rvalue expression"
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "kan ikke tage adressen af 'this' som er et højreværdiudtryk"
 
-#: config/rs6000/rs6000.c:32842
+#: config/rs6000/rs6000.c:32919
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32850
+#: config/rs6000/rs6000.c:32927
 #, fuzzy, gcc-internal-format
 #| msgid "complex invalid for `%s'"
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "complex ugyldig for '%s'"
 
-#: config/rs6000/rs6000.c:32853
+#: config/rs6000/rs6000.c:32930
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:36876
+#: config/rs6000/rs6000.c:36932
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter type `%T'"
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "ugyldig parametertype '%T'"
 
-#: config/rs6000/rs6000.c:36879
+#: config/rs6000/rs6000.c:36935
 #, fuzzy, gcc-internal-format
 #| msgid "\"%s\" is not defined"
 msgid "%s%qs%s is not allowed"
 msgstr "\"%s\" er ikke defineret"
 
-#: config/rs6000/rs6000.c:36881
+#: config/rs6000/rs6000.c:36937
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "%s%qs%s is invalid"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: config/rs6000/rs6000.c:37416
+#: config/rs6000/rs6000.c:37472
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:37575
+#: config/rs6000/rs6000.c:37631
 #, gcc-internal-format
 msgid "target_clones attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
@@ -37457,53 +37504,53 @@
 msgid "subprogram %q+F not marked Inline"
 msgstr ""
 
-#: ada/gcc-interface/trans.c:6404
+#: ada/gcc-interface/trans.c:6401
 #, gcc-internal-format
 msgid "out-of-bounds access may be optimized away"
 msgstr ""
 
-#: ada/gcc-interface/trans.c:6406
+#: ada/gcc-interface/trans.c:6403
 #, gcc-internal-format
 msgid "containing loop"
 msgstr ""
 
-#: ada/gcc-interface/utils.c:3887
+#: ada/gcc-interface/utils.c:3890
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute `%s'"
 msgid "invalid element type for attribute %qs"
 msgstr "ugyldig vektortype for egenskaben '%s'"
 
-#: ada/gcc-interface/utils.c:3911
+#: ada/gcc-interface/utils.c:3914
 #, fuzzy, gcc-internal-format
 #| msgid "number of arguments doesn't match prototype"
 msgid "number of components of vector not a power of two"
 msgstr "antallet af parametre passer ikke til prototypen"
 
-#: ada/gcc-interface/utils.c:6037 ada/gcc-interface/utils.c:6215
-#: ada/gcc-interface/utils.c:6322
+#: ada/gcc-interface/utils.c:6043 ada/gcc-interface/utils.c:6220
+#: ada/gcc-interface/utils.c:6327
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored"
 msgid "%qs attribute ignored"
 msgstr "egenskaben '%s' ignoreret"
 
-#: ada/gcc-interface/utils.c:6158
+#: ada/gcc-interface/utils.c:6164
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute requires an integer constant argument"
 msgid "%qs attribute requires prototypes with named arguments"
 msgstr "egenskaben '%s' kræver en heltalskonstant som parameter"
 
-#: ada/gcc-interface/utils.c:6167
+#: ada/gcc-interface/utils.c:6173
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to functions"
 msgid "%qs attribute only applies to variadic functions"
 msgstr "egenskaben '%s' kan kun anvendes sammen med funktioner"
 
-#: ada/gcc-interface/utils.c:6282
+#: ada/gcc-interface/utils.c:6287
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute has no effect"
 msgstr "%s har ingen %s"
 
-#: ada/gcc-interface/utils.c:6406
+#: ada/gcc-interface/utils.c:6411
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to variables"
 msgid "attribute %qs applies to array types only"
@@ -37520,7 +37567,7 @@
 #. an unprototyped function, it is compile-time undefined;
 #. making it a constraint in that case was rejected in
 #. DR#252.
-#: c/c-convert.c:101 c/c-typeck.c:2175 c/c-typeck.c:6507 c/c-typeck.c:12138
+#: c/c-convert.c:101 c/c-typeck.c:2175 c/c-typeck.c:6512 c/c-typeck.c:12143
 #: cp/typeck.c:2027 cp/typeck.c:7977 cp/typeck.c:8742
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
@@ -37585,7 +37632,7 @@
 msgid "type of array %q+D completed incompatibly with implicit initialization"
 msgstr ""
 
-#: c/c-decl.c:1567 c/c-decl.c:6701 c/c-decl.c:7574 c/c-decl.c:8381
+#: c/c-decl.c:1567 c/c-decl.c:6721 c/c-decl.c:7594 c/c-decl.c:8401
 #, fuzzy, gcc-internal-format
 msgid "originally defined here"
 msgstr "  oprindelig definition er her"
@@ -38023,16 +38070,11 @@
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.c:4548 c/c-decl.c:7147
+#: c/c-decl.c:4548 c/c-decl.c:7167
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr ""
 
-#: c/c-decl.c:4635 cp/decl2.c:1520
-#, gcc-internal-format
-msgid "%q+D in declare target directive does not have mappable type"
-msgstr ""
-
 #: c/c-decl.c:4693
 #, gcc-internal-format
 msgid "%q+D is usually a function"
@@ -38059,7 +38101,7 @@
 #. of VLAs themselves count as VLAs, it does not make
 #. sense to permit them to be initialized given that
 #. ordinary VLAs may not be initialized.
-#: c/c-decl.c:4732 c/c-decl.c:4747 c/c-typeck.c:7630
+#: c/c-decl.c:4732 c/c-decl.c:4747 c/c-typeck.c:7635
 #, gcc-internal-format
 msgid "variable-sized object may not be initialized"
 msgstr "et objekt af variabel størrelse må ikke tildeles en startværdi"
@@ -38124,58 +38166,63 @@
 msgid "uninitialized const %qD is invalid in C++"
 msgstr "konstant '%D' uden startværdi"
 
-#: c/c-decl.c:5268
+#: c/c-decl.c:5224 cp/decl.c:7318
 #, gcc-internal-format
+msgid "%q+D in declare target directive does not have mappable type"
+msgstr ""
+
+#: c/c-decl.c:5288
+#, gcc-internal-format
 msgid "ISO C forbids forward parameter declarations"
 msgstr "ISO C forbyder forhåndsparametererklæringer"
 
-#: c/c-decl.c:5371
+#: c/c-decl.c:5391
 #, gcc-internal-format
 msgid "defining a type in a compound literal is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:5425 c/c-decl.c:5440
+#: c/c-decl.c:5445 c/c-decl.c:5460
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field `%s' width not an integer constant"
 msgid "bit-field %qs width not an integer constant"
 msgstr "bredden af bitfeltet '%s' er ikke en heltalskonstant"
 
-#: c/c-decl.c:5435
+#: c/c-decl.c:5455
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field `%s' width not an integer constant"
 msgid "bit-field %qs width not an integer constant expression"
 msgstr "bredden af bitfeltet '%s' er ikke en heltalskonstant"
 
-#: c/c-decl.c:5446
+#: c/c-decl.c:5466
 #, fuzzy, gcc-internal-format
 #| msgid "negative width in bit-field `%s'"
 msgid "negative width in bit-field %qs"
 msgstr "negativ bredde i bitfeltet '%s'"
 
-#: c/c-decl.c:5451
+#: c/c-decl.c:5471
 #, fuzzy, gcc-internal-format
 #| msgid "zero width for bit-field `%s'"
 msgid "zero width for bit-field %qs"
 msgstr "en bredde på nul for bitfeltet '%s'"
 
-#: c/c-decl.c:5461
+#: c/c-decl.c:5481
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field `%s' has invalid type"
 msgid "bit-field %qs has invalid type"
 msgstr "bitfeltet '%s' er af en ufuldstændig type"
 
-#: c/c-decl.c:5467
+#: c/c-decl.c:5487
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare bit-field `%D' with function type"
 msgid "cannot declare bit-field %qs with %<warn_if_not_aligned%> type"
 msgstr "kan ikke erklære bitfelt '%D' med funktionstype"
 
-#: c/c-decl.c:5478
+#: c/c-decl.c:5498
 #, fuzzy, gcc-internal-format
 msgid "type of bit-field %qs is a GCC extension"
 msgstr "linjestilsdirektiv er en GCC-udvidelse"
 
-#: c/c-decl.c:5484
+#: c/c-decl.c:5504
 #, fuzzy, gcc-internal-format
 #| msgid "width of `%s' exceeds its type"
 msgid "width of %qs exceeds its type"
@@ -38182,175 +38229,175 @@
 msgstr "bredden af '%s' overstiger typen"
 
 # RETMIG: find på et eller andet med præcisionen
-#: c/c-decl.c:5497
+#: c/c-decl.c:5517
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is narrower than values of its type"
 msgid "%qs is narrower than values of its type"
 msgstr "'%s' er smallere end værdier af dens type"
 
-#: c/c-decl.c:5512
+#: c/c-decl.c:5532
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids array `%s' whose size can't be evaluated"
 msgid "ISO C90 forbids array %qE whose size can%'t be evaluated"
 msgstr "ISO C90 forbyder tabellen '%s' hvis størrelse ikke kan bestemmes"
 
-#: c/c-decl.c:5515
+#: c/c-decl.c:5535
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids array `%s' whose size can't be evaluated"
 msgid "ISO C90 forbids array whose size can%'t be evaluated"
 msgstr "ISO C90 forbyder tabellen '%s' hvis størrelse ikke kan bestemmes"
 
-#: c/c-decl.c:5522
+#: c/c-decl.c:5542
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable-size array `%s'"
 msgid "ISO C90 forbids variable length array %qE"
 msgstr "ISO C90 forbyder tabellen '%s' med variabel størrelse"
 
-#: c/c-decl.c:5524
+#: c/c-decl.c:5544
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids variable-size array"
 msgid "ISO C90 forbids variable length array"
 msgstr "ISO C++ forbyder tabel med variabel størrelse"
 
-#: c/c-decl.c:5733 c/c-decl.c:6107 c/c-decl.c:6117
+#: c/c-decl.c:5753 c/c-decl.c:6127 c/c-decl.c:6137
 #, fuzzy, gcc-internal-format
 msgid "variably modified %qE at file scope"
 msgstr "skabelonsparameter '%T' er en variabelt ændret type"
 
-#: c/c-decl.c:5735
+#: c/c-decl.c:5755
 #, fuzzy, gcc-internal-format
 msgid "variably modified field at file scope"
 msgstr "skabelonsparameter '%T' er en variabelt ændret type"
 
-#: c/c-decl.c:5755
+#: c/c-decl.c:5775
 #, fuzzy, gcc-internal-format
 #| msgid "type defaults to `int' in declaration of `%s'"
 msgid "type defaults to %<int%> in declaration of %qE"
 msgstr "typen antages at være 'int' i erklæringen af '%s'"
 
-#: c/c-decl.c:5759
+#: c/c-decl.c:5779
 #, fuzzy, gcc-internal-format
 #| msgid "type defaults to `int' in declaration of `%s'"
 msgid "type defaults to %<int%> in type name"
 msgstr "typen antages at være 'int' i erklæringen af '%s'"
 
-#: c/c-decl.c:5791
+#: c/c-decl.c:5811
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `const'"
 msgid "duplicate %<const%>"
 msgstr "'const' optræder mere end én gang"
 
-#: c/c-decl.c:5793
+#: c/c-decl.c:5813
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `restrict'"
 msgid "duplicate %<restrict%>"
 msgstr "'restrict' optræder mere end én gang"
 
-#: c/c-decl.c:5795
+#: c/c-decl.c:5815
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `volatile'"
 msgid "duplicate %<volatile%>"
 msgstr "'volatile' optræder mere end én gang"
 
-#: c/c-decl.c:5797
+#: c/c-decl.c:5817
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `restrict'"
 msgid "duplicate %<_Atomic%>"
 msgstr "'restrict' optræder mere end én gang"
 
-#: c/c-decl.c:5800
+#: c/c-decl.c:5820
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "conflicting super class name `%s'"
 msgid "conflicting named address spaces (%s vs %s)"
 msgstr "modstridende superklassenavn '%s'"
 
-#: c/c-decl.c:5823 c/c-parser.c:2821
+#: c/c-decl.c:5843 c/c-parser.c:2821
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified array type"
 msgstr ""
 
-#: c/c-decl.c:5837
+#: c/c-decl.c:5857
 #, fuzzy, gcc-internal-format
 #| msgid "function definition declared `auto'"
 msgid "function definition declared %<auto%>"
 msgstr "'auto' er påhæftet funktionsdefinitionen"
 
-#: c/c-decl.c:5839
+#: c/c-decl.c:5859
 #, fuzzy, gcc-internal-format
 #| msgid "function definition declared `register'"
 msgid "function definition declared %<register%>"
 msgstr "'register' er påhæftet funktionsdefinitionen"
 
-#: c/c-decl.c:5841
+#: c/c-decl.c:5861
 #, fuzzy, gcc-internal-format
 #| msgid "function definition declared `typedef'"
 msgid "function definition declared %<typedef%>"
 msgstr "'typedef' er påhæftet funktionsdefinitionen"
 
-#: c/c-decl.c:5843
+#: c/c-decl.c:5863
 #, fuzzy, gcc-internal-format
 #| msgid "function definition declared `auto'"
 msgid "function definition declared %qs"
 msgstr "'auto' er påhæftet funktionsdefinitionen"
 
-#: c/c-decl.c:5861
+#: c/c-decl.c:5881
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for structure field `%s'"
 msgid "storage class specified for structure field %qE"
 msgstr "lagringsklasse angivet for strukturfelt '%s'"
 
-#: c/c-decl.c:5864
+#: c/c-decl.c:5884
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for structure field `%s'"
 msgid "storage class specified for structure field"
 msgstr "lagringsklasse angivet for strukturfelt '%s'"
 
-#: c/c-decl.c:5868
+#: c/c-decl.c:5888
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter `%s'"
 msgid "storage class specified for parameter %qE"
 msgstr "lagringsklasse angivet for parameter '%s'"
 
-#: c/c-decl.c:5871
+#: c/c-decl.c:5891
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter `%s'"
 msgid "storage class specified for unnamed parameter"
 msgstr "lagringsklasse angivet for parameter '%s'"
 
-#: c/c-decl.c:5874 cp/decl.c:10935
+#: c/c-decl.c:5894 cp/decl.c:10959
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "lagringsklasse angivet for typenavn"
 
-#: c/c-decl.c:5891
+#: c/c-decl.c:5911
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' initialized and declared `extern'"
 msgid "%qE initialized and declared %<extern%>"
 msgstr "'%s' bliver tildelt en startværdi og er samtidig erklæret 'extern'"
 
-#: c/c-decl.c:5895
+#: c/c-decl.c:5915
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' has both `extern' and initializer"
 msgid "%qE has both %<extern%> and initializer"
 msgstr "'%s' er erklæret 'extern', men bliver tildelt en startværdi"
 
-#: c/c-decl.c:5900
+#: c/c-decl.c:5920
 #, fuzzy, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<auto%>"
 msgstr "erklæring af '%s' på øverste niveau angiver 'auto'"
 
-#: c/c-decl.c:5904
+#: c/c-decl.c:5924
 #, fuzzy, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<register%>"
 msgstr "erklæring af '%s' på øverste niveau angiver 'auto'"
 
-#: c/c-decl.c:5909
+#: c/c-decl.c:5929
 #, fuzzy, gcc-internal-format
 #| msgid "nested function `%s' declared `extern'"
 msgid "nested function %qE declared %<extern%>"
 msgstr "indlejret funktion '%s' er erklæret 'extern'"
 
-#: c/c-decl.c:5912
+#: c/c-decl.c:5932
 #, fuzzy, gcc-internal-format
 #| msgid "function-scope `%s' implicitly auto and declared `__thread'"
 msgid "function-scope %qE implicitly auto and declared %qs"
@@ -38359,325 +38406,325 @@
 #. Only the innermost declarator (making a parameter be of
 #. array type which is converted to pointer type)
 #. may have static or type qualifiers.
-#: c/c-decl.c:5959 c/c-decl.c:6328
+#: c/c-decl.c:5979 c/c-decl.c:6348
 #, gcc-internal-format
 msgid "static or type qualifiers in non-parameter array declarator"
 msgstr "static eller typemodifikationer i ikke-parametertabelerklæring"
 
-#: c/c-decl.c:6007
+#: c/c-decl.c:6027
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' as array of voids"
 msgid "declaration of %qE as array of voids"
 msgstr "'%s' erklæret som en tabel af void"
 
-#: c/c-decl.c:6009
+#: c/c-decl.c:6029
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' as array of voids"
 msgid "declaration of type name as array of voids"
 msgstr "'%s' erklæret som en tabel af void"
 
-#: c/c-decl.c:6016
+#: c/c-decl.c:6036
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' as array of functions"
 msgid "declaration of %qE as array of functions"
 msgstr "'%s' erklæret som en tabel af funktioner"
 
-#: c/c-decl.c:6019
+#: c/c-decl.c:6039
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' as array of functions"
 msgid "declaration of type name as array of functions"
 msgstr "'%s' erklæret som en tabel af funktioner"
 
-#: c/c-decl.c:6027 c/c-decl.c:8085
+#: c/c-decl.c:6047 c/c-decl.c:8105
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr "ugyldig brug af struktur med fleksibelt tabelmedlem"
 
-#: c/c-decl.c:6053
+#: c/c-decl.c:6073
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%s' has non-integer type"
 msgid "size of array %qE has non-integer type"
 msgstr "størrelsen af tabellen '%s' er ikke af en heltalstype"
 
-#: c/c-decl.c:6057
+#: c/c-decl.c:6077
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%s' has non-integer type"
 msgid "size of unnamed array has non-integer type"
 msgstr "størrelsen af tabellen '%s' er ikke af en heltalstype"
 
-#: c/c-decl.c:6064
+#: c/c-decl.c:6084
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%s' has non-integer type"
 msgid "size of array %qE has incomplete type"
 msgstr "størrelsen af tabellen '%s' er ikke af en heltalstype"
 
-#: c/c-decl.c:6067
+#: c/c-decl.c:6087
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%s' has non-integer type"
 msgid "size of unnamed array has incomplete type"
 msgstr "størrelsen af tabellen '%s' er ikke af en heltalstype"
 
-#: c/c-decl.c:6078
+#: c/c-decl.c:6098
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids zero-size array `%s'"
 msgid "ISO C forbids zero-size array %qE"
 msgstr "ISO C forbyder tabellen '%s' med størrelsen nul"
 
-#: c/c-decl.c:6081
+#: c/c-decl.c:6101
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids zero-size array"
 msgid "ISO C forbids zero-size array"
 msgstr "ISO C++ forbyder tabel med størrelsen nul"
 
-#: c/c-decl.c:6090
+#: c/c-decl.c:6110
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is negative"
 msgid "size of array %qE is negative"
 msgstr "størrelsen af tabel er negativ"
 
-#: c/c-decl.c:6092
+#: c/c-decl.c:6112
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is negative"
 msgid "size of unnamed array is negative"
 msgstr "størrelsen af tabel er negativ"
 
-#: c/c-decl.c:6216 c/c-decl.c:6871
+#: c/c-decl.c:6236 c/c-decl.c:6891
 #, gcc-internal-format
 msgid "ISO C90 does not support flexible array members"
 msgstr "ISO C90 understøtter ikke fleksible tabelmedlemmer"
 
 #. C99 6.7.5.2p4
-#: c/c-decl.c:6238
+#: c/c-decl.c:6258
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not at beginning of declaration"
 msgid "%<[*]%> not in a declaration"
 msgstr "'%s' er ikke ved begyndelsen af erklæringen"
 
-#: c/c-decl.c:6251
+#: c/c-decl.c:6271
 #, fuzzy, gcc-internal-format
 #| msgid "array type has incomplete element type"
 msgid "array type has incomplete element type %qT"
 msgstr "tabeltypen er af en ufuldstændig type"
 
-#: c/c-decl.c:6257
+#: c/c-decl.c:6277
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' as multidimensional array must have bounds for all dimensions except the first"
 msgid "declaration of %qE as multidimensional array must have bounds for all dimensions except the first"
 msgstr "erklæring af '%D' som flerdimensional tabel skal have grænser for alle dimensioner pånær den første"
 
-#: c/c-decl.c:6261
+#: c/c-decl.c:6281
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' as multidimensional array must have bounds for all dimensions except the first"
 msgid "declaration of multidimensional array must have bounds for all dimensions except the first"
 msgstr "erklæring af '%D' som flerdimensional tabel skal have grænser for alle dimensioner pånær den første"
 
-#: c/c-decl.c:6364
+#: c/c-decl.c:6384
 #, gcc-internal-format
 msgid "%qE declared as function returning a function"
 msgstr "%qE er erklæret som en funktion, der returnerer en funktion"
 
-#: c/c-decl.c:6367
+#: c/c-decl.c:6387
 #, gcc-internal-format
 msgid "type name declared as function returning a function"
 msgstr "'typenavn er erklæret som en funktion, der returnerer en funktion"
 
-#: c/c-decl.c:6374
+#: c/c-decl.c:6394
 #, gcc-internal-format
 msgid "%qE declared as function returning an array"
 msgstr "%qE er erklæret som en funktion, der returnerer en array"
 
-#: c/c-decl.c:6377
+#: c/c-decl.c:6397
 #, gcc-internal-format
 msgid "type name declared as function returning an array"
 msgstr "typenavn er erklæret som en funktion, der returnerer en array"
 
-#: c/c-decl.c:6418
+#: c/c-decl.c:6438
 #, gcc-internal-format
 msgid "function definition has qualified void return type"
 msgstr "funktiondefinition har kvalificeret void-returtype"
 
-#: c/c-decl.c:6421 cp/decl.c:11201
+#: c/c-decl.c:6441 cp/decl.c:11225
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "typemodifikationer ignoreret i funktionsreturtypen"
 
-#: c/c-decl.c:6459 c/c-decl.c:6668 c/c-decl.c:6721 c/c-decl.c:6805
-#: c/c-decl.c:6926 c/c-parser.c:2823
+#: c/c-decl.c:6479 c/c-decl.c:6688 c/c-decl.c:6741 c/c-decl.c:6825
+#: c/c-decl.c:6946 c/c-parser.c:2823
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids qualified function types"
 msgid "%<_Atomic%>-qualified function type"
 msgstr "ISO C forbyder funktionsreturtype med modifikationer"
 
-#: c/c-decl.c:6465 c/c-decl.c:6674 c/c-decl.c:6810 c/c-decl.c:6931
+#: c/c-decl.c:6485 c/c-decl.c:6694 c/c-decl.c:6830 c/c-decl.c:6951
 #, gcc-internal-format
 msgid "ISO C forbids qualified function types"
 msgstr "ISO C forbyder funktionsreturtype med modifikationer"
 
-#: c/c-decl.c:6559
+#: c/c-decl.c:6579
 #, gcc-internal-format
 msgid "%qs combined with %<auto%> qualifier for %qE"
 msgstr ""
 
-#: c/c-decl.c:6563
+#: c/c-decl.c:6583
 #, gcc-internal-format
 msgid "%qs combined with %<register%> qualifier for %qE"
 msgstr ""
 
-#: c/c-decl.c:6569
+#: c/c-decl.c:6589
 #, fuzzy, gcc-internal-format
 msgid "%qs specified for auto variable %qE"
 msgstr "ignorerer asm-anvisning til den ikke-statiske, lokale variabel '%s'"
 
-#: c/c-decl.c:6585
+#: c/c-decl.c:6605
 #, fuzzy, gcc-internal-format
 #| msgid "type specifier omitted for parameter `%E'"
 msgid "%qs specified for parameter %qE"
 msgstr "typeangivelse udeladt for parameteren '%E'"
 
-#: c/c-decl.c:6588
+#: c/c-decl.c:6608
 #, fuzzy, gcc-internal-format
 #| msgid "type specifier omitted for parameter"
 msgid "%qs specified for unnamed parameter"
 msgstr "typeangivelsen er ikke angivet for parameteren"
 
-#: c/c-decl.c:6594
+#: c/c-decl.c:6614
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for structure field `%s'"
 msgid "%qs specified for structure field %qE"
 msgstr "lagringsklasse angivet for strukturfelt '%s'"
 
-#: c/c-decl.c:6597
+#: c/c-decl.c:6617
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for structure field `%s'"
 msgid "%qs specified for structure field"
 msgstr "lagringsklasse angivet for strukturfelt '%s'"
 
-#: c/c-decl.c:6612
+#: c/c-decl.c:6632
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field `%s' has invalid type"
 msgid "bit-field %qE has atomic type"
 msgstr "bitfeltet '%s' er af en ufuldstændig type"
 
-#: c/c-decl.c:6614
+#: c/c-decl.c:6634
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field `%s' has invalid type"
 msgid "bit-field has atomic type"
 msgstr "bitfeltet '%s' er af en ufuldstændig type"
 
-#: c/c-decl.c:6623
+#: c/c-decl.c:6643
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for typedef %qE"
 msgstr "justering må ikke angives for '%s'"
 
-#: c/c-decl.c:6625
+#: c/c-decl.c:6645
 #, gcc-internal-format
 msgid "alignment specified for %<register%> object %qE"
 msgstr ""
 
-#: c/c-decl.c:6630
+#: c/c-decl.c:6650
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter `%s'"
 msgid "alignment specified for parameter %qE"
 msgstr "lagringsklasse angivet for parameter '%s'"
 
-#: c/c-decl.c:6632
+#: c/c-decl.c:6652
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter `%s'"
 msgid "alignment specified for unnamed parameter"
 msgstr "lagringsklasse angivet for parameter '%s'"
 
-#: c/c-decl.c:6637
+#: c/c-decl.c:6657
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for bit-field %qE"
 msgstr "justering må ikke angives for '%s'"
 
-#: c/c-decl.c:6639
+#: c/c-decl.c:6659
 #, fuzzy, gcc-internal-format
 #| msgid "`__alignof' applied to a bit-field"
 msgid "alignment specified for unnamed bit-field"
 msgstr "'__alignof' benyttet på et bitfelt"
 
-#: c/c-decl.c:6642
+#: c/c-decl.c:6662
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified for functions"
 msgid "alignment specified for function %qE"
 msgstr "'%D' kan kun angives for funktioner"
 
-#: c/c-decl.c:6649
+#: c/c-decl.c:6669
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of %qE"
 msgstr ""
 
-#: c/c-decl.c:6652
+#: c/c-decl.c:6672
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of unnamed field"
 msgstr ""
 
-#: c/c-decl.c:6683
+#: c/c-decl.c:6703
 #, fuzzy, gcc-internal-format
 msgid "typedef %q+D declared %<inline%>"
 msgstr "variablen '%s' er erklæret 'inline'"
 
-#: c/c-decl.c:6685
+#: c/c-decl.c:6705
 #, fuzzy, gcc-internal-format
 #| msgid "operator `%T' declared to return `%T'"
 msgid "typedef %q+D declared %<_Noreturn%>"
 msgstr "operator '%T' erklæret til at returnere '%T'"
 
-#: c/c-decl.c:6727
+#: c/c-decl.c:6747
 #, gcc-internal-format
 msgid "ISO C forbids const or volatile function types"
 msgstr "ISO C forbyder const eller volatile funktionstyper"
 
 #. C99 6.7.2.1p8
-#: c/c-decl.c:6738
+#: c/c-decl.c:6758
 #, fuzzy, gcc-internal-format
 #| msgid "data member may not have variably modified type `%T'"
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "datamedlem må ikke have variabelt ændret type '%T'"
 
-#: c/c-decl.c:6755 cp/decl.c:9989
+#: c/c-decl.c:6775 cp/decl.c:10010
 #, fuzzy, gcc-internal-format
 #| msgid "variable or field declared void"
 msgid "variable or field %qE declared void"
 msgstr "variabel eller felt erklæret void"
 
-#: c/c-decl.c:6795
+#: c/c-decl.c:6815
 #, gcc-internal-format
 msgid "attributes in parameter array declarator ignored"
 msgstr "egenskaber i parametertabelerklæring ignoreret"
 
-#: c/c-decl.c:6837
+#: c/c-decl.c:6857
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%D' declared void"
 msgid "parameter %q+D declared %<inline%>"
 msgstr "parameteren '%D' erklæret void"
 
-#: c/c-decl.c:6839
+#: c/c-decl.c:6859
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%D' declared void"
 msgid "parameter %q+D declared %<_Noreturn%>"
 msgstr "parameteren '%D' erklæret void"
 
-#: c/c-decl.c:6852
+#: c/c-decl.c:6872
 #, fuzzy, gcc-internal-format
 #| msgid "field `%s' declared as a function"
 msgid "field %qE declared as a function"
 msgstr "feltet '%s' er erklæret som en funktion"
 
-#: c/c-decl.c:6859
+#: c/c-decl.c:6879
 #, fuzzy, gcc-internal-format
 #| msgid "field `%s' has incomplete type"
 msgid "field %qE has incomplete type"
 msgstr "feltet '%s' er af en ufuldstændig type"
 
-#: c/c-decl.c:6861
+#: c/c-decl.c:6881
 #, fuzzy, gcc-internal-format
 #| msgid "name `%T' has incomplete type"
 msgid "unnamed field has incomplete type"
 msgstr "navnet '%T' er af en ufuldstændig type"
 
-#: c/c-decl.c:6897 c/c-decl.c:6908 c/c-decl.c:6911
+#: c/c-decl.c:6917 c/c-decl.c:6928 c/c-decl.c:6931
 #, fuzzy, gcc-internal-format
 #| msgid "invalid storage class for function `%s'"
 msgid "invalid storage class for function %qE"
@@ -38684,242 +38731,242 @@
 msgstr "ugyldig lagringsklasse for funktion '%s'"
 
 # at oversætte inline med et udsagnsord her bliver vist for tvetydigt
-#: c/c-decl.c:6968
+#: c/c-decl.c:6988
 #, fuzzy, gcc-internal-format
 #| msgid "cannot inline function `main'"
 msgid "cannot inline function %<main%>"
 msgstr "funktionen 'main' kan ikke være inline"
 
-#: c/c-decl.c:6970
+#: c/c-decl.c:6990
 #, gcc-internal-format
 msgid "%<main%> declared %<_Noreturn%>"
 msgstr ""
 
-#: c/c-decl.c:6981
+#: c/c-decl.c:7001
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support complex types"
 msgid "ISO C99 does not support %<_Noreturn%>"
 msgstr "ISO C90 understøtter ikke komplekse typer"
 
-#: c/c-decl.c:6984
+#: c/c-decl.c:7004
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support complex types"
 msgid "ISO C90 does not support %<_Noreturn%>"
 msgstr "ISO C90 understøtter ikke komplekse typer"
 
-#: c/c-decl.c:7013
+#: c/c-decl.c:7033
 #, fuzzy, gcc-internal-format
 msgid "variable previously declared %<static%> redeclared %<extern%>"
 msgstr "variabel eller felt '%s' erklæret void"
 
-#: c/c-decl.c:7023
+#: c/c-decl.c:7043
 #, fuzzy, gcc-internal-format
 msgid "variable %q+D declared %<inline%>"
 msgstr "variablen '%s' er erklæret 'inline'"
 
-#: c/c-decl.c:7025
+#: c/c-decl.c:7045
 #, fuzzy, gcc-internal-format
 msgid "variable %q+D declared %<_Noreturn%>"
 msgstr "variablen '%s' er erklæret 'inline'"
 
-#: c/c-decl.c:7060
+#: c/c-decl.c:7080
 #, fuzzy, gcc-internal-format
 msgid "non-nested function with variably modified type"
 msgstr "skabelonsparameter '%T' er en variabelt ændret type"
 
-#: c/c-decl.c:7062
+#: c/c-decl.c:7082
 #, gcc-internal-format
 msgid "object with variably modified type must have no linkage"
 msgstr ""
 
-#: c/c-decl.c:7153 c/c-decl.c:8821
+#: c/c-decl.c:7173 c/c-decl.c:8841
 #, fuzzy, gcc-internal-format
 #| msgid "function declaration isn't a prototype"
 msgid "function declaration isn%'t a prototype"
 msgstr "funktionserklæringen er ikke en prototype"
 
-#: c/c-decl.c:7163
+#: c/c-decl.c:7183
 #, gcc-internal-format
 msgid "parameter names (without types) in function declaration"
 msgstr "parameternavne (uden typer) i funktionserklæringen"
 
-#: c/c-decl.c:7201
+#: c/c-decl.c:7221
 #, fuzzy, gcc-internal-format
 msgid "parameter %u (%q+D) has incomplete type"
 msgstr "parameteren er af en ufuldstændig type"
 
-#: c/c-decl.c:7205
+#: c/c-decl.c:7225
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "parameter has incomplete type"
 msgid "parameter %u has incomplete type"
 msgstr "parameteren er af en ufuldstændig type"
 
-#: c/c-decl.c:7216
+#: c/c-decl.c:7236
 #, fuzzy, gcc-internal-format
 msgid "parameter %u (%q+D) has void type"
 msgstr "parameteren er af en ufuldstændig type"
 
-#: c/c-decl.c:7220
+#: c/c-decl.c:7240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "parameter `%s' has incomplete type"
 msgid "parameter %u has void type"
 msgstr "parameteren '%s' er af en ufuldstændig type"
 
-#: c/c-decl.c:7294
+#: c/c-decl.c:7314
 #, fuzzy, gcc-internal-format
 msgid "%<void%> as only parameter may not be qualified"
 msgstr "typedef-navn kan ikke klassemodificeres"
 
-#: c/c-decl.c:7298 c/c-decl.c:7334
+#: c/c-decl.c:7318 c/c-decl.c:7354
 #, fuzzy, gcc-internal-format
 msgid "%<void%> must be the only parameter"
 msgstr "ugyldig brug af skabelonstypeparameter"
 
-#: c/c-decl.c:7328
+#: c/c-decl.c:7348
 #, fuzzy, gcc-internal-format
 msgid "parameter %q+D has just a forward declaration"
 msgstr "parameteren '%s' har kun en forhåndserklæring"
 
-#: c/c-decl.c:7374
+#: c/c-decl.c:7394
 #, gcc-internal-format
 msgid "%<%s %E%> declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr ""
 
-#: c/c-decl.c:7380
+#: c/c-decl.c:7400
 #, gcc-internal-format, gfc-internal-format
 msgid "anonymous %s declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr ""
 
-#: c/c-decl.c:7482
+#: c/c-decl.c:7502
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' previously defined here"
 msgid "enum type defined here"
 msgstr "'%s' tidligere defineret her"
 
-#: c/c-decl.c:7488
+#: c/c-decl.c:7508
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' previously defined here"
 msgid "struct defined here"
 msgstr "'%s' tidligere defineret her"
 
-#: c/c-decl.c:7494
+#: c/c-decl.c:7514
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' previously defined here"
 msgid "union defined here"
 msgstr "'%s' tidligere defineret her"
 
-#: c/c-decl.c:7570
+#: c/c-decl.c:7590
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of `union %s'"
 msgid "redefinition of %<union %E%>"
 msgstr "omdefinering af 'union %s'"
 
-#: c/c-decl.c:7572
+#: c/c-decl.c:7592
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of `struct %s'"
 msgid "redefinition of %<struct %E%>"
 msgstr "omdefinering af 'struct %s'"
 
-#: c/c-decl.c:7581
+#: c/c-decl.c:7601
 #, fuzzy, gcc-internal-format
 #| msgid "nested redefinition of `%s'"
 msgid "nested redefinition of %<union %E%>"
 msgstr "indlejret omdefinering af '%s'"
 
-#: c/c-decl.c:7583
+#: c/c-decl.c:7603
 #, fuzzy, gcc-internal-format
 #| msgid "nested redefinition of `%s'"
 msgid "nested redefinition of %<struct %E%>"
 msgstr "indlejret omdefinering af '%s'"
 
-#: c/c-decl.c:7613 c/c-decl.c:8400
+#: c/c-decl.c:7633 c/c-decl.c:8420
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:7680 cp/decl.c:4802
+#: c/c-decl.c:7700 cp/decl.c:4802
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "erklæring erklærer ikke noget"
 
-#: c/c-decl.c:7685
+#: c/c-decl.c:7705
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C doesn't support unnamed structs/unions"
 msgid "ISO C99 doesn%'t support unnamed structs/unions"
 msgstr "ISO C understøtter ikke unavngivne struct/union-konstruktioner"
 
-#: c/c-decl.c:7688
+#: c/c-decl.c:7708
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C doesn't support unnamed structs/unions"
 msgid "ISO C90 doesn%'t support unnamed structs/unions"
 msgstr "ISO C understøtter ikke unavngivne struct/union-konstruktioner"
 
-#: c/c-decl.c:7781 c/c-decl.c:7799 c/c-decl.c:7860
+#: c/c-decl.c:7801 c/c-decl.c:7819 c/c-decl.c:7880
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate member `%D'"
 msgid "duplicate member %q+D"
 msgstr "medlemmet '%D' optræder mere end én gang"
 
-#: c/c-decl.c:7886
+#: c/c-decl.c:7906
 #, gcc-internal-format
 msgid "empty struct has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.c:7889
+#: c/c-decl.c:7909
 #, gcc-internal-format
 msgid "empty union has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.c:7994
+#: c/c-decl.c:8014
 #, fuzzy, gcc-internal-format
 #| msgid "named members"
 msgid "union has no named members"
 msgstr "navngivne medlemmer"
 
-#: c/c-decl.c:7996
+#: c/c-decl.c:8016
 #, fuzzy, gcc-internal-format
 msgid "union has no members"
 msgstr "anonym sammensat type uden medlemmer"
 
-#: c/c-decl.c:8001
+#: c/c-decl.c:8021
 #, fuzzy, gcc-internal-format
 #| msgid "named members"
 msgid "struct has no named members"
 msgstr "navngivne medlemmer"
 
-#: c/c-decl.c:8003
+#: c/c-decl.c:8023
 #, fuzzy, gcc-internal-format
 #| msgid "%s has no member named `%s'"
 msgid "struct has no members"
 msgstr "%s har intet medlem ved navn '%s'"
 
-#: c/c-decl.c:8064 cp/decl.c:12069
+#: c/c-decl.c:8084 cp/decl.c:12093
 #, fuzzy, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "fleksibelt tabelmedlem i union"
 
-#: c/c-decl.c:8070
+#: c/c-decl.c:8090
 #, fuzzy, gcc-internal-format
 msgid "flexible array member not at end of struct"
 msgstr "fleksibelt tabelmedlem ikke i slutningen af struktur"
 
-#: c/c-decl.c:8076
+#: c/c-decl.c:8096
 #, fuzzy, gcc-internal-format
 msgid "flexible array member in a struct with no named members"
 msgstr "fleksibelt tabelmedlem i union"
 
-#: c/c-decl.c:8107
+#: c/c-decl.c:8127
 #, fuzzy, gcc-internal-format
 #| msgid "%s is too large"
 msgid "type %qT is too large"
 msgstr "%s er for stor"
 
-#: c/c-decl.c:8230
+#: c/c-decl.c:8250
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr "union kan ikke ikke gøres gennemsigtig"
 
-#: c/c-decl.c:8372
+#: c/c-decl.c:8392
 #, fuzzy, gcc-internal-format
 #| msgid "nested redefinition of `%s'"
 msgid "nested redefinition of %<enum %E%>"
@@ -38926,203 +38973,203 @@
 msgstr "indlejret omdefinering af '%s'"
 
 #. This enum is a named one that has been declared already.
-#: c/c-decl.c:8379
+#: c/c-decl.c:8399
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of `enum %s'"
 msgid "redeclaration of %<enum %E%>"
 msgstr "omerklæring af 'enum %s'"
 
-#: c/c-decl.c:8458 cp/decl.c:14423
+#: c/c-decl.c:8478 cp/decl.c:14447
 #, gcc-internal-format
 msgid "specified mode too small for enumeral values"
 msgstr ""
 
-#: c/c-decl.c:8473
+#: c/c-decl.c:8493
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr "enum-værdier overstige rækkevidden af det største heltal"
 
-#: c/c-decl.c:8587 c/c-decl.c:8603
+#: c/c-decl.c:8607 c/c-decl.c:8623
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for `%s' not integer constant"
 msgid "enumerator value for %qE is not an integer constant"
 msgstr "enum-værdien for '%s' er ikke en heltalskonstant"
 
-#: c/c-decl.c:8598
+#: c/c-decl.c:8618
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for `%s' not integer constant"
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr "enum-værdien for '%s' er ikke en heltalskonstant"
 
-#: c/c-decl.c:8622
+#: c/c-decl.c:8642
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr "enum-værdier for store"
 
-#: c/c-decl.c:8630
+#: c/c-decl.c:8650
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C restricts enumerator values to range of `int'"
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "ISO C begrænser enum-værdier til rækkevidden af 'int'"
 
-#: c/c-decl.c:8715 cp/decl.c:5104 cp/decl.c:14955
+#: c/c-decl.c:8735 cp/decl.c:5104 cp/decl.c:14979
 #, fuzzy, gcc-internal-format
 msgid "inline function %qD given attribute noinline"
 msgstr "inline funktion '%s' givet egenskaben noinline"
 
-#: c/c-decl.c:8733
+#: c/c-decl.c:8753
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr "returtypen er en ufuldstændig type"
 
-#: c/c-decl.c:8744
+#: c/c-decl.c:8764
 #, fuzzy, gcc-internal-format
 #| msgid "return type defaults to `int'"
 msgid "return type defaults to %<int%>"
 msgstr "returtypen antages at være 'int'"
 
-#: c/c-decl.c:8771
+#: c/c-decl.c:8791
 #, fuzzy, gcc-internal-format
 #| msgid "field `%s' declared as a function"
 msgid "%q+D defined as variadic function without prototype"
 msgstr "feltet '%s' er erklæret som en funktion"
 
-#: c/c-decl.c:8830
+#: c/c-decl.c:8850
 #, fuzzy, gcc-internal-format
 msgid "no previous prototype for %qD"
 msgstr "ingen tidligere prototype for '%s'"
 
-#: c/c-decl.c:8839
+#: c/c-decl.c:8859
 #, fuzzy, gcc-internal-format
 msgid "%qD was used with no prototype before its definition"
 msgstr "'%s' blev brugt uden en prototype før dens definition"
 
-#: c/c-decl.c:8847 cp/decl.c:15090
+#: c/c-decl.c:8867 cp/decl.c:15114
 #, fuzzy, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "ingen tidligere erklæring af '%s'"
 
-#: c/c-decl.c:8857
+#: c/c-decl.c:8877
 #, fuzzy, gcc-internal-format
 msgid "%qD was used with no declaration before its definition"
 msgstr "'%s' blev brugt uden en erklæring før dens definition"
 
-#: c/c-decl.c:8876
+#: c/c-decl.c:8896
 #, fuzzy, gcc-internal-format
 msgid "return type of %qD is not %<int%>"
 msgstr "returtypen til '%s' er ikke 'int'"
 
-#: c/c-decl.c:8878
+#: c/c-decl.c:8898
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr ""
 
-#: c/c-decl.c:8885
+#: c/c-decl.c:8905
 #, fuzzy, gcc-internal-format
 msgid "%qD is normally a non-static function"
 msgstr "'%s' er normalt en ikke-statisk funktion"
 
-#: c/c-decl.c:8922
+#: c/c-decl.c:8942
 #, fuzzy, gcc-internal-format
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr "kan ikke bruge '::' i parametererklæring"
 
-#: c/c-decl.c:8937
+#: c/c-decl.c:8957
 #, gcc-internal-format
 msgid "traditional C rejects ISO C style function definitions"
 msgstr "traditionel C tillader ikke ISO C-functionsdefinitioner"
 
-#: c/c-decl.c:8953
+#: c/c-decl.c:8973
 #, fuzzy, gcc-internal-format
 msgid "parameter name omitted"
 msgstr "parameternavn udeladt"
 
-#: c/c-decl.c:8990
+#: c/c-decl.c:9010
 #, fuzzy, gcc-internal-format
 #| msgid "traditional C rejects ISO C style function definitions"
 msgid "old-style function definition"
 msgstr "traditionel C tillader ikke ISO C-functionsdefinitioner"
 
-#: c/c-decl.c:8999
+#: c/c-decl.c:9019
 #, fuzzy, gcc-internal-format
 msgid "parameter name missing from parameter list"
 msgstr "parameternavn mangler fra parameterliste"
 
-#: c/c-decl.c:9015
+#: c/c-decl.c:9035
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a non-parameter"
 msgstr "'%D' er erklæret som en ven"
 
-#: c/c-decl.c:9023
+#: c/c-decl.c:9043
 #, fuzzy, gcc-internal-format
 msgid "multiple parameters named %qD"
 msgstr "flere parametre ved navn '%s'"
 
-#: c/c-decl.c:9032
+#: c/c-decl.c:9052
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%D' declared void"
 msgid "parameter %qD declared with void type"
 msgstr "parameteren '%D' erklæret void"
 
-#: c/c-decl.c:9061 c/c-decl.c:9066
+#: c/c-decl.c:9081 c/c-decl.c:9086
 #, fuzzy, gcc-internal-format
 msgid "type of %qD defaults to %<int%>"
 msgstr "typen til '%s' antages at være 'int'"
 
-#: c/c-decl.c:9086
+#: c/c-decl.c:9106
 #, fuzzy, gcc-internal-format
 #| msgid "parameter has incomplete type"
 msgid "parameter %qD has incomplete type"
 msgstr "parameteren er af en ufuldstændig type"
 
-#: c/c-decl.c:9093
+#: c/c-decl.c:9113
 #, fuzzy, gcc-internal-format
 msgid "declaration for parameter %qD but no such parameter"
 msgstr "erklæring af parameteren '%s', men ingen sådan parameter"
 
-#: c/c-decl.c:9146
+#: c/c-decl.c:9166
 #, fuzzy, gcc-internal-format
 #| msgid "number of arguments doesn't match prototype"
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr "antallet af parametre passer ikke til prototypen"
 
-#: c/c-decl.c:9157
+#: c/c-decl.c:9177
 #, fuzzy, gcc-internal-format
 #| msgid "number of arguments doesn't match prototype"
 msgid "number of arguments doesn%'t match prototype"
 msgstr "antallet af parametre passer ikke til prototypen"
 
-#: c/c-decl.c:9160 c/c-decl.c:9207 c/c-decl.c:9221
+#: c/c-decl.c:9180 c/c-decl.c:9227 c/c-decl.c:9241
 #, fuzzy, gcc-internal-format
 msgid "prototype declaration"
 msgstr "tom erklæring"
 
-#: c/c-decl.c:9199
+#: c/c-decl.c:9219
 #, fuzzy, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr "den forfremmede parameter '%s' passer ikke til prototypen"
 
-#: c/c-decl.c:9204
+#: c/c-decl.c:9224
 #, fuzzy, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr "den forfremmede parameter '%s' passer ikke til prototypen"
 
-#: c/c-decl.c:9214
+#: c/c-decl.c:9234
 #, fuzzy, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr "parameteren '%s' passer ikke til prototypen"
 
-#: c/c-decl.c:9219
+#: c/c-decl.c:9239
 #, fuzzy, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr "parameteren '%s' passer ikke til prototypen"
 
-#: c/c-decl.c:9470 cp/decl.c:15873
+#: c/c-decl.c:9490 cp/decl.c:15897
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "ingen return-sætning i en funktion der ikke returnerer void"
 
-#: c/c-decl.c:9490 cp/decl.c:15905
+#: c/c-decl.c:9510 cp/decl.c:15929
 #, fuzzy, gcc-internal-format
 #| msgid "label `%D' defined but not used"
 msgid "parameter %qD set but not used"
@@ -39131,272 +39178,272 @@
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:9586
+#: c/c-decl.c:9606
 #, fuzzy, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "begyndelseserklæring i 'for'-løkke benyttet uden for C99-tilstand"
 
-#: c/c-decl.c:9591
+#: c/c-decl.c:9611
 #, gcc-internal-format
 msgid "use option -std=c99, -std=gnu99, -std=c11 or -std=gnu11 to compile your code"
 msgstr ""
 
-#: c/c-decl.c:9626
+#: c/c-decl.c:9646
 #, fuzzy, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "erklæring af '%s' der er en statisk variabel, i begyndelseserklæring i 'for'-løkke"
 
-#: c/c-decl.c:9630
+#: c/c-decl.c:9650
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "erklæring af '%s' der er en 'extern'-variabel, i begyndelseserklæring i 'for'-løkke"
 
-#: c/c-decl.c:9637
+#: c/c-decl.c:9657
 #, fuzzy, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "'struct %s' erklæret i begyndelseserklæring i 'for'-løkke"
 
-#: c/c-decl.c:9642
+#: c/c-decl.c:9662
 #, fuzzy, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "'union %s' erklæret i begyndelseserklæring i 'for'-løkke"
 
-#: c/c-decl.c:9646
+#: c/c-decl.c:9666
 #, fuzzy, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "'enum %s' erklæret i begyndelseserklæring i 'for'-løkke"
 
-#: c/c-decl.c:9650
+#: c/c-decl.c:9670
 #, fuzzy, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "erklæring af '%s' der ikke er en variabel, i begyndelseserklæring i 'for'-løkke"
 
-#: c/c-decl.c:9900
+#: c/c-decl.c:9920
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr ""
 
-#: c/c-decl.c:9958 c/c-decl.c:9965
+#: c/c-decl.c:9978 c/c-decl.c:9985
 #, fuzzy, gcc-internal-format
 #| msgid "repeated declaration of unit `%s'"
 msgid "duplicate %qE declaration specifier"
 msgstr "gentaget erklæring af enheden '%s'"
 
-#: c/c-decl.c:9992 c/c-decl.c:10376 c/c-decl.c:10766
+#: c/c-decl.c:10012 c/c-decl.c:10396 c/c-decl.c:10786
 #, fuzzy, gcc-internal-format
 #| msgid "two or more data types in declaration of `%s'"
 msgid "two or more data types in declaration specifiers"
 msgstr "mere end én datatype i erklæringen af '%s'"
 
-#: c/c-decl.c:10004 cp/parser.c:28261
+#: c/c-decl.c:10024 cp/parser.c:28258
 #, fuzzy, gcc-internal-format
 #| msgid "`long long long' is too long for GCC"
 msgid "%<long long long%> is too long for GCC"
 msgstr "'long long long' er for langt for GCC"
 
-#: c/c-decl.c:10017
+#: c/c-decl.c:10037
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support `long long'"
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C90 understøtter ikke 'long long'"
 
-#: c/c-decl.c:10246 c/c-parser.c:8848
+#: c/c-decl.c:10266 c/c-parser.c:8848
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C90 understøtter ikke komplekse typer"
 
-#: c/c-decl.c:10292
+#: c/c-decl.c:10312
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support saturating types"
 msgstr "ISO C understøtter ikke komplekse heltalstyper"
 
-#: c/c-decl.c:10363 c/c-decl.c:10923
+#: c/c-decl.c:10383 c/c-decl.c:10943
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `%s'"
 msgid "duplicate %qE"
 msgstr "'%s' optræder mere end én gang"
 
-#: c/c-decl.c:10419
+#: c/c-decl.c:10439
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C understøtter ikke komplekse heltalstyper"
 
-#: c/c-decl.c:10441
+#: c/c-decl.c:10461
 #, fuzzy, gcc-internal-format
 #| msgid "Profiling is not supported on this target."
 msgid "%<__int%d%> is not supported on this target"
 msgstr "Profilering er ikke understøttet på målarkitekturen."
 
-#: c/c-decl.c:10484
+#: c/c-decl.c:10504
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support complex types"
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C90 understøtter ikke komplekse typer"
 
-#: c/c-decl.c:10603
+#: c/c-decl.c:10623
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support the %<_Float%d%s%> type"
 msgstr "ISO C understøtter ikke komplekse heltalstyper"
 
-#: c/c-decl.c:10653
+#: c/c-decl.c:10673
 #, fuzzy, gcc-internal-format
 #| msgid "Profiling is not supported on this target."
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "Profilering er ikke understøttet på målarkitekturen."
 
-#: c/c-decl.c:10724
+#: c/c-decl.c:10744
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support `long long'"
 msgid "ISO C does not support decimal floating point"
 msgstr "ISO C90 understøtter ikke 'long long'"
 
-#: c/c-decl.c:10747 c/c-decl.c:11013 c/c-parser.c:7842
+#: c/c-decl.c:10767 c/c-decl.c:11033 c/c-parser.c:7842
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "fixed-point types not supported for this target"
 msgstr "-fdata-sections understøttes ikke på målarkitekturen"
 
-#: c/c-decl.c:10749
+#: c/c-decl.c:10769
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C understøtter ikke komplekse heltalstyper"
 
-#: c/c-decl.c:10784
+#: c/c-decl.c:10804
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr ""
 
-#: c/c-decl.c:10797
+#: c/c-decl.c:10817
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' fails to be a typedef or built in type"
 msgid "%qE fails to be a typedef or built in type"
 msgstr "'%s' er hverken en typedef eller en indbygget type"
 
-#: c/c-decl.c:10845
+#: c/c-decl.c:10865
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not at beginning of declaration"
 msgid "%qE is not at beginning of declaration"
 msgstr "'%s' er ikke ved begyndelsen af erklæringen"
 
-#: c/c-decl.c:10866
+#: c/c-decl.c:10886
 #, gcc-internal-format
 msgid "%qE used with %<auto%>"
 msgstr ""
 
-#: c/c-decl.c:10868
+#: c/c-decl.c:10888
 #, gcc-internal-format
 msgid "%qE used with %<register%>"
 msgstr ""
 
-#: c/c-decl.c:10870
+#: c/c-decl.c:10890
 #, gcc-internal-format
 msgid "%qE used with %<typedef%>"
 msgstr ""
 
-#: c/c-decl.c:10884 c/c-parser.c:7360
+#: c/c-decl.c:10904 c/c-parser.c:7360
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "ISO C99 does not support %qE"
 msgstr "%s understøtter ikke %s"
 
-#: c/c-decl.c:10887 c/c-parser.c:7363
+#: c/c-decl.c:10907 c/c-parser.c:7363
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support `long long'"
 msgid "ISO C90 does not support %qE"
 msgstr "ISO C90 understøtter ikke 'long long'"
 
-#: c/c-decl.c:10899
+#: c/c-decl.c:10919
 #, fuzzy, gcc-internal-format
 #| msgid "`__thread' before `extern'"
 msgid "%<__thread%> before %<extern%>"
 msgstr "'__thread' før 'extern'"
 
-#: c/c-decl.c:10908
+#: c/c-decl.c:10928
 #, fuzzy, gcc-internal-format
 #| msgid "`__thread' before `static'"
 msgid "%<__thread%> before %<static%>"
 msgstr "'__thread' før 'static'"
 
-#: c/c-decl.c:10921
+#: c/c-decl.c:10941
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr ""
 
-#: c/c-decl.c:10929
+#: c/c-decl.c:10949
 #, fuzzy, gcc-internal-format
 #| msgid "multiple storage classes in declaration of `%s'"
 msgid "multiple storage classes in declaration specifiers"
 msgstr "flere lagringsklasser optræder i erklæringen af '%s'"
 
-#: c/c-decl.c:10937
+#: c/c-decl.c:10957
 #, fuzzy, gcc-internal-format
 #| msgid "%s used with `%%%c' %s format"
 msgid "%qs used with %qE"
 msgstr "%s brugt med '%%%c' %s-formatering"
 
-#: c/c-decl.c:11010
+#: c/c-decl.c:11030
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr ""
 
-#: c/c-decl.c:11025
+#: c/c-decl.c:11045
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain `complex' meaning `double complex'"
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C understøtter ikke at blot 'complex' betyder 'double complex'"
 
-#: c/c-decl.c:11076 c/c-decl.c:11092 c/c-decl.c:11118
+#: c/c-decl.c:11096 c/c-decl.c:11112 c/c-decl.c:11138
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C understøtter ikke komplekse heltalstyper"
 
-#: c/c-decl.c:11514 cp/semantics.c:5348
+#: c/c-decl.c:11534 cp/semantics.c:5351
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:11518 cp/semantics.c:5352
+#: c/c-decl.c:11538 cp/semantics.c:5355
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.c:385 c/c-typeck.c:11426 cp/typeck.c:4680
+#: c/c-fold.c:385 c/c-typeck.c:11431 cp/typeck.c:4680
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count is negative"
 msgid "left shift of negative value"
 msgstr "venstreskiftsantal er negativ"
 
-#: c/c-fold.c:395 c/c-typeck.c:11435 cp/typeck.c:4688
+#: c/c-fold.c:395 c/c-typeck.c:11440 cp/typeck.c:4688
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "venstreskiftsantal er negativ"
 
-#: c/c-fold.c:396 c/c-typeck.c:11365 cp/typeck.c:4633
+#: c/c-fold.c:396 c/c-typeck.c:11370 cp/typeck.c:4633
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "højreskiftsantal er negativ"
 
-#: c/c-fold.c:404 c/c-typeck.c:11454 cp/typeck.c:4696
+#: c/c-fold.c:404 c/c-typeck.c:11459 cp/typeck.c:4696
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "venstreskiftsantal er større end bredden af typen"
 
-#: c/c-fold.c:405 c/c-typeck.c:11389 cp/typeck.c:4641
+#: c/c-fold.c:405 c/c-typeck.c:11394 cp/typeck.c:4641
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "højreskiftsantal er større end bredden af typen"
 
-#: c/c-fold.c:412 c/c-typeck.c:11446
+#: c/c-fold.c:412 c/c-typeck.c:11451
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count >= width of type"
 msgid "left shift count >= width of vector element"
 msgstr "venstreskiftsantal er større end bredden af typen"
 
-#: c/c-fold.c:413 c/c-typeck.c:11376
+#: c/c-fold.c:413 c/c-typeck.c:11381
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count >= width of type"
 msgid "right shift count >= width of vector element"
@@ -39418,7 +39465,7 @@
 msgid "to match this %qs"
 msgstr "  anden type her"
 
-#: c/c-parser.c:1216 cp/parser.c:28484
+#: c/c-parser.c:1216 cp/parser.c:28481
 #, fuzzy, gcc-internal-format
 #| msgid "garbage at end of #line"
 msgid "expected end of line"
@@ -39464,7 +39511,7 @@
 msgstr "ukendt registernavn: %s"
 
 #: c/c-parser.c:1848 c/c-parser.c:11129 c/c-parser.c:16147 c/c-parser.c:16585
-#: c/c-parser.c:17061 cp/parser.c:36007 cp/parser.c:38993
+#: c/c-parser.c:17061 cp/parser.c:36004 cp/parser.c:38990
 #, fuzzy, gcc-internal-format
 #| msgid "repeated declaration of unit `%s'"
 msgid "expected declaration specifiers"
@@ -39481,7 +39528,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr ""
 
-#: c/c-parser.c:1906 cp/parser.c:30161 cp/parser.c:30235
+#: c/c-parser.c:1906 cp/parser.c:30158 cp/parser.c:30232
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored for `%s'"
 msgid "prefix attributes are ignored for methods"
@@ -39537,7 +39584,7 @@
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr ""
 
-#: c/c-parser.c:2220 cp/parser.c:13002 cp/parser.c:13159
+#: c/c-parser.c:2220 cp/parser.c:12999 cp/parser.c:13156
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr ""
@@ -39567,7 +39614,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C90 understøtter ikke komplekse typer"
 
-#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38634
+#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38631
 #, fuzzy, gcc-internal-format
 #| msgid "_Pragma takes a parenthesized string literal"
 msgid "expected string literal"
@@ -39639,13 +39686,13 @@
 #: c/c-parser.c:10745 c/c-parser.c:10798 c/c-parser.c:10814 c/c-parser.c:10860
 #: c/c-parser.c:11496 c/c-parser.c:11537 c/c-parser.c:13445 c/c-parser.c:13681
 #: c/c-parser.c:15544 c/c-parser.c:18218 c/gimple-parser.c:1058
-#: c/gimple-parser.c:1096 cp/parser.c:28487 cp/parser.c:31013
-#: cp/parser.c:31043 cp/parser.c:31113 cp/parser.c:33230 cp/parser.c:38350
+#: c/gimple-parser.c:1096 cp/parser.c:28484 cp/parser.c:31010
+#: cp/parser.c:31040 cp/parser.c:31110 cp/parser.c:33227 cp/parser.c:38347
 #, fuzzy, gcc-internal-format
 msgid "expected identifier"
 msgstr "uventet operand"
 
-#: c/c-parser.c:2995 cp/parser.c:18384
+#: c/c-parser.c:2995 cp/parser.c:18381
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "komma i slutningen af enum-liste"
@@ -39826,12 +39873,12 @@
 msgid "expected statement"
 msgstr "uventet operand"
 
-#: c/c-parser.c:5639 cp/parser.c:12516
+#: c/c-parser.c:5639 cp/parser.c:12513
 #, fuzzy, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "tom krop i en else-sætning"
 
-#: c/c-parser.c:5681 cp/parser.c:12519
+#: c/c-parser.c:5681 cp/parser.c:12516
 #, fuzzy, gcc-internal-format
 #| msgid "empty body in an else-statement"
 msgid "suggest braces around empty body in an %<else%> statement"
@@ -40208,7 +40255,7 @@
 msgid "%<__builtin_complex%> operands of different types"
 msgstr "operander til ?: har forskellige typer"
 
-#: c/c-parser.c:8891 cp/parser.c:6918
+#: c/c-parser.c:8891 cp/parser.c:6921
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "wrong number of arguments to %<__builtin_shuffle%>"
@@ -40273,78 +40320,78 @@
 msgid "no type or storage class may be specified here,"
 msgstr "lagringsklasse angivet for typenavn"
 
-#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31073
+#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31070
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr ""
 
-#: c/c-parser.c:10682 cp/parser.c:31033
+#: c/c-parser.c:10682 cp/parser.c:31030
 #, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr ""
 
-#: c/c-parser.c:10685 cp/parser.c:31036
+#: c/c-parser.c:10685 cp/parser.c:31033
 #, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr ""
 
-#: c/c-parser.c:10699 cp/parser.c:31051
+#: c/c-parser.c:10699 cp/parser.c:31048
 #, fuzzy, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "sektionsegenskaben kan ikke angives for lokale variabler"
 
-#: c/c-parser.c:10704 cp/parser.c:31057
+#: c/c-parser.c:10704 cp/parser.c:31054
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.c:10711 cp/parser.c:31065
+#: c/c-parser.c:10711 cp/parser.c:31062
 #, fuzzy, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "en dataområdeegenskab kan ikke angives for lokale variable"
 
-#: c/c-parser.c:10905 cp/parser.c:38674
+#: c/c-parser.c:10905 cp/parser.c:38671
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
 #: c/c-parser.c:10949 c/c-parser.c:16582 c/c-parser.c:16840 c/c-parser.c:16899
-#: c/c-parser.c:16983 cp/parser.c:36004 cp/parser.c:36298 cp/parser.c:36386
-#: cp/parser.c:36457 cp/parser.c:38721 cp/parser.c:38736 cp/parser.c:38752
-#: cp/parser.c:38768 cp/parser.c:38784 cp/parser.c:38811 cp/parser.c:38824
-#: cp/parser.c:38847 cp/parser.c:38860
+#: c/c-parser.c:16983 cp/parser.c:36001 cp/parser.c:36295 cp/parser.c:36383
+#: cp/parser.c:36454 cp/parser.c:38718 cp/parser.c:38733 cp/parser.c:38749
+#: cp/parser.c:38765 cp/parser.c:38781 cp/parser.c:38808 cp/parser.c:38821
+#: cp/parser.c:38844 cp/parser.c:38857
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "'%D' blev ikke erklæret i dette virkefelt"
 
-#: c/c-parser.c:10972 cp/parser.c:38837
+#: c/c-parser.c:10972 cp/parser.c:38834
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma once in main file"
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "'#pragma once' i hovedfil"
 
-#: c/c-parser.c:11050 cp/parser.c:38918
+#: c/c-parser.c:11050 cp/parser.c:38915
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr ""
 
-#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38947 cp/parser.c:38980
+#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38944 cp/parser.c:38977
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr ""
 
-#: c/c-parser.c:11111 cp/parser.c:38711
+#: c/c-parser.c:11111 cp/parser.c:38708
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr ""
 
-#: c/c-parser.c:11421 cp/parser.c:31457
+#: c/c-parser.c:11421 cp/parser.c:31454
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %qs clauses"
 msgstr "for mange inddatafiler"
 
-#: c/c-parser.c:11443 cp/parser.c:31994
+#: c/c-parser.c:11443 cp/parser.c:31991
 #, fuzzy, gcc-internal-format
 #| msgid "']' expected, invalid type expression"
 msgid "expected integer expression before ')'"
@@ -40362,60 +40409,60 @@
 msgid "%qD is not a variable"
 msgstr "'%D' er ikke et navnerum"
 
-#: c/c-parser.c:11746 cp/semantics.c:6808
+#: c/c-parser.c:11746 cp/semantics.c:6811
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a pointer-to-object type"
 msgid "%qD is not a pointer variable"
 msgstr "'%T' er ikke af en henvisning til objekt-type"
 
-#: c/c-parser.c:11788 cp/parser.c:32073
+#: c/c-parser.c:11788 cp/parser.c:32070
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between signed and unsigned integer expressions"
 msgid "collapse argument needs positive constant integer expression"
 msgstr "sammenlign mellem signed og unsigned heltalsudtryk"
 
-#: c/c-parser.c:11865 cp/parser.c:32137
+#: c/c-parser.c:11865 cp/parser.c:32134
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<::%>"
 msgid "expected %<none%> or %<present%>"
 msgstr "forventede %<:%> or %<::%>"
 
-#: c/c-parser.c:11867 cp/parser.c:32139
+#: c/c-parser.c:11867 cp/parser.c:32136
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr ""
 
-#: c/c-parser.c:11968 cp/parser.c:32242
+#: c/c-parser.c:11968 cp/parser.c:32239
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "forventede %<class%>, %<typename%>, eller %<template%>"
 
-#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32260
-#: cp/parser.c:36290 cp/parser.c:36378
+#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32257
+#: cp/parser.c:36287 cp/parser.c:36375
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<catch%>"
 msgid "expected %<data%>"
 msgstr "forventede %<catch%>"
 
-#: c/c-parser.c:12035 cp/parser.c:32313
+#: c/c-parser.c:12035 cp/parser.c:32310
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:12042 cp/parser.c:32320
+#: c/c-parser.c:12042 cp/parser.c:32317
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %<if%> clauses"
 msgstr "for mange inddatafiler"
 
-#: c/c-parser.c:12044 cp/parser.c:32322
+#: c/c-parser.c:12044 cp/parser.c:32319
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %<if%> clauses without modifier"
 msgstr "for mange inddatafiler"
 
-#: c/c-parser.c:12050 cp/parser.c:32328
+#: c/c-parser.c:12050 cp/parser.c:32325
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -40438,91 +40485,91 @@
 msgid "%<num_tasks%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:12229 cp/semantics.c:6992
+#: c/c-parser.c:12229 cp/semantics.c:6995
 #, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:12276 cp/semantics.c:7021
+#: c/c-parser.c:12276 cp/semantics.c:7024
 #, fuzzy, gcc-internal-format
 #| msgid "%s rotate count is negative"
 msgid "%<priority%> value must be non-negative"
 msgstr "%s-roteringsantal er negativt"
 
-#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32545 cp/parser.c:32552
+#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32542 cp/parser.c:32549
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<throw%>"
 msgid "expected %<tofrom%>"
 msgstr "forventede %<throw%>"
 
-#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32561 cp/parser.c:32568
+#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32558 cp/parser.c:32565
 #, fuzzy, gcc-internal-format
 msgid "expected %<scalar%>"
 msgstr "uventet operand"
 
-#: c/c-parser.c:12425 cp/semantics.c:6299
+#: c/c-parser.c:12425 cp/semantics.c:6302
 #, fuzzy, gcc-internal-format
 #| msgid "predicate must be an identifier"
 msgid "%qs expression must be integral"
 msgstr "udsagn skal være et kaldenavn"
 
-#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6331
+#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6334
 #, fuzzy, gcc-internal-format
 #| msgid "%s rotate count is negative"
 msgid "%qs value must be positive"
 msgstr "%s-roteringsantal er negativt"
 
-#: c/c-parser.c:12499 cp/parser.c:31853
+#: c/c-parser.c:12499 cp/parser.c:31850
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments"
 msgid "too many %<static%> arguments"
 msgstr "for mange parametre"
 
-#: c/c-parser.c:12533 cp/parser.c:31886
+#: c/c-parser.c:12533 cp/parser.c:31883
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "unexpected argument"
 msgstr "uventet operand"
 
-#: c/c-parser.c:12699 cp/semantics.c:7120
+#: c/c-parser.c:12699 cp/semantics.c:7123
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute argument not an integer constant"
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "parameteren til egenskaben '%s' er ikke en heltalskonstant"
 
-#: c/c-parser.c:12765 cp/parser.c:32626
+#: c/c-parser.c:12765 cp/parser.c:32623
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between signed and unsigned integer expressions"
 msgid "ordered argument needs positive constant integer expression"
 msgstr "sammenlign mellem signed og unsigned heltalsudtryk"
 
-#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37643
+#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37640
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr ""
 
-#: c/c-parser.c:12967 cp/parser.c:32840
+#: c/c-parser.c:12967 cp/parser.c:32837
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr ""
 
-#: c/c-parser.c:13021 cp/parser.c:32856
+#: c/c-parser.c:13021 cp/parser.c:32853
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:13025 cp/parser.c:32859
+#: c/c-parser.c:13025 cp/parser.c:32856
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:13037 cp/semantics.c:6389
+#: c/c-parser.c:13037 cp/semantics.c:6392
 #, fuzzy, gcc-internal-format
 #| msgid "%s rotate count is negative"
 msgid "chunk size value must be positive"
 msgstr "%s-roteringsantal er negativt"
 
-#: c/c-parser.c:13060 cp/parser.c:32879
+#: c/c-parser.c:13060 cp/parser.c:32876
 #, fuzzy, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "ugyldig roteringsinstruktion"
@@ -40532,12 +40579,12 @@
 msgid "%<num_teams%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:13226 cp/semantics.c:6479
+#: c/c-parser.c:13226 cp/semantics.c:6482
 #, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:13271 cp/semantics.c:6589
+#: c/c-parser.c:13271 cp/semantics.c:6592
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr ""
@@ -40557,19 +40604,19 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:13584 cp/parser.c:33374 cp/parser.c:33599
+#: c/c-parser.c:13584 cp/parser.c:33371 cp/parser.c:33596
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%d operand"
 msgid "invalid depend kind"
 msgstr "ugyldig %%d-operand"
 
-#: c/c-parser.c:13669 cp/parser.c:33447
+#: c/c-parser.c:13669 cp/parser.c:33444
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mask"
 msgid "invalid map kind"
 msgstr "ugyldig maske"
 
-#: c/c-parser.c:13767 cp/parser.c:33546
+#: c/c-parser.c:13767 cp/parser.c:33543
 #, fuzzy, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "ugyldig roteringsinstruktion"
@@ -40580,69 +40627,69 @@
 msgid "invalid proc_bind kind"
 msgstr "ugyldig roteringsinstruktion"
 
-#: c/c-parser.c:14059 cp/parser.c:33825
+#: c/c-parser.c:14059 cp/parser.c:33822
 #, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr ""
 
-#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33836 cp/parser.c:34143
+#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33833 cp/parser.c:34140
 #, fuzzy, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%s understøtter ikke %s"
 
-#: c/c-parser.c:14214 cp/parser.c:34010
+#: c/c-parser.c:14214 cp/parser.c:34007
 #, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr ""
 
-#: c/c-parser.c:14334 cp/parser.c:34132
+#: c/c-parser.c:14334 cp/parser.c:34129
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr ""
 
-#: c/c-parser.c:14472 cp/parser.c:36803
+#: c/c-parser.c:14472 cp/parser.c:36800
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14482 cp/parser.c:36813
+#: c/c-parser.c:14482 cp/parser.c:36810
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of \"%s\" shadows a global declaration"
 msgid "array section in %<#pragma acc declare%>"
 msgstr "erklæring af '%s' skygger for en global erklæring"
 
-#: c/c-parser.c:14502 cp/parser.c:36833
+#: c/c-parser.c:14502 cp/parser.c:36830
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr "erklæring af '%s' der er en 'extern'-variabel, i begyndelseserklæring i 'for'-løkke"
 
-#: c/c-parser.c:14513 cp/parser.c:36844
+#: c/c-parser.c:14513 cp/parser.c:36841
 #, fuzzy, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr "skabelonsparameter '%T' er en variabelt ændret type"
 
-#: c/c-parser.c:14520 cp/parser.c:36851
+#: c/c-parser.c:14520 cp/parser.c:36848
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "erklæring af '%s' der er en 'extern'-variabel, i begyndelseserklæring i 'for'-løkke"
 
-#: c/c-parser.c:14528 cp/parser.c:36859
+#: c/c-parser.c:14528 cp/parser.c:36856
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14540 cp/parser.c:36871
+#: c/c-parser.c:14540 cp/parser.c:36868
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14632 cp/parser.c:36957
+#: c/c-parser.c:14632 cp/parser.c:36954
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "forventede %<class%>, %<typename%>, eller %<template%>"
 
-#: c/c-parser.c:14648 cp/parser.c:36974
+#: c/c-parser.c:14648 cp/parser.c:36971
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma once in main file"
 msgid "%<#pragma acc %s data%> has no data movement clause"
@@ -40659,7 +40706,7 @@
 msgid "expected function name"
 msgstr "forventet funktion"
 
-#: c/c-parser.c:14893 cp/parser.c:38064
+#: c/c-parser.c:14893 cp/parser.c:38061
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a member template function"
 msgid "%qD does not refer to a function"
@@ -40670,47 +40717,47 @@
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr "en global registervariabel følger en funktionsdefinition"
 
-#: c/c-parser.c:14953 cp/parser.c:38118 cp/parser.c:38160
+#: c/c-parser.c:14953 cp/parser.c:38115 cp/parser.c:38157
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr "en global registervariabel følger en funktionsdefinition"
 
-#: c/c-parser.c:14970 cp/parser.c:38174
+#: c/c-parser.c:14970 cp/parser.c:38171
 #, fuzzy, gcc-internal-format
 #| msgid "braced-group within expression allowed only inside a function"
 msgid "%<#pragma acc routine%> already applied to %qD"
 msgstr "sætningsblokke i udtryk er kun tilladt inde i en funktion"
 
-#: c/c-parser.c:14979 cp/parser.c:38183
+#: c/c-parser.c:14979 cp/parser.c:38180
 #, fuzzy, gcc-internal-format
 #| msgid "braced-group within expression allowed only inside a function"
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr "sætningsblokke i udtryk er kun tilladt inde i en funktion"
 
-#: c/c-parser.c:14980 cp/parser.c:38184
+#: c/c-parser.c:14980 cp/parser.c:38181
 #, fuzzy, gcc-internal-format
 #| msgid "braced-group within expression allowed only inside a function"
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "sætningsblokke i udtryk er kun tilladt inde i en funktion"
 
-#: c/c-parser.c:15023 cp/parser.c:37152
+#: c/c-parser.c:15023 cp/parser.c:37149
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
 
-#: c/c-parser.c:15435 cp/parser.c:34511 cp/parser.c:34537
+#: c/c-parser.c:15435 cp/parser.c:34508 cp/parser.c:34534
 #, fuzzy, gcc-internal-format
 #| msgid "invalid #pragma %s"
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "ugyldig #pragma %s"
 
-#: c/c-parser.c:15439 cp/parser.c:34568 cp/parser.c:34584
+#: c/c-parser.c:15439 cp/parser.c:34565 cp/parser.c:34581
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand for 'p' modifier"
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "ugyldig operand til 'p'-ændring"
 
-#: c/c-parser.c:15488 cp/semantics.c:8401 cp/semantics.c:8411
+#: c/c-parser.c:15488 cp/semantics.c:8404 cp/semantics.c:8414
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
@@ -40720,23 +40767,23 @@
 msgid "expected %<(%> or end of line"
 msgstr ""
 
-#: c/c-parser.c:15619 cp/parser.c:35103
+#: c/c-parser.c:15619 cp/parser.c:35100
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:15630 cp/parser.c:35114
+#: c/c-parser.c:15630 cp/parser.c:35111
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:15648 cp/parser.c:35141
+#: c/c-parser.c:15648 cp/parser.c:35138
 #, fuzzy, gcc-internal-format
 #| msgid "')' or term expected"
 msgid "for statement expected"
 msgstr "')' eller term forventet"
 
-#: c/c-parser.c:15718 cp/semantics.c:8066 cp/semantics.c:8153
+#: c/c-parser.c:15718 cp/semantics.c:8069 cp/semantics.c:8156
 #, fuzzy, gcc-internal-format
 #| msgid "repeated declaration of automaton `%s'"
 msgid "expected iteration declaration or initialization"
@@ -40747,73 +40794,73 @@
 msgid "not enough perfectly nested loops"
 msgstr ""
 
-#: c/c-parser.c:15862 cp/parser.c:35364
+#: c/c-parser.c:15862 cp/parser.c:35361
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.c:15909 cp/parser.c:35184 cp/parser.c:35226 cp/pt.c:16385
+#: c/c-parser.c:15909 cp/parser.c:35181 cp/parser.c:35223 cp/pt.c:16407
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr ""
 
-#: c/c-parser.c:16000 cp/parser.c:35437
+#: c/c-parser.c:16000 cp/parser.c:35434
 #, fuzzy, gcc-internal-format
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "typedef-navn kan ikke klassemodificeres"
 
-#: c/c-parser.c:16166 cp/parser.c:35600
+#: c/c-parser.c:16166 cp/parser.c:35597
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:16374 cp/parser.c:35799
+#: c/c-parser.c:16374 cp/parser.c:35796
 #, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr ""
 
-#: c/c-parser.c:16573 cp/parser.c:35995
+#: c/c-parser.c:16573 cp/parser.c:35992
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected %<point%>"
 msgstr "uventet operand"
 
-#: c/c-parser.c:16793 cp/parser.c:36232
+#: c/c-parser.c:16793 cp/parser.c:36229
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16806 cp/parser.c:36245
+#: c/c-parser.c:16806 cp/parser.c:36242
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16853 cp/parser.c:36470
+#: c/c-parser.c:16853 cp/parser.c:36467
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:16925 cp/parser.c:36325
+#: c/c-parser.c:16925 cp/parser.c:36322
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16937 cp/parser.c:36337
+#: c/c-parser.c:16937 cp/parser.c:36334
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17011 cp/parser.c:36414
+#: c/c-parser.c:17011 cp/parser.c:36411
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17024 cp/parser.c:36427
+#: c/c-parser.c:17024 cp/parser.c:36424
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17238 cp/parser.c:36680
+#: c/c-parser.c:17238 cp/parser.c:36677
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -40833,32 +40880,32 @@
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17395 cp/parser.c:37273
+#: c/c-parser.c:17395 cp/parser.c:37270
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17474 cp/parser.c:37343
+#: c/c-parser.c:17474 cp/parser.c:37340
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> with clauses in between %<#pragma omp declare target%> without clauses and %<#pragma omp end declare target%>"
 msgstr ""
 
-#: c/c-parser.c:17493 cp/parser.c:37362
+#: c/c-parser.c:17493 cp/parser.c:37359
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17534 cp/parser.c:37409
+#: c/c-parser.c:17534 cp/parser.c:37406
 #, fuzzy, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "uventet operand"
 
-#: c/c-parser.c:17541 cp/parser.c:37416
+#: c/c-parser.c:17541 cp/parser.c:37413
 #, fuzzy, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "uventet operand"
 
-#: c/c-parser.c:17547 cp/parser.c:37423
+#: c/c-parser.c:17547 cp/parser.c:37420
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr ""
@@ -40914,47 +40961,47 @@
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:17947 cp/parser.c:37868
+#: c/c-parser.c:17947 cp/parser.c:37865
 #, gcc-internal-format
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr ""
 
-#: c/c-parser.c:18162 cp/semantics.c:7531
+#: c/c-parser.c:18162 cp/semantics.c:7534
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr ""
 
-#: c/c-parser.c:18164 cp/semantics.c:7533
+#: c/c-parser.c:18164 cp/semantics.c:7536
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr ""
 
-#: c/c-parser.c:18168 cp/semantics.c:7535
+#: c/c-parser.c:18168 cp/semantics.c:7538
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "parameteren er af en ufuldstændig type"
 
-#: c/c-parser.c:18368 cp/parser.c:38565
+#: c/c-parser.c:18368 cp/parser.c:38562
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:18374 cp/parser.c:38571
+#: c/c-parser.c:18374 cp/parser.c:38568
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
 
-#: c/c-parser.c:18383 cp/parser.c:38580
+#: c/c-parser.c:18383 cp/parser.c:38577
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.c:18385 cp/parser.c:38583
+#: c/c-parser.c:18385 cp/parser.c:38580
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.c:18391 cp/parser.c:38589
+#: c/c-parser.c:18391 cp/parser.c:38586
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
@@ -40971,7 +41018,7 @@
 msgid "%qD has an incomplete type %qT"
 msgstr "'%s' er af en ufuldstændig type"
 
-#: c/c-typeck.c:237 c/c-typeck.c:9994 c/c-typeck.c:10036 cp/call.c:4147
+#: c/c-typeck.c:237 c/c-typeck.c:9999 c/c-typeck.c:10041 cp/call.c:4147
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "ugyldig brug af void-udtryk"
@@ -41050,13 +41097,13 @@
 msgid "converting an array compound literal to a pointer is ill-formed in C++"
 msgstr ""
 
-#: c/c-typeck.c:2417 c/c-typeck.c:8641
+#: c/c-typeck.c:2417 c/c-typeck.c:8646
 #, fuzzy, gcc-internal-format
 #| msgid "'%D' has no member named '%E'"
 msgid "%qT has no member named %qE; did you mean %qE?"
 msgstr "'%D' har intet medlem ved navn '%E'"
 
-#: c/c-typeck.c:2421 c/c-typeck.c:8645
+#: c/c-typeck.c:2421 c/c-typeck.c:8650
 #, fuzzy, gcc-internal-format
 #| msgid "'%D' has no member named '%E'"
 msgid "%qT has no member named %qE"
@@ -41283,64 +41330,64 @@
 msgid "pointer to a function used in subtraction"
 msgstr "henvisning til en funktion benyttet i subtraktion"
 
-#: c/c-typeck.c:3847
+#: c/c-typeck.c:3852
 #, gcc-internal-format
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "beregninger udført på en henvisning til en ufuldstændig type"
 
-#: c/c-typeck.c:3852 cp/typeck.c:5562
+#: c/c-typeck.c:3857 cp/typeck.c:5562
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr "beregninger udført på en henvisning til en ufuldstændig type"
 
-#: c/c-typeck.c:4283
+#: c/c-typeck.c:4288
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected address expression"
 msgid "%<~%> on a boolean expression"
 msgstr "uventet adresseudtryk"
 
-#: c/c-typeck.c:4287
+#: c/c-typeck.c:4292
 #, gcc-internal-format
 msgid "did you mean to use logical not?"
 msgstr ""
 
-#: c/c-typeck.c:4296
+#: c/c-typeck.c:4301
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support `~' for complex conjugation"
 msgid "ISO C does not support %<~%> for complex conjugation"
 msgstr "ISO C understøtter ikke '~' til compleks-konjugering"
 
-#: c/c-typeck.c:4335
+#: c/c-typeck.c:4340
 #, gcc-internal-format
 msgid "wrong type argument to unary exclamation mark"
 msgstr "forkert parametertype til unært udråbstegn"
 
-#: c/c-typeck.c:4393
+#: c/c-typeck.c:4398
 #, fuzzy, gcc-internal-format
 #| msgid "enumeration value `%s' not handled in switch"
 msgid "increment of enumeration value is invalid in C++"
 msgstr "enum-værdien '%s' håndteres ikke i switch-sætning"
 
-#: c/c-typeck.c:4396
+#: c/c-typeck.c:4401
 #, fuzzy, gcc-internal-format
 #| msgid "enumeration value `%s' not handled in switch"
 msgid "decrement of enumeration value is invalid in C++"
 msgstr "enum-værdien '%s' håndteres ikke i switch-sætning"
 
-#: c/c-typeck.c:4403
+#: c/c-typeck.c:4408
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected address expression"
 msgid "increment of a boolean expression"
 msgstr "uventet adresseudtryk"
 
-#: c/c-typeck.c:4406
+#: c/c-typeck.c:4411
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected address expression"
 msgid "decrement of a boolean expression"
 msgstr "uventet adresseudtryk"
 
-#: c/c-typeck.c:4422
+#: c/c-typeck.c:4427
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support `++' and `--' on complex types"
 msgid "ISO C does not support %<++%> and %<--%> on complex types"
@@ -41348,459 +41395,459 @@
 
 # man kan ikke stikke en forøgelse (++) en type som parameter, 'type
 # argument' skal opfattes på en anden måde
-#: c/c-typeck.c:4447 c/c-typeck.c:4481
+#: c/c-typeck.c:4452 c/c-typeck.c:4486
 #, gcc-internal-format
 msgid "wrong type argument to increment"
 msgstr "forkert parametertype til forøgelse"
 
-#: c/c-typeck.c:4449 c/c-typeck.c:4484
+#: c/c-typeck.c:4454 c/c-typeck.c:4489
 #, gcc-internal-format
 msgid "wrong type argument to decrement"
 msgstr "forkert parametertype til formindskelse"
 
-#: c/c-typeck.c:4469
+#: c/c-typeck.c:4474
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "increment of pointer to an incomplete type %qT"
 msgstr "beregninger udført på en henvisning til en ufuldstændig type"
 
-#: c/c-typeck.c:4473
+#: c/c-typeck.c:4478
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "decrement of pointer to an incomplete type %qT"
 msgstr "beregninger udført på en henvisning til en ufuldstændig type"
 
-#: c/c-typeck.c:4577
+#: c/c-typeck.c:4582
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of expression of type %<void%>"
 msgstr "tager adressen på midlertidig variabel"
 
-#: c/c-typeck.c:4636
+#: c/c-typeck.c:4641
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take address of bit-field `%s'"
 msgid "cannot take address of bit-field %qD"
 msgstr "kan ikke finde adressen af bitfeltet '%s'"
 
-#: c/c-typeck.c:4649
+#: c/c-typeck.c:4654
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take the address of an unaligned member"
 msgid "cannot take address of scalar with reverse storage order"
 msgstr "kan ikke tage adressen af et ikke-justeret medlem"
 
-#: c/c-typeck.c:4657
+#: c/c-typeck.c:4662
 #, fuzzy, gcc-internal-format
 #| msgid "address of register variable `%s' requested"
 msgid "address of array with reverse scalar storage order requested"
 msgstr "forespørgsel efter adressen af registervariablen '%s'"
 
-#: c/c-typeck.c:4838
+#: c/c-typeck.c:4843
 #, fuzzy, gcc-internal-format
 #| msgid "global register variable `%s' used in nested function"
 msgid "global register variable %qD used in nested function"
 msgstr "global registervariabel '%s' benyttet i indlejret funktion"
 
-#: c/c-typeck.c:4841
+#: c/c-typeck.c:4846
 #, fuzzy, gcc-internal-format
 #| msgid "register variable `%s' used in nested function"
 msgid "register variable %qD used in nested function"
 msgstr "registervariabel '%s' benyttet i indlejret funktion"
 
-#: c/c-typeck.c:4846
+#: c/c-typeck.c:4851
 #, fuzzy, gcc-internal-format
 #| msgid "address of global register variable `%s' requested"
 msgid "address of global register variable %qD requested"
 msgstr "forespørgsel efter adressen af den globale registervariabel '%s'"
 
-#: c/c-typeck.c:4848
+#: c/c-typeck.c:4853
 #, fuzzy, gcc-internal-format
 #| msgid "address of register variable `%s' requested"
 msgid "address of register variable %qD requested"
 msgstr "forespørgsel efter adressen af registervariablen '%s'"
 
-#: c/c-typeck.c:4951
+#: c/c-typeck.c:4956
 #, fuzzy, gcc-internal-format
 #| msgid "type mismatch in conditional expression"
 msgid "non-lvalue array in conditional expression"
 msgstr "typerne i betingelsesudtrykket passer ikke sammen"
 
-#: c/c-typeck.c:5033
+#: c/c-typeck.c:5038
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other result of conditional"
 msgstr ""
 
-#: c/c-typeck.c:5092 c/c-typeck.c:5098
+#: c/c-typeck.c:5097 c/c-typeck.c:5103
 #, gcc-internal-format
 msgid "operand of ?: changes signedness from %qT to %qT due to unsignedness of other operand"
 msgstr ""
 
-#: c/c-typeck.c:5115
+#: c/c-typeck.c:5120
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr with only one void side"
 msgstr "ISO C forbyder betingede udtryk med kun én tom side"
 
-#: c/c-typeck.c:5132
+#: c/c-typeck.c:5137
 #, fuzzy, gcc-internal-format
 #| msgid "pointer type mismatch in conditional expression"
 msgid "pointers to disjoint address spaces used in conditional expression"
 msgstr "henvisningstyperne i betingelsesudtrykket passer ikke sammen"
 
-#: c/c-typeck.c:5143 c/c-typeck.c:5160
+#: c/c-typeck.c:5148 c/c-typeck.c:5165
 #, fuzzy, gcc-internal-format
 #| msgid "pointer type mismatch in conditional expression"
 msgid "pointer to array loses qualifier in conditional expression"
 msgstr "henvisningstyperne i betingelsesudtrykket passer ikke sammen"
 
-#: c/c-typeck.c:5148 c/c-typeck.c:5165
+#: c/c-typeck.c:5153 c/c-typeck.c:5170
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids conditional expr between `void *' and function pointer"
 msgid "ISO C forbids conditional expr between %<void *%> and function pointer"
 msgstr "ISO C++ forbyder betinget udtryk mellem 'void *' og funktionshenvisning"
 
-#: c/c-typeck.c:5178
+#: c/c-typeck.c:5183
 #, gcc-internal-format
 msgid "pointer type mismatch in conditional expression"
 msgstr "henvisningstyperne i betingelsesudtrykket passer ikke sammen"
 
-#: c/c-typeck.c:5187 c/c-typeck.c:5198
+#: c/c-typeck.c:5192 c/c-typeck.c:5203
 #, gcc-internal-format
 msgid "pointer/integer type mismatch in conditional expression"
 msgstr "henvisnings- og heltalstype i betingelsesudtrykket passer ikke sammen"
 
-#: c/c-typeck.c:5336
+#: c/c-typeck.c:5341
 #, gcc-internal-format
 msgid "left-hand operand of comma expression has no effect"
 msgstr "venstreoperanden til kommaudtrykket har ingen virkning"
 
-#: c/c-typeck.c:5354 c/c-typeck.c:10636
+#: c/c-typeck.c:5359 c/c-typeck.c:10641
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "right-hand operand of comma expression has no effect"
 msgstr "venstreoperanden til kommaudtrykket har ingen virkning"
 
-#: c/c-typeck.c:5423
+#: c/c-typeck.c:5428
 #, fuzzy
 #| msgid "cast adds new qualifiers to function type"
 msgid "cast adds %q#v qualifier to function type"
 msgstr "typeomtvingning tilføjer modifikationer til en funktionstype"
 
-#: c/c-typeck.c:5429
+#: c/c-typeck.c:5434
 #, fuzzy
 #| msgid "cast discards qualifiers from pointer target type"
 msgid "cast discards %qv qualifier from pointer target type"
 msgstr "typeomtvingelse kasserer modifikationer på henvisningsmålets type"
 
-#: c/c-typeck.c:5464
+#: c/c-typeck.c:5469
 #, gcc-internal-format
 msgid "to be safe all intermediate pointers in cast from %qT to %qT must be %<const%> qualified"
 msgstr ""
 
-#: c/c-typeck.c:5554
+#: c/c-typeck.c:5559
 #, gcc-internal-format
 msgid "cast specifies array type"
 msgstr "typetildelingen angiver en tabeltype"
 
-#: c/c-typeck.c:5560
+#: c/c-typeck.c:5565
 #, gcc-internal-format
 msgid "cast specifies function type"
 msgstr "typetildelingen angiver en funktionstype"
 
-#: c/c-typeck.c:5575
+#: c/c-typeck.c:5580
 #, gcc-internal-format
 msgid "ISO C forbids casting nonscalar to the same type"
 msgstr "ISO C forbyder omtvingelse af ikke-skalar til den samme type"
 
-#: c/c-typeck.c:5595
+#: c/c-typeck.c:5600
 #, gcc-internal-format
 msgid "ISO C forbids casts to union type"
 msgstr "ISO C forbyder omtvingelse til uniontype"
 
-#: c/c-typeck.c:5605
+#: c/c-typeck.c:5610
 #, gcc-internal-format
 msgid "cast to union type from type not present in union"
 msgstr "typetildeling til en uniontype fra en type der ikke findes i union'en"
 
-#: c/c-typeck.c:5640
+#: c/c-typeck.c:5645
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint generic address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5645
+#: c/c-typeck.c:5650
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to generic address space pointer from disjoint %s address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5650
+#: c/c-typeck.c:5655
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint %s address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5670
+#: c/c-typeck.c:5675
 #, gcc-internal-format
 msgid "cast increases required alignment of target type"
 msgstr "typeomtvingelse forøger den påkrævne justering af måltypen"
 
-#: c/c-typeck.c:5681
+#: c/c-typeck.c:5686
 #, gcc-internal-format
 msgid "cast from pointer to integer of different size"
 msgstr "typeomtvingelse fra henvisning til heltal af en anden størrelse"
 
-#: c/c-typeck.c:5686
+#: c/c-typeck.c:5691
 #, gcc-internal-format
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr ""
 
-#: c/c-typeck.c:5695 cp/typeck.c:7811
+#: c/c-typeck.c:5700 cp/typeck.c:7811
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "typeomtvingelse fra heltal til henvisning af en anden størrelse"
 
-#: c/c-typeck.c:5709
+#: c/c-typeck.c:5714
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids conversion of function pointer to object pointer type"
 msgstr "ISO C forbyder sammenligning af 'void *' med funktionshenvisning"
 
-#: c/c-typeck.c:5718
+#: c/c-typeck.c:5723
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids conversion of object pointer to function pointer type"
 msgstr "ISO C forbyder sammenligning af 'void *' med funktionshenvisning"
 
-#: c/c-typeck.c:5728
+#: c/c-typeck.c:5733
 #, fuzzy, gcc-internal-format
 #| msgid "can%'t convert from incomplete type %qT to %qT"
 msgid "cast between incompatible function types from %qT to %qT"
 msgstr "kan ikke konvertere fra ufuldstændig type %qT til %qT"
 
-#: c/c-typeck.c:5815
+#: c/c-typeck.c:5820
 #, gcc-internal-format
 msgid "defining a type in a cast is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:5856
+#: c/c-typeck.c:5861
 #, fuzzy, gcc-internal-format
 #| msgid "assignment suppression"
 msgid "assignment to expression with array type"
 msgstr "tildelingsundertrykkelse"
 
-#: c/c-typeck.c:5982
+#: c/c-typeck.c:5987
 #, gcc-internal-format
 msgid "enum conversion in assignment is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:6180 c/c-typeck.c:6202 c/c-typeck.c:6226
+#: c/c-typeck.c:6185 c/c-typeck.c:6207 c/c-typeck.c:6231
 #, fuzzy, gcc-internal-format
 #| msgid "(near initialization for `%s')"
 msgid "(near initialization for %qs)"
 msgstr "(i nærheden af klargøringen af '%s')"
 
-#: c/c-typeck.c:6241
+#: c/c-typeck.c:6246
 #, fuzzy, gcc-internal-format
 #| msgid "char-array initialized from wide string"
 msgid "array initialized from parenthesized string constant"
 msgstr "char-tabel får tildelt startværdi fra en bred streng"
 
-#: c/c-typeck.c:6284 c/c-typeck.c:6476 c/c-typeck.c:6908
+#: c/c-typeck.c:6289 c/c-typeck.c:6481 c/c-typeck.c:6913
 #, gcc-internal-format
 msgid "expected %qT but argument is of type %qT"
 msgstr ""
 
-#: c/c-typeck.c:6471
+#: c/c-typeck.c:6476
 #, gcc-internal-format
 msgid "enum conversion when passing argument %d of %qE is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:6480
+#: c/c-typeck.c:6485
 #, fuzzy, gcc-internal-format
 msgid "enum conversion from %qT to %qT in assignment is invalid in C++"
 msgstr "konvertering fra NaN til unsigned int"
 
-#: c/c-typeck.c:6484
+#: c/c-typeck.c:6489
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert `%T' to `%T' in %s"
 msgid "enum conversion from %qT to %qT in initialization is invalid in C++"
 msgstr "kan ikke konvertere '%T' til '%T' i %s"
 
-#: c/c-typeck.c:6489
+#: c/c-typeck.c:6494
 #, fuzzy, gcc-internal-format
 msgid "enum conversion from %qT to %qT in return is invalid in C++"
 msgstr "konvertering fra NaN til unsigned int"
 
-#: c/c-typeck.c:6523
+#: c/c-typeck.c:6528
 #, gcc-internal-format
 msgid "cannot pass rvalue to reference parameter"
 msgstr "kan ikke videregive højreværdi til referenceparameter"
 
-#: c/c-typeck.c:6656 c/c-typeck.c:6942
+#: c/c-typeck.c:6661 c/c-typeck.c:6947
 #, fuzzy
 #| msgid "%s makes qualified function pointer from unqualified"
 msgid "passing argument %d of %qE makes %q#v qualified function pointer from unqualified"
 msgstr "%s opretter en funktionshenvisning med modifikationer fra én uden"
 
-#: c/c-typeck.c:6659 c/c-typeck.c:6945
+#: c/c-typeck.c:6664 c/c-typeck.c:6950
 #, fuzzy
 #| msgid "%s makes qualified function pointer from unqualified"
 msgid "assignment makes %q#v qualified function pointer from unqualified"
 msgstr "%s opretter en funktionshenvisning med modifikationer fra én uden"
 
-#: c/c-typeck.c:6662 c/c-typeck.c:6947
+#: c/c-typeck.c:6667 c/c-typeck.c:6952
 #, fuzzy
 #| msgid "%s makes qualified function pointer from unqualified"
 msgid "initialization makes %q#v qualified function pointer from unqualified"
 msgstr "%s opretter en funktionshenvisning med modifikationer fra én uden"
 
-#: c/c-typeck.c:6665 c/c-typeck.c:6949
+#: c/c-typeck.c:6670 c/c-typeck.c:6954
 #, fuzzy
 #| msgid "%s makes qualified function pointer from unqualified"
 msgid "return makes %q#v qualified function pointer from unqualified"
 msgstr "%s opretter en funktionshenvisning med modifikationer fra én uden"
 
-#: c/c-typeck.c:6673 c/c-typeck.c:6840 c/c-typeck.c:6883
+#: c/c-typeck.c:6678 c/c-typeck.c:6845 c/c-typeck.c:6888
 #, fuzzy
 #| msgid "cast from `%T' to `%T' discards qualifiers from pointer target type"
 msgid "passing argument %d of %qE discards %qv qualifier from pointer target type"
 msgstr "typeomtvingning fra '%T' til '%T' kasserer modifikationer på henvisningsmålets type"
 
-#: c/c-typeck.c:6675 c/c-typeck.c:6842 c/c-typeck.c:6885
+#: c/c-typeck.c:6680 c/c-typeck.c:6847 c/c-typeck.c:6890
 #, fuzzy
 #| msgid "cast discards qualifiers from pointer target type"
 msgid "assignment discards %qv qualifier from pointer target type"
 msgstr "typeomtvingelse kasserer modifikationer på henvisningsmålets type"
 
-#: c/c-typeck.c:6677 c/c-typeck.c:6844 c/c-typeck.c:6887
+#: c/c-typeck.c:6682 c/c-typeck.c:6849 c/c-typeck.c:6892
 #, fuzzy
 #| msgid "cast discards qualifiers from pointer target type"
 msgid "initialization discards %qv qualifier from pointer target type"
 msgstr "typeomtvingelse kasserer modifikationer på henvisningsmålets type"
 
-#: c/c-typeck.c:6679 c/c-typeck.c:6846 c/c-typeck.c:6889
+#: c/c-typeck.c:6684 c/c-typeck.c:6851 c/c-typeck.c:6894
 #, fuzzy
 #| msgid "cast discards qualifiers from pointer target type"
 msgid "return discards %qv qualifier from pointer target type"
 msgstr "typeomtvingelse kasserer modifikationer på henvisningsmålets type"
 
-#: c/c-typeck.c:6688
+#: c/c-typeck.c:6693
 #, gcc-internal-format
 msgid "ISO C prohibits argument conversion to union type"
 msgstr "ISO C forbyder parameterkonvertering til uniontype"
 
-#: c/c-typeck.c:6750
+#: c/c-typeck.c:6755
 #, fuzzy, gcc-internal-format
 msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgstr "konvertering fra NaN til unsigned int"
 
-#: c/c-typeck.c:6762
+#: c/c-typeck.c:6767
 #, fuzzy, gcc-internal-format
 #| msgid "passing arg %d of pointer to function"
 msgid "passing argument %d of %qE from pointer to non-enclosed address space"
 msgstr "videregiver den %d. parameter af henvisning til funktion"
 
-#: c/c-typeck.c:6766
+#: c/c-typeck.c:6771
 #, fuzzy, gcc-internal-format
 #| msgid "cast from pointer to integer of different size"
 msgid "assignment from pointer to non-enclosed address space"
 msgstr "typeomtvingelse fra henvisning til heltal af en anden størrelse"
 
-#: c/c-typeck.c:6770
+#: c/c-typeck.c:6775
 #, gcc-internal-format
 msgid "initialization from pointer to non-enclosed address space"
 msgstr ""
 
-#: c/c-typeck.c:6774
+#: c/c-typeck.c:6779
 #, gcc-internal-format
 msgid "return from pointer to non-enclosed address space"
 msgstr ""
 
-#: c/c-typeck.c:6792
+#: c/c-typeck.c:6797
 #, fuzzy, gcc-internal-format
 #| msgid "function might be possible candidate for `%s' format attribute"
 msgid "argument %d of %qE might be a candidate for a format attribute"
 msgstr "funktion er en mulig kandidat til '%s'-formateringsegenskab"
 
-#: c/c-typeck.c:6798
+#: c/c-typeck.c:6803
 #, fuzzy, gcc-internal-format
 #| msgid "Warn about functions which might be candidates for format attributes"
 msgid "assignment left-hand side might be a candidate for a format attribute"
 msgstr "Advar om funktioner som kan være kandidater til formateringsegenskaber"
 
-#: c/c-typeck.c:6803
+#: c/c-typeck.c:6808
 #, fuzzy, gcc-internal-format
 #| msgid "function might be possible candidate for `%s' format attribute"
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "funktion er en mulig kandidat til '%s'-formateringsegenskab"
 
-#: c/c-typeck.c:6808 cp/typeck.c:8891
+#: c/c-typeck.c:6813 cp/typeck.c:8891
 #, fuzzy, gcc-internal-format
 #| msgid "function might be possible candidate for `%s' format attribute"
 msgid "return type might be a candidate for a format attribute"
 msgstr "funktion er en mulig kandidat til '%s'-formateringsegenskab"
 
-#: c/c-typeck.c:6857
+#: c/c-typeck.c:6862
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids %s between function pointer and `void *'"
 msgid "ISO C forbids passing argument %d of %qE between function pointer and %<void *%>"
 msgstr "ISO C forbyder %s mellem funktionshenvisning og 'void *'"
 
-#: c/c-typeck.c:6860
+#: c/c-typeck.c:6865
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids %s between function pointer and `void *'"
 msgid "ISO C forbids assignment between function pointer and %<void *%>"
 msgstr "ISO C forbyder %s mellem funktionshenvisning og 'void *'"
 
-#: c/c-typeck.c:6862
+#: c/c-typeck.c:6867
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids %s between function pointer and `void *'"
 msgid "ISO C forbids initialization between function pointer and %<void *%>"
 msgstr "ISO C forbyder %s mellem funktionshenvisning og 'void *'"
 
-#: c/c-typeck.c:6864
+#: c/c-typeck.c:6869
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids %s between function pointer and `void *'"
 msgid "ISO C forbids return between function pointer and %<void *%>"
 msgstr "ISO C forbyder %s mellem funktionshenvisning og 'void *'"
 
-#: c/c-typeck.c:6904
+#: c/c-typeck.c:6909
 #, fuzzy, gcc-internal-format
 #| msgid "pointer targets in %s differ in signedness"
 msgid "pointer targets in passing argument %d of %qE differ in signedness"
 msgstr "fortegnene i henvisningsmål i %s er forskellige"
 
-#: c/c-typeck.c:6913
+#: c/c-typeck.c:6918
 #, fuzzy, gcc-internal-format
 #| msgid "pointer targets in %s differ in signedness"
 msgid "pointer targets in assignment from %qT to %qT differ in signedness"
 msgstr "fortegnene i henvisningsmål i %s er forskellige"
 
-#: c/c-typeck.c:6918
+#: c/c-typeck.c:6923
 #, fuzzy, gcc-internal-format
 #| msgid "pointer targets in %s differ in signedness"
 msgid "pointer targets in initialization of %qT from %qT differ in signedness"
 msgstr "fortegnene i henvisningsmål i %s er forskellige"
 
-#: c/c-typeck.c:6923
+#: c/c-typeck.c:6928
 #, fuzzy, gcc-internal-format
 #| msgid "pointer targets in %s differ in signedness"
 msgid "pointer targets in returning %qT from a function with return type %qT differ in signedness"
 msgstr "fortegnene i henvisningsmål i %s er forskellige"
 
-#: c/c-typeck.c:6961
+#: c/c-typeck.c:6966
 #, fuzzy, gcc-internal-format
 #| msgid "%s from incompatible pointer type"
 msgid "passing argument %d of %qE from incompatible pointer type"
 msgstr "%s fra en henvisningstype der ikke er forenelig med målets"
 
-#: c/c-typeck.c:6967
+#: c/c-typeck.c:6972
 #, fuzzy, gcc-internal-format
 #| msgid "%s from incompatible pointer type"
 msgid "assignment to %qT from incompatible pointer type %qT"
 msgstr "%s fra en henvisningstype der ikke er forenelig med målets"
 
-#: c/c-typeck.c:6972
+#: c/c-typeck.c:6977
 #, fuzzy, gcc-internal-format
 #| msgid "%s from incompatible pointer type"
 msgid "initialization of %qT from incompatible pointer type %qT"
 msgstr "%s fra en henvisningstype der ikke er forenelig med målets"
 
-#: c/c-typeck.c:6977
+#: c/c-typeck.c:6982
 #, fuzzy, gcc-internal-format
 #| msgid "return-statement with a value, in function declared with a void return type"
 msgid "returning %qT from a function with incompatible return type %qT"
@@ -41808,78 +41855,78 @@
 
 #. ??? This should not be an error when inlining calls to
 #. unprototyped functions.
-#: c/c-typeck.c:6991 c/c-typeck.c:7514 cp/typeck.c:2063
+#: c/c-typeck.c:6996 c/c-typeck.c:7519 cp/typeck.c:2063
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "ugyldig brug af en tabel der ikke kan optræde som en venstreværdi"
 
-#: c/c-typeck.c:7004
+#: c/c-typeck.c:7009
 #, fuzzy, gcc-internal-format
 #| msgid "%s makes pointer from integer without a cast"
 msgid "passing argument %d of %qE makes pointer from integer without a cast"
 msgstr "%s opretter en henvisningsvariabel ud fra et heltal uden en typeomtvingning"
 
-#: c/c-typeck.c:7010
+#: c/c-typeck.c:7015
 #, fuzzy, gcc-internal-format
 #| msgid "%s makes pointer from integer without a cast"
 msgid "assignment to %qT from %qT makes pointer from integer without a cast"
 msgstr "%s opretter en henvisningsvariabel ud fra et heltal uden en typeomtvingning"
 
-#: c/c-typeck.c:7015
+#: c/c-typeck.c:7020
 #, fuzzy, gcc-internal-format
 #| msgid "%s makes pointer from integer without a cast"
 msgid "initialization of %qT from %qT makes pointer from integer without a cast"
 msgstr "%s opretter en henvisningsvariabel ud fra et heltal uden en typeomtvingning"
 
-#: c/c-typeck.c:7019
+#: c/c-typeck.c:7024
 #, fuzzy, gcc-internal-format
 #| msgid "%s makes pointer from integer without a cast"
 msgid "returning %qT from a function with return type %qT makes pointer from integer without a cast"
 msgstr "%s opretter en henvisningsvariabel ud fra et heltal uden en typeomtvingning"
 
-#: c/c-typeck.c:7035
+#: c/c-typeck.c:7040
 #, fuzzy, gcc-internal-format
 #| msgid "%s makes integer from pointer without a cast"
 msgid "passing argument %d of %qE makes integer from pointer without a cast"
 msgstr "%s opretter et heltal ud fra en henvisningsvariabel uden en typeomtvingning"
 
-#: c/c-typeck.c:7041
+#: c/c-typeck.c:7046
 #, fuzzy, gcc-internal-format
 #| msgid "%s makes integer from pointer without a cast"
 msgid "assignment to %qT from %qT makes integer from pointer without a cast"
 msgstr "%s opretter et heltal ud fra en henvisningsvariabel uden en typeomtvingning"
 
-#: c/c-typeck.c:7046
+#: c/c-typeck.c:7051
 #, fuzzy, gcc-internal-format
 #| msgid "%s makes integer from pointer without a cast"
 msgid "initialization of %qT from %qT makes integer from pointer without a cast"
 msgstr "%s opretter et heltal ud fra en henvisningsvariabel uden en typeomtvingning"
 
-#: c/c-typeck.c:7050
+#: c/c-typeck.c:7055
 #, fuzzy, gcc-internal-format
 #| msgid "%s makes integer from pointer without a cast"
 msgid "returning %qT from a function with return type %qT makes integer from pointer without a cast"
 msgstr "%s opretter et heltal ud fra en henvisningsvariabel uden en typeomtvingning"
 
-#: c/c-typeck.c:7073
+#: c/c-typeck.c:7078
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible type for argument %d of `%s'"
 msgid "incompatible type for argument %d of %qE"
 msgstr "typen af den %d. parameter i '%s' passer ikke"
 
-#: c/c-typeck.c:7078
+#: c/c-typeck.c:7083
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible types in assignment of `%T' to `%T'"
 msgid "incompatible types when assigning to type %qT from type %qT"
 msgstr "uforenelige typer i tildeling af '%T' til '%T'"
 
-#: c/c-typeck.c:7083
+#: c/c-typeck.c:7088
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible types in assignment of `%T' to `%T'"
 msgid "incompatible types when initializing type %qT using type %qT"
 msgstr "uforenelige typer i tildeling af '%T' til '%T'"
 
-#: c/c-typeck.c:7088
+#: c/c-typeck.c:7093
 #, gcc-internal-format
 msgid "incompatible types when returning type %qT but %qT was expected"
 msgstr ""
@@ -41886,769 +41933,769 @@
 
 # 'automatic aggregate' betyder automatisk allokerede variabler, dvs.
 # ganske almindelige lokale variabler (kan evt. erklæres med 'auto')
-#: c/c-typeck.c:7152
+#: c/c-typeck.c:7157
 #, gcc-internal-format
 msgid "traditional C rejects automatic aggregate initialization"
 msgstr "traditionel C forbyder klargøring af auto-variabler af sammensatte typer"
 
-#: c/c-typeck.c:7388 c/c-typeck.c:8284 cp/typeck2.c:1045
+#: c/c-typeck.c:7393 c/c-typeck.c:8289 cp/typeck2.c:1045
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "klargøring af fleksibelt tabelmedlem"
 
-#: c/c-typeck.c:7398 cp/typeck2.c:1059
+#: c/c-typeck.c:7403 cp/typeck2.c:1059
 #, gcc-internal-format
 msgid "char-array initialized from wide string"
 msgstr "char-tabel får tildelt startværdi fra en bred streng"
 
-#: c/c-typeck.c:7407
+#: c/c-typeck.c:7412
 #, fuzzy, gcc-internal-format
 #| msgid "int-array initialized from non-wide string"
 msgid "wide character array initialized from non-wide string"
 msgstr "int-tabel får tildelt startværdi fra en ikke-bred streng"
 
-#: c/c-typeck.c:7413
+#: c/c-typeck.c:7418
 #, fuzzy, gcc-internal-format
 #| msgid "char-array initialized from wide string"
 msgid "wide character array initialized from incompatible wide string"
 msgstr "char-tabel får tildelt startværdi fra en bred streng"
 
-#: c/c-typeck.c:7446
+#: c/c-typeck.c:7451
 #, fuzzy, gcc-internal-format
 #| msgid "char-array initialized from wide string"
 msgid "array of inappropriate type initialized from string constant"
 msgstr "char-tabel får tildelt startværdi fra en bred streng"
 
-#: c/c-typeck.c:7533 c/c-typeck.c:7557 c/c-typeck.c:7560 c/c-typeck.c:7568
-#: c/c-typeck.c:7608 c/c-typeck.c:9131 c/c-typeck.c:9181
+#: c/c-typeck.c:7538 c/c-typeck.c:7562 c/c-typeck.c:7565 c/c-typeck.c:7573
+#: c/c-typeck.c:7613 c/c-typeck.c:9136 c/c-typeck.c:9186
 #, gcc-internal-format
 msgid "initializer element is not constant"
 msgstr "startværdielement er ikke en konstant"
 
-#: c/c-typeck.c:7542
+#: c/c-typeck.c:7547
 #, gcc-internal-format
 msgid "array initialized from non-constant array expression"
 msgstr "tabel får tildelt en startværdi fra et tabeludtryk der ikke er konstant"
 
-#: c/c-typeck.c:7573 c/c-typeck.c:7621 c/c-typeck.c:9191
+#: c/c-typeck.c:7578 c/c-typeck.c:7626 c/c-typeck.c:9196
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not constant"
 msgid "initializer element is not a constant expression"
 msgstr "startværdielement er ikke en konstant"
 
-#: c/c-typeck.c:7615 c/c-typeck.c:9186
+#: c/c-typeck.c:7620 c/c-typeck.c:9191
 #, gcc-internal-format
 msgid "initializer element is not computable at load time"
 msgstr "startværdielement kan ikke beregnes ved indlæsningstidspunktet"
 
-#: c/c-typeck.c:7634
+#: c/c-typeck.c:7639
 #, gcc-internal-format
 msgid "invalid initializer"
 msgstr "ugyldig startværdi"
 
-#: c/c-typeck.c:7912 cp/decl.c:6396
+#: c/c-typeck.c:7917 cp/decl.c:6396
 #, fuzzy, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "objekt af typen '%T' med variabel størrelse må ikke tildeles en startværdi"
 
-#: c/c-typeck.c:8132
+#: c/c-typeck.c:8137
 #, gcc-internal-format
 msgid "extra brace group at end of initializer"
 msgstr "overskydende krøllede paranteser ved slutningen af startværdien"
 
-#: c/c-typeck.c:8215
+#: c/c-typeck.c:8220
 #, gcc-internal-format
 msgid "braces around scalar initializer"
 msgstr "krøllede paranteser omkring skalarstartværdi"
 
 # RETMIG: eller er det fleksibel tabel-medlem
-#: c/c-typeck.c:8281 c/c-typeck.c:9615 cp/typeck2.c:1084 cp/typeck2.c:1297
+#: c/c-typeck.c:8286 c/c-typeck.c:9620 cp/typeck2.c:1084 cp/typeck2.c:1297
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "klargøring af fleksibelt tabelmedlem i en indlejret kontekst"
 
-#: c/c-typeck.c:8318
+#: c/c-typeck.c:8323
 #, gcc-internal-format
 msgid "missing braces around initializer"
 msgstr "krøllede paranteser mangler omkring startværdien"
 
-#: c/c-typeck.c:8341
+#: c/c-typeck.c:8346
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member `%D'"
 msgid "missing initializer for field %qD of %qT"
 msgstr "manglende startværdi for medlemmet '%D'"
 
-#: c/c-typeck.c:8365
+#: c/c-typeck.c:8370
 #, gcc-internal-format
 msgid "empty scalar initializer"
 msgstr "tom skalarstartværdi"
 
-#: c/c-typeck.c:8370
+#: c/c-typeck.c:8375
 #, gcc-internal-format
 msgid "extra elements in scalar initializer"
 msgstr "overskydende elementer i skalarstarværdi"
 
-#: c/c-typeck.c:8483 c/c-typeck.c:8565
+#: c/c-typeck.c:8488 c/c-typeck.c:8570
 #, gcc-internal-format
 msgid "array index in non-array initializer"
 msgstr "tabelindeks i en startværdi der ikke er en tabel"
 
 # RETMIG: record?
-#: c/c-typeck.c:8488 c/c-typeck.c:8627
+#: c/c-typeck.c:8493 c/c-typeck.c:8632
 #, gcc-internal-format
 msgid "field name not in record or union initializer"
 msgstr "feltnavn ikke i struktur- eller union-startværdi"
 
-#: c/c-typeck.c:8538
+#: c/c-typeck.c:8543
 #, fuzzy, gcc-internal-format
 #| msgid "array index in initializer exceeds array bounds"
 msgid "array index in initializer not of integer type"
 msgstr "tabelindeks i startværdi overskrider tabelgrænser"
 
-#: c/c-typeck.c:8547 c/c-typeck.c:8556
+#: c/c-typeck.c:8552 c/c-typeck.c:8561
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "array index in initializer is not an integer constant expression"
 msgstr "størrelsen af tabel er ikke af et heltalligt konstantudtryk"
 
-#: c/c-typeck.c:8561 c/c-typeck.c:8563
+#: c/c-typeck.c:8566 c/c-typeck.c:8568
 #, gcc-internal-format
 msgid "nonconstant array index in initializer"
 msgstr "tabelindekset i startværdien er ikke en konstant"
 
-#: c/c-typeck.c:8567 c/c-typeck.c:8570
+#: c/c-typeck.c:8572 c/c-typeck.c:8575
 #, gcc-internal-format
 msgid "array index in initializer exceeds array bounds"
 msgstr "tabelindeks i startværdi overskrider tabelgrænser"
 
-#: c/c-typeck.c:8589
+#: c/c-typeck.c:8594
 #, gcc-internal-format
 msgid "empty index range in initializer"
 msgstr "tomt indeksinterval i startværdi"
 
-#: c/c-typeck.c:8598
+#: c/c-typeck.c:8603
 #, gcc-internal-format
 msgid "array index range in initializer exceeds array bounds"
 msgstr "tabelindeksinterval i startværdi overskrider tabelgrænser"
 
-#: c/c-typeck.c:8700 c/c-typeck.c:8730 c/c-typeck.c:9274
+#: c/c-typeck.c:8705 c/c-typeck.c:8735 c/c-typeck.c:9279
 #, gcc-internal-format
 msgid "initialized field with side-effects overwritten"
 msgstr "klargjort felt med bivirkninger overskrevet"
 
-#: c/c-typeck.c:8704 c/c-typeck.c:8734 c/c-typeck.c:9277
+#: c/c-typeck.c:8709 c/c-typeck.c:8739 c/c-typeck.c:9282
 #, fuzzy, gcc-internal-format
 #| msgid "initialized field with side-effects overwritten"
 msgid "initialized field overwritten"
 msgstr "klargjort felt med bivirkninger overskrevet"
 
-#: c/c-typeck.c:9208
+#: c/c-typeck.c:9213
 #, gcc-internal-format
 msgid "enum conversion in initialization is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:9496
+#: c/c-typeck.c:9501
 #, gcc-internal-format
 msgid "excess elements in char array initializer"
 msgstr "for mange elementer i char-tabelstartværdien"
 
-#: c/c-typeck.c:9503 c/c-typeck.c:9574
+#: c/c-typeck.c:9508 c/c-typeck.c:9579
 #, gcc-internal-format
 msgid "excess elements in struct initializer"
 msgstr "for mange elementer i struct-startværdi"
 
-#: c/c-typeck.c:9518
+#: c/c-typeck.c:9523
 #, gcc-internal-format
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr ""
 
-#: c/c-typeck.c:9589
+#: c/c-typeck.c:9594
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr "ikke-statisk klargøring af fleksibelt tabelmedlem"
 
-#: c/c-typeck.c:9687
+#: c/c-typeck.c:9692
 #, gcc-internal-format
 msgid "excess elements in union initializer"
 msgstr "for mange elementer i union-startværdi"
 
-#: c/c-typeck.c:9709
+#: c/c-typeck.c:9714
 #, gcc-internal-format
 msgid "traditional C rejects initialization of unions"
 msgstr "traditionel C forbyder tildeling af startværdi til unioner"
 
-#: c/c-typeck.c:9777
+#: c/c-typeck.c:9782
 #, gcc-internal-format
 msgid "excess elements in array initializer"
 msgstr "for mange elementer i tabelstartværdi"
 
-#: c/c-typeck.c:9811
+#: c/c-typeck.c:9816
 #, gcc-internal-format
 msgid "excess elements in vector initializer"
 msgstr "for mange elementer i vektorstartværdi"
 
-#: c/c-typeck.c:9843
+#: c/c-typeck.c:9848
 #, gcc-internal-format
 msgid "excess elements in scalar initializer"
 msgstr "for mange elementer i skalarstartværdi"
 
-#: c/c-typeck.c:10086
+#: c/c-typeck.c:10091
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids `goto *expr;'"
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C forbyder 'goto *udtryk;'"
 
-#: c/c-typeck.c:10113 c/gimple-parser.c:1604 cp/typeck.c:9113
+#: c/c-typeck.c:10118 c/gimple-parser.c:1604 cp/typeck.c:9113
 #, fuzzy, gcc-internal-format
 #| msgid "function declared `noreturn' has a `return' statement"
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "funktion der er erklæret 'noreturn' har en 'return'-sætning"
 
-#: c/c-typeck.c:10139 c/c-typeck.c:10143
+#: c/c-typeck.c:10144 c/c-typeck.c:10148
 #, fuzzy, gcc-internal-format
 #| msgid "`return' with no value, in function returning non-void"
 msgid "%<return%> with no value, in function returning non-void"
 msgstr "'return' uden nogen værdi i en funktion der ikke returnerer void"
 
-#: c/c-typeck.c:10157 c/gimple-parser.c:1614
+#: c/c-typeck.c:10162 c/gimple-parser.c:1614
 #, fuzzy, gcc-internal-format
 #| msgid "`return' with a value, in function returning void"
 msgid "%<return%> with a value, in function returning void"
 msgstr "'return' med en værdi i en funktion der returnerer void"
 
-#: c/c-typeck.c:10160
+#: c/c-typeck.c:10165
 #, fuzzy, gcc-internal-format
 #| msgid "`return' with a value, in function returning void"
 msgid "ISO C forbids %<return%> with expression, in function returning void"
 msgstr "'return' med en værdi i en funktion der returnerer void"
 
-#: c/c-typeck.c:10236
+#: c/c-typeck.c:10241
 #, fuzzy, gcc-internal-format
 #| msgid "function returns address of local variable"
 msgid "function returns address of label"
 msgstr "funktion returnerer adressen på en lokal variabel"
 
-#: c/c-typeck.c:10327 cp/semantics.c:1171
+#: c/c-typeck.c:10332 cp/semantics.c:1171
 #, gcc-internal-format
 msgid "switch quantity not an integer"
 msgstr "switch-størrelsen er ikke et heltal"
 
-#: c/c-typeck.c:10352
+#: c/c-typeck.c:10357
 #, fuzzy, gcc-internal-format
 #| msgid "`long' switch expression not converted to `int' in ISO C"
 msgid "%<long%> switch expression not converted to %<int%> in ISO C"
 msgstr "'long'-udtryk i switch konverteres ikke til 'int' i ISO C"
 
-#: c/c-typeck.c:10390 c/c-typeck.c:10398
+#: c/c-typeck.c:10395 c/c-typeck.c:10403
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "case label is not an integer constant expression"
 msgstr "størrelsen af tabel er ikke af et heltalligt konstantudtryk"
 
-#: c/c-typeck.c:10404 cp/parser.c:11067
+#: c/c-typeck.c:10409 cp/parser.c:11067
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "case-etiket befinder sig ikke inden i en switch-sætning"
 
-#: c/c-typeck.c:10406
+#: c/c-typeck.c:10411
 #, fuzzy, gcc-internal-format
 #| msgid "`default' label not within a switch statement"
 msgid "%<default%> label not within a switch statement"
 msgstr "'default'-etiket befinder sig ikke inden i en switch-sætning"
 
-#: c/c-typeck.c:10578 cp/parser.c:12356
+#: c/c-typeck.c:10583 cp/parser.c:12353
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "break-sætning befinder sig ikke i en løkke- eller switch-konstruktion"
 
-#: c/c-typeck.c:10580 cp/parser.c:12379
+#: c/c-typeck.c:10585 cp/parser.c:12376
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "continue-sætning befinder sig ikke i en løkke"
 
-#: c/c-typeck.c:10585 cp/parser.c:12369
+#: c/c-typeck.c:10590 cp/parser.c:12366
 #, fuzzy, gcc-internal-format
 #| msgid "break statement not within loop or switch"
 msgid "break statement used with OpenMP for loop"
 msgstr "break-sætning befinder sig ikke i en løkke- eller switch-konstruktion"
 
-#: c/c-typeck.c:10590
+#: c/c-typeck.c:10595
 #, fuzzy, gcc-internal-format
 #| msgid "break statement not within loop or switch"
 msgid "break statement within %<#pragma simd%> loop body"
 msgstr "break-sætning befinder sig ikke i en løkke- eller switch-konstruktion"
 
-#: c/c-typeck.c:10592
+#: c/c-typeck.c:10597
 #, fuzzy, gcc-internal-format
 #| msgid "continue statement not within a loop"
 msgid "continue statement within %<#pragma simd%> loop body"
 msgstr "continue-sætning befinder sig ikke i en løkke"
 
-#: c/c-typeck.c:10618 cp/cp-gimplify.c:432
+#: c/c-typeck.c:10623 cp/cp-gimplify.c:432
 #, fuzzy, gcc-internal-format
 #| msgid "%Hstatement with no effect"
 msgid "statement with no effect"
 msgstr "%Hsætning uden nogen virkning"
 
-#: c/c-typeck.c:10662
+#: c/c-typeck.c:10667
 #, gcc-internal-format
 msgid "expression statement has incomplete type"
 msgstr "udtrykket er af en ufuldstændig type"
 
-#: c/c-typeck.c:11476 c/c-typeck.c:11644 cp/typeck.c:5017
+#: c/c-typeck.c:11481 c/c-typeck.c:11649 cp/typeck.c:5017
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types"
 msgid "comparing vectors with different element types"
 msgstr "operander til ?: har forskellige typer"
 
-#: c/c-typeck.c:11484 c/c-typeck.c:11652 cp/typeck.c:5030
+#: c/c-typeck.c:11489 c/c-typeck.c:11657 cp/typeck.c:5030
 #, fuzzy, gcc-internal-format
 #| msgid "operand constraints for `asm' differ in number of alternatives"
 msgid "comparing vectors with different number of elements"
 msgstr "operandbegrænsninger til 'asm' har forskellige antal alternativer"
 
-#: c/c-typeck.c:11509 c/c-typeck.c:11677 cp/typeck.c:5058
+#: c/c-typeck.c:11514 c/c-typeck.c:11682 cp/typeck.c:5058
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr ""
 
-#: c/c-typeck.c:11523 cp/typeck.c:4743
+#: c/c-typeck.c:11528 cp/typeck.c:4743
 #, gcc-internal-format
 msgid "comparing floating point with == or != is unsafe"
 msgstr "sammenligning af kommatal med == eller != er ikke sikkert"
 
-#: c/c-typeck.c:11541 c/c-typeck.c:11562
+#: c/c-typeck.c:11546 c/c-typeck.c:11567
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<false%> for the address of %qD will never be NULL"
 msgstr ""
 
-#: c/c-typeck.c:11547 c/c-typeck.c:11568
+#: c/c-typeck.c:11552 c/c-typeck.c:11573
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<true%> for the address of %qD will never be NULL"
 msgstr ""
 
-#: c/c-typeck.c:11589 c/c-typeck.c:11718
+#: c/c-typeck.c:11594 c/c-typeck.c:11723
 #, fuzzy, gcc-internal-format
 #| msgid "comparison of distinct pointer types lacks a cast"
 msgid "comparison of pointers to disjoint address spaces"
 msgstr "sammenligning med forskellige henvisningstyper mangler en typeomtvingelse"
 
-#: c/c-typeck.c:11596 c/c-typeck.c:11602
+#: c/c-typeck.c:11601 c/c-typeck.c:11607
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids comparison of `void *' with function pointer"
 msgid "ISO C forbids comparison of %<void *%> with function pointer"
 msgstr "ISO C forbyder sammenligning af 'void *' med funktionshenvisning"
 
-#: c/c-typeck.c:11609 c/c-typeck.c:11728
+#: c/c-typeck.c:11614 c/c-typeck.c:11733
 #, gcc-internal-format
 msgid "comparison of distinct pointer types lacks a cast"
 msgstr "sammenligning med forskellige henvisningstyper mangler en typeomtvingelse"
 
-#: c/c-typeck.c:11621 c/c-typeck.c:11626 c/c-typeck.c:11754 c/c-typeck.c:11759
+#: c/c-typeck.c:11626 c/c-typeck.c:11631 c/c-typeck.c:11759 c/c-typeck.c:11764
 #, gcc-internal-format
 msgid "comparison between pointer and integer"
 msgstr "sammenligning mellem henvisningsvariabel og heltal"
 
-#: c/c-typeck.c:11706
+#: c/c-typeck.c:11711
 #, gcc-internal-format
 msgid "comparison of complete and incomplete pointers"
 msgstr "sammenligning mellem en fuldstændig og ufuldstændig henvisning"
 
-#: c/c-typeck.c:11708
+#: c/c-typeck.c:11713
 #, gcc-internal-format
 msgid "ISO C forbids ordered comparisons of pointers to functions"
 msgstr "ISO C forbyder ordnede sammenligninger af henvisninger til funktioner"
 
-#: c/c-typeck.c:11713
+#: c/c-typeck.c:11718
 #, fuzzy, gcc-internal-format
 #| msgid "ordered comparison of pointer with integer zero"
 msgid "ordered comparison of pointer with null pointer"
 msgstr "ordnet sammenligning af henvisning med heltallet nul"
 
-#: c/c-typeck.c:11736 c/c-typeck.c:11739 c/c-typeck.c:11746 c/c-typeck.c:11749
+#: c/c-typeck.c:11741 c/c-typeck.c:11744 c/c-typeck.c:11751 c/c-typeck.c:11754
 #: cp/typeck.c:5081 cp/typeck.c:5088
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "ordnet sammenligning af henvisning med heltallet nul"
 
-#: c/c-typeck.c:11811
+#: c/c-typeck.c:11816
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
 msgstr ""
 
-#: c/c-typeck.c:12126
+#: c/c-typeck.c:12131
 #, fuzzy, gcc-internal-format
 #| msgid "array type value used where scalar is required"
 msgid "used array that cannot be converted to pointer where scalar is required"
 msgstr "værdi af tabeltype angivet hvor skalar er påkrævet"
 
-#: c/c-typeck.c:12130
+#: c/c-typeck.c:12135
 #, fuzzy, gcc-internal-format
 #| msgid "struct type value used where scalar is required"
 msgid "used struct type value where scalar is required"
 msgstr "værdi af struct-type angivet hvor skalar er påkrævet"
 
-#: c/c-typeck.c:12134
+#: c/c-typeck.c:12139
 #, fuzzy, gcc-internal-format
 #| msgid "union type value used where scalar is required"
 msgid "used union type value where scalar is required"
 msgstr "værdi af union-type angivet hvor skalar er påkrævet"
 
-#: c/c-typeck.c:12150
+#: c/c-typeck.c:12155
 #, fuzzy, gcc-internal-format
 #| msgid "struct type value used where scalar is required"
 msgid "used vector type where scalar is required"
 msgstr "værdi af struct-type angivet hvor skalar er påkrævet"
 
-#: c/c-typeck.c:12340 cp/semantics.c:8508
+#: c/c-typeck.c:12345 cp/semantics.c:8511
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12379 cp/semantics.c:8545
+#: c/c-typeck.c:12384 cp/semantics.c:8548
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12423 c/c-typeck.c:13581 c/c-typeck.c:13642 c/c-typeck.c:13704
+#: c/c-typeck.c:12428 c/c-typeck.c:13586 c/c-typeck.c:13647 c/c-typeck.c:13709
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field `%s' has invalid type"
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "bitfeltet '%s' er af en ufuldstændig type"
 
-#: c/c-typeck.c:12436 c/c-typeck.c:13628 cp/semantics.c:4546
-#: cp/semantics.c:6717
+#: c/c-typeck.c:12441 c/c-typeck.c:13633 cp/semantics.c:4549
+#: cp/semantics.c:6720
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field `%s' has invalid type"
 msgid "bit-field %qE in %qs clause"
 msgstr "bitfeltet '%s' er af en ufuldstændig type"
 
-#: c/c-typeck.c:12445 c/c-typeck.c:13652 cp/semantics.c:4556
-#: cp/semantics.c:6735
+#: c/c-typeck.c:12450 c/c-typeck.c:13657 cp/semantics.c:4559
+#: cp/semantics.c:6738
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a member template function"
 msgid "%qE is a member of a union"
 msgstr "'%D' er ikke en medlemsskabelonfunktion"
 
-#: c/c-typeck.c:12455 cp/semantics.c:4570 cp/semantics.c:6760
+#: c/c-typeck.c:12460 cp/semantics.c:4573 cp/semantics.c:6763
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qD is not a variable in %qs clause"
 msgstr "'%s' er et ugyldigt klassenavn"
 
-#: c/c-typeck.c:12459 c/c-typeck.c:13669 cp/semantics.c:4574
-#: cp/semantics.c:6763
+#: c/c-typeck.c:12464 c/c-typeck.c:13674 cp/semantics.c:4577
+#: cp/semantics.c:6766
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qE is not a variable in %qs clause"
 msgstr "'%s' er et ugyldigt klassenavn"
 
-#: c/c-typeck.c:12466
+#: c/c-typeck.c:12471
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field `%s' has invalid type"
 msgid "%<_Atomic%> %qD in %qs clause"
 msgstr "bitfeltet '%s' er af en ufuldstændig type"
 
-#: c/c-typeck.c:12475 c/c-typeck.c:13676 c/c-typeck.c:13778
-#: cp/semantics.c:4591 cp/semantics.c:6769 cp/semantics.c:6931
+#: c/c-typeck.c:12480 c/c-typeck.c:13681 c/c-typeck.c:13783
+#: cp/semantics.c:4594 cp/semantics.c:6772 cp/semantics.c:6934
 #, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12511 cp/semantics.c:4623
+#: c/c-typeck.c:12516 cp/semantics.c:4626
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "low bound %qE of array section does not have integral type"
 msgstr "størrelse i tabel-new skal være en heltalstype"
 
-#: c/c-typeck.c:12518 cp/semantics.c:4630
+#: c/c-typeck.c:12523 cp/semantics.c:4633
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "length %qE of array section does not have integral type"
 msgstr "størrelse i tabel-new skal være en heltalstype"
 
-#: c/c-typeck.c:12545 c/c-typeck.c:12609 c/c-typeck.c:12867
-#: cp/semantics.c:4666 cp/semantics.c:4730
+#: c/c-typeck.c:12550 c/c-typeck.c:12614 c/c-typeck.c:12872
+#: cp/semantics.c:4669 cp/semantics.c:4733
 #, fuzzy, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr "Intern oversætterfejl i %s ved %s:%d."
 
-#: c/c-typeck.c:12564 cp/semantics.c:4685
+#: c/c-typeck.c:12569 cp/semantics.c:4688
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12572 cp/semantics.c:4693
+#: c/c-typeck.c:12577 cp/semantics.c:4696
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12581 c/c-typeck.c:12691 cp/semantics.c:4702
-#: cp/semantics.c:4812
+#: c/c-typeck.c:12586 c/c-typeck.c:12696 cp/semantics.c:4705
+#: cp/semantics.c:4815
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12598 cp/semantics.c:4719
+#: c/c-typeck.c:12603 cp/semantics.c:4722
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12635 cp/semantics.c:4756
+#: c/c-typeck.c:12640 cp/semantics.c:4759
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12650 cp/semantics.c:4771
+#: c/c-typeck.c:12655 cp/semantics.c:4774
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12683 cp/semantics.c:4804
+#: c/c-typeck.c:12688 cp/semantics.c:4807
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12701 c/c-typeck.c:12810 cp/semantics.c:4822
-#: cp/semantics.c:4934
+#: c/c-typeck.c:12706 c/c-typeck.c:12815 cp/semantics.c:4825
+#: cp/semantics.c:4937
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12709 cp/semantics.c:4830
+#: c/c-typeck.c:12714 cp/semantics.c:4833
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qE does not have pointer or array type"
 msgstr "variablen til tabel-delete er hverken af en henvisnings- eller en tabeltype"
 
-#: c/c-typeck.c:13103 c/c-typeck.c:13113
+#: c/c-typeck.c:13108 c/c-typeck.c:13118
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qD in %<reduction%> clause is a zero size array"
 msgstr "variablen til tabel-delete er hverken af en henvisnings- eller en tabeltype"
 
-#: c/c-typeck.c:13130
+#: c/c-typeck.c:13135
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids qualified function types"
 msgid "%<_Atomic%> %qE in %<reduction%> clause"
 msgstr "ISO C forbyder funktionsreturtype med modifikationer"
 
-#: c/c-typeck.c:13178
+#: c/c-typeck.c:13183
 #, fuzzy, gcc-internal-format
 #| msgid "invalid return type for function `%#D'"
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "ugyldig returtype for funktionen '%#D'"
 
-#: c/c-typeck.c:13187 cp/semantics.c:5755
+#: c/c-typeck.c:13192 cp/semantics.c:5758
 #, fuzzy, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr "brug af '%D' er tvetydigt"
 
-#: c/c-typeck.c:13275
+#: c/c-typeck.c:13280
 #, gcc-internal-format
 msgid "variable length element type in array %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13293 c/c-typeck.c:13836 cp/semantics.c:7249
+#: c/c-typeck.c:13298 c/c-typeck.c:13841 cp/semantics.c:7252
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13305 cp/semantics.c:7289
+#: c/c-typeck.c:13310 cp/semantics.c:7292
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr ""
 
-#: c/c-typeck.c:13319 cp/semantics.c:5929
+#: c/c-typeck.c:13324 cp/semantics.c:5932
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr ""
 
-#: c/c-typeck.c:13327
+#: c/c-typeck.c:13332
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with type %qT"
 msgstr ""
 
-#: c/c-typeck.c:13335
+#: c/c-typeck.c:13340
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13354 cp/semantics.c:5999
+#: c/c-typeck.c:13359 cp/semantics.c:6002
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr "variablen til tabel-delete er hverken af en henvisnings- eller en tabeltype"
 
-#: c/c-typeck.c:13384 c/c-typeck.c:13771 cp/semantics.c:6083
-#: cp/semantics.c:6924
+#: c/c-typeck.c:13389 c/c-typeck.c:13776 cp/semantics.c:6086
+#: cp/semantics.c:6927
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qE is not a variable in clause %qs"
 msgstr "'%s' er et ugyldigt klassenavn"
 
-#: c/c-typeck.c:13393 cp/semantics.c:6092
+#: c/c-typeck.c:13398 cp/semantics.c:6095
 #, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr ""
 
-#: c/c-typeck.c:13404 c/c-typeck.c:13434 c/c-typeck.c:13463
+#: c/c-typeck.c:13409 c/c-typeck.c:13439 c/c-typeck.c:13468
 #, gcc-internal-format
 msgid "%qE appears more than once in data clauses"
 msgstr ""
 
-#: c/c-typeck.c:13411 c/c-typeck.c:13440 c/c-typeck.c:13600 c/c-typeck.c:13714
-#: c/c-typeck.c:13720 c/c-typeck.c:13733 c/c-typeck.c:13742
-#: cp/semantics.c:6102 cp/semantics.c:6109 cp/semantics.c:6160
-#: cp/semantics.c:6166 cp/semantics.c:6203 cp/semantics.c:6680
-#: cp/semantics.c:6817 cp/semantics.c:6823 cp/semantics.c:6836
-#: cp/semantics.c:6845
+#: c/c-typeck.c:13416 c/c-typeck.c:13445 c/c-typeck.c:13605 c/c-typeck.c:13719
+#: c/c-typeck.c:13725 c/c-typeck.c:13738 c/c-typeck.c:13747
+#: cp/semantics.c:6105 cp/semantics.c:6112 cp/semantics.c:6163
+#: cp/semantics.c:6169 cp/semantics.c:6206 cp/semantics.c:6683
+#: cp/semantics.c:6820 cp/semantics.c:6826 cp/semantics.c:6839
+#: cp/semantics.c:6848
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
-#: c/c-typeck.c:13413 c/c-typeck.c:13442 c/c-typeck.c:13722 c/c-typeck.c:13744
-#: cp/semantics.c:6111 cp/semantics.c:6168 cp/semantics.c:6825
-#: cp/semantics.c:6847
+#: c/c-typeck.c:13418 c/c-typeck.c:13447 c/c-typeck.c:13727 c/c-typeck.c:13749
+#: cp/semantics.c:6114 cp/semantics.c:6171 cp/semantics.c:6828
+#: cp/semantics.c:6850
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr ""
 
-#: c/c-typeck.c:13427 cp/semantics.c:6154
+#: c/c-typeck.c:13432 cp/semantics.c:6157
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable `%s' is declared private"
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "instansvariablen '%s' er erklæret privat"
 
-#: c/c-typeck.c:13456 cp/semantics.c:6197
+#: c/c-typeck.c:13461 cp/semantics.c:6200
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable `%s' is declared private"
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "instansvariablen '%s' er erklæret privat"
 
-#: c/c-typeck.c:13475 cp/semantics.c:6545
+#: c/c-typeck.c:13480 cp/semantics.c:6548
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "'%s' er et ugyldigt klassenavn"
 
-#: c/c-typeck.c:13482
+#: c/c-typeck.c:13487
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array"
 msgstr "variablen til tabel-delete er hverken af en henvisnings- eller en tabeltype"
 
-#: c/c-typeck.c:13489
+#: c/c-typeck.c:13494
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<aligned%> clause"
 msgstr "%<_Atomic%> %qD i %<aligned%>-klausul"
 
-#: c/c-typeck.c:13496
+#: c/c-typeck.c:13501
 #, gcc-internal-format
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:13551 cp/semantics.c:6627
+#: c/c-typeck.c:13556 cp/semantics.c:6630
 #, gcc-internal-format
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr "%qE er ikke en variable i %<depend%>-klausul"
 
-#: c/c-typeck.c:13573 cp/semantics.c:6658
+#: c/c-typeck.c:13578 cp/semantics.c:6661
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13597 c/c-typeck.c:13731 cp/semantics.c:6677
-#: cp/semantics.c:6834
+#: c/c-typeck.c:13602 c/c-typeck.c:13736 cp/semantics.c:6680
+#: cp/semantics.c:6837
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD fremgår mere end en gang i motion-klausuller"
 
-#: c/c-typeck.c:13603 c/c-typeck.c:13735 cp/semantics.c:6683
-#: cp/semantics.c:6838
+#: c/c-typeck.c:13608 c/c-typeck.c:13740 cp/semantics.c:6686
+#: cp/semantics.c:6841
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD fremgår mere end en gang i map-klausuller"
 
-#: c/c-typeck.c:13635 cp/semantics.c:6724
+#: c/c-typeck.c:13640 cp/semantics.c:6727
 #, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qE har ikke en mappable-type i %qs-klausul"
 
-#: c/c-typeck.c:13695 c/c-typeck.c:13785 cp/semantics.c:6799
-#: cp/semantics.c:6938
+#: c/c-typeck.c:13700 c/c-typeck.c:13790 cp/semantics.c:6802
+#: cp/semantics.c:6941
 #, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD har ikke en mappable-type i %qs-klausul"
 
-#: c/c-typeck.c:13766 cp/semantics.c:6918
+#: c/c-typeck.c:13771 cp/semantics.c:6921
 #, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE er hverken en variabel eller et funktionsnavn i klausul %qs"
 
-#: c/c-typeck.c:13794 cp/semantics.c:6947
+#: c/c-typeck.c:13799 cp/semantics.c:6950
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr ""
 
-#: c/c-typeck.c:13808 cp/semantics.c:6962
+#: c/c-typeck.c:13813 cp/semantics.c:6965
 #, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13811 cp/semantics.c:6964
+#: c/c-typeck.c:13816 cp/semantics.c:6967
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13826
+#: c/c-typeck.c:13831
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "variablen til tabel-delete er hverken af en henvisnings- eller en tabeltype"
 
-#: c/c-typeck.c:13900 cp/semantics.c:6359
+#: c/c-typeck.c:13905 cp/semantics.c:6362
 #, gcc-internal-format
 msgid "%<nonmonotonic%> modifier specified for %qs schedule kind"
 msgstr ""
 
-#: c/c-typeck.c:13931 cp/semantics.c:7141
+#: c/c-typeck.c:13936 cp/semantics.c:7144
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:13981 cp/semantics.c:7332
+#: c/c-typeck.c:13986 cp/semantics.c:7335
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr ""
 
-#: c/c-typeck.c:14001 cp/semantics.c:7223
+#: c/c-typeck.c:14006 cp/semantics.c:7226
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:14013 cp/semantics.c:7236
+#: c/c-typeck.c:14018 cp/semantics.c:7239
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14031 cp/semantics.c:7203
+#: c/c-typeck.c:14036 cp/semantics.c:7206
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14204
+#: c/c-typeck.c:14209
 #, gcc-internal-format
 msgid "cannot use %<va_arg%> with reverse storage order"
 msgstr ""
 
-#: c/c-typeck.c:14209
+#: c/c-typeck.c:14214
 #, fuzzy, gcc-internal-format
 #| msgid "first argument to `va_arg' not of type `va_list'"
 msgid "second argument to %<va_arg%> is of incomplete type %qT"
 msgstr "den første parameter til 'va_arg' er ikke af typen 'va_list'"
 
-#: c/c-typeck.c:14215
+#: c/c-typeck.c:14220
 #, gcc-internal-format
 msgid "C++ requires promoted type, not enum type, in %<va_arg%>"
 msgstr ""
@@ -42780,7 +42827,7 @@
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "  for konvertering fra '%T' til '%T'"
 
-#: cp/call.c:3441 cp/pt.c:6495
+#: cp/call.c:3441 cp/pt.c:6509
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -43096,7 +43143,7 @@
 msgid "%q#D is private within this context"
 msgstr "i denne kontekst"
 
-#: cp/call.c:6478 cp/decl.c:7343
+#: cp/call.c:6478 cp/decl.c:7364
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "declared private here"
@@ -43108,7 +43155,7 @@
 msgid "%q#D is protected within this context"
 msgstr "i denne kontekst"
 
-#: cp/call.c:6486 cp/decl.c:7344
+#: cp/call.c:6486 cp/decl.c:7365
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "declared protected here"
@@ -43444,7 +43491,7 @@
 msgid "call to non-function %qD"
 msgstr "kald af ikke-funktion '%D'"
 
-#: cp/call.c:9119 cp/pt.c:15053 cp/typeck.c:2901
+#: cp/call.c:9119 cp/pt.c:15075 cp/typeck.c:2901
 #, fuzzy, gcc-internal-format
 #| msgid "cannot call destructor `%T::~%T' without object"
 msgid "cannot call constructor %<%T::%D%> directly"
@@ -43681,300 +43728,300 @@
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr "kan ikke konvertere fra stamklassen '%T' til den nedarvede type '%T' via den virtuelle stamklasse '%T'"
 
-#: cp/class.c:2098
+#: cp/class.c:2103
 #, fuzzy, gcc-internal-format
 #| msgid "all member functions in class `%T' are private"
 msgid "all member functions in class %qT are private"
 msgstr "alle medlemsfunktioner i klassen '%T' er private"
 
-#: cp/class.c:2110
+#: cp/class.c:2115
 #, fuzzy, gcc-internal-format
 #| msgid "`%#T' only defines a private destructor and has no friends"
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr "'%#T' definerer kun en privat destruktionsfunktion og har ingen venner"
 
-#: cp/class.c:2152
+#: cp/class.c:2156
 #, fuzzy, gcc-internal-format
 #| msgid "`%#T' only defines private constructors and has no friends"
 msgid "%q#T only defines private constructors and has no friends"
 msgstr "'%#T' definerer kun private konstruktionsfunktioner og har ingen venner"
 
-#: cp/class.c:2156
+#: cp/class.c:2160
 #, gcc-internal-format
 msgid "%q#D is public, but requires an existing %q#T object"
 msgstr ""
 
 # %D er en funktion
-#: cp/class.c:2430
+#: cp/class.c:2434
 #, fuzzy, gcc-internal-format
 #| msgid "no unique final overrider for `%D' in `%T'"
 msgid "no unique final overrider for %qD in %qT"
 msgstr "ingen unik endelig overskrivning af '%D' i '%T'"
 
-#: cp/class.c:2785
+#: cp/class.c:2789
 #, fuzzy, gcc-internal-format
 #| msgid "`%#D' and `%#D' cannot be overloaded"
 msgid "%qD can be marked override"
 msgstr "'%#D' og '%#D' kan ikke flertydiggøres"
 
-#: cp/class.c:2797
+#: cp/class.c:2801
 #, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr ""
 
-#: cp/class.c:2799
+#: cp/class.c:2803
 #, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr ""
 
-#: cp/class.c:2861
+#: cp/class.c:2865
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' was hidden"
 msgid "%qD was hidden"
 msgstr "'%D' var skjult"
 
-#: cp/class.c:2863
+#: cp/class.c:2867
 #, fuzzy, gcc-internal-format
 #| msgid "  by `%D'"
 msgid "  by %qD"
 msgstr "  af '%D'"
 
-#: cp/class.c:2896
+#: cp/class.c:2900
 #, fuzzy, gcc-internal-format
 #| msgid "`%#D' invalid; an anonymous union can only have non-static data members"
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "'%#D' er ugyldig; en anonym union kan kun have ikke-statiske datamedlemmer"
 
-#: cp/class.c:2906 cp/name-lookup.c:3293 cp/parser.c:19720
+#: cp/class.c:2910 cp/name-lookup.c:3293 cp/parser.c:19717
 #, fuzzy, gcc-internal-format
 #| msgid "-traditional is deprecated and may be removed"
 msgid "this flexibility is deprecated and will be removed"
 msgstr "-traditional er forældet og kan blive fjernet"
 
-#: cp/class.c:3097
+#: cp/class.c:3101
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr ""
 
-#: cp/class.c:3213
+#: cp/class.c:3217
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field `%#D' with non-integral type"
 msgid "bit-field %q+#D with non-integral type"
 msgstr "bitfelt '%#D' med en ikke-heltalstype"
 
-#: cp/class.c:3229
+#: cp/class.c:3233
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field `%D' width not an integer constant"
 msgid "bit-field %q+D width not an integer constant"
 msgstr "bredden af bitfeltet '%D' er ikke en heltalskonstant"
 
-#: cp/class.c:3234
+#: cp/class.c:3238
 #, fuzzy, gcc-internal-format
 #| msgid "negative width in bit-field `%D'"
 msgid "negative width in bit-field %q+D"
 msgstr "negativ bredde i bitfeltet '%D'"
 
-#: cp/class.c:3239
+#: cp/class.c:3243
 #, fuzzy, gcc-internal-format
 #| msgid "zero width for bit-field `%D'"
 msgid "zero width for bit-field %q+D"
 msgstr "en bredde på nul for bitfeltet '%D'"
 
-#: cp/class.c:3249
+#: cp/class.c:3253
 #, fuzzy, gcc-internal-format
 #| msgid "width of `%D' exceeds its type"
 msgid "width of %qD exceeds its type"
 msgstr "bredden af '%D' overstiger typen"
 
-#: cp/class.c:3255
+#: cp/class.c:3259
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is too small to hold all values of `%#T'"
 msgid "%qD is too small to hold all values of %q#T"
 msgstr "'%D' er for lille til at indeholde alle værdierne af '%#T'"
 
-#: cp/class.c:3316
+#: cp/class.c:3320
 #, fuzzy, gcc-internal-format
 #| msgid "member `%#D' with constructor not allowed in union"
 msgid "member %q+#D with constructor not allowed in union"
 msgstr "medlemmet '%#D' med en konstruktionsfunktion er ikke tilladt i en union"
 
-#: cp/class.c:3319
+#: cp/class.c:3323
 #, fuzzy, gcc-internal-format
 #| msgid "member `%#D' with destructor not allowed in union"
 msgid "member %q+#D with destructor not allowed in union"
 msgstr "medlemmet '%#D' med en destruktionsfunktion er ikke tilladt i en union"
 
-#: cp/class.c:3321
+#: cp/class.c:3325
 #, fuzzy, gcc-internal-format
 #| msgid "member `%#D' with copy assignment operator not allowed in union"
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr "medlemmet '%#D' med en kopitildelingsoperator er ikke tilladt i en union"
 
-#: cp/class.c:3325
+#: cp/class.c:3329
 #, gcc-internal-format
 msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/class.c:3453
+#: cp/class.c:3457
 #, gcc-internal-format
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr ""
 
-#: cp/class.c:3460
+#: cp/class.c:3464
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type `%T'"
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr "opretter henvisning til medlemsreference af typen '%T'"
 
-#: cp/class.c:3470
+#: cp/class.c:3474
 #, fuzzy, gcc-internal-format
 #| msgid "field `%D' invalidly declared function type"
 msgid "field %q+D invalidly declared function type"
 msgstr "feltet '%D' er på ugyldig vis erklæret som en funktionstype"
 
-#: cp/class.c:3476
+#: cp/class.c:3480
 #, fuzzy, gcc-internal-format
 #| msgid "field `%D' invalidly declared method type"
 msgid "field %q+D invalidly declared method type"
 msgstr "feltet '%D' er på ugyldig vis erklæret som en medlemsfunktionstype"
 
-#: cp/class.c:3536
+#: cp/class.c:3540
 #, gcc-internal-format
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr ""
 
-#: cp/class.c:3585
+#: cp/class.c:3589
 #, fuzzy, gcc-internal-format
 #| msgid "member `%D' cannot be declared both virtual and static"
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr "medlemmet '%D' kan ikke afklæres både virtual og static"
 
-#: cp/class.c:3591
+#: cp/class.c:3595
 #, fuzzy, gcc-internal-format
 #| msgid "non-member `%s' cannot be declared `mutable'"
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr "'%s' som ikke er medlem, kan ikke erklæres 'mutable'"
 
-#: cp/class.c:3617
+#: cp/class.c:3621
 #, fuzzy, gcc-internal-format
 #| msgid "multiple fields in union `%T' initialized"
 msgid "multiple fields in union %qT initialized"
 msgstr "flere felter i union '%T' tildeles startværdi"
 
-#: cp/class.c:3658
+#: cp/class.c:3662
 #, fuzzy, gcc-internal-format
 #| msgid "field `%#D' with same name as class"
 msgid "field %q#D with same name as class"
 msgstr "felt '%#D' med samme navn som klassen"
 
-#: cp/class.c:3681
+#: cp/class.c:3685
 #, fuzzy, gcc-internal-format
 #| msgid "`%#T' has pointer data members"
 msgid "%q#T has pointer data members"
 msgstr "'%#T' har henvisningsdatamedlemmer"
 
-#: cp/class.c:3686
+#: cp/class.c:3690
 #, fuzzy, gcc-internal-format
 #| msgid "  but does not override `%T(const %T&)'"
 msgid "  but does not override %<%T(const %T&)%>"
 msgstr "  men overskriver ikke '%T(const %T&)'"
 
-#: cp/class.c:3688
+#: cp/class.c:3692
 #, fuzzy, gcc-internal-format
 #| msgid "  or `operator=(const %T&)'"
 msgid "  or %<operator=(const %T&)%>"
 msgstr "  eller 'operator=(const %T&)'"
 
-#: cp/class.c:3692
+#: cp/class.c:3696
 #, fuzzy, gcc-internal-format
 #| msgid "  but does not override `operator=(const %T&)'"
 msgid "  but does not override %<operator=(const %T&)%>"
 msgstr "  men overskriver ikke 'operator=(const %T&)'"
 
-#: cp/class.c:4097
+#: cp/class.c:4101
 #, gcc-internal-format
 msgid "alignment of %qD increased in -fabi-version=9 (GCC 5.2)"
 msgstr ""
 
-#: cp/class.c:4100
+#: cp/class.c:4104
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "alignment of %qD will increase in -fabi-version=9"
 msgstr "tildeling (ikke klargøring) i erklæring"
 
-#: cp/class.c:4378
+#: cp/class.c:4382
 #, fuzzy, gcc-internal-format
 #| msgid "initializer specified for non-virtual method `%D'"
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "startværdi angivet for ikke-virtuel medlemsfunktion '%D'"
 
-#: cp/class.c:4813
+#: cp/class.c:4817
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr ""
 
-#: cp/class.c:4834
+#: cp/class.c:4838
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr ""
 
-#: cp/class.c:5350 cp/constexpr.c:237
+#: cp/class.c:5367 cp/constexpr.c:237
 #, fuzzy, gcc-internal-format
 msgid "enclosing class of %<constexpr%> non-static member function %q+#D is not a literal type"
 msgstr "ugyldig brug af ikke-statisk felt '%D'"
 
-#: cp/class.c:5374
+#: cp/class.c:5391
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a template"
 msgid "%q+T is not literal because:"
 msgstr "'%T' er ikke en skabelon"
 
-#: cp/class.c:5377
+#: cp/class.c:5394
 #, gcc-internal-format
 msgid "  %qT is a closure type, which is only literal in C++17 and later"
 msgstr ""
 
-#: cp/class.c:5380
+#: cp/class.c:5397
 #, fuzzy, gcc-internal-format
 #| msgid "base class `%#T' has a non-virtual destructor"
 msgid "  %q+T has a non-trivial destructor"
 msgstr "stamklassen '%#T' har en ikke-virtuel destruktionsfunktion"
 
-#: cp/class.c:5387
+#: cp/class.c:5404
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no %<constexpr%> constructor that is not a copy or move constructor"
 msgstr ""
 
-#: cp/class.c:5420
+#: cp/class.c:5437
 #, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr ""
 
-#: cp/class.c:5435
+#: cp/class.c:5452
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type `%T'"
 msgid "  non-static data member %qD has non-literal type"
 msgstr "ugyldig tildeling af startværdi i klasse til statisk datamedlem af en ikke-heltalstype '%T'"
 
-#: cp/class.c:5442
+#: cp/class.c:5459
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' has no non-static data member named `%D'"
 msgid "  non-static data member %qD has volatile type"
 msgstr "'%T' har intet ikke-statisk medlem ved navn '%D'"
 
-#: cp/class.c:5561
+#: cp/class.c:5578
 #, fuzzy, gcc-internal-format
 #| msgid "base class `%#T' has a non-virtual destructor"
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "stamklassen '%#T' har en ikke-virtuel destruktionsfunktion"
 
-#: cp/class.c:5590
+#: cp/class.c:5607
 #, fuzzy, gcc-internal-format
 #| msgid "non-static reference `%#D' in class without a constructor"
 msgid "non-static reference %q#D in class without a constructor"
 msgstr "ikke-statisk reference '%#D' i klasse uden en konstruktionsfunktion"
 
-#: cp/class.c:5596
+#: cp/class.c:5613
 #, fuzzy, gcc-internal-format
 #| msgid "non-static const member `%#D' in class without a constructor"
 msgid "non-static const member %q#D in class without a constructor"
@@ -43982,171 +44029,171 @@
 
 #. If the function is defaulted outside the class, we just
 #. give the synthesis error.
-#: cp/class.c:5624
+#: cp/class.c:5641
 #, gcc-internal-format
 msgid "%q+D declared to take const reference, but implicit declaration would take non-const"
 msgstr ""
 
-#: cp/class.c:5898
+#: cp/class.c:5915
 #, fuzzy, gcc-internal-format
 #| msgid "direct base `%T' inaccessible in `%T' due to ambiguity"
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr "direkte stamklasse '%T' er ikke tilgængelig i '%T' på grund af tvetydighed"
 
-#: cp/class.c:5910
+#: cp/class.c:5927
 #, fuzzy, gcc-internal-format
 #| msgid "virtual base `%T' inaccessible in `%T' due to ambiguity"
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr "virtuel stamklasse '%T' er ikke tilgængelig i '%T' på grund af tvetydighed"
 
-#: cp/class.c:6133
+#: cp/class.c:6150
 #, fuzzy, gcc-internal-format
 #| msgid "offset of `%D' is not ABI-compliant and may change in a future version of GCC"
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr "afsættet for '%D' følger ikke ABI'en og kan ændre sig i en fremtidig version af GCC"
 
-#: cp/class.c:6291
+#: cp/class.c:6308
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%s' is too large"
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr "størrelsen af tabellen '%s' er for stor"
 
-#: cp/class.c:6576
+#: cp/class.c:6593
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<...%> with non-slice"
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr "ugyldig brug af %<...%> med ikke-skive"
 
-#: cp/class.c:6578
+#: cp/class.c:6595
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of structure with flexible array member"
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr "ugyldig brug af struktur med fleksibelt tabelmedlem"
 
-#: cp/class.c:6583
+#: cp/class.c:6600
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "array member %q#D declared here"
 msgstr "  '%#D' erklæret her"
 
-#: cp/class.c:6610
+#: cp/class.c:6627
 #, fuzzy, gcc-internal-format
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr "fleksibelt tabelmedlem ikke i slutningen af struktur"
 
-#: cp/class.c:6612
+#: cp/class.c:6629
 #, fuzzy, gcc-internal-format
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr "fleksibelt tabelmedlem i ellers tom struktur"
 
-#: cp/class.c:6620 cp/class.c:6650
+#: cp/class.c:6637 cp/class.c:6667
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of `%#T'"
 msgid "in the definition of %q#T"
 msgstr "omdefinering af '%#T'"
 
-#: cp/class.c:6628
+#: cp/class.c:6645
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD not at end of %q#T"
 msgstr "fleksibelt tabelmedlem ikke i slutningen af struktur"
 
-#: cp/class.c:6630
+#: cp/class.c:6647
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr "fleksibelt tabelmedlem i ellers tom struktur"
 
-#: cp/class.c:6648
+#: cp/class.c:6665
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "next member %q#D declared here"
 msgstr "  '%#D' erklæret her"
 
-#: cp/class.c:6760 cp/parser.c:23239
+#: cp/class.c:6777 cp/parser.c:23236
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of `%#T'"
 msgid "redefinition of %q#T"
 msgstr "omdefinering af '%#T'"
 
-#: cp/class.c:6897
+#: cp/class.c:6914
 #, fuzzy, gcc-internal-format
 #| msgid "`%#T' has virtual functions but non-virtual destructor"
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "'%#T' har virtuelle funktioner, men ikke-virtuel destruktionsfunktion"
 
-#: cp/class.c:6925
+#: cp/class.c:6942
 #, fuzzy, gcc-internal-format
 #| msgid "class `%T' does not have any field named `%D'"
 msgid "type transparent %q#T does not have any fields"
 msgstr "klassen '%T' har ikke et felt ved navn '%D'"
 
-#: cp/class.c:6931
+#: cp/class.c:6948
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr ""
 
-#: cp/class.c:6935
+#: cp/class.c:6952
 #, fuzzy, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr "  eftersom typen '%T' har abstrakte virtuelle funktioner"
 
-#: cp/class.c:6941
+#: cp/class.c:6958
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:7071
+#: cp/class.c:7088
 #, fuzzy, gcc-internal-format
 #| msgid "brace-enclosed initializer used to initialize `%T'"
 msgid "definition of %qD does not match %<#include <initializer_list>%>"
 msgstr "startværdi i krøllede paranteser benyttet til at klargøre '%T'"
 
-#: cp/class.c:7082
+#: cp/class.c:7099
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr "forsøgte at afslutte struct, men blev stoppet af tidligere fortolkningsfejl"
 
-#: cp/class.c:7582
+#: cp/class.c:7599
 #, fuzzy, gcc-internal-format
 #| msgid "language string `\"%s\"' not recognized"
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "sprogstrengen '\"%s\"' ikke genkendt"
 
-#: cp/class.c:7672
+#: cp/class.c:7689
 #, fuzzy, gcc-internal-format
 #| msgid "cannot resolve overloaded function `%D' based on conversion to type `%T'"
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr "kan ikke benytte den flertydiggjorte funktion '%D' baseret på konvertering til typen '%T'"
 
-#: cp/class.c:7817
+#: cp/class.c:7834
 #, fuzzy, gcc-internal-format
 #| msgid "no matches converting function `%D' to type `%#T'"
 msgid "no matches converting function %qD to type %q#T"
 msgstr "ingen passende ved konvertering af funktionen '%D' til typen '%#T'"
 
-#: cp/class.c:7844
+#: cp/class.c:7861
 #, fuzzy, gcc-internal-format
 #| msgid "converting overloaded function `%D' to type `%#T' is ambiguous"
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "konvertering af den flertydiggjorte funktion '%D' til typen '%T' er tvetydig"
 
-#: cp/class.c:7870
+#: cp/class.c:7887
 #, fuzzy, gcc-internal-format
 #| msgid "assuming pointer to member `%D'"
 msgid "assuming pointer to member %qD"
 msgstr "antager henvisning til medlemmet '%D'"
 
-#: cp/class.c:7873
+#: cp/class.c:7890
 #, fuzzy, gcc-internal-format
 #| msgid "(a pointer to member can only be formed with `&%E')"
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(en henvisning til medlem kan kun dannes med '&%E')"
 
-#: cp/class.c:7948 cp/class.c:7990
+#: cp/class.c:7965 cp/class.c:8007
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "ikke tilstrækkelig information om typen"
 
-#: cp/class.c:7968
+#: cp/class.c:7985
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert `%E' from type `%T' to type `%T'"
 msgid "cannot convert %qE from type %qT to type %qT"
@@ -44157,13 +44204,13 @@
 #. A name N used in a class S shall refer to the same declaration
 #. in its context and when re-evaluated in the completed scope of
 #. S.
-#: cp/class.c:8235
+#: cp/class.c:8252
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D'"
 msgid "declaration of %q#D"
 msgstr "omerklæring af '%#D'"
 
-#: cp/class.c:8237
+#: cp/class.c:8254
 #, fuzzy, gcc-internal-format
 #| msgid "changes meaning of `%D' from `%+#D'"
 msgid "changes meaning of %qD from %q#D"
@@ -44598,17 +44645,17 @@
 msgid "unexpected AST of kind %s"
 msgstr "uventet type for 'id' (%s)"
 
-#: cp/cp-gimplify.c:1415
+#: cp/cp-gimplify.c:1416
 #, gcc-internal-format
 msgid "throw will always call terminate()"
 msgstr ""
 
-#: cp/cp-gimplify.c:1418
+#: cp/cp-gimplify.c:1419
 #, gcc-internal-format
 msgid "in C++11 destructors default to noexcept"
 msgstr ""
 
-#: cp/cp-gimplify.c:1429
+#: cp/cp-gimplify.c:1430
 #, gcc-internal-format
 msgid "in C++11 this throw will terminate because destructors default to noexcept"
 msgstr ""
@@ -45070,7 +45117,7 @@
 msgstr "erklæring af '%D' som %s"
 
 # hænger sammen med næste tekst
-#: cp/decl.c:1304 cp/decl.c:13843
+#: cp/decl.c:1304 cp/decl.c:13867
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration `%D'"
 msgid "previous declaration %qD"
@@ -45436,7 +45483,7 @@
 msgid "  enters OpenMP structured block"
 msgstr "  går ind i try-blok"
 
-#: cp/decl.c:3434 cp/parser.c:12366 cp/parser.c:12387
+#: cp/decl.c:3434 cp/parser.c:12363 cp/parser.c:12384
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr ""
@@ -45447,7 +45494,7 @@
 msgid "%qD is not a type"
 msgstr "'%T' er ikke en skabelon"
 
-#: cp/decl.c:3838 cp/parser.c:6366
+#: cp/decl.c:3838 cp/parser.c:6369
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' used without template parameters"
 msgid "%qD used without template parameters"
@@ -45876,8 +45923,8 @@
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr "for mange elementer i startværdi til sammensat type"
 
-#: cp/decl.c:6011 cp/decl.c:6234 cp/typeck2.c:1310 cp/typeck2.c:1590
-#: cp/typeck2.c:1638 cp/typeck2.c:1685
+#: cp/decl.c:6011 cp/decl.c:6234 cp/typeck2.c:1310 cp/typeck2.c:1593
+#: cp/typeck2.c:1641 cp/typeck2.c:1688
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "for mange startværdier for %qT"
@@ -45963,12 +46010,12 @@
 msgid "assignment (not initialization) in declaration"
 msgstr "tildeling (ikke klargøring) i erklæring"
 
-#: cp/decl.c:6873 cp/decl.c:12605
+#: cp/decl.c:6873 cp/decl.c:12629
 #, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C++17 tillader ikke %<register%>-lagerklasseangivelse"
 
-#: cp/decl.c:6877 cp/decl.c:12609
+#: cp/decl.c:6877 cp/decl.c:12633
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for %s `%s'"
 msgid "%<register%> storage class specifier used"
@@ -45998,46 +46045,46 @@
 msgid "function %q#D is initialized like a variable"
 msgstr "funktionen '%#D' bliver tildelt en startværdi som en variabel"
 
-#: cp/decl.c:7329
+#: cp/decl.c:7350
 #, fuzzy, gcc-internal-format
 #| msgid "  cannot use obsolete binding at `%D' because it has a destructor"
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "  kan ikke bruge forældet binding til '%D' fordi den har en destruktionsfunktion"
 
-#: cp/decl.c:7332
+#: cp/decl.c:7353
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.c:7339
+#: cp/decl.c:7360
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type `%T'"
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "opretter henvisning til medlem af typen '%T' der ikke er en klasse"
 
-#: cp/decl.c:7365
+#: cp/decl.c:7386
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:7374
+#: cp/decl.c:7395
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:7592
+#: cp/decl.c:7613
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing pointer to incomplete type"
 msgid "structured binding refers to incomplete type %qT"
 msgstr "forsøg på at følge en henvisning til en variabel af en ufuldstændig type"
 
-#: cp/decl.c:7608
+#: cp/decl.c:7629
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable-size array `%s'"
 msgid "cannot decompose variable length array %qT"
 msgstr "ISO C90 forbyder tabellen '%s' med variabel størrelse"
 
-#: cp/decl.c:7617 cp/decl.c:7702
+#: cp/decl.c:7638 cp/decl.c:7723
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "storage class specified for structure field `%s'"
 msgid "%u name provided for structured binding"
@@ -46045,7 +46092,7 @@
 msgstr[0] "lagringsklasse angivet for strukturfelt '%s'"
 msgstr[1] "lagringsklasse angivet for strukturfelt '%s'"
 
-#: cp/decl.c:7621
+#: cp/decl.c:7642
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
@@ -46052,7 +46099,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:7624
+#: cp/decl.c:7645
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
@@ -46059,104 +46106,104 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:7669
+#: cp/decl.c:7690
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable-size array `%s'"
 msgid "cannot decompose variable length vector %qT"
 msgstr "ISO C90 forbyder tabellen '%s' med variabel størrelse"
 
-#: cp/decl.c:7695
+#: cp/decl.c:7716
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "størrelsen af tabel er ikke af et heltalligt konstantudtryk"
 
-#: cp/decl.c:7704
+#: cp/decl.c:7725
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.c:7725
+#: cp/decl.c:7746
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute `%s'"
 msgid "in initialization of structured binding variable %qD"
 msgstr "ugyldig vektortype for egenskaben '%s'"
 
-#: cp/decl.c:7751
+#: cp/decl.c:7772
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare bit-field `%D' with function type"
 msgid "cannot decompose union type %qT"
 msgstr "kan ikke erklære bitfelt '%D' med funktionstype"
 
-#: cp/decl.c:7756
+#: cp/decl.c:7777
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type `%T'"
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "opretter henvisning til medlem af typen '%T' der ikke er en klasse"
 
-#: cp/decl.c:7761
+#: cp/decl.c:7782
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare bit-field `%D' with function type"
 msgid "cannot decompose lambda closure type %qT"
 msgstr "kan ikke erklære bitfelt '%D' med funktionstype"
 
-#: cp/decl.c:7765
+#: cp/decl.c:7786
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing pointer to incomplete type"
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "forsøg på at følge en henvisning til en variabel af en ufuldstændig type"
 
-#: cp/decl.c:7774
+#: cp/decl.c:7795
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "ugyldig brug af ikke-statisk felt '%D'"
 
-#: cp/decl.c:8213
+#: cp/decl.c:8234
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:8216
+#: cp/decl.c:8237
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:8222
+#: cp/decl.c:8243
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:8450
+#: cp/decl.c:8471
 #, fuzzy, gcc-internal-format
 #| msgid "initializer fails to determine size of `%D'"
 msgid "initializer fails to determine size of %qT"
 msgstr "startværdien giver ikke størrelsen af '%D'"
 
-#: cp/decl.c:8454
+#: cp/decl.c:8475
 #, fuzzy, gcc-internal-format
 #| msgid "array size missing in `%D'"
 msgid "array size missing in %qT"
 msgstr "tabelstørrelsen mangler i '%D'"
 
-#: cp/decl.c:8457
+#: cp/decl.c:8478
 #, fuzzy, gcc-internal-format
 #| msgid "zero-size array `%D'"
 msgid "zero-size array %qT"
 msgstr "nulstørrelsestabel '%D'"
 
-#: cp/decl.c:8473
+#: cp/decl.c:8494
 #, fuzzy, gcc-internal-format
 #| msgid "destructor for alien class `%T' cannot be a member"
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "destruktionsfunktionen for den fremmede klasse '%T' kan ikke være et medlem"
 
-#: cp/decl.c:8475
+#: cp/decl.c:8496
 #, fuzzy, gcc-internal-format
 #| msgid "constructor for alien class `%T' cannot be a member"
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "konstruktionsfunktionen for den fremmede klasse '%T' kan ikke være et medlem"
 
-#: cp/decl.c:8499
+#: cp/decl.c:8520
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as a `virtual' %s"
 msgid "%qD declared as a %<virtual%> variable"
@@ -46163,37 +46210,37 @@
 msgstr "'%D' erklæret som 'virtual' %s"
 
 # %s bliver omsat til typen
-#: cp/decl.c:8501
+#: cp/decl.c:8522
 #, fuzzy, gcc-internal-format
 #| msgid "`const' and `volatile' function specifiers on `%D' invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "'const'- og 'volatile'-funktionsangivelser til '%D' er ugyldigt i erklæring af %s"
 
-#: cp/decl.c:8506
+#: cp/decl.c:8527
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as a `virtual' %s"
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "'%D' erklæret som 'virtual' %s"
 
-#: cp/decl.c:8508
+#: cp/decl.c:8529
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "'%D' er erklæret som en ven"
 
 # %s bliver omsat til typen
-#: cp/decl.c:8510
+#: cp/decl.c:8531
 #, fuzzy, gcc-internal-format
 #| msgid "`const' and `volatile' function specifiers on `%D' invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "'const'- og 'volatile'-funktionsangivelser til '%D' er ugyldigt i erklæring af %s"
 
-#: cp/decl.c:8515
+#: cp/decl.c:8536
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as a `virtual' %s"
 msgid "%qD declared as a %<virtual%> type"
 msgstr "'%D' erklæret som 'virtual' %s"
 
-#: cp/decl.c:8517
+#: cp/decl.c:8538
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as an `inline' %s"
 msgid "%qD declared as an %<inline%> type"
@@ -46200,19 +46247,19 @@
 msgstr "'%D' erklæret som 'inline' %s"
 
 # %s bliver omsat til typen
-#: cp/decl.c:8519
+#: cp/decl.c:8540
 #, fuzzy, gcc-internal-format
 #| msgid "`const' and `volatile' function specifiers on `%D' invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "'const'- og 'volatile'-funktionsangivelser til '%D' er ugyldigt i erklæring af %s"
 
-#: cp/decl.c:8524
+#: cp/decl.c:8545
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as a `virtual' %s"
 msgid "%qD declared as a %<virtual%> field"
 msgstr "'%D' erklæret som 'virtual' %s"
 
-#: cp/decl.c:8526
+#: cp/decl.c:8547
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as an `inline' %s"
 msgid "%qD declared as an %<inline%> field"
@@ -46219,60 +46266,60 @@
 msgstr "'%D' erklæret som 'inline' %s"
 
 # %s bliver omsat til typen
-#: cp/decl.c:8528
+#: cp/decl.c:8549
 #, fuzzy, gcc-internal-format
 #| msgid "`const' and `volatile' function specifiers on `%D' invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "'const'- og 'volatile'-funktionsangivelser til '%D' er ugyldigt i erklæring af %s"
 
-#: cp/decl.c:8535
+#: cp/decl.c:8556
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as a friend"
 msgid "%q+D declared as a friend"
 msgstr "'%D' er erklæret som en ven"
 
-#: cp/decl.c:8542
+#: cp/decl.c:8563
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared with an exception specification"
 msgid "%q+D declared with an exception specification"
 msgstr "'%D' erklæret med en undtagelsesspecifikation"
 
-#: cp/decl.c:8574
+#: cp/decl.c:8595
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' not in a namespace surrounding `%D'"
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "erklæring af '%D' er ikke i et navnerum der omgiver '%D'"
 
-#: cp/decl.c:8614
+#: cp/decl.c:8635
 #, fuzzy, gcc-internal-format
 #| msgid "static member function `%#D' declared with type qualifiers"
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "statisk medlemsfunktion '%#D' erklæret med typemodifikationer"
 
-#: cp/decl.c:8624
+#: cp/decl.c:8645
 #, fuzzy, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr "'%D' er erklæret som en ven"
 
-#: cp/decl.c:8630
+#: cp/decl.c:8651
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%D' declared void"
 msgid "concept %q#D declared with a deduced return type"
 msgstr "parameteren '%D' erklæret void"
 
-#: cp/decl.c:8632
+#: cp/decl.c:8653
 #, fuzzy, gcc-internal-format
 #| msgid "Java method '%D' has non-Java return type `%T'"
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "Java-metoden '%D' har har en returtype '%T' som ikke er fra Java"
 
-#: cp/decl.c:8703
+#: cp/decl.c:8724
 #, fuzzy, gcc-internal-format
 #| msgid "node is alias but not definition"
 msgid "concept %qD has no definition"
 msgstr "node er alias men ikke definition"
 
-#: cp/decl.c:8772
+#: cp/decl.c:8793
 #, fuzzy, gcc-internal-format
 #| msgid "defining explicit specialization `%D' in friend declaration"
 msgid "defining explicit specialization %qD in friend declaration"
@@ -46279,797 +46326,797 @@
 msgstr "definering af eksplicit specialisering '%D' i friend-erklæring"
 
 #. Something like `template <class T> friend void f<T>()'.
-#: cp/decl.c:8782
+#: cp/decl.c:8803
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of template-id `%D' in declaration of primary template"
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "ugyldig brug af skabelons-id '%D' i erklæring af primær skabelon"
 
-#: cp/decl.c:8800
+#: cp/decl.c:8821
 #, fuzzy, gcc-internal-format
 #| msgid "default arguments are not allowed in declaration of friend template specialization `%D'"
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "standardparametre er ikke tilladt i erklæring af venneskabelonsspecialisering '%D'"
 
-#: cp/decl.c:8808
+#: cp/decl.c:8829
 #, fuzzy, gcc-internal-format
 #| msgid "`inline' is not allowed in declaration of friend template specialization `%D'"
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "'inline' er ikke tilladt i erklæring venneskabelonsspecialisering '%D'"
 
-#: cp/decl.c:8857
+#: cp/decl.c:8878
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare `::main' to be a template"
 msgid "cannot declare %<::main%> to be a template"
 msgstr "kan ikke erklære '::main' som en skabelon"
 
-#: cp/decl.c:8859
+#: cp/decl.c:8880
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare `::main' to be inline"
 msgid "cannot declare %<::main%> to be inline"
 msgstr "kan ikke erklære '::main' som indlejret"
 
-#: cp/decl.c:8861
+#: cp/decl.c:8882
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare `::main' to be inline"
 msgid "cannot declare %<::main%> to be %<constexpr%>"
 msgstr "kan ikke erklære '::main' som indlejret"
 
-#: cp/decl.c:8863
+#: cp/decl.c:8884
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare `::main' to be static"
 msgid "cannot declare %<::main%> to be static"
 msgstr "kan ikke erklære '::main' som statisk"
 
-#: cp/decl.c:8920
+#: cp/decl.c:8941
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function `%D' cannot have `%T' method qualifier"
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "%smedlemsfunktion '%D' kan ikke have metodemodifikationen '%T'"
 
-#: cp/decl.c:8921
+#: cp/decl.c:8942
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function `%D' cannot have `%T' method qualifier"
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "%smedlemsfunktion '%D' kan ikke have metodemodifikationen '%T'"
 
-#: cp/decl.c:8929
+#: cp/decl.c:8950
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function `%D' cannot have `%T' method qualifier"
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "%smedlemsfunktion '%D' kan ikke have metodemodifikationen '%T'"
 
-#: cp/decl.c:8930
+#: cp/decl.c:8951
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function `%D' cannot have `%T' method qualifier"
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "%smedlemsfunktion '%D' kan ikke have metodemodifikationen '%T'"
 
-#: cp/decl.c:8940
+#: cp/decl.c:8961
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %D after instantiation"
 msgid "deduction guide %qD must be declared at namespace scope"
 msgstr "specialisering af '%D' efter instantiering"
 
-#: cp/decl.c:8946
+#: cp/decl.c:8967
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' as non-function"
 msgid "deduction guide %qD must not have a function body"
 msgstr "erklæring af '%D' som ikke-funktion"
 
-#: cp/decl.c:8959
+#: cp/decl.c:8980
 #, fuzzy, gcc-internal-format
 #| msgid "template with C linkage"
 msgid "literal operator with C linkage"
 msgstr "skabelon med C-kædning"
 
-#: cp/decl.c:8969
+#: cp/decl.c:8990
 #, fuzzy, gcc-internal-format
 #| msgid "#%s with invalid argument"
 msgid "%qD has invalid argument list"
 msgstr "#%s med ugyldig parameter"
 
-#: cp/decl.c:8977
+#: cp/decl.c:8998
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:8983
+#: cp/decl.c:9004
 #, gcc-internal-format
 msgid "floating point suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:8991
+#: cp/decl.c:9012
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/decl.c:8996
+#: cp/decl.c:9017
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must be a nonstatic member function"
 msgid "%qD must be a non-member function"
 msgstr "'%D' skal være en ikke-statisk medlemsfunktion"
 
-#: cp/decl.c:9076
+#: cp/decl.c:9097
 #, fuzzy, gcc-internal-format
 #| msgid "`main' must return `int'"
 msgid "%<::main%> must return %<int%>"
 msgstr "'main' skal returnere typen 'int'"
 
-#: cp/decl.c:9116
+#: cp/decl.c:9137
 #, fuzzy, gcc-internal-format
 #| msgid "definition of implicitly-declared `%D'"
 msgid "definition of implicitly-declared %qD"
 msgstr "definition af underforstået-erklæret '%D'"
 
-#: cp/decl.c:9121
+#: cp/decl.c:9142
 #, fuzzy, gcc-internal-format
 #| msgid "definition of implicitly-declared `%D'"
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "definition af underforstået-erklæret '%D'"
 
-#: cp/decl.c:9123
+#: cp/decl.c:9144
 #, fuzzy, gcc-internal-format
 #| msgid "`%#D' previously defined here"
 msgid "%q#D explicitly defaulted here"
 msgstr "'%#D' tidligere defineret her"
 
-#: cp/decl.c:9140
+#: cp/decl.c:9161
 #, fuzzy, gcc-internal-format
 #| msgid "no `%#D' member function declared in class `%T'"
 msgid "no %q#D member function declared in class %qT"
 msgstr "ingen medlemsfunktion '%#D' erklæret i klassen '%T'"
 
-#: cp/decl.c:9329
+#: cp/decl.c:9350
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare `::main' to be a template"
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "kan ikke erklære '::main' som en skabelon"
 
-#: cp/decl.c:9337
+#: cp/decl.c:9358
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be `%s'"
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "destruktionsfunktioner må ikke være '%s'"
 
-#: cp/decl.c:9344
+#: cp/decl.c:9365
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.c:9464
+#: cp/decl.c:9485
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type `%T'"
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "ugyldig tildeling af startværdi i klasse til statisk datamedlem af en ikke-heltalstype '%T'"
 
-#: cp/decl.c:9468
+#: cp/decl.c:9489
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type `%T'"
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "ugyldig tildeling af startværdi i klasse til statisk datamedlem af en ikke-heltalstype '%T'"
 
-#: cp/decl.c:9472
+#: cp/decl.c:9493
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type `%T'"
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "ugyldig tildeling af startværdi i klasse til statisk datamedlem af en ikke-heltalstype '%T'"
 
-#: cp/decl.c:9486
+#: cp/decl.c:9507
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type `%T'"
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "ugyldig tildeling af startværdi i klasse til statisk datamedlem af en ikke-heltalstype '%T'"
 
-#: cp/decl.c:9493
+#: cp/decl.c:9514
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids in-class initialization of non-const static member `%D'"
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ISO C++ forbyder tildeling af startværdi i klasse til ikke-konstant statisk medlem '%D'"
 
-#: cp/decl.c:9498
+#: cp/decl.c:9519
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids initialization of member constant `%D' of non-integral type `%T'"
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO C++ forbyder tildeling af startværdi til medlemskonstant '%D' af en ikke-heltallig type"
 
-#: cp/decl.c:9598
+#: cp/decl.c:9619
 #, fuzzy, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "størrelsen af tabellen '%D' er ikke af en heltalstype"
 
-#: cp/decl.c:9600
+#: cp/decl.c:9621
 #, fuzzy, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "størrelsen af tabel er ikke af en heltalstype"
 
-#: cp/decl.c:9630 cp/decl.c:9680
+#: cp/decl.c:9651 cp/decl.c:9701
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "størrelsen af tabel er ikke af et heltalligt konstantudtryk"
 
-#: cp/decl.c:9646
+#: cp/decl.c:9667
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%D' is negative"
 msgid "size of array %qD is negative"
 msgstr "størrelsen af tabellen '%D' er negativ"
 
-#: cp/decl.c:9648 cp/init.c:3651
+#: cp/decl.c:9669 cp/init.c:3667
 #, gcc-internal-format
 msgid "size of array is negative"
 msgstr "størrelsen af tabel er negativ"
 
-#: cp/decl.c:9662
+#: cp/decl.c:9683
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids zero-size array `%D'"
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C++ forbyder tabellen '%D' med størrelsen nul"
 
-#: cp/decl.c:9664
+#: cp/decl.c:9685
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++ forbyder tabel med størrelsen nul"
 
-#: cp/decl.c:9677
+#: cp/decl.c:9698
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%D' is not an integral constant-expression"
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/decl.c:9686
+#: cp/decl.c:9707
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids variable-size array `%D'"
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++ forbyder tabellen '%D' med variabel størrelse"
 
-#: cp/decl.c:9688
+#: cp/decl.c:9709
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids variable-size array"
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++ forbyder tabel med variabel størrelse"
 
-#: cp/decl.c:9694
+#: cp/decl.c:9715
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr ""
 
-#: cp/decl.c:9697
+#: cp/decl.c:9718
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr ""
 
-#: cp/decl.c:9746
+#: cp/decl.c:9767
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "tabeldimension for stor"
 
-#: cp/decl.c:9799
+#: cp/decl.c:9820
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as a friend"
 msgid "%qD declared as array of %qT"
 msgstr "'%D' er erklæret som en ven"
 
-#: cp/decl.c:9809
+#: cp/decl.c:9830
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' as array of voids"
 msgid "declaration of %qD as array of void"
 msgstr "'%s' erklæret som en tabel af void"
 
-#: cp/decl.c:9811
+#: cp/decl.c:9832
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of `%T'"
 msgid "creating array of void"
 msgstr "opretter tabel af '%T'"
 
-#: cp/decl.c:9816
+#: cp/decl.c:9837
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' as array of functions"
 msgid "declaration of %qD as array of functions"
 msgstr "'%s' erklæret som en tabel af funktioner"
 
-#: cp/decl.c:9818
+#: cp/decl.c:9839
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' as array of functions"
 msgid "creating array of functions"
 msgstr "'%s' erklæret som en tabel af funktioner"
 
-#: cp/decl.c:9823
+#: cp/decl.c:9844
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' as array of functions"
 msgid "declaration of %qD as array of references"
 msgstr "'%s' erklæret som en tabel af funktioner"
 
-#: cp/decl.c:9825
+#: cp/decl.c:9846
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of `%T'"
 msgid "creating array of references"
 msgstr "opretter tabel af '%T'"
 
-#: cp/decl.c:9830
+#: cp/decl.c:9851
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' as array of functions"
 msgid "declaration of %qD as array of function members"
 msgstr "'%s' erklæret som en tabel af funktioner"
 
-#: cp/decl.c:9832
+#: cp/decl.c:9853
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' as array of functions"
 msgid "creating array of function members"
 msgstr "'%s' erklæret som en tabel af funktioner"
 
-#: cp/decl.c:9846
+#: cp/decl.c:9867
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' as multidimensional array must have bounds for all dimensions except the first"
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "erklæring af '%D' som flerdimensional tabel skal have grænser for alle dimensioner pånær den første"
 
-#: cp/decl.c:9850
+#: cp/decl.c:9871
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "flerdimensional tabel skal have grænser for alle dimensioner pånær den første"
 
-#: cp/decl.c:9909
+#: cp/decl.c:9930
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "angivelse af returneringstypen til konstruktionsfunktion er ugyldigt"
 
-#: cp/decl.c:9912
+#: cp/decl.c:9933
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of `operator %T'"
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "modifikationer er ikke tilladt i erklæring af 'operator %T'"
 
-#: cp/decl.c:9922
+#: cp/decl.c:9943
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "angivelse af returneringstypen til destruktionsfunktion er ugyldigt"
 
-#: cp/decl.c:9925
+#: cp/decl.c:9946
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of `operator %T'"
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "modifikationer er ikke tilladt i erklæring af 'operator %T'"
 
-#: cp/decl.c:9937
+#: cp/decl.c:9958
 #, fuzzy, gcc-internal-format
 #| msgid "return type specified for `operator %T'"
 msgid "return type specified for %<operator %T%>"
 msgstr "returtype angivet for 'operator %T'"
 
-#: cp/decl.c:9940
+#: cp/decl.c:9961
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of `operator %T'"
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "modifikationer er ikke tilladt i erklæring af 'operator %T'"
 
-#: cp/decl.c:9948
+#: cp/decl.c:9969
 #, fuzzy, gcc-internal-format
 #| msgid "return type specification for destructor invalid"
 msgid "return type specified for deduction guide"
 msgstr "angivelse af returneringstypen til destruktionsfunktion er ugyldigt"
 
-#: cp/decl.c:9951
+#: cp/decl.c:9972
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of `operator %T'"
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "modifikationer er ikke tilladt i erklæring af 'operator %T'"
 
-#: cp/decl.c:9955
+#: cp/decl.c:9976
 #, fuzzy, gcc-internal-format
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "modstridende erklæringer af '%s'"
 
-#: cp/decl.c:9964
+#: cp/decl.c:9985
 #, fuzzy, gcc-internal-format
 msgid "decl-specifier in declaration of deduction guide"
 msgstr "modstridende erklæringer af '%s'"
 
-#: cp/decl.c:9985
+#: cp/decl.c:10006
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "unavngiven variabel eller felt erklæret void"
 
-#: cp/decl.c:9992
+#: cp/decl.c:10013
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "variabel eller felt erklæret void"
 
-#: cp/decl.c:10007
+#: cp/decl.c:10028
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `inline' invalid for function `%s' declared out of global scope"
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "lagringsklassen 'inline' er ugyldig for funktionen '%s' erklæret uden for det globale virkefelt"
 
-#: cp/decl.c:10013
+#: cp/decl.c:10034
 #, gcc-internal-format
 msgid "inline variables are only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/decl.c:10268
+#: cp/decl.c:10292
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member `%D'"
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "ugyldig brug af medlemmet '%D'"
 
-#: cp/decl.c:10271 cp/decl.c:10291
+#: cp/decl.c:10295 cp/decl.c:10315
 #, fuzzy, gcc-internal-format
 #| msgid "invalid definition of qualified type `%T'"
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "ugyldig definition af modificeret type '%T'"
 
-#: cp/decl.c:10274
+#: cp/decl.c:10298
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member `%D'"
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "ugyldig brug af medlemmet '%D'"
 
-#: cp/decl.c:10283
+#: cp/decl.c:10307
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a class or namespace"
 msgid "%q#T is not a class or a namespace"
 msgstr "'%T' er ikke en klasse eller et navnerum"
 
-#: cp/decl.c:10305 cp/decl.c:10398 cp/decl.c:10407 cp/decl.c:11970
+#: cp/decl.c:10329 cp/decl.c:10422 cp/decl.c:10431 cp/decl.c:11994
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' as non-function"
 msgid "declaration of %qD as non-function"
 msgstr "erklæring af '%D' som ikke-funktion"
 
-#: cp/decl.c:10311
+#: cp/decl.c:10335
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' as non-function"
 msgid "declaration of %qD as non-member"
 msgstr "erklæring af '%D' som ikke-funktion"
 
-#: cp/decl.c:10339
+#: cp/decl.c:10363
 #, fuzzy, gcc-internal-format
 #| msgid "declarator-id missing; using reserved word `%D'"
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "erklærer-id mangler; bruger reserveret ord '%D'"
 
-#: cp/decl.c:10390
+#: cp/decl.c:10414
 #, fuzzy, gcc-internal-format
 #| msgid "function definition declared `register'"
 msgid "function definition does not declare parameters"
 msgstr "'register' er påhæftet funktionsdefinitionen"
 
-#: cp/decl.c:10415
+#: cp/decl.c:10439
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' as %s"
 msgid "declaration of %qD as %<typedef%>"
 msgstr "erklæring af '%D' som %s"
 
-#: cp/decl.c:10420
+#: cp/decl.c:10444
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D' shadows a parameter"
 msgid "declaration of %qD as parameter"
 msgstr "erklæring af '%#D' skygger for en parameter"
 
-#: cp/decl.c:10454
+#: cp/decl.c:10478
 #, fuzzy, gcc-internal-format
 msgid "%<concept%> cannot appear in a typedef declaration"
 msgstr "navnerum '%D' ikke tilladt i using-erklæring"
 
-#: cp/decl.c:10460
+#: cp/decl.c:10484
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgstr "navnerum '%D' ikke tilladt i using-erklæring"
 
-#: cp/decl.c:10468
+#: cp/decl.c:10492
 #, fuzzy, gcc-internal-format
 #| msgid "two or more data types in declaration of `%s'"
 msgid "two or more data types in declaration of %qs"
 msgstr "mere end én datatype i erklæringen af '%s'"
 
-#: cp/decl.c:10474
+#: cp/decl.c:10498
 #, fuzzy, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr "modstridende erklæringer af '%s'"
 
-#: cp/decl.c:10515
+#: cp/decl.c:10539
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain `complex' meaning `double complex'"
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C understøtter ikke at blot 'complex' betyder 'double complex'"
 
-#: cp/decl.c:10564 cp/decl.c:10567 cp/decl.c:10570
+#: cp/decl.c:10588 cp/decl.c:10591 cp/decl.c:10594
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids declaration of `%s' with no type"
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ forbyder erklæring af '%s' uden en type"
 
-#: cp/decl.c:10586
+#: cp/decl.c:10610
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_trap not supported by this target"
 msgid "%<__int%d%> is not supported by this target"
 msgstr "__builtin_trap understøttes ikke på denne målarkitektur"
 
-#: cp/decl.c:10592
+#: cp/decl.c:10616
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not support `long long'"
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ understøtter ikke 'long long'"
 
-#: cp/decl.c:10614 cp/decl.c:10634
+#: cp/decl.c:10638 cp/decl.c:10658
 #, fuzzy, gcc-internal-format
 #| msgid "short, signed or unsigned invalid for `%s'"
 msgid "%<signed%> or %<unsigned%> invalid for %qs"
 msgstr "short, signed eller unsigned er ugyldig for '%s'"
 
-#: cp/decl.c:10616
+#: cp/decl.c:10640
 #, fuzzy, gcc-internal-format
 #| msgid "signed and unsigned given together for `%s'"
 msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgstr "signed og unsigned er begge angivet for '%s'"
 
-#: cp/decl.c:10618
+#: cp/decl.c:10642
 #, fuzzy, gcc-internal-format
 #| msgid "complex invalid for `%s'"
 msgid "%<long long%> invalid for %qs"
 msgstr "complex ugyldig for '%s'"
 
-#: cp/decl.c:10620
+#: cp/decl.c:10644
 #, fuzzy, gcc-internal-format
 #| msgid "complex invalid for `%s'"
 msgid "%<long%> invalid for %qs"
 msgstr "complex ugyldig for '%s'"
 
-#: cp/decl.c:10622
+#: cp/decl.c:10646
 #, fuzzy, gcc-internal-format
 #| msgid "complex invalid for `%s'"
 msgid "%<short%> invalid for %qs"
 msgstr "complex ugyldig for '%s'"
 
-#: cp/decl.c:10624
+#: cp/decl.c:10648
 #, fuzzy, gcc-internal-format
 #| msgid "long, short, signed or unsigned invalid for `%s'"
 msgid "%<long%> or %<short%> invalid for %qs"
 msgstr "long, short, signed og unsigned er ugyldige for '%s'"
 
-#: cp/decl.c:10626
+#: cp/decl.c:10650
 #, gcc-internal-format
 msgid "%<long%>, %<int%>, %<short%>, or %<char%> invalid for %qs"
 msgstr ""
 
-#: cp/decl.c:10628
+#: cp/decl.c:10652
 #, fuzzy, gcc-internal-format
 #| msgid "long or short specified with char for `%s'"
 msgid "%<long%> or %<short%> specified with char for %qs"
 msgstr "long eller short angivet samtidig med char for '%s'"
 
-#: cp/decl.c:10630
+#: cp/decl.c:10654
 #, fuzzy, gcc-internal-format
 #| msgid "long and short specified together for `%s'"
 msgid "%<long%> and %<short%> specified together for %qs"
 msgstr "long og short er begge angivet for '%s'"
 
-#: cp/decl.c:10636
+#: cp/decl.c:10660
 #, fuzzy, gcc-internal-format
 #| msgid "short, signed or unsigned invalid for `%s'"
 msgid "%<short%> or %<long%> invalid for %qs"
 msgstr "short, signed eller unsigned er ugyldig for '%s'"
 
-#: cp/decl.c:10644
+#: cp/decl.c:10668
 #, fuzzy, gcc-internal-format
 #| msgid "long, short, signed or unsigned used invalidly for `%s'"
 msgid "long, short, signed or unsigned used invalidly for %qs"
 msgstr "long, short, signed og unsigned er benyttet på ugyldig vis for '%s'"
 
-#: cp/decl.c:10712
+#: cp/decl.c:10736
 #, fuzzy, gcc-internal-format
 #| msgid "complex invalid for `%s'"
 msgid "complex invalid for %qs"
 msgstr "complex ugyldig for '%s'"
 
-#: cp/decl.c:10751
+#: cp/decl.c:10775
 #, gcc-internal-format
 msgid "template placeholder type %qT must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.c:10769
+#: cp/decl.c:10793
 #, fuzzy, gcc-internal-format
 #| msgid "member `%D' cannot be declared both virtual and static"
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "medlemmet '%D' kan ikke afklæres både virtual og static"
 
-#: cp/decl.c:10775
+#: cp/decl.c:10799
 #, fuzzy, gcc-internal-format
 #| msgid "member `%D' cannot be declared both virtual and static"
 msgid "member %qD cannot be declared both %<virtual%> and %<constexpr%>"
 msgstr "medlemmet '%D' kan ikke afklæres både virtual og static"
 
-#: cp/decl.c:10785
+#: cp/decl.c:10809
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "typedef-erklæringer er ugyldig i parametererklæringer"
 
-#: cp/decl.c:10790
+#: cp/decl.c:10814
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter `%s'"
 msgid "storage class specified for template parameter %qs"
 msgstr "lagringsklasse angivet for parameter '%s'"
 
-#: cp/decl.c:10796
+#: cp/decl.c:10820
 #, gcc-internal-format
 msgid "storage class specifiers invalid in parameter declarations"
 msgstr "lagringsklasseanvisninger er ugyldige i parametererklæringer"
 
-#: cp/decl.c:10800
+#: cp/decl.c:10824
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "a parameter cannot be declared %<concept%>"
 msgstr "skabelonsparametre kan ikke være venner"
 
-#: cp/decl.c:10805
+#: cp/decl.c:10829
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "a parameter cannot be declared %<constexpr%>"
 msgstr "skabelonsparametre kan ikke være venner"
 
-#: cp/decl.c:10815
+#: cp/decl.c:10839
 #, fuzzy, gcc-internal-format
 #| msgid "virtual outside class declaration"
 msgid "%<virtual%> outside class declaration"
 msgstr "virtual angivet uden for klasseerklæring"
 
-#: cp/decl.c:10825
+#: cp/decl.c:10849
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "structured binding declaration cannot be %<inline%>"
 msgstr "konstruktionsfunktioner kan ikke erklæres virtual"
 
-#: cp/decl.c:10828
+#: cp/decl.c:10852
 #, fuzzy, gcc-internal-format
 #| msgid "function definition declared `typedef'"
 msgid "structured binding declaration cannot be %<typedef%>"
 msgstr "'typedef' er påhæftet funktionsdefinitionen"
 
-#: cp/decl.c:10830
+#: cp/decl.c:10854
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "structured binding declaration cannot be %<constexpr%>"
 msgstr "skabelonsparametre kan ikke være venner"
 
-#: cp/decl.c:10834
+#: cp/decl.c:10858
 #, fuzzy, gcc-internal-format
 #| msgid "forward declaration of `%#T'"
 msgid "structured binding declaration cannot be %qs"
 msgstr "forhåndserklæring af '%#T'"
 
-#: cp/decl.c:10839
+#: cp/decl.c:10863
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "structured binding declaration cannot be %<concept%>"
 msgstr "skabelonsparametre kan ikke være venner"
 
-#: cp/decl.c:10845
+#: cp/decl.c:10869
 #, fuzzy, gcc-internal-format
 #| msgid "function definition declared `register'"
 msgid "structured binding declaration cannot be %<register%>"
 msgstr "'register' er påhæftet funktionsdefinitionen"
 
-#: cp/decl.c:10849
+#: cp/decl.c:10873
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "structured binding declaration cannot be %<static%>"
 msgstr "konstruktionsfunktioner kan ikke erklæres virtual"
 
-#: cp/decl.c:10853
+#: cp/decl.c:10877
 #, fuzzy, gcc-internal-format
 #| msgid "function `%s' cannot be declared `mutable'"
 msgid "structured binding declaration cannot be %<extern%>"
 msgstr "funktionen '%s' kan ikke erklæres 'mutable'"
 
-#: cp/decl.c:10857
+#: cp/decl.c:10881
 #, fuzzy, gcc-internal-format
 #| msgid "const `%s' cannot be declared `mutable'"
 msgid "structured binding declaration cannot be %<mutable%>"
 msgstr "const '%s' kan ikke erklæres 'mutable'"
 
-#: cp/decl.c:10861
+#: cp/decl.c:10885
 #, fuzzy, gcc-internal-format
 #| msgid "function `%s' cannot be declared `mutable'"
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr "funktionen '%s' kan ikke erklæres 'mutable'"
 
-#: cp/decl.c:10872
+#: cp/decl.c:10896
 #, fuzzy, gcc-internal-format
 #| msgid "function `%D' cannot be declared friend"
 msgid "structured binding declaration cannot have type %qT"
 msgstr "funktionen '%D' kan ikke erklæres friend"
 
-#: cp/decl.c:10875
+#: cp/decl.c:10899
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10906
+#: cp/decl.c:10930
 #, fuzzy, gcc-internal-format
 #| msgid "multiple storage classes in declaration of `%s'"
 msgid "multiple storage classes in declaration of %qs"
 msgstr "flere lagringsklasser optræder i erklæringen af '%s'"
 
-#: cp/decl.c:10929
+#: cp/decl.c:10953
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for %s `%s'"
 msgid "storage class specified for %qs"
 msgstr "lagringsklasse angivet for %s '%s'"
 
-#: cp/decl.c:10933
+#: cp/decl.c:10957
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter `%s'"
 msgid "storage class specified for parameter %qs"
 msgstr "lagringsklasse angivet for parameter '%s'"
 
-#: cp/decl.c:10946
+#: cp/decl.c:10970
 #, fuzzy, gcc-internal-format
 #| msgid "nested function `%s' declared `extern'"
 msgid "nested function %qs declared %<extern%>"
 msgstr "indlejret funktion '%s' er erklæret 'extern'"
 
-#: cp/decl.c:10950
+#: cp/decl.c:10974
 #, fuzzy, gcc-internal-format
 #| msgid "top-level declaration of `%s' specifies `auto'"
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "erklæring af '%s' på øverste niveau angiver 'auto'"
 
-#: cp/decl.c:10957
+#: cp/decl.c:10981
 #, fuzzy, gcc-internal-format
 #| msgid "function-scope `%s' implicitly auto and declared `__thread'"
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "'%s' i funktionsvirkefelt underforstået auto og erklæret '__thread'"
 
-#: cp/decl.c:10969
+#: cp/decl.c:10993
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "lagringsklasseanvisninger er ugyldige i vennefunktionserklæringer"
 
-#: cp/decl.c:11050
+#: cp/decl.c:11074
 #, fuzzy, gcc-internal-format
 #| msgid "multiple storage classes in declaration of `%s'"
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "flere lagringsklasser optræder i erklæringen af '%s'"
 
-#: cp/decl.c:11098
+#: cp/decl.c:11122
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute requires an integer constant argument"
 msgid "requires-clause on return type"
 msgstr "egenskaben '%s' kræver en heltalskonstant som parameter"
 
-#: cp/decl.c:11118
+#: cp/decl.c:11142
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.c:11121
+#: cp/decl.c:11145
 #, gcc-internal-format
 msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/decl.c:11127
+#: cp/decl.c:11151
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual function cannot have deduced return type"
 msgstr "en virtuel funktion kan ikke erklæres som friend"
 
-#: cp/decl.c:11134
+#: cp/decl.c:11158
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:11147
+#: cp/decl.c:11171
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "deduced class type %qD in function return type"
 msgstr "typemodifikationer ignoreret i funktionsreturtypen"
 
-#: cp/decl.c:11156
+#: cp/decl.c:11180
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "deduction guide for %qT must have trailing return type"
 msgstr "en virtuel funktion kan ikke erklæres som friend"
 
-#: cp/decl.c:11169
+#: cp/decl.c:11193
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
@@ -47076,63 +47123,63 @@
 
 #. Not using maybe_warn_cpp0x because this should
 #. always be an error.
-#: cp/decl.c:11180
+#: cp/decl.c:11204
 #, gcc-internal-format
 msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/decl.c:11183
+#: cp/decl.c:11207
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.c:11212
+#: cp/decl.c:11236
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' declared as function returning a function"
 msgid "%qs declared as function returning a function"
 msgstr "'%s' er erklæret som en funktion der returnerer en funktion"
 
-#: cp/decl.c:11218
+#: cp/decl.c:11242
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' declared as function returning an array"
 msgid "%qs declared as function returning an array"
 msgstr "'%s' er erklæret som en funktion der returnerer en tabel"
 
-#: cp/decl.c:11247
+#: cp/decl.c:11271
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "destruktionsfunktionen kan ikke være en statisk medlemsfunktion"
 
-#: cp/decl.c:11248
+#: cp/decl.c:11272
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "konstruktionsfunktionen kan ikke være en statisk medlemsfunktion"
 
-#: cp/decl.c:11252
+#: cp/decl.c:11276
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be `%s'"
 msgid "destructors may not be cv-qualified"
 msgstr "destruktionsfunktioner må ikke være '%s'"
 
-#: cp/decl.c:11253
+#: cp/decl.c:11277
 #, fuzzy, gcc-internal-format
 #| msgid "constructors may not be `%s'"
 msgid "constructors may not be cv-qualified"
 msgstr "konstruktionsfunktioner må ikke være '%s'"
 
-#: cp/decl.c:11261
+#: cp/decl.c:11285
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be `%s'"
 msgid "destructors may not be ref-qualified"
 msgstr "destruktionsfunktioner må ikke være '%s'"
 
-#: cp/decl.c:11262
+#: cp/decl.c:11286
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be `%s'"
 msgid "constructors may not be ref-qualified"
 msgstr "destruktionsfunktioner må ikke være '%s'"
 
-#: cp/decl.c:11280
+#: cp/decl.c:11304
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructors cannot be declared %<virtual%>"
@@ -47139,277 +47186,277 @@
 msgstr "konstruktionsfunktioner kan ikke erklæres virtual"
 
 #. Cannot be both friend and virtual.
-#: cp/decl.c:11295
+#: cp/decl.c:11319
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "en virtuel funktion kan ikke erklæres som friend"
 
-#: cp/decl.c:11299
+#: cp/decl.c:11323
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "friend-erklæringen er ikke i klassedefinitionen"
 
-#: cp/decl.c:11301
+#: cp/decl.c:11325
 #, fuzzy, gcc-internal-format
 #| msgid "can't define friend function `%s' in a local class definition"
 msgid "can%'t define friend function %qs in a local class definition"
 msgstr "kan ikke definere vennefunktion '%s' i en lokal klassedefinition"
 
-#: cp/decl.c:11313
+#: cp/decl.c:11337
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "a conversion function cannot have a trailing return type"
 msgstr "en virtuel funktion kan ikke erklæres som friend"
 
-#: cp/decl.c:11339
+#: cp/decl.c:11363
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "destruktionsfunktioner må ikke have parametre"
 
-#: cp/decl.c:11379
+#: cp/decl.c:11403
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to `%#T'"
 msgid "cannot declare pointer to %q#T"
 msgstr "kan ikke erklære henvisning til '%#T'"
 
-#: cp/decl.c:11392 cp/decl.c:11399
+#: cp/decl.c:11416 cp/decl.c:11423
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to `%#T'"
 msgid "cannot declare reference to %q#T"
 msgstr "kan ikke erklære reference til '%#T'"
 
-#: cp/decl.c:11401
+#: cp/decl.c:11425
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to `%#T' member"
 msgid "cannot declare pointer to %q#T member"
 msgstr "kan ikke erklære henvisning til medlemmet '%#T'"
 
-#: cp/decl.c:11430
+#: cp/decl.c:11454
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare references to references"
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "kan ikke erklære referencer til referencer"
 
-#: cp/decl.c:11431
+#: cp/decl.c:11455
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare bit-field `%D' with function type"
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "kan ikke erklære bitfelt '%D' med funktionstype"
 
-#: cp/decl.c:11504
+#: cp/decl.c:11528
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.c:11574
+#: cp/decl.c:11598
 #, fuzzy, gcc-internal-format
 #| msgid "template-id `%D' used as a declarator"
 msgid "template-id %qD used as a declarator"
 msgstr "skabelons-id '%D' benyttet som erklærer"
 
-#: cp/decl.c:11599
+#: cp/decl.c:11623
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "medlemsfunktioner er underforstået venner af deres klasse"
 
-#: cp/decl.c:11605
+#: cp/decl.c:11629
 #, fuzzy, gcc-internal-format
 #| msgid "extra qualification `%T::' on member `%s' ignored"
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "ekstra modifikation '%T::' af medlemmet '%s' ignoreret"
 
-#: cp/decl.c:11635
+#: cp/decl.c:11659
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member function `%T::%s' within `%T'"
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "kan ikke erklære medlemsfunktion '%T::%s' inde i '%T'"
 
-#: cp/decl.c:11637
+#: cp/decl.c:11661
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member function `%T::%s' within `%T'"
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "kan ikke erklære medlemsfunktion '%T::%s' inde i '%T'"
 
-#: cp/decl.c:11645
+#: cp/decl.c:11669
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member `%T::%s' within `%T'"
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "kan ikke erklære medlem '%T::%s' inde i '%T'"
 
-#: cp/decl.c:11685
+#: cp/decl.c:11709
 #, fuzzy, gcc-internal-format
 #| msgid "data member `%D' cannot be a member template"
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "datamedlem '%D' kan ikke være en medlemsskabelon"
 
-#: cp/decl.c:11693
+#: cp/decl.c:11717
 #, fuzzy, gcc-internal-format
 #| msgid "data member may not have variably modified type `%T'"
 msgid "data member may not have variably modified type %qT"
 msgstr "datamedlem må ikke have variabelt ændret type '%T'"
 
-#: cp/decl.c:11695
+#: cp/decl.c:11719
 #, fuzzy, gcc-internal-format
 #| msgid "parameter may not have variably modified type `%T'"
 msgid "parameter may not have variably modified type %qT"
 msgstr "parameter må ikke have variabelt ændret type '%T'"
 
-#: cp/decl.c:11706
+#: cp/decl.c:11730
 #, fuzzy, gcc-internal-format
 #| msgid "virtual outside class declaration"
 msgid "%<explicit%> outside class declaration"
 msgstr "virtual angivet uden for klasseerklæring"
 
-#: cp/decl.c:11709
+#: cp/decl.c:11733
 #, fuzzy, gcc-internal-format
 #| msgid "defining explicit specialization `%D' in friend declaration"
 msgid "%<explicit%> in friend declaration"
 msgstr "definering af eksplicit specialisering '%D' i friend-erklæring"
 
-#: cp/decl.c:11712
+#: cp/decl.c:11736
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be `explicit'"
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "kun erklæringer af konstruktionsfunktioner kan være 'explicit'"
 
-#: cp/decl.c:11721
+#: cp/decl.c:11745
 #, fuzzy, gcc-internal-format
 #| msgid "non-member `%s' cannot be declared `mutable'"
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "'%s' som ikke er medlem, kan ikke erklæres 'mutable'"
 
-#: cp/decl.c:11726
+#: cp/decl.c:11750
 #, fuzzy, gcc-internal-format
 #| msgid "non-object member `%s' cannot be declared `mutable'"
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "'%s' som ikke er objektmedlem, kan ikke erklæres 'mutable'"
 
-#: cp/decl.c:11732
+#: cp/decl.c:11756
 #, fuzzy, gcc-internal-format
 #| msgid "function `%s' cannot be declared `mutable'"
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "funktionen '%s' kan ikke erklæres 'mutable'"
 
-#: cp/decl.c:11737
+#: cp/decl.c:11761
 #, fuzzy, gcc-internal-format
 #| msgid "static `%s' cannot be declared `mutable'"
 msgid "static %qs cannot be declared %<mutable%>"
 msgstr "static '%s' kan ikke erklæres 'mutable'"
 
-#: cp/decl.c:11742
+#: cp/decl.c:11766
 #, fuzzy, gcc-internal-format
 #| msgid "const `%s' cannot be declared `mutable'"
 msgid "const %qs cannot be declared %<mutable%>"
 msgstr "const '%s' kan ikke erklæres 'mutable'"
 
-#: cp/decl.c:11747
+#: cp/decl.c:11771
 #, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "referencen %qs kan ikke erklæres %<mutable%>"
 
-#: cp/decl.c:11778
+#: cp/decl.c:11802
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "typedef erklæret %<auto%>"
 
-#: cp/decl.c:11783
+#: cp/decl.c:11807
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.c:11787
+#: cp/decl.c:11811
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "typedef-navn kan ikke være en indlejret-navn-specifikation"
 
-#: cp/decl.c:11813
+#: cp/decl.c:11837
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ISO C++ forbyder indlejret type %qD med samme navn som den omgivende klasse"
 
-#: cp/decl.c:11900
+#: cp/decl.c:11924
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "%<inline%> angivet for friend class-erklæring"
 
-#: cp/decl.c:11908
+#: cp/decl.c:11932
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "skabelonsparametre kan ikke være venner"
 
-#: cp/decl.c:11910
+#: cp/decl.c:11934
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "friend-erklæring kræver klasseangivelse, dvs. %<friend class %T::%D%>"
 
-#: cp/decl.c:11914
+#: cp/decl.c:11938
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "friend-erklæring kræver klasseangivelse, dvs. %<friend %#T%>"
 
-#: cp/decl.c:11927
+#: cp/decl.c:11951
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "forsøg på at gøre klassen %qT til ven af det globale virkningsfelt"
 
-#: cp/decl.c:11947
+#: cp/decl.c:11971
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "ugyldige modifikationer for ikke-medlemsfunktionstype"
 
-#: cp/decl.c:11951
+#: cp/decl.c:11975
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.c:11961
+#: cp/decl.c:11985
 #, fuzzy, gcc-internal-format
 #| msgid "abstract declarator `%T' used as declaration"
 msgid "abstract declarator %qT used as declaration"
 msgstr "abstrakt erklærer '%T' benyttet som erklæring"
 
-#: cp/decl.c:11976
+#: cp/decl.c:12000
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type `%T'"
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "ugyldig omtvingelse til funktionstypen '%T'"
 
-#: cp/decl.c:11995
+#: cp/decl.c:12019
 #, fuzzy, gcc-internal-format
 #| msgid "cannot use `::' in parameter declaration"
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "kan ikke bruge '::' i parametererklæring"
 
-#: cp/decl.c:12001
+#: cp/decl.c:12025
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "'%D' blev ikke erklæret i dette virkefelt"
 
-#: cp/decl.c:12003
+#: cp/decl.c:12027
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%D' declared void"
 msgid "parameter declared %<auto%>"
 msgstr "parameteren '%D' erklæret void"
 
-#: cp/decl.c:12052 cp/parser.c:3270
+#: cp/decl.c:12076 cp/parser.c:3270
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of template-name '%E' in a declarator"
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "ugyldig brug af skabelonsnavn '%E' i erklæring"
 
-#: cp/decl.c:12056
+#: cp/decl.c:12080
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' has no non-static data member named `%D'"
 msgid "non-static data member declared with placeholder %qT"
 msgstr "'%T' har intet ikke-statisk medlem ved navn '%D'"
 
-#: cp/decl.c:12080
+#: cp/decl.c:12104
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C90 understøtter ikke fleksible tabelmedlemmer"
 
-#: cp/decl.c:12083
+#: cp/decl.c:12107
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array members"
@@ -47416,187 +47463,187 @@
 msgstr "ISO C90 understøtter ikke fleksible tabelmedlemmer"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:12099
+#: cp/decl.c:12123
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `::'"
 msgid "invalid use of %<::%>"
 msgstr "ugyldig brug af '::'"
 
-#: cp/decl.c:12121
+#: cp/decl.c:12145
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of C function `%#D' conflicts with"
 msgid "declaration of function %qD in invalid context"
 msgstr "erklæring af C-funktionen '%#D' strider mod"
 
-#: cp/decl.c:12130
+#: cp/decl.c:12154
 #, fuzzy, gcc-internal-format
 #| msgid "function `%D' declared virtual inside a union"
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "funktionen '%D' erklæret virtual inden i en union"
 
-#: cp/decl.c:12139
+#: cp/decl.c:12163
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' cannot be declared virtual, since it is always static"
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "'%D' kan ikke erklæres virtual eftersom den altid er statisk"
 
-#: cp/decl.c:12153
+#: cp/decl.c:12177
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of `operator %T'"
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "modifikationer er ikke tilladt i erklæring af 'operator %T'"
 
-#: cp/decl.c:12160
+#: cp/decl.c:12184
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' shadows a member of `this'"
 msgid "declaration of %qD as member of %qT"
 msgstr "erklæring af '%s' skygger for et medlem af 'this'"
 
-#: cp/decl.c:12166
+#: cp/decl.c:12190
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be `%s'"
 msgid "a destructor cannot be %<concept%>"
 msgstr "destruktionsfunktioner må ikke være '%s'"
 
-#: cp/decl.c:12171
+#: cp/decl.c:12195
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be `%s'"
 msgid "a destructor cannot be %<constexpr%>"
 msgstr "destruktionsfunktioner må ikke være '%s'"
 
-#: cp/decl.c:12177
+#: cp/decl.c:12201
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of `operator %T'"
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "modifikationer er ikke tilladt i erklæring af 'operator %T'"
 
-#: cp/decl.c:12185
+#: cp/decl.c:12209
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be `%s'"
 msgid "a constructor cannot be %<concept%>"
 msgstr "destruktionsfunktioner må ikke være '%s'"
 
-#: cp/decl.c:12190
+#: cp/decl.c:12214
 #, fuzzy, gcc-internal-format
 #| msgid "constructor cannot be static member function"
 msgid "a concept cannot be a member function"
 msgstr "konstruktionsfunktionen kan ikke være en statisk medlemsfunktion"
 
-#: cp/decl.c:12199
+#: cp/decl.c:12223
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of implicitly-declared special member function"
 msgid "specialization of variable template %qD declared as function"
 msgstr "specialisering af underforstået erklæret speciel medlemsfunktion"
 
-#: cp/decl.c:12202
+#: cp/decl.c:12226
 #, fuzzy, gcc-internal-format
 #| msgid "variable or field declared void"
 msgid "variable template declared here"
 msgstr "variabel eller felt erklæret void"
 
-#: cp/decl.c:12257
+#: cp/decl.c:12281
 #, fuzzy, gcc-internal-format
 #| msgid "field `%D' has incomplete type"
 msgid "field %qD has incomplete type %qT"
 msgstr "feltet '%D' er af en ufuldstændig type"
 
-#: cp/decl.c:12262
+#: cp/decl.c:12286
 #, fuzzy, gcc-internal-format
 #| msgid "name `%T' has incomplete type"
 msgid "name %qT has incomplete type"
 msgstr "navnet '%T' er af en ufuldstændig type"
 
-#: cp/decl.c:12272
+#: cp/decl.c:12296
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is neither function nor member function; cannot be declared friend"
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "'%s' er hverken en almindelig funktion eller en medlemsfunktion; kan ikke erklæres som friend"
 
-#: cp/decl.c:12318
+#: cp/decl.c:12342
 #, fuzzy, gcc-internal-format
 #| msgid "static member `%D' declared `register'"
 msgid "static data member %qE declared %<concept%>"
 msgstr "statisk medlem '%D' erklæret 'register'"
 
-#: cp/decl.c:12322
+#: cp/decl.c:12346
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type `%T'"
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "ugyldig tildeling af startværdi i klasse til statisk datamedlem af en ikke-heltalstype '%T'"
 
-#: cp/decl.c:12350
+#: cp/decl.c:12374
 #, fuzzy, gcc-internal-format
 #| msgid "static member `%D' declared `register'"
 msgid "non-static data member %qE declared %<concept%>"
 msgstr "statisk medlem '%D' erklæret 'register'"
 
-#: cp/decl.c:12354
+#: cp/decl.c:12378
 #, fuzzy, gcc-internal-format
 #| msgid "static member `%D' declared `register'"
 msgid "non-static data member %qE declared %<constexpr%>"
 msgstr "statisk medlem '%D' erklæret 'register'"
 
-#: cp/decl.c:12409
+#: cp/decl.c:12433
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `auto' invalid for function `%s'"
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "lagringsklassen 'auto' er ugyldig for funktionen '%s'"
 
-#: cp/decl.c:12411
+#: cp/decl.c:12435
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `register' invalid for function `%s'"
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "lagringsklassen 'register' er ugyldig for funktionen '%s'"
 
-#: cp/decl.c:12415
+#: cp/decl.c:12439
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `__thread' invalid for function `%s'"
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "lagringsklassen '__thread' er ugyldig for funktionen '%s'"
 
-#: cp/decl.c:12418
+#: cp/decl.c:12442
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `__thread' invalid for function `%s'"
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "lagringsklassen '__thread' er ugyldig for funktionen '%s'"
 
-#: cp/decl.c:12423
+#: cp/decl.c:12447
 #, fuzzy, gcc-internal-format
 #| msgid "type specifier `%s' not allowed after struct or class"
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "typeangivelsen '%s' er ikke tilladt efter struct eller class"
 
-#: cp/decl.c:12434
+#: cp/decl.c:12458
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `inline' invalid for function `%s' declared out of global scope"
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "lagringsklassen 'inline' er ugyldig for funktionen '%s' erklæret uden for det globale virkefelt"
 
-#: cp/decl.c:12438
+#: cp/decl.c:12462
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `inline' invalid for function `%s' declared out of global scope"
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "lagringsklassen 'inline' er ugyldig for funktionen '%s' erklæret uden for det globale virkefelt"
 
-#: cp/decl.c:12446
+#: cp/decl.c:12470
 #, fuzzy, gcc-internal-format
 #| msgid "virtual non-class function `%s'"
 msgid "virtual non-class function %qs"
 msgstr "virtuel funktion '%s' tilhører ikke en klasse"
 
-#: cp/decl.c:12453
+#: cp/decl.c:12477
 #, fuzzy, gcc-internal-format
 #| msgid "method definition not in class context"
 msgid "%qs defined in a non-class scope"
 msgstr "metodedefinitionen optræder ikke i en klassekontekst"
 
-#: cp/decl.c:12454
+#: cp/decl.c:12478
 #, fuzzy, gcc-internal-format
 #| msgid "using-declaration for non-member at class scope"
 msgid "%qs declared in a non-class scope"
 msgstr "using-erklæring for ikke-medlem ved klassevirkefelt"
 
-#: cp/decl.c:12489
+#: cp/decl.c:12513
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member function `%D' to have static linkage"
 msgid "cannot declare member function %qD to have static linkage"
@@ -47604,90 +47651,90 @@
 
 #. 7.1.1: There can be no static function declarations within a
 #. block.
-#: cp/decl.c:12497
+#: cp/decl.c:12521
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "kan ikke erklære en funktion for static inden i en anden funktion"
 
-#: cp/decl.c:12533
+#: cp/decl.c:12557
 #, fuzzy, gcc-internal-format
 #| msgid "`static' may not be used when defining (as opposed to declaring) a static data member"
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "'static' må ikke bruges ved definering (i modsætning til erklæring) af et statisk datamedlem"
 
-#: cp/decl.c:12540
+#: cp/decl.c:12564
 #, fuzzy, gcc-internal-format
 #| msgid "static member `%D' declared `register'"
 msgid "static member %qD declared %<register%>"
 msgstr "statisk medlem '%D' erklæret 'register'"
 
-#: cp/decl.c:12546
+#: cp/decl.c:12570
 #, fuzzy, gcc-internal-format
 #| msgid "cannot explicitly declare member `%#D' to have extern linkage"
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "kan ikke eksplicit erklære medlemmet '%#D' til at have extern-kædning"
 
-#: cp/decl.c:12553
+#: cp/decl.c:12577
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D' outside of class is not definition"
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "erklæring af '%#D' uden for en klasse er ikke en definition"
 
-#: cp/decl.c:12574
+#: cp/decl.c:12598
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D' has `extern' and is initialized"
 msgid "declaration of %q#D has no initializer"
 msgstr "erklæringen af '%#D' indeholder 'extern' og variablen bliver tildelt en startværdi"
 
-#: cp/decl.c:12585
+#: cp/decl.c:12609
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' initialized and declared `extern'"
 msgid "%qs initialized and declared %<extern%>"
 msgstr "'%s' bliver tildelt en startværdi og er samtidig erklæret 'extern'"
 
-#: cp/decl.c:12589
+#: cp/decl.c:12613
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' has both `extern' and initializer"
 msgid "%qs has both %<extern%> and initializer"
 msgstr "'%s' er erklæret 'extern', men bliver tildelt en startværdi"
 
-#: cp/decl.c:12754
+#: cp/decl.c:12778
 #, fuzzy, gcc-internal-format
 #| msgid "default argument `%E' uses local variable `%D'"
 msgid "default argument %qE uses %qD"
 msgstr "standardparameter '%E' bruger lokal variabel '%D'"
 
-#: cp/decl.c:12757
+#: cp/decl.c:12781
 #, fuzzy, gcc-internal-format
 #| msgid "default argument `%E' uses local variable `%D'"
 msgid "default argument %qE uses local variable %qD"
 msgstr "standardparameter '%E' bruger lokal variabel '%D'"
 
-#: cp/decl.c:12841
+#: cp/decl.c:12865
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `virtual' in template declaration of `%#D'"
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "ugyldig brug af 'virtual' i skabelonserklæring af '%#D'"
 
-#: cp/decl.c:12845
+#: cp/decl.c:12869
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of template-name '%E' in a declarator"
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "ugyldig brug af skabelonsnavn '%E' i erklæring"
 
-#: cp/decl.c:12868
+#: cp/decl.c:12892
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%D' invalidly declared method type"
 msgid "parameter %qD invalidly declared method type"
 msgstr "parameteren '%D' er på ugyldig vis erklæret som af en medlemsfunktionstype"
 
-#: cp/decl.c:12895
+#: cp/decl.c:12919
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%D' includes %s to array of unknown bound `%T'"
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "parameteren '%D' inkluderer %s til tabel med ukendt grænse '%T'"
 
-#: cp/decl.c:12897
+#: cp/decl.c:12921
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%D' includes %s to array of unknown bound `%T'"
 msgid "parameter %qD includes reference to array of unknown bound %qT"
@@ -47708,36 +47755,36 @@
 #. or implicitly defined), there's no need to worry about their
 #. existence.  Theoretically, they should never even be
 #. instantiated, but that's hard to forestall.
-#: cp/decl.c:13150
+#: cp/decl.c:13174
 #, fuzzy, gcc-internal-format
 #| msgid "invalid constructor; you probably meant `%T (const %T&)'"
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "ugyldig konstruktionsfunktion; du mente sandsynligvis '%T (const %T&)'"
 
-#: cp/decl.c:13228
+#: cp/decl.c:13252
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' was not declared in this scope"
 msgid "%qD may not be declared within a namespace"
 msgstr "'%D' blev ikke erklæret i dette virkefelt"
 
-#: cp/decl.c:13234
+#: cp/decl.c:13258
 #, fuzzy, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "'%#D' kan ikke erklæres"
 
-#: cp/decl.c:13261
+#: cp/decl.c:13285
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must be a nonstatic member function"
 msgid "%qD must be a nonstatic member function"
 msgstr "'%D' skal være en ikke-statisk medlemsfunktion"
 
-#: cp/decl.c:13267
+#: cp/decl.c:13291
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must be either a non-static member function or a non-member function"
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "'%D' skal enten være en ikke-statisk medlemsfunktion eller ikke en medlemsfunktion"
 
-#: cp/decl.c:13277
+#: cp/decl.c:13301
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must have an argument of class or enumerated type"
 msgid "%qD must have an argument of class or enumerated type"
@@ -47744,160 +47791,160 @@
 msgstr "'%D' skal have en parameter af en klasse- eller enum-type"
 
 #. 13.4.0.3
-#: cp/decl.c:13303
+#: cp/decl.c:13327
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading operator ?:"
 msgstr "ISO C++ forbyder flertydiggørelse af operatoren ?:"
 
 #. Variadic.
-#: cp/decl.c:13314
+#: cp/decl.c:13338
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must take either one or two arguments"
 msgid "%qD must not have variable number of arguments"
 msgstr "'%D' skal tage mod én eller to parametre"
 
-#: cp/decl.c:13338
+#: cp/decl.c:13362
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must take either zero or one argument"
 msgid "%qD must have either zero or one argument"
 msgstr "'%D' skal tage mod nul eller én parameter"
 
-#: cp/decl.c:13339
+#: cp/decl.c:13363
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must take either one or two arguments"
 msgid "%qD must have either one or two arguments"
 msgstr "'%D' skal tage mod én eller to parametre"
 
-#: cp/decl.c:13350
+#: cp/decl.c:13374
 #, fuzzy, gcc-internal-format
 #| msgid "postfix `%D' must take `int' as its argument"
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "postfiks '%D' skal tage mod 'int' som parameter"
 
-#: cp/decl.c:13351
+#: cp/decl.c:13375
 #, fuzzy, gcc-internal-format
 #| msgid "postfix `%D' must take `int' as its second argument"
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "postfiks '%D' skal tage mod 'int' som den anden parameter"
 
-#: cp/decl.c:13361
+#: cp/decl.c:13385
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must take exactly two arguments"
 msgid "%qD must have no arguments"
 msgstr "'%s' skal tage mod to parametre"
 
-#: cp/decl.c:13362 cp/decl.c:13371
+#: cp/decl.c:13386 cp/decl.c:13395
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must take exactly one argument"
 msgid "%qD must have exactly one argument"
 msgstr "'%s' skal tage mod én parameter"
 
-#: cp/decl.c:13372
+#: cp/decl.c:13396
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must take exactly two arguments"
 msgid "%qD must have exactly two arguments"
 msgstr "'%s' skal tage mod to parametre"
 
-#: cp/decl.c:13389 cp/decl.c:13392
+#: cp/decl.c:13413 cp/decl.c:13416
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' cannot have default arguments"
 msgid "%qD cannot have default arguments"
 msgstr "'%D' kan ikke have standardparametre"
 
-#: cp/decl.c:13419
+#: cp/decl.c:13443
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to a reference to void will never use a type conversion operator"
 msgstr "konvertering til %s%s vil aldrig bruge en typekonverteringsoperator"
 
-#: cp/decl.c:13421
+#: cp/decl.c:13445
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to void will never use a type conversion operator"
 msgstr "konvertering til %s%s vil aldrig bruge en typekonverteringsoperator"
 
-#: cp/decl.c:13428
+#: cp/decl.c:13452
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgstr "konvertering til %s%s vil aldrig bruge en typekonverteringsoperator"
 
-#: cp/decl.c:13430
+#: cp/decl.c:13454
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to the same type will never use a type conversion operator"
 msgstr "konvertering til %s%s vil aldrig bruge en typekonverteringsoperator"
 
-#: cp/decl.c:13438
+#: cp/decl.c:13462
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgstr "konvertering til %s%s vil aldrig bruge en typekonverteringsoperator"
 
-#: cp/decl.c:13440
+#: cp/decl.c:13464
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to a base class will never use a type conversion operator"
 msgstr "konvertering til %s%s vil aldrig bruge en typekonverteringsoperator"
 
-#: cp/decl.c:13455
+#: cp/decl.c:13479
 #, fuzzy, gcc-internal-format
 #| msgid "user-defined `%D' always evaluates both arguments"
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "brugerdefineret '%D' evaluerer altid begge parametre"
 
-#: cp/decl.c:13474
+#: cp/decl.c:13498
 #, fuzzy, gcc-internal-format
 #| msgid "prefix `%D' should return `%T'"
 msgid "prefix %qD should return %qT"
 msgstr "præfiks '%D' skal returnere '%T'"
 
-#: cp/decl.c:13480
+#: cp/decl.c:13504
 #, fuzzy, gcc-internal-format
 #| msgid "postfix `%D' should return `%T'"
 msgid "postfix %qD should return %qT"
 msgstr "postfiks '%D' skal returnere '%T'"
 
-#: cp/decl.c:13492
+#: cp/decl.c:13516
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' should return by value"
 msgid "%qD should return by value"
 msgstr "'%D' skal returnere pr. værdi (ikke reference)"
 
-#: cp/decl.c:13547
+#: cp/decl.c:13571
 #, fuzzy, gcc-internal-format
 #| msgid "using template type parameter `%T' after `%s'"
 msgid "using template type parameter %qT after %qs"
 msgstr "bruger skabelonstypeparameter '%D' efter '%s'"
 
-#: cp/decl.c:13570
+#: cp/decl.c:13594
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous template specialization `%D' for `%+D'"
 msgid "using alias template specialization %qT after %qs"
 msgstr "tvetydig skabelonsspecialisering '%D' for '%+D'"
 
-#: cp/decl.c:13573
+#: cp/decl.c:13597
 #, fuzzy, gcc-internal-format
 #| msgid "using typedef-name `%D' after `%s'"
 msgid "using typedef-name %qD after %qs"
 msgstr "bruger typedef-navn '%D' efter '%s'"
 
-#: cp/decl.c:13575
+#: cp/decl.c:13599
 #, fuzzy, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "tidligere erklæring som '%#D'"
 
-#: cp/decl.c:13583
+#: cp/decl.c:13607
 #, fuzzy, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "'%#D' omerklæret som %C"
 
-#: cp/decl.c:13584 cp/decl.c:13591
+#: cp/decl.c:13608 cp/decl.c:13615
 #, fuzzy, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr "dette er en tidligere erklæring"
 
-#: cp/decl.c:13590
+#: cp/decl.c:13614
 #, fuzzy, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "'%#D' omerklæret som %C"
@@ -47909,103 +47956,103 @@
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:13605
+#: cp/decl.c:13629
 #, fuzzy, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "skabelonsparameter er påkrævet for '%T'"
 
-#: cp/decl.c:13659 cp/name-lookup.c:4652
+#: cp/decl.c:13683 cp/name-lookup.c:4652
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr ""
 
-#: cp/decl.c:13689 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6425
-#: cp/pt.c:9209
+#: cp/decl.c:13713 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6428
+#: cp/pt.c:9223
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a template"
 msgid "%qT is not a template"
 msgstr "'%T' er ikke en skabelon"
 
-#: cp/decl.c:13694
+#: cp/decl.c:13718
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:13703 cp/name-lookup.c:4079 cp/name-lookup.c:4086
-#: cp/name-lookup.c:4939 cp/parser.c:6376 cp/parser.c:26300
+#: cp/decl.c:13727 cp/name-lookup.c:4079 cp/name-lookup.c:4086
+#: cp/name-lookup.c:4939 cp/parser.c:6379 cp/parser.c:26297
 #, fuzzy, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "brug af '%D' er tvetydigt"
 
-#: cp/decl.c:13806
+#: cp/decl.c:13830
 #, fuzzy, gcc-internal-format
 #| msgid "use of enum `%#D' without previous declaration"
 msgid "use of enum %q#D without previous declaration"
 msgstr "brug af enum '%#D' uden tidligere erklæring"
 
-#: cp/decl.c:13842
+#: cp/decl.c:13866
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration `%#D' declares a non-template function"
 msgid "redeclaration of %qT as a non-template"
 msgstr "friend-erklæring '%#D' erklærer en ikke-skabelonsfunktion"
 
-#: cp/decl.c:13982
+#: cp/decl.c:14006
 #, fuzzy, gcc-internal-format
 #| msgid "derived union `%T' invalid"
 msgid "derived union %qT invalid"
 msgstr "nedarvet union '%T' ugyldig"
 
-#: cp/decl.c:13989
+#: cp/decl.c:14013
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is already defined in the class %T"
 msgid "%qT defined with multiple direct bases"
 msgstr "'%D' er allerede defineret i klassen '%T'"
 
-#: cp/decl.c:14000
+#: cp/decl.c:14024
 #, fuzzy, gcc-internal-format
 #| msgid "type `%D' is not a direct or virtual base of `%T'"
 msgid "%qT defined with direct virtual base"
 msgstr "typen '%D' er ikke en direkte eller en virtuel stamklasse til '%T'"
 
-#: cp/decl.c:14025
+#: cp/decl.c:14049
 #, fuzzy, gcc-internal-format
 #| msgid "base type `%T' fails to be a struct or class type"
 msgid "base type %qT fails to be a struct or class type"
 msgstr "stamklassetype '%T' er hverken en struct- eller class-type"
 
-#: cp/decl.c:14055
+#: cp/decl.c:14079
 #, fuzzy, gcc-internal-format
 #| msgid "recursive type `%T' undefined"
 msgid "recursive type %qT undefined"
 msgstr "rekursiv type '%T' ikke defineret"
 
-#: cp/decl.c:14057
+#: cp/decl.c:14081
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate base type `%T' invalid"
 msgid "duplicate base type %qT invalid"
 msgstr "stamklassetype '%T' optræder mere end én gang"
 
-#: cp/decl.c:14202
+#: cp/decl.c:14226
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14205 cp/decl.c:14213 cp/decl.c:14225 cp/parser.c:18284
+#: cp/decl.c:14229 cp/decl.c:14237 cp/decl.c:14249 cp/parser.c:18281
 #, fuzzy, gcc-internal-format
 msgid "previous definition here"
 msgstr "tidligere definition her"
 
-#: cp/decl.c:14210
+#: cp/decl.c:14234
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14222
+#: cp/decl.c:14246
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14300
+#: cp/decl.c:14324
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 of `%s' must be a 2-bit literal"
 msgid "underlying type %qT of %qT must be an integral type"
@@ -48015,86 +48062,86 @@
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:14447
+#: cp/decl.c:14471
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr ""
 
-#: cp/decl.c:14619
+#: cp/decl.c:14643
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for `%s' not integer constant"
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "enum-værdien for '%s' er ikke en heltalskonstant"
 
-#: cp/decl.c:14629
+#: cp/decl.c:14653
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for `%s' not integer constant"
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "enum-værdien for '%s' er ikke en heltalskonstant"
 
-#: cp/decl.c:14678
+#: cp/decl.c:14702
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr ""
 
-#: cp/decl.c:14679
+#: cp/decl.c:14703
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C restricts enumerator values to range of `int'"
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "ISO C begrænser enum-værdier til rækkevidden af 'int'"
 
-#: cp/decl.c:14690
+#: cp/decl.c:14714
 #, fuzzy, gcc-internal-format
 #| msgid "overflow in enumeration values at `%D'"
 msgid "overflow in enumeration values at %qD"
 msgstr "enum-værdier for store ved '%D'"
 
-#: cp/decl.c:14710
+#: cp/decl.c:14734
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "tabelindeks er ikke et heltal"
 
-#: cp/decl.c:14821
+#: cp/decl.c:14845
 #, fuzzy, gcc-internal-format
 #| msgid "return type `%#T' is incomplete"
 msgid "return type %q#T is incomplete"
 msgstr "returtype '%#T' er ufuldstændig"
 
-#: cp/decl.c:14999 cp/typeck.c:9286
+#: cp/decl.c:15023 cp/typeck.c:9286
 #, fuzzy, gcc-internal-format
 #| msgid "`operator=' should return a reference to `*this'"
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "'operator=' bør returnere en reference til '*this'"
 
-#: cp/decl.c:15344
+#: cp/decl.c:15368
 #, fuzzy, gcc-internal-format
 msgid "invalid function declaration"
 msgstr "Ugyldig erklæring"
 
-#: cp/decl.c:15786
+#: cp/decl.c:15810
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statements in function returning %qT"
 msgstr "ingen return-sætning i en funktion der ikke returnerer void"
 
-#: cp/decl.c:15788 cp/typeck.c:9166
+#: cp/decl.c:15812 cp/typeck.c:9166
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr ""
 
-#: cp/decl.c:15996
+#: cp/decl.c:16020
 #, fuzzy, gcc-internal-format
 msgid "invalid member function declaration"
 msgstr "ugyldig medlemsskabelonerklæring '%D'"
 
-#: cp/decl.c:16010
+#: cp/decl.c:16034
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is already defined in class `%T'"
 msgid "%qD is already defined in class %qT"
 msgstr "'%D' er allerede defineret i klassen '%T'"
 
-#: cp/decl.c:16386
+#: cp/decl.c:16410
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -48139,7 +48186,7 @@
 msgid "deleting %qT is undefined"
 msgstr "benyttelse af delete på '%T' er ikke defineret"
 
-#: cp/decl2.c:585 cp/pt.c:5552
+#: cp/decl2.c:585 cp/pt.c:5566
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of `%#D'"
 msgid "template declaration of %q#D"
@@ -48154,7 +48201,7 @@
 #. [temp.mem]
 #.
 #. A destructor shall not be a member template.
-#: cp/decl2.c:640 cp/pt.c:5511
+#: cp/decl2.c:640 cp/pt.c:5525
 #, fuzzy, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "datamedlem '%D' kan ikke være en medlemsskabelon"
@@ -48354,47 +48401,47 @@
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "den første parameter til 'operator delete' skal være af typen '%T'"
 
-#: cp/decl2.c:2660
+#: cp/decl2.c:2650
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2664
+#: cp/decl2.c:2654
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2669
+#: cp/decl2.c:2659
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2677
+#: cp/decl2.c:2667
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr ""
 
-#: cp/decl2.c:2695
+#: cp/decl2.c:2685
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2699
+#: cp/decl2.c:2689
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2704
+#: cp/decl2.c:2694
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2711
+#: cp/decl2.c:2701
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr ""
 
-#: cp/decl2.c:4309
+#: cp/decl2.c:4299
 #, fuzzy, gcc-internal-format
 #| msgid "%J'%F' declared `static' but never defined"
 msgid "%q#D, declared using unnamed type, is used but never defined"
@@ -48404,70 +48451,70 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4318
+#: cp/decl2.c:4308
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of `%#D' with %L linkage"
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr "tidligere erklæring af '%#D' med %L-kædning"
 
-#: cp/decl2.c:4322
+#: cp/decl2.c:4312
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of `%#D' with %L linkage"
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr "tidligere erklæring af '%#D' med %L-kædning"
 
-#: cp/decl2.c:4326
+#: cp/decl2.c:4316
 #, fuzzy, gcc-internal-format
 #| msgid "`%#D' does not refer to the unqualified type, so it is not used for linkage"
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr "'%#D' refererer ikke til den ikkemodificerede type, so den bruges ikke til sammenkædning"
 
-#: cp/decl2.c:4334
+#: cp/decl2.c:4324
 #, fuzzy, gcc-internal-format
 #| msgid "%J'%F' declared `static' but never defined"
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "%J'%F' erklæret 'static', men aldrig defineret"
 
-#: cp/decl2.c:4338
+#: cp/decl2.c:4328
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4341
+#: cp/decl2.c:4331
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of `%#D' with %L linkage"
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "tidligere erklæring af '%#D' med %L-kædning"
 
-#: cp/decl2.c:4529
+#: cp/decl2.c:4519
 #, fuzzy, gcc-internal-format
 msgid "mangling of %q#D as %qE conflicts with a previous mangle"
 msgstr "strider mod tidligere erklæring '%#D'"
 
 # hænger sammen med næste tekst
-#: cp/decl2.c:4532
+#: cp/decl2.c:4522
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration `%D'"
 msgid "previous mangling %q#D"
 msgstr "tidligere erklæring '%D'"
 
-#: cp/decl2.c:4534
+#: cp/decl2.c:4524
 #, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr ""
 
-#: cp/decl2.c:4606 cp/decl2.c:4609
+#: cp/decl2.c:4596 cp/decl2.c:4599
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.c:4956
+#: cp/decl2.c:4946
 #, fuzzy, gcc-internal-format
 #| msgid "inline function `%D' used but never defined"
 msgid "inline function %qD used but never defined"
 msgstr "indbygget funktion '%D' benyttet, men aldrig defineret"
 
-#: cp/decl2.c:5143
+#: cp/decl2.c:5133
 #, fuzzy, gcc-internal-format
 #| msgid "default argument missing for parameter %P of `%+#D'"
 msgid "default argument missing for parameter %P of %q+#D"
@@ -48475,19 +48522,19 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5251
+#: cp/decl2.c:5241
 #, fuzzy, gcc-internal-format
 #| msgid "converting NULL to non-pointer type"
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr "konverterer NULL til en ikke-henvisningstype"
 
-#: cp/decl2.c:5254
+#: cp/decl2.c:5244
 #, fuzzy, gcc-internal-format
 #| msgid "sizeof applied to a function type"
 msgid "use of deleted function %qD"
 msgstr "sizeof benyttet på en funktionstype"
 
-#: cp/decl2.c:5307
+#: cp/decl2.c:5297
 #, fuzzy, gcc-internal-format
 #| msgid "use of template qualifier outside template"
 msgid "use of built-in parameter pack %qD outside of a template"
@@ -48800,48 +48847,48 @@
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr "ugyldig tildeling af startværdi i klasse til statisk datamedlem af en ikke-heltalstype '%T'"
 
-#: cp/init.c:613
+#: cp/init.c:629
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr ""
 
-#: cp/init.c:615
+#: cp/init.c:631
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' previously defined here"
 msgid "defined here"
 msgstr "'%s' tidligere defineret her"
 
-#: cp/init.c:673
+#: cp/init.c:689
 #, fuzzy, gcc-internal-format
 #| msgid "initialization of a flexible array member"
 msgid "initializer for flexible array member %q#D"
 msgstr "klargøring af fleksibelt tabelmedlem"
 
-#: cp/init.c:699
+#: cp/init.c:715
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' should be initialized in the member initialization list"
 msgid "%qD should be initialized in the member initialization list"
 msgstr "'%D' bør blive klargjort i medlemsklargøringslisten"
 
-#: cp/init.c:720
+#: cp/init.c:736
 #, fuzzy, gcc-internal-format
 #| msgid "class `%T' is implicitly friends with itself"
 msgid "%qD is initialized with itself"
 msgstr "klassen '%T' er underforstået ven med sig selv"
 
-#: cp/init.c:831
+#: cp/init.c:847
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer for virtual method `%D'"
 msgid "invalid initializer for array member %q#D"
 msgstr "ugyldig startværdi til virtuel medlemsfunktion '%D'"
 
-#: cp/init.c:845 cp/init.c:869 cp/init.c:2410 cp/method.c:1368
+#: cp/init.c:861 cp/init.c:885 cp/init.c:2427 cp/method.c:1368
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const member `%D'"
 msgid "uninitialized const member in %q#T"
 msgstr "konstant medlem '%D' uden startværdi"
 
-#: cp/init.c:847 cp/init.c:864 cp/init.c:871 cp/init.c:2395 cp/init.c:2423
+#: cp/init.c:863 cp/init.c:880 cp/init.c:887 cp/init.c:2412 cp/init.c:2440
 #: cp/method.c:1371 cp/method.c:1382
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' will be initialized after"
@@ -48848,317 +48895,317 @@
 msgid "%q#D should be initialized"
 msgstr "'%D' vil blive klargjort efter"
 
-#: cp/init.c:862 cp/init.c:2382 cp/method.c:1379
+#: cp/init.c:878 cp/init.c:2399 cp/method.c:1379
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized reference member `%D'"
 msgid "uninitialized reference member in %q#T"
 msgstr "referencemedlem '%D' uden startværdi"
 
-#: cp/init.c:1041
+#: cp/init.c:1057
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' will be initialized after"
 msgid "%qD will be initialized after"
 msgstr "'%D' vil blive klargjort efter"
 
-#: cp/init.c:1044
+#: cp/init.c:1060
 #, fuzzy, gcc-internal-format
 #| msgid "base `%T' will be initialized after"
 msgid "base %qT will be initialized after"
 msgstr "stamklasse '%T' vil blive klargjort efter"
 
-#: cp/init.c:1048
+#: cp/init.c:1064
 #, gcc-internal-format
 msgid "  %q#D"
 msgstr ""
 
-#: cp/init.c:1050
+#: cp/init.c:1066
 #, fuzzy, gcc-internal-format
 #| msgid "  base `%T'"
 msgid "  base %qT"
 msgstr "  stamklasse '%T'"
 
-#: cp/init.c:1052
+#: cp/init.c:1068
 #, fuzzy, gcc-internal-format
 msgid "  when initialized here"
 msgstr "'%D' vil blive klargjort efter"
 
-#: cp/init.c:1069
+#: cp/init.c:1085
 #, fuzzy, gcc-internal-format
 #| msgid "multiple initializations given for `%D'"
 msgid "multiple initializations given for %qD"
 msgstr "flere startværdier angivet for '%D'"
 
-#: cp/init.c:1073
+#: cp/init.c:1089
 #, fuzzy, gcc-internal-format
 #| msgid "multiple initializations given for base `%T'"
 msgid "multiple initializations given for base %qT"
 msgstr "flere startværdier angivet for stamklassen '%T'"
 
-#: cp/init.c:1158
+#: cp/init.c:1174
 #, fuzzy, gcc-internal-format
 #| msgid "initializations for multiple members of `%T'"
 msgid "initializations for multiple members of %qT"
 msgstr "startværdier for flere medlemmer af '%T'"
 
-#: cp/init.c:1255
+#: cp/init.c:1271
 #, fuzzy, gcc-internal-format
 #| msgid "base class `%#T' should be explicitly initialized in the copy constructor"
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr "stamklassen '%#T' bør eksplicit blive klargjort i kopikonstruktionsfunktionen"
 
-#: cp/init.c:1482 cp/init.c:1501
+#: cp/init.c:1498 cp/init.c:1517
 #, fuzzy, gcc-internal-format
 #| msgid "class `%T' does not have any field named `%D'"
 msgid "class %qT does not have any field named %qD"
 msgstr "klassen '%T' har ikke et felt ved navn '%D'"
 
-#: cp/init.c:1488
+#: cp/init.c:1504
 #, fuzzy, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr "feltet '%#D' er statisk; det eneste sted det kan klargøres er ved dets definition"
 
-#: cp/init.c:1495
+#: cp/init.c:1511
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr "'%#D' er ikke et statisk medlem af '%#T'"
 
-#: cp/init.c:1534
+#: cp/init.c:1550
 #, fuzzy, gcc-internal-format
 #| msgid "unnamed initializer for `%T', which has no base classes"
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr "unavngiven klargøring af '%T' som ikke har nogen stamklasser"
 
-#: cp/init.c:1542
+#: cp/init.c:1558
 #, fuzzy, gcc-internal-format
 #| msgid "unnamed initializer for `%T', which uses multiple inheritance"
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr "unavngiven klargøring af '%T' som benytter multipel nedarvning"
 
-#: cp/init.c:1589
+#: cp/init.c:1605
 #, fuzzy, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr "typen '%D' er ikke en direkte eller en virtuel stamklasse til '%T'"
 
-#: cp/init.c:1597
+#: cp/init.c:1613
 #, fuzzy, gcc-internal-format
 #| msgid "type `%D' is not a direct or virtual base of `%T'"
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr "typen '%D' er ikke en direkte eller en virtuel stamklasse til '%T'"
 
-#: cp/init.c:1600
+#: cp/init.c:1616
 #, fuzzy, gcc-internal-format
 #| msgid "type `%D' is not a direct base of `%T'"
 msgid "type %qT is not a direct base of %qT"
 msgstr "typen '%D' er ikke en direkte stamklasse til '%T'"
 
-#: cp/init.c:1710 cp/init.c:4386 cp/typeck2.c:1175
+#: cp/init.c:1727 cp/init.c:4402 cp/typeck2.c:1175
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
 
-#: cp/init.c:2019 cp/semantics.c:3268
+#: cp/init.c:2036 cp/semantics.c:3271
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a class or union type"
 msgid "%qT is not a class type"
 msgstr "'%T' er ikke af en klasse- eller union-type"
 
-#: cp/init.c:2075
+#: cp/init.c:2092
 #, fuzzy, gcc-internal-format
 #| msgid "incomplete type `%T' does not have member `%D'"
 msgid "incomplete type %qT does not have member %qD"
 msgstr "ufuldstændig type '%T' har ikke medlemmet '%D'"
 
-#: cp/init.c:2089
+#: cp/init.c:2106
 #, fuzzy, gcc-internal-format
 #| msgid "invalid pointer to bit-field `%D'"
 msgid "invalid pointer to bit-field %qD"
 msgstr "ugyldig henvisning til bitfeltet '%D'"
 
-#: cp/init.c:2175 cp/typeck.c:1893
+#: cp/init.c:2192 cp/typeck.c:1893
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "ugyldig brug af ikke-statisk felt '%D'"
 
-#: cp/init.c:2182 cp/semantics.c:1835
+#: cp/init.c:2199 cp/semantics.c:1835
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "ugyldig brug af ikke-statisk felt '%D'"
 
-#: cp/init.c:2379
+#: cp/init.c:2396
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2387
+#: cp/init.c:2404
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2391
+#: cp/init.c:2408
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized reference member `%D'"
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr "referencemedlem '%D' uden startværdi"
 
-#: cp/init.c:2407
+#: cp/init.c:2424
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2415
+#: cp/init.c:2432
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2419
+#: cp/init.c:2436
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const in `new' of `%#T'"
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr "konstant uden startværdi i 'new' af '%#T'"
 
-#: cp/init.c:2710
+#: cp/init.c:2727
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2721
+#: cp/init.c:2738
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2732
+#: cp/init.c:2749
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2880
+#: cp/init.c:2896
 #, fuzzy, gcc-internal-format
 #| msgid "integer overflow in expression"
 msgid "integer overflow in array size"
 msgstr "heltalsoverløb i udtryk"
 
-#: cp/init.c:2890
+#: cp/init.c:2906
 #, gcc-internal-format
 msgid "array size in new-expression must be constant"
 msgstr ""
 
-#: cp/init.c:2904
+#: cp/init.c:2920
 #, fuzzy, gcc-internal-format
 #| msgid "double quoted strings not allowed in #if expressions"
 msgid "variably modified type not allowed in new-expression"
 msgstr "strenge med dobbelte anførselstegn er ikke tilladte i #if-udtryk"
 
-#: cp/init.c:2920
+#: cp/init.c:2936
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by typedef"
 msgstr ""
 
-#: cp/init.c:2922
+#: cp/init.c:2938
 #, gcc-internal-format
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr ""
 
-#: cp/init.c:2932
+#: cp/init.c:2948
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type `void' for new"
 msgid "invalid type %<void%> for new"
 msgstr "ugyldig type 'void' til new"
 
-#: cp/init.c:2975
+#: cp/init.c:2991
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const in `new' of `%#T'"
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr "konstant uden startværdi i 'new' af '%#T'"
 
-#: cp/init.c:3101
+#: cp/init.c:3117
 #, fuzzy, gcc-internal-format
 #| msgid "field '%s' not found in class"
 msgid "no suitable %qD found in class %qT"
 msgstr "feltet '%s' blev ikke fundet i klassen"
 
-#: cp/init.c:3108 cp/search.c:1023
+#: cp/init.c:3124 cp/search.c:1026
 #, fuzzy, gcc-internal-format
 #| msgid "request for member `%D' is ambiguous"
 msgid "request for member %qD is ambiguous"
 msgstr "forespørgsel efter medlemmet '%D' er tvetydigt"
 
-#: cp/init.c:3181
+#: cp/init.c:3197
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr ""
 
-#: cp/init.c:3184
+#: cp/init.c:3200
 #, fuzzy, gcc-internal-format
 #| msgid "class `%T' does not have any field named `%D'"
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr "klassen '%T' har ikke et felt ved navn '%D'"
 
-#: cp/init.c:3187
+#: cp/init.c:3203
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr ""
 
-#: cp/init.c:3370
+#: cp/init.c:3386
 #, fuzzy, gcc-internal-format
 msgid "parenthesized initializer in array new"
 msgstr "egenskaber i parametertabelerklæring ignoreret"
 
-#: cp/init.c:3633
+#: cp/init.c:3649
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr "størrelse i tabel-new skal være en heltalstype"
 
-#: cp/init.c:3665
+#: cp/init.c:3681
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/init.c:3674
+#: cp/init.c:3690
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr "new kan ikke bruges på en funktionstype"
 
-#: cp/init.c:3743
+#: cp/init.c:3759
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete [] operator:"
 msgstr ""
 
-#: cp/init.c:3747
+#: cp/init.c:3763
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete [] will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4295
+#: cp/init.c:4311
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "startværdien slutter for tidligt"
 
-#: cp/init.c:4599
+#: cp/init.c:4615
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr "ukendt tabelstørrelse i delete"
 
-#: cp/init.c:4623
+#: cp/init.c:4639
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete operator:"
 msgstr ""
 
-#: cp/init.c:4628
+#: cp/init.c:4644
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4642
+#: cp/init.c:4658
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4647
+#: cp/init.c:4663
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4954
+#: cp/init.c:4970
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "variablen til tabel-delete er hverken af en henvisnings- eller en tabeltype"
@@ -49677,7 +49724,7 @@
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "egenskaben '%s' kan kun anvendes på variabler"
 
-#: cp/name-lookup.c:5111 cp/name-lookup.c:7065
+#: cp/name-lookup.c:5111 cp/name-lookup.c:7073
 #, fuzzy, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "egenskabsdirektivet '%s' ignoreret"
@@ -49727,30 +49774,30 @@
 msgid "it was later defined here"
 msgstr "'%s' tidligere defineret her"
 
-#: cp/name-lookup.c:6687
+#: cp/name-lookup.c:6695
 #, fuzzy, gcc-internal-format
 #| msgid "brace-enclosed initializer used to initialize `%T'"
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn't a template"
 msgstr "startværdi i krøllede paranteser benyttet til at klargøre '%T'"
 
-#: cp/name-lookup.c:7059
+#: cp/name-lookup.c:7067
 #, fuzzy, gcc-internal-format
 #| msgid "switch \"%s\" is no longer supported"
 msgid "strong using directive no longer supported"
 msgstr "tilvalget '%s' understøttes ikke længere"
 
-#: cp/name-lookup.c:7062
+#: cp/name-lookup.c:7070
 #, fuzzy, gcc-internal-format
 msgid "you may use an inline namespace instead"
 msgstr "Angiv klassesti (forældet: benyt --classpath i stedet)"
 
-#: cp/name-lookup.c:7079
+#: cp/name-lookup.c:7087
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operation on uninstantiated type"
 msgid "attributes ignored on local using directive"
 msgstr "ugyldig operation på uudskiftet type"
 
-#: cp/name-lookup.c:7163
+#: cp/name-lookup.c:7171
 #, fuzzy, gcc-internal-format
 #| msgid "namespace alias `%D' not allowed here, assuming `%D'"
 msgid "namespace alias %qD not allowed here, assuming %qD"
@@ -49757,29 +49804,29 @@
 msgstr "navnerumsalias '%D' er ikke tilladt her, antager '%D'"
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:7183
+#: cp/name-lookup.c:7191
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "`%D' was not declared in this scope"
 msgid "cannot nest more than %d namespaces"
 msgstr "'%D' blev ikke erklæret i dette virkefelt"
 
-#: cp/name-lookup.c:7218
+#: cp/name-lookup.c:7226
 #, fuzzy, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr "sektionsegenskaben kan ikke angives for lokale variabler"
 
-#: cp/name-lookup.c:7219
+#: cp/name-lookup.c:7227
 #, fuzzy, gcc-internal-format
 #| msgid "label `%D' defined but not used"
 msgid "%qD defined here"
 msgstr "etiketten '%D' er defineret, men ikke benyttet"
 
-#: cp/name-lookup.c:7292
+#: cp/name-lookup.c:7300
 #, gcc-internal-format
 msgid "XXX entering pop_everything ()\n"
 msgstr ""
 
-#: cp/name-lookup.c:7301
+#: cp/name-lookup.c:7309
 #, gcc-internal-format
 msgid "XXX leaving pop_everything ()\n"
 msgstr ""
@@ -49799,7 +49846,7 @@
 msgid "LEXER_DEBUGGING_ENABLED_P is not set to true"
 msgstr ""
 
-#: cp/parser.c:1352 cp/parser.c:37254
+#: cp/parser.c:1352 cp/parser.c:37251
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -49826,7 +49873,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr "forespørgsel efter medlemmet '%D' i '%E' som er af en ikke-klassetype '%T'"
 
-#: cp/parser.c:2949 cp/parser.c:18221
+#: cp/parser.c:2949 cp/parser.c:18218
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "'%#D' kan ikke erklæres"
@@ -49918,7 +49965,7 @@
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/parser.c:3143 cp/pt.c:17853
+#: cp/parser.c:3143 cp/pt.c:17890
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr ""
@@ -50149,7 +50196,7 @@
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr ""
 
-#: cp/parser.c:4587 cp/parser.c:12940
+#: cp/parser.c:4587 cp/parser.c:12937
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "expected declaration"
@@ -50205,7 +50252,7 @@
 msgid "fold-expressions only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:5275 cp/parser.c:5452 cp/parser.c:5630 cp/semantics.c:3612
+#: cp/parser.c:5275 cp/parser.c:5452 cp/parser.c:5633 cp/semantics.c:3615
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected address expression"
 msgid "expected primary-expression"
@@ -50226,98 +50273,98 @@
 msgid "local variable %qD may not appear in this context"
 msgstr "'%D' blev ikke erklæret i dette virkefelt"
 
-#: cp/parser.c:5787
+#: cp/parser.c:5790
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected address expression"
 msgid "expected id-expression"
 msgstr "uventet adresseudtryk"
 
-#: cp/parser.c:5919
+#: cp/parser.c:5922
 #, gcc-internal-format
 msgid "scope %qT before %<~%> is not a class-name"
 msgstr ""
 
-#: cp/parser.c:5948 cp/parser.c:7860
+#: cp/parser.c:5951 cp/parser.c:7860
 #, gcc-internal-format
 msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:6059
+#: cp/parser.c:6062
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' shadows a member of `this'"
 msgid "declaration of %<~%T%> as member of %qT"
 msgstr "erklæring af '%s' skygger for et medlem af 'this'"
 
-#: cp/parser.c:6074
+#: cp/parser.c:6077
 #, fuzzy, gcc-internal-format
 msgid "typedef-name %qD used as destructor declarator"
 msgstr "skabelons-id '%D' benyttet som erklærer"
 
-#: cp/parser.c:6111 cp/parser.c:20249
+#: cp/parser.c:6114 cp/parser.c:20246
 #, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr ""
 
-#: cp/parser.c:6220
+#: cp/parser.c:6223
 #, gcc-internal-format
 msgid "found %<:%> in nested-name-specifier, expected %<::%>"
 msgstr ""
 
-#: cp/parser.c:6288
+#: cp/parser.c:6291
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a class or union type"
 msgid "decltype evaluates to %qT, which is not a class or enumeration type"
 msgstr "'%T' er ikke af en klasse- eller union-type"
 
-#: cp/parser.c:6314
+#: cp/parser.c:6317
 #, fuzzy, gcc-internal-format
 msgid "function template-id %qD in nested-name-specifier"
 msgstr "ufuldstændig type '%T' kan ikke bruges til at navngive et virkefelt"
 
-#: cp/parser.c:6322
+#: cp/parser.c:6325
 #, fuzzy, gcc-internal-format
 msgid "variable template-id %qD in nested-name-specifier"
 msgstr "ufuldstændig type '%T' kan ikke bruges til at navngive et virkefelt"
 
-#: cp/parser.c:6426 cp/typeck.c:2684 cp/typeck.c:2687 cp/typeck.c:2704
+#: cp/parser.c:6429 cp/typeck.c:2684 cp/typeck.c:2687 cp/typeck.c:2704
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a template"
 msgid "%qD is not a template"
 msgstr "'%T' er ikke en skabelon"
 
-#: cp/parser.c:6504
+#: cp/parser.c:6507
 #, fuzzy, gcc-internal-format
 msgid "expected nested-name-specifier"
 msgstr "uventet operand"
 
-#: cp/parser.c:6711 cp/parser.c:8950
+#: cp/parser.c:6714 cp/parser.c:8950
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:6797
+#: cp/parser.c:6800
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a %<typeid%> expression"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:6889
+#: cp/parser.c:6892
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "forkert antal skabelonsparametre (%d, skulle være %d)"
 
-#: cp/parser.c:6901 cp/pt.c:18416
+#: cp/parser.c:6904 cp/pt.c:18453
 #, fuzzy, gcc-internal-format
 #| msgid "wrong type argument to bit-complement"
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "forkert parametertype til bitkomplement"
 
-#: cp/parser.c:6995
+#: cp/parser.c:6998
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids compound-literals"
 msgstr "ISO C++ forbyder sammensatte konstanter"
 
-#: cp/parser.c:7054
+#: cp/parser.c:7057
 #, gcc-internal-format
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
@@ -50455,7 +50502,7 @@
 msgid "capture of non-variable %qE"
 msgstr "%s af variablen '%s' der kun må læses"
 
-#: cp/parser.c:10391 cp/parser.c:10401 cp/semantics.c:3453 cp/semantics.c:3465
+#: cp/parser.c:10391 cp/parser.c:10401 cp/semantics.c:3456 cp/semantics.c:3468
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "%q#D declared here"
@@ -50546,7 +50593,7 @@
 msgid "init-statement in selection statements only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:11546 cp/parser.c:28490
+#: cp/parser.c:11546 cp/parser.c:28487
 #, fuzzy, gcc-internal-format
 #| msgid "empty body in an else-statement"
 msgid "expected selection-statement"
@@ -50568,209 +50615,209 @@
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:12250 cp/parser.c:28493
+#: cp/parser.c:12250 cp/parser.c:28490
 #, fuzzy, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "uventet operand"
 
-#: cp/parser.c:12298
+#: cp/parser.c:12297
 #, gcc-internal-format
 msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/parser.c:12426
+#: cp/parser.c:12423
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr ""
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:12434
+#: cp/parser.c:12431
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ forbyder beregnede goto'er"
 
-#: cp/parser.c:12447 cp/parser.c:28496
+#: cp/parser.c:12444 cp/parser.c:28493
 #, fuzzy, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "uventet operand"
 
-#: cp/parser.c:12620 cp/parser.c:23584
+#: cp/parser.c:12617 cp/parser.c:23581
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr ""
 
-#: cp/parser.c:12863
+#: cp/parser.c:12860
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr ""
 
-#: cp/parser.c:13083
+#: cp/parser.c:13080
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:13103
+#: cp/parser.c:13100
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr ""
 
-#: cp/parser.c:13124
+#: cp/parser.c:13121
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr ""
 
-#: cp/parser.c:13148
+#: cp/parser.c:13145
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:13203
+#: cp/parser.c:13200
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13206
+#: cp/parser.c:13203
 #, fuzzy, gcc-internal-format
 #| msgid "multiple declarations `%T' and `%T'"
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr "flere erklæringer '%T' og '%T'"
 
-#: cp/parser.c:13257
+#: cp/parser.c:13254
 #, gcc-internal-format
 msgid "structured bindings only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:13306
+#: cp/parser.c:13303
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "empty structured binding declaration"
 msgstr "tom erklæring"
 
-#: cp/parser.c:13324
+#: cp/parser.c:13321
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer for bit string"
 msgid "invalid initializer for structured binding declaration"
 msgstr "ugyldig startværdi til bitstreng"
 
-#: cp/parser.c:13491
+#: cp/parser.c:13488
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr ""
 
-#: cp/parser.c:13558
+#: cp/parser.c:13555
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr ""
 
-#: cp/parser.c:13594
+#: cp/parser.c:13591
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specifiers invalid in friend function declarations"
 msgid "decl-specifier invalid in condition"
 msgstr "lagringsklasseanvisninger er ugyldige i vennefunktionserklæringer"
 
-#: cp/parser.c:13600
+#: cp/parser.c:13597
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' invalid in `%#T'"
 msgid "%qD invalid in lambda"
 msgstr "'%D' ugyldig i '%#T'"
 
-#: cp/parser.c:13693
+#: cp/parser.c:13690
 #, fuzzy, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "funktionen '%D' kan ikke erklæres friend"
 
-#: cp/parser.c:13763 cp/parser.c:24064
+#: cp/parser.c:13760 cp/parser.c:24061
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:13805
+#: cp/parser.c:13802
 #, fuzzy, gcc-internal-format
 #| msgid "invalid base-class specification"
 msgid "invalid linkage-specification"
 msgstr "ugyldig stamklasseangivelse"
 
-#: cp/parser.c:13909
+#: cp/parser.c:13906
 #, gcc-internal-format
 msgid "static_assert without a message only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:14111
+#: cp/parser.c:14108
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:14264
+#: cp/parser.c:14261
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:14291
+#: cp/parser.c:14288
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of void expression"
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "ugyldig brug af void-udtryk"
 
-#: cp/parser.c:14295
+#: cp/parser.c:14292
 #, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr ""
 
-#: cp/parser.c:14379
+#: cp/parser.c:14376
 #, fuzzy, gcc-internal-format
 #| msgid "only constructors take base initializers"
 msgid "only constructors take member initializers"
 msgstr "kun konstruktionsfunktioner har stamklasseklargøringer"
 
-#: cp/parser.c:14406
+#: cp/parser.c:14403
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member `%D'"
 msgid "cannot expand initializer for member %qD"
 msgstr "manglende startværdi for medlemmet '%D'"
 
-#: cp/parser.c:14418 cp/pt.c:24255
+#: cp/parser.c:14415 cp/pt.c:24333
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr ""
 
-#: cp/parser.c:14430 cp/pt.c:24267
+#: cp/parser.c:14427 cp/pt.c:24345
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
 
-#: cp/parser.c:14482
+#: cp/parser.c:14479
 #, fuzzy, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr "forældet stamklasseklargøring"
 
-#: cp/parser.c:14552
+#: cp/parser.c:14549
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:14927
+#: cp/parser.c:14924
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr ""
 
-#: cp/parser.c:14933
+#: cp/parser.c:14930
 #, fuzzy, gcc-internal-format
 #| msgid "predicate must be an identifier"
 msgid "expected suffix identifier"
 msgstr "udsagn skal være et kaldenavn"
 
-#: cp/parser.c:14942
+#: cp/parser.c:14939
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr ""
 
-#: cp/parser.c:14948
+#: cp/parser.c:14945
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type modifier within pointer declarator"
 msgid "invalid encoding prefix in literal operator"
 msgstr "ugyldig typemodifikation i erklæring af henvisning"
 
-#: cp/parser.c:14975
+#: cp/parser.c:14972
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected operator"
@@ -50777,391 +50824,391 @@
 msgstr "uventet operand"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:15020
+#: cp/parser.c:15017
 #, fuzzy, gcc-internal-format
 #| msgid "keyword `export' not implemented, and will be ignored"
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "det reserverede ord 'export' er ikke implementeret og vil blive ignoreret"
 
-#: cp/parser.c:15190
+#: cp/parser.c:15187
 #, fuzzy, gcc-internal-format
 #| msgid "invalid catch parameter"
 msgid "invalid constrained type parameter"
 msgstr "ugyldig catch-parameter"
 
-#: cp/parser.c:15198
+#: cp/parser.c:15195
 #, fuzzy, gcc-internal-format
 #| msgid "invalid catch parameter"
 msgid "cv-qualified type parameter"
 msgstr "ugyldig catch-parameter"
 
-#: cp/parser.c:15283
+#: cp/parser.c:15280
 #, gcc-internal-format
 msgid "variadic constraint introduced without %<...%>"
 msgstr ""
 
-#: cp/parser.c:15347
+#: cp/parser.c:15344
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "ugyldig standardparameter i skabelon"
 
-#: cp/parser.c:15582 cp/parser.c:15668 cp/parser.c:21694
+#: cp/parser.c:15579 cp/parser.c:15665 cp/parser.c:21691
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' cannot have default arguments"
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "'%D' kan ikke have standardparametre"
 
-#: cp/parser.c:15586 cp/parser.c:15672
+#: cp/parser.c:15583 cp/parser.c:15669
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "template parameter packs cannot have default arguments"
 msgstr "skabelonsparametre kan ikke være venner"
 
-#: cp/parser.c:15738
+#: cp/parser.c:15735
 #, fuzzy, gcc-internal-format
 msgid "expected template-id"
 msgstr "uventet operand"
 
-#: cp/parser.c:15798
+#: cp/parser.c:15795
 #, fuzzy, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "objektet '%E' kan ikke bruges som skabelonsparameter"
 
-#: cp/parser.c:15802
+#: cp/parser.c:15799
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr ""
 
-#: cp/parser.c:15806
+#: cp/parser.c:15803
 #, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr ""
 
-#: cp/parser.c:15924
+#: cp/parser.c:15921
 #, fuzzy, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "objektet '%E' kan ikke bruges som skabelonsparameter"
 
 #. The name does not name a template.
-#: cp/parser.c:15992 cp/parser.c:16122 cp/parser.c:16337
+#: cp/parser.c:15989 cp/parser.c:16119 cp/parser.c:16334
 #, fuzzy, gcc-internal-format
 msgid "expected template-name"
 msgstr "uventet operand"
 
 #. Explain what went wrong.
-#: cp/parser.c:16038
+#: cp/parser.c:16035
 #, fuzzy, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr "ikke-skabelon benyttet som skabelon"
 
-#: cp/parser.c:16040
+#: cp/parser.c:16037
 #, fuzzy, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr "skabelons-id '%D' i erklæring af primær skabelon"
 
-#: cp/parser.c:16189
+#: cp/parser.c:16186
 #, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr ""
 
-#: cp/parser.c:16298 cp/parser.c:16316 cp/parser.c:16483
+#: cp/parser.c:16295 cp/parser.c:16313 cp/parser.c:16480
 #, fuzzy, gcc-internal-format
 msgid "expected template-argument"
 msgstr "uventet operand"
 
-#: cp/parser.c:16458
+#: cp/parser.c:16455
 #, fuzzy, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr "ugyldig standardparameter i skabelon"
 
-#: cp/parser.c:16585
+#: cp/parser.c:16582
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of `%#D' after"
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "eksplicit instantiering af '%#D' efter"
 
-#: cp/parser.c:16589
+#: cp/parser.c:16586
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of `%#D' after"
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "eksplicit instantiering af '%#D' efter"
 
-#: cp/parser.c:16648
+#: cp/parser.c:16645
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr "skabelonsspecialisering med C-kædning"
 
-#: cp/parser.c:16869
+#: cp/parser.c:16866
 #, fuzzy, gcc-internal-format
 #| msgid "sigof type specifier"
 msgid "expected type specifier"
 msgstr "sigof-typeangivelse"
 
-#: cp/parser.c:17053
+#: cp/parser.c:17050
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:17059
+#: cp/parser.c:17056
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:17064
+#: cp/parser.c:17061
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids forward parameter declarations"
 msgid "use of %<auto%> in parameter declaration only available with -fconcepts"
 msgstr "ISO C forbyder forhåndsparametererklæringer"
 
-#: cp/parser.c:17209
+#: cp/parser.c:17206
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a template of type `%D', got `%D'"
 msgid "expected template-id for type"
 msgstr "  forventede en skabelon af typen '%D', modtog '%D'"
 
-#: cp/parser.c:17278
+#: cp/parser.c:17275
 #, fuzzy, gcc-internal-format
 msgid "expected type-name"
 msgstr "uventet operand"
 
-#: cp/parser.c:17631
+#: cp/parser.c:17628
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr ""
 
-#: cp/parser.c:17854
+#: cp/parser.c:17851
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "declaration %qD does not declare anything"
 msgstr "erklæring erklærer ikke noget"
 
-#: cp/parser.c:17942
+#: cp/parser.c:17939
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operation on uninstantiated type"
 msgid "attributes ignored on uninstantiated type"
 msgstr "ugyldig operation på uudskiftet type"
 
-#: cp/parser.c:17946
+#: cp/parser.c:17943
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `%D' applied to template instantiation"
 msgid "attributes ignored on template instantiation"
 msgstr "lagringsklasse '%D' anvendt på skabelonsinstantiering"
 
-#: cp/parser.c:17951
+#: cp/parser.c:17948
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr ""
 
-#: cp/parser.c:18085
+#: cp/parser.c:18082
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function template"
 msgid "%qD is an enumeration template"
 msgstr "'%D' er ikke en funktionsskabelon"
 
-#: cp/parser.c:18096
+#: cp/parser.c:18093
 #, fuzzy, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr "størrelse i tabel-new skal være en heltalstype"
 
-#: cp/parser.c:18111
+#: cp/parser.c:18108
 #, fuzzy, gcc-internal-format
 #| msgid "Min/max instructions not allowed"
 msgid "unnamed scoped enum is not allowed"
 msgstr "Min/max-instruktioner ikke tilladt"
 
-#: cp/parser.c:18166
+#: cp/parser.c:18163
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr ""
 
-#: cp/parser.c:18215
+#: cp/parser.c:18212
 #, fuzzy, gcc-internal-format
 #| msgid "Enable automatic template instantiation"
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "Aktivér automatisk skabelonsinstantiering"
 
-#: cp/parser.c:18229
+#: cp/parser.c:18226
 #, fuzzy, gcc-internal-format
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "friend-erklæringen er ikke i klassedefinitionen"
 
-#: cp/parser.c:18241 cp/parser.c:23070
+#: cp/parser.c:18238 cp/parser.c:23067
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' in `%D' which does not enclose `%D'"
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "erklæring af '%D' i '%D' som ikke omgiver '%D'"
 
-#: cp/parser.c:18246 cp/parser.c:23075
+#: cp/parser.c:18243 cp/parser.c:23072
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' in `%D' which does not enclose `%D'"
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "erklæring af '%D' i '%D' som ikke omgiver '%D'"
 
-#: cp/parser.c:18258 cp/parser.c:23089
+#: cp/parser.c:18255 cp/parser.c:23086
 #, fuzzy, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr "ekstra modifikation '%T::' af medlemmet '%D' ignoreret"
 
-#: cp/parser.c:18282
+#: cp/parser.c:18279
 #, fuzzy, gcc-internal-format
 #| msgid "multiple definition of `%#T'"
 msgid "multiple definition of %q#T"
 msgstr "flere definitioner af '%#T'"
 
-#: cp/parser.c:18295
+#: cp/parser.c:18292
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing an enum"
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO C++ forbyder %s af en enum"
 
-#: cp/parser.c:18315
+#: cp/parser.c:18312
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:18318
+#: cp/parser.c:18315
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:18497
+#: cp/parser.c:18494
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a namespace"
 msgid "%qD is not a namespace-name"
 msgstr "'%D' er ikke et navnerum"
 
-#: cp/parser.c:18503
+#: cp/parser.c:18500
 #, fuzzy, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "uventet operand"
 
-#: cp/parser.c:18570
+#: cp/parser.c:18567
 #, gcc-internal-format
 msgid "nested namespace definitions only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:18578
+#: cp/parser.c:18575
 #, fuzzy, gcc-internal-format
 msgid "nested namespace name required"
 msgstr "uventet operand"
 
-#: cp/parser.c:18583
+#: cp/parser.c:18580
 #, fuzzy, gcc-internal-format
 #| msgid "namespace `%T' undeclared"
 msgid "namespace name required"
 msgstr "navnerummet '%T' er ikke erklæret"
 
-#: cp/parser.c:18587
+#: cp/parser.c:18584
 #, fuzzy, gcc-internal-format
 #| msgid "Min/max instructions not allowed"
 msgid "a nested namespace definition cannot have attributes"
 msgstr "Min/max-instruktioner ikke tilladt"
 
-#: cp/parser.c:18590
+#: cp/parser.c:18587
 #, fuzzy, gcc-internal-format
 #| msgid "function with nested functions cannot be inline"
 msgid "a nested namespace definition cannot be inline"
 msgstr "funktion med indlejrede funktioner kan ikke indbygges"
 
-#: cp/parser.c:18597
+#: cp/parser.c:18594
 #, fuzzy, gcc-internal-format
 #| msgid "namespace `%T' undeclared"
 msgid "namespace %qD entered"
 msgstr "navnerummet '%T' er ikke erklæret"
 
-#: cp/parser.c:18652
+#: cp/parser.c:18649
 #, fuzzy, gcc-internal-format
 #| msgid "Min/max instructions not allowed"
 msgid "%<namespace%> definition is not allowed here"
 msgstr "Min/max-instruktioner ikke tilladt"
 
-#: cp/parser.c:18803
+#: cp/parser.c:18800
 #, gcc-internal-format
 msgid "pack expansion in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:18818
+#: cp/parser.c:18815
 #, fuzzy, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "navnerum '%D' ikke tilladt i using-erklæring"
 
-#: cp/parser.c:18865
+#: cp/parser.c:18862
 #, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:18875
+#: cp/parser.c:18872
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:18940
+#: cp/parser.c:18937
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:19106
+#: cp/parser.c:19103
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:19493
+#: cp/parser.c:19490
 #, fuzzy, gcc-internal-format
 #| msgid "%s: function definition not converted\n"
 msgid "a function-definition is not allowed here"
 msgstr "%s: funktionsdefinitionen er ikke omdannet\n"
 
-#: cp/parser.c:19504
+#: cp/parser.c:19501
 #, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr ""
 
-#: cp/parser.c:19508
+#: cp/parser.c:19505
 #, fuzzy, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "en global registervariabel følger en funktionsdefinition"
 
-#: cp/parser.c:19559
+#: cp/parser.c:19556
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
 #. Anything else is an error.
-#: cp/parser.c:19598 cp/parser.c:21906
+#: cp/parser.c:19595 cp/parser.c:21903
 #, fuzzy, gcc-internal-format
 #| msgid "empty scalar initializer"
 msgid "expected initializer"
 msgstr "tom skalarstartværdi"
 
-#: cp/parser.c:19679
+#: cp/parser.c:19676
 #, fuzzy, gcc-internal-format
 #| msgid "initializer specified for non-member function `%D'"
 msgid "initializer provided for function"
 msgstr "startværdi angivet for ikke-medlemsfunktion '%D'"
 
-#: cp/parser.c:19713
+#: cp/parser.c:19710
 #, fuzzy, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "egenskaber i parametertabelerklæring ignoreret"
 
-#: cp/parser.c:19727
+#: cp/parser.c:19724
 #, fuzzy, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr "funktionen '%s' omerklæret som inline"
 
-#: cp/parser.c:20169
+#: cp/parser.c:20166
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "array bound is not an integer constant"
 msgstr "tabelindeks er ikke et heltal"
 
-#: cp/parser.c:20295
+#: cp/parser.c:20292
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type `%T'"
 msgid "cannot define member of dependent typedef %qT"
 msgstr "opretter henvisning til medlemsreference af typen '%T'"
 
-#: cp/parser.c:20299
+#: cp/parser.c:20296
 #, fuzzy, gcc-internal-format
 #| msgid "`%D::%D' is not a template"
 msgid "%<%T::%E%> is not a type"
@@ -51171,17 +51218,17 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:20328
+#: cp/parser.c:20325
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr "ugyldig erklærer"
 
-#: cp/parser.c:20336
+#: cp/parser.c:20333
 #, fuzzy, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "ugyldig brug af ikke-statisk felt '%D'"
 
-#: cp/parser.c:20338
+#: cp/parser.c:20335
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr ""
@@ -51188,407 +51235,407 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:20410
+#: cp/parser.c:20407
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid declaration"
 msgid "qualified-id in declaration"
 msgstr "Ugyldig erklæring"
 
-#: cp/parser.c:20435
+#: cp/parser.c:20432
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "expected declarator"
 msgstr "tom erklæring"
 
-#: cp/parser.c:20554
+#: cp/parser.c:20551
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is a namespace"
 msgid "%qD is a namespace"
 msgstr "'%D' er et navnerum"
 
-#: cp/parser.c:20556
+#: cp/parser.c:20553
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type `%T'"
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "opretter henvisning til medlem af typen '%T' der ikke er en klasse"
 
-#: cp/parser.c:20577
+#: cp/parser.c:20574
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected ptr-operator"
 msgstr "uventet operand"
 
-#: cp/parser.c:20638
+#: cp/parser.c:20635
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate case value"
 msgid "duplicate cv-qualifier"
 msgstr "case-værdi optræder mere end én gang"
 
-#: cp/parser.c:20692
+#: cp/parser.c:20689
 #, fuzzy, gcc-internal-format
 #| msgid "multiple `virtual' specifiers"
 msgid "multiple ref-qualifiers"
 msgstr "mere end én 'virtual'-angivelse"
 
-#: cp/parser.c:20729
+#: cp/parser.c:20726
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr "--resource påkræver -o"
 
-#: cp/parser.c:20787
+#: cp/parser.c:20784
 #, fuzzy, gcc-internal-format
 #| msgid "multiple `virtual' specifiers"
 msgid "duplicate virt-specifier"
 msgstr "mere end én 'virtual'-angivelse"
 
-#: cp/parser.c:21025
+#: cp/parser.c:21022
 #, fuzzy, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr "skabelonsparameter er påkrævet for '%T'"
 
-#: cp/parser.c:21031 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2090
+#: cp/parser.c:21028 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2093
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `%T'"
 msgid "invalid use of %qT"
 msgstr "ugyldig brug af '%T'"
 
-#: cp/parser.c:21052
+#: cp/parser.c:21049
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:21057
+#: cp/parser.c:21054
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "ugyldig standardparameter i skabelon"
 
-#: cp/parser.c:21145
+#: cp/parser.c:21142
 #, fuzzy, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "uventet operand"
 
-#: cp/parser.c:21429
+#: cp/parser.c:21426
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr ""
 
-#: cp/parser.c:21504
+#: cp/parser.c:21501
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:21678
+#: cp/parser.c:21675
 #, fuzzy, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "standardparameter givet til %d. parameter for '%#D'"
 
-#: cp/parser.c:21696
+#: cp/parser.c:21693
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' cannot have default arguments"
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "'%D' kan ikke have standardparametre"
 
-#: cp/parser.c:21702
+#: cp/parser.c:21699
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "template parameter pack cannot have a default argument"
 msgstr "skabelonsparametre kan ikke være venner"
 
-#: cp/parser.c:21704
+#: cp/parser.c:21701
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' cannot have default arguments"
 msgid "parameter pack cannot have a default argument"
 msgstr "'%D' kan ikke have standardparametre"
 
-#: cp/parser.c:22131
+#: cp/parser.c:22128
 #, gcc-internal-format
 msgid "C++ designated initializers only available with -std=c++2a or -std=gnu++2a"
 msgstr ""
 
-#: cp/parser.c:22151
+#: cp/parser.c:22148
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr "ISO C++ tillader ikke udpegede startværdier"
 
-#: cp/parser.c:22189
+#: cp/parser.c:22186
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C++ tillader ikke udpegede startværdier"
 
-#: cp/parser.c:22203
+#: cp/parser.c:22200
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr ""
 
-#: cp/parser.c:22228
+#: cp/parser.c:22225
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "%<...%> not allowed in designated initializer list"
 msgstr "ISO C++ tillader ikke udpegede startværdier"
 
-#: cp/parser.c:22266
+#: cp/parser.c:22263
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr ""
 
-#: cp/parser.c:22322 cp/parser.c:22448
+#: cp/parser.c:22319 cp/parser.c:22445
 #, fuzzy, gcc-internal-format
 msgid "expected class-name"
 msgstr "uventet operand"
 
-#: cp/parser.c:22650
+#: cp/parser.c:22647
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "'%s' er erklæret inline efter dens definition"
 
-#: cp/parser.c:22653
+#: cp/parser.c:22650
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr ""
 
-#: cp/parser.c:22656
+#: cp/parser.c:22653
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "'%s' er erklæret inline efter dens definition"
 
-#: cp/parser.c:23012
+#: cp/parser.c:23009
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr ""
 
-#: cp/parser.c:23023
+#: cp/parser.c:23020
 #, fuzzy, gcc-internal-format
 #| msgid "cannot find file for class %s"
 msgid "cannot specify %<override%> for a class"
 msgstr "kan ikke finde filen for klassen %s"
 
-#: cp/parser.c:23031
+#: cp/parser.c:23028
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:23038
+#: cp/parser.c:23035
 #, fuzzy, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "friend-erklæringen er ikke i klassedefinitionen"
 
-#: cp/parser.c:23050
+#: cp/parser.c:23047
 #, fuzzy, gcc-internal-format
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr "bruger 'typename' uden for en skabelon"
 
-#: cp/parser.c:23056
+#: cp/parser.c:23053
 #, fuzzy, gcc-internal-format
 #| msgid "invalid redeclaration of `%D'"
 msgid "invalid class name in declaration of %qD"
 msgstr "ugyldig omerklæring af '%D'"
 
-#: cp/parser.c:23114
+#: cp/parser.c:23111
 #, fuzzy, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "eksplicit specialisering følger ikke efter 'template <>'"
 
-#: cp/parser.c:23146
+#: cp/parser.c:23143
 #, fuzzy, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "ikke-skabelon benyttet som skabelon"
 
-#: cp/parser.c:23182
+#: cp/parser.c:23179
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr ""
 
-#: cp/parser.c:23241
+#: cp/parser.c:23238
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of `%#T'"
 msgid "previous definition of %q#T"
 msgstr "tidligere definition af '%#T'"
 
-#: cp/parser.c:23331 cp/parser.c:28499
+#: cp/parser.c:23328 cp/parser.c:28496
 #, fuzzy, gcc-internal-format
 msgid "expected class-key"
 msgstr "uventet operand"
 
-#: cp/parser.c:23355
+#: cp/parser.c:23352
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:23359
+#: cp/parser.c:23356
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "uventet operand"
 
-#: cp/parser.c:23605
+#: cp/parser.c:23602
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr ""
 
-#: cp/parser.c:23623
+#: cp/parser.c:23620
 #, fuzzy, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "friend-erklæringen er ikke i klassedefinitionen"
 
-#: cp/parser.c:23641
+#: cp/parser.c:23638
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:23738
+#: cp/parser.c:23735
 #, gcc-internal-format
 msgid "default member initializers for bit-fields only available with -std=c++2a or -std=gnu++2a"
 msgstr ""
 
-#: cp/parser.c:23745
+#: cp/parser.c:23742
 #, fuzzy, gcc-internal-format
 #| msgid "`__alignof' applied to a bit-field"
 msgid "default member initializer for unnamed bit-field"
 msgstr "'__alignof' benyttet på et bitfelt"
 
-#: cp/parser.c:23758
+#: cp/parser.c:23755
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr ""
 
-#: cp/parser.c:23903
+#: cp/parser.c:23900
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr ""
 
-#: cp/parser.c:23923
+#: cp/parser.c:23920
 #, fuzzy, gcc-internal-format
 msgid "extra %<;%> after in-class function definition"
 msgstr "'%s' er erklæret inline efter dens definition"
 
-#: cp/parser.c:23970
+#: cp/parser.c:23967
 #, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr ""
 
-#: cp/parser.c:23984
+#: cp/parser.c:23981
 #, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr ""
 
-#: cp/parser.c:24058
+#: cp/parser.c:24055
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr ""
 
-#: cp/parser.c:24093
+#: cp/parser.c:24090
 #, fuzzy, gcc-internal-format
 #| msgid "brace-enclosed initializer used to initialize `%T'"
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "startværdi i krøllede paranteser benyttet til at klargøre '%T'"
 
-#: cp/parser.c:24223
+#: cp/parser.c:24220
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr ""
 
-#: cp/parser.c:24243
+#: cp/parser.c:24240
 #, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr ""
 
-#: cp/parser.c:24267
+#: cp/parser.c:24264
 #, fuzzy, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "bruger 'typename' uden for en skabelon"
 
-#: cp/parser.c:24270
+#: cp/parser.c:24267
 #, fuzzy, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "bruger 'typename' uden for en skabelon"
 
-#: cp/parser.c:24364 cp/parser.c:24442
+#: cp/parser.c:24361 cp/parser.c:24439
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:24450
+#: cp/parser.c:24447
 #, fuzzy, gcc-internal-format
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "Generér ikke kode til at kontrollere undtagelsesspecifikationer"
 
-#: cp/parser.c:24456
+#: cp/parser.c:24453
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr ""
 
-#: cp/parser.c:24500
+#: cp/parser.c:24497
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of void expression"
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "ugyldig brug af void-udtryk"
 
-#: cp/parser.c:24539
+#: cp/parser.c:24536
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:24650
+#: cp/parser.c:24647
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:25203
+#: cp/parser.c:25200
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to variables"
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr "egenskaben '%s' kan kun anvendes på variabler"
 
-#: cp/parser.c:25217
+#: cp/parser.c:25214
 #, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr ""
 
-#: cp/parser.c:25301
+#: cp/parser.c:25298
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:25305
+#: cp/parser.c:25302
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:25342
+#: cp/parser.c:25339
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected attribute before %<...%>"
 msgstr "uventet operand"
 
-#: cp/parser.c:25403
+#: cp/parser.c:25400
 #, gcc-internal-format
 msgid "attribute using prefix only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:25721
+#: cp/parser.c:25718
 #, gcc-internal-format
 msgid "%<requires%> only available with -fconcepts"
 msgstr ""
 
-#: cp/parser.c:25753
+#: cp/parser.c:25750
 #, fuzzy, gcc-internal-format
 msgid "a requires expression cannot appear outside a template"
 msgstr "overløb i konstant udtryk"
 
-#: cp/parser.c:26467
+#: cp/parser.c:26464
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:26472
+#: cp/parser.c:26469
 #, fuzzy, gcc-internal-format
 #| msgid "invalid redeclaration of `%D'"
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "ugyldig omerklæring af '%D'"
 
-#: cp/parser.c:26476
+#: cp/parser.c:26473
 #, fuzzy, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "for få skabelonsparameterlister angivet i erklæring af '%D'"
@@ -51597,427 +51644,427 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:26483
+#: cp/parser.c:26480
 #, fuzzy, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "for mange skabelonsparameterlister angivet i erklæring af '%D'"
 
-#: cp/parser.c:26832
+#: cp/parser.c:26829
 #, fuzzy, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "--driver understøttes ikke længere"
 
-#: cp/parser.c:26991
+#: cp/parser.c:26988
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr ""
 
-#: cp/parser.c:26996
+#: cp/parser.c:26993
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr ""
 
-#: cp/parser.c:27066
+#: cp/parser.c:27063
 #, fuzzy, gcc-internal-format
 #| msgid "Enable multiply instructions"
 msgid "empty introduction-list"
 msgstr "Aktiver multiply-instruktioner"
 
-#: cp/parser.c:27090
+#: cp/parser.c:27087
 #, fuzzy, gcc-internal-format
 #| msgid "no matching template for `%D' found"
 msgid "no matching concept for template-introduction"
 msgstr "ingen passende skabelon for '%D' fundet"
 
-#: cp/parser.c:27112
+#: cp/parser.c:27109
 #, fuzzy, gcc-internal-format
 #| msgid "invalid declaration of member template `%#D' in local class"
 msgid "invalid declaration of member template in local class"
 msgstr "ugyldig erklæring af medlemsskabelon '%#D' i lokal klasse"
 
-#: cp/parser.c:27121
+#: cp/parser.c:27118
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "skabelon med C-kædning"
 
-#: cp/parser.c:27141
+#: cp/parser.c:27138
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization here"
 msgid "invalid explicit specialization"
 msgstr "eksplicit specialisering her"
 
-#: cp/parser.c:27245
+#: cp/parser.c:27242
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of `%#D'"
 msgid "template declaration of %<typedef%>"
 msgstr "skabelonserklæring af '%#D'"
 
-#: cp/parser.c:27296
+#: cp/parser.c:27293
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "a class template declaration must not declare anything else"
 msgstr "erklæring erklærer ikke noget"
 
-#: cp/parser.c:27342
+#: cp/parser.c:27339
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization here"
 msgid "explicit template specialization cannot have a storage class"
 msgstr "eksplicit specialisering her"
 
-#: cp/parser.c:27650
+#: cp/parser.c:27647
 #, fuzzy, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "'>>' skulle have været '> >' i skabelonsklassenavn"
 
-#: cp/parser.c:27663
+#: cp/parser.c:27660
 #, fuzzy, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "'>>' skulle have været '> >' i skabelonsklassenavn"
 
-#: cp/parser.c:27958
+#: cp/parser.c:27955
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:28118
+#: cp/parser.c:28115
 #, fuzzy, gcc-internal-format
 #| msgid "invalid base-class specification"
 msgid "invalid use of %qD in linkage specification"
 msgstr "ugyldig stamklasseangivelse"
 
-#: cp/parser.c:28133
+#: cp/parser.c:28130
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> før %qD"
 
-#: cp/parser.c:28267
+#: cp/parser.c:28264
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ 1998 understøtter ikke %<long long%>"
 
-#: cp/parser.c:28275
+#: cp/parser.c:28272
 #, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr ""
 
-#: cp/parser.c:28280
+#: cp/parser.c:28277
 #, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "duplikere %qD"
 
-#: cp/parser.c:28304
+#: cp/parser.c:28301
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "duplikere %qs"
 
-#: cp/parser.c:28356
+#: cp/parser.c:28353
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "forventede %<new%>"
 
-#: cp/parser.c:28359
+#: cp/parser.c:28356
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "forventede %<delete%>"
 
-#: cp/parser.c:28362
+#: cp/parser.c:28359
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "forventede %<return%>"
 
-#: cp/parser.c:28368
+#: cp/parser.c:28365
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "forventede %<extern%>"
 
-#: cp/parser.c:28371
+#: cp/parser.c:28368
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "forventede %<static_assert%>"
 
-#: cp/parser.c:28374
+#: cp/parser.c:28371
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "forventede %<decltype%>"
 
-#: cp/parser.c:28377
+#: cp/parser.c:28374
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "forventede %<operator%>"
 
-#: cp/parser.c:28380
+#: cp/parser.c:28377
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "forventede %<class%>"
 
-#: cp/parser.c:28383
+#: cp/parser.c:28380
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "forventede %<template%>"
 
-#: cp/parser.c:28386
+#: cp/parser.c:28383
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "forventede %<namespace%>"
 
-#: cp/parser.c:28389
+#: cp/parser.c:28386
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "forventede %<using%>"
 
-#: cp/parser.c:28392
+#: cp/parser.c:28389
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "forventede %<asm%>"
 
-#: cp/parser.c:28395
+#: cp/parser.c:28392
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "forventede %<try%>"
 
-#: cp/parser.c:28398
+#: cp/parser.c:28395
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "forventede %<catch%>"
 
-#: cp/parser.c:28401
+#: cp/parser.c:28398
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "forventede %<throw%>"
 
-#: cp/parser.c:28404
+#: cp/parser.c:28401
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "forventede %<__label__%>"
 
-#: cp/parser.c:28407
+#: cp/parser.c:28404
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "forventede %<@try%>"
 
-#: cp/parser.c:28410
+#: cp/parser.c:28407
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "forventede %<@synchronized%>"
 
-#: cp/parser.c:28413
+#: cp/parser.c:28410
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "forventede %<@throw%>"
 
-#: cp/parser.c:28416
+#: cp/parser.c:28413
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "forventede %<__transaction_atomic%>"
 
-#: cp/parser.c:28419
+#: cp/parser.c:28416
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "forventede %<__transaction_relaxed%>"
 
-#: cp/parser.c:28451
+#: cp/parser.c:28448
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "forventede %<::%>"
 
-#: cp/parser.c:28463
+#: cp/parser.c:28460
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "forventede %<...%>"
 
-#: cp/parser.c:28466
+#: cp/parser.c:28463
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "forventede %<*%>"
 
-#: cp/parser.c:28469
+#: cp/parser.c:28466
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "forventede %<~%>"
 
-#: cp/parser.c:28475
+#: cp/parser.c:28472
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "forventede %<:%> or %<::%>"
 
-#: cp/parser.c:28502
+#: cp/parser.c:28499
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "forventede %<class%>, %<typename%>, eller %<template%>"
 
-#: cp/parser.c:28772
+#: cp/parser.c:28769
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' tag used in naming `%#T'"
 msgid "%qs tag used in naming %q#T"
 msgstr "'%s'-mærke benyttet i navngivning af '%#T'"
 
-#: cp/parser.c:28777
+#: cp/parser.c:28774
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' previously declared here"
 msgid "%q#T was previously declared here"
 msgstr "'%s' tidligere erklæret her"
 
-#: cp/parser.c:28798
+#: cp/parser.c:28795
 #, fuzzy, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "'%#D' omerklæret som en anden form for symbol"
 
-#: cp/parser.c:28819
+#: cp/parser.c:28816
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr ""
 
-#: cp/parser.c:29062
+#: cp/parser.c:29059
 #, fuzzy, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "%Hslutningen af filen læst inden i standardparameter"
 
-#: cp/parser.c:29303 cp/parser.c:30620 cp/parser.c:30808
+#: cp/parser.c:29300 cp/parser.c:30617 cp/parser.c:30805
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr ""
 
-#: cp/parser.c:29372
+#: cp/parser.c:29369
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr ""
 
-#: cp/parser.c:29442
+#: cp/parser.c:29439
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:29473
+#: cp/parser.c:29470
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr ""
 
-#: cp/parser.c:29883
+#: cp/parser.c:29880
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr ""
 
-#: cp/parser.c:29958 cp/parser.c:29976
+#: cp/parser.c:29955 cp/parser.c:29973
 #, fuzzy, gcc-internal-format
 #| msgid "Class or interface declaration expected"
 msgid "objective-c++ method declaration is expected"
 msgstr "Klasse- eller grænsefladeerklæring forventet"
 
-#: cp/parser.c:29970 cp/parser.c:30035
+#: cp/parser.c:29967 cp/parser.c:30032
 #, fuzzy, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "sektionsegenskaben kan ikke angives for lokale variabler"
 
-#: cp/parser.c:30078
+#: cp/parser.c:30075
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:30284 cp/parser.c:30291 cp/parser.c:30298
+#: cp/parser.c:30281 cp/parser.c:30288 cp/parser.c:30295
 #, fuzzy, gcc-internal-format
 #| msgid "invalid register name `%s' for register variable"
 msgid "invalid type for instance variable"
 msgstr "ugyldigt registernavn '%s' for registervariabel"
 
-#: cp/parser.c:30413
+#: cp/parser.c:30410
 #, fuzzy, gcc-internal-format
 #| msgid "Identifier expected"
 msgid "identifier expected after %<@protocol%>"
 msgstr "Kaldenavn forventet"
 
-#: cp/parser.c:30585
+#: cp/parser.c:30582
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:30592
+#: cp/parser.c:30589
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored for `%s'"
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "'%s'-egenskaben ignoreret for '%s'"
 
-#: cp/parser.c:30867 cp/parser.c:30874 cp/parser.c:30881
+#: cp/parser.c:30864 cp/parser.c:30871 cp/parser.c:30878
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "invalid type for property"
 msgstr "ugyldig typeparameter"
 
-#: cp/parser.c:32011
+#: cp/parser.c:32008
 #, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr ""
 
-#: cp/parser.c:32724
+#: cp/parser.c:32721
 #, fuzzy, gcc-internal-format
 #| msgid "invalid identifier `%s'"
 msgid "invalid reduction-identifier"
 msgstr "ugyldigt kaldenavn '%s'"
 
-#: cp/parser.c:34911
+#: cp/parser.c:34908
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:35231 cp/pt.c:16392
+#: cp/parser.c:35228 cp/pt.c:16414
 #, fuzzy, gcc-internal-format
 #| msgid "register variable `%s' used in nested function"
 msgid "iteration variable %qD should not be reduction"
 msgstr "registervariabel '%s' benyttet i indlejret funktion"
 
-#: cp/parser.c:35316
+#: cp/parser.c:35313
 #, fuzzy, gcc-internal-format
 #| msgid "not enough type information"
 msgid "not enough for loops to collapse"
 msgstr "ikke tilstrækkelig information om typen"
 
-#: cp/parser.c:37521
+#: cp/parser.c:37518
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer clause"
 msgstr "ugyldig startværdi"
 
-#: cp/parser.c:37549
+#: cp/parser.c:37546
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected side-effects in address"
 msgid "expected id-expression (arguments)"
 msgstr "uventede bivirkninger i adresse"
 
-#: cp/parser.c:37561
+#: cp/parser.c:37558
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:37662
+#: cp/parser.c:37659
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:37682 cp/semantics.c:5405
+#: cp/parser.c:37679 cp/semantics.c:5408
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37687 cp/semantics.c:5414
+#: cp/parser.c:37684 cp/semantics.c:5417
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37690 cp/pt.c:12944 cp/semantics.c:5420
+#: cp/parser.c:37687 cp/pt.c:12966 cp/semantics.c:5423
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37693 cp/semantics.c:5426
+#: cp/parser.c:37690 cp/semantics.c:5429
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:38047
+#: cp/parser.c:38044
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:38057
+#: cp/parser.c:38054
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a member template function"
 msgid "%qD does not refer to a namespace scope function"
@@ -52024,50 +52071,50 @@
 msgstr "'%D' er ikke en medlemsskabelonfunktion"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:38392
+#: cp/parser.c:38389
 #, gcc-internal-format
 msgid "atomic_cancel"
 msgstr ""
 
-#: cp/parser.c:38435 cp/semantics.c:8575
+#: cp/parser.c:38432 cp/semantics.c:8578
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:38437 cp/semantics.c:8577
+#: cp/parser.c:38434 cp/semantics.c:8580
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:38631
+#: cp/parser.c:38628
 #, fuzzy, gcc-internal-format
 #| msgid "junk at end of #pragma GCC java_exceptions"
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "ragelse i slutningen af #pragma GCC java_exceptions"
 
-#: cp/parser.c:38927
+#: cp/parser.c:38924
 #, fuzzy, gcc-internal-format
 #| msgid "braced-group within expression allowed only inside a function"
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "sætningsblokke i udtryk er kun tilladt inde i en funktion"
 
-#: cp/parser.c:38959
+#: cp/parser.c:38956
 #, fuzzy, gcc-internal-format
 #| msgid "braced-group within expression allowed only inside a function"
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr "sætningsblokke i udtryk er kun tilladt inde i en funktion"
 
-#: cp/parser.c:39039
+#: cp/parser.c:39036
 #, fuzzy, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "profilering understøttes ikke endnu"
 
-#: cp/parser.c:39295
+#: cp/parser.c:39292
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:39351
+#: cp/parser.c:39348
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
@@ -52169,7 +52216,7 @@
 msgid "specialization of %qD after instantiation"
 msgstr "specialisering af '%D' efter instantiering"
 
-#: cp/pt.c:1954 cp/semantics.c:5274
+#: cp/pt.c:1954 cp/semantics.c:5277
 #, fuzzy, gcc-internal-format
 #| msgid "%s %+#D"
 msgid "%s %#qD"
@@ -52355,115 +52402,115 @@
 msgid "argument to __integer_pack must be between 0 and %d"
 msgstr "parameteren til 'asm' er ikke en konstant streng"
 
-#: cp/pt.c:3942
+#: cp/pt.c:3955
 #, gcc-internal-format
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr ""
 
-#: cp/pt.c:4010
+#: cp/pt.c:4023
 #, fuzzy, gcc-internal-format
 #| msgid "data member `%D' cannot be a member template"
 msgid "expansion pattern %qT contains no argument packs"
 msgstr "datamedlem '%D' kan ikke være en medlemsskabelon"
 
-#: cp/pt.c:4012
+#: cp/pt.c:4025
 #, fuzzy, gcc-internal-format
 #| msgid "data member `%D' cannot be a member template"
 msgid "expansion pattern %qE contains no argument packs"
 msgstr "datamedlem '%D' kan ikke være en medlemsskabelon"
 
-#: cp/pt.c:4063
+#: cp/pt.c:4077
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr ""
 
-#: cp/pt.c:4080 cp/pt.c:4835
+#: cp/pt.c:4094 cp/pt.c:4849
 #, fuzzy, gcc-internal-format
 #| msgid "        `%D'"
 msgid "        %qD"
 msgstr "        '%D'"
 
-#: cp/pt.c:4082
+#: cp/pt.c:4096
 #, fuzzy, gcc-internal-format
 msgid "        <anonymous>"
 msgstr "<anonym %s>"
 
-#: cp/pt.c:4208
+#: cp/pt.c:4222
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D' shadows a parameter"
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr "erklæring af '%#D' skygger for en parameter"
 
-#: cp/pt.c:4211
+#: cp/pt.c:4225
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D' shadows a parameter"
 msgid "declaration of %q+#D shadows template parameter"
 msgstr "erklæring af '%#D' skygger for en parameter"
 
-#: cp/pt.c:4213
+#: cp/pt.c:4227
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter type `%T' declared `friend'"
 msgid "template parameter %qD declared here"
 msgstr "skabelonsparametertypen '%T' erklæret 'friend'"
 
-#: cp/pt.c:4771
+#: cp/pt.c:4785
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template `%#D'"
 msgid "specialization of variable concept %q#D"
 msgstr "erklæring af skabelon '%#D'"
 
-#: cp/pt.c:4830
+#: cp/pt.c:4844
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "template parameters not deducible in partial specialization:"
 msgstr "skabelonsparametre der ikke bruges i partiel specialisering:"
 
-#: cp/pt.c:4854
+#: cp/pt.c:4868
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization `%T' does not specialize any template arguments"
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr "den partielle specialisering '%T' specialiserer ikke nogen skabelonsparametre"
 
-#: cp/pt.c:4858
+#: cp/pt.c:4872
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization `%T' does not specialize any template arguments"
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr "den partielle specialisering '%T' specialiserer ikke nogen skabelonsparametre"
 
-#: cp/pt.c:4862 cp/pt.c:4873
+#: cp/pt.c:4876 cp/pt.c:4887
 #, gcc-internal-format
 msgid "primary template here"
 msgstr ""
 
-#: cp/pt.c:4870
+#: cp/pt.c:4884
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:4885
+#: cp/pt.c:4899
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization `%T' does not specialize any template arguments"
 msgid "partial specialization %qD is not more specialized than"
 msgstr "den partielle specialisering '%T' specialiserer ikke nogen skabelonsparametre"
 
-#: cp/pt.c:4887
+#: cp/pt.c:4901
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate label `%D'"
 msgid "primary template %qD"
 msgstr "etiketten '%D' optræder mere end én gang"
 
-#: cp/pt.c:4934
+#: cp/pt.c:4948
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:4937
+#: cp/pt.c:4951
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr ""
 
 # flertalsform unødvendig
-#: cp/pt.c:4958
+#: cp/pt.c:4972
 #, fuzzy, gcc-internal-format
 #| msgid "template argument `%E' involves template parameter(s)"
 msgid "template argument %qE involves template parameter(s)"
@@ -52470,7 +52517,7 @@
 msgstr "skabelonsparameter '%E' involverer skabelonsparameter"
 
 # flertalsform unødvendig
-#: cp/pt.c:5004
+#: cp/pt.c:5018
 #, fuzzy, gcc-internal-format
 #| msgid "type `%T' of template argument `%E' depends on template parameter(s)"
 msgid "type %qT of template argument %qE depends on a template parameter"
@@ -52478,19 +52525,19 @@
 msgstr[0] "typen '%T' af skabelonsparameteren '%E' afhænger af skabelonsparameter"
 msgstr[1] "typen '%T' af skabelonsparameteren '%E' afhænger af skabelonsparameter"
 
-#: cp/pt.c:5066
+#: cp/pt.c:5080
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for `%#T'"
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "tvetydig klasseskabelonsinstantiering for '%#T'"
 
-#: cp/pt.c:5070
+#: cp/pt.c:5084
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %D after instantiation"
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "specialisering af '%D' efter instantiering"
 
-#: cp/pt.c:5247
+#: cp/pt.c:5261
 #, fuzzy, gcc-internal-format
 #| msgid "no default argument for `%D'"
 msgid "no default argument for %qD"
@@ -52499,52 +52546,52 @@
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5269
+#: cp/pt.c:5283
 #, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr ""
 
-#: cp/pt.c:5305
+#: cp/pt.c:5319
 #, fuzzy, gcc-internal-format
 #| msgid "default arguments are not allowed in declaration of friend template specialization `%D'"
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "standardparametre er ikke tilladt i erklæring af venneskabelonsspecialisering '%D'"
 
-#: cp/pt.c:5308
+#: cp/pt.c:5322
 #, fuzzy, gcc-internal-format
 #| msgid "default arguments are not allowed in declaration of friend template specialization `%D'"
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "standardparametre er ikke tilladt i erklæring af venneskabelonsspecialisering '%D'"
 
-#: cp/pt.c:5311
+#: cp/pt.c:5325
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/pt.c:5314
+#: cp/pt.c:5328
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "default template arguments may not be used in partial specializations"
 msgstr "skabelonsparametre der ikke bruges i partiel specialisering:"
 
-#: cp/pt.c:5317 cp/pt.c:5375
+#: cp/pt.c:5331 cp/pt.c:5389
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for parameter of type `%T' has type `%T'"
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "standardparameter for parameter af typen '%T' har typen '%T'"
 
-#: cp/pt.c:5489
+#: cp/pt.c:5503
 #, fuzzy, gcc-internal-format
 #| msgid "parameter `%D' declared void"
 msgid "template %qD declared"
 msgstr "parameteren '%D' erklæret void"
 
-#: cp/pt.c:5496
+#: cp/pt.c:5510
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "skabelonsklasse uden et navn"
 
-#: cp/pt.c:5504
+#: cp/pt.c:5518
 #, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr ""
@@ -52554,66 +52601,66 @@
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5526
+#: cp/pt.c:5540
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member template declaration `%D'"
 msgid "invalid template declaration of %qD"
 msgstr "ugyldig medlemsskabelonerklæring '%D'"
 
-#: cp/pt.c:5669
+#: cp/pt.c:5683
 #, fuzzy, gcc-internal-format
 #| msgid "template definition of non-template `%#D'"
 msgid "template definition of non-template %q#D"
 msgstr "skabelonsdefinition af ikke-skabelon '%#D'"
 
-#: cp/pt.c:5712
+#: cp/pt.c:5726
 #, fuzzy, gcc-internal-format
 #| msgid "expected %d levels of template parms for `%#D', got %d"
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "forvented %d niveauer af skabelonsparametre for '%#D', modtog %d"
 
-#: cp/pt.c:5726
+#: cp/pt.c:5740
 #, fuzzy, gcc-internal-format
 #| msgid "got %d template parameters for `%#D'"
 msgid "got %d template parameters for %q#D"
 msgstr "modtog %d skabelonsparametre for '%#D'"
 
-#: cp/pt.c:5729
+#: cp/pt.c:5743
 #, fuzzy, gcc-internal-format
 #| msgid "got %d template parameters for `%#T'"
 msgid "got %d template parameters for %q#T"
 msgstr "modtog %d skabelonsparametre for '%#T'"
 
-#: cp/pt.c:5731
+#: cp/pt.c:5745
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  men %d påkrævet"
 
-#: cp/pt.c:5752
+#: cp/pt.c:5766
 #, fuzzy, gcc-internal-format
 #| msgid "template-id `%D' for `%+D' does not match any template declaration"
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "skabelons-id '%D' for '%+D' passer ikke til nogen skabelonserklæring"
 
-#: cp/pt.c:5755
+#: cp/pt.c:5769
 #, fuzzy, gcc-internal-format
 #| msgid "enclosing class templates are not explicitly specialized"
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "omgivende klasseskabeloner er ikke eksplicit specialiserede"
 
-#: cp/pt.c:5882
+#: cp/pt.c:5896
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a template type"
 msgid "%qT is not a template type"
 msgstr "'%T' er ikke en skabelonstype"
 
-#: cp/pt.c:5895
+#: cp/pt.c:5909
 #, fuzzy, gcc-internal-format
 #| msgid "too few template parameter lists in declaration of `%D'"
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "for få skabelonsparameterlister angivet i erklæring af '%D'"
 
-#: cp/pt.c:5906
+#: cp/pt.c:5920
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "`%D' used without template parameters"
 msgid "redeclared with %d template parameter"
@@ -52621,7 +52668,7 @@
 msgstr[0] "'%D' benyttet uden skabelonsparametre"
 msgstr[1] "'%D' benyttet uden skabelonsparametre"
 
-#: cp/pt.c:5910
+#: cp/pt.c:5924
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration `%#D' here"
 msgid "previous declaration %qD used %d template parameter"
@@ -52629,13 +52676,13 @@
 msgstr[0] "tidligere erklæring af '%#D' her"
 msgstr[1] "tidligere erklæring af '%#D' her"
 
-#: cp/pt.c:5947
+#: cp/pt.c:5961
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter `%#D'"
 msgid "template parameter %q+#D"
 msgstr "skabelonsparameter '%#D'"
 
-#: cp/pt.c:5948
+#: cp/pt.c:5962
 #, fuzzy, gcc-internal-format
 #| msgid "redeclared here as `%#D'"
 msgid "redeclared here as %q#D"
@@ -52645,130 +52692,130 @@
 #.
 #. A template-parameter may not be given default arguments
 #. by two different declarations in the same scope.
-#: cp/pt.c:5958
+#: cp/pt.c:5972
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for `%#D'"
 msgid "redefinition of default argument for %q#D"
 msgstr "omdefinering af standardparameter for '%#D'"
 
-#: cp/pt.c:5960
+#: cp/pt.c:5974
 #, fuzzy, gcc-internal-format
 msgid "original definition appeared here"
 msgstr "  oprindelig definition er her"
 
-#: cp/pt.c:5988
+#: cp/pt.c:6002
 #, fuzzy, gcc-internal-format
 msgid "redeclaration %q#D with different constraints"
 msgstr "'%#D' omerklæret som en anden form for symbol"
 
-#: cp/pt.c:5991
+#: cp/pt.c:6005
 #, fuzzy, gcc-internal-format
 msgid "original declaration appeared here"
 msgstr "  oprindelig definition er her"
 
-#: cp/pt.c:6250 cp/pt.c:6318
+#: cp/pt.c:6264 cp/pt.c:6332
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' is not a valid template argument"
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "'%E' er ikke en gyldig skabelonsparameter"
 
-#: cp/pt.c:6253
+#: cp/pt.c:6267
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr "den skal være adressen af en funktion med ekstern kædning"
 
-#: cp/pt.c:6256
+#: cp/pt.c:6270
 #, fuzzy, gcc-internal-format
 #| msgid "it must be the address of a function with external linkage"
 msgid "it must be the name of a function with external linkage"
 msgstr "den skal være adressen af en funktion med ekstern kædning"
 
-#: cp/pt.c:6268
+#: cp/pt.c:6282
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.c:6272
+#: cp/pt.c:6286
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.c:6321
+#: cp/pt.c:6335
 #, fuzzy, gcc-internal-format
 #| msgid "it must be a pointer-to-member of the form `&X::Y'"
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "den skal være en henvisning til medlem på formen '&X::Y'"
 
-#: cp/pt.c:6323
+#: cp/pt.c:6337
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a member of `%T'"
 msgid "because it is a member of %qT"
 msgstr "'%D' er ikke et medlem af '%T'"
 
-#: cp/pt.c:6383
+#: cp/pt.c:6397
 #, fuzzy, gcc-internal-format
 #| msgid "got %d template parameters for `%#D'"
 msgid "  couldn't deduce template parameter %qD"
 msgstr "modtog %d skabelonsparametre for '%#D'"
 
-#: cp/pt.c:6392
+#: cp/pt.c:6406
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.c:6401
+#: cp/pt.c:6415
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between types `%#T' and `%#T'"
 msgid "  mismatched types %qT and %qT"
 msgstr "sammenligning mellem typerne '%#T' og '%#T'"
 
-#: cp/pt.c:6410
+#: cp/pt.c:6424
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr ""
 
 # flertalsform unødvendig
-#: cp/pt.c:6421
+#: cp/pt.c:6435
 #, fuzzy, gcc-internal-format
 #| msgid "template argument `%E' involves template parameter(s)"
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "skabelonsparameter '%E' involverer skabelonsparameter"
 
-#: cp/pt.c:6431
+#: cp/pt.c:6445
 #, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr ""
 
-#: cp/pt.c:6440
+#: cp/pt.c:6454
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:6452
+#: cp/pt.c:6466
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.c:6456
+#: cp/pt.c:6470
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.c:6467
+#: cp/pt.c:6481
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' is not a valid template argument"
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "'%E' er ikke en gyldig skabelonsparameter"
 
-#: cp/pt.c:6478
+#: cp/pt.c:6492
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' is not a valid template argument"
 msgid "  member function type %qT is not a valid template argument"
 msgstr "'%E' er ikke en gyldig skabelonsparameter"
 
-#: cp/pt.c:6490
+#: cp/pt.c:6504
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
@@ -52775,331 +52822,331 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/pt.c:6521
+#: cp/pt.c:6535
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert type `%T' to type `%T'"
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "kan ikke konvertere typen '%T' til typen '%T'"
 
-#: cp/pt.c:6534
+#: cp/pt.c:6548
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is an ambiguous base of `%T'"
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "'%T' er en tvetydig stamklasse til '%T'"
 
-#: cp/pt.c:6538
+#: cp/pt.c:6552
 #, fuzzy, gcc-internal-format
 #| msgid "type `%T' is not derived from type `%T'"
 msgid "  %qT is not derived from %qT"
 msgstr "typen '%T' er ikke nedarvet fra typen '%T'"
 
-#: cp/pt.c:6549
+#: cp/pt.c:6563
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.c:6559
+#: cp/pt.c:6573
 #, gcc-internal-format
 msgid "  can't deduce a template for %qT from non-template type %qT"
 msgstr ""
 
-#: cp/pt.c:6569
+#: cp/pt.c:6583
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "  template argument %qE does not match %qE"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/pt.c:6609
+#: cp/pt.c:6623
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.c:6758
+#: cp/pt.c:6772
 #, fuzzy, gcc-internal-format
 msgid "in template argument for type %qT"
 msgstr "skabelonsparameter er påkrævet for '%T'"
 
-#: cp/pt.c:6772
+#: cp/pt.c:6786
 #, fuzzy, gcc-internal-format
 msgid "template argument %qE for type %qT not a constant integer"
 msgstr "skabelonsparameter er påkrævet for '%T'"
 
-#: cp/pt.c:6833
+#: cp/pt.c:6847
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.c:6841
+#: cp/pt.c:6855
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.c:6857
+#: cp/pt.c:6871
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.c:6864
+#: cp/pt.c:6878
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.c:6873
+#: cp/pt.c:6887
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.c:6888
+#: cp/pt.c:6902
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' is not a valid template argument"
 msgid "the address of %qD is not a valid template argument"
 msgstr "'%E' er ikke en gyldig skabelonsparameter"
 
-#: cp/pt.c:6897
+#: cp/pt.c:6911
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' is not a valid template argument"
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr "'%E' er ikke en gyldig skabelonsparameter"
 
-#: cp/pt.c:6904
+#: cp/pt.c:6918
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.c:6933
+#: cp/pt.c:6947
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr ""
 
-#: cp/pt.c:6941
+#: cp/pt.c:6955
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.c:6959
+#: cp/pt.c:6973
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr ""
 
-#: cp/pt.c:6975
+#: cp/pt.c:6989
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument for type %qT because it is not an object with linkage"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.c:6986
+#: cp/pt.c:7000
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument for type %qT because object %qD does not have linkage"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.c:7036
+#: cp/pt.c:7050
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' is not a valid template argument"
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "'%E' er ikke en gyldig skabelonsparameter"
 
-#: cp/pt.c:7038
+#: cp/pt.c:7052
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr ""
 
-#: cp/pt.c:7092
+#: cp/pt.c:7106
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' is not a valid template argument"
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "'%E' er ikke en gyldig skabelonsparameter"
 
-#: cp/pt.c:7654
+#: cp/pt.c:7668
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr ""
 
-#: cp/pt.c:7670
+#: cp/pt.c:7684
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `%D' applied to template instantiation"
 msgid "ignoring attributes in template argument %qE"
 msgstr "lagringsklasse '%D' anvendt på skabelonsinstantiering"
 
-#: cp/pt.c:7805
+#: cp/pt.c:7819
 #, fuzzy, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "ugyldig standardparameter i skabelon"
 
-#: cp/pt.c:7834
+#: cp/pt.c:7848
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `restrict'"
 msgid "invalid use of destructor %qE as a type"
 msgstr "ugyldig brug af 'restrict'"
 
-#: cp/pt.c:7839
+#: cp/pt.c:7853
 #, fuzzy, gcc-internal-format
 #| msgid "to refer to a type member of a template parameter, use `typename %E'"
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "benyt 'typename %E' for at referere til et typemedlem af en skabelonsparameter"
 
-#: cp/pt.c:7855 cp/pt.c:7877 cp/pt.c:7931
+#: cp/pt.c:7869 cp/pt.c:7891 cp/pt.c:7945
 #, fuzzy, gcc-internal-format
 #| msgid "type/value mismatch at argument %d in template parameter list for `%D'"
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "type/værdi-konflikt ved %d. parameter i skabelonsparameterliste for '%D'"
 
-#: cp/pt.c:7860
+#: cp/pt.c:7874
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a constant of type `%T', got `%T'"
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  forventede en konstant af typen '%T', modtog '%T'"
 
-#: cp/pt.c:7865
+#: cp/pt.c:7879
 #, fuzzy, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  forventede en klasseskabelon, modtog '%T'"
 
-#: cp/pt.c:7868
+#: cp/pt.c:7882
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a type, got `%E'"
 msgid "  expected a type, got %qE"
 msgstr "  forventede en type, modtog '%E'"
 
-#: cp/pt.c:7882
+#: cp/pt.c:7896
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a type, got `%T'"
 msgid "  expected a type, got %qT"
 msgstr "  forventede en type, modtog '%T'"
 
-#: cp/pt.c:7885
+#: cp/pt.c:7899
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a class template, got `%T'"
 msgid "  expected a class template, got %qT"
 msgstr "  forventede en klasseskabelon, modtog '%T'"
 
-#: cp/pt.c:7935
+#: cp/pt.c:7949
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a template of type `%D', got `%D'"
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  forventede en skabelon af typen '%D', modtog '%D'"
 
-#: cp/pt.c:7949
+#: cp/pt.c:7963
 #, fuzzy, gcc-internal-format
 #| msgid "type/value mismatch at argument %d in template parameter list for `%D'"
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "type/værdi-konflikt ved %d. parameter i skabelonsparameterliste for '%D'"
 
-#: cp/pt.c:7952
+#: cp/pt.c:7966
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a type, got `%E'"
 msgid "  expected %qD but got %qD"
 msgstr "  forventede en type, modtog '%E'"
 
-#: cp/pt.c:8012
+#: cp/pt.c:8026
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert template argument `%E' to `%T'"
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "kunne ikke konvertere skabelonsparameteren '%E' til '%T'"
 
-#: cp/pt.c:8149 cp/pt.c:8465
+#: cp/pt.c:8163 cp/pt.c:8479
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/pt.c:8164 cp/pt.c:8298
+#: cp/pt.c:8178 cp/pt.c:8312
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "forkert antal skabelonsparametre (%d, skulle være %d)"
 
-#: cp/pt.c:8294
+#: cp/pt.c:8308
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "forkert antal skabelonsparametre (%d, skulle være %d)"
 
-#: cp/pt.c:8303
+#: cp/pt.c:8317
 #, fuzzy, gcc-internal-format
 #| msgid "provided for `%D'"
 msgid "provided for %qD"
 msgstr "angivet for '%D'"
 
-#: cp/pt.c:8328
+#: cp/pt.c:8342
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:8332
+#: cp/pt.c:8346
 #, fuzzy, gcc-internal-format
 #| msgid "default argument given for parameter %d of `%#D'"
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "standardparameter givet til %d. parameter for '%#D'"
 
-#: cp/pt.c:8431
+#: cp/pt.c:8445
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:9054
+#: cp/pt.c:9068
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function template"
 msgid "%q#D is not a function template"
 msgstr "'%D' er ikke en funktionsskabelon"
 
-#: cp/pt.c:9221
+#: cp/pt.c:9235
 #, fuzzy, gcc-internal-format
 #| msgid "non-template type `%T' used as a template"
 msgid "non-template type %qT used as a template"
 msgstr "ikke-skabelonstype '%T' benyttet som skabelon"
 
-#: cp/pt.c:9223
+#: cp/pt.c:9237
 #, fuzzy, gcc-internal-format
 #| msgid "for template declaration `%D'"
 msgid "for template declaration %q+D"
 msgstr "til skabelonserklæring '%D'"
 
-#: cp/pt.c:9346
+#: cp/pt.c:9360
 #, fuzzy, gcc-internal-format
 #| msgid "internal gcc abort"
 msgid "template constraint failure"
 msgstr "intern GCC-afbrydelse"
 
-#: cp/pt.c:9697
+#: cp/pt.c:9718
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a template"
 msgid "use of invalid variable template %qE"
 msgstr "'%T' er ikke en skabelon"
 
-#: cp/pt.c:10125
+#: cp/pt.c:10148
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating `%D'"
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr "skabelonsinstantieringsdybden overskrider maksimum på %d (benyt -ftemplate-depth-NN for at forøge maksimum) ved instantiering af '%D'"
 
-#: cp/pt.c:11202
+#: cp/pt.c:11225
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD in union"
 msgstr "fleksibelt tabelmedlem i union"
 
-#: cp/pt.c:11691
+#: cp/pt.c:11713
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:12160
+#: cp/pt.c:12182
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr ""
 
-#: cp/pt.c:12163
+#: cp/pt.c:12185
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr ""
 
-#: cp/pt.c:12747
+#: cp/pt.c:12769
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for `%#D'"
 msgid "  when instantiating default argument for call to %qD"
@@ -53118,317 +53165,317 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:13708
+#: cp/pt.c:13730
 #, fuzzy, gcc-internal-format
 #| msgid "sizeof applied to a function type"
 msgid "variable %qD has function type"
 msgstr "sizeof benyttet på en funktionstype"
 
-#: cp/pt.c:13881
+#: cp/pt.c:13903
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter type `%T'"
 msgid "invalid parameter type %qT"
 msgstr "ugyldig parametertype '%T'"
 
-#: cp/pt.c:13883
+#: cp/pt.c:13905
 #, fuzzy, gcc-internal-format
 #| msgid "in declaration `%D'"
 msgid "in declaration %q+D"
 msgstr "i erklæringen '%D'"
 
-#: cp/pt.c:14001
+#: cp/pt.c:14023
 #, fuzzy, gcc-internal-format
 #| msgid "function returns an aggregate"
 msgid "function returning an array"
 msgstr "funktion returnerer en værdi af en sammensat type"
 
-#: cp/pt.c:14003
+#: cp/pt.c:14025
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' declared as function returning a function"
 msgid "function returning a function"
 msgstr "'%s' er erklæret som en funktion der returnerer en funktion"
 
-#: cp/pt.c:14043
+#: cp/pt.c:14065
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member function of non-class type `%T'"
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "opretter henvisning til medlemsfunktion af typen '%T' der ikke er en klasse"
 
-#: cp/pt.c:14637
+#: cp/pt.c:14659
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "danner reference til void"
 
-#: cp/pt.c:14639
+#: cp/pt.c:14661
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type `%T'"
 msgid "forming pointer to reference type %qT"
 msgstr "danner %s til referencetypen '%T'"
 
-#: cp/pt.c:14641
+#: cp/pt.c:14663
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type `%T'"
 msgid "forming reference to reference type %qT"
 msgstr "danner %s til referencetypen '%T'"
 
-#: cp/pt.c:14654
+#: cp/pt.c:14676
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids qualified function types"
 msgid "forming pointer to qualified function type %qT"
 msgstr "ISO C forbyder funktionsreturtype med modifikationer"
 
-#: cp/pt.c:14657
+#: cp/pt.c:14679
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids qualified function types"
 msgid "forming reference to qualified function type %qT"
 msgstr "ISO C forbyder funktionsreturtype med modifikationer"
 
-#: cp/pt.c:14705
+#: cp/pt.c:14727
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type `%T'"
 msgid "creating pointer to member of non-class type %qT"
 msgstr "opretter henvisning til medlem af typen '%T' der ikke er en klasse"
 
-#: cp/pt.c:14711
+#: cp/pt.c:14733
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type `%T'"
 msgid "creating pointer to member reference type %qT"
 msgstr "opretter henvisning til medlemsreference af typen '%T'"
 
-#: cp/pt.c:14717
+#: cp/pt.c:14739
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type `%T'"
 msgid "creating pointer to member of type void"
 msgstr "opretter henvisning til medlemsreference af typen '%T'"
 
-#: cp/pt.c:14783
+#: cp/pt.c:14805
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of `%T'"
 msgid "creating array of %qT"
 msgstr "opretter tabel af '%T'"
 
-#: cp/pt.c:14816
+#: cp/pt.c:14838
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a class, struct, or union type"
 msgid "%qT is not a class, struct, or union type"
 msgstr "'%T' er ikke en class-, struct- eller union-type"
 
-#: cp/pt.c:14853
+#: cp/pt.c:14875
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr ""
 
-#: cp/pt.c:14861
+#: cp/pt.c:14883
 #, fuzzy, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr "unavngiven klargøring af '%T' som ikke har nogen stamklasser"
 
-#: cp/pt.c:14925
+#: cp/pt.c:14947
 #, fuzzy, gcc-internal-format
 #| msgid "non-empty initializer for array of empty elements"
 msgid "empty initializer in lambda init-capture"
 msgstr "en startværdi der ikke er tom, tildeles til en tabel med tomme elementer"
 
-#: cp/pt.c:15000
+#: cp/pt.c:15022
 #, fuzzy, gcc-internal-format
 #| msgid "use of `%s' in template"
 msgid "use of %qs in template"
 msgstr "brug af '%s' i skabelon"
 
-#: cp/pt.c:15178
+#: cp/pt.c:15200
 #, fuzzy, gcc-internal-format
 #| msgid "qualified type `%T' does not match destructor name `~%T'"
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "den modificerede type '%T' passer ikke til destruktionsfunktionsnavnet '~%T'"
 
-#: cp/pt.c:15193
+#: cp/pt.c:15215
 #, fuzzy, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "'%D' benyttes som en type, men er ikke defineret som en type"
 
-#: cp/pt.c:15195
+#: cp/pt.c:15217
 #, fuzzy, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "  (benyt 'typename %T::%D' hvis det er hvad du mener)"
 
-#: cp/pt.c:15394
+#: cp/pt.c:15416
 #, fuzzy, gcc-internal-format
 #| msgid "missing static field `%s'"
 msgid "using invalid field %qD"
 msgstr "manglende statisk felt '%s'"
 
-#: cp/pt.c:15883 cp/pt.c:17386
+#: cp/pt.c:15905 cp/pt.c:17408
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of void expression"
 msgid "invalid use of pack expansion expression"
 msgstr "ugyldig brug af void-udtryk"
 
-#: cp/pt.c:15887 cp/pt.c:17390
+#: cp/pt.c:15909 cp/pt.c:17412
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr ""
 
-#: cp/pt.c:18334
+#: cp/pt.c:18371
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:18362
+#: cp/pt.c:18399
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:18367
+#: cp/pt.c:18404
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.c:18370
+#: cp/pt.c:18407
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr ""
 
-#: cp/pt.c:18375
+#: cp/pt.c:18412
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' undeclared here (not in a function)"
 msgid "%qD declared here, later in the translation unit"
 msgstr "'%s' ikke erklæret her (ikke i en funktion)"
 
-#: cp/pt.c:18712
+#: cp/pt.c:18752
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a class or namespace"
 msgid "%qT is not a class or namespace"
 msgstr "'%T' er ikke en klasse eller et navnerum"
 
-#: cp/pt.c:18715
+#: cp/pt.c:18755
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a class or namespace"
 msgid "%qD is not a class or namespace"
 msgstr "'%T' er ikke en klasse eller et navnerum"
 
-#: cp/pt.c:19026
+#: cp/pt.c:19066
 #, fuzzy, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr "skabelonsparameter '%T' benytter anonym type"
 
-#: cp/pt.c:19028
+#: cp/pt.c:19068
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for `%#D' has type `%T'"
 msgid "template argument for %qD uses local type %qT"
 msgstr "standardparameter for '%#D' har typen '%T'"
 
-#: cp/pt.c:19038
+#: cp/pt.c:19078
 #, fuzzy, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "skabelonsparameter '%T' er en variabelt ændret type"
 
-#: cp/pt.c:19053
+#: cp/pt.c:19093
 #, fuzzy, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "størrelsen af medlemmet '%D' er ikke konstant"
 
-#: cp/pt.c:19071
+#: cp/pt.c:19111
 #, fuzzy, gcc-internal-format
 #| msgid "  trying to instantiate `%D'"
 msgid "  trying to instantiate %qD"
 msgstr "  ved forsøg på at instantiere '%D'"
 
-#: cp/pt.c:22972
+#: cp/pt.c:23050
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for `%#T'"
 msgid "ambiguous template instantiation for %q#T"
 msgstr "tvetydig klasseskabelonsinstantiering for '%#T'"
 
-#: cp/pt.c:22974
+#: cp/pt.c:23052
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for `%#T'"
 msgid "ambiguous template instantiation for %q#D"
 msgstr "tvetydig klasseskabelonsinstantiering for '%#T'"
 
-#: cp/pt.c:22980
+#: cp/pt.c:23058
 #, fuzzy
 #| msgid "%s %+#D"
 msgid "%s %#qS"
 msgstr "%s %+#D"
 
-#: cp/pt.c:23004 cp/pt.c:23091
+#: cp/pt.c:23082 cp/pt.c:23169
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template `%#D'"
 msgid "explicit instantiation of non-template %q#D"
 msgstr "eksplicit instantiering af ikke-skabelon '%#D'"
 
-#: cp/pt.c:23023
+#: cp/pt.c:23101
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "'%#D' er ikke et statisk medlem af '%#T'"
 
-#: cp/pt.c:23029 cp/pt.c:23086
+#: cp/pt.c:23107 cp/pt.c:23164
 #, fuzzy, gcc-internal-format
 #| msgid "no matching template for `%D' found"
 msgid "no matching template for %qD found"
 msgstr "ingen passende skabelon for '%D' fundet"
 
-#: cp/pt.c:23034
+#: cp/pt.c:23112
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type `%T'"
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "eksplicit instantiering af '%T' der ikke er en skabelonstype"
 
-#: cp/pt.c:23042
+#: cp/pt.c:23120
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of `%#D'"
 msgid "explicit instantiation of %q#D"
 msgstr "eksplicit instantiering af '%#D'"
 
-#: cp/pt.c:23078
+#: cp/pt.c:23156
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate explicit instantiation of `%#D'"
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "'%#D' er blevet eksplicit instantieret mere end én gang"
 
-#: cp/pt.c:23101 cp/pt.c:23187
+#: cp/pt.c:23179 cp/pt.c:23265
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids the use of `extern' on explicit instantiations"
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ forbyder brugen af 'extern' ved eksplicitte instantieringer"
 
-#: cp/pt.c:23106 cp/pt.c:23204
+#: cp/pt.c:23184 cp/pt.c:23282
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `%D' applied to template instantiation"
 msgid "storage class %qD applied to template instantiation"
 msgstr "lagringsklasse '%D' anvendt på skabelonsinstantiering"
 
-#: cp/pt.c:23163
+#: cp/pt.c:23241
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template `%#D'"
 msgid "explicit instantiation of non-class template %qD"
 msgstr "eksplicit instantiering af ikke-skabelon '%#D'"
 
-#: cp/pt.c:23165
+#: cp/pt.c:23243
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type `%T'"
 msgid "explicit instantiation of non-template type %qT"
 msgstr "eksplicit instantiering af '%T' der ikke er en skabelonstype"
 
-#: cp/pt.c:23174
+#: cp/pt.c:23252
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of `%#T' before definition of template"
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "eksplicit instantiering af '%T' før definering af skabelonen"
 
-#: cp/pt.c:23192
+#: cp/pt.c:23270
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids the use of `%s' on explicit instantiations"
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ forbyder brugen af '%s ved eksplicitte instantieringer"
 
-#: cp/pt.c:23238
+#: cp/pt.c:23316
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate explicit instantiation of `%#T'"
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "'%#T' er blevet eksplicit instantieret mere end én gang"
 
-#: cp/pt.c:23536
+#: cp/pt.c:23614
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %D after first use"
 msgid "exception specification of %qD depends on itself"
@@ -53441,119 +53488,119 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:23842
+#: cp/pt.c:23920
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of `%D' but no definition available"
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "eksplicit instantiering af '%D', men ingen definition tilgængelig"
 
-#: cp/pt.c:24043
+#: cp/pt.c:24121
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating `%D'"
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr "skabelonsinstantieringsdybden overskrider maksimum på %d (benyt -ftemplate-depth-NN for at forøge maksimum) ved instantiering af '%D'"
 
-#: cp/pt.c:24418
+#: cp/pt.c:24496
 #, fuzzy, gcc-internal-format
 #| msgid "invalid catch parameter"
 msgid "invalid template non-type parameter"
 msgstr "ugyldig catch-parameter"
 
-#: cp/pt.c:24420
+#: cp/pt.c:24498
 #, fuzzy, gcc-internal-format
 #| msgid "`%#T' is not a valid type for a template constant parameter"
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "'%#T' er ikke en gyldig type for en skabelonsparameterkonstant "
 
-#: cp/pt.c:25723
+#: cp/pt.c:25802
 #, fuzzy, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "bruger 'typename' uden for en skabelon"
 
-#: cp/pt.c:25961
+#: cp/pt.c:26040
 #, fuzzy, gcc-internal-format
 #| msgid "brace-enclosed initializer used to initialize `%T'"
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr "startværdi i krøllede paranteser benyttet til at klargøre '%T'"
 
-#: cp/pt.c:26440
+#: cp/pt.c:26519
 #, fuzzy, gcc-internal-format
 msgid "non-class template %qT used without template arguments"
 msgstr "ikke-skabelon benyttet som skabelon"
 
-#: cp/pt.c:26586
+#: cp/pt.c:26665
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:26593
+#: cp/pt.c:26672
 #, fuzzy, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "skabelonsparameter er påkrævet for '%T'"
 
-#: cp/pt.c:26607
+#: cp/pt.c:26686
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "class template argument deduction failed:"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/pt.c:26614
+#: cp/pt.c:26693
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "funktion overvejes ikke for indbygning"
 
-#: cp/pt.c:26676
+#: cp/pt.c:26755
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:26679
+#: cp/pt.c:26758
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:26711
+#: cp/pt.c:26790
 #, fuzzy, gcc-internal-format
 #| msgid "%s as integer rather than floating due to prototype"
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr "%s som heltal i stedet for kommatal på grund af prototypen"
 
-#: cp/pt.c:26746
+#: cp/pt.c:26825
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid method declaration, return type required"
 msgid "unable to deduce lambda return type from %qE"
 msgstr "Ugyldig metodeerklæring, returtype påkrævet"
 
-#: cp/pt.c:26748
+#: cp/pt.c:26827
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr ""
 
-#: cp/pt.c:26781
+#: cp/pt.c:26860
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:26785
+#: cp/pt.c:26864
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "instruktion tilfredsstiller ikke sine begrænsninger:"
 
-#: cp/pt.c:26789
+#: cp/pt.c:26868
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "instruktion tilfredsstiller ikke sine begrænsninger:"
 
-#: cp/pt.c:26793
+#: cp/pt.c:26872
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "instruktion tilfredsstiller ikke sine begrænsninger:"
 
-#: cp/pt.c:26912
+#: cp/pt.c:26991
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr "ugyldig standardparameter i skabelon"
@@ -53616,89 +53663,89 @@
 msgid "cannot dynamic_cast %qE (of type %q#T) to type %q#T (%s)"
 msgstr "kan ikke anvende dynamic_cast på '%E' (af typen '%#T') til typen '%#T' (%s)"
 
-#: cp/search.c:240
+#: cp/search.c:243
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is an ambiguous base of `%T'"
 msgid "%qT is an ambiguous base of %qT"
 msgstr "'%T' er en tvetydig stamklasse til '%T'"
 
-#: cp/search.c:256
+#: cp/search.c:259
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is an inaccessible base of `%T'"
 msgid "%qT is an inaccessible base of %qT"
 msgstr "'%T' er en utilgængelig stamklasse til '%T'"
 
-#: cp/search.c:1905
+#: cp/search.c:1908
 #, fuzzy, gcc-internal-format
 #| msgid "invalid covariant return type for `%#D'"
 msgid "invalid covariant return type for %q#D"
 msgstr "ugyldig kovariant returneringstype for '%#D'"
 
-#: cp/search.c:1907 cp/search.c:1922 cp/search.c:1928 cp/search.c:1957
+#: cp/search.c:1910 cp/search.c:1925 cp/search.c:1931 cp/search.c:1960
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function `%s'"
 msgid "overridden function is %q#D"
 msgstr "for få parametre til funktionen '%s'"
 
-#: cp/search.c:1920
+#: cp/search.c:1923
 #, fuzzy, gcc-internal-format
 #| msgid "invalid covariant return type for `%#D'"
 msgid "invalid covariant return type for %q+#D"
 msgstr "ugyldig kovariant returneringstype for '%#D'"
 
-#: cp/search.c:1926
+#: cp/search.c:1929
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting return type specified for `%#D'"
 msgid "conflicting return type specified for %q+#D"
 msgstr "modstridende returtyper angivet for '%#D'"
 
-#: cp/search.c:1942
+#: cp/search.c:1945
 #, fuzzy, gcc-internal-format
 #| msgid "looser throw specifier for `%#F'"
 msgid "looser throw specifier for %q+#F"
 msgstr "løsere throw-angivelse for '%#F'"
 
-#: cp/search.c:1944
+#: cp/search.c:1947
 #, fuzzy, gcc-internal-format
 #| msgid "  overriding `%#F'"
 msgid "overridden function is %q#F"
 msgstr "  overskriver '%#F'"
 
-#: cp/search.c:1955
+#: cp/search.c:1958
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting return type specified for `%#D'"
 msgid "conflicting type attributes specified for %q+#D"
 msgstr "modstridende returtyper angivet for '%#D'"
 
-#: cp/search.c:1972
+#: cp/search.c:1975
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<__transaction_atomic%>"
 msgid "%qD declared %<transaction_safe_dynamic%>"
 msgstr "forventede %<__transaction_atomic%>"
 
-#: cp/search.c:1974
+#: cp/search.c:1977
 #, fuzzy, gcc-internal-format
 msgid "overriding %qD declared %<transaction_safe%>"
 msgstr "variablen '%s' er erklæret 'inline'"
 
-#: cp/search.c:1981
+#: cp/search.c:1984
 #, fuzzy, gcc-internal-format
 msgid "deleted function %q+D overriding non-deleted function"
 msgstr "den indbyggede funktion '%s' er erklæret som noget der ikke er en funktion"
 
-#: cp/search.c:1984 cp/search.c:1992 cp/search.c:2000
+#: cp/search.c:1987 cp/search.c:1995 cp/search.c:2003
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function `%s'"
 msgid "overridden function is %qD"
 msgstr "for få parametre til funktionen '%s'"
 
-#: cp/search.c:1989
+#: cp/search.c:1992
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function `%D'"
 msgid "non-deleted function %q+D overriding deleted function"
 msgstr "kald af ikke-funktion '%D'"
 
-#: cp/search.c:1998
+#: cp/search.c:2001
 #, fuzzy, gcc-internal-format
 msgid "virtual function %q+D overriding final function"
 msgstr "den indbyggede funktion '%s' er erklæret som noget der ikke er en funktion"
@@ -53705,13 +53752,13 @@
 
 #. A static member function cannot match an inherited
 #. virtual member function.
-#: cp/search.c:2082
+#: cp/search.c:2085
 #, fuzzy, gcc-internal-format
 #| msgid "`%#D' cannot be declared"
 msgid "%q+#D cannot be declared"
 msgstr "'%#D' kan ikke erklæres"
 
-#: cp/search.c:2083
+#: cp/search.c:2086
 #, fuzzy, gcc-internal-format
 #| msgid "  since `%#D' declared in base class"
 msgid "  since %q+#D declared in base class"
@@ -53756,146 +53803,146 @@
 msgid "invalid use of member %qD in static member function"
 msgstr "ugyldig brug af medlemmet '%D' i statisk medlemsfunktion"
 
-#: cp/semantics.c:2153
+#: cp/semantics.c:2156
 #, gcc-internal-format
 msgid "a statement expression is an insufficient context for overload resolution"
 msgstr ""
 
-#: cp/semantics.c:2540
+#: cp/semantics.c:2543
 #, fuzzy, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr "parameter til egenskaben '%s' er større end %d"
 
-#: cp/semantics.c:2622
+#: cp/semantics.c:2625
 #, fuzzy, gcc-internal-format
 #| msgid "`this' is unavailable for static member functions"
 msgid "%<this%> is unavailable for static member functions"
 msgstr "'this' er ikke tilgængelig for statiske medlemsfunktioner"
 
-#: cp/semantics.c:2624
+#: cp/semantics.c:2627
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `this' in non-member function"
 msgid "invalid use of %<this%> in non-member function"
 msgstr "ugyldig brug af 'this' i ikke-medlemsfunktion"
 
-#: cp/semantics.c:2626
+#: cp/semantics.c:2629
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `this' at top level"
 msgid "invalid use of %<this%> at top level"
 msgstr "ugyldig brug af 'this' ved øverste niveau"
 
-#: cp/semantics.c:2648
+#: cp/semantics.c:2651
 #, fuzzy, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "ugyldige modifikationer for ikke-medlemsfunktionstype"
 
-#: cp/semantics.c:2656 cp/typeck.c:2604
+#: cp/semantics.c:2659 cp/typeck.c:2604
 #, fuzzy, gcc-internal-format
 #| msgid "qualified type `%T' does not match destructor name `~%T'"
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "den modificerede type '%T' passer ikke til destruktionsfunktionsnavnet '~%T'"
 
-#: cp/semantics.c:2678
+#: cp/semantics.c:2681
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' is not of type `%T'"
 msgid "%qE is not of type %qT"
 msgstr "'%E' er ikke af typen '%T'"
 
-#: cp/semantics.c:2751
+#: cp/semantics.c:2754
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr ""
 
-#: cp/semantics.c:2892
+#: cp/semantics.c:2895
 #, fuzzy, gcc-internal-format
 #| msgid "template type parameters must use the keyword `class' or `typename'"
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr "skabelonstypeparametre skal begynde med 'class' eller 'typename'"
 
-#: cp/semantics.c:2942
+#: cp/semantics.c:2945
 #, fuzzy, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr "ugyldig brug af skabelonstypeparameter"
 
-#: cp/semantics.c:2945
+#: cp/semantics.c:2948
 #, fuzzy, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr "ugyldig brug af skabelonstypeparameter"
 
-#: cp/semantics.c:2962
+#: cp/semantics.c:2965
 #, fuzzy, gcc-internal-format
 #| msgid "definition of `%#T' inside template parameter list"
 msgid "definition of %q#T inside template parameter list"
 msgstr "definition af '%#T' inden i skabelonsparameterliste"
 
-#: cp/semantics.c:2993
+#: cp/semantics.c:2996
 #, fuzzy, gcc-internal-format
 #| msgid "invalid definition of qualified type `%T'"
 msgid "invalid definition of qualified type %qT"
 msgstr "ugyldig definition af modificeret type '%T'"
 
-#: cp/semantics.c:3263
+#: cp/semantics.c:3266
 #, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "ugyldig stamklasseangivelse"
 
-#: cp/semantics.c:3423
+#: cp/semantics.c:3426
 #, fuzzy, gcc-internal-format
 #| msgid "protected member `%#D' in anonymous union"
 msgid "cannot capture member %qD of anonymous union"
 msgstr "beskyttet medlem '%#D' i en anonym union"
 
-#: cp/semantics.c:3443 cp/semantics.c:9269
+#: cp/semantics.c:3446 cp/semantics.c:9272
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' not declared"
 msgid "%qD is not captured"
 msgstr "'%D' ikke erklæret"
 
-#: cp/semantics.c:3448
+#: cp/semantics.c:3451
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.c:3450
+#: cp/semantics.c:3453
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.c:3462
+#: cp/semantics.c:3465
 #, fuzzy, gcc-internal-format
 #| msgid "use of %s from containing function"
 msgid "use of local variable with automatic storage from containing function"
 msgstr "brug af %s fra indeholdende funktion"
 
-#: cp/semantics.c:3464
+#: cp/semantics.c:3467
 #, fuzzy, gcc-internal-format
 #| msgid "use of %s from containing function"
 msgid "use of parameter from containing function"
 msgstr "brug af %s fra indeholdende funktion"
 
-#: cp/semantics.c:3596
+#: cp/semantics.c:3599
 #, fuzzy, gcc-internal-format
 #| msgid "use of %s from containing function"
 msgid "use of parameter outside function body"
 msgstr "brug af %s fra indeholdende funktion"
 
-#: cp/semantics.c:3606
+#: cp/semantics.c:3609
 #, fuzzy, gcc-internal-format
 msgid "missing template arguments"
 msgstr "skabelonsparameter er påkrævet for '%T'"
 
-#: cp/semantics.c:3633
+#: cp/semantics.c:3636
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr ""
 
-#: cp/semantics.c:3664
+#: cp/semantics.c:3667
 #, fuzzy, gcc-internal-format
 #| msgid "use of namespace `%D' as expression"
 msgid "use of namespace %qD as expression"
 msgstr "brug af navnerummet '%D' som udtryk"
 
-#: cp/semantics.c:3669
+#: cp/semantics.c:3672
 #, fuzzy, gcc-internal-format
 #| msgid "use of class template `%T' as expression"
 msgid "use of class template %qT as expression"
@@ -53902,24 +53949,24 @@
 msgstr "brug af klasseskabelonen '%T' som udtryk"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:3675
+#: cp/semantics.c:3678
 #, fuzzy, gcc-internal-format
 #| msgid "request for member `%D' is ambiguous in multiple inheritance lattice"
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "forespørgsel efter medlemmet '%D' er tvetydigt i det multiple nedarvningsnet"
 
-#: cp/semantics.c:3702
+#: cp/semantics.c:3705
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/semantics.c:3841
+#: cp/semantics.c:3844
 #, fuzzy, gcc-internal-format
 #| msgid "type of `%E' is unknown"
 msgid "type of %qE is unknown"
 msgstr "typen af '%E' er ukendt"
 
-#: cp/semantics.c:3870
+#: cp/semantics.c:3873
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a template type"
 msgid "%qT is not an enumeration type"
@@ -53926,303 +53973,303 @@
 msgstr "'%T' er ikke en skabelonstype"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4009
+#: cp/semantics.c:4012
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specifiers invalid in parameter declarations"
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr "lagringsklasseanvisninger er ugyldige i parametererklæringer"
 
-#: cp/semantics.c:4038
+#: cp/semantics.c:4041
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr ""
 
-#: cp/semantics.c:4052
+#: cp/semantics.c:4055
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "ugyldig brug af ikke-statisk felt '%D'"
 
-#: cp/semantics.c:4056
+#: cp/semantics.c:4059
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function"
 msgstr "ugyldig brug af ikke-statisk felt '%D'"
 
-#: cp/semantics.c:4061
+#: cp/semantics.c:4064
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr "ugyldig brug af ikke-statisk felt '%D'"
 
-#: cp/semantics.c:4072
+#: cp/semantics.c:4075
 #, gcc-internal-format
 msgid "offsetof within non-standard-layout type %qT is conditionally-supported"
 msgstr ""
 
-#: cp/semantics.c:4583 cp/semantics.c:6069 cp/semantics.c:6140
-#: cp/semantics.c:6183 cp/semantics.c:6533 cp/semantics.c:6632
-#: cp/semantics.c:6775
+#: cp/semantics.c:4586 cp/semantics.c:6072 cp/semantics.c:6143
+#: cp/semantics.c:6186 cp/semantics.c:6536 cp/semantics.c:6635
+#: cp/semantics.c:6778
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5271
+#: cp/semantics.c:5274
 #, fuzzy, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr "brug af '%D' er tvetydigt"
 
-#: cp/semantics.c:5544
+#: cp/semantics.c:5547
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr "variablen til tabel-delete er hverken af en henvisnings- eller en tabeltype"
 
-#: cp/semantics.c:5592
+#: cp/semantics.c:5595
 #, fuzzy, gcc-internal-format
 #| msgid "invalid return type for function `%#D'"
 msgid "%qE has const type for %<reduction%>"
 msgstr "ugyldig returtype for funktionen '%#D'"
 
-#: cp/semantics.c:5707
+#: cp/semantics.c:5710
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:5941
+#: cp/semantics.c:5944
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5955
+#: cp/semantics.c:5958
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5977
+#: cp/semantics.c:5980
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6080
+#: cp/semantics.c:6083
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qD is not a variable in clause %qs"
 msgstr "'%s' er et ugyldigt klassenavn"
 
-#: cp/semantics.c:6152
+#: cp/semantics.c:6155
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable `%s' is declared private"
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "instansvariablen '%s' er erklæret privat"
 
-#: cp/semantics.c:6195
+#: cp/semantics.c:6198
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable `%s' is declared private"
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "instansvariablen '%s' er erklæret privat"
 
-#: cp/semantics.c:6240
+#: cp/semantics.c:6243
 #, fuzzy, gcc-internal-format
 #| msgid "predicate must be an identifier"
 msgid "%<gang%> static expression must be integral"
 msgstr "udsagn skal være et kaldenavn"
 
-#: cp/semantics.c:6254
+#: cp/semantics.c:6257
 #, fuzzy, gcc-internal-format
 #| msgid "%s rotate count is negative"
 msgid "%<gang%> static value must be positive"
 msgstr "%s-roteringsantal er negativt"
 
-#: cp/semantics.c:6288
+#: cp/semantics.c:6291
 #, fuzzy, gcc-internal-format
 #| msgid "predicate must be an identifier"
 msgid "%<gang%> num expression must be integral"
 msgstr "udsagn skal være et kaldenavn"
 
-#: cp/semantics.c:6291
+#: cp/semantics.c:6294
 #, fuzzy, gcc-internal-format
 #| msgid "predicate must be an identifier"
 msgid "%<vector%> length expression must be integral"
 msgstr "udsagn skal være et kaldenavn"
 
-#: cp/semantics.c:6295
+#: cp/semantics.c:6298
 #, fuzzy, gcc-internal-format
 #| msgid "predicate must be an identifier"
 msgid "%<worker%> num expression must be integral"
 msgstr "udsagn skal være et kaldenavn"
 
-#: cp/semantics.c:6317
+#: cp/semantics.c:6320
 #, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr ""
 
-#: cp/semantics.c:6321
+#: cp/semantics.c:6324
 #, fuzzy, gcc-internal-format
 #| msgid "requested alignment is not a power of 2"
 msgid "%<vector%> length value must be positive"
 msgstr "angivet justering er ikke en potens af 2"
 
-#: cp/semantics.c:6326
+#: cp/semantics.c:6329
 #, fuzzy, gcc-internal-format
 #| msgid "left argument must be a slice"
 msgid "%<worker%> num value must be positive"
 msgstr "venstre parameter skal være en skive"
 
-#: cp/semantics.c:6376
+#: cp/semantics.c:6379
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6406
+#: cp/semantics.c:6409
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6419
+#: cp/semantics.c:6422
 #, fuzzy, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "klargøringsliste behandlet som et sammensat udtryk"
 
-#: cp/semantics.c:6438
+#: cp/semantics.c:6441
 #, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6466
+#: cp/semantics.c:6469
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6495
+#: cp/semantics.c:6498
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr ""
 
-#: cp/semantics.c:6516
+#: cp/semantics.c:6519
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6543
+#: cp/semantics.c:6546
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "'%s' er et ugyldigt klassenavn"
 
-#: cp/semantics.c:6557
+#: cp/semantics.c:6560
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:6563
+#: cp/semantics.c:6566
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: cp/semantics.c:6576
+#: cp/semantics.c:6579
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6625
+#: cp/semantics.c:6628
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr "'%s' er et ugyldigt klassenavn"
 
-#: cp/semantics.c:6910
+#: cp/semantics.c:6913
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "template %qE in clause %qs"
 msgstr "for mange inddatafiler"
 
-#: cp/semantics.c:6914
+#: cp/semantics.c:6917
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6979
+#: cp/semantics.c:6982
 #, fuzzy, gcc-internal-format
 #| msgid "predicate must be an identifier"
 msgid "%<grainsize%> expression must be integral"
 msgstr "udsagn skal være et kaldenavn"
 
-#: cp/semantics.c:7008
+#: cp/semantics.c:7011
 #, fuzzy, gcc-internal-format
 #| msgid "predicate must be an identifier"
 msgid "%<priority%> expression must be integral"
 msgstr "udsagn skal være et kaldenavn"
 
-#: cp/semantics.c:7037
+#: cp/semantics.c:7040
 #, fuzzy, gcc-internal-format
 #| msgid "predicate must be an identifier"
 msgid "%<num_tasks%> expression must be integral"
 msgstr "udsagn skal være et kaldenavn"
 
-#: cp/semantics.c:7066
+#: cp/semantics.c:7069
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr "variablen til tabel-delete er hverken af en henvisnings- eller en tabeltype"
 
-#: cp/semantics.c:7105
+#: cp/semantics.c:7108
 #, fuzzy, gcc-internal-format
 #| msgid "slice end must be integer"
 msgid "%<tile%> argument needs integral type"
 msgstr "skive-slutning skal være heltal"
 
-#: cp/semantics.c:7524
+#: cp/semantics.c:7527
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.c:7538
+#: cp/semantics.c:7541
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr ""
 
-#: cp/semantics.c:7743
+#: cp/semantics.c:7746
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.c:8171
+#: cp/semantics.c:8174
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.c:8398 cp/semantics.c:8408
+#: cp/semantics.c:8401 cp/semantics.c:8411
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.c:8702
+#: cp/semantics.c:8705
 #, fuzzy, gcc-internal-format
 #| msgid "verification error at PC=%d"
 msgid "static assertion failed"
 msgstr "verifikationsfejl ved PC=%d"
 
-#: cp/semantics.c:8704
+#: cp/semantics.c:8707
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr ""
 
-#: cp/semantics.c:8709
+#: cp/semantics.c:8712
 #, fuzzy, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "erklæring uden static af '%s' følger static-erklæring"
 
-#: cp/semantics.c:8739
+#: cp/semantics.c:8742
 #, fuzzy, gcc-internal-format
 #| msgid "use of class template `%T' as expression"
 msgid "argument to decltype must be an expression"
 msgstr "brug af klasseskabelonen '%T' som udtryk"
 
-#: cp/semantics.c:8767
+#: cp/semantics.c:8770
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "decltype cannot resolve address of overloaded function"
 msgstr "%s kan ikke finde adressen af flertydiggjort funktion"
 
-#: cp/semantics.c:9308
+#: cp/semantics.c:9311
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "operand of fold expression has no unexpanded parameter packs"
@@ -54229,167 +54276,183 @@
 msgstr "venstreoperanden til kommaudtrykket har ingen virkning"
 
 # flertalsform unødvendig
-#: cp/semantics.c:9361
+#: cp/semantics.c:9364
 #, fuzzy, gcc-internal-format
 #| msgid "template argument `%E' involves template parameter(s)"
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "skabelonsparameter '%E' involverer skabelonsparameter"
 
-#: cp/semantics.c:9363
+#: cp/semantics.c:9366
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:9381
+#: cp/semantics.c:9384
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported arg to `__builtin_return_address'"
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "ikke-understøttet parameter til '__builtin_return_address'"
 
-#: cp/tree.c:1276
+#: cp/tree.c:1295
 #, fuzzy, gcc-internal-format
 #| msgid "`%V' qualifiers cannot be applied to `%T'"
 msgid "%qV qualifiers cannot be applied to %qT"
 msgstr "modifikationerne '%V' kan ikke anvendes på '%T'"
 
-#: cp/tree.c:1788
+#: cp/tree.c:1807
 #, fuzzy, gcc-internal-format
 #| msgid "overflow in constant expression"
 msgid "lambda-expression in a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/tree.c:1792
+#: cp/tree.c:1811
 #, fuzzy, gcc-internal-format
 #| msgid "overflow in constant expression"
 msgid "statement-expression in a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/tree.c:4050
+#: cp/tree.c:4083
+#, gcc-internal-format
+msgid "-fabi-version=13 (GCC 8.2) fixes the calling convention for %qT, which was accidentally changed in 8.1"
+msgstr ""
+
+#: cp/tree.c:4087
+#, gcc-internal-format
+msgid "-fabi-version=12 (GCC 8.1) accidentally changes the calling convention for %qT"
+msgstr ""
+
+#: cp/tree.c:4090
 #, fuzzy, gcc-internal-format
+#| msgid "  `%#D' declared here"
+msgid " declared here"
+msgstr "  '%#D' erklæret her"
+
+#: cp/tree.c:4094
+#, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
-msgid "the calling convention for %qT changes in -fabi-version=12 (GCC 8)"
+msgid "the calling convention for %qT changes in -fabi-version=13 (GCC 8.2)"
 msgstr "tildeling (ikke klargøring) i erklæring"
 
-#: cp/tree.c:4055
+#: cp/tree.c:4096
 #, gcc-internal-format
 msgid " because all of its copy and move constructors are deleted"
 msgstr ""
 
-#: cp/tree.c:4416
+#: cp/tree.c:4464
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute requires an integer constant argument"
 msgid "%qE attribute applied to %qD with void return type"
 msgstr "egenskaben '%s' kræver en heltalskonstant som parameter"
 
-#: cp/tree.c:4423
+#: cp/tree.c:4471
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute can only be applied to class definitions"
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr "egenskaben '%s' kan kun anvendes med klassedefinitioner"
 
-#: cp/tree.c:4475
+#: cp/tree.c:4523
 #, gcc-internal-format
 msgid "requested init_priority is not an integer constant"
 msgstr "den udbedte init_priority er ikke en heltalskonstant"
 
-#: cp/tree.c:4497
+#: cp/tree.c:4545
 #, fuzzy, gcc-internal-format
 #| msgid "can only use `%s' attribute on file-scope definitions of objects of class type"
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr "kan kun bruge egenskaben '%s' på filvirkefeltsdefinitioner af objekter af klassetype"
 
-#: cp/tree.c:4505
+#: cp/tree.c:4553
 #, gcc-internal-format
 msgid "requested init_priority is out of range"
 msgstr "den udbedte init_priority er uden for det gyldige interval"
 
-#: cp/tree.c:4515
+#: cp/tree.c:4563
 #, gcc-internal-format
 msgid "requested init_priority is reserved for internal use"
 msgstr "den udbedte init_priority er reserveret til intern brug"
 
-#: cp/tree.c:4526
+#: cp/tree.c:4574
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute is not supported on this platform"
 msgid "%qE attribute is not supported on this platform"
 msgstr "egenskaben '%s' er ikke understøttet på denne platform"
 
-#: cp/tree.c:4553
+#: cp/tree.c:4601
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' as %s"
 msgid "redeclaration of %qD adds abi tag %qE"
 msgstr "erklæring af '%D' som %s"
 
-#: cp/tree.c:4573
+#: cp/tree.c:4621
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute requires an integer constant argument"
 msgid "the %qE attribute requires arguments"
 msgstr "egenskaben '%s' kræver en heltalskonstant som parameter"
 
-#: cp/tree.c:4584
+#: cp/tree.c:4632
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `%s' attribute is not a string constant"
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "parameteren til egenskaben '%s er ikke en strengkonstant"
 
-#: cp/tree.c:4597 cp/tree.c:4610
+#: cp/tree.c:4645 cp/tree.c:4658
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `%s' attribute is not a string constant"
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "parameteren til egenskaben '%s er ikke en strengkonstant"
 
-#: cp/tree.c:4599
+#: cp/tree.c:4647
 #, fuzzy, gcc-internal-format
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "'%T::%D' er ikke en gyldig erklærer"
 
-#: cp/tree.c:4612
+#: cp/tree.c:4660
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a valid expression"
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "'%T' er ikke et gyldigt udtryk"
 
-#: cp/tree.c:4636
+#: cp/tree.c:4684
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to function types"
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "egenskaben '%s' kan kun anvendes sammen med funktionstyper"
 
-#: cp/tree.c:4642
+#: cp/tree.c:4690
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute can only be applied to class definitions"
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "egenskaben '%s' kan kun anvendes med klassedefinitioner"
 
-#: cp/tree.c:4649
+#: cp/tree.c:4697
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `%D' applied to template instantiation"
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "lagringsklasse '%D' anvendt på skabelonsinstantiering"
 
-#: cp/tree.c:4656
+#: cp/tree.c:4704
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `%D' applied to template instantiation"
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "lagringsklasse '%D' anvendt på skabelonsinstantiering"
 
-#: cp/tree.c:4678
+#: cp/tree.c:4726
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "'%s'-egenskaben kan kun anvendes sammen med funktioner"
 
-#: cp/tree.c:4684
+#: cp/tree.c:4732
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "'%s'-egenskaben kan kun anvendes sammen med funktioner"
 
-#: cp/tree.c:5440
+#: cp/tree.c:5488
 #, fuzzy, gcc-internal-format
 #| msgid "two `u's in integer constant"
 msgid "zero as null pointer constant"
 msgstr "to 'u'-endelser i heltalskonstant"
 
-#: cp/tree.c:5453
+#: cp/tree.c:5501
 #, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr "lang_*-kontrol: mislykkedes i %s, ved %s:%d"
@@ -55629,124 +55692,124 @@
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr ""
 
-#: cp/typeck2.c:1496 cp/typeck2.c:1523
+#: cp/typeck2.c:1499 cp/typeck2.c:1526
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member `%D'"
 msgid "missing initializer for member %qD"
 msgstr "manglende startværdi for medlemmet '%D'"
 
-#: cp/typeck2.c:1504
+#: cp/typeck2.c:1507
 #, fuzzy, gcc-internal-format
 #| msgid "member `%D' is uninitialized reference"
 msgid "member %qD is uninitialized reference"
 msgstr "medlemmet '%D' er en reference uden startværdi"
 
-#: cp/typeck2.c:1511
+#: cp/typeck2.c:1514
 #, fuzzy, gcc-internal-format
 #| msgid "member `%D' is uninitialized reference"
 msgid "member %qD with uninitialized reference fields"
 msgstr "medlemmet '%D' er en reference uden startværdi"
 
-#: cp/typeck2.c:1587
+#: cp/typeck2.c:1590
 #, fuzzy, gcc-internal-format
 #| msgid "template-id `%D' for `%+D' does not match any template declaration"
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "skabelons-id '%D' for '%+D' passer ikke til nogen skabelonserklæring"
 
-#: cp/typeck2.c:1660
+#: cp/typeck2.c:1663
 #, fuzzy, gcc-internal-format
 #| msgid "no field `%D' in union being initialized"
 msgid "no field %qD found in union being initialized"
 msgstr "intet felt '%D' i union der tildeles startværdi"
 
-#: cp/typeck2.c:1671
+#: cp/typeck2.c:1674
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "indeksværdi i stedet for feltnavn i union-startværdi"
 
-#: cp/typeck2.c:1858
+#: cp/typeck2.c:1861
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "fundet en henvisningsefterfølgelse der går i ring"
 
-#: cp/typeck2.c:1872
+#: cp/typeck2.c:1875
 #, fuzzy, gcc-internal-format
 #| msgid "base operand of `->' has non-pointer type `%T'"
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "grundoperanden til '->' har en ikke-henvisningstype '%T'"
 
-#: cp/typeck2.c:1898
+#: cp/typeck2.c:1901
 #, fuzzy, gcc-internal-format
 #| msgid "result of `operator->()' yields non-pointer result"
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "resultatet af 'operator->()' er ikke en henvisning"
 
-#: cp/typeck2.c:1900
+#: cp/typeck2.c:1903
 #, fuzzy, gcc-internal-format
 #| msgid "base operand of `->' is not a pointer"
 msgid "base operand of %<->%> is not a pointer"
 msgstr "grundoperanden til '->' er ikke en henvisning"
 
-#: cp/typeck2.c:1927
+#: cp/typeck2.c:1930
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' cannot be used as a member pointer, since it is of type `%T'"
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "'%E' kan ikke bruges som en medlemshenvisning eftersom udtrykkets type er '%T'"
 
-#: cp/typeck2.c:1936
+#: cp/typeck2.c:1939
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply member pointer `%E' to `%E', which is of non-aggregate type `%T'"
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "kan ikke anvende medlemshenvisning '%E' på '%E' som er af den ikke-sammensatte type '%T'"
 
-#: cp/typeck2.c:1958
+#: cp/typeck2.c:1961
 #, fuzzy, gcc-internal-format
 #| msgid "member type `%T::' incompatible with object type `%T'"
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "medlemstypen '%T::' uforenelige med objekttypen '%T'"
 
-#: cp/typeck2.c:2018
+#: cp/typeck2.c:2021
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "henvisning til en medlemsfunktion benyttet i udregning"
 
-#: cp/typeck2.c:2029
+#: cp/typeck2.c:2032
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "henvisning til en medlemsfunktion benyttet i udregning"
 
-#: cp/typeck2.c:2037
+#: cp/typeck2.c:2040
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue before C++2a"
 msgstr "henvisning til en medlemsfunktion benyttet i udregning"
 
-#: cp/typeck2.c:2080
+#: cp/typeck2.c:2083
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type `%T'"
 msgid "functional cast to array type %qT"
 msgstr "ugyldig omtvingelse til funktionstypen '%T'"
 
-#: cp/typeck2.c:2096
+#: cp/typeck2.c:2099
 #, fuzzy, gcc-internal-format
 msgid "cannot deduce template arguments for %qT from ()"
 msgstr "skabelonsparameter er påkrævet for '%T'"
 
-#: cp/typeck2.c:2114
+#: cp/typeck2.c:2117
 #, fuzzy, gcc-internal-format
 #| msgid "default-initialization of `%#D', which has reference type"
 msgid "invalid value-initialization of reference type"
 msgstr "standardklargøring af '%#D' som er af en referencetype"
 
-#: cp/typeck2.c:2341
+#: cp/typeck2.c:2344
 #, fuzzy, gcc-internal-format
 #| msgid "call to function `%D' which throws incomplete type `%#T'"
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "kald af en funktion '%D' som kaster en ufuldstændig type '%#T'"
 
-#: cp/typeck2.c:2344
+#: cp/typeck2.c:2347
 #, fuzzy, gcc-internal-format
 #| msgid "call to function which throws incomplete type `%#T'"
 msgid "call to function which throws incomplete type %q#T"
@@ -55972,11 +56035,11 @@
 msgstr ""
 
 #: fortran/array.c:221 fortran/array.c:661 fortran/check.c:2849
-#: fortran/check.c:5222 fortran/check.c:5260 fortran/check.c:5302
-#: fortran/check.c:5329 fortran/check.c:5529 fortran/match.c:1821
+#: fortran/check.c:5225 fortran/check.c:5263 fortran/check.c:5305
+#: fortran/check.c:5332 fortran/check.c:5532 fortran/match.c:1821
 #: fortran/match.c:3174 fortran/match.c:3516 fortran/match.c:3712
-#: fortran/simplify.c:2909 fortran/simplify.c:2939 fortran/simplify.c:5764
-#: fortran/simplify.c:7658
+#: fortran/simplify.c:2909 fortran/simplify.c:2939 fortran/simplify.c:5769
+#: fortran/simplify.c:7663
 #, gcc-internal-format
 msgid "Coarrays disabled at %C, use %<-fcoarray=%> to enable"
 msgstr ""
@@ -56120,123 +56183,128 @@
 msgid "DO-iterator %qs at %L is inside iterator of the same name"
 msgstr ""
 
-#: fortran/array.c:1073 fortran/array.c:1255
+#: fortran/array.c:1073 fortran/array.c:1264
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in array constructor at %C"
 msgstr "\"%s\" må ikke optræde i makroparameterliste"
 
-#: fortran/array.c:1129
+#: fortran/array.c:1105
+#, fuzzy, gcc-internal-format, gfc-internal-format
+msgid "NULL() at %C cannot appear in an array constructor"
+msgstr "overløb i konstant udtryk"
+
+#: fortran/array.c:1138
 #, gcc-internal-format, gfc-internal-format
 msgid "[...] style array constructors at %C"
 msgstr ""
 
-#: fortran/array.c:1149
+#: fortran/array.c:1158
 #, gcc-internal-format, gfc-internal-format
 msgid "Array constructor including type specification at %C"
 msgstr ""
 
-#: fortran/array.c:1155 fortran/match.c:4148
+#: fortran/array.c:1164 fortran/match.c:4148
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-spec at %L cannot contain a deferred type parameter"
 msgstr ""
 
-#: fortran/array.c:1163
+#: fortran/array.c:1172
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type-spec at %L cannot contain an asterisk for a type parameter"
 msgstr "objektet '%E' kan ikke bruges som skabelonsparameter"
 
-#: fortran/array.c:1181
+#: fortran/array.c:1190
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Min/max instructions not allowed"
 msgid "Empty array constructor at %C is not allowed"
 msgstr "Min/max-instruktioner ikke tilladt"
 
-#: fortran/array.c:1218 fortran/array.c:1228
+#: fortran/array.c:1227 fortran/array.c:1237
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "incompatible type for argument %d of `%s'"
 msgid "Incompatible typespec for array element at %L"
 msgstr "typen af den %d. parameter i '%s' passer ikke"
 
-#: fortran/array.c:1302
+#: fortran/array.c:1311
 #, gcc-internal-format, gfc-internal-format
 msgid "Element in %s array constructor at %L is %s"
 msgstr ""
 
-#: fortran/array.c:1633
+#: fortran/array.c:1642
 #, gcc-internal-format, gfc-internal-format
 msgid "Iterator step at %L cannot be zero"
 msgstr ""
 
-#: fortran/array.c:1770
+#: fortran/array.c:1779
 #, gcc-internal-format
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit.   See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/array.c:1940
+#: fortran/array.c:1949
 #, gcc-internal-format, gfc-internal-format
 msgid "AC-IMPLIED-DO initial expression references control variable at %L"
 msgstr ""
 
-#: fortran/array.c:1947
+#: fortran/array.c:1956
 #, gcc-internal-format, gfc-internal-format
 msgid "AC-IMPLIED-DO final expression references control variable at %L"
 msgstr ""
 
-#: fortran/array.c:1954
+#: fortran/array.c:1963
 #, gcc-internal-format, gfc-internal-format
 msgid "AC-IMPLIED-DO step expression references control variable at %L"
 msgstr ""
 
-#: fortran/array.c:1966
+#: fortran/array.c:1975
 #, gcc-internal-format, gfc-internal-format
 msgid "Array constructor value at %L shall not be unlimited polymorphic [F2008: C4106]"
 msgstr ""
 
-#: fortran/array.c:2055
+#: fortran/array.c:2067
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "two `u's in integer constant"
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor at %L"
 msgstr "to 'u'-endelser i heltalskonstant"
 
-#: fortran/array.c:2174
+#: fortran/array.c:2186
 #, gcc-internal-format
 msgid "spec_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2233
+#: fortran/array.c:2245
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2237
+#: fortran/array.c:2249
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Null element at %0 for array reference at %1"
 msgid "Bad array dimension at %L"
 msgstr "Nulelement ved %0 for tabelreference ved %1"
 
-#: fortran/array.c:2264 fortran/data.c:552 fortran/data.c:571
-#: fortran/data.c:585 fortran/data.c:714
+#: fortran/array.c:2276 fortran/data.c:563 fortran/data.c:582
+#: fortran/data.c:596 fortran/data.c:725
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D'"
 msgid "Simplification error"
 msgstr "omerklæring af '%#D'"
 
-#: fortran/array.c:2376
+#: fortran/array.c:2388
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimen_type"
 msgstr ""
 
-#: fortran/array.c:2427
+#: fortran/array.c:2439
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2472
+#: fortran/array.c:2484
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad EXPR_ARRAY expr"
 msgstr ""
 
-#: fortran/array.c:2620
+#: fortran/array.c:2632
 #, gcc-internal-format
 msgid "gfc_find_array_ref(): No ref found"
 msgstr ""
@@ -56292,7 +56360,7 @@
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or PROCEDURE"
 msgstr ""
 
-#: fortran/check.c:205 fortran/check.c:6658
+#: fortran/check.c:205 fortran/check.c:6661
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate must be a constant"
 msgid "%qs argument of %qs intrinsic at %L must be a constant"
@@ -56414,7 +56482,7 @@
 msgid "Unequal character lengths (%ld/%ld) in %s at %L"
 msgstr ""
 
-#: fortran/check.c:946 fortran/check.c:6602
+#: fortran/check.c:946 fortran/check.c:6605
 #, gcc-internal-format
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have the same type"
 msgstr ""
@@ -56658,9 +56726,9 @@
 msgstr "1. parameter til __builtin_spe_predicate skal være en konstant"
 
 #: fortran/check.c:1939 fortran/check.c:2525 fortran/check.c:2628
-#: fortran/check.c:2835 fortran/check.c:2880 fortran/check.c:4256
-#: fortran/check.c:4390 fortran/check.c:4445 fortran/check.c:5515
-#: fortran/check.c:5644
+#: fortran/check.c:2835 fortran/check.c:2880 fortran/check.c:4259
+#: fortran/check.c:4393 fortran/check.c:4448 fortran/check.c:5518
+#: fortran/check.c:5647
 #, gcc-internal-format
 msgid "%qs intrinsic with KIND argument at %L"
 msgstr ""
@@ -56862,7 +56930,7 @@
 msgid "NULL intrinsic with allocatable MOLD at %L"
 msgstr ""
 
-#: fortran/check.c:3768 fortran/check.c:5591
+#: fortran/check.c:3768 fortran/check.c:5594
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must provide at least as many elements as there are .TRUE. values in %qs (%ld/%d)"
 msgstr ""
@@ -56882,376 +56950,376 @@
 msgid "%qs argument of %qs intrinsic at %L must not be a subobject of %qs"
 msgstr ""
 
-#: fortran/check.c:3901
+#: fortran/check.c:3904
 #, gcc-internal-format, gfc-internal-format
 msgid "The argument of the RANK intrinsic at %L must be a data object"
 msgstr ""
 
-#: fortran/check.c:4005
+#: fortran/check.c:4008
 #, gcc-internal-format
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L must be an array of constant size"
 msgstr ""
 
-#: fortran/check.c:4015
+#: fortran/check.c:4018
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L is empty"
 msgstr ""
 
-#: fortran/check.c:4022
+#: fortran/check.c:4025
 #, gcc-internal-format
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L has more than %d elements"
 msgstr ""
 
-#: fortran/check.c:4039
+#: fortran/check.c:4042
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has negative element (%d)"
 msgstr ""
 
-#: fortran/check.c:4071
+#: fortran/check.c:4074
 #, gcc-internal-format, gfc-internal-format
 msgid "Element %d of actual argument of RESHAPE at %L cannot be negative"
 msgstr ""
 
-#: fortran/check.c:4109
+#: fortran/check.c:4112
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has wrong number of elements (%d/%d)"
 msgstr ""
 
-#: fortran/check.c:4127
+#: fortran/check.c:4130
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has out-of-range dimension (%d)"
 msgstr ""
 
-#: fortran/check.c:4136
+#: fortran/check.c:4139
 #, fuzzy, gcc-internal-format
 #| msgid "argument to `%s' attribute larger than %d"
 msgid "%qs argument of %qs intrinsic at %L has invalid permutation of dimensions (dimension %qd duplicated)"
 msgstr "parameter til egenskaben '%s' er større end %d"
 
-#: fortran/check.c:4172
+#: fortran/check.c:4175
 #, gcc-internal-format, gfc-internal-format
 msgid "Without padding, there are not enough elements in the intrinsic RESHAPE source at %L to match the shape"
 msgstr ""
 
-#: fortran/check.c:4189 fortran/check.c:4208
+#: fortran/check.c:4192 fortran/check.c:4211
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L cannot be of type %s"
 msgstr ""
 
-#: fortran/check.c:4199 fortran/check.c:4218
+#: fortran/check.c:4202 fortran/check.c:4221
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of an extensible type"
 msgstr ""
 
-#: fortran/check.c:4317
+#: fortran/check.c:4320
 #, gcc-internal-format
 msgid "SELECTED_REAL_KIND with neither %<P%> nor %<R%> argument at %L"
 msgstr ""
 
-#: fortran/check.c:4348
+#: fortran/check.c:4351
 #, gcc-internal-format
 msgid "%qs intrinsic with RADIX argument at %L"
 msgstr ""
 
-#: fortran/check.c:4383
+#: fortran/check.c:4386
 #, gcc-internal-format
 msgid "%<source%> argument of %<shape%> intrinsic at %L must not be an assumed size array"
 msgstr ""
 
-#: fortran/check.c:4460 fortran/check.c:6641
+#: fortran/check.c:4463 fortran/check.c:6644
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be a procedure"
 msgstr ""
 
-#: fortran/check.c:4473 fortran/check.c:4612 fortran/check.c:6633
+#: fortran/check.c:4476 fortran/check.c:4615 fortran/check.c:6636
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be TYPE(*)"
 msgstr ""
 
-#: fortran/check.c:4484 fortran/check.c:4624
+#: fortran/check.c:4487 fortran/check.c:4627
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be an assumed-size array"
 msgstr ""
 
-#: fortran/check.c:4554
+#: fortran/check.c:4557
 #, gcc-internal-format
 msgid "is_c_interoperable(): gfc_simplify_expr failed"
 msgstr ""
 
-#: fortran/check.c:4603
+#: fortran/check.c:4606
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be an interoperable data entity: %s"
 msgstr ""
 
-#: fortran/check.c:4642
+#: fortran/check.c:4645
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_1 at %L to C_ASSOCIATED shall have the type TYPE(C_PTR) or TYPE(C_FUNPTR)"
 msgstr ""
 
-#: fortran/check.c:4656
+#: fortran/check.c:4659
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_2 at %L to C_ASSOCIATED shall have the same type as C_PTR_1: %s instead of %s"
 msgstr ""
 
-#: fortran/check.c:4680
+#: fortran/check.c:4683
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_POINTER shall have the type TYPE(C_PTR)"
 msgstr ""
 
-#: fortran/check.c:4692
+#: fortran/check.c:4695
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER must be a pointer"
 msgstr ""
 
-#: fortran/check.c:4699
+#: fortran/check.c:4702
 #, gcc-internal-format, gfc-internal-format
 msgid "FPTR argument at %L to C_F_POINTER shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:4706
+#: fortran/check.c:4709
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:4713
+#: fortran/check.c:4716
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected SHAPE argument at %L to C_F_POINTER with scalar FPTR"
 msgstr ""
 
-#: fortran/check.c:4719
+#: fortran/check.c:4722
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected SHAPE argument to C_F_POINTER with array FPTR at %L"
 msgstr ""
 
-#: fortran/check.c:4738
+#: fortran/check.c:4741
 #, gcc-internal-format, gfc-internal-format
 msgid "SHAPE argument at %L to C_F_POINTER must have the same size as the RANK of FPTR"
 msgstr ""
 
-#: fortran/check.c:4748
+#: fortran/check.c:4751
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic FPTR at %L to C_F_POINTER"
 msgstr ""
 
-#: fortran/check.c:4753
+#: fortran/check.c:4756
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array FPTR at %L to C_F_POINTER: %s"
 msgstr ""
 
-#: fortran/check.c:4769
+#: fortran/check.c:4772
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_PROCPOINTER shall have the type TYPE(C_FUNPTR)"
 msgstr ""
 
-#: fortran/check.c:4781
+#: fortran/check.c:4784
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall be a procedure pointer"
 msgstr ""
 
-#: fortran/check.c:4788
+#: fortran/check.c:4791
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:4794
+#: fortran/check.c:4797
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure pointer at %L to C_F_PROCPOINTER"
 msgstr ""
 
-#: fortran/check.c:4808
+#: fortran/check.c:4811
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:4823
+#: fortran/check.c:4826
 #, gcc-internal-format
 msgid "Function result %qs at %L is invalid as X argument to C_FUNLOC"
 msgstr ""
 
-#: fortran/check.c:4831
+#: fortran/check.c:4834
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall be a procedure or a procedure pointer"
 msgstr ""
 
-#: fortran/check.c:4837
+#: fortran/check.c:4840
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure at %L to C_FUNLOC"
 msgstr ""
 
-#: fortran/check.c:4851
+#: fortran/check.c:4854
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:4857
+#: fortran/check.c:4860
 #, gcc-internal-format, gfc-internal-format
 msgid "X argument at %L to C_LOC shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:4868
+#: fortran/check.c:4871
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall have either the POINTER or the TARGET attribute"
 msgstr ""
 
-#: fortran/check.c:4876
+#: fortran/check.c:4879
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall be not be a zero-sized string"
 msgstr ""
 
-#: fortran/check.c:4885
+#: fortran/check.c:4888
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument at %L to C_LOC shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:4892
+#: fortran/check.c:4895
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array at %L as argument to C_LOC: %s"
 msgstr ""
 
-#: fortran/check.c:4903
+#: fortran/check.c:4906
 #, gcc-internal-format, gfc-internal-format
 msgid "Array of interoperable type at %L to C_LOC which is nonallocatable and neither assumed size nor explicit size"
 msgstr ""
 
-#: fortran/check.c:4908
+#: fortran/check.c:4911
 #, gcc-internal-format, gfc-internal-format
 msgid "Array section at %L to C_LOC"
 msgstr ""
 
-#: fortran/check.c:4936
+#: fortran/check.c:4939
 #, gcc-internal-format, gfc-internal-format
 msgid "non double precision REAL argument to %s intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:4949
+#: fortran/check.c:4952
 #, fuzzy, gcc-internal-format
 #| msgid "argument to `%s' attribute larger than %d"
 msgid "%qs argument of %qs intrinsic at %L must be less than rank %d"
 msgstr "parameter til egenskaben '%s' er større end %d"
 
-#: fortran/check.c:4968
+#: fortran/check.c:4971
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L is not a valid dimension index"
 msgstr ""
 
-#: fortran/check.c:5231
+#: fortran/check.c:5234
 #, gcc-internal-format, gfc-internal-format
 msgid "%s argument to IMAGE_INDEX must be a rank one array at %L"
 msgstr ""
 
-#: fortran/check.c:5242
+#: fortran/check.c:5245
 #, gcc-internal-format, gfc-internal-format
 msgid "The number of array elements of the SUB argument to IMAGE_INDEX at %L shall be %d (corank) not %d"
 msgstr ""
 
-#: fortran/check.c:5275
+#: fortran/check.c:5278
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to NUM_IMAGES at %L"
 msgstr ""
 
-#: fortran/check.c:5288
+#: fortran/check.c:5291
 #, gcc-internal-format, gfc-internal-format
 msgid "FAILED= argument to NUM_IMAGES at %L"
 msgstr ""
 
-#: fortran/check.c:5312
+#: fortran/check.c:5315
 #, gcc-internal-format, gfc-internal-format
 msgid "TEAM argument at %L to the intrinsic TEAM_NUMBER shall be of type TEAM_TYPE"
 msgstr ""
 
-#: fortran/check.c:5338
+#: fortran/check.c:5341
 #, gcc-internal-format, gfc-internal-format
 msgid "DIM argument without COARRAY argument not allowed for THIS_IMAGE intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:5345
+#: fortran/check.c:5348
 #, gcc-internal-format, gfc-internal-format
 msgid "The DISTANCE argument may not be specified together with the COARRAY or DIM argument in intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:5356
+#: fortran/check.c:5359
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected DIM argument with noncoarray argument at %L"
 msgstr ""
 
-#: fortran/check.c:5374
+#: fortran/check.c:5377
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to THIS_IMAGE at %L"
 msgstr ""
 
-#: fortran/check.c:5454
+#: fortran/check.c:5457
 #, gcc-internal-format
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L must not be %s"
 msgstr ""
 
-#: fortran/check.c:5483
+#: fortran/check.c:5486
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic TRANSFER at %L has partly undefined result: source size %ld < result size %ld"
 msgstr ""
 
-#: fortran/check.c:5605
+#: fortran/check.c:5608
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must have the same rank as %qs or be a scalar"
 msgstr ""
 
-#: fortran/check.c:5618
+#: fortran/check.c:5621
 #, gcc-internal-format
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have identical shape."
 msgstr ""
 
-#: fortran/check.c:5861 fortran/check.c:5893
+#: fortran/check.c:5864 fortran/check.c:5896
 #, gcc-internal-format
 msgid "Size of %qs argument of %qs intrinsic at %L too small (%i/%i)"
 msgstr ""
 
-#: fortran/check.c:5901
+#: fortran/check.c:5904
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "too many arguments to %s `%+#D'"
 msgid "Too many arguments to %s at %L"
 msgstr "for mange parametre til %s '%+#D'"
 
-#: fortran/check.c:5919
+#: fortran/check.c:5922
 #, gcc-internal-format
 msgid "fe_runtime_error string must be null terminated"
 msgstr ""
 
-#: fortran/check.c:5931
+#: fortran/check.c:5934
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "fe_runtime_error: Wrong number of arguments (%d instead of %d)"
 msgstr "forkert antal skabelonsparametre (%d, skulle være %d)"
 
-#: fortran/check.c:5971
+#: fortran/check.c:5974
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:5990
+#: fortran/check.c:5993
 #, gcc-internal-format, gfc-internal-format
 msgid "Real COUNT_RATE argument to SYSTEM_CLOCK at %L"
 msgstr ""
 
-#: fortran/check.c:6000
+#: fortran/check.c:6003
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT_RATE argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:6017
+#: fortran/check.c:6020
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT_MAX argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:6234
+#: fortran/check.c:6237
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of a kind not wider than the default kind (%d)"
 msgstr ""
 
-#: fortran/check.c:6586 fortran/check.c:6594
+#: fortran/check.c:6589 fortran/check.c:6597
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or LOGICAL"
 msgstr ""
 
-#: fortran/check.c:6625
+#: fortran/check.c:6628
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic function NULL at %L cannot be an actual argument to STORAGE_SIZE, because it returns a disassociated pointer"
 msgstr ""
@@ -57263,7 +57331,7 @@
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:727 fortran/decl.c:3636 fortran/decl.c:10066
+#: fortran/class.c:727 fortran/decl.c:3655 fortran/decl.c:10091
 #, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr ""
@@ -57289,46 +57357,51 @@
 msgid "non-constant array in DATA statement %L"
 msgstr "tabelindekset i startværdien er ikke en konstant"
 
-#: fortran/data.c:137
+#: fortran/data.c:140
 #, gcc-internal-format, gfc-internal-format
 msgid "failure to simplify substring reference in DATA statement at %L"
 msgstr ""
 
-#: fortran/data.c:170
+#: fortran/data.c:173
 #, gcc-internal-format, gfc-internal-format
 msgid "Unused initialization string at %L because variable has zero length"
 msgstr ""
 
-#: fortran/data.c:176
+#: fortran/data.c:179
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization string at %L was truncated to fit the variable (%ld/%ld)"
 msgstr ""
 
-#: fortran/data.c:265
+#: fortran/data.c:268
 #, fuzzy, gcc-internal-format
 #| msgid "base class `%T' already initialized"
 msgid "%qs at %L already is initialized at %L"
 msgstr "stamklassen '%T' er allerede klargjort"
 
-#: fortran/data.c:289
+#: fortran/data.c:292
 #, gcc-internal-format, gfc-internal-format
 msgid "Data element below array lower bound at %L"
 msgstr ""
 
-#: fortran/data.c:306 fortran/data.c:395
+#: fortran/data.c:309 fortran/data.c:398
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Null element at %0 for array reference at %1"
 msgid "Data element above array upper bound at %L"
 msgstr "Nulelement ved %0 for tabelreference ved %1"
 
-#: fortran/data.c:336 fortran/data.c:505
+#: fortran/data.c:339 fortran/data.c:496
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate initialization of %D"
 msgid "re-initialization of %qs at %L"
 msgstr "%D tildelt startværdi mere end én gang"
 
-#: fortran/data.c:727
+#: fortran/data.c:515
 #, gcc-internal-format
+msgid "Nonpointer object %qs with default initialization shall not appear in a DATA statement at %L"
+msgstr ""
+
+#: fortran/data.c:738
+#, gcc-internal-format
 msgid "TODO: Vector sections in data statements"
 msgstr ""
 
@@ -57353,834 +57426,833 @@
 msgid "Invalid initializer %s in Data statement at %C"
 msgstr "ugyldig startværdi til virtuel medlemsfunktion '%D'"
 
-#: fortran/decl.c:536
+#: fortran/decl.c:537
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:573
+#: fortran/decl.c:574
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "RETURN statement at %0 invalid within a main program unit"
 msgid "DATA statement at %C cannot appear within an INTERFACE"
 msgstr "RETURN-sætning ved %0 ugyldig inden i en hovedprogramenhed"
 
-#: fortran/decl.c:597
+#: fortran/decl.c:598
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid initializer for virtual method `%D'"
 msgid "Invalid substring in data-implied-do at %L in DATA statement"
 msgstr "ugyldig startværdi til virtuel medlemsfunktion '%D'"
 
-#: fortran/decl.c:619
+#: fortran/decl.c:620
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:664
+#: fortran/decl.c:662
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "duplicate initialization of %D"
 msgid "Empty old style initializer list at %C"
 msgstr "%D tildelt startværdi mere end én gang"
 
-#: fortran/decl.c:684
+#: fortran/decl.c:671
+#, gcc-internal-format, gfc-internal-format
+msgid "Array in initializer list at %L must have an explicit shape"
+msgstr ""
+
+#: fortran/decl.c:694
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "extra elements in scalar initializer"
 msgid "Repeat spec invalid in scalar initializer at %C"
 msgstr "overskydende elementer i skalarstarværdi"
 
-#: fortran/decl.c:689
+#: fortran/decl.c:699
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "two `u's in integer constant"
 msgid "Repeat spec must be an integer at %C"
 msgstr "to 'u'-endelser i heltalskonstant"
 
-#: fortran/decl.c:698
+#: fortran/decl.c:710
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected data constant after repeat spec at %C"
 msgstr "objekt mangler i brug af '%E'"
 
-#: fortran/decl.c:729
+#: fortran/decl.c:742
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "initialization of new expression with `='"
 msgid "End of scalar initializer expected at %C"
 msgstr "tildeling af startværdi til new-udtryk med '='"
 
-#: fortran/decl.c:758
+#: fortran/decl.c:773
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "duplicate initialization of %D"
-msgid "Expected constant array-spec in initializer list at %L"
-msgstr "%D tildelt startværdi mere end én gang"
-
-#: fortran/decl.c:767
-#, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "excess elements in array initializer"
 msgid "Not enough elements in array initializer at %C"
 msgstr "for mange elementer i tabelstartværdi"
 
-#: fortran/decl.c:769
+#: fortran/decl.c:775
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "excess elements in array initializer"
 msgid "Too many elements in array initializer at %C"
 msgstr "for mange elementer i tabelstartværdi"
 
-#: fortran/decl.c:790
+#: fortran/decl.c:795
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in old style initializer list at %C"
 msgstr "\"%s\" må ikke optræde i makroparameterliste"
 
-#: fortran/decl.c:812
+#: fortran/decl.c:821
 #, gcc-internal-format, gfc-internal-format
 msgid "The assumed-rank array at %C shall not have a codimension"
 msgstr ""
 
-#: fortran/decl.c:876
+#: fortran/decl.c:885
 #, gcc-internal-format, gfc-internal-format
 msgid "Sum of array rank %d and corank %d at %C exceeds maximum allowed dimensions of %d"
 msgstr ""
 
-#: fortran/decl.c:900
+#: fortran/decl.c:909
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad INTENT specification at %C"
 msgstr ""
 
-#: fortran/decl.c:921
+#: fortran/decl.c:930
 #, gcc-internal-format, gfc-internal-format
 msgid "deferred type parameter at %C"
 msgstr ""
 
-#: fortran/decl.c:1004 fortran/resolve.c:11705
+#: fortran/decl.c:1013 fortran/resolve.c:11725
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
 
-#: fortran/decl.c:1030
+#: fortran/decl.c:1039
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Zero-length character constant at %0"
 msgid "Old-style character length at %C"
 msgstr "Nul-længde tegnkonstant ved %0"
 
-#: fortran/decl.c:1061
+#: fortran/decl.c:1070
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "parse error in method specification"
 msgid "Syntax error in character length specification at %C"
 msgstr "tolkningsfejl i medlemsfunktionsangivelsen"
 
-#: fortran/decl.c:1212 fortran/decl.c:1217 fortran/decl.c:1266
+#: fortran/decl.c:1221 fortran/decl.c:1226 fortran/decl.c:1275
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is already defined in `%T'"
 msgid "Procedure %qs at %C is already defined at %L"
 msgstr "'%D' er allerede defineret i '%T'"
 
-#: fortran/decl.c:1222
+#: fortran/decl.c:1231
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is already defined in `%T'"
 msgid "Contained procedure %qs at %C clashes with procedure defined at %L"
 msgstr "'%D' er allerede defineret i '%T'"
 
-#: fortran/decl.c:1231
+#: fortran/decl.c:1240
 #, fuzzy, gcc-internal-format
 #| msgid "Label %A already defined at %1 when redefined at %0"
 msgid "Name %qs at %C is already defined as a generic interface at %L"
 msgstr "Etiket %A er allerede defineret ved %1 ved omdefinering ved %0"
 
-#: fortran/decl.c:1244
+#: fortran/decl.c:1253
 #, fuzzy, gcc-internal-format
 #| msgid "External procedure `%A' is passed as actual argument at %0 but not explicitly declared EXTERNAL"
 msgid "Procedure %qs at %C has an explicit interface from a previous declaration"
 msgstr "Ekstern procedure '%A' er overbragt som faktisk parameter ved %0, men ikke eksplicit erklæret EXTERNAL"
 
-#: fortran/decl.c:1257
+#: fortran/decl.c:1266
 #, gcc-internal-format
 msgid "Procedure %qs defined in interface body at %L clashes with internal procedure defined at %C"
 msgstr ""
 
-#: fortran/decl.c:1335
+#: fortran/decl.c:1344
 #, gcc-internal-format
 msgid "Procedure %qs at %L must have the BIND(C) attribute to be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:1362
+#: fortran/decl.c:1371
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because derived type %qs is not C interoperable"
 msgstr ""
 
-#: fortran/decl.c:1369
+#: fortran/decl.c:1378
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because it is polymorphic"
 msgstr ""
 
-#: fortran/decl.c:1376
+#: fortran/decl.c:1385
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument of the BIND(C) procedure %qs but may not be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:1391
+#: fortran/decl.c:1400
 #, gcc-internal-format
 msgid "Character argument %qs at %L must be length 1 because procedure %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1404
+#: fortran/decl.c:1413
 #, gcc-internal-format
 msgid "Variable %qs at %L with ALLOCATABLE attribute in procedure %qs with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1412
+#: fortran/decl.c:1421
 #, gcc-internal-format
 msgid "Variable %qs at %L with POINTER attribute in procedure %qs with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1421
+#: fortran/decl.c:1430
 #, gcc-internal-format
 msgid "Scalar variable %qs at %L with POINTER or ALLOCATABLE in procedure %qs with BIND(C) is not yet supported"
 msgstr ""
 
-#: fortran/decl.c:1430
+#: fortran/decl.c:1439
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the OPTIONAL and the VALUE attribute because procedure %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1437
+#: fortran/decl.c:1446
 #, gcc-internal-format
 msgid "Variable %qs at %L with OPTIONAL attribute in procedure %qs which is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1448
+#: fortran/decl.c:1457
 #, gcc-internal-format
 msgid "Assumed-shape array %qs at %L as dummy argument to the BIND(C) procedure %qs at %L"
 msgstr ""
 
-#: fortran/decl.c:1516
+#: fortran/decl.c:1525
 #, fuzzy, gcc-internal-format
 #| msgid "Symbols have a leading underscore"
 msgid "Symbol %qs at %C also declared as a type at %L"
 msgstr "Symboler har en indledende understreg"
 
-#: fortran/decl.c:1575
+#: fortran/decl.c:1584
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %C must be declared with a C interoperable kind since common block %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1615
+#: fortran/decl.c:1624
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "two `u's in integer constant"
 msgid "CHARACTER length must be a constant at %L"
 msgstr "to 'u'-endelser i heltalskonstant"
 
-#: fortran/decl.c:1630
+#: fortran/decl.c:1639
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression at %L is being truncated (%ld/%ld)"
 msgstr ""
 
-#: fortran/decl.c:1638
+#: fortran/decl.c:1647
 #, gcc-internal-format, gfc-internal-format
 msgid "The CHARACTER elements of the array constructor at %L must have the same length (%ld/%ld)"
 msgstr ""
 
-#: fortran/decl.c:1729
+#: fortran/decl.c:1738
 #, gcc-internal-format
 msgid "Initializer not allowed for PARAMETER %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:1739
+#: fortran/decl.c:1748
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing initializer"
 msgid "PARAMETER at %L is missing an initializer"
 msgstr "manglende startværdi"
 
-#: fortran/decl.c:1749
+#: fortran/decl.c:1758
 #, gcc-internal-format
 msgid "Variable %qs at %C with an initializer already appears in a DATA statement"
 msgstr ""
 
-#: fortran/decl.c:1792
+#: fortran/decl.c:1801
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot initialize multi-dimensional array with initializer"
 msgid "Cannot initialize parameter array at %L with variable length elements"
 msgstr "kan ikke klargøre multidimensional tabel med startværdi"
 
-#: fortran/decl.c:1861
+#: fortran/decl.c:1870
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot initialize multi-dimensional array with initializer"
 msgid "Can't initialize implied-shape array at %L with scalar"
 msgstr "kan ikke klargøre multidimensional tabel med startværdi"
 
-#: fortran/decl.c:1896
+#: fortran/decl.c:1905
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-constant lower bound in implied-shape declaration at %L"
 msgstr ""
 
-#: fortran/decl.c:1982 fortran/decl.c:1989
+#: fortran/decl.c:1991 fortran/decl.c:1998
 #, gcc-internal-format, gfc-internal-format
 msgid "Component at %C must have the POINTER attribute"
 msgstr ""
 
-#: fortran/decl.c:1998
+#: fortran/decl.c:2007
 #, gcc-internal-format
 msgid "Component %qs with CLASS at %C must be allocatable or pointer"
 msgstr ""
 
-#: fortran/decl.c:2007
+#: fortran/decl.c:2016
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr ""
 
-#: fortran/decl.c:2031 fortran/symbol.c:2230
+#: fortran/decl.c:2040 fortran/symbol.c:2244
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is already defined in `%T'"
 msgid "Component %qs at %C already declared at %L"
 msgstr "'%D' er allerede defineret i '%T'"
 
-#: fortran/decl.c:2079
+#: fortran/decl.c:2088
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer array component of structure at %C must have a deferred shape"
 msgstr ""
 
-#: fortran/decl.c:2088
+#: fortran/decl.c:2097
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component of structure at %C must have a deferred shape"
 msgstr ""
 
-#: fortran/decl.c:2097
+#: fortran/decl.c:2106
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have an explicit shape"
 msgstr ""
 
-#: fortran/decl.c:2114
+#: fortran/decl.c:2123
 #, fuzzy, gcc-internal-format
 #| msgid "a parameter list with an ellipsis can't match an empty parameter name list declaration"
 msgid "Type parameter %qs at %C has no corresponding entry in the type parameter name list at %L"
 msgstr "en parameterliste med '...' passer ikke til en erklæring med en tom parameterliste"
 
-#: fortran/decl.c:2171
+#: fortran/decl.c:2180
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C is ambiguous"
 msgstr ""
 
-#: fortran/decl.c:2188
+#: fortran/decl.c:2197
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "initialization designators may not nest"
 msgid "NULL() initialization at %C may not have MOLD"
 msgstr "klargøringstegn må ikke indlejres"
 
-#: fortran/decl.c:2205
+#: fortran/decl.c:2214
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of pointer at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:2226
+#: fortran/decl.c:2235
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "duplicate initialization of %D"
 msgid "Error in pointer initialization at %C"
 msgstr "%D tildelt startværdi mere end én gang"
 
-#: fortran/decl.c:2233
+#: fortran/decl.c:2242
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "duplicate initialization of %D"
 msgid "non-NULL pointer initialization at %C"
 msgstr "%D tildelt startværdi mere end én gang"
 
-#: fortran/decl.c:2256
+#: fortran/decl.c:2265
 #, gcc-internal-format
 msgid "RESULT variable %qs at %L prohibits FUNCTION name %qs at %C from appearing in a specification statement"
 msgstr ""
 
-#: fortran/decl.c:2318
+#: fortran/decl.c:2327
 #, fuzzy, gcc-internal-format
 #| msgid "INTENT is not allowed inside of BLOCK at %C"
 msgid "%qs not allowed outside STRUCTURE at %C"
 msgstr "INTENT er ikke tilladt i BLOCK ved %C"
 
-#: fortran/decl.c:2320
+#: fortran/decl.c:2329
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a member of type `%T'"
 msgid "%qs at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr "'%D' er ikke et medlem af typen '%T'"
 
-#: fortran/decl.c:2327
+#: fortran/decl.c:2336
 #, fuzzy, gcc-internal-format
 #| msgid "`-%c' option must have argument"
 msgid "%qs entity cannot have attributes at %C"
 msgstr "tilvalget '-%c' skal have en parameter"
 
-#: fortran/decl.c:2367
+#: fortran/decl.c:2376
 #, gcc-internal-format
 msgid "Non-PARAMETER symbol %qs at %L can't be implied-shape"
 msgstr ""
 
-#: fortran/decl.c:2377
+#: fortran/decl.c:2386
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Zero-size array at %0"
 msgid "Implied-shape array at %L"
 msgstr "Nulstørrelsestabel ved %0"
 
-#: fortran/decl.c:2422
+#: fortran/decl.c:2431
 #, gcc-internal-format, gfc-internal-format
 msgid "Explicit shaped array with nonconstant bounds at %C"
 msgstr ""
 
-#: fortran/decl.c:2501
+#: fortran/decl.c:2510
 #, gcc-internal-format
 msgid "%qs at %C is a redefinition of the declaration in the corresponding interface for MODULE PROCEDURE %qs"
 msgstr ""
 
-#: fortran/decl.c:2512
+#: fortran/decl.c:2521
 #, fuzzy, gcc-internal-format
 msgid "%qs entity cannot have an initializer at %C"
 msgstr "slutfeltet '%s' bliver måske ikke klargjort"
 
-#: fortran/decl.c:2538 fortran/decl.c:8369
+#: fortran/decl.c:2547 fortran/decl.c:8388
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr ""
 
-#: fortran/decl.c:2546
+#: fortran/decl.c:2555
 #, gcc-internal-format
 msgid "Couldn't set pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:2609
+#: fortran/decl.c:2618
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "duplicate initialization of %D"
 msgid "Old-style initialization at %C"
 msgstr "%D tildelt startværdi mere end én gang"
 
-#: fortran/decl.c:2617
+#: fortran/decl.c:2626
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr ""
 
-#: fortran/decl.c:2630
+#: fortran/decl.c:2639
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "duplicate initialization of %D"
 msgid "Syntax error in old style initialization of %s at %C"
 msgstr "%D tildelt startværdi mere end én gang"
 
-#: fortran/decl.c:2650 fortran/decl.c:6661
+#: fortran/decl.c:2659 fortran/decl.c:6680
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr ""
 
-#: fortran/decl.c:2663
+#: fortran/decl.c:2672
 #, gcc-internal-format
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr ""
 
-#: fortran/decl.c:2672 fortran/decl.c:10240
+#: fortran/decl.c:2681 fortran/decl.c:10265
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "initialization of new expression with `='"
 msgid "Expected an initialization expression at %C"
 msgstr "tildeling af startværdi til new-udtryk med '='"
 
-#: fortran/decl.c:2679
+#: fortran/decl.c:2688
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:2696
+#: fortran/decl.c:2705
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr ""
 
-#: fortran/decl.c:2710
+#: fortran/decl.c:2719
 #, gcc-internal-format, gfc-internal-format
 msgid "The component with KIND or LEN attribute at %C does not not appear in the type parameter list at %L"
 msgstr ""
 
-#: fortran/decl.c:2718
+#: fortran/decl.c:2727
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C that appears in the type parameter list at %L has neither the KIND nor LEN attribute"
 msgstr ""
 
-#: fortran/decl.c:2726
+#: fortran/decl.c:2735
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C which is a type parameter must be a scalar"
 msgstr ""
 
-#: fortran/decl.c:2789 fortran/decl.c:2825
+#: fortran/decl.c:2798 fortran/decl.c:2834
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%Jweak declaration of '%D' not supported"
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr "%Jsvag erklæring af '%D' ikke understøttet"
 
-#: fortran/decl.c:2831
+#: fortran/decl.c:2840
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "nested extern declaration of `%s'"
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr "indlejret extern-erklæring af '%s'"
 
-#: fortran/decl.c:2890 fortran/decl.c:2967
+#: fortran/decl.c:2899 fortran/decl.c:2976
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing formal parameter term"
 msgid "Missing right parenthesis at %C"
 msgstr "Manglende formel parameterterm"
 
-#: fortran/decl.c:2903 fortran/decl.c:3038
+#: fortran/decl.c:2912 fortran/decl.c:3047
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "initialization of new expression with `='"
 msgid "Expected initialization expression at %C"
 msgstr "tildeling af startværdi til new-udtryk med '='"
 
-#: fortran/decl.c:2911 fortran/decl.c:3044
+#: fortran/decl.c:2920 fortran/decl.c:3053
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "initialization of new expression with `='"
 msgid "Expected scalar initialization expression at %C"
 msgstr "tildeling af startværdi til new-udtryk med '='"
 
-#: fortran/decl.c:2941 fortran/decl.c:3657
+#: fortran/decl.c:2950 fortran/decl.c:3676
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "rounding mode not supported for VAX floats"
 msgid "Kind %d not supported for type %s at %C"
 msgstr "afrundingstilstand er ikke understøttet for VAX-kommatal"
 
-#: fortran/decl.c:2954
+#: fortran/decl.c:2963
 #, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr ""
 
-#: fortran/decl.c:2965
+#: fortran/decl.c:2974
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr ""
 
-#: fortran/decl.c:3070
+#: fortran/decl.c:3079
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "rounding mode not supported for VAX floats"
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr "afrundingstilstand er ikke understøttet for VAX-kommatal"
 
-#: fortran/decl.c:3202
+#: fortran/decl.c:3211
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:3291
+#: fortran/decl.c:3310
 #, gcc-internal-format, gfc-internal-format
 msgid "RECORD at %C is an extension, enable it with -fdec-structure"
 msgstr ""
 
-#: fortran/decl.c:3304
+#: fortran/decl.c:3323
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Structure name expected after RECORD at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/decl.c:3417
+#: fortran/decl.c:3436
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C cannot contain both ASSUMED and DEFERRED parameters"
 msgstr ""
 
-#: fortran/decl.c:3441
+#: fortran/decl.c:3460
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C does not contain enough parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3465
+#: fortran/decl.c:3484
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' cannot have default arguments"
 msgid "The derived parameter %qs at %C does not have a default value"
 msgstr "'%D' kan ikke have standardparametre"
 
-#: fortran/decl.c:3497
+#: fortran/decl.c:3516
 #, gcc-internal-format, gfc-internal-format
 msgid "The parameter expression at %C must be of INTEGER type and not %s type"
 msgstr ""
 
-#: fortran/decl.c:3525
+#: fortran/decl.c:3544
 #, gcc-internal-format
 msgid "The KIND parameter %qs at %C cannot either be ASSUMED or DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:3532
+#: fortran/decl.c:3551
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%D' is not an integral constant-expression"
 msgid "The value for the KIND parameter %qs at %C does not reduce to a constant expression"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: fortran/decl.c:3547
+#: fortran/decl.c:3566
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C contains too many parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3556
+#: fortran/decl.c:3575
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid type argument"
 msgid "Parameterized derived type at %C is ambiguous"
 msgstr "ugyldig typeparameter"
 
-#: fortran/decl.c:3819
+#: fortran/decl.c:3838
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type at %C"
 msgstr ""
 
-#: fortran/decl.c:3824
+#: fortran/decl.c:3843
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr ""
 
-#: fortran/decl.c:3846
+#: fortran/decl.c:3865
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C is not allowed for components"
 msgstr ""
 
-#: fortran/decl.c:3849
+#: fortran/decl.c:3868
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr ""
 
-#: fortran/decl.c:3872 fortran/decl.c:3903 fortran/decl.c:3932
-#: fortran/decl.c:4216
+#: fortran/decl.c:3891 fortran/decl.c:3922 fortran/decl.c:3951
+#: fortran/decl.c:4235
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr ""
 
-#: fortran/decl.c:3928
+#: fortran/decl.c:3947
 #, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr ""
 
-#: fortran/decl.c:3971 fortran/decl.c:4107 fortran/decl.c:4119
-#: fortran/decl.c:4133 fortran/decl.c:4611 fortran/decl.c:4619
+#: fortran/decl.c:3990 fortran/decl.c:4126 fortran/decl.c:4138
+#: fortran/decl.c:4152 fortran/decl.c:4630 fortran/decl.c:4638
 #, fuzzy, gcc-internal-format
 msgid "Type name %qs at %C is ambiguous"
 msgstr "brug af '%D' er tvetydigt"
 
-#: fortran/decl.c:4066
+#: fortran/decl.c:4085
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4148
+#: fortran/decl.c:4167
 #, gcc-internal-format
 msgid "Type name %qs at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr ""
 
-#: fortran/decl.c:4287
+#: fortran/decl.c:4306
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/decl.c:4296
+#: fortran/decl.c:4315
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr ""
 
-#: fortran/decl.c:4355
+#: fortran/decl.c:4374
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr ""
 
-#: fortran/decl.c:4401
+#: fortran/decl.c:4420
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4454
+#: fortran/decl.c:4473
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr ""
 
-#: fortran/decl.c:4464
+#: fortran/decl.c:4483
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Empty IMPLICIT statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/decl.c:4570
+#: fortran/decl.c:4589
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr ""
 
-#: fortran/decl.c:4577
+#: fortran/decl.c:4596
 #, gcc-internal-format, gfc-internal-format
 msgid "F2008: C1210 IMPORT statement at %C is not permitted in a module procedure interface body"
 msgstr ""
 
-#: fortran/decl.c:4582
+#: fortran/decl.c:4601
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing comma in FORMAT statement at %0"
 msgid "IMPORT statement at %C"
 msgstr "Manglende komma i FORMAT-sætning ved %0"
 
-#: fortran/decl.c:4596
+#: fortran/decl.c:4615
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr ""
 
-#: fortran/decl.c:4625
+#: fortran/decl.c:4644
 #, gcc-internal-format
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr ""
 
-#: fortran/decl.c:4632
+#: fortran/decl.c:4651
 #, gcc-internal-format
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr ""
 
-#: fortran/decl.c:4673
+#: fortran/decl.c:4692
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Spurious number in FORMAT statement at %0"
 msgid "Syntax error in IMPORT statement at %C"
 msgstr "Mystisk tal i FORMAT-sætning ved %0"
 
-#: fortran/decl.c:5010
+#: fortran/decl.c:5029
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Conflicting I/O control specifications at %0 and %1"
 msgid "Missing codimension specification at %C"
 msgstr "Modstridende I/O-kontrolangivelser ved %0 og %1"
 
-#: fortran/decl.c:5012
+#: fortran/decl.c:5031
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing %A specifier in statement at %0"
 msgid "Missing dimension specification at %C"
 msgstr "Manglende %A-angivelse i sætning ved %0"
 
-#: fortran/decl.c:5107
+#: fortran/decl.c:5126
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "duplicate ConstantValue attribute for field '%s'"
 msgid "Duplicate %s attribute at %L"
 msgstr "mere end én ConstantValue-egenskab for feltet '%s'"
 
-#: fortran/decl.c:5124
+#: fortran/decl.c:5143
 #, gcc-internal-format
 msgid "%s at %L is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:5141
+#: fortran/decl.c:5160
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5150
+#: fortran/decl.c:5169
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "KIND attribute at %C in a TYPE definition"
 msgstr "egenskaben '%s' kan kun anvendes med klassedefinitioner"
 
-#: fortran/decl.c:5158
+#: fortran/decl.c:5177
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be INTEGER"
 msgstr ""
 
-#: fortran/decl.c:5165
+#: fortran/decl.c:5184
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5174
+#: fortran/decl.c:5193
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LEN attribute at %C in a TYPE definition"
 msgstr "egenskaben '%s' kan kun anvendes med klassedefinitioner"
 
-#: fortran/decl.c:5182
+#: fortran/decl.c:5201
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be INTEGER"
 msgstr ""
 
-#: fortran/decl.c:5189
+#: fortran/decl.c:5208
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5198
+#: fortran/decl.c:5217
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr "en global registervariabel følger en funktionsdefinition"
 
-#: fortran/decl.c:5216
+#: fortran/decl.c:5235
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr "egenskaben '%s' kan kun anvendes med klassedefinitioner"
 
-#: fortran/decl.c:5226
+#: fortran/decl.c:5245
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:5236
+#: fortran/decl.c:5255
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed outside a TYPE definition"
 msgstr "en global registervariabel følger en funktionsdefinition"
 
-#: fortran/decl.c:5249
+#: fortran/decl.c:5268
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5260
+#: fortran/decl.c:5279
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5315 fortran/decl.c:8673
+#: fortran/decl.c:5334 fortran/decl.c:8692
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:5321
+#: fortran/decl.c:5340
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5355
+#: fortran/decl.c:5374
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5362
+#: fortran/decl.c:5381
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5369
+#: fortran/decl.c:5388
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr ""
 
-#: fortran/decl.c:5410
+#: fortran/decl.c:5429
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:5508
+#: fortran/decl.c:5527
 #, gcc-internal-format
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:5530
+#: fortran/decl.c:5549
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5539
+#: fortran/decl.c:5558
 #, gcc-internal-format
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5543
+#: fortran/decl.c:5562
 #, gcc-internal-format
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5555
+#: fortran/decl.c:5574
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr ""
 
-#: fortran/decl.c:5569
+#: fortran/decl.c:5588
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr ""
 
-#: fortran/decl.c:5577
+#: fortran/decl.c:5596
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr ""
 
-#: fortran/decl.c:5589
+#: fortran/decl.c:5608
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr ""
 
-#: fortran/decl.c:5597
+#: fortran/decl.c:5616
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be a character string"
 msgstr ""
@@ -58187,353 +58259,353 @@
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:5608
+#: fortran/decl.c:5627
 #, gcc-internal-format
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr ""
 
-#: fortran/decl.c:5682
+#: fortran/decl.c:5701
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5727
+#: fortran/decl.c:5746
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5734
+#: fortran/decl.c:5753
 #, fuzzy, gcc-internal-format
 #| msgid "Missing term"
 msgid "Missing symbol"
 msgstr "Manglende term"
 
-#: fortran/decl.c:5763
+#: fortran/decl.c:5782
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5850
+#: fortran/decl.c:5869
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr ""
 
-#: fortran/decl.c:5892
+#: fortran/decl.c:5911
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in anonymous structure declaration at %C"
 msgstr "\"%s\" må ikke optræde i makroparameterliste"
 
-#: fortran/decl.c:5901
+#: fortran/decl.c:5920
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr "\"%s\" må ikke optræde i makroparameterliste"
 
-#: fortran/decl.c:5951
+#: fortran/decl.c:5970
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C"
 msgstr ""
 
-#: fortran/decl.c:5996
+#: fortran/decl.c:6015
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPURE procedure at %C"
 msgstr ""
 
-#: fortran/decl.c:6008
+#: fortran/decl.c:6027
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr ""
 
-#: fortran/decl.c:6054
+#: fortran/decl.c:6073
 #, gcc-internal-format, gfc-internal-format
 msgid "ELEMENTAL prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6061
+#: fortran/decl.c:6080
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6068
+#: fortran/decl.c:6087
 #, gcc-internal-format, gfc-internal-format
 msgid "RECURSIVE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6134 fortran/primary.c:1820
+#: fortran/decl.c:6153 fortran/primary.c:1820
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong type argument to %s"
 msgid "Alternate-return argument at %C"
 msgstr "forkert parametertype til %s"
 
-#: fortran/decl.c:6140 fortran/decl.c:6148
+#: fortran/decl.c:6159 fortran/decl.c:6167
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "A parameter name is required at %C"
 msgstr "skabelonsparameter er påkrævet for '%T'"
 
-#: fortran/decl.c:6188
+#: fortran/decl.c:6207
 #, fuzzy, gcc-internal-format
 msgid "Name %qs at %C is the name of the procedure"
 msgstr "Planlæg ikke begyndelsen og slutningen af proceduren"
 
-#: fortran/decl.c:6201
+#: fortran/decl.c:6220
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Can't specify array dimension in a declaration"
 msgid "Expected parameter list in type declaration at %C"
 msgstr "Kan ikke angive tabeldimension i en erklæring"
 
-#: fortran/decl.c:6204
+#: fortran/decl.c:6223
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr ""
 
-#: fortran/decl.c:6222
+#: fortran/decl.c:6241
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate initialization of %D"
 msgid "Duplicate name %qs in parameter list at %C"
 msgstr "%D tildelt startværdi mere end én gang"
 
-#: fortran/decl.c:6225
+#: fortran/decl.c:6244
 #, gcc-internal-format
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr ""
 
-#: fortran/decl.c:6264
+#: fortran/decl.c:6283
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in MODULE PROCEDURE formal argument names (%s/%s) at %C"
 msgstr ""
 
-#: fortran/decl.c:6270
+#: fortran/decl.c:6289
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in number of MODULE PROCEDURE formal arguments at %C"
 msgstr ""
 
-#: fortran/decl.c:6309
+#: fortran/decl.c:6328
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr ""
 
-#: fortran/decl.c:6386
+#: fortran/decl.c:6405
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "conflicts with function declaration `%#D'"
 msgid "Unexpected junk after function declaration at %C"
 msgstr "strider mod funktionserklæring '%#D'"
 
-#: fortran/decl.c:6396 fortran/decl.c:7494
+#: fortran/decl.c:6415 fortran/decl.c:7513
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr "sektionsegenskaben kan ikke angives for lokale variabler"
 
-#: fortran/decl.c:6600
+#: fortran/decl.c:6619
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:6607
+#: fortran/decl.c:6626
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:6613
+#: fortran/decl.c:6632
 #, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr ""
 
-#: fortran/decl.c:6636
+#: fortran/decl.c:6655
 #, gcc-internal-format
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr ""
 
-#: fortran/decl.c:6682 fortran/decl.c:6870 fortran/decl.c:10723
+#: fortran/decl.c:6701 fortran/decl.c:6889 fortran/decl.c:10748
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Spurious number in FORMAT statement at %0"
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr "Mystisk tal i FORMAT-sætning ved %0"
 
-#: fortran/decl.c:6731 fortran/decl.c:10623
+#: fortran/decl.c:6750 fortran/decl.c:10648
 #, gcc-internal-format
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr ""
 
-#: fortran/decl.c:6738
+#: fortran/decl.c:6757
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr ""
 
-#: fortran/decl.c:6742
+#: fortran/decl.c:6761
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:6814
+#: fortran/decl.c:6833
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:6832
+#: fortran/decl.c:6851
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr ""
 
-#: fortran/decl.c:6841 fortran/decl.c:9392
+#: fortran/decl.c:6860 fortran/decl.c:9411
 #, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr ""
 
-#: fortran/decl.c:6911
+#: fortran/decl.c:6930
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6983
+#: fortran/decl.c:7002
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr ""
 
-#: fortran/decl.c:7007 fortran/decl.c:7011 fortran/decl.c:7266
-#: fortran/decl.c:7270 fortran/decl.c:7462 fortran/decl.c:7466
-#: fortran/symbol.c:1875
+#: fortran/decl.c:7026 fortran/decl.c:7030 fortran/decl.c:7285
+#: fortran/decl.c:7289 fortran/decl.c:7481 fortran/decl.c:7485
+#: fortran/symbol.c:1889
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr ""
 
-#: fortran/decl.c:7164
+#: fortran/decl.c:7183
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "ENTRY statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/decl.c:7173
+#: fortran/decl.c:7192
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr ""
 
-#: fortran/decl.c:7176
+#: fortran/decl.c:7195
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr ""
 
-#: fortran/decl.c:7179
+#: fortran/decl.c:7198
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "RETURN statement at %0 invalid within a main program unit"
 msgid "ENTRY statement at %C cannot appear within a SUBMODULE"
 msgstr "RETURN-sætning ved %0 ugyldig inden i en hovedprogramenhed"
 
-#: fortran/decl.c:7182
+#: fortran/decl.c:7201
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr ""
 
-#: fortran/decl.c:7186 fortran/decl.c:7231
+#: fortran/decl.c:7205 fortran/decl.c:7250
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr ""
 
-#: fortran/decl.c:7190
+#: fortran/decl.c:7209
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a STRUCTURE block"
 msgstr "ENTRY-sætning ved %C kan ikke fremgå i en STRUCTURE-blok"
 
-#: fortran/decl.c:7194
+#: fortran/decl.c:7213
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr ""
 
-#: fortran/decl.c:7198
+#: fortran/decl.c:7217
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr ""
 
-#: fortran/decl.c:7203
+#: fortran/decl.c:7222
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "RETURN statement at %0 invalid within a main program unit"
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr "RETURN-sætning ved %0 ugyldig inden i en hovedprogramenhed"
 
-#: fortran/decl.c:7207
+#: fortran/decl.c:7226
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr ""
 
-#: fortran/decl.c:7211
+#: fortran/decl.c:7230
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr ""
 
-#: fortran/decl.c:7215
+#: fortran/decl.c:7234
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr ""
 
-#: fortran/decl.c:7219
+#: fortran/decl.c:7238
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "RETURN statement at %0 invalid within a main program unit"
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr "RETURN-sætning ved %0 ugyldig inden i en hovedprogramenhed"
 
-#: fortran/decl.c:7223
+#: fortran/decl.c:7242
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Unexpected ENTRY statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/decl.c:7244
+#: fortran/decl.c:7263
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr "overløb i konstant udtryk"
 
-#: fortran/decl.c:7295 fortran/decl.c:7501
+#: fortran/decl.c:7314 fortran/decl.c:7520
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7563 fortran/decl.c:7570
+#: fortran/decl.c:7582 fortran/decl.c:7589
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:7610
+#: fortran/decl.c:7629
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr ""
 
-#: fortran/decl.c:7626
+#: fortran/decl.c:7645
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr "Manglende eller ugyldigt konstant udtryk"
 
-#: fortran/decl.c:7634
+#: fortran/decl.c:7653
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr ""
 
-#: fortran/decl.c:7653
+#: fortran/decl.c:7672
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing first operand for binary operator at %0"
 msgid "Missing closing paren for binding label at %C"
 msgstr "Manglende første operand for binær operator ved %0"
 
-#: fortran/decl.c:7659
+#: fortran/decl.c:7678
 #, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7665
+#: fortran/decl.c:7684
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7694
+#: fortran/decl.c:7713
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr ""
 
-#: fortran/decl.c:7939
+#: fortran/decl.c:7958
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Unexpected END statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/decl.c:7948
+#: fortran/decl.c:7967
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "No label definition for FORMAT statement at %0"
 msgid "END statement instead of %s statement at %L"
@@ -58540,169 +58612,169 @@
 msgstr "Ingen etiketdefinition for FORMAT-sætning ved %0"
 
 #. We would have required END [something].
-#: fortran/decl.c:7957
+#: fortran/decl.c:7976
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr "%s-udtryk forventet ved %L"
 
-#: fortran/decl.c:7968
+#: fortran/decl.c:7987
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extraneous comma in FORMAT statement at %0"
 msgid "Expecting %s statement at %L"
 msgstr "Ekstra komma i FORMAT-sætning ved %0"
 
-#: fortran/decl.c:7988
+#: fortran/decl.c:8007
 #, gcc-internal-format
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr ""
 
-#: fortran/decl.c:8005
+#: fortran/decl.c:8024
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr ""
 
-#: fortran/decl.c:8019 fortran/decl.c:8027
+#: fortran/decl.c:8038 fortran/decl.c:8046
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate label `%s' in switch statement"
 msgid "Expected label %qs for %s statement at %C"
 msgstr "mere end én '%s'-etiket i switch-sætningen"
 
-#: fortran/decl.c:8126
+#: fortran/decl.c:8145
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing %A specifier in statement at %0"
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr "Manglende %A-angivelse i sætning ved %0"
 
-#: fortran/decl.c:8134
+#: fortran/decl.c:8153
 #, gcc-internal-format, gfc-internal-format
 msgid "Dimensions specified for %s at %L after its initialization"
 msgstr ""
 
-#: fortran/decl.c:8142
+#: fortran/decl.c:8161
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr ""
 
-#: fortran/decl.c:8151
+#: fortran/decl.c:8170
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr ""
 
-#: fortran/decl.c:8249
+#: fortran/decl.c:8268
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr ""
 
-#: fortran/decl.c:8286
+#: fortran/decl.c:8305
 #, gcc-internal-format
 msgid "Expected %<(%> at %C"
 msgstr ""
 
-#: fortran/decl.c:8300 fortran/decl.c:8340
+#: fortran/decl.c:8319 fortran/decl.c:8359
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr ""
 
-#: fortran/decl.c:8316
+#: fortran/decl.c:8335
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "predicate must be an identifier"
 msgid "Cray pointer at %C must be an integer"
 msgstr "udsagn skal være et kaldenavn"
 
-#: fortran/decl.c:8320
+#: fortran/decl.c:8339
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr ""
 
-#: fortran/decl.c:8326
+#: fortran/decl.c:8345
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr ""
 
-#: fortran/decl.c:8365
+#: fortran/decl.c:8384
 #, gcc-internal-format
 msgid "Couldn't set Cray pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:8389
+#: fortran/decl.c:8408
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr ""
 
-#: fortran/decl.c:8401
+#: fortran/decl.c:8420
 #, gcc-internal-format
 msgid "Expected %<,%> or end of statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8427
+#: fortran/decl.c:8446
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr "INTENT er ikke tilladt i BLOCK ved %C"
 
-#: fortran/decl.c:8459
+#: fortran/decl.c:8478
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr "OPTIONAL er ikke tilladt i BLOCK ved %C"
 
-#: fortran/decl.c:8478
+#: fortran/decl.c:8497
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer declaration at %C requires -fcray-pointer flag"
 msgstr ""
 
-#: fortran/decl.c:8517
+#: fortran/decl.c:8536
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8623
+#: fortran/decl.c:8642
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:8640
+#: fortran/decl.c:8659
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:8679
+#: fortran/decl.c:8698
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8717
+#: fortran/decl.c:8736
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr "Syntaksfejl i PROTECTED-udtryk ved %C"
 
-#: fortran/decl.c:8741
+#: fortran/decl.c:8760
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Access specifier or PRIVATE statement at %0 invalid for derived-type definition within other than the specification part of a module"
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr "Tilgangsangivelse eller PRIVATE-sætning ved %0 er ugyldig for nedarvet typedefinition som ikke er i specifikationsdelen af et modul"
 
-#: fortran/decl.c:8778
+#: fortran/decl.c:8797
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Access specifier or PRIVATE statement at %0 invalid for derived-type definition within other than the specification part of a module"
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr "Tilgangsangivelse eller PRIVATE-sætning ved %0 er ugyldig for nedarvet typedefinition som ikke er i specifikationsdelen af et modul"
 
-#: fortran/decl.c:8806
+#: fortran/decl.c:8825
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr ""
 
-#: fortran/decl.c:8813
+#: fortran/decl.c:8832
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Spurious sign in FORMAT statement at %0"
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr "Mystisk fortegn i FORMAT-sætning ved %0"
 
-#: fortran/decl.c:8819
+#: fortran/decl.c:8838
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr ""
 
-#: fortran/decl.c:8839
+#: fortran/decl.c:8858
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "initializing array with parameter list"
 msgid "Initializing already initialized variable at %C"
@@ -58709,476 +58781,482 @@
 msgstr "klargør tabel med en parameterliste"
 
 #. With legacy PARAMETER statements, don't expect a terminating ')'.
-#: fortran/decl.c:8864
+#: fortran/decl.c:8883
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER without '()' at %C"
 msgstr ""
 
-#: fortran/decl.c:8880
+#: fortran/decl.c:8899
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extraneous comma in FORMAT statement at %0"
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr "Ekstra komma i FORMAT-sætning ved %0"
 
-#: fortran/decl.c:8899 fortran/decl.c:8955
+#: fortran/decl.c:8918 fortran/decl.c:8974
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:8934
+#: fortran/decl.c:8953
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extraneous comma in FORMAT statement at %0"
 msgid "Expected entity-list in AUTOMATIC statement at %C"
 msgstr "Ekstra komma i FORMAT-sætning ved %0"
 
-#: fortran/decl.c:8941
+#: fortran/decl.c:8960
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Spurious number in FORMAT statement at %0"
 msgid "Syntax error in AUTOMATIC statement at %C"
 msgstr "Mystisk tal i FORMAT-sætning ved %0"
 
-#: fortran/decl.c:8990
+#: fortran/decl.c:9009
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extraneous comma in FORMAT statement at %0"
 msgid "Expected entity-list in STATIC statement at %C"
 msgstr "Ekstra komma i FORMAT-sætning ved %0"
 
-#: fortran/decl.c:8997
+#: fortran/decl.c:9016
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Spurious number in FORMAT statement at %0"
 msgid "Syntax error in STATIC statement at %C"
 msgstr "Mystisk tal i FORMAT-sætning ved %0"
 
-#: fortran/decl.c:9016
+#: fortran/decl.c:9035
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:9027
+#: fortran/decl.c:9046
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:9073
+#: fortran/decl.c:9092
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Spurious number in FORMAT statement at %0"
 msgid "Syntax error in SAVE statement at %C"
 msgstr "Mystisk tal i FORMAT-sætning ved %0"
 
-#: fortran/decl.c:9087
+#: fortran/decl.c:9106
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:9091
+#: fortran/decl.c:9110
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "VALUE statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/decl.c:9129
+#: fortran/decl.c:9148
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Spurious number in FORMAT statement at %0"
 msgid "Syntax error in VALUE statement at %C"
 msgstr "Mystisk tal i FORMAT-sætning ved %0"
 
-#: fortran/decl.c:9141
+#: fortran/decl.c:9160
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "VOLATILE statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/decl.c:9168
+#: fortran/decl.c:9187
 #, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr ""
 
-#: fortran/decl.c:9193
+#: fortran/decl.c:9212
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Spurious number in FORMAT statement at %0"
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr "Mystisk tal i FORMAT-sætning ved %0"
 
-#: fortran/decl.c:9205
+#: fortran/decl.c:9224
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9249
+#: fortran/decl.c:9268
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9274
+#: fortran/decl.c:9293
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "forward declaration of `%#T'"
 msgid "MODULE PROCEDURE declaration at %C"
 msgstr "forhåndserklæring af '%#T'"
 
-#: fortran/decl.c:9367
+#: fortran/decl.c:9386
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr ""
 
-#: fortran/decl.c:9425
+#: fortran/decl.c:9444
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr ""
 
-#: fortran/decl.c:9474
+#: fortran/decl.c:9493
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr ""
 
-#: fortran/decl.c:9483
+#: fortran/decl.c:9502
 #, gcc-internal-format
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr ""
 
-#: fortran/decl.c:9489
+#: fortran/decl.c:9508
 #, gcc-internal-format
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr ""
 
-#: fortran/decl.c:9496
+#: fortran/decl.c:9515
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:9503
+#: fortran/decl.c:9522
 #, fuzzy, gcc-internal-format
 #| msgid "  cannot use obsolete binding at `%D' because it has a destructor"
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr "  kan ikke bruge forældet binding til '%D' fordi den har en destruktionsfunktion"
 
-#: fortran/decl.c:9526
+#: fortran/decl.c:9545
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:9538
+#: fortran/decl.c:9557
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:9559
+#: fortran/decl.c:9578
 #, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
 msgstr ""
 
-#: fortran/decl.c:9605
+#: fortran/decl.c:9624
 #, gcc-internal-format, gfc-internal-format
 msgid "Failed to create structure type '%s' at %C"
 msgstr ""
 
-#: fortran/decl.c:9611
+#: fortran/decl.c:9630
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is already defined in `%T'"
 msgid "Type definition of %qs at %C was already defined at %L"
 msgstr "'%D' er allerede defineret i '%T'"
 
-#: fortran/decl.c:9658
+#: fortran/decl.c:9677
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Junk after MAP statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/decl.c:9691
+#: fortran/decl.c:9710
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Junk after UNION statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/decl.c:9726
+#: fortran/decl.c:9745
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a member of type `%T'"
 msgid "%s at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr "'%D' er ikke et medlem af typen '%T'"
 
-#: fortran/decl.c:9740
+#: fortran/decl.c:9759
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing structure name for outer structure definition at %0"
 msgid "Structure name expected in non-nested structure declaration at %C"
 msgstr "Manglende strukturnavn for ydre strukturdefinition ved %0"
 
-#: fortran/decl.c:9758
+#: fortran/decl.c:9777
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Junk after non-nested STRUCTURE statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/decl.c:9765
+#: fortran/decl.c:9784
 #, fuzzy, gcc-internal-format
 #| msgid "Type name at %0 not the same as name at %1"
 msgid "Structure name %qs at %C cannot be the same as an intrinsic type"
 msgstr "Typenavn ved %0 er ikke det samme som navn ved %1"
 
-#: fortran/decl.c:9926
+#: fortran/decl.c:9947
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr ""
 
-#: fortran/decl.c:9954
+#: fortran/decl.c:9975
 #, fuzzy, gcc-internal-format
 #| msgid "Type name at %0 not the same as name at %1"
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr "Typenavn ved %0 er ikke det samme som navn ved %1"
 
-#: fortran/decl.c:9964
+#: fortran/decl.c:9986
 #, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr ""
 
-#: fortran/decl.c:9981
+#: fortran/decl.c:9989
+#, fuzzy, gcc-internal-format
+#| msgid "Type name at %0 not the same as name at %1"
+msgid "Derived type name %qs at %C already has a basic type"
+msgstr "Typenavn ved %0 er ikke det samme som navn ved %1"
+
+#: fortran/decl.c:10006
 #, gcc-internal-format
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr ""
 
-#: fortran/decl.c:10042
+#: fortran/decl.c:10067
 #, gcc-internal-format, gfc-internal-format
 msgid "Garbage after PARAMETERIZED TYPE declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:10126
+#: fortran/decl.c:10151
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr ""
 
-#: fortran/decl.c:10146
+#: fortran/decl.c:10171
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM and ENUMERATOR at %C"
 msgstr ""
 
-#: fortran/decl.c:10178
+#: fortran/decl.c:10203
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr ""
 
-#: fortran/decl.c:10257
+#: fortran/decl.c:10282
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr ""
 
-#: fortran/decl.c:10305
+#: fortran/decl.c:10330
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "type name expected before `*'"
 msgid "ENUM definition statement expected before %C"
 msgstr "der forventedes et typenavn før '*'"
 
-#: fortran/decl.c:10341
+#: fortran/decl.c:10366
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr ""
 
-#: fortran/decl.c:10388 fortran/decl.c:10403
+#: fortran/decl.c:10413 fortran/decl.c:10428
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "multiple access specifiers"
 msgid "Duplicate access-specifier at %C"
 msgstr "mere end én tilgangsangivelse"
 
-#: fortran/decl.c:10423
+#: fortran/decl.c:10448
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10443
+#: fortran/decl.c:10468
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10470
+#: fortran/decl.c:10495
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:10488
+#: fortran/decl.c:10513
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr ""
 
-#: fortran/decl.c:10504
+#: fortran/decl.c:10529
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DEFERRED at %C"
 msgstr ""
 
-#: fortran/decl.c:10517
+#: fortran/decl.c:10542
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected access-specifier at %C"
 msgstr "Forventede tilgangsangivere ved %C"
 
-#: fortran/decl.c:10519
+#: fortran/decl.c:10544
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr "Forventede bindingattribut ved %C"
 
-#: fortran/decl.c:10527
+#: fortran/decl.c:10552
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED can't both appear at %C"
 msgstr "NON_OVERRIDABLE og DEFERRED kan ikke begge vises ved %C"
 
-#: fortran/decl.c:10539
+#: fortran/decl.c:10564
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:10581
+#: fortran/decl.c:10606
 #, gcc-internal-format
 msgid "Interface-name expected after %<(%> at %C"
 msgstr ""
 
-#: fortran/decl.c:10587
+#: fortran/decl.c:10612
 #, gcc-internal-format
 msgid "%<)%> expected at %C"
 msgstr "%<)%> forventet ved %C"
 
-#: fortran/decl.c:10607
+#: fortran/decl.c:10632
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:10612
+#: fortran/decl.c:10637
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:10635
+#: fortran/decl.c:10660
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr ""
 
-#: fortran/decl.c:10639
+#: fortran/decl.c:10664
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
 msgstr "PROCEDURE-liste ved %C"
 
-#: fortran/decl.c:10651
+#: fortran/decl.c:10676
 #, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr "%<=> target%> er ugyldig for DEFERRED-binding ved %C"
 
-#: fortran/decl.c:10657
+#: fortran/decl.c:10682
 #, gcc-internal-format
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr ""
 
-#: fortran/decl.c:10667
+#: fortran/decl.c:10692
 #, gcc-internal-format
 msgid "Expected binding target after %<=>%> at %C"
 msgstr ""
 
-#: fortran/decl.c:10684
+#: fortran/decl.c:10709
 #, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr ""
 
-#: fortran/decl.c:10695
+#: fortran/decl.c:10720
 #, gcc-internal-format
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:10746
+#: fortran/decl.c:10771
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr ""
 
-#: fortran/decl.c:10766
+#: fortran/decl.c:10791
 #, gcc-internal-format
 msgid "Expected %<::%> at %C"
 msgstr "Forventede %<::%> ved %C"
 
-#: fortran/decl.c:10778
+#: fortran/decl.c:10803
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected generic name or operator descriptor at %C"
 msgstr "Forventede generisk navn elelr operatordeskriptor ved %C"
 
-#: fortran/decl.c:10799
+#: fortran/decl.c:10824
 #, gcc-internal-format, gfc-internal-format
 msgid "Malformed GENERIC statement at %C"
 msgstr "Forkert udformet GENERIC-udtryk ved %C"
 
-#: fortran/decl.c:10810
+#: fortran/decl.c:10835
 #, gcc-internal-format
 msgid "Expected %<=>%> at %C"
 msgstr "Forventede %<=>%> ved %C"
 
-#: fortran/decl.c:10846
+#: fortran/decl.c:10871
 #, gcc-internal-format
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:10854
+#: fortran/decl.c:10879
 #, gcc-internal-format
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr ""
 
-#: fortran/decl.c:10902
+#: fortran/decl.c:10927
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr ""
 
-#: fortran/decl.c:10912
+#: fortran/decl.c:10937
 #, gcc-internal-format
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:10930
+#: fortran/decl.c:10955
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr ""
 
-#: fortran/decl.c:10965
+#: fortran/decl.c:10990
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr ""
 
-#: fortran/decl.c:10976
+#: fortran/decl.c:11001
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr ""
 
-#: fortran/decl.c:10998
+#: fortran/decl.c:11023
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr ""
 
-#: fortran/decl.c:11005
+#: fortran/decl.c:11030
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr ""
 
-#: fortran/decl.c:11015
+#: fortran/decl.c:11040
 #, gcc-internal-format
 msgid "Expected %<,%> at %C"
 msgstr ""
 
-#: fortran/decl.c:11021
+#: fortran/decl.c:11046
 #, fuzzy, gcc-internal-format
 #| msgid "unknown register name: %s"
 msgid "Unknown procedure name %qs at %C"
 msgstr "ukendt registernavn: %s"
 
-#: fortran/decl.c:11034
+#: fortran/decl.c:11059
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is already defined in `%T'"
 msgid "%qs at %C is already defined as FINAL procedure"
 msgstr "'%D' er allerede defineret i '%T'"
 
-#: fortran/decl.c:11104
+#: fortran/decl.c:11129
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr ""
 
-#: fortran/decl.c:11150
+#: fortran/decl.c:11175
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr ""
 
-#: fortran/decl.c:11170
+#: fortran/decl.c:11195
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive requires a non-negative integral constant less than or equal to %u at %C"
 msgstr ""
 
-#: fortran/decl.c:11184
+#: fortran/decl.c:11209
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ UNROLL directive at %C"
 msgstr "\"%s\" må ikke optræde i makroparameterliste"
@@ -59523,27 +59601,27 @@
 msgid "BOZ literal at %L used to initialize non-integer variable %qs"
 msgstr ""
 
-#: fortran/expr.c:3369 fortran/resolve.c:10197
+#: fortran/expr.c:3369 fortran/resolve.c:10210
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal at %L outside a DATA statement and outside INT/REAL/DBLE/CMPLX"
 msgstr ""
 
-#: fortran/expr.c:3380 fortran/resolve.c:10208
+#: fortran/expr.c:3380 fortran/resolve.c:10221
 #, gcc-internal-format
 msgid "BOZ literal at %L is bitwise transferred non-integer symbol %qs"
 msgstr ""
 
-#: fortran/expr.c:3388 fortran/resolve.c:10217
+#: fortran/expr.c:3388 fortran/resolve.c:10230
 #, gcc-internal-format
 msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3392 fortran/resolve.c:10221
+#: fortran/expr.c:3392 fortran/resolve.c:10234
 #, gcc-internal-format
 msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3396 fortran/resolve.c:10225
+#: fortran/expr.c:3396 fortran/resolve.c:10238
 #, gcc-internal-format
 msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
@@ -59553,151 +59631,151 @@
 msgid "The assignment to a KIND or LEN component of a parameterized type at %L is not allowed"
 msgstr ""
 
-#: fortran/expr.c:3426
+#: fortran/expr.c:3429
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible types in DATA statement at %L; attempted conversion of %s to %s"
 msgstr ""
 
-#: fortran/expr.c:3465
+#: fortran/expr.c:3468
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is not a POINTER at %L"
 msgstr ""
 
-#: fortran/expr.c:3473
+#: fortran/expr.c:3476
 #, gcc-internal-format
 msgid "%qs in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgstr ""
 
-#: fortran/expr.c:3496
+#: fortran/expr.c:3499
 #, gcc-internal-format
 msgid "Expected bounds specification for %qs at %L"
 msgstr ""
 
-#: fortran/expr.c:3501
+#: fortran/expr.c:3504
 #, fuzzy, gcc-internal-format
 #| msgid "Array or substring specification for `%A' out of range in statement at %0"
 msgid "Bounds specification for %qs in pointer assignment at %L"
 msgstr "Tabel- eller understrengsangivelse for '%A' er uden for det gyldige interval i sætning ved %0"
 
-#: fortran/expr.c:3514
+#: fortran/expr.c:3517
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower bound has to be present at %L"
 msgstr ""
 
-#: fortran/expr.c:3520
+#: fortran/expr.c:3523
 #, gcc-internal-format, gfc-internal-format
 msgid "Stride must not be present at %L"
 msgstr ""
 
-#: fortran/expr.c:3532
+#: fortran/expr.c:3535
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the upper bounds must be specified at %L"
 msgstr ""
 
-#: fortran/expr.c:3558
+#: fortran/expr.c:3561
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %L shall not have a coindex"
 msgstr ""
 
-#: fortran/expr.c:3579
+#: fortran/expr.c:3582
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid lvalue in assignment"
 msgid "Invalid procedure pointer assignment at %L"
 msgstr "ugyldig venstreværdi i tildeling"
 
-#: fortran/expr.c:3603
+#: fortran/expr.c:3606
 #, gcc-internal-format
 msgid "Function result %qs is invalid as proc-target in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3612
+#: fortran/expr.c:3615
 #, gcc-internal-format
 msgid "Abstract interface %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3622
+#: fortran/expr.c:3625
 #, fuzzy, gcc-internal-format
 #| msgid "Statement at %0 invalid in context established by statement at %1"
 msgid "Statement function %qs is invalid in procedure pointer assignment at %L"
 msgstr "Sætning ved %0 er ugyldig i den kontekst der er etableret af sætning ved %1"
 
-#: fortran/expr.c:3628
+#: fortran/expr.c:3631
 #, gcc-internal-format
 msgid "Internal procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3635
+#: fortran/expr.c:3638
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L is invalid in procedure pointer assignment"
 msgstr ""
 
-#: fortran/expr.c:3643
+#: fortran/expr.c:3646
 #, gcc-internal-format
 msgid "Nonintrinsic elemental procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3666
+#: fortran/expr.c:3669
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in the procedure pointer assignment at %L: mismatch in the calling convention"
 msgstr ""
 
-#: fortran/expr.c:3719
+#: fortran/expr.c:3722
 #, fuzzy, gcc-internal-format
 #| msgid "invalid lvalue in assignment"
 msgid "Interface mismatch in procedure pointer assignment at %L: %qs is not a subroutine"
 msgstr "ugyldig venstreværdi i tildeling"
 
-#: fortran/expr.c:3729 fortran/expr.c:3744
+#: fortran/expr.c:3732 fortran/expr.c:3747
 #, gcc-internal-format
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr ""
 
-#: fortran/expr.c:3735 fortran/expr.c:3750 fortran/resolve.c:2566
+#: fortran/expr.c:3738 fortran/expr.c:3753 fortran/resolve.c:2566
 #, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr ""
 
-#: fortran/expr.c:3762
+#: fortran/expr.c:3765
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %s"
 msgstr ""
 
-#: fortran/expr.c:3771
+#: fortran/expr.c:3774
 #, gcc-internal-format
 msgid "Procedure pointer target %qs at %L must be either an intrinsic, host or use associated, referenced or have the EXTERNAL attribute"
 msgstr ""
 
-#: fortran/expr.c:3788
+#: fortran/expr.c:3791
 #, gcc-internal-format, gfc-internal-format
 msgid "Data-pointer-object at %L must be unlimited polymorphic, or of a type with the BIND or SEQUENCE attribute, to be compatible with an unlimited polymorphic target"
 msgstr ""
 
-#: fortran/expr.c:3793
+#: fortran/expr.c:3796
 #, gcc-internal-format, gfc-internal-format
 msgid "Different types in pointer assignment at %L; attempted assignment of %s to %s"
 msgstr ""
 
-#: fortran/expr.c:3802
+#: fortran/expr.c:3805
 #, gcc-internal-format, gfc-internal-format
 msgid "Different kind type parameters in pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3809
+#: fortran/expr.c:3812
 #, gcc-internal-format, gfc-internal-format
 msgid "Different ranks in pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3828
+#: fortran/expr.c:3831
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is smaller than size of the pointer (%ld < %ld) at %L"
 msgstr ""
 
-#: fortran/expr.c:3841
+#: fortran/expr.c:3844
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target must be rank 1 or simply contiguous at %L"
 msgstr ""
 
-#: fortran/expr.c:3845
+#: fortran/expr.c:3848
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is not rank 1 at %L"
 msgstr ""
@@ -59705,147 +59783,152 @@
 #. The test above might need to be extend when F08, Note 5.4 has to be
 #. interpreted in the way that target and pointer with the same coindex
 #. are allowed.
-#: fortran/expr.c:3877 fortran/expr.c:3925
+#: fortran/expr.c:3880 fortran/expr.c:3928
 #, gcc-internal-format, gfc-internal-format
 msgid "Data target at %L shall not have a coindex"
 msgstr ""
 
-#: fortran/expr.c:3880
+#: fortran/expr.c:3883
 #, gcc-internal-format, gfc-internal-format
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr ""
 
-#: fortran/expr.c:3888
+#: fortran/expr.c:3891
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr ""
 
-#: fortran/expr.c:3895
+#: fortran/expr.c:3898
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr ""
 
-#: fortran/expr.c:3904
+#: fortran/expr.c:3907
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr ""
 
-#: fortran/expr.c:3912
+#: fortran/expr.c:3915
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/expr.c:3936
+#: fortran/expr.c:3939
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to contiguous pointer from non-contiguous target at %L"
 msgstr ""
 
-#: fortran/expr.c:3975
+#: fortran/expr.c:3978
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr ""
 
-#: fortran/expr.c:4051 fortran/resolve.c:1452
+#: fortran/expr.c:4054 fortran/resolve.c:1452
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/expr.c:4057
+#: fortran/expr.c:4060
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr ""
 
-#: fortran/expr.c:4072 fortran/resolve.c:1458
+#: fortran/expr.c:4075 fortran/resolve.c:1458
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr ""
 
-#: fortran/expr.c:4084
+#: fortran/expr.c:4087
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr ""
 
-#: fortran/expr.c:5512
+#: fortran/expr.c:4557
+#, gcc-internal-format
+msgid "generate_isocbinding_initializer(): bad iso_c_binding type, expected %<c_ptr%> or %<c_funptr%>"
+msgstr ""
+
+#: fortran/expr.c:5568
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5520
+#: fortran/expr.c:5576
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5528
+#: fortran/expr.c:5584
 #, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5537
+#: fortran/expr.c:5593
 #, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr ""
 
-#: fortran/expr.c:5548
+#: fortran/expr.c:5604
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5557
+#: fortran/expr.c:5613
 #, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5570
+#: fortran/expr.c:5626
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5583
+#: fortran/expr.c:5639
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5613
+#: fortran/expr.c:5669
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5621
+#: fortran/expr.c:5677
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5634
+#: fortran/expr.c:5690
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5642
+#: fortran/expr.c:5698
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5654
+#: fortran/expr.c:5710
 #, gcc-internal-format
 msgid "Variable %qs can not appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr ""
 
-#: fortran/expr.c:5713
+#: fortran/expr.c:5769
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:5717
+#: fortran/expr.c:5773
 #, gcc-internal-format
 msgid "%qs at %L associated to expression can not be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:5728
+#: fortran/expr.c:5784
 #, gcc-internal-format
 msgid "Associate-name %qs can not appear in a variable definition context (%s) at %L because its target at %L can not, either"
 msgstr ""
 
-#: fortran/expr.c:5770
+#: fortran/expr.c:5826
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr ""
@@ -59856,24 +59939,24 @@
 msgid "can't open input file: %s"
 msgstr "kan ikke åbne uddatafilen '%s'"
 
-#: fortran/frontend-passes.c:190
+#: fortran/frontend-passes.c:192
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid init statement"
 msgid "No location in statement"
 msgstr "Ugyldig klargøringssætning"
 
-#: fortran/frontend-passes.c:205
+#: fortran/frontend-passes.c:207
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected binary operator between expressions at %0 and at %1"
 msgid "No location in expression near %L"
 msgstr "Forventede binær operator mellem udtryk ved %0 og ved %1"
 
-#: fortran/frontend-passes.c:409
+#: fortran/frontend-passes.c:414
 #, gcc-internal-format
 msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
-#: fortran/frontend-passes.c:817 fortran/trans-array.c:1182
+#: fortran/frontend-passes.c:822 fortran/trans-array.c:1182
 #: fortran/trans-array.c:6440 fortran/trans-array.c:7864
 #: fortran/trans-intrinsic.c:7307
 #, fuzzy, gcc-internal-format, gfc-internal-format
@@ -59881,70 +59964,70 @@
 msgid "Creating array temporary at %L"
 msgstr "opretter tabel af '%T'"
 
-#: fortran/frontend-passes.c:842 fortran/frontend-passes.c:846
+#: fortran/frontend-passes.c:847 fortran/frontend-passes.c:851
 #, fuzzy, gcc-internal-format
 #| msgid "No calls in function %s\n"
 msgid "Removing call to function %qs at %L"
 msgstr "Ingen kald i funktionen %s\n"
 
-#: fortran/frontend-passes.c:1273 fortran/frontend-passes.c:1312
+#: fortran/frontend-passes.c:1278 fortran/frontend-passes.c:1317
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected address expression"
 msgid "bad expression"
 msgstr "uventet adresseudtryk"
 
-#: fortran/frontend-passes.c:1308
+#: fortran/frontend-passes.c:1313
 #, fuzzy, gcc-internal-format
 #| msgid "bad operand"
 msgid "bad op"
 msgstr "ugyldig operand"
 
-#: fortran/frontend-passes.c:2161
+#: fortran/frontend-passes.c:2166
 #, gcc-internal-format
 msgid "illegal OP in optimize_comparison"
 msgstr ""
 
-#: fortran/frontend-passes.c:2407
+#: fortran/frontend-passes.c:2412
 #, gcc-internal-format
 msgid "Variable %qs at %L set to undefined value inside loop  beginning at %L as INTENT(OUT) argument to subroutine %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:2414
+#: fortran/frontend-passes.c:2419
 #, gcc-internal-format
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to subroutine %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:2637 fortran/frontend-passes.c:2661
+#: fortran/frontend-passes.c:2642 fortran/frontend-passes.c:2666
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L out of bounds (%ld < %ld) in loop beginning at %L"
 msgstr ""
 
-#: fortran/frontend-passes.c:2646 fortran/frontend-passes.c:2670
+#: fortran/frontend-passes.c:2651 fortran/frontend-passes.c:2675
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L out of bounds (%ld > %ld) in loop beginning at %L"
 msgstr ""
 
-#: fortran/frontend-passes.c:2730
+#: fortran/frontend-passes.c:2735
 #, gcc-internal-format
 msgid "Variable %qs at %L set to undefined value inside loop beginning at %L as INTENT(OUT) argument to function %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:2736
+#: fortran/frontend-passes.c:2741
 #, gcc-internal-format
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:3128 fortran/trans-expr.c:1581
+#: fortran/frontend-passes.c:3133 fortran/trans-expr.c:1581
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr ""
 
-#: fortran/frontend-passes.c:3637
+#: fortran/frontend-passes.c:3642
 #, gcc-internal-format
 msgid "Scalarization using DIMEN_RANGE unimplemented"
 msgstr ""
 
-#: fortran/frontend-passes.c:4429
+#: fortran/frontend-passes.c:4434
 #, gcc-internal-format, gfc-internal-format
 msgid "Interchanging loops at %L"
 msgstr ""
@@ -60067,12 +60150,12 @@
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:970 fortran/resolve.c:16351
+#: fortran/interface.c:970 fortran/resolve.c:16378
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:977 fortran/resolve.c:16369
+#: fortran/interface.c:977 fortran/resolve.c:16396
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
@@ -61319,7 +61402,7 @@
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.c:3369 fortran/resolve.c:14263
+#: fortran/io.c:3369 fortran/resolve.c:14283
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -61498,7 +61581,7 @@
 msgid "Integer too large at %C"
 msgstr "Heltal ved %0 for stort"
 
-#: fortran/match.c:580 fortran/parse.c:1132
+#: fortran/match.c:580 fortran/parse.c:1136
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many digits in statement label at %C"
 msgstr ""
@@ -62293,63 +62376,63 @@
 msgid "Expected block name %qs of SELECT construct at %C"
 msgstr ""
 
-#: fortran/match.c:6186
+#: fortran/match.c:6201
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Spurious number in FORMAT statement at %0"
 msgid "parse error in SELECT TYPE statement at %C"
 msgstr "Mystisk tal i FORMAT-sætning ved %0"
 
-#: fortran/match.c:6211
+#: fortran/match.c:6226
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr ""
 
-#: fortran/match.c:6249
+#: fortran/match.c:6264
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Unexpected CASE statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/match.c:6301
+#: fortran/match.c:6316
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "parse error in method specification"
 msgid "Syntax error in CASE specification at %C"
 msgstr "tolkningsfejl i medlemsfunktionsangivelsen"
 
-#: fortran/match.c:6319
+#: fortran/match.c:6334
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Unexpected TYPE IS statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/match.c:6351
+#: fortran/match.c:6366
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr ""
 
-#: fortran/match.c:6362
+#: fortran/match.c:6377
 #, gcc-internal-format, gfc-internal-format
 msgid "All the LEN type parameters in the TYPE IS statement at %C must be ASSUMED"
 msgstr ""
 
-#: fortran/match.c:6373
+#: fortran/match.c:6388
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "parse error in method specification"
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr "tolkningsfejl i medlemsfunktionsangivelsen"
 
-#: fortran/match.c:6449
+#: fortran/match.c:6464
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "parse error in method specification"
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr "tolkningsfejl i medlemsfunktionsangivelsen"
 
-#: fortran/match.c:6572
+#: fortran/match.c:6587
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr ""
 
-#: fortran/match.c:6610
+#: fortran/match.c:6625
 #, gcc-internal-format
 msgid "Label %qs at %C doesn't match WHERE label %qs"
 msgstr ""
@@ -62512,196 +62595,196 @@
 msgid "mio_array_ref(): Unknown array ref"
 msgstr ""
 
-#: fortran/module.c:3716
+#: fortran/module.c:3718
 #, gcc-internal-format, gfc-internal-format
 msgid "Namelist %s cannot be renamed by USE association to %s"
 msgstr ""
 
-#: fortran/module.c:4832
+#: fortran/module.c:4834
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4835
+#: fortran/module.c:4837
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:5029
+#: fortran/module.c:5031
 #, gcc-internal-format
 msgid "%qs of module %qs, imported at %C, is also the name of the current program unit"
 msgstr ""
 
-#: fortran/module.c:5381
+#: fortran/module.c:5383
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5388
+#: fortran/module.c:5390
 #, gcc-internal-format
 msgid "User operator %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5393
+#: fortran/module.c:5395
 #, gcc-internal-format
 msgid "Intrinsic operator %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5628
+#: fortran/module.c:5630
 #, gcc-internal-format
 msgid "write_symbol(): bad module symbol %qs"
 msgstr ""
 
-#: fortran/module.c:5961
+#: fortran/module.c:5963
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr ""
 
-#: fortran/module.c:6148
+#: fortran/module.c:6150
 #, fuzzy, gcc-internal-format
 #| msgid "can't open %s for writing: %m"
 msgid "Can't open module file %qs for writing at %C: %s"
 msgstr "kan ikke åbne %s til skrivning: %m"
 
-#: fortran/module.c:6169
+#: fortran/module.c:6171
 #, fuzzy, gcc-internal-format
 #| msgid "%s: error writing file `%s': %s\n"
 msgid "Error writing module file %qs for writing: %s"
 msgstr "%s: fejl ved skrivning til filen '%s': %s\n"
 
-#: fortran/module.c:6180
+#: fortran/module.c:6182
 #, fuzzy, gcc-internal-format
 #| msgid "%s: can't delete file `%s': %s\n"
 msgid "Can't delete module file %qs: %s"
 msgstr "%s: kan ikke slette filen '%s': %s\n"
 
-#: fortran/module.c:6183
+#: fortran/module.c:6185
 #, fuzzy, gcc-internal-format
 #| msgid "%s: warning: can't rename file `%s' to `%s': %s\n"
 msgid "Can't rename module file %qs to %qs: %s"
 msgstr "%s: advarsel: kan ikke omdøbe filen '%s' til '%s': %s\n"
 
-#: fortran/module.c:6189
+#: fortran/module.c:6191
 #, fuzzy, gcc-internal-format
 #| msgid "%s: can't delete aux info file `%s': %s\n"
 msgid "Can't delete temporary module file %qs: %s"
 msgstr "%s: kan ikke slette hjælpeinformationsfilen '%s': %s\n"
 
-#: fortran/module.c:6246
+#: fortran/module.c:6248
 #, fuzzy, gcc-internal-format
 #| msgid "Symbols have a leading underscore"
 msgid "Symbol %qs at %C already declared"
 msgstr "Symboler har en indledende understreg"
 
-#: fortran/module.c:6317
+#: fortran/module.c:6319
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr ""
 
-#: fortran/module.c:6425 fortran/module.c:6769
+#: fortran/module.c:6427 fortran/module.c:6771
 #, gcc-internal-format
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr ""
 
-#: fortran/module.c:6553
+#: fortran/module.c:6555
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr ""
 
-#: fortran/module.c:6574 fortran/module.c:6607 fortran/module.c:6649
+#: fortran/module.c:6576 fortran/module.c:6609 fortran/module.c:6651
 #, fuzzy, gcc-internal-format
 #| msgid "Symbols have a leading underscore"
 msgid "Symbol %qs already declared"
 msgstr "Symboler har en indledende understreg"
 
-#: fortran/module.c:6754
+#: fortran/module.c:6756
 #, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:6776
+#: fortran/module.c:6778
 #, gcc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr ""
 
-#: fortran/module.c:6844
+#: fortran/module.c:6846
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr ""
 
-#: fortran/module.c:6898
+#: fortran/module.c:6900
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr ""
 
-#: fortran/module.c:6924
+#: fortran/module.c:6926
 #, gcc-internal-format, gfc-internal-format
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr ""
 
-#: fortran/module.c:6953
+#: fortran/module.c:6955
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr ""
 
-#: fortran/module.c:6965
+#: fortran/module.c:6967
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
 msgstr ""
 
-#: fortran/module.c:6978
+#: fortran/module.c:6980
 #, gcc-internal-format
 msgid "Can't find an intrinsic module named %qs at %C"
 msgstr ""
 
-#: fortran/module.c:6984
+#: fortran/module.c:6986
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr ""
 
-#: fortran/module.c:6990
+#: fortran/module.c:6992
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr ""
 
-#: fortran/module.c:6996
+#: fortran/module.c:6998
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr ""
 
-#: fortran/module.c:7006
+#: fortran/module.c:7008
 #, fuzzy, gcc-internal-format
 #| msgid "%s: can't open file `%s' for reading: %s\n"
 msgid "Can't open module file %qs for reading at %C: %s"
 msgstr "%s: kan ikke åbne filen '%s' til at læse fra: %s\n"
 
-#: fortran/module.c:7009
+#: fortran/module.c:7011
 #, gcc-internal-format
 msgid "Module file %qs has not been generated, either because the module does not contain a MODULE PROCEDURE or there is an error in the module."
 msgstr ""
 
-#: fortran/module.c:7020
+#: fortran/module.c:7022
 #, gcc-internal-format
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:7043
+#: fortran/module.c:7045
 #, gcc-internal-format
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr ""
 
-#: fortran/module.c:7051
+#: fortran/module.c:7053
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr ""
 
-#: fortran/module.c:7066
+#: fortran/module.c:7068
 #, gcc-internal-format, gfc-internal-format
 msgid "Can't USE the same %smodule we're building"
 msgstr ""
 
 #: fortran/openmp.c:296 fortran/openmp.c:397 fortran/openmp.c:692
-#: fortran/openmp.c:3167
+#: fortran/openmp.c:3166
 #, gcc-internal-format, gfc-internal-format
 msgid "COMMON block /%s/ not found at %C"
 msgstr ""
@@ -62786,868 +62869,868 @@
 #: fortran/openmp.c:2180
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid argument of `%s' attribute"
-msgid "Invalid argument to !$ACC WAIT at %L"
+msgid "Invalid argument to !$ACC WAIT at %C"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
-#: fortran/openmp.c:2188
+#: fortran/openmp.c:2187
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT clause at %L requires a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/openmp.c:2221
+#: fortran/openmp.c:2220
 #, gcc-internal-format, gfc-internal-format
 msgid "ACC CACHE directive must be inside of loop %C"
 msgstr ""
 
-#: fortran/openmp.c:2252
+#: fortran/openmp.c:2251
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for typename"
 msgid "Multiple loop axes specified for routine"
 msgstr "lagringsklasse angivet for typenavn"
 
-#: fortran/openmp.c:2278
+#: fortran/openmp.c:2277
 #, gcc-internal-format, gfc-internal-format
 msgid "Only the !$ACC ROUTINE form without list is allowed in interface block at %C"
 msgstr ""
 
-#: fortran/openmp.c:2306
+#: fortran/openmp.c:2305
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$ACC ROUTINE ( NAME ) at %C, invalid function name %s"
 msgstr ""
 
-#: fortran/openmp.c:2315
+#: fortran/openmp.c:2314
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$ACC ROUTINE ( NAME ) at %C"
 msgstr ""
 
-#: fortran/openmp.c:2322
+#: fortran/openmp.c:2321
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$ACC ROUTINE ( NAME ) at %C, expecting ')' after NAME"
 msgstr ""
 
-#: fortran/openmp.c:2457 fortran/openmp.c:2481
+#: fortran/openmp.c:2456 fortran/openmp.c:2480
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP CRITICAL statement at %C"
 msgstr ""
 
-#: fortran/openmp.c:2548
+#: fortran/openmp.c:2547
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP FLUSH statement at %C"
 msgstr ""
 
-#: fortran/openmp.c:2942 fortran/openmp.c:6225
+#: fortran/openmp.c:2941 fortran/openmp.c:6230
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined %s !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2946 fortran/openmp.c:6229
+#: fortran/openmp.c:2945 fortran/openmp.c:6234
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2951
+#: fortran/openmp.c:2950
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2953
+#: fortran/openmp.c:2952
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2973
+#: fortran/openmp.c:2972
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after !$OMP DECLARE REDUCTION at %C"
 msgstr ""
 
-#: fortran/openmp.c:3010
+#: fortran/openmp.c:3009
 #, gcc-internal-format, gfc-internal-format
 msgid "Only the !$OMP DECLARE TARGET form without clauses is allowed in interface block at %C"
 msgstr ""
 
-#: fortran/openmp.c:3025
+#: fortran/openmp.c:3024
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after !$OMP DECLARE TARGET at %C"
 msgstr ""
 
-#: fortran/openmp.c:3048
+#: fortran/openmp.c:3047
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET variable at %L is an element of a COMMON block"
 msgstr ""
 
-#: fortran/openmp.c:3053
+#: fortran/openmp.c:3052
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET variable at %L previously mentioned in LINK clause and later in TO clause"
 msgstr ""
 
-#: fortran/openmp.c:3059
+#: fortran/openmp.c:3058
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET variable at %L previously mentioned in TO clause and later in LINK clause"
 msgstr ""
 
-#: fortran/openmp.c:3063
+#: fortran/openmp.c:3062
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable at %L mentioned multiple times in clauses of the same OMP DECLARE TARGET directive"
 msgstr ""
 
-#: fortran/openmp.c:3078
+#: fortran/openmp.c:3077
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET COMMON at %L previously mentioned in LINK clause and later in TO clause"
 msgstr ""
 
-#: fortran/openmp.c:3084
+#: fortran/openmp.c:3083
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET COMMON at %L previously mentioned in TO clause and later in LINK clause"
 msgstr ""
 
-#: fortran/openmp.c:3088
+#: fortran/openmp.c:3087
 #, gcc-internal-format, gfc-internal-format
 msgid "COMMON at %L mentioned multiple times in clauses of the same OMP DECLARE TARGET directive"
 msgstr ""
 
-#: fortran/openmp.c:3115
+#: fortran/openmp.c:3114
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$OMP DECLARE TARGET list at %C"
 msgstr ""
 
-#: fortran/openmp.c:3147
+#: fortran/openmp.c:3146
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate variable at %C is an element of a COMMON block"
 msgstr ""
 
-#: fortran/openmp.c:3184
+#: fortran/openmp.c:3183
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after OMP THREADPRIVATE at %C"
 msgstr ""
 
-#: fortran/openmp.c:3191
+#: fortran/openmp.c:3190
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$OMP THREADPRIVATE list at %C"
 msgstr ""
 
-#: fortran/openmp.c:3405
+#: fortran/openmp.c:3404
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after TASKWAIT clause at %C"
 msgstr ""
 
-#: fortran/openmp.c:3419
+#: fortran/openmp.c:3418
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after TASKYIELD clause at %C"
 msgstr ""
 
-#: fortran/openmp.c:3478
+#: fortran/openmp.c:3477
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP WORKSHARE statement at %C"
 msgstr ""
 
-#: fortran/openmp.c:3492
+#: fortran/openmp.c:3491
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP MASTER statement at %C"
 msgstr ""
 
-#: fortran/openmp.c:3551
+#: fortran/openmp.c:3550
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP ATOMIC statement at %C"
 msgstr ""
 
-#: fortran/openmp.c:3578
+#: fortran/openmp.c:3577
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP BARRIER statement at %C"
 msgstr ""
 
-#: fortran/openmp.c:3592
+#: fortran/openmp.c:3591
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP TASKGROUP statement at %C"
 msgstr ""
 
-#: fortran/openmp.c:3642
+#: fortran/openmp.c:3641
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP CANCELLATION POINT statement at %C"
 msgstr ""
 
-#: fortran/openmp.c:3662
+#: fortran/openmp.c:3661
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after NOWAIT clause at %C"
 msgstr ""
 
-#: fortran/openmp.c:3704
+#: fortran/openmp.c:3703
 #, gcc-internal-format, gfc-internal-format
 msgid "%s clause at %L requires a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/openmp.c:3715
+#: fortran/openmp.c:3714
 #, gcc-internal-format, gfc-internal-format
 msgid "INTEGER expression of %s clause at %L must be positive"
 msgstr ""
 
-#: fortran/openmp.c:3726
+#: fortran/openmp.c:3725
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s rotate count is negative"
 msgid "INTEGER expression of %s clause at %L must be non-negative"
 msgstr "%s-roteringsantal er negativt"
 
-#: fortran/openmp.c:3737
+#: fortran/openmp.c:3736
 #, gcc-internal-format
 msgid "POINTER object %qs of derived type in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3740
+#: fortran/openmp.c:3739
 #, fuzzy, gcc-internal-format
 msgid "Cray pointer object %qs of derived type in %s clause at %L"
 msgstr "%s understøttes ikke af denne konfiguration"
 
-#: fortran/openmp.c:3743
+#: fortran/openmp.c:3742
 #, fuzzy, gcc-internal-format
 msgid "Cray pointee object %qs of derived type in %s clause at %L"
 msgstr "%s understøttes ikke af denne konfiguration"
 
-#: fortran/openmp.c:3749 fortran/openmp.c:4687
+#: fortran/openmp.c:3748 fortran/openmp.c:4686
 #, gcc-internal-format
 msgid "POINTER object %qs of polymorphic type in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3754
+#: fortran/openmp.c:3753
 #, fuzzy, gcc-internal-format
 msgid "Cray pointer object %qs of polymorphic type in %s clause at %L"
 msgstr "%s understøttes ikke af denne konfiguration"
 
-#: fortran/openmp.c:3759
+#: fortran/openmp.c:3758
 #, fuzzy, gcc-internal-format
 msgid "Cray pointee object %qs of polymorphic type in %s clause at %L"
 msgstr "%s understøttes ikke af denne konfiguration"
 
-#: fortran/openmp.c:3769 fortran/openmp.c:4385 fortran/openmp.c:4490
+#: fortran/openmp.c:3768 fortran/openmp.c:4384 fortran/openmp.c:4489
 #, gcc-internal-format
 msgid "Assumed size array %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3772
+#: fortran/openmp.c:3771
 #, fuzzy, gcc-internal-format
 msgid "Assumed rank array %qs in %s clause at %L"
 msgstr "Intern oversætterfejl i %s ved %s:%d."
 
-#: fortran/openmp.c:3776
+#: fortran/openmp.c:3775
 #, gcc-internal-format
 msgid "Noncontiguous deferred shape array %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3784
+#: fortran/openmp.c:3783
 #, gcc-internal-format
 msgid "ALLOCATABLE object %qs of derived type in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3789
+#: fortran/openmp.c:3788
 #, gcc-internal-format
 msgid "ALLOCATABLE object %qs of polymorphic type in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3801 fortran/openmp.c:4480
+#: fortran/openmp.c:3800 fortran/openmp.c:4479
 #, gcc-internal-format
 msgid "POINTER object %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3806 fortran/openmp.c:4691
+#: fortran/openmp.c:3805 fortran/openmp.c:4690
 #, gcc-internal-format
 msgid "Cray pointer object %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3811 fortran/openmp.c:4694
+#: fortran/openmp.c:3810 fortran/openmp.c:4693
 #, gcc-internal-format
 msgid "Cray pointee object %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3816 fortran/openmp.c:4682
+#: fortran/openmp.c:3815 fortran/openmp.c:4681
 #, gcc-internal-format
 msgid "ALLOCATABLE object %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3819
+#: fortran/openmp.c:3818
 #, gcc-internal-format
 msgid "VALUE object %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3862
+#: fortran/openmp.c:3861
 #, gcc-internal-format, gfc-internal-format
 msgid "Implicitly declared function %s used in !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:3911
+#: fortran/openmp.c:3910
 #, gcc-internal-format, gfc-internal-format
 msgid "Implicitly declared subroutine %s used in !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:3944
+#: fortran/openmp.c:3943
 #, gcc-internal-format, gfc-internal-format
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:3952 fortran/openmp.c:3963 fortran/resolve.c:10028
-#: fortran/resolve.c:11295
+#: fortran/openmp.c:3951 fortran/openmp.c:3962 fortran/resolve.c:10041
+#: fortran/resolve.c:11315
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/openmp.c:3967
+#: fortran/openmp.c:3966
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause without modifier at %L used together with IF clauses with modifiers"
 msgstr ""
 
-#: fortran/openmp.c:4044
+#: fortran/openmp.c:4043
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause modifier %s at %L not appropriate for the current OpenMP construct"
 msgstr ""
 
-#: fortran/openmp.c:4054
+#: fortran/openmp.c:4053
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/openmp.c:4064
+#: fortran/openmp.c:4063
 #, gcc-internal-format, gfc-internal-format
 msgid "SCHEDULE clause's chunk_size at %L requires a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/openmp.c:4069
+#: fortran/openmp.c:4068
 #, gcc-internal-format, gfc-internal-format
 msgid "INTEGER expression of SCHEDULE clause's chunk_size at %L must be positive"
 msgstr ""
 
-#: fortran/openmp.c:4084
+#: fortran/openmp.c:4083
 #, gcc-internal-format
 msgid "Variable %qs is not a dummy argument at %L"
 msgstr ""
 
-#: fortran/openmp.c:4116
+#: fortran/openmp.c:4115 fortran/openmp.c:5998
 #, gcc-internal-format
 msgid "Object %qs is not a variable at %L"
 msgstr ""
 
-#: fortran/openmp.c:4132 fortran/openmp.c:4143 fortran/openmp.c:4151
-#: fortran/openmp.c:4162 fortran/openmp.c:4174 fortran/openmp.c:4189
-#: fortran/openmp.c:6023
+#: fortran/openmp.c:4131 fortran/openmp.c:4142 fortran/openmp.c:4150
+#: fortran/openmp.c:4161 fortran/openmp.c:4173 fortran/openmp.c:4188
+#: fortran/openmp.c:6028
 #, gcc-internal-format
 msgid "Symbol %qs present on multiple clauses at %L"
 msgstr ""
 
-#: fortran/openmp.c:4196
+#: fortran/openmp.c:4195
 #, fuzzy, gcc-internal-format
 msgid "Array %qs is not permitted in reduction at %L"
 msgstr "overløb i konstant udtryk"
 
-#: fortran/openmp.c:4209
+#: fortran/openmp.c:4208
 #, gcc-internal-format
 msgid "Symbol %qs present on both FROM and TO clauses at %L"
 msgstr ""
 
-#: fortran/openmp.c:4231
+#: fortran/openmp.c:4230
 #, gcc-internal-format
 msgid "Non-THREADPRIVATE object %qs in COPYIN clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4239
+#: fortran/openmp.c:4238
 #, gcc-internal-format
 msgid "Assumed size array %qs in COPYPRIVATE clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4242
+#: fortran/openmp.c:4241
 #, gcc-internal-format
 msgid "INTENT(IN) POINTER %qs in COPYPRIVATE clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4250
+#: fortran/openmp.c:4249
 #, gcc-internal-format
 msgid "THREADPRIVATE object %qs in SHARED clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4253
+#: fortran/openmp.c:4252
 #, gcc-internal-format
 msgid "Cray pointee %qs in SHARED clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4256
+#: fortran/openmp.c:4255
 #, gcc-internal-format
 msgid "ASSOCIATE name %qs in SHARED clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4271
+#: fortran/openmp.c:4270
 #, gcc-internal-format
 msgid "%qs in ALIGNED clause must be POINTER, ALLOCATABLE, Cray pointer or C_PTR at %L"
 msgstr ""
 
-#: fortran/openmp.c:4283
+#: fortran/openmp.c:4282
 #, gcc-internal-format
 msgid "%qs in ALIGNED clause at %L requires a scalar positive constant integer alignment expression"
 msgstr ""
 
-#: fortran/openmp.c:4302
+#: fortran/openmp.c:4301
 #, gcc-internal-format, gfc-internal-format
 msgid "SINK dependence type only allowed on ORDERED directive at %L"
 msgstr ""
 
-#: fortran/openmp.c:4306
+#: fortran/openmp.c:4305
 #, gcc-internal-format, gfc-internal-format
 msgid "DEPEND SINK used together with DEPEND SOURCE on the same construct at %L"
 msgstr ""
 
-#: fortran/openmp.c:4316
+#: fortran/openmp.c:4315
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "accumulator is not a constant integer"
 msgid "SINK addend not a constant integer at %L"
 msgstr "akkumulator er ikke et konstant heltal"
 
-#: fortran/openmp.c:4322
+#: fortran/openmp.c:4321
 #, gcc-internal-format, gfc-internal-format
 msgid "Only SOURCE or SINK dependence types are allowed on ORDERED directive at %L"
 msgstr ""
 
-#: fortran/openmp.c:4333 fortran/openmp.c:4354
+#: fortran/openmp.c:4332 fortran/openmp.c:4353
 #, gcc-internal-format
 msgid "%qs in %s clause at %L is not a proper array section"
 msgstr ""
 
-#: fortran/openmp.c:4337
+#: fortran/openmp.c:4336
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coarrays not supported in %s clause at %L"
 msgstr "%s understøttes ikke af denne konfiguration"
 
-#: fortran/openmp.c:4346
+#: fortran/openmp.c:4345
 #, gcc-internal-format, gfc-internal-format
 msgid "Stride should not be specified for array section in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4367
+#: fortran/openmp.c:4366
 #, gcc-internal-format
 msgid "%qs in DEPEND clause at %L is a zero size array section"
 msgstr ""
 
-#: fortran/openmp.c:4403
+#: fortran/openmp.c:4402
 #, gcc-internal-format, gfc-internal-format
 msgid "TARGET%s with map-type other than TO, FROM, TOFROM, or ALLOC on MAP clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4419
+#: fortran/openmp.c:4418
 #, gcc-internal-format, gfc-internal-format
 msgid "TARGET ENTER DATA with map-type other than TO, or ALLOC on MAP clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4434
+#: fortran/openmp.c:4433
 #, gcc-internal-format, gfc-internal-format
 msgid "TARGET EXIT DATA with map-type other than FROM, RELEASE, or DELETE on MAP clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4450 fortran/openmp.c:4466
+#: fortran/openmp.c:4449 fortran/openmp.c:4465
 #, gcc-internal-format
 msgid "THREADPRIVATE object %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4453 fortran/openmp.c:4469
+#: fortran/openmp.c:4452 fortran/openmp.c:4468
 #, gcc-internal-format
 msgid "Cray pointee %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4472
+#: fortran/openmp.c:4471
 #, gcc-internal-format
 msgid "ASSOCIATE name %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4477
+#: fortran/openmp.c:4476
 #, gcc-internal-format
 msgid "Procedure pointer %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4483
+#: fortran/openmp.c:4482
 #, gcc-internal-format
 msgid "Cray pointer %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4493
+#: fortran/openmp.c:4492
 #, gcc-internal-format
 msgid "Variable %qs in %s clause is used in NAMELIST statement at %L"
 msgstr ""
 
 #. case OMP_LIST_REDUCTION:
-#: fortran/openmp.c:4503
+#: fortran/openmp.c:4502
 #, gcc-internal-format
 msgid "INTENT(IN) POINTER %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4596
+#: fortran/openmp.c:4595
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP DECLARE REDUCTION %s not found for type %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:4622
+#: fortran/openmp.c:4621
 #, gcc-internal-format, gfc-internal-format
 msgid "LINEAR clause modifier used on DO or SIMD construct at %L"
 msgstr ""
 
-#: fortran/openmp.c:4627
+#: fortran/openmp.c:4626
 #, gcc-internal-format, gfc-internal-format
 msgid "LINEAR clause specified together with ORDERED clause with argument at %L"
 msgstr ""
 
-#: fortran/openmp.c:4632
+#: fortran/openmp.c:4631
 #, gcc-internal-format
 msgid "LINEAR variable %qs must be INTEGER at %L"
 msgstr ""
 
-#: fortran/openmp.c:4637
+#: fortran/openmp.c:4636
 #, gcc-internal-format
 msgid "LINEAR dummy argument %qs with VALUE attribute with %s modifier at %L"
 msgstr ""
 
-#: fortran/openmp.c:4648
+#: fortran/openmp.c:4647
 #, gcc-internal-format
 msgid "%qs in LINEAR clause at %L requires a scalar integer linear-step expression"
 msgstr ""
 
-#: fortran/openmp.c:4665
+#: fortran/openmp.c:4664
 #, gcc-internal-format
 msgid "%qs in LINEAR clause at %L requires a constant integer linear-step expression or dummy argument specified in UNIFORM clause"
 msgstr ""
 
-#: fortran/openmp.c:4699
+#: fortran/openmp.c:4698
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%s clause variable %qs at %L is neither a POINTER nor an array"
 msgstr "variablen til tabel-delete er hverken af en henvisnings- eller en tabeltype"
 
-#: fortran/openmp.c:4731
+#: fortran/openmp.c:4730
 #, gcc-internal-format, gfc-internal-format
 msgid "DIST_SCHEDULE clause's chunk_size at %L requires a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/openmp.c:4763
+#: fortran/openmp.c:4762
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible use of TILE and COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:4765
+#: fortran/openmp.c:4764
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE dependence type only allowed on ORDERED directive at %L"
 msgstr ""
 
-#: fortran/openmp.c:4778
+#: fortran/openmp.c:4777
 #, gcc-internal-format, gfc-internal-format
 msgid "%s must contain at least one MAP clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4875
+#: fortran/openmp.c:4874
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected binary operator between expressions at %0 and at %1"
 msgid "unexpected !$OMP ATOMIC expression at %L"
 msgstr "Forventede binær operator mellem udtryk ved %0 og ved %1"
 
-#: fortran/openmp.c:4904
+#: fortran/openmp.c:4903
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC statement must set a scalar variable of intrinsic type at %L"
 msgstr ""
 
-#: fortran/openmp.c:4929
+#: fortran/openmp.c:4928
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC READ statement must read from a scalar variable of intrinsic type at %L"
 msgstr ""
 
-#: fortran/openmp.c:4934
+#: fortran/openmp.c:4933
 #, gcc-internal-format, gfc-internal-format
 msgid "expr in !$OMP ATOMIC WRITE assignment var = expr must be scalar and cannot reference var at %L"
 msgstr ""
 
-#: fortran/openmp.c:4956 fortran/openmp.c:5247
+#: fortran/openmp.c:4955 fortran/openmp.c:5246
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE capture statement must read from a scalar variable of intrinsic type at %L"
 msgstr ""
 
-#: fortran/openmp.c:4971
+#: fortran/openmp.c:4970
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE update statement must set a scalar variable of intrinsic type at %L"
 msgstr ""
 
-#: fortran/openmp.c:4978 fortran/openmp.c:5254
+#: fortran/openmp.c:4977 fortran/openmp.c:5253
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE capture statement reads from different variable than update statement writes into at %L"
 msgstr ""
 
-#: fortran/openmp.c:4994
+#: fortran/openmp.c:4993
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC with ALLOCATABLE variable at %L"
 msgstr ""
 
-#: fortran/openmp.c:5036
+#: fortran/openmp.c:5035
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment operator must be binary +, *, -, /, .AND., .OR., .EQV. or .NEQV. at %L"
 msgstr ""
 
-#: fortran/openmp.c:5084
+#: fortran/openmp.c:5083
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment must be var = var op expr or var = expr op var at %L"
 msgstr ""
 
-#: fortran/openmp.c:5098
+#: fortran/openmp.c:5097
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC var = var op expr not mathematically equivalent to var = var op (expr) at %L"
 msgstr ""
 
-#: fortran/openmp.c:5130
+#: fortran/openmp.c:5129
 #, gcc-internal-format, gfc-internal-format
 msgid "expr in !$OMP ATOMIC assignment var = var op expr must be scalar and cannot reference var at %L"
 msgstr ""
 
-#: fortran/openmp.c:5154
+#: fortran/openmp.c:5153
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment intrinsic IAND, IOR or IEOR must have two arguments at %L"
 msgstr ""
 
-#: fortran/openmp.c:5161
+#: fortran/openmp.c:5160
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment intrinsic must be MIN, MAX, IAND, IOR or IEOR at %L"
 msgstr ""
 
-#: fortran/openmp.c:5178
+#: fortran/openmp.c:5177
 #, gcc-internal-format
 msgid "!$OMP ATOMIC intrinsic arguments except one must not reference %qs at %L"
 msgstr ""
 
-#: fortran/openmp.c:5185
+#: fortran/openmp.c:5184
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC intrinsic arguments must be scalar at %L"
 msgstr ""
 
-#: fortran/openmp.c:5193
+#: fortran/openmp.c:5192
 #, gcc-internal-format
 msgid "First or last !$OMP ATOMIC intrinsic argument must be %qs at %L"
 msgstr ""
 
-#: fortran/openmp.c:5211
+#: fortran/openmp.c:5210
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment must have an operator or intrinsic on right hand side at %L"
 msgstr ""
 
-#: fortran/openmp.c:5225
+#: fortran/openmp.c:5224
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE capture statement must set a scalar variable of intrinsic type at %L"
 msgstr ""
 
-#: fortran/openmp.c:5544
+#: fortran/openmp.c:5543
 #, gcc-internal-format, gfc-internal-format
 msgid "%s cannot be a DO WHILE or DO without loop control at %L"
 msgstr ""
 
-#: fortran/openmp.c:5550
+#: fortran/openmp.c:5549
 #, gcc-internal-format, gfc-internal-format
 msgid "%s cannot be a DO CONCURRENT loop at %L"
 msgstr ""
 
-#: fortran/openmp.c:5556
+#: fortran/openmp.c:5555
 #, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable must be of type integer at %L"
 msgstr ""
 
-#: fortran/openmp.c:5560
+#: fortran/openmp.c:5559
 #, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable must not be THREADPRIVATE at %L"
 msgstr ""
 
-#: fortran/openmp.c:5573
+#: fortran/openmp.c:5572
 #, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable present on clause other than PRIVATE or LASTPRIVATE at %L"
 msgstr ""
 
-#: fortran/openmp.c:5577
+#: fortran/openmp.c:5576
 #, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable present on clause other than LASTPRIVATE at %L"
 msgstr ""
 
-#: fortran/openmp.c:5581
+#: fortran/openmp.c:5580
 #, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable present on clause other than LINEAR at %L"
 msgstr ""
 
-#: fortran/openmp.c:5599
+#: fortran/openmp.c:5598
 #, gcc-internal-format, gfc-internal-format
 msgid "%s collapsed loops don't form rectangular iteration space at %L"
 msgstr ""
 
-#: fortran/openmp.c:5611
+#: fortran/openmp.c:5610
 #, gcc-internal-format, gfc-internal-format
 msgid "collapsed %s loops not perfectly nested at %L"
 msgstr ""
 
-#: fortran/openmp.c:5620 fortran/openmp.c:5628
+#: fortran/openmp.c:5619 fortran/openmp.c:5627
 #, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for collapsed %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:5712 fortran/openmp.c:5725
+#: fortran/openmp.c:5711 fortran/openmp.c:5724
 #, gcc-internal-format, gfc-internal-format
 msgid "The %s directive cannot be specified within a %s region at %L"
 msgstr ""
 
-#: fortran/openmp.c:5744
+#: fortran/openmp.c:5743
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP cannot be a DO WHILE or DO without loop control at %L"
 msgstr ""
 
-#: fortran/openmp.c:5750
+#: fortran/openmp.c:5749
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP iteration variable must be of type integer at %L"
 msgstr ""
 
-#: fortran/openmp.c:5766
+#: fortran/openmp.c:5765
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s loops don't form rectangular iteration space at %L"
 msgstr ""
 
-#: fortran/openmp.c:5778
+#: fortran/openmp.c:5777
 #, gcc-internal-format, gfc-internal-format
 msgid "%s !$ACC LOOP loops not perfectly nested at %L"
 msgstr ""
 
-#: fortran/openmp.c:5788 fortran/openmp.c:5797
+#: fortran/openmp.c:5787 fortran/openmp.c:5796
 #, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for %s !$ACC LOOP at %L"
 msgstr ""
 
-#: fortran/openmp.c:5812 fortran/openmp.c:5819
+#: fortran/openmp.c:5811 fortran/openmp.c:5818
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s in PARALLEL region doesn't allow %s arguments at %L"
 msgstr ""
 
-#: fortran/openmp.c:5841
+#: fortran/openmp.c:5840
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside another loop parallelized across gangs at %L"
 msgstr ""
 
-#: fortran/openmp.c:5845 fortran/openmp.c:5849
+#: fortran/openmp.c:5844 fortran/openmp.c:5848
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside loop parallelized across workers at %L"
 msgstr ""
 
-#: fortran/openmp.c:5856
+#: fortran/openmp.c:5855
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across workers at %L"
 msgstr ""
 
-#: fortran/openmp.c:5860
+#: fortran/openmp.c:5859
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across vectors at %L"
 msgstr ""
 
-#: fortran/openmp.c:5866
+#: fortran/openmp.c:5865
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across vectors is not allowed inside another loop parallelized across vectors at %L"
 msgstr ""
 
-#: fortran/openmp.c:5878
+#: fortran/openmp.c:5877
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with INDEPENDENT at %L"
 msgstr ""
 
-#: fortran/openmp.c:5880
+#: fortran/openmp.c:5879
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "  conflict with `%D'"
 msgid "Clause SEQ conflicts with GANG at %L"
 msgstr "  konflikt med '%D'"
 
-#: fortran/openmp.c:5882
+#: fortran/openmp.c:5881
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with WORKER at %L"
 msgstr ""
 
-#: fortran/openmp.c:5884
+#: fortran/openmp.c:5883
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with VECTOR at %L"
 msgstr ""
 
-#: fortran/openmp.c:5886
+#: fortran/openmp.c:5885
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "  conflict with `%D'"
 msgid "Clause SEQ conflicts with AUTO at %L"
 msgstr "  konflikt med '%D'"
 
-#: fortran/openmp.c:5891
+#: fortran/openmp.c:5890
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with GANG at %L"
 msgstr ""
 
-#: fortran/openmp.c:5893
+#: fortran/openmp.c:5892
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with WORKER at %L"
 msgstr ""
 
-#: fortran/openmp.c:5895
+#: fortran/openmp.c:5894
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with VECTOR at %L"
 msgstr ""
 
-#: fortran/openmp.c:5899
+#: fortran/openmp.c:5898
 #, gcc-internal-format, gfc-internal-format
 msgid "Tiled loop cannot be parallelized across gangs, workers and vectors at the same time at %L"
 msgstr ""
 
-#: fortran/openmp.c:5934
+#: fortran/openmp.c:5933
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "overflow in constant expression"
 msgid "TILE requires constant expression at %L"
 msgstr "overløb i konstant udtryk"
 
-#: fortran/openmp.c:5999
+#: fortran/openmp.c:6004
 #, gcc-internal-format
 msgid "PARAMETER object %qs is not allowed at %L"
 msgstr ""
 
-#: fortran/openmp.c:6006
+#: fortran/openmp.c:6011
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "Array sections: %qs not allowed in !$ACC DECLARE at %L"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
-#: fortran/openmp.c:6133
+#: fortran/openmp.c:6138
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP TARGET UPDATE at %L requires at least one TO or FROM clause"
 msgstr ""
 
-#: fortran/openmp.c:6155
+#: fortran/openmp.c:6160
 #, gcc-internal-format
 msgid "!$OMP DECLARE SIMD should refer to containing procedure %qs at %L"
 msgstr ""
 
-#: fortran/openmp.c:6179
+#: fortran/openmp.c:6184
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_PRIV or OMP_ORIG used in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6187
+#: fortran/openmp.c:6192
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_OUT or OMP_IN used in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6216
+#: fortran/openmp.c:6221
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid operator for !$OMP DECLARE REDUCTION %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:6238
+#: fortran/openmp.c:6243
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER length in !$OMP DECLARE REDUCTION %s not constant at %L"
 msgstr ""
 
-#: fortran/openmp.c:6254
+#: fortran/openmp.c:6259
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6269
+#: fortran/openmp.c:6274
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6279
+#: fortran/openmp.c:6284
 #, gcc-internal-format, gfc-internal-format
 msgid "One of actual subroutine arguments in INITIALIZER clause of !$OMP DECLARE REDUCTION must be OMP_PRIV at %L"
 msgstr ""
 
-#: fortran/openmp.c:6287
+#: fortran/openmp.c:6292
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing INITIALIZER clause for !$OMP DECLARE REDUCTION of derived type without default initializer at %L"
 msgstr ""
@@ -63759,514 +63842,514 @@
 msgid "Unclassifiable statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/parse.c:629
+#: fortran/parse.c:631
 #, gcc-internal-format, gfc-internal-format
 msgid "OpenACC directives at %C may not appear in PURE procedures"
 msgstr ""
 
-#: fortran/parse.c:705
+#: fortran/parse.c:707
 #, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable OpenACC directive at %C"
 msgstr ""
 
-#: fortran/parse.c:831 fortran/parse.c:1040
+#: fortran/parse.c:835 fortran/parse.c:1044
 #, gcc-internal-format, gfc-internal-format
 msgid "OpenMP directives other than SIMD or DECLARE TARGET at %C may not appear in PURE or ELEMENTAL procedures"
 msgstr ""
 
-#: fortran/parse.c:1024
+#: fortran/parse.c:1028
 #, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable OpenMP directive at %C"
 msgstr ""
 
-#: fortran/parse.c:1076
+#: fortran/parse.c:1080
 #, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable GCC directive at %C"
 msgstr ""
 
-#: fortran/parse.c:1135 fortran/parse.c:1362
+#: fortran/parse.c:1139 fortran/parse.c:1366
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "`%E' is not a valid template argument"
 msgid "Zero is not a valid statement label at %C"
 msgstr "'%E' er ikke en gyldig skabelonsparameter"
 
-#: fortran/parse.c:1142 fortran/parse.c:1354
+#: fortran/parse.c:1146 fortran/parse.c:1358
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Non-numeric character at %0 in label field [info -f g77 M LEX]"
 msgid "Non-numeric character in statement label at %C"
 msgstr "Tegn der ikke er tal ved %0 i etiketfelt [info -f g77 M LEX]"
 
-#: fortran/parse.c:1154 fortran/parse.c:1403
+#: fortran/parse.c:1158 fortran/parse.c:1407
 #, gcc-internal-format, gfc-internal-format
 msgid "Semicolon at %C needs to be preceded by statement"
 msgstr ""
 
-#: fortran/parse.c:1161 fortran/parse.c:1418
+#: fortran/parse.c:1165 fortran/parse.c:1422
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "No label definition for FORMAT statement at %0"
 msgid "Statement label without statement at %L"
 msgstr "Ingen etiketdefinition for FORMAT-sætning ved %0"
 
-#: fortran/parse.c:1224 fortran/parse.c:1405
+#: fortran/parse.c:1228 fortran/parse.c:1409
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Semicolon at %C without preceding statement"
 msgstr ""
 
-#: fortran/parse.c:1247 fortran/parse.c:1381
+#: fortran/parse.c:1251 fortran/parse.c:1385
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Blank common initialized at %0"
 msgid "Bad continuation line at %C"
 msgstr "Tom almen tildelt startværdi ved %0"
 
-#: fortran/parse.c:1679
+#: fortran/parse.c:1683
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT statement at %L does not have a statement label"
 msgstr ""
 
-#: fortran/parse.c:2435
+#: fortran/parse.c:2439
 #, gcc-internal-format
 msgid "gfc_ascii_statement(): Bad statement code"
 msgstr ""
 
-#: fortran/parse.c:2577
+#: fortran/parse.c:2581
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Unexpected %s statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/parse.c:2732
+#: fortran/parse.c:2736
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Statement at %0 invalid in context established by statement at %1"
 msgid "%s statement at %C cannot follow %s statement at %L"
 msgstr "Sætning ved %0 er ugyldig i den kontekst der er etableret af sætning ved %1"
 
-#: fortran/parse.c:2749
+#: fortran/parse.c:2753
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected EOF while reading source file %s.\n"
 msgid "Unexpected end of file in %qs"
 msgstr "Stødt på slutningen af kildefilen %s tidligere end forventet.\n"
 
-#: fortran/parse.c:2784
+#: fortran/parse.c:2788
 #, gcc-internal-format
 msgid "Derived-type %qs with SEQUENCE must not have a CONTAINS section at %C"
 msgstr ""
 
-#: fortran/parse.c:2787
+#: fortran/parse.c:2791
 #, gcc-internal-format
 msgid "Derived-type %qs with BIND(C) must not have a CONTAINS section at %C"
 msgstr ""
 
-#: fortran/parse.c:2807
+#: fortran/parse.c:2811
 #, gcc-internal-format, gfc-internal-format
 msgid "Components in TYPE at %C must precede CONTAINS"
 msgstr ""
 
-#: fortran/parse.c:2811
+#: fortran/parse.c:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound procedure at %C"
 msgstr ""
 
-#: fortran/parse.c:2819
+#: fortran/parse.c:2823
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC binding at %C"
 msgstr ""
 
-#: fortran/parse.c:2827
+#: fortran/parse.c:2831
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "previous declaration of `%D'"
 msgid "FINAL procedure declaration at %C"
 msgstr "'%D' er tidligere erklæret"
 
-#: fortran/parse.c:2839
+#: fortran/parse.c:2843
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type definition at %C with empty CONTAINS section"
 msgstr ""
 
-#: fortran/parse.c:2849 fortran/parse.c:3304
+#: fortran/parse.c:2853 fortran/parse.c:3308
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement in TYPE at %C must be inside a MODULE"
 msgstr ""
 
-#: fortran/parse.c:2856
+#: fortran/parse.c:2860
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede procedure bindings"
 msgstr ""
 
-#: fortran/parse.c:2863 fortran/parse.c:3317
+#: fortran/parse.c:2867 fortran/parse.c:3321
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Duplicate PRIVATE statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/parse.c:2873
+#: fortran/parse.c:2877
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede CONTAINS"
 msgstr ""
 
-#: fortran/parse.c:2877
+#: fortran/parse.c:2881
 #, gcc-internal-format, gfc-internal-format
 msgid "Already inside a CONTAINS block at %C"
 msgstr ""
 
-#: fortran/parse.c:2996
+#: fortran/parse.c:3000
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s at %L of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray, which is not possible as the component has the pointer attribute"
 msgstr ""
 
-#: fortran/parse.c:3002
+#: fortran/parse.c:3006
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer component %s at %L has a noncoarray subcomponent of type LOCK_TYPE, which must have a codimension or be a subcomponent of a coarray"
 msgstr ""
 
-#: fortran/parse.c:3007
+#: fortran/parse.c:3011
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L of type LOCK_TYPE must have a codimension"
 msgstr ""
 
-#: fortran/parse.c:3011
+#: fortran/parse.c:3015
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L must have a codimension as it has a noncoarray subcomponent of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/parse.c:3016
+#: fortran/parse.c:3020
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as already a coarray subcomponent exists)"
 msgstr ""
 
-#: fortran/parse.c:3023
+#: fortran/parse.c:3027
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as %s at %L has a codimension or a coarray subcomponent)"
 msgstr ""
 
-#: fortran/parse.c:3033
+#: fortran/parse.c:3037
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s at %L of type EVENT_TYPE must have a codimension or be a subcomponent of a coarray, which is not possible as the component has the pointer attribute"
 msgstr ""
 
-#: fortran/parse.c:3039
+#: fortran/parse.c:3043
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer component %s at %L has a noncoarray subcomponent of type EVENT_TYPE, which must have a codimension or be a subcomponent of a coarray"
 msgstr ""
 
-#: fortran/parse.c:3044
+#: fortran/parse.c:3048
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L of type EVENT_TYPE must have a codimension"
 msgstr ""
 
-#: fortran/parse.c:3048
+#: fortran/parse.c:3052
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L must have a codimension as it has a noncoarray subcomponent of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/parse.c:3053
+#: fortran/parse.c:3057
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as already a coarray subcomponent exists)"
 msgstr ""
 
-#: fortran/parse.c:3060
+#: fortran/parse.c:3064
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as %s at %L has a codimension or a coarray subcomponent)"
 msgstr ""
 
-#: fortran/parse.c:3112
+#: fortran/parse.c:3116
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to create map component '%s'"
 msgstr ""
 
-#: fortran/parse.c:3145
+#: fortran/parse.c:3149
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "failed to find class '%s'"
 msgid "failed to create union component '%s'"
 msgstr "kunne ikke finde klassen '%s'"
 
-#: fortran/parse.c:3200
+#: fortran/parse.c:3204
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in nested structure declaration at %C"
 msgstr "\"%s\" må ikke optræde i makroparameterliste"
 
-#: fortran/parse.c:3287
+#: fortran/parse.c:3291
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside CONTAINS"
 msgstr ""
 
-#: fortran/parse.c:3295
+#: fortran/parse.c:3299
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type definition at %C without components"
 msgstr ""
 
-#: fortran/parse.c:3311
+#: fortran/parse.c:3315
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede structure components"
 msgstr ""
 
-#: fortran/parse.c:3328
+#: fortran/parse.c:3332
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede structure components"
 msgstr ""
 
-#: fortran/parse.c:3334
+#: fortran/parse.c:3338
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE attribute at %C already specified in TYPE statement"
 msgstr ""
 
-#: fortran/parse.c:3339
+#: fortran/parse.c:3343
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Duplicate SEQUENCE statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/parse.c:3349
+#: fortran/parse.c:3353
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS block in derived type definition at %C"
 msgstr ""
 
-#: fortran/parse.c:3407
+#: fortran/parse.c:3411
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM declaration at %C has no ENUMERATORS"
 msgstr ""
 
-#: fortran/parse.c:3494
+#: fortran/parse.c:3498
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in INTERFACE block at %C"
 msgstr ""
 
-#: fortran/parse.c:3518
+#: fortran/parse.c:3522
 #, gcc-internal-format
 msgid "Name %qs of ABSTRACT INTERFACE at %C cannot be the same as an intrinsic type"
 msgstr ""
 
-#: fortran/parse.c:3552
+#: fortran/parse.c:3556
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement at %C in INTERFACE body"
 msgstr ""
 
-#: fortran/parse.c:3570
+#: fortran/parse.c:3574
 #, gcc-internal-format
 msgid "INTERFACE procedure %qs at %L has the same name as the enclosing procedure"
 msgstr ""
 
-#: fortran/parse.c:3700
+#: fortran/parse.c:3704
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/parse.c:3732
+#: fortran/parse.c:3736
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Statement at %0 invalid in BLOCK DATA program unit at %1"
 msgid "%s statement is not allowed inside of BLOCK DATA at %C"
 msgstr "Sætning ved %0 er ugyldig  i BLOCK DATA-programenhed ved %1"
 
-#: fortran/parse.c:3822
+#: fortran/parse.c:3826
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement must appear in a MODULE"
 msgstr ""
 
-#: fortran/parse.c:3830
+#: fortran/parse.c:3834
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C follows another accessibility specification"
 msgstr ""
 
-#: fortran/parse.c:3882
+#: fortran/parse.c:3886
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid token at %0 in expression or subexpression at %1"
 msgid "Bad kind expression for function %qs at %L"
 msgstr "Ugyldigt symbol ved %0 i udtryk eller underudtryk ved %1"
 
-#: fortran/parse.c:3886
+#: fortran/parse.c:3890
 #, gcc-internal-format
 msgid "The type for function %qs at %L is not accessible"
 msgstr ""
 
-#: fortran/parse.c:3946
+#: fortran/parse.c:3950
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C follows previous unmasked ELSEWHERE"
 msgstr ""
 
-#: fortran/parse.c:3968
+#: fortran/parse.c:3972
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in WHERE block at %C"
 msgstr ""
 
-#: fortran/parse.c:4027
+#: fortran/parse.c:4031
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in FORALL block at %C"
 msgstr ""
 
-#: fortran/parse.c:4078
+#: fortran/parse.c:4082
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PUBLIC or PRIVATE statement at %1 cannot be specified along with PUBLIC or PRIVATE statement at %0"
 msgid "ELSE IF statement at %C cannot follow ELSE statement at %L"
 msgstr "PUBLIC- eller PRIVATE-sætning ved %1 kan ikke angives sammen med PUBLIC- eller PRIVATE-sætning ved %0"
 
-#: fortran/parse.c:4096
+#: fortran/parse.c:4100
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ELSE statements at %L and %C"
 msgstr ""
 
-#: fortran/parse.c:4157
+#: fortran/parse.c:4161
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected a CASE or END SELECT statement following SELECT CASE at %C"
 msgstr ""
 
-#: fortran/parse.c:4241
+#: fortran/parse.c:4245
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected TYPE IS, CLASS IS or END SELECT statement following SELECT TYPE at %C"
 msgstr ""
 
-#: fortran/parse.c:4303
+#: fortran/parse.c:4307
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %C cannot be redefined inside loop beginning at %L"
 msgstr "overløb i konstant udtryk"
 
-#: fortran/parse.c:4336
+#: fortran/parse.c:4340
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is within another block"
 msgstr ""
 
-#: fortran/parse.c:4346
+#: fortran/parse.c:4350
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is interwoven with another DO loop"
 msgstr ""
 
-#: fortran/parse.c:4372
+#: fortran/parse.c:4376
 #, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL block inside of OpenACC region at %C"
 msgstr ""
 
-#: fortran/parse.c:4373
+#: fortran/parse.c:4377
 #, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL block inside of OpenMP region at %C"
 msgstr ""
 
-#: fortran/parse.c:4399
+#: fortran/parse.c:4403
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label in END CRITICAL at %C does not match CRITICAL label"
 msgstr ""
 
-#: fortran/parse.c:4468
+#: fortran/parse.c:4472
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "In construct"
 msgid "BLOCK construct at %C"
 msgstr "I konstruktionen"
 
-#: fortran/parse.c:4502
+#: fortran/parse.c:4506
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSOCIATE construct at %C"
 msgstr ""
 
-#: fortran/parse.c:4690
+#: fortran/parse.c:4694
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label in ENDDO at %C doesn't match DO label"
 msgstr ""
 
-#: fortran/parse.c:4706
+#: fortran/parse.c:4710
 #, gcc-internal-format, gfc-internal-format
 msgid "Named block DO at %L requires matching ENDDO name"
 msgstr ""
 
-#: fortran/parse.c:4897
+#: fortran/parse.c:4901
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing !$OMP END ATOMIC after !$OMP ATOMIC CAPTURE at %C"
 msgstr ""
 
-#: fortran/parse.c:4913 fortran/parse.c:4972
+#: fortran/parse.c:4917 fortran/parse.c:4976
 #, gcc-internal-format, gfc-internal-format
 msgid "OpenACC directive inside of CRITICAL block at %C"
 msgstr ""
 
-#: fortran/parse.c:4947
+#: fortran/parse.c:4951
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "in %s, at %s:%d"
 msgid "Expecting %s at %C"
 msgstr "i %s, ved %s:%d"
 
-#: fortran/parse.c:4991
+#: fortran/parse.c:4995
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected DO loop at %C"
 msgstr ""
 
-#: fortran/parse.c:5011
+#: fortran/parse.c:5015
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant !$ACC END LOOP at %C"
 msgstr ""
 
-#: fortran/parse.c:5225
+#: fortran/parse.c:5229
 #, gcc-internal-format, gfc-internal-format
 msgid "Name after !$omp critical and !$omp end critical does not match at %C"
 msgstr ""
 
-#: fortran/parse.c:5283
+#: fortran/parse.c:5287
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot terminate a non-block DO loop"
 msgstr ""
 
-#: fortran/parse.c:5297
+#: fortran/parse.c:5301
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %C after the first executable statement"
 msgstr ""
 
-#: fortran/parse.c:5423
+#: fortran/parse.c:5427
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive does not commence a loop at %C"
 msgstr ""
 
-#: fortran/parse.c:5538
+#: fortran/parse.c:5542
 #, gcc-internal-format
 msgid "Contained procedure %qs at %C is already ambiguous"
 msgstr ""
 
-#: fortran/parse.c:5595
+#: fortran/parse.c:5599
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in CONTAINS section at %C"
 msgstr ""
 
-#: fortran/parse.c:5620
+#: fortran/parse.c:5624
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "No label definition for FORMAT statement at %0"
 msgid "CONTAINS statement without FUNCTION or SUBROUTINE statement at %L"
 msgstr "Ingen etiketdefinition for FORMAT-sætning ved %0"
 
-#: fortran/parse.c:5732
+#: fortran/parse.c:5736
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "RETURN statement at %0 invalid within a main program unit"
 msgid "CONTAINS statement at %C is already in a contained program unit"
 msgstr "RETURN-sætning ved %0 ugyldig inden i en hovedprogramenhed"
 
-#: fortran/parse.c:5784
+#: fortran/parse.c:5788
 #, fuzzy, gcc-internal-format
 #| msgid "Label %A already defined at %1 when redefined at %0"
 msgid "Global binding name %qs at %L is already being used as a %s at %L"
 msgstr "Etiket %A er allerede defineret ved %1 ved omdefinering ved %0"
 
-#: fortran/parse.c:5788
+#: fortran/parse.c:5792
 #, fuzzy, gcc-internal-format
 #| msgid "Label %A already defined at %1 when redefined at %0"
 msgid "Global name %qs at %L is already being used as a %s at %L"
 msgstr "Etiket %A er allerede defineret ved %1 ved omdefinering ved %0"
 
-#: fortran/parse.c:5794
+#: fortran/parse.c:5798
 #, fuzzy, gcc-internal-format
 #| msgid "Label %A already defined at %1 when redefined at %0"
 msgid "Global binding name %qs at %L is already being used at %L"
 msgstr "Etiket %A er allerede defineret ved %1 ved omdefinering ved %0"
 
-#: fortran/parse.c:5797
+#: fortran/parse.c:5801
 #, fuzzy, gcc-internal-format
 #| msgid "Label %A already defined at %1 when redefined at %0"
 msgid "Global name %qs at %L is already being used at %L"
 msgstr "Etiket %A er allerede defineret ved %1 ved omdefinering ved %0"
 
-#: fortran/parse.c:5819
+#: fortran/parse.c:5823
 #, gcc-internal-format, gfc-internal-format
 msgid "Blank BLOCK DATA at %C conflicts with prior BLOCK DATA at %L"
 msgstr ""
 
-#: fortran/parse.c:5845
+#: fortran/parse.c:5849
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in BLOCK DATA at %C"
 msgstr ""
 
-#: fortran/parse.c:5949
+#: fortran/parse.c:5953
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Unexpected %s statement in MODULE at %C"
@@ -64275,7 +64358,7 @@
 #. If we see a duplicate main program, shut down.  If the second
 #. instance is an implied main program, i.e. data decls or executable
 #. statements, we're in for lots of errors.
-#: fortran/parse.c:6333
+#: fortran/parse.c:6337
 #, gcc-internal-format, gfc-internal-format
 msgid "Two main PROGRAMs at %L and %C"
 msgstr ""
@@ -65049,7 +65132,7 @@
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.c:1893 fortran/resolve.c:9560 fortran/resolve.c:11225
+#: fortran/resolve.c:1893 fortran/resolve.c:9573 fortran/resolve.c:11245
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Label %A already defined at %1 when redefined at %0"
 msgid "Label %d referenced at %L is never defined"
@@ -65165,7 +65248,7 @@
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "'%D' erklærer ikke en skabelonstype"
 
-#: fortran/resolve.c:2905 fortran/resolve.c:16283
+#: fortran/resolve.c:2905 fortran/resolve.c:16310
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr ""
@@ -65290,202 +65373,202 @@
 msgid "logical_to_bitwise(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:4059
+#: fortran/resolve.c:4065
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:4229 fortran/resolve.c:4252
+#: fortran/resolve.c:4235 fortran/resolve.c:4258
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:4347
+#: fortran/resolve.c:4353
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4352
+#: fortran/resolve.c:4358
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4362
+#: fortran/resolve.c:4368
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4367
+#: fortran/resolve.c:4373
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4387
+#: fortran/resolve.c:4393
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr ""
 
-#: fortran/resolve.c:4404
+#: fortran/resolve.c:4410
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4412
+#: fortran/resolve.c:4418
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4428
+#: fortran/resolve.c:4434
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4437
+#: fortran/resolve.c:4443
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4453
+#: fortran/resolve.c:4459
 #, fuzzy, gcc-internal-format
 #| msgid "subscript missing in array reference"
 msgid "check_dimension(): Bad array reference"
 msgstr "indeks mangler i tabelopslag"
 
-#: fortran/resolve.c:4476
+#: fortran/resolve.c:4482
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:4486
+#: fortran/resolve.c:4492
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.c:4494
+#: fortran/resolve.c:4500
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.c:4510
+#: fortran/resolve.c:4516
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr ""
 
-#: fortran/resolve.c:4538
+#: fortran/resolve.c:4544
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4544
+#: fortran/resolve.c:4550
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr ""
 
-#: fortran/resolve.c:4550
+#: fortran/resolve.c:4556
 #, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr ""
 
-#: fortran/resolve.c:4589
+#: fortran/resolve.c:4595
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 3 of `%s' must be a 2-bit literal"
 msgid "Argument dim at %L must be scalar"
 msgstr "parameter til '%s' skal være en 2 bit-konstant"
 
-#: fortran/resolve.c:4596
+#: fortran/resolve.c:4602
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr ""
 
-#: fortran/resolve.c:4641
+#: fortran/resolve.c:4647
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr ""
 
-#: fortran/resolve.c:4652
+#: fortran/resolve.c:4658
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.c:4663
+#: fortran/resolve.c:4669
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.c:4706
+#: fortran/resolve.c:4712
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array `%A' at %0 is too large to handle"
 msgid "Array index at %L is an array of rank %d"
 msgstr "Tabellen '%A' ved %0 er for stor til at håndtere"
 
-#: fortran/resolve.c:4804
+#: fortran/resolve.c:4810
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:4811
+#: fortran/resolve.c:4817
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4820
+#: fortran/resolve.c:4826
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr ""
 
-#: fortran/resolve.c:4833
+#: fortran/resolve.c:4839
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:4840
+#: fortran/resolve.c:4846
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Substring begin/end point at %0 out of defined range"
 msgid "Substring end index at %L must be scalar"
 msgstr "Understrengs begyndelses-/slutpunkt ved %0 er uden for det definerede interval"
 
-#: fortran/resolve.c:4850
+#: fortran/resolve.c:4856
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr ""
 
-#: fortran/resolve.c:4860
+#: fortran/resolve.c:4866
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "requested alignment is too large"
 msgid "Substring end index at %L is too large"
 msgstr "angivet justering er for stor"
 
-#: fortran/resolve.c:5013
+#: fortran/resolve.c:5019
 #, gcc-internal-format
 msgid "resolve_ref(): Bad array reference"
 msgstr ""
 
-#: fortran/resolve.c:5027
+#: fortran/resolve.c:5033
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:5037
+#: fortran/resolve.c:5043
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:5056
+#: fortran/resolve.c:5062
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:5154
+#: fortran/resolve.c:5160
 #, gcc-internal-format
 msgid "expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.c:5236
+#: fortran/resolve.c:5242
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr ""
 
-#: fortran/resolve.c:5246
+#: fortran/resolve.c:5252
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -65494,12 +65577,12 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5256
+#: fortran/resolve.c:5262
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5271
+#: fortran/resolve.c:5277
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -65508,274 +65591,274 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5281
+#: fortran/resolve.c:5287
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5292
+#: fortran/resolve.c:5298
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5301
+#: fortran/resolve.c:5307
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5316
+#: fortran/resolve.c:5322
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5478
+#: fortran/resolve.c:5484
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5483
+#: fortran/resolve.c:5489
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5553
+#: fortran/resolve.c:5559
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.c:5566
+#: fortran/resolve.c:5572
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.c:5919
+#: fortran/resolve.c:5925
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:5926
+#: fortran/resolve.c:5932
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5961
+#: fortran/resolve.c:5967
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5970
+#: fortran/resolve.c:5976
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr ""
 
 #. Nothing matching found!
-#: fortran/resolve.c:6158
+#: fortran/resolve.c:6164
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:6185
+#: fortran/resolve.c:6191
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:6236
+#: fortran/resolve.c:6242
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:6786
+#: fortran/resolve.c:6792
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr ""
 
-#: fortran/resolve.c:6812
+#: fortran/resolve.c:6818
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr ""
 
-#: fortran/resolve.c:6822
+#: fortran/resolve.c:6828
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "\"%s\" after # is not a positive integer"
 msgid "%s at %L must be integer"
 msgstr "\"%s\" efter # er ikke et positivt heltal"
 
-#: fortran/resolve.c:6826 fortran/resolve.c:6833
+#: fortran/resolve.c:6832 fortran/resolve.c:6839
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6875
+#: fortran/resolve.c:6881
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:6911
+#: fortran/resolve.c:6917
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.c:6928
+#: fortran/resolve.c:6934
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.c:6934
+#: fortran/resolve.c:6940
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.c:6995
+#: fortran/resolve.c:7001
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7000
+#: fortran/resolve.c:7006
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7007
+#: fortran/resolve.c:7013
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7015
+#: fortran/resolve.c:7021
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr ""
 
-#: fortran/resolve.c:7020
+#: fortran/resolve.c:7026
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:7033
+#: fortran/resolve.c:7039
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr ""
 
-#: fortran/resolve.c:7136 fortran/resolve.c:7428
+#: fortran/resolve.c:7142 fortran/resolve.c:7434
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:7144 fortran/resolve.c:7393
+#: fortran/resolve.c:7150 fortran/resolve.c:7399
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7250
+#: fortran/resolve.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7281
+#: fortran/resolve.c:7287
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.c:7439
+#: fortran/resolve.c:7445
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.c:7451
+#: fortran/resolve.c:7457
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.c:7465
+#: fortran/resolve.c:7471
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7480
+#: fortran/resolve.c:7486
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7493
+#: fortran/resolve.c:7499
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.c:7511
+#: fortran/resolve.c:7517
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.c:7592 fortran/resolve.c:7607
+#: fortran/resolve.c:7598 fortran/resolve.c:7613
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array or substring specification for `%A' out of range in statement at %0"
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "Tabel- eller understrengsangivelse for '%A' er uden for det gyldige interval i sætning ved %0"
 
-#: fortran/resolve.c:7599
+#: fortran/resolve.c:7605
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array or substring specification for `%A' out of range in statement at %0"
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "Tabel- eller understrengsangivelse for '%A' er uden for det gyldige interval i sætning ved %0"
 
-#: fortran/resolve.c:7622
+#: fortran/resolve.c:7628
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array or substring specification for `%A' out of range in statement at %0"
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "Tabel- eller understrengsangivelse for '%A' er uden for det gyldige interval i sætning ved %0"
 
-#: fortran/resolve.c:7649
+#: fortran/resolve.c:7655
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "No label definition for FORMAT statement at %0"
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "Ingen etiketdefinition for FORMAT-sætning ved %0"
 
-#: fortran/resolve.c:7668
+#: fortran/resolve.c:7674
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.c:7683
+#: fortran/resolve.c:7689
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7694
+#: fortran/resolve.c:7700
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "No label definition for FORMAT statement at %0"
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "Ingen etiketdefinition for FORMAT-sætning ved %0"
 
-#: fortran/resolve.c:7726
+#: fortran/resolve.c:7732
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:7749
+#: fortran/resolve.c:7755
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:7760
+#: fortran/resolve.c:7766
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.c:7771
+#: fortran/resolve.c:7782
 #, gcc-internal-format, gfc-internal-format
-msgid "Errmsg-variable at %L must be a scalar CHARACTER variable"
+msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:7794
+#: fortran/resolve.c:7805
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:7824
+#: fortran/resolve.c:7835
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.c:7830 fortran/resolve.c:7836
+#: fortran/resolve.c:7841 fortran/resolve.c:7847
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -65784,238 +65867,238 @@
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8064
+#: fortran/resolve.c:8075
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr ""
 
-#: fortran/resolve.c:8115
+#: fortran/resolve.c:8126
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "expression statement has incomplete type"
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "udtrykket er af en ufuldstændig type"
 
-#: fortran/resolve.c:8126
+#: fortran/resolve.c:8137
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr ""
 
-#: fortran/resolve.c:8139
+#: fortran/resolve.c:8150
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:8185
+#: fortran/resolve.c:8196
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr ""
 
-#: fortran/resolve.c:8204
+#: fortran/resolve.c:8215
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr ""
 
-#: fortran/resolve.c:8214
+#: fortran/resolve.c:8225
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr ""
 
-#: fortran/resolve.c:8232 fortran/resolve.c:8240
+#: fortran/resolve.c:8243 fortran/resolve.c:8251
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr ""
 
-#: fortran/resolve.c:8302 fortran/resolve.c:8873
+#: fortran/resolve.c:8313 fortran/resolve.c:8884
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr ""
 
-#: fortran/resolve.c:8328
+#: fortran/resolve.c:8339
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:8340
+#: fortran/resolve.c:8351
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:8355
+#: fortran/resolve.c:8366
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr ""
 
-#: fortran/resolve.c:8458
+#: fortran/resolve.c:8469
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr ""
 
-#: fortran/resolve.c:8518
+#: fortran/resolve.c:8529
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "expression statement has incomplete type"
 msgid "Selector at %L cannot be NULL()"
 msgstr "udtrykket er af en ufuldstændig type"
 
-#: fortran/resolve.c:8523
+#: fortran/resolve.c:8534
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "parameter `%s' has incomplete type"
 msgid "Selector at %L has no type"
 msgstr "parameteren '%s' er af en ufuldstændig type"
 
-#: fortran/resolve.c:8545
+#: fortran/resolve.c:8556
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.c:8556
+#: fortran/resolve.c:8567
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:8763
+#: fortran/resolve.c:8774
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8783 fortran/resolve.c:8795
+#: fortran/resolve.c:8794 fortran/resolve.c:8806
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.c:8824
+#: fortran/resolve.c:8835
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr ""
 
-#: fortran/resolve.c:8836
+#: fortran/resolve.c:8847
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr ""
 
-#: fortran/resolve.c:8848
+#: fortran/resolve.c:8859
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr ""
 
-#: fortran/resolve.c:8851
+#: fortran/resolve.c:8862
 #, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:8861
+#: fortran/resolve.c:8872
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.c:9108
+#: fortran/resolve.c:9119
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9204
+#: fortran/resolve.c:9215
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr ""
 
-#: fortran/resolve.c:9257
+#: fortran/resolve.c:9268
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "`%D' must take exactly one argument"
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "'%s' skal tage mod én parameter"
 
-#: fortran/resolve.c:9267
+#: fortran/resolve.c:9278
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9280
+#: fortran/resolve.c:9291
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9289
+#: fortran/resolve.c:9300
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr ""
 
-#: fortran/resolve.c:9296
+#: fortran/resolve.c:9307
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9307
+#: fortran/resolve.c:9318
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr ""
 
-#: fortran/resolve.c:9313
+#: fortran/resolve.c:9324
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9328
+#: fortran/resolve.c:9339
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:9388
+#: fortran/resolve.c:9399
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:9398
+#: fortran/resolve.c:9409
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:9402
+#: fortran/resolve.c:9413
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr ""
 
-#: fortran/resolve.c:9405
+#: fortran/resolve.c:9416
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr ""
 
-#: fortran/resolve.c:9412 fortran/resolve.c:9533
+#: fortran/resolve.c:9423 fortran/resolve.c:9545
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:9424 fortran/resolve.c:9540
+#: fortran/resolve.c:9435 fortran/resolve.c:9553
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:9436
+#: fortran/resolve.c:9447
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr ""
 
-#: fortran/resolve.c:9449
+#: fortran/resolve.c:9460
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "use of class template `%T' as expression"
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "brug af klasseskabelonen '%T' som udtryk"
 
-#: fortran/resolve.c:9510
+#: fortran/resolve.c:9521
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:9514 fortran/resolve.c:9524
+#: fortran/resolve.c:9525 fortran/resolve.c:9535
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr ""
 
-#: fortran/resolve.c:9567
+#: fortran/resolve.c:9580
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Statement at %0 invalid in context established by statement at %1"
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "Sætning ved %0 er ugyldig i den kontekst der er etableret af sætning ved %1"
 
-#: fortran/resolve.c:9577
+#: fortran/resolve.c:9590
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr ""
@@ -66022,12 +66105,12 @@
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:9594 fortran/resolve.c:9617
+#: fortran/resolve.c:9607 fortran/resolve.c:9630
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.c:9598 fortran/resolve.c:9623
+#: fortran/resolve.c:9611 fortran/resolve.c:9636
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -66035,109 +66118,109 @@
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:9638
+#: fortran/resolve.c:9651
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Statement at %0 invalid in context established by statement at %1"
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "Sætning ved %0 er ugyldig i den kontekst der er etableret af sætning ved %1"
 
-#: fortran/resolve.c:9710
+#: fortran/resolve.c:9723
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:9726
+#: fortran/resolve.c:9739
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:9734 fortran/resolve.c:9821
+#: fortran/resolve.c:9747 fortran/resolve.c:9834
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:9744 fortran/resolve.c:9831
+#: fortran/resolve.c:9757 fortran/resolve.c:9844
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/resolve.c:9775
+#: fortran/resolve.c:9788
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:9784
+#: fortran/resolve.c:9797
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr ""
 
-#: fortran/resolve.c:9949
+#: fortran/resolve.c:9962
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr ""
 
-#: fortran/resolve.c:9959
+#: fortran/resolve.c:9972
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr ""
 
-#: fortran/resolve.c:10036
+#: fortran/resolve.c:10049
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr ""
 
-#: fortran/resolve.c:10138
+#: fortran/resolve.c:10151
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:10251
+#: fortran/resolve.c:10264
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr ""
 
-#: fortran/resolve.c:10283
+#: fortran/resolve.c:10296
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:10288
+#: fortran/resolve.c:10301
 #, gcc-internal-format, gfc-internal-format
 msgid "The impure variable at %L is assigned to a derived type variable with a POINTER component in a PURE procedure (12.6)"
 msgstr ""
 
-#: fortran/resolve.c:10298
+#: fortran/resolve.c:10311
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:10330
+#: fortran/resolve.c:10343
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:10334
+#: fortran/resolve.c:10347
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:10339
+#: fortran/resolve.c:10352
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.c:10346
+#: fortran/resolve.c:10359
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr ""
 
-#: fortran/resolve.c:10357
+#: fortran/resolve.c:10370
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:10663
+#: fortran/resolve.c:10683
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
@@ -66144,69 +66227,69 @@
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:10905
+#: fortran/resolve.c:10925
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid lvalue in assignment"
 msgid "Pointer procedure assignment at %L"
 msgstr "ugyldig venstreværdi i tildeling"
 
-#: fortran/resolve.c:10917
+#: fortran/resolve.c:10937
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr ""
 
-#: fortran/resolve.c:11157
+#: fortran/resolve.c:11177
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:11160
+#: fortran/resolve.c:11180
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr ""
 
-#: fortran/resolve.c:11171
+#: fortran/resolve.c:11191
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr ""
 
-#: fortran/resolve.c:11233
+#: fortran/resolve.c:11253
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:11278
+#: fortran/resolve.c:11298
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid string constant `%E'"
 msgid "Invalid NULL at %L"
 msgstr "ugyldig strengkonstant '%E'"
 
-#: fortran/resolve.c:11282
+#: fortran/resolve.c:11302
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:11339
+#: fortran/resolve.c:11359
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:11344
+#: fortran/resolve.c:11364
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:11428
+#: fortran/resolve.c:11448
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:11507
+#: fortran/resolve.c:11527
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr ""
 
-#: fortran/resolve.c:11617
+#: fortran/resolve.c:11637
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
@@ -66213,7 +66296,7 @@
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:11630
+#: fortran/resolve.c:11650
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr ""
@@ -66221,58 +66304,58 @@
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:11647
+#: fortran/resolve.c:11667
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.c:11732
+#: fortran/resolve.c:11752
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Integer at %0 too large"
 msgid "String length at %L is too large"
 msgstr "Heltal ved %0 for stort"
 
-#: fortran/resolve.c:11961
+#: fortran/resolve.c:11981
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:11965
+#: fortran/resolve.c:11985
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:11973
+#: fortran/resolve.c:11993
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:11983
+#: fortran/resolve.c:12003
 #, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:11998
+#: fortran/resolve.c:12018
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.c:12010
+#: fortran/resolve.c:12030
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.c:12041
+#: fortran/resolve.c:12061
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.c:12063
+#: fortran/resolve.c:12083
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
 
-#: fortran/resolve.c:12090
+#: fortran/resolve.c:12110
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
@@ -66279,898 +66362,904 @@
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12131
+#: fortran/resolve.c:12151
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr ""
 
-#: fortran/resolve.c:12150
+#: fortran/resolve.c:12170
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr ""
 
-#: fortran/resolve.c:12171
+#: fortran/resolve.c:12191
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr ""
 
-#: fortran/resolve.c:12178
+#: fortran/resolve.c:12198
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr ""
 
-#: fortran/resolve.c:12225
+#: fortran/resolve.c:12245
 #, fuzzy, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "slutfeltet '%s' bliver måske ikke klargjort"
 
-#: fortran/resolve.c:12228
+#: fortran/resolve.c:12248
 #, fuzzy, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr "slutfeltet '%s' bliver måske ikke klargjort"
 
-#: fortran/resolve.c:12232
+#: fortran/resolve.c:12252
 #, fuzzy, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "slutfeltet '%s' bliver måske ikke klargjort"
 
-#: fortran/resolve.c:12235
+#: fortran/resolve.c:12255
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "slutfeltet '%s' bliver måske ikke klargjort"
 
-#: fortran/resolve.c:12238
+#: fortran/resolve.c:12258
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "slutfeltet '%s' bliver måske ikke klargjort"
 
-#: fortran/resolve.c:12241
+#: fortran/resolve.c:12261
 #, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12283
+#: fortran/resolve.c:12303
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "fstat %s"
 msgid "%s at %L"
 msgstr "fejl ved egenskabsundersøgelse af filen %s"
 
-#: fortran/resolve.c:12310
+#: fortran/resolve.c:12330
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:12332
+#: fortran/resolve.c:12352
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:12354
+#: fortran/resolve.c:12374
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.c:12372
+#: fortran/resolve.c:12392
 #, fuzzy, gcc-internal-format
 #| msgid "function cannot be inline"
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "funktion kan ikke indbygges"
 
-#: fortran/resolve.c:12381
+#: fortran/resolve.c:12401
 #, fuzzy, gcc-internal-format
 #| msgid "variable-sized object of type `%T' may not be initialized"
 msgid "External object %qs at %L may not have an initializer"
 msgstr "objekt af typen '%T' med variabel størrelse må ikke tildeles en startværdi"
 
-#: fortran/resolve.c:12389
+#: fortran/resolve.c:12409
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr ""
 
-#: fortran/resolve.c:12399
+#: fortran/resolve.c:12419
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr ""
 
-#: fortran/resolve.c:12418
+#: fortran/resolve.c:12438
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr ""
 
-#: fortran/resolve.c:12422
+#: fortran/resolve.c:12442
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr ""
 
-#: fortran/resolve.c:12426
+#: fortran/resolve.c:12446
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr ""
 
-#: fortran/resolve.c:12430
+#: fortran/resolve.c:12450
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr ""
 
-#: fortran/resolve.c:12443
+#: fortran/resolve.c:12463
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12452
+#: fortran/resolve.c:12472
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:12458
+#: fortran/resolve.c:12478
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:12470
+#: fortran/resolve.c:12490
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:12527
+#: fortran/resolve.c:12547
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12533
+#: fortran/resolve.c:12553
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12539
+#: fortran/resolve.c:12559
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12547
+#: fortran/resolve.c:12567
 #, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12553
+#: fortran/resolve.c:12573
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.c:12596
+#: fortran/resolve.c:12616
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12604
+#: fortran/resolve.c:12624
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12612
+#: fortran/resolve.c:12632
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12621
+#: fortran/resolve.c:12641
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.c:12705
+#: fortran/resolve.c:12725
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:12714
+#: fortran/resolve.c:12734
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "`%D' must take exactly one argument"
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "'%s' skal tage mod én parameter"
 
-#: fortran/resolve.c:12723
+#: fortran/resolve.c:12743
 #, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr ""
 
-#: fortran/resolve.c:12731
+#: fortran/resolve.c:12751
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:12737
+#: fortran/resolve.c:12757
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:12743
+#: fortran/resolve.c:12763
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr ""
 
-#: fortran/resolve.c:12751
+#: fortran/resolve.c:12771
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:12760
+#: fortran/resolve.c:12780
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr ""
 
-#: fortran/resolve.c:12782
+#: fortran/resolve.c:12802
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr ""
 
-#: fortran/resolve.c:12819
+#: fortran/resolve.c:12839
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr ""
 
-#: fortran/resolve.c:12859
+#: fortran/resolve.c:12879
 #, gcc-internal-format
 msgid "%qs and %qs can't be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12895
+#: fortran/resolve.c:12915
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.c:12954
+#: fortran/resolve.c:12974
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12966
+#: fortran/resolve.c:12986
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.c:12994
+#: fortran/resolve.c:13014
 #, gcc-internal-format
 msgid "GENERIC %qs at %L can't overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.c:13050
+#: fortran/resolve.c:13070
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L can't be NOPASS"
 msgstr ""
 
-#: fortran/resolve.c:13242
+#: fortran/resolve.c:13262
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr ""
 
-#: fortran/resolve.c:13284
+#: fortran/resolve.c:13304
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:13298
+#: fortran/resolve.c:13318
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:13312 fortran/resolve.c:13778
+#: fortran/resolve.c:13332 fortran/resolve.c:13798
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13320
+#: fortran/resolve.c:13340
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr ""
 
-#: fortran/resolve.c:13329
+#: fortran/resolve.c:13349
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:13335
+#: fortran/resolve.c:13355
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13341
+#: fortran/resolve.c:13361
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr ""
 
-#: fortran/resolve.c:13370
+#: fortran/resolve.c:13390
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:13380
+#: fortran/resolve.c:13400
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:13472
+#: fortran/resolve.c:13492
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.c:13574
+#: fortran/resolve.c:13594
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:13583
+#: fortran/resolve.c:13603
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13593
+#: fortran/resolve.c:13613
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.c:13602
+#: fortran/resolve.c:13622
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.c:13613
+#: fortran/resolve.c:13633
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 of `%s' must be a 2-bit literal"
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "parameter til '%s' skal være en 2 bit-konstant"
 
-#: fortran/resolve.c:13711
+#: fortran/resolve.c:13731
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:13725
+#: fortran/resolve.c:13745
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:13741
+#: fortran/resolve.c:13761
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:13751
+#: fortran/resolve.c:13771
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:13760
+#: fortran/resolve.c:13780
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:13769
+#: fortran/resolve.c:13789
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13811
+#: fortran/resolve.c:13831
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr ""
 
-#: fortran/resolve.c:13824
+#: fortran/resolve.c:13844
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr ""
 
-#: fortran/resolve.c:13835
+#: fortran/resolve.c:13855
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13868
+#: fortran/resolve.c:13888
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:13876
+#: fortran/resolve.c:13896
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.c:13885
+#: fortran/resolve.c:13905
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr ""
 
-#: fortran/resolve.c:13903 fortran/resolve.c:13915
+#: fortran/resolve.c:13923 fortran/resolve.c:13935
 #, gcc-internal-format
 msgid "The pointer component %qs of %qs at %L is a type that has not been declared"
 msgstr ""
 
-#: fortran/resolve.c:13989
+#: fortran/resolve.c:14009
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "initialization of new expression with `='"
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "tildeling af startværdi til new-udtryk med '='"
 
-#: fortran/resolve.c:14034
+#: fortran/resolve.c:14054
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.c:14047
+#: fortran/resolve.c:14067
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr ""
 
-#: fortran/resolve.c:14111
+#: fortran/resolve.c:14131
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14144
+#: fortran/resolve.c:14164
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.c:14216
+#: fortran/resolve.c:14236
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:14222
+#: fortran/resolve.c:14242
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14228
+#: fortran/resolve.c:14248
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14236
+#: fortran/resolve.c:14256
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14253
+#: fortran/resolve.c:14273
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14275
+#: fortran/resolve.c:14295
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14286
+#: fortran/resolve.c:14306
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14313
+#: fortran/resolve.c:14333
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14337
+#: fortran/resolve.c:14357
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:14353
+#: fortran/resolve.c:14373
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:14364
+#: fortran/resolve.c:14384
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "uforenelig afledt type i PARAMETER ved %L"
 
-#: fortran/resolve.c:14372
+#: fortran/resolve.c:14392
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "CLASS-variablen %qs ved %L kan ikke have PARAMETER-attributten"
 
-#: fortran/resolve.c:14423
+#: fortran/resolve.c:14443
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr ""
 
-#: fortran/resolve.c:14434
+#: fortran/resolve.c:14454
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.c:14441
+#: fortran/resolve.c:14461
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.c:14480
+#: fortran/resolve.c:14500
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:14544
+#: fortran/resolve.c:14564
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:14547
+#: fortran/resolve.c:14567
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:14643
+#: fortran/resolve.c:14663
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:14664
+#: fortran/resolve.c:14684
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "No specification for implied-DO iterator `%A' at %0"
 msgid "Bad specification for assumed size array at %L"
 msgstr "Ingen angivelse af underforstået DO-iterator '%A' ved %0"
 
-#: fortran/resolve.c:14677
+#: fortran/resolve.c:14697
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14680
+#: fortran/resolve.c:14700
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14688
+#: fortran/resolve.c:14708
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14695
+#: fortran/resolve.c:14715
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:14708
+#: fortran/resolve.c:14728
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr ""
 
-#: fortran/resolve.c:14714
+#: fortran/resolve.c:14734
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14724
+#: fortran/resolve.c:14744
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:14733
+#: fortran/resolve.c:14753
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.c:14746 fortran/resolve.c:14923
+#: fortran/resolve.c:14766 fortran/resolve.c:14943
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.c:14760
+#: fortran/resolve.c:14780
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14769
+#: fortran/resolve.c:14789
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:14778
+#: fortran/resolve.c:14798
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14786
+#: fortran/resolve.c:14806
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:14793
+#: fortran/resolve.c:14813
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:14813
+#: fortran/resolve.c:14833
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.c:14820
+#: fortran/resolve.c:14840
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14827
+#: fortran/resolve.c:14847
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:14834
+#: fortran/resolve.c:14854
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:14860
+#: fortran/resolve.c:14880
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:14870
+#: fortran/resolve.c:14890
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 of `%s' must be a 2-bit literal"
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "parameter til '%s' skal være en 2 bit-konstant"
 
-#: fortran/resolve.c:14949
+#: fortran/resolve.c:14969
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:14964
+#: fortran/resolve.c:14984
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14977
+#: fortran/resolve.c:14997
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14995
+#: fortran/resolve.c:15015
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.c:15007
+#: fortran/resolve.c:15027
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:15016
+#: fortran/resolve.c:15036
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:15028
+#: fortran/resolve.c:15048
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr ""
 
-#: fortran/resolve.c:15037
+#: fortran/resolve.c:15057
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15049
+#: fortran/resolve.c:15069
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15065
+#: fortran/resolve.c:15085
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15073
+#: fortran/resolve.c:15093
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15080
+#: fortran/resolve.c:15100
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15092
+#: fortran/resolve.c:15112
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.c:15101
+#: fortran/resolve.c:15121
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15117
+#: fortran/resolve.c:15137
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15123
+#: fortran/resolve.c:15143
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15148
+#: fortran/resolve.c:15168
 #, fuzzy, gcc-internal-format
 #| msgid "data member `%D' cannot be a member template"
 msgid "Namelist %qs can not be an argument to subroutine or function at %L"
 msgstr "datamedlem '%D' kan ikke være en medlemsskabelon"
 
-#: fortran/resolve.c:15218
+#: fortran/resolve.c:15238
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:15229
+#: fortran/resolve.c:15249
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:15333
+#: fortran/resolve.c:15353
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:15339
+#: fortran/resolve.c:15359
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:15345
+#: fortran/resolve.c:15365
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.c:15354
+#: fortran/resolve.c:15374
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr ""
 
-#: fortran/resolve.c:15368
+#: fortran/resolve.c:15388
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:15414
+#: fortran/resolve.c:15434
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.c:15427
+#: fortran/resolve.c:15447
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.c:15526
+#: fortran/resolve.c:15546
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15534
+#: fortran/resolve.c:15554
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15542
+#: fortran/resolve.c:15562
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15667
+#: fortran/resolve.c:15687
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.c:15832
+#: fortran/resolve.c:15852
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "label `%D' defined but not used"
 msgid "Label %d at %L defined but not used"
 msgstr "etiketten '%D' er defineret, men ikke benyttet"
 
-#: fortran/resolve.c:15838
+#: fortran/resolve.c:15858
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "label `%D' defined but not used"
 msgid "Label %d at %L defined but cannot be used"
 msgstr "etiketten '%D' er defineret, men ikke benyttet"
 
-#: fortran/resolve.c:15922
+#: fortran/resolve.c:15942
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15931
+#: fortran/resolve.c:15951
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15939
+#: fortran/resolve.c:15959
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:15955
+#: fortran/resolve.c:15975
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16058
+#: fortran/resolve.c:16078
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:16073
+#: fortran/resolve.c:16093
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:16098
+#: fortran/resolve.c:16118
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:16107
+#: fortran/resolve.c:16127
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16180
+#: fortran/resolve.c:16200
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16191
+#: fortran/resolve.c:16211
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16202
+#: fortran/resolve.c:16222
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr ""
 
-#: fortran/resolve.c:16293
+#: fortran/resolve.c:16253
+#, fuzzy, gcc-internal-format
+#| msgid "parse error in method specification"
+msgid "Self reference in character length expression for %qs at %L"
+msgstr "tolkningsfejl i medlemsfunktionsangivelsen"
+
+#: fortran/resolve.c:16320
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.c:16306
+#: fortran/resolve.c:16333
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:16326
+#: fortran/resolve.c:16353
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:16336
+#: fortran/resolve.c:16363
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr ""
 
-#: fortran/resolve.c:16344
+#: fortran/resolve.c:16371
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:16358
+#: fortran/resolve.c:16385
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:16376
+#: fortran/resolve.c:16403
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:16383
+#: fortran/resolve.c:16410
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr ""
 
-#: fortran/resolve.c:16461
+#: fortran/resolve.c:16488
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -67504,19 +67593,13 @@
 msgid "simplify_min_max(): Bad type in arglist"
 msgstr ""
 
-#. Result is processor-dependent.
-#: fortran/simplify.c:5472
-#, gcc-internal-format, gfc-internal-format
-msgid "Second argument MOD at %L is zero"
-msgstr ""
+#: fortran/simplify.c:5470 fortran/simplify.c:5478
+#, fuzzy, gcc-internal-format
+#| msgid "argument 3 of `%s' must be a 2-bit literal"
+msgid "Argument %qs of MOD at %L shall not be zero"
+msgstr "parameter til '%s' skal være en 2 bit-konstant"
 
-#. Result is processor-dependent.
-#: fortran/simplify.c:5483
-#, gcc-internal-format, gfc-internal-format
-msgid "Second argument of MOD at %L is zero"
-msgstr ""
-
-#: fortran/simplify.c:5494
+#: fortran/simplify.c:5484
 #, gcc-internal-format
 msgid "gfc_simplify_mod(): Bad arguments"
 msgstr ""
@@ -67524,100 +67607,100 @@
 #. Result is processor-dependent. This processor just opts
 #. to not handle it at all.
 #. Result is processor-dependent.
-#: fortran/simplify.c:5520 fortran/simplify.c:5532
+#: fortran/simplify.c:5525 fortran/simplify.c:5537
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of MODULO at %L is zero"
 msgstr ""
 
-#: fortran/simplify.c:5552
+#: fortran/simplify.c:5557
 #, gcc-internal-format
 msgid "gfc_simplify_modulo(): Bad arguments"
 msgstr ""
 
-#: fortran/simplify.c:5600
+#: fortran/simplify.c:5605
 #, gcc-internal-format, gfc-internal-format
 msgid "Result of NEAREST is NaN at %L"
 msgstr ""
 
-#: fortran/simplify.c:6081
+#: fortran/simplify.c:6086
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative at %L"
 msgstr ""
 
-#: fortran/simplify.c:6137
+#: fortran/simplify.c:6142
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument NCOPIES of REPEAT intrinsic is too large at %L"
 msgstr ""
 
-#: fortran/simplify.c:6174
+#: fortran/simplify.c:6179
 #, gcc-internal-format, gfc-internal-format
 msgid "Evaluation of string longer than 2**28 at %L deferred to runtime, expect bugs"
 msgstr ""
 
-#: fortran/simplify.c:6302
+#: fortran/simplify.c:6307
 #, gcc-internal-format, gfc-internal-format
 msgid "Reshaped array too large at %C"
 msgstr ""
 
-#: fortran/simplify.c:6416
+#: fortran/simplify.c:6421
 #, gcc-internal-format, gfc-internal-format
 msgid "Result of SCALE overflows its kind at %L"
 msgstr ""
 
-#: fortran/simplify.c:6995
+#: fortran/simplify.c:7000
 #, gcc-internal-format
 msgid "Bad type in gfc_simplify_sign"
 msgstr ""
 
-#: fortran/simplify.c:7024
+#: fortran/simplify.c:7029
 #, gcc-internal-format
 msgid "in gfc_simplify_sin(): Bad type"
 msgstr ""
 
-#: fortran/simplify.c:7151 fortran/simplify.c:7431
+#: fortran/simplify.c:7156 fortran/simplify.c:7436
 #, gcc-internal-format
 msgid "Failure getting length of a constant array."
 msgstr ""
 
-#: fortran/simplify.c:7161
+#: fortran/simplify.c:7166
 #, gcc-internal-format
 msgid "The number of elements (%d) in the array constructor at %L requires an increase of the allowed %d upper limit.  See %<-fmax-array-constructor%> option."
 msgstr ""
 
-#: fortran/simplify.c:7227
+#: fortran/simplify.c:7232
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "trampolines not yet implemented"
 msgid "Simplification of SPREAD at %C not yet implemented"
 msgstr "trampoliner understøttes ikke endnu"
 
-#: fortran/simplify.c:7251
+#: fortran/simplify.c:7256
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "function call has aggregate value"
 msgid "Argument of SQRT at %L has a negative value"
 msgstr "funktionskald har en sammensat værdi"
 
-#: fortran/simplify.c:7267
+#: fortran/simplify.c:7272
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "invalid argument of SQRT at %L"
 msgstr "ugyldig parameter til egenskaben '%s'"
 
-#: fortran/simplify.c:7598
+#: fortran/simplify.c:7603
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY lower bound is %ld)"
 msgstr ""
 
-#: fortran/simplify.c:7621
+#: fortran/simplify.c:7626
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY upper bound is %ld)"
 msgstr ""
 
-#: fortran/simplify.c:7993
+#: fortran/simplify.c:7998
 #, gcc-internal-format
 msgid "gfc_convert_constant(): Unexpected type"
 msgstr ""
 
-#: fortran/simplify.c:8078
+#: fortran/simplify.c:8083
 #, gcc-internal-format
 msgid "Character %qs in string at %L cannot be converted into character kind %d"
 msgstr ""
@@ -67724,7 +67807,7 @@
 msgid "BIND(C) applied to %s %s at %L"
 msgstr ""
 
-#: fortran/symbol.c:901 fortran/symbol.c:912 fortran/symbol.c:1762
+#: fortran/symbol.c:901 fortran/symbol.c:912 fortran/symbol.c:1776
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "`%s' attribute only applies to variables"
 msgid "%s attribute conflicts with %s attribute at %L"
@@ -67805,17 +67888,23 @@
 msgid "Duplicate VOLATILE attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1367
+#: fortran/symbol.c:1360
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "SAVE statement or attribute at %1 cannot be specified along with SAVE statement or attribute at %0"
+msgid "VOLATILE attribute at %L cannot be specified in a PURE procedure"
+msgstr "SAVE-sætning eller -egenskab ved %1 kan ikke angives sammen med SAVE-sætning eller -egenskab ved %0"
+
+#: fortran/symbol.c:1381
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ASYNCHRONOUS attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1758
+#: fortran/symbol.c:1772
 #, fuzzy, gcc-internal-format
 msgid "%s attribute of %qs conflicts with %s attribute at %L"
 msgstr "dataområdet '%s' er i modstrid med tidligere erklæring"
 
-#: fortran/symbol.c:1794
+#: fortran/symbol.c:1808
 #, gcc-internal-format, gfc-internal-format
 msgid ""
 "%s procedure at %L is already declared as %s procedure. \n"
@@ -67822,212 +67911,212 @@
 "F2008: A pointer function assignment is ambiguous if it is the first executable statement after the specification block. Please add any other kind of executable statement before it. FIXME"
 msgstr ""
 
-#: fortran/symbol.c:1802
+#: fortran/symbol.c:1816
 #, gcc-internal-format, gfc-internal-format
 msgid "%s procedure at %L is already declared as %s procedure"
 msgstr ""
 
-#: fortran/symbol.c:1837
+#: fortran/symbol.c:1851
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgstr ""
 
-#: fortran/symbol.c:1861
+#: fortran/symbol.c:1875
 #, gcc-internal-format, gfc-internal-format
 msgid "ACCESS specification at %L was already specified"
 msgstr ""
 
-#: fortran/symbol.c:1878
+#: fortran/symbol.c:1892
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate BIND attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1885
+#: fortran/symbol.c:1899
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) at %L"
 msgstr ""
 
-#: fortran/symbol.c:1901
+#: fortran/symbol.c:1915
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate EXTENDS attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1905
+#: fortran/symbol.c:1919
 #, gcc-internal-format, gfc-internal-format
 msgid "EXTENDS at %L"
 msgstr ""
 
-#: fortran/symbol.c:1931
+#: fortran/symbol.c:1945
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has an explicit interface"
 msgstr ""
 
-#: fortran/symbol.c:1938
+#: fortran/symbol.c:1952
 #, gcc-internal-format
 msgid "%qs at %L has attributes specified outside its INTERFACE body"
 msgstr ""
 
-#: fortran/symbol.c:1976
+#: fortran/symbol.c:1990
 #, gcc-internal-format
 msgid "Symbol %qs at %L conflicts with symbol from module %qs, use-associated at %L"
 msgstr ""
 
-#: fortran/symbol.c:1980
+#: fortran/symbol.c:1994
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr ""
 
-#: fortran/symbol.c:1987
+#: fortran/symbol.c:2001
 #, gcc-internal-format
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr ""
 
-#: fortran/symbol.c:1999
+#: fortran/symbol.c:2013
 #, gcc-internal-format
 msgid "Symbol %qs at %L cannot have a type"
 msgstr ""
 
-#: fortran/symbol.c:2242
+#: fortran/symbol.c:2256
 #, fuzzy, gcc-internal-format
 #| msgid "Label %A already defined at %1 when redefined at %0"
 msgid "Component %qs at %C already in the parent type at %L"
 msgstr "Etiket %A er allerede defineret ved %1 ved omdefinering ved %0"
 
-#: fortran/symbol.c:2327
+#: fortran/symbol.c:2341
 #, fuzzy, gcc-internal-format
 #| msgid "use of `%D' is ambiguous"
 msgid "Symbol %qs at %C is ambiguous"
 msgstr "brug af '%D' er tvetydigt"
 
-#: fortran/symbol.c:2359
+#: fortran/symbol.c:2373
 #, gcc-internal-format
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr ""
 
-#: fortran/symbol.c:2508
+#: fortran/symbol.c:2522
 #, gcc-internal-format
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr ""
 
-#: fortran/symbol.c:2529
+#: fortran/symbol.c:2543
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a member of type `%T'"
 msgid "%qs at %C is not a member of the %qs structure; did you mean %qs?"
 msgstr "'%D' er ikke et medlem af typen '%T'"
 
-#: fortran/symbol.c:2533
+#: fortran/symbol.c:2547
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a member of type `%T'"
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr "'%D' er ikke et medlem af typen '%T'"
 
-#: fortran/symbol.c:2697
+#: fortran/symbol.c:2711
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr ""
 
-#: fortran/symbol.c:2708
+#: fortran/symbol.c:2722
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr ""
 
-#: fortran/symbol.c:2718
+#: fortran/symbol.c:2732
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr ""
 
-#: fortran/symbol.c:2724
+#: fortran/symbol.c:2738
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:2766
+#: fortran/symbol.c:2780
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr ""
 
-#: fortran/symbol.c:2775
+#: fortran/symbol.c:2789
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr ""
 
-#: fortran/symbol.c:2781
+#: fortran/symbol.c:2795
 #, gcc-internal-format, gfc-internal-format
 msgid "Shared DO termination label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:3110
+#: fortran/symbol.c:3124
 #, gcc-internal-format
 msgid "new_symbol(): Symbol name too long"
 msgstr ""
 
-#: fortran/symbol.c:3135
+#: fortran/symbol.c:3149
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr ""
 
-#: fortran/symbol.c:3138
+#: fortran/symbol.c:3152
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
 msgstr ""
 
 #. Symbol is from another namespace.
-#: fortran/symbol.c:3381
+#: fortran/symbol.c:3395
 #, gcc-internal-format
 msgid "Symbol %qs at %C has already been host associated"
 msgstr ""
 
-#: fortran/symbol.c:4397
+#: fortran/symbol.c:4411
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr ""
 
-#: fortran/symbol.c:4410
+#: fortran/symbol.c:4424
 #, gcc-internal-format
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr ""
 
-#: fortran/symbol.c:4428
+#: fortran/symbol.c:4442
 #, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr ""
 
-#: fortran/symbol.c:4449
+#: fortran/symbol.c:4463
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:4459
+#: fortran/symbol.c:4473
 #, gcc-internal-format
 msgid "Procedure pointer component %qs at %L cannot be a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:4470
+#: fortran/symbol.c:4484
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:4509
+#: fortran/symbol.c:4523
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.c:4519
+#: fortran/symbol.c:4533
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/symbol.c:4533
+#: fortran/symbol.c:4547
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot be declared with both PRIVATE and BIND(C) attributes"
 msgstr ""
 
-#: fortran/symbol.c:4541
+#: fortran/symbol.c:4555
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.c:5018 fortran/symbol.c:5023
+#: fortran/symbol.c:5032 fortran/symbol.c:5037
 #, gcc-internal-format
 msgid "Symbol %qs is used before it is typed at %L"
 msgstr ""
@@ -68077,7 +68166,7 @@
 msgid "Creating array temporary at %L for argument %qs"
 msgstr ""
 
-#: fortran/trans-array.c:10693
+#: fortran/trans-array.c:10724
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr ""
@@ -68289,12 +68378,12 @@
 msgid "%<dim%> argument of %s intrinsic at %L is not a valid dimension index"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:10572 fortran/trans-stmt.c:1050
+#: fortran/trans-intrinsic.c:10574 fortran/trans-stmt.c:1050
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, the event component of derived type at %L is not yet supported"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:10579
+#: fortran/trans-intrinsic.c:10581
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "environment variable DJGPP not defined"
 msgid "The event variable at %L shall not be coindexed"
@@ -68337,7 +68426,7 @@
 msgid "Sorry, only support for integer kind %d implemented for image-set at %L"
 msgstr ""
 
-#: fortran/trans-stmt.c:3346
+#: fortran/trans-stmt.c:3343
 #, gcc-internal-format
 msgid "gfc_trans_select(): Bad type for case expr."
 msgstr ""
@@ -68466,7 +68555,7 @@
 msgid "two or more sections for %s"
 msgstr "mere end én datatype i erklæringen af '%s'"
 
-#: lto/lto-partition.c:516
+#: lto/lto-partition.c:570
 #, gcc-internal-format
 msgid "min partition size cannot be greater than max partition size"
 msgstr ""
@@ -68611,58 +68700,58 @@
 msgid "Cannot read %s"
 msgstr "Kan ikke læse %s"
 
-#: lto/lto.c:2369
+#: lto/lto.c:2337
 #, gcc-internal-format
 msgid "lto_obj_file_open() failed"
 msgstr "lto_obj_file_open() mislykkedes"
 
-#: lto/lto.c:2394
+#: lto/lto.c:2362
 #, gcc-internal-format
 msgid "waitpid failed"
 msgstr "waitpid mislykkedes"
 
-#: lto/lto.c:2397
+#: lto/lto.c:2365
 #, gcc-internal-format
 msgid "streaming subprocess failed"
 msgstr ""
 
-#: lto/lto.c:2400
+#: lto/lto.c:2368
 #, gcc-internal-format
 msgid "streaming subprocess was killed by signal"
 msgstr ""
 
-#: lto/lto.c:2476
+#: lto/lto.c:2445
 #, gcc-internal-format
 msgid "no LTRANS output list filename provided"
 msgstr ""
 
-#: lto/lto.c:2564
+#: lto/lto.c:2525
 #, gcc-internal-format
 msgid "opening LTRANS output list %s: %m"
 msgstr "åbner LTRANS-uddatalisten %s: %m"
 
-#: lto/lto.c:2570
+#: lto/lto.c:2532
 #, gcc-internal-format
 msgid "writing to LTRANS output list %s: %m"
 msgstr "skriver til LTRANS-uddatalisten til %s: %m"
 
-#: lto/lto.c:2581
+#: lto/lto.c:2542
 #, gcc-internal-format
 msgid "closing LTRANS output list %s: %m"
 msgstr "lukker LTRANS-uddatalisten %s: %m"
 
-#: lto/lto.c:2833
+#: lto/lto.c:2794
 #, gcc-internal-format
 msgid "could not open symbol resolution file: %m"
 msgstr "kunne ikke åbne symbolløsningsfilen: %m"
 
-#: lto/lto.c:2954
+#: lto/lto.c:2915
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing braces around initializer"
 msgid "missing resolution data for %s"
 msgstr "krøllede paranteser mangler omkring startværdien"
 
-#: lto/lto.c:2986
+#: lto/lto.c:2947
 #, gcc-internal-format
 msgid "errors during merging of translation units"
 msgstr ""
@@ -69725,6 +69814,11 @@
 #~ msgstr "kan ikke konvertere '%T' til '%T' for parameter '%P' til '%D'"
 
 #, fuzzy
+#~| msgid "duplicate initialization of %D"
+#~ msgid "Expected constant array-spec in initializer list at %L"
+#~ msgstr "%D tildelt startværdi mere end én gang"
+
+#, fuzzy
 #~ msgid "Function name %qs not allowed at %C"
 #~ msgstr "sektionsegenskaben er ikke tilladt for '%s'"
 
@@ -70236,11 +70330,6 @@
 #~ msgstr "Hvor meget en oversættelsesenhed kan vokse pga. indlejring (i procent)"
 
 #, fuzzy
-#~| msgid "  `%#D' declared here"
-#~ msgid "  declared here"
-#~ msgstr "  '%#D' erklæret her"
-
-#, fuzzy
 #~| msgid "`%D' will be initialized after"
 #~ msgid "%q#D initialized"
 #~ msgstr "'%D' vil blive klargjort efter"
Index: gcc/po/tr.po
===================================================================
--- gcc/po/tr.po	(.../tags/gcc_8_2_0_release)
+++ gcc/po/tr.po	(.../branches/gcc-8-branch)
@@ -7,7 +7,7 @@
 msgstr ""
 "Project-Id-Version: gcc 5.2.0\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2018-05-01 20:30+0000\n"
+"POT-Creation-Date: 2018-07-25 14:25+0000\n"
 "PO-Revision-Date: 2015-09-11 20:22+0300\n"
 "Last-Translator: Nilgün Belma Bugüner <nilgun@fide.org>\n"
 "Language-Team: Turkish <gnu-tr-u12a@lists.sourceforge.net>\n"
@@ -40,12 +40,12 @@
 msgid "[cannot find %s]"
 msgstr "[%s bulunamıyor]"
 
-#: collect2.c:1557
+#: collect2.c:1585
 #, c-format
 msgid "collect2 version %s\n"
 msgstr "collect2 %s sürümü\n"
 
-#: collect2.c:1664
+#: collect2.c:1692
 #, fuzzy, c-format
 #| msgid "%d constructor(s) found\n"
 msgid "%d constructor found\n"
@@ -53,7 +53,7 @@
 msgstr[0] "%d kurucu bulundu\n"
 msgstr[1] "%d kurucu bulundu\n"
 
-#: collect2.c:1668
+#: collect2.c:1696
 #, fuzzy, c-format
 #| msgid "%d destructor(s)  found\n"
 msgid "%d destructor found\n"
@@ -61,7 +61,7 @@
 msgstr[0] "%d serbestleştirici bulundu\n"
 msgstr[1] "%d serbestleştirici bulundu\n"
 
-#: collect2.c:1672
+#: collect2.c:1700
 #, fuzzy, c-format
 #| msgid "%d frame table(s) found\n"
 msgid "%d frame table found\n"
@@ -69,12 +69,12 @@
 msgstr[0] "%d çerçeve tablosu bulundu\n"
 msgstr[1] "%d çerçeve tablosu bulundu\n"
 
-#: collect2.c:1836
+#: collect2.c:1864
 #, c-format
 msgid "[Leaving %s]\n"
 msgstr "[%s bırakılıyor]\n"
 
-#: collect2.c:2068
+#: collect2.c:2094
 #, c-format
 msgid ""
 "\n"
@@ -83,7 +83,7 @@
 "\n"
 "write_c_file - çıktı ismi %s, önek %s\n"
 
-#: collect2.c:2584
+#: collect2.c:2610
 #, c-format
 msgid ""
 "\n"
@@ -110,7 +110,7 @@
 msgid "%s: some warnings being treated as errors"
 msgstr "%s: UYARI: `%s' dosyası için okuma erişimi yok\n"
 
-#: diagnostic.c:324 input.c:222 input.c:1834 c-family/c-opts.c:1377
+#: diagnostic.c:324 input.c:222 input.c:1834 c-family/c-opts.c:1392
 #: fortran/cpp.c:576 fortran/error.c:1008 fortran/error.c:1028
 msgid "<built-in>"
 msgstr "<yerleşik>"
@@ -209,13 +209,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:4164 config/arc/arc.c:5784 config/i386/i386.c:17302
+#: final.c:4164 config/arc/arc.c:5775 config/i386/i386.c:17305
 #: config/pdp11/pdp11.c:1715
 #, c-format
 msgid "floating constant misused"
 msgstr "gerçel sayı sabit yanlış kullanılmış"
 
-#: final.c:4222 config/arc/arc.c:5881 config/i386/i386.c:17393
+#: final.c:4222 config/arc/arc.c:5872 config/i386/i386.c:17396
 #: config/pdp11/pdp11.c:1756
 #, c-format
 msgid "invalid expression as operand"
@@ -1237,7 +1237,7 @@
 msgid "GCSE disabled"
 msgstr "GCSE iptal edildi"
 
-#: gimple-ssa-isolate-paths.c:542 c/c-typeck.c:10240
+#: gimple-ssa-isolate-paths.c:542 c/c-typeck.c:10245
 #, gcc-internal-format
 msgid "function returns address of local variable"
 msgstr "işlev yerel değişkenin adresi ile dönüyor"
@@ -1577,7 +1577,7 @@
 msgid "options enabled: "
 msgstr "etkin seçenekler: "
 
-#: tree-diagnostic.c:299 c/c-decl.c:5419 c/c-typeck.c:7259 cp/error.c:1042
+#: tree-diagnostic.c:299 c/c-decl.c:5439 c/c-typeck.c:7264 cp/error.c:1042
 #: c-family/c-pretty-print.c:413
 #, gcc-internal-format
 msgid "<anonymous>"
@@ -3189,71 +3189,71 @@
 msgstr "strfmon biçiminde uzunluk değiştirici"
 
 #. Handle deferred options from command-line.
-#: c-family/c-opts.c:1402 fortran/cpp.c:590
+#: c-family/c-opts.c:1417 fortran/cpp.c:590
 msgid "<command-line>"
 msgstr "<komut-satırı>"
 
-#: config/aarch64/aarch64.c:6613
+#: config/aarch64/aarch64.c:6629
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "unsupported operand for code '%c'"
 msgstr "terim, kod `%c' için geçersiz"
 
-#: config/aarch64/aarch64.c:6624 config/aarch64/aarch64.c:6640
-#: config/aarch64/aarch64.c:6652 config/aarch64/aarch64.c:6663
-#: config/aarch64/aarch64.c:6673 config/aarch64/aarch64.c:6694
-#: config/aarch64/aarch64.c:6764 config/aarch64/aarch64.c:6775
-#: config/aarch64/aarch64.c:6789 config/aarch64/aarch64.c:7011
-#: config/aarch64/aarch64.c:7029
+#: config/aarch64/aarch64.c:6640 config/aarch64/aarch64.c:6656
+#: config/aarch64/aarch64.c:6668 config/aarch64/aarch64.c:6679
+#: config/aarch64/aarch64.c:6689 config/aarch64/aarch64.c:6710
+#: config/aarch64/aarch64.c:6780 config/aarch64/aarch64.c:6791
+#: config/aarch64/aarch64.c:6805 config/aarch64/aarch64.c:7027
+#: config/aarch64/aarch64.c:7045
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "invalid operand for '%%%c'"
 msgstr "terim, kod `%c' için geçersiz"
 
-#: config/aarch64/aarch64.c:6709 config/aarch64/aarch64.c:6720
-#: config/aarch64/aarch64.c:6871 config/aarch64/aarch64.c:6882
+#: config/aarch64/aarch64.c:6725 config/aarch64/aarch64.c:6736
+#: config/aarch64/aarch64.c:6887 config/aarch64/aarch64.c:6898
 #, fuzzy, c-format
 #| msgid "invalid insn:"
 msgid "invalid vector constant"
 msgstr "geçersiz komut:"
 
-#: config/aarch64/aarch64.c:6732 config/aarch64/aarch64.c:6744
-#: config/aarch64/aarch64.c:6755
+#: config/aarch64/aarch64.c:6748 config/aarch64/aarch64.c:6760
+#: config/aarch64/aarch64.c:6771
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6823 config/arm/arm.c:22704
+#: config/aarch64/aarch64.c:6839 config/arm/arm.c:22704
 #, c-format
 msgid "missing operand"
 msgstr "terim eksik"
 
-#: config/aarch64/aarch64.c:6908
+#: config/aarch64/aarch64.c:6924
 #, fuzzy, c-format
 #| msgid "invalid insn:"
 msgid "invalid constant"
 msgstr "geçersiz komut:"
 
-#: config/aarch64/aarch64.c:6911
+#: config/aarch64/aarch64.c:6927
 #, fuzzy, c-format
 #| msgid "invalid %%d operand"
 msgid "invalid operand"
 msgstr "geçersiz %%d terimi"
 
-#: config/aarch64/aarch64.c:7040 config/aarch64/aarch64.c:7045
+#: config/aarch64/aarch64.c:7056 config/aarch64/aarch64.c:7061
 #, fuzzy, c-format
 #| msgid "invalid operand code '%c'"
 msgid "invalid operand prefix '%%%c'"
 msgstr "terim kodu `%c' geçersiz"
 
-#: config/aarch64/aarch64.c:7062
+#: config/aarch64/aarch64.c:7078
 #, fuzzy, c-format
 #| msgid "invalid address"
 msgid "invalid address mode"
 msgstr "adres geçersiz"
 
-#: config/alpha/alpha.c:5125 config/i386/i386.c:18558
-#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21798
+#: config/alpha/alpha.c:5125 config/i386/i386.c:18561
+#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21875
 #: config/sparc/sparc.c:9290
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
@@ -3270,7 +3270,7 @@
 msgstr "%%r değeri geçersiz"
 
 #: config/alpha/alpha.c:5223 config/ia64/ia64.c:5534
-#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21506
+#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21583
 #: config/xtensa/xtensa.c:2429
 #, c-format
 msgid "invalid %%R value"
@@ -3277,13 +3277,13 @@
 msgstr "%%R değeri geçersiz"
 
 #: config/alpha/alpha.c:5229 config/powerpcspe/powerpcspe.c:23933
-#: config/rs6000/rs6000.c:21426 config/xtensa/xtensa.c:2396
+#: config/rs6000/rs6000.c:21503 config/xtensa/xtensa.c:2396
 #, c-format
 msgid "invalid %%N value"
 msgstr "%%N değeri geçersiz"
 
 #: config/alpha/alpha.c:5237 config/powerpcspe/powerpcspe.c:23961
-#: config/rs6000/rs6000.c:21454
+#: config/rs6000/rs6000.c:21531
 #, c-format
 msgid "invalid %%P value"
 msgstr "%%P değeri geçersiz"
@@ -3314,7 +3314,7 @@
 msgstr "%%U değeri geçersiz"
 
 #: config/alpha/alpha.c:5323 config/powerpcspe/powerpcspe.c:24021
-#: config/rs6000/rs6000.c:21514
+#: config/rs6000/rs6000.c:21591
 #, c-format
 msgid "invalid %%s value"
 msgstr "%%s değeri geçersiz"
@@ -3325,7 +3325,7 @@
 msgstr "%%C değeri geçersiz"
 
 #: config/alpha/alpha.c:5371 config/powerpcspe/powerpcspe.c:23797
-#: config/rs6000/rs6000.c:21290
+#: config/rs6000/rs6000.c:21367
 #, c-format
 msgid "invalid %%E value"
 msgstr "%%E değeri geçersiz"
@@ -3336,7 +3336,7 @@
 msgstr "bilinmeyen yerdeğişim unspec"
 
 #: config/alpha/alpha.c:5405 config/cr16/cr16.c:1569
-#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21803
+#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21880
 #: config/spu/spu.c:1458
 #, c-format
 msgid "invalid %%xn code"
@@ -3348,61 +3348,61 @@
 msgid "invalid operand address"
 msgstr "adres geçersiz"
 
-#: config/arc/arc.c:3810
+#: config/arc/arc.c:3808
 #, fuzzy, c-format
 #| msgid "invalid operand to %%R code"
 msgid "invalid operand to %%Z code"
 msgstr "%%R kodu için terim geçersiz"
 
-#: config/arc/arc.c:3818
+#: config/arc/arc.c:3816
 #, fuzzy, c-format
 #| msgid "invalid operand to %%R code"
 msgid "invalid operand to %%z code"
 msgstr "%%R kodu için terim geçersiz"
 
-#: config/arc/arc.c:3826
+#: config/arc/arc.c:3824
 #, fuzzy, c-format
 #| msgid "invalid operand to %%R code"
 msgid "invalid operands to %%c code"
 msgstr "%%R kodu için terim geçersiz"
 
-#: config/arc/arc.c:3834
+#: config/arc/arc.c:3832
 #, fuzzy, c-format
 #| msgid "invalid operand to %%R code"
 msgid "invalid operand to %%M code"
 msgstr "%%R kodu için terim geçersiz"
 
-#: config/arc/arc.c:3842 config/m32r/m32r.c:2100
+#: config/arc/arc.c:3840 config/m32r/m32r.c:2100
 #, c-format
 msgid "invalid operand to %%p code"
 msgstr "%%p kodu için terim geçersiz"
 
-#: config/arc/arc.c:3853 config/m32r/m32r.c:2093
+#: config/arc/arc.c:3851 config/m32r/m32r.c:2093
 #, c-format
 msgid "invalid operand to %%s code"
 msgstr "%%s kodu için terim geçersiz"
 
-#: config/arc/arc.c:4001 config/m32r/m32r.c:2126
+#: config/arc/arc.c:3999 config/m32r/m32r.c:2126
 #, c-format
 msgid "invalid operand to %%R code"
 msgstr "%%R kodu için terim geçersiz"
 
-#: config/arc/arc.c:4077 config/m32r/m32r.c:2149
+#: config/arc/arc.c:4075 config/m32r/m32r.c:2149
 #, c-format
 msgid "invalid operand to %%H/%%L code"
 msgstr "%%H/%%L kodu için terim geçersiz"
 
-#: config/arc/arc.c:4145 config/m32r/m32r.c:2220
+#: config/arc/arc.c:4143 config/m32r/m32r.c:2220
 #, c-format
 msgid "invalid operand to %%U code"
 msgstr "%%U kodu için terim geçersiz"
 
-#: config/arc/arc.c:4157
+#: config/arc/arc.c:4155
 #, c-format
 msgid "invalid operand to %%V code"
 msgstr "%%V kodu için terim geçersiz"
 
-#: config/arc/arc.c:4214
+#: config/arc/arc.c:4212
 #, fuzzy, c-format
 #| msgid "invalid operand to %%R code"
 msgid "invalid operand to %%O code"
@@ -3410,19 +3410,19 @@
 
 #. Unknown flag.
 #. Undocumented flag.
-#: config/arc/arc.c:4240 config/epiphany/epiphany.c:1305
-#: config/m32r/m32r.c:2247 config/nds32/nds32.c:3079 config/sparc/sparc.c:9569
+#: config/arc/arc.c:4238 config/epiphany/epiphany.c:1305
+#: config/m32r/m32r.c:2247 config/nds32/nds32.c:3080 config/sparc/sparc.c:9569
 #, c-format
 msgid "invalid operand output code"
 msgstr "geçersiz terim çıktı kodu"
 
-#: config/arc/arc.c:5869
+#: config/arc/arc.c:5860
 #, fuzzy, c-format
 #| msgid "invalid UNSPEC as operand"
 msgid "invalid UNSPEC as operand: %d"
 msgstr "terim olarak UNSPEC geçersiz"
 
-#: config/arc/arc.c:6158 config/cris/cris.c:2568
+#: config/arc/arc.c:6149 config/cris/cris.c:2568
 msgid "unrecognized supposed constant"
 msgstr "tanınmayan tahmini sabit"
 
@@ -3459,7 +3459,7 @@
 #: config/arm/arm.c:22685 config/arm/arm.c:22692 config/bfin/bfin.c:1441
 #: config/bfin/bfin.c:1448 config/bfin/bfin.c:1455 config/bfin/bfin.c:1462
 #: config/bfin/bfin.c:1471 config/bfin/bfin.c:1478 config/bfin/bfin.c:1485
-#: config/bfin/bfin.c:1492 config/nds32/nds32.c:3098
+#: config/bfin/bfin.c:1492 config/nds32/nds32.c:3099
 #, c-format
 msgid "invalid operand for code '%c'"
 msgstr "terim, kod `%c' için geçersiz"
@@ -3820,112 +3820,112 @@
 msgid "bad output_condmove_single operand"
 msgstr "output_condmove_single terimi hatalı"
 
-#: config/i386/i386.c:17387
+#: config/i386/i386.c:17390
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "terim olarak UNSPEC geçersiz"
 
-#: config/i386/i386.c:17925
+#: config/i386/i386.c:17928
 #, fuzzy, c-format
 #| msgid "invalid use of %<restrict%>"
 msgid "invalid use of register '%s'"
 msgstr "%<restrict%> kullanımı geçersiz"
 
-#: config/i386/i386.c:17930
+#: config/i386/i386.c:17933
 #, fuzzy, c-format
 #| msgid "invalid lvalue in asm output %d"
 msgid "invalid use of asm flag output"
 msgstr "asm çıktısı %d içinde geçersiz sol değer"
 
-#: config/i386/i386.c:18160
+#: config/i386/i386.c:18163
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "invalid operand size for operand code 'O'"
 msgstr "terim, kod `%c' için geçersiz"
 
-#: config/i386/i386.c:18195
+#: config/i386/i386.c:18198
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "invalid operand size for operand code 'z'"
 msgstr "terim, kod `%c' için geçersiz"
 
-#: config/i386/i386.c:18264
+#: config/i386/i386.c:18267
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "terim, kod `%c' için geçersiz"
 
-#: config/i386/i386.c:18269
+#: config/i386/i386.c:18272
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "invalid operand size for operand code 'Z'"
 msgstr "terim, kod `%c' için geçersiz"
 
-#: config/i386/i386.c:18346
+#: config/i386/i386.c:18349
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "terim ne bir sabit ne de bir koşul kodu, geçersiz terim kodu 'c'"
 
-#: config/i386/i386.c:18425
+#: config/i386/i386.c:18428
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "terim ne bir sabit ne de bir koşul kodu, geçersiz terim kodu 'c'"
 
-#: config/i386/i386.c:18443
+#: config/i386/i386.c:18446
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "terim ne bir sabit ne de bir koşul kodu, geçersiz terim kodu 'c'"
 
-#: config/i386/i386.c:18456
+#: config/i386/i386.c:18459
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "terim ne bir sabit ne de bir koşul kodu, geçersiz terim kodu 'c'"
 
-#: config/i386/i386.c:18471
+#: config/i386/i386.c:18474
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr "terim ne bir sabit ne de bir koşul kodu, geçersiz terim kodu 'c'"
 
-#: config/i386/i386.c:18499
+#: config/i386/i386.c:18502
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr "terim ne bir sabit ne de bir koşul kodu, geçersiz terim kodu 'c'"
 
-#: config/i386/i386.c:18517
+#: config/i386/i386.c:18520
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr "terim ne bir sabit ne de bir koşul kodu, geçersiz terim kodu 'c'"
 
-#: config/i386/i386.c:18540
+#: config/i386/i386.c:18543
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "terim ne bir sabit ne de bir koşul kodu, geçersiz terim kodu 'c'"
 
-#: config/i386/i386.c:18626
+#: config/i386/i386.c:18629
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "terim kodu `%c' geçersiz"
 
-#: config/i386/i386.c:18688
+#: config/i386/i386.c:18691
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "kısıtlar terim için geçersiz"
 
-#: config/i386/i386.c:18738
+#: config/i386/i386.c:18741
 #, fuzzy, c-format
 #| msgid "invalid conditional operand"
 msgid "invalid vector immediate"
 msgstr "koşullu terim geçersiz"
 
-#: config/i386/i386.c:29572
+#: config/i386/i386.c:29575
 msgid "unknown insn mode"
 msgstr "bilinmeyen komut kipi"
 
@@ -3965,7 +3965,7 @@
 msgstr "%%P terimi geçersiz"
 
 #: config/iq2000/iq2000.c:3185 config/powerpcspe/powerpcspe.c:23951
-#: config/rs6000/rs6000.c:21444
+#: config/rs6000/rs6000.c:21521
 #, c-format
 msgid "invalid %%p value"
 msgstr "%%p değeri geçersiz"
@@ -4023,7 +4023,7 @@
 msgstr "sonradan arttırımlı adres bir yazmaç değil"
 
 #: config/m32r/m32r.c:2350 config/m32r/m32r.c:2365
-#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33292
+#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33348
 msgid "bad address"
 msgstr "hatalı adres"
 
@@ -4150,208 +4150,208 @@
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr "Sınırını belirlemek için kabukta `%s' çalıştırmayı deneyin.\n"
 
-#: config/powerpcspe/powerpcspe.c:4411 config/rs6000/rs6000.c:4258
+#: config/powerpcspe/powerpcspe.c:4411 config/rs6000/rs6000.c:4278
 msgid "-maltivec=le not allowed for big-endian targets"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4423 config/rs6000/rs6000.c:4273
+#: config/powerpcspe/powerpcspe.c:4423 config/rs6000/rs6000.c:4293
 #, fuzzy
 #| msgid "Use hardware floating point"
 msgid "-mvsx requires hardware floating point"
 msgstr "Donanım kayan nokta aritmetiği kullanılır"
 
-#: config/powerpcspe/powerpcspe.c:4431 config/rs6000/rs6000.c:4281
+#: config/powerpcspe/powerpcspe.c:4431 config/rs6000/rs6000.c:4301
 #, fuzzy
 #| msgid "-f%s and -msdata=%s are incompatible"
 msgid "-mvsx and -mpaired are incompatible"
 msgstr "-f%s ile -msdata=%s uyumsuz."
 
-#: config/powerpcspe/powerpcspe.c:4433 config/rs6000/rs6000.c:4283
+#: config/powerpcspe/powerpcspe.c:4433 config/rs6000/rs6000.c:4303
 #, fuzzy
 #| msgid "Disable indexed addressing"
 msgid "-mvsx needs indexed addressing"
 msgstr "İndisli adresleme kapatılır"
 
-#: config/powerpcspe/powerpcspe.c:4438 config/rs6000/rs6000.c:4288
+#: config/powerpcspe/powerpcspe.c:4438 config/rs6000/rs6000.c:4308
 #, fuzzy
 #| msgid "-f%s and -msdata=%s are incompatible"
 msgid "-mvsx and -mno-altivec are incompatible"
 msgstr "-f%s ile -msdata=%s uyumsuz."
 
-#: config/powerpcspe/powerpcspe.c:4440 config/rs6000/rs6000.c:4290
+#: config/powerpcspe/powerpcspe.c:4440 config/rs6000/rs6000.c:4310
 msgid "-mno-altivec disables vsx"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4648 config/rs6000/rs6000.c:4416
+#: config/powerpcspe/powerpcspe.c:4648 config/rs6000/rs6000.c:4436
 #, fuzzy
 #| msgid "--resource requires -o"
 msgid "-mquad-memory requires 64-bit mode"
 msgstr "--resource, -o gerektirir"
 
-#: config/powerpcspe/powerpcspe.c:4651 config/rs6000/rs6000.c:4419
+#: config/powerpcspe/powerpcspe.c:4651 config/rs6000/rs6000.c:4439
 msgid "-mquad-memory-atomic requires 64-bit mode"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4663 config/rs6000/rs6000.c:4431
+#: config/powerpcspe/powerpcspe.c:4663 config/rs6000/rs6000.c:4451
 #, fuzzy
 #| msgid "Generate code in little endian mode"
 msgid "-mquad-memory is not available in little endian mode"
 msgstr "Kıymetsiz baytın başta olduğu kod üretilir"
 
-#: config/powerpcspe/powerpcspe.c:4735 config/rs6000/rs6000.c:4512
+#: config/powerpcspe/powerpcspe.c:4735 config/rs6000/rs6000.c:4532
 #, fuzzy
 #| msgid "--resource requires -o"
 msgid "-mtoc-fusion requires 64-bit"
 msgstr "--resource, -o gerektirir"
 
-#: config/powerpcspe/powerpcspe.c:4742 config/rs6000/rs6000.c:4519
+#: config/powerpcspe/powerpcspe.c:4742 config/rs6000/rs6000.c:4539
 msgid "-mtoc-fusion requires medium/large code model"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10915
+#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10947
 #, fuzzy
 #| msgid "bad test"
 msgid "bad move"
 msgstr "hatalı test"
 
-#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21087
+#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21164
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21278
+#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21355
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%e value"
 msgstr "%%H değeri geçersiz"
 
-#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21299
+#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21376
 #, c-format
 msgid "invalid %%f value"
 msgstr "%%f değeri geçersiz"
 
-#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21308
+#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21385
 #, c-format
 msgid "invalid %%F value"
 msgstr "%%F değeri geçersiz"
 
-#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21317
+#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21394
 #, c-format
 msgid "invalid %%G value"
 msgstr "%%G değeri geçersiz"
 
-#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21352
+#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21429
 #, c-format
 msgid "invalid %%j code"
 msgstr "%%j kodu geçersiz"
 
-#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21362
+#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21439
 #, c-format
 msgid "invalid %%J code"
 msgstr "%%J kodu geçersiz"
 
-#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21372
+#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21449
 #, c-format
 msgid "invalid %%k value"
 msgstr "%%k değeri geçersiz"
 
-#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21387
+#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21464
 #: config/xtensa/xtensa.c:2415
 #, c-format
 msgid "invalid %%K value"
 msgstr "%%K değeri geçersiz"
 
-#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21434
+#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21511
 #, c-format
 msgid "invalid %%O value"
 msgstr "%%O değeri geçersiz"
 
-#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21481
+#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21558
 #, c-format
 msgid "invalid %%q value"
 msgstr "%%q değeri geçersiz"
 
-#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21534
+#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21611
 #, c-format
 msgid "invalid %%T value"
 msgstr "%%T değeri geçersiz"
 
-#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21546
+#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21623
 #, c-format
 msgid "invalid %%u value"
 msgstr "%%u değeri geçersiz"
 
-#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21560
+#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21637
 #: config/xtensa/xtensa.c:2384
 #, c-format
 msgid "invalid %%v value"
 msgstr "%%v değeri geçersiz"
 
-#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21627
+#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21704
 #: config/xtensa/xtensa.c:2436
 #, c-format
 msgid "invalid %%x value"
 msgstr "%%x değeri geçersiz"
 
-#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21747
+#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21824
 #, fuzzy, c-format
 #| msgid "invalid punctuation %qc in constraint"
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "kısıt içindeki `%qc' işareti geçersiz"
 
-#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22282
+#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22359
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22288
+#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22365
 #, fuzzy
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr "%2$qT mutlak sınıf türündeki %1$qE ifadesi throw ifadesi içinde kullanılamaz"
 
-#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22294
+#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22371
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36572
+#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36628
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "AltiVec argümanı prototipsiz işleve aktarıldı"
 
-#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38739
+#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38795
 #, fuzzy
 #| msgid "Do not generate a single exit point for each function"
 msgid "Could not generate addis value for fusion"
 msgstr "Her işlev için tek çıkış noktası üretilmez"
 
-#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38809
+#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38865
 #, fuzzy
 #| msgid "unable to generate reloads for:"
 msgid "Unable to generate load/store offset for fusion"
 msgstr "aşağıdakiler için yeniden yüklemeler üretilemiyor:"
 
-#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38908
+#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38964
 msgid "Bad GPR fusion"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39126
+#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39182
 msgid "emit_fusion_p9_load, bad reg #1"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39172
+#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39228
 msgid "emit_fusion_p9_load, bad reg #2"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39175
+#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39231
 msgid "emit_fusion_p9_load not MEM"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39213
+#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39269
 msgid "emit_fusion_p9_store, bad reg #1"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39259
+#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39315
 msgid "emit_fusion_p9_store, bad reg #2"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39262
+#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39318
 msgid "emit_fusion_p9_store not MEM"
 msgstr ""
 
@@ -4767,14 +4767,14 @@
 #: c/gimple-parser.c:188 c/gimple-parser.c:197 c/gimple-parser.c:226
 #: c/gimple-parser.c:1375 c/gimple-parser.c:1404 c/gimple-parser.c:1484
 #: c/gimple-parser.c:1511 c/c-parser.c:3204 c/c-parser.c:9967
-#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27841
-#: cp/parser.c:28430
+#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27838
+#: cp/parser.c:28427
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "%<;%> umuluyordu"
 
 #: c/c-parser.c:2431 c/c-parser.c:7573 c/c-parser.c:8015 c/c-parser.c:8058
-#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27839 cp/parser.c:28448
+#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27836 cp/parser.c:28445
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<,%>"
@@ -4790,7 +4790,7 @@
 #: c/gimple-parser.c:821 c/gimple-parser.c:837 c/gimple-parser.c:853
 #: c/gimple-parser.c:880 c/gimple-parser.c:915 c/gimple-parser.c:1038
 #: c/gimple-parser.c:1209 c/gimple-parser.c:1220 c/gimple-parser.c:1342
-#: c/gimple-parser.c:1441 cp/parser.c:28478
+#: c/gimple-parser.c:1441 cp/parser.c:28475
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<)%>"
@@ -4799,7 +4799,7 @@
 #: c/c-parser.c:3824 c/c-parser.c:4733 c/c-parser.c:4769 c/c-parser.c:6441
 #: c/c-parser.c:8125 c/c-parser.c:8983 c/c-parser.c:9127 c/c-parser.c:11588
 #: c/c-parser.c:18220 c/c-parser.c:18222 c/gimple-parser.c:1015
-#: cp/parser.c:28442
+#: cp/parser.c:28439
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<]%>"
@@ -4816,7 +4816,7 @@
 #: c/c-parser.c:17792 c/gimple-parser.c:363 c/gimple-parser.c:811
 #: c/gimple-parser.c:873 c/gimple-parser.c:911 c/gimple-parser.c:1198
 #: c/gimple-parser.c:1339 c/gimple-parser.c:1438 c/c-parser.c:11911
-#: cp/parser.c:28433
+#: cp/parser.c:28430
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<(%>"
@@ -4824,7 +4824,7 @@
 
 #: c/c-parser.c:4903 c/c-parser.c:10310 c/c-parser.c:16212 c/c-parser.c:18449
 #: c/gimple-parser.c:141 c/gimple-parser.c:1444 c/c-parser.c:3018
-#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18155 cp/parser.c:28439
+#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18152 cp/parser.c:28436
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "%<{%> umuluyordu"
@@ -4834,14 +4834,14 @@
 #: c/c-parser.c:12351 c/c-parser.c:12493 c/c-parser.c:12864 c/c-parser.c:12957
 #: c/c-parser.c:13566 c/c-parser.c:17636 c/c-parser.c:17695
 #: c/gimple-parser.c:431 c/gimple-parser.c:1492 c/gimple-parser.c:1519
-#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28472 cp/parser.c:29597
-#: cp/parser.c:32279
+#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28469 cp/parser.c:29594
+#: cp/parser.c:32276
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<:%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.c:5974 cp/parser.c:28365
+#: c/c-parser.c:5974 cp/parser.c:28362
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<while%>"
@@ -4853,20 +4853,20 @@
 msgid "expected %<.%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30172
-#: cp/parser.c:30246
+#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30169
+#: cp/parser.c:30243
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@end%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28457
+#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28454
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<>%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28481
+#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28478
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<,%> or %<)%>"
@@ -4875,37 +4875,37 @@
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15190 c/c-parser.c:15234 c/c-parser.c:15466 c/c-parser.c:15701
 #: c/c-parser.c:17833 c/gimple-parser.c:286 c/c-parser.c:4792
-#: cp/parser.c:28460
+#: cp/parser.c:28457
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "%<=%> umuluyordu"
 
-#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28436
-#: cp/parser.c:30389
+#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28433
+#: cp/parser.c:30386
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<}%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35674
+#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35671
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<}%>"
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "%<,%> veya %<}%> umuluyordu"
 
-#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28445 cp/parser.c:31535
+#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28442 cp/parser.c:31532
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<[%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-typeck.c:7847
+#: c/c-typeck.c:7852
 #, fuzzy
 #| msgid "<anonymous>"
 msgid "(anonymous)"
 msgstr "<anonim>"
 
-#: c/gimple-parser.c:795 cp/parser.c:15791 cp/parser.c:28454
+#: c/gimple-parser.c:795 cp/parser.c:15788 cp/parser.c:28451
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<<%>"
@@ -5211,11 +5211,11 @@
 msgid "%r%s:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr ""
 
-#: cp/pt.c:1949 cp/semantics.c:5268
+#: cp/pt.c:1949 cp/semantics.c:5271
 msgid "candidates are:"
 msgstr "adaylar:"
 
-#: cp/pt.c:1951 cp/pt.c:22975
+#: cp/pt.c:1951 cp/pt.c:23053
 #, fuzzy
 #| msgid "candidate 1:"
 msgid "candidate is:"
@@ -5277,27 +5277,27 @@
 msgid "source type is not polymorphic"
 msgstr ""
 
-#: cp/typeck.c:6083 c/c-typeck.c:4261
+#: cp/typeck.c:6083 c/c-typeck.c:4266
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "tek terimli eksiye yanlış türde argüman"
 
-#: cp/typeck.c:6084 c/c-typeck.c:4248
+#: cp/typeck.c:6084 c/c-typeck.c:4253
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "tek terimli artıya yanlış türde argüman"
 
-#: cp/typeck.c:6111 c/c-typeck.c:4302
+#: cp/typeck.c:6111 c/c-typeck.c:4307
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "bit-tümler için yanlış türde argüman"
 
-#: cp/typeck.c:6128 c/c-typeck.c:4310
+#: cp/typeck.c:6128 c/c-typeck.c:4315
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "abs'a yanlış türde argüman"
 
-#: cp/typeck.c:6140 c/c-typeck.c:4322
+#: cp/typeck.c:6140 c/c-typeck.c:4327
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "mantıksal çarpım için yanlış türde argüman"
@@ -5561,67 +5561,67 @@
 msgid "Expected attribute bit name"
 msgstr "Öznitelik bit ismi umuluyordu"
 
-#: fortran/module.c:3223
+#: fortran/module.c:3225
 msgid "Expected integer string"
 msgstr "Tamsayı dizgesi umuluyordu"
 
-#: fortran/module.c:3227
+#: fortran/module.c:3229
 msgid "Error converting integer"
 msgstr "Tamsayı dönüşümünde hata"
 
-#: fortran/module.c:3249
+#: fortran/module.c:3251
 msgid "Expected real string"
 msgstr "Gerçel sayı dizgesi umuluyordu"
 
-#: fortran/module.c:3474
+#: fortran/module.c:3476
 msgid "Expected expression type"
 msgstr "İfade türü umuluyordu"
 
-#: fortran/module.c:3554
+#: fortran/module.c:3556
 msgid "Bad operator"
 msgstr "Hatalı işleç"
 
-#: fortran/module.c:3671
+#: fortran/module.c:3673
 msgid "Bad type in constant expression"
 msgstr "Sabit ifadesinde tür hatalı"
 
-#: fortran/module.c:7038
+#: fortran/module.c:7040
 msgid "Unexpected end of module"
 msgstr "Beklenmeyen modül sonu"
 
-#: fortran/parse.c:1757
+#: fortran/parse.c:1761
 msgid "arithmetic IF"
 msgstr "aritmetik IF"
 
-#: fortran/parse.c:1766
+#: fortran/parse.c:1770
 msgid "attribute declaration"
 msgstr "öznitelik bildirimi"
 
-#: fortran/parse.c:1802
+#: fortran/parse.c:1806
 msgid "data declaration"
 msgstr "veri bildirimi"
 
-#: fortran/parse.c:1820
+#: fortran/parse.c:1824
 msgid "derived type declaration"
 msgstr "türetilmiş tür bildirimi"
 
-#: fortran/parse.c:1947
+#: fortran/parse.c:1951
 msgid "block IF"
 msgstr "blok IF"
 
-#: fortran/parse.c:1956
+#: fortran/parse.c:1960
 msgid "implied END DO"
 msgstr "örtük END DO"
 
-#: fortran/parse.c:2050 fortran/resolve.c:11199
+#: fortran/parse.c:2054 fortran/resolve.c:11219
 msgid "assignment"
 msgstr "atama"
 
-#: fortran/parse.c:2053 fortran/resolve.c:11250 fortran/resolve.c:11253
+#: fortran/parse.c:2057 fortran/resolve.c:11270 fortran/resolve.c:11273
 msgid "pointer assignment"
 msgstr "gösterici ataması"
 
-#: fortran/parse.c:2071
+#: fortran/parse.c:2075
 msgid "simple IF"
 msgstr "basit IF"
 
@@ -5745,127 +5745,132 @@
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr "%%L'deki tek terimli sayısal '%s' işlecinin terimi %s"
 
-#: fortran/resolve.c:3878
+#: fortran/resolve.c:3879
+#, c-format
+msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
+msgstr ""
+
+#: fortran/resolve.c:3884
 #, fuzzy, c-format
 #| msgid "Operands of binary numeric operator '%s' at %%L are %s/%s"
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr "%%L'deki iki terimli sayısal '%s' işlecinin terimleri %s/%s"
 
-#: fortran/resolve.c:3893
+#: fortran/resolve.c:3899
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr "%%L'deki dizge ekleme işlecinin terimleri %s/%s"
 
-#: fortran/resolve.c:3926
+#: fortran/resolve.c:3932
 #, fuzzy, c-format
 #| msgid "Operands of logical operator '%s' at %%L are %s/%s"
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr "%%L'deki mantıksal '%s' işlecinin terimleri %s/%s"
 
-#: fortran/resolve.c:3949
+#: fortran/resolve.c:3955
 #, fuzzy, c-format
 #| msgid "Operand of .NOT. operator at %%L is %s"
 msgid "Operand of .not. operator at %%L is %s"
 msgstr "%%L'deki .NOT. işlecinin terimi %s"
 
-#: fortran/resolve.c:3963
+#: fortran/resolve.c:3969
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "%L'de COMPLEX nicelikler karşılaştırılamıyor"
 
-#: fortran/resolve.c:4015
+#: fortran/resolve.c:4021
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr "%%L'deki mantıksallar %s ile karşılaştırılmalı %s ile değil"
 
-#: fortran/resolve.c:4021
+#: fortran/resolve.c:4027
 #, fuzzy, c-format
 #| msgid "Operands of comparison operator '%s' at %%L are %s/%s"
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr "%%L'deki '%s' karşılaştırma işlecinin terimleri %s/%s"
 
-#: fortran/resolve.c:4034
+#: fortran/resolve.c:4040
 #, fuzzy, c-format
 #| msgid "unknown operator '%s' in %%:version-compare"
 msgid "Unknown operator %%<%s%%> at %%L; did you mean '%s'?"
 msgstr "%%:version-compare içindeki '%s' işleci bilinmiyor"
 
-#: fortran/resolve.c:4037
+#: fortran/resolve.c:4043
 #, fuzzy, c-format
 #| msgid "unknown operator '%s' in %%:version-compare"
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr "%%:version-compare içindeki '%s' işleci bilinmiyor"
 
-#: fortran/resolve.c:4040
+#: fortran/resolve.c:4046
 #, fuzzy, c-format
 #| msgid "Operand of user operator '%s' at %%L is %s"
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr "%%L'deki '%s' kullanıcı işlecinin terimi %s"
 
-#: fortran/resolve.c:4044
+#: fortran/resolve.c:4050
 #, fuzzy, c-format
 #| msgid "Operands of user operator '%s' at %%L are %s/%s"
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr "%%L'deki '%s' kullanıcı işlecinin terimleri %s/%s"
 
-#: fortran/resolve.c:4132
+#: fortran/resolve.c:4138
 #, fuzzy, c-format
 #| msgid "Inconsistent ranks for operator at %L and %L"
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "%L ve %L'de işliçler için sıralar uyumsuz"
 
-#: fortran/resolve.c:6849
+#: fortran/resolve.c:6855
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.c:6853
+#: fortran/resolve.c:6859
 #, fuzzy
 #| msgid "Perform variable tracking"
 msgid "iterator variable"
 msgstr "Değişken izleme uygulanır"
 
-#: fortran/resolve.c:6857
+#: fortran/resolve.c:6863
 #, fuzzy
 #| msgid "Step expression in DO loop at %L cannot be zero"
 msgid "Start expression in DO loop"
 msgstr "%L'de Do döngüsündeki adım ifadesi sıfır olamaz"
 
-#: fortran/resolve.c:6861
+#: fortran/resolve.c:6867
 #, fuzzy
 #| msgid "invalid expression as operand"
 msgid "End expression in DO loop"
 msgstr "terim olarak ifade geçersiz"
 
-#: fortran/resolve.c:6865
+#: fortran/resolve.c:6871
 #, fuzzy
 #| msgid "Step expression in DO loop at %L cannot be zero"
 msgid "Step expression in DO loop"
 msgstr "%L'de Do döngüsündeki adım ifadesi sıfır olamaz"
 
-#: fortran/resolve.c:7150 fortran/resolve.c:7153
+#: fortran/resolve.c:7156 fortran/resolve.c:7159
 #, fuzzy
 #| msgid "DEALLOCATE "
 msgid "DEALLOCATE object"
 msgstr "YERAÇ "
 
-#: fortran/resolve.c:7525 fortran/resolve.c:7528
+#: fortran/resolve.c:7531 fortran/resolve.c:7534
 #, fuzzy
 #| msgid "ALLOCATE "
 msgid "ALLOCATE object"
 msgstr "AYIR "
 
-#: fortran/resolve.c:7720 fortran/resolve.c:9417
+#: fortran/resolve.c:7726 fortran/resolve.c:9428
 msgid "STAT variable"
 msgstr ""
 
-#: fortran/resolve.c:7764 fortran/resolve.c:9429
+#: fortran/resolve.c:7770 fortran/resolve.c:9440
 msgid "ERRMSG variable"
 msgstr ""
 
-#: fortran/resolve.c:9219
+#: fortran/resolve.c:9230
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.c:9441
+#: fortran/resolve.c:9452
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
@@ -5898,7 +5903,7 @@
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:10154
+#: fortran/trans-expr.c:10157
 msgid "Assignment of scalar to unallocated array"
 msgstr ""
 
@@ -5907,13 +5912,13 @@
 msgid "Unequal character lengths (%ld/%ld) in %s"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:8088
+#: fortran/trans-intrinsic.c:8090
 #, fuzzy, c-format
 #| msgid "Argument of SQRT at %L has a negative value"
 msgid "Argument NCOPIES of REPEAT intrinsic is negative (its value is %ld)"
 msgstr "%L'de SQRT'nin argümanı negatif değer içeriyor"
 
-#: fortran/trans-intrinsic.c:8120
+#: fortran/trans-intrinsic.c:8122
 msgid "Argument NCOPIES of REPEAT intrinsic is too large"
 msgstr ""
 
@@ -5938,15 +5943,15 @@
 msgid "Invalid image number %d in SYNC IMAGES"
 msgstr ""
 
-#: fortran/trans-stmt.c:2180
+#: fortran/trans-stmt.c:2177
 msgid "Loop iterates infinitely"
 msgstr ""
 
-#: fortran/trans-stmt.c:2200 fortran/trans-stmt.c:2456
+#: fortran/trans-stmt.c:2197 fortran/trans-stmt.c:2453
 msgid "Loop variable has been modified"
 msgstr ""
 
-#: fortran/trans-stmt.c:2309
+#: fortran/trans-stmt.c:2306
 msgid "DO step value is zero"
 msgstr ""
 
@@ -6648,10 +6653,10 @@
 msgid "Allow dollar signs in entity names."
 msgstr "Öğe isimlerinde dolar simgesine izin verilir"
 
-#: fortran/lang.opt:485 config/alpha/alpha.opt:31 common.opt:783
-#: common.opt:985 common.opt:989 common.opt:993 common.opt:997 common.opt:1532
-#: common.opt:1588 common.opt:1712 common.opt:1716 common.opt:1946
-#: common.opt:2116 common.opt:2792
+#: fortran/lang.opt:485 config/alpha/alpha.opt:31 common.opt:649
+#: common.opt:783 common.opt:989 common.opt:993 common.opt:997 common.opt:1001
+#: common.opt:1536 common.opt:1592 common.opt:1716 common.opt:1720
+#: common.opt:1950 common.opt:2120 common.opt:2796
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr ""
 
@@ -6925,12 +6930,12 @@
 msgstr "Dışsal olarak görünür isimlere altçizgiler ekler"
 
 #: fortran/lang.opt:751 c-family/c.opt:1356 c-family/c.opt:1384
-#: c-family/c.opt:1634 config/pa/pa.opt:42 config/pa/pa.opt:70 common.opt:1154
-#: common.opt:1333 common.opt:1408 common.opt:1676 common.opt:1799
-#: common.opt:2169 common.opt:2205 common.opt:2298 common.opt:2302
-#: common.opt:2407 common.opt:2498 common.opt:2506 common.opt:2514
-#: common.opt:2522 common.opt:2623 common.opt:2675 common.opt:2755
-#: common.opt:2893 common.opt:2897 common.opt:2901 common.opt:2905
+#: c-family/c.opt:1634 config/pa/pa.opt:42 config/pa/pa.opt:70 common.opt:1158
+#: common.opt:1337 common.opt:1412 common.opt:1680 common.opt:1803
+#: common.opt:2173 common.opt:2209 common.opt:2302 common.opt:2306
+#: common.opt:2411 common.opt:2502 common.opt:2510 common.opt:2518
+#: common.opt:2526 common.opt:2627 common.opt:2679 common.opt:2759
+#: common.opt:2897 common.opt:2901 common.opt:2905 common.opt:2909
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr ""
 
@@ -6994,7 +6999,7 @@
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:220 c-family/c.opt:224
 #: c-family/c.opt:236 c-family/c.opt:1855 c-family/c.opt:1863 brig/lang.opt:39
-#: config/darwin.opt:56 common.opt:338 common.opt:341 common.opt:3046
+#: config/darwin.opt:56 common.opt:338 common.opt:341 common.opt:3050
 #, c-format
 msgid "missing filename after %qs"
 msgstr "%qs den sonra dosyaismi yok"
@@ -7768,7 +7773,7 @@
 #: c-family/c.opt:1525 c-family/c.opt:1528 c-family/c.opt:1569
 #: c-family/c.opt:1704 c-family/c.opt:1731 c-family/c.opt:1771
 #: c-family/c.opt:1802 c-family/c.opt:1806 c-family/c.opt:1822
-#: config/ia64/ia64.opt:167 config/ia64/ia64.opt:170 c-family/c-opts.c:434
+#: config/ia64/ia64.opt:167 config/ia64/ia64.opt:170 c-family/c-opts.c:432
 #, gcc-internal-format
 msgid "switch %qs is no longer supported"
 msgstr "switch %qs artık desteklenmiyor"
@@ -17283,10 +17288,6 @@
 msgid "Warn if dereferencing a NULL pointer may lead to erroneous or undefined behavior."
 msgstr ""
 
-#: common.opt:649
-msgid "Warn if the loop cannot be optimized due to nontrivial assumptions."
-msgstr "Önemsiz olmayan varsayımlardan dolayı döngü eniyilenemezse uyarır"
-
 #: common.opt:656
 msgid "Warn about some C++ One Definition Rule violations during link time optimization."
 msgstr ""
@@ -17527,2232 +17528,2232 @@
 msgid "-dumpdir <dir>\tSet the directory name to be used for dumps."
 msgstr "Dökümleme için kullanılacak dosyanın salt ismi belirtilir"
 
-#: common.opt:946
+#: common.opt:950
 msgid "The version of the C++ ABI in use."
 msgstr ""
 
-#: common.opt:950
+#: common.opt:954
 msgid "Aggressively optimize loops using language constraints."
 msgstr ""
 
-#: common.opt:954
+#: common.opt:958
 #, fuzzy
 #| msgid "Align the start of functions"
 msgid "Align the start of functions."
 msgstr "İşlevlerin başlangıcı hizalanır"
 
-#: common.opt:964
+#: common.opt:968
 #, fuzzy
 #| msgid "Align labels which are only reached by jumping"
 msgid "Align labels which are only reached by jumping."
 msgstr "Sadece atlanarak ulaşılabilen yaftalara hizalanır"
 
-#: common.opt:971
+#: common.opt:975
 #, fuzzy
 #| msgid "Align all labels"
 msgid "Align all labels."
 msgstr "Tum yaftalara hizalanır"
 
-#: common.opt:978
+#: common.opt:982
 #, fuzzy
 #| msgid "Align the start of loops"
 msgid "Align the start of loops."
 msgstr "Döngü başlangıcına hizalanır"
 
-#: common.opt:1001
+#: common.opt:1005
 #, fuzzy
 #| msgid "Select the target MCU"
 msgid "Select what to sanitize."
 msgstr "Hedef MCU ismi belirtilir"
 
-#: common.opt:1005
+#: common.opt:1009
 msgid "Select type of coverage sanitization."
 msgstr ""
 
-#: common.opt:1009
+#: common.opt:1013
 msgid "-fasan-shadow-offset=<number>\tUse custom shadow memory offset."
 msgstr ""
 
-#: common.opt:1013
+#: common.opt:1017
 msgid "-fsanitize-sections=<sec1,sec2,...>\tSanitize global variables in user-defined sections."
 msgstr ""
 
-#: common.opt:1018
+#: common.opt:1022
 msgid "After diagnosing undefined behavior attempt to continue execution."
 msgstr ""
 
-#: common.opt:1022
+#: common.opt:1026
 #, fuzzy
 #| msgid "This switch is deprecated; use -Wextra instead"
 msgid "This switch is deprecated; use -fsanitize-recover= instead."
 msgstr "Önerilmiyor; yerine -Wextra kullanın"
 
-#: common.opt:1029
+#: common.opt:1033
 msgid "Use trap instead of a library function for undefined behavior sanitization."
 msgstr ""
 
-#: common.opt:1033
+#: common.opt:1037
 #, fuzzy
 #| msgid "Generate unwind tables that are exact at each instruction boundary"
 msgid "Generate unwind tables that are exact at each instruction boundary."
 msgstr "Birbirlerini etkilemeyenlerin tablosu her komutun tam sınırında oluşturulur"
 
-#: common.opt:1037
+#: common.opt:1041
 #, fuzzy
 #| msgid "Generate isel instructions"
 msgid "Generate auto-inc/dec instructions."
 msgstr "isel komutları üretilir"
 
-#: common.opt:1041
+#: common.opt:1045
 #, fuzzy
 #| msgid "Use profiling information for branch probabilities"
 msgid "Use sample profile information for call graph node weights. The default profile file is fbdata.afdo in 'pwd'."
 msgstr "Dallanma olasılıkları için ayrımlama bilgileri kullanılır"
 
-#: common.opt:1046
+#: common.opt:1050
 #, fuzzy
 #| msgid "Use profiling information for branch probabilities"
 msgid "Use sample profile information for call graph node weights. The profile file is specified in the argument."
 msgstr "Dallanma olasılıkları için ayrımlama bilgileri kullanılır"
 
-#: common.opt:1055
+#: common.opt:1059
 #, fuzzy
 #| msgid "Generate code to check bounds before indexing arrays"
 msgid "Generate code to check bounds before indexing arrays."
 msgstr "Diziler indislenmeden önce sınırlarını sınayacak kod üretilir"
 
-#: common.opt:1059
+#: common.opt:1063
 #, fuzzy
 #| msgid "Replace add, compare, branch with branch on count register"
 msgid "Replace add, compare, branch with branch on count register."
 msgstr "Ekleme, karşılaştırma, dallanma sayaç yazmacı üzerinden dallanma ile değiştirilir"
 
-#: common.opt:1063
+#: common.opt:1067
 #, fuzzy
 #| msgid "Use profiling information for branch probabilities"
 msgid "Use profiling information for branch probabilities."
 msgstr "Dallanma olasılıkları için ayrımlama bilgileri kullanılır"
 
-#: common.opt:1067
+#: common.opt:1071
 #, fuzzy
 #| msgid "Perform branch target load optimization before prologue / epilogue threading"
 msgid "Perform branch target load optimization before prologue / epilogue threading."
 msgstr "Ön ve ard evreleme öncesi dal hedefli yük eniyilemesi uygulanır"
 
-#: common.opt:1071
+#: common.opt:1075
 #, fuzzy
 #| msgid "Perform branch target load optimization after prologue / epilogue threading"
 msgid "Perform branch target load optimization after prologue / epilogue threading."
 msgstr "Ön ve ard evreleme sonrası dal hedefli yük eniyilemesi uygulanır"
 
-#: common.opt:1075
+#: common.opt:1079
 #, fuzzy
 #| msgid "Restrict target load migration not to re-use registers in any basic block"
 msgid "Restrict target load migration not to re-use registers in any basic block."
 msgstr "Hedef yük göçü hiçbir temel bloktaki yazmaçlar yeniden kullanılmayacak şekilde sınırlanır"
 
-#: common.opt:1079
+#: common.opt:1083
 #, fuzzy
 #| msgid "Mark <register> as being preserved across functions"
 msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions."
 msgstr "<yazmaç> işlevlere karşı korunmuş olarak imlenir"
 
-#: common.opt:1083
+#: common.opt:1087
 #, fuzzy
 #| msgid "Mark <register> as being corrupted by function calls"
 msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls."
 msgstr "<yazmaç> işlev çağrıları tarafından bozulmuş olarak imlenir"
 
-#: common.opt:1090
+#: common.opt:1094
 #, fuzzy
 #| msgid "Save registers around function calls"
 msgid "Save registers around function calls."
 msgstr "İşlev çağrıları civarındaki yazmaçlar saklanır"
 
-#: common.opt:1094
+#: common.opt:1098
 #, fuzzy
 #| msgid "This switch is deprecated; use -Wextra instead"
 msgid "This switch is deprecated; do not use."
 msgstr "Önerilmiyor; yerine -Wextra kullanın"
 
-#: common.opt:1098
+#: common.opt:1102
 #, fuzzy
 #| msgid "Check the return value of new"
 msgid "Check the return value of new in C++."
 msgstr "new için dönüş değeri sınanır"
 
-#: common.opt:1102 common.opt:1106
+#: common.opt:1106 common.opt:1110
 #, fuzzy
 #| msgid "internal consistency failure"
 msgid "Perform internal consistency checkings."
 msgstr "dahili tutarlılık hatası"
 
-#: common.opt:1110
+#: common.opt:1114
 #, fuzzy
 #| msgid "Enable function profiling"
 msgid "Enable code hoisting."
 msgstr "İşlev ayrımlama etkinleştirilir"
 
-#: common.opt:1114
+#: common.opt:1118
 msgid "Looks for opportunities to reduce stack adjustments and stack references."
 msgstr ""
 
-#: common.opt:1118
+#: common.opt:1122
 #, fuzzy
 #| msgid "Do not put uninitialized globals in the common section"
 msgid "Do not put uninitialized globals in the common section."
 msgstr "İlklendirilmemiş global'ler ortak bölüme konmaz"
 
-#: common.opt:1126
+#: common.opt:1130
 msgid "-fcompare-debug[=<opts>]\tCompile with and without e.g. -gtoggle, and compare the final-insns dump."
 msgstr ""
 
-#: common.opt:1130
+#: common.opt:1134
 msgid "Run only the second compilation of -fcompare-debug."
 msgstr ""
 
-#: common.opt:1134
+#: common.opt:1138
 #, fuzzy
 #| msgid "Perform global common subexpression elimination after register allocation"
 msgid "Perform comparison elimination after register allocation has finished."
 msgstr "Global ortak alt ifade elemesi yazmaç ayırmasından sonra uygulanır"
 
-#: common.opt:1138
+#: common.opt:1142
 msgid "Do not perform optimizations increasing noticeably stack usage."
 msgstr ""
 
-#: common.opt:1142
+#: common.opt:1146
 #, fuzzy
 #| msgid "Perform a register copy-propagation optimization pass"
 msgid "Perform a register copy-propagation optimization pass."
 msgstr "Yazmaç kopyalama girişimi eniyileme geçişi uygulanır"
 
-#: common.opt:1146
+#: common.opt:1150
 #, fuzzy
 #| msgid "Perform cross-jumping optimization"
 msgid "Perform cross-jumping optimization."
 msgstr "Çapraz atlama eniyilemesi uygulanır"
 
-#: common.opt:1150
+#: common.opt:1154
 #, fuzzy
 #| msgid "When running CSE, follow jumps to their targets"
 msgid "When running CSE, follow jumps to their targets."
 msgstr "Ortak alt ifade elemesi sırasında hedeflerine dallanmalar izlenir"
 
-#: common.opt:1158
+#: common.opt:1162
 #, fuzzy
 #| msgid "Omit range reduction step when performing complex division"
 msgid "Omit range reduction step when performing complex division."
 msgstr "Karmaşık bölme sırasında aralık arttırma adımı atlanır"
 
-#: common.opt:1162
+#: common.opt:1166
 msgid "Complex multiplication and division follow Fortran rules."
 msgstr ""
 
-#: common.opt:1166
+#: common.opt:1170
 #, fuzzy
 #| msgid "Place data items into their own section"
 msgid "Place data items into their own section."
 msgstr "Veri öğelerini kendi bölümlerine yerleştirir"
 
-#: common.opt:1170
+#: common.opt:1174
 msgid "List all available debugging counters with their limits and counts."
 msgstr ""
 
-#: common.opt:1174
+#: common.opt:1178
 msgid "-fdbg-cnt=<counter>:<limit>[,<counter>:<limit>,...]\tSet the debug counter limit."
 msgstr ""
 
-#: common.opt:1178
+#: common.opt:1182
 msgid "-fdebug-prefix-map=<old>=<new> Map one directory name to another in debug information."
 msgstr ""
 
-#: common.opt:1182
+#: common.opt:1186
 msgid "-ffile-prefix-map=<old>=<new> Map one directory name to another in compilation result."
 msgstr ""
 
-#: common.opt:1186
+#: common.opt:1190
 msgid "Output .debug_types section when using DWARF v4 debuginfo."
 msgstr ""
 
-#: common.opt:1192
+#: common.opt:1196
 #, fuzzy
 #| msgid "Defer popping functions args from stack until later"
 msgid "Defer popping functions args from stack until later."
 msgstr "Yığıttan işlev argümanlarının çekilmesini erteler"
 
-#: common.opt:1196
+#: common.opt:1200
 #, fuzzy
 #| msgid "Attempt to fill delay slots of branch instructions"
 msgid "Attempt to fill delay slots of branch instructions."
 msgstr "Dallanma komutlarının gecikme yuvalarını doldurmaya çalışır"
 
-#: common.opt:1200
+#: common.opt:1204
 msgid "Delete dead instructions that may throw exceptions."
 msgstr ""
 
-#: common.opt:1204
+#: common.opt:1208
 #, fuzzy
 #| msgid "Delete useless null pointer checks"
 msgid "Delete useless null pointer checks."
 msgstr "Kullanışsız boş gösterici sınamalarını siler"
 
-#: common.opt:1208
+#: common.opt:1212
 msgid "Stream extra data to support more aggressive devirtualization in LTO local transformation mode."
 msgstr ""
 
-#: common.opt:1212
+#: common.opt:1216
 #, fuzzy
 #| msgid "Perform superblock formation via tail duplication"
 msgid "Perform speculative devirtualization."
 msgstr "Kuyruk tekrarı üzerinden süper blok oluşumu uygulanır"
 
-#: common.opt:1216
+#: common.opt:1220
 msgid "Try to convert virtual calls to direct ones."
 msgstr ""
 
-#: common.opt:1220
+#: common.opt:1224
 #, fuzzy
 #| msgid "How often to emit source location at the beginning of line-wrapped diagnostics"
 msgid "-fdiagnostics-show-location=[once|every-line]\tHow often to emit source location at the beginning of line-wrapped diagnostics."
 msgstr "Satır sarmalamalı teşhislerin başlangıcında kaynak konumunun ne sıklıkta gösterileceği belirtilir. once: bir kere, every-line: her satırda"
 
-#: common.opt:1237
+#: common.opt:1241
 msgid "Show the source line with a caret indicating the column."
 msgstr ""
 
-#: common.opt:1245
+#: common.opt:1249
 msgid "-fdiagnostics-color=[never|always|auto]\tColorize diagnostics."
 msgstr ""
 
-#: common.opt:1265
+#: common.opt:1269
 msgid "Print fix-it hints in machine-readable form."
 msgstr ""
 
-#: common.opt:1269
+#: common.opt:1273
 msgid "Print fix-it hints to stderr in unified diff format."
 msgstr ""
 
-#: common.opt:1273
+#: common.opt:1277
 #, fuzzy
 #| msgid "Amend appropriate diagnostic messages with the command line option that controls them"
 msgid "Amend appropriate diagnostic messages with the command line option that controls them."
 msgstr "İlgili teşhis iletileri onları denetleyen komut satırı seçenekleri ile iyileştirilir"
 
-#: common.opt:1277
+#: common.opt:1281
 msgid "-fdisable-[tree|rtl|ipa]-<pass>=range1+range2 disables an optimization pass."
 msgstr ""
 
-#: common.opt:1281
+#: common.opt:1285
 msgid "-fenable-[tree|rtl|ipa]-<pass>=range1+range2 enables an optimization pass."
 msgstr ""
 
-#: common.opt:1285
+#: common.opt:1289
 #, fuzzy
 #| msgid "Dump various compiler internals to a file"
 msgid "-fdump-<type>\tDump various compiler internals to a file."
 msgstr "Çeşitli derleyici iç oluşumları bir dosyaya dökümlenir"
 
-#: common.opt:1292
+#: common.opt:1296
 msgid "-fdump-final-insns=filename\tDump to filename the insns at the end of translation."
 msgstr ""
 
-#: common.opt:1296
+#: common.opt:1300
 msgid "-fdump-go-spec=filename\tWrite all declarations to file as Go code."
 msgstr ""
 
-#: common.opt:1300
+#: common.opt:1304
 #, fuzzy
 #| msgid "Suppress output of instruction numbers and line number notes in debugging dumps"
 msgid "Suppress output of addresses in debugging dumps."
 msgstr "Hata ayıklama dökümlerinde satır numarası ve komut numarası bilgilerinin çıktılanması engellenir"
 
-#: common.opt:1304
+#: common.opt:1308
 msgid "Collect and dump debug information into temporary file if ICE in C/C++ compiler occurred."
 msgstr ""
 
-#: common.opt:1309
+#: common.opt:1313
 msgid "Dump detailed information on GCC's internal representation of source code locations."
 msgstr ""
 
-#: common.opt:1313
+#: common.opt:1317
 #, fuzzy
 #| msgid "Perform loop optimizations"
 msgid "Dump optimization passes."
 msgstr "Döngü eniyilemeleri uygulanır"
 
-#: common.opt:1317
+#: common.opt:1321
 #, fuzzy
 #| msgid "Suppress output of instruction numbers and line number notes in debugging dumps"
 msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps."
 msgstr "Hata ayıklama dökümlerinde satır numarası ve komut numarası bilgilerinin çıktılanması engellenir"
 
-#: common.opt:1321
+#: common.opt:1325
 #, fuzzy
 #| msgid "Suppress output of instruction numbers and line number notes in debugging dumps"
 msgid "Suppress output of previous and next insn numbers in debugging dumps."
 msgstr "Hata ayıklama dökümlerinde satır numarası ve komut numarası bilgilerinin çıktılanması engellenir"
 
-#: common.opt:1325
+#: common.opt:1329
 msgid "Enable CFI tables via GAS assembler directives."
 msgstr ""
 
-#: common.opt:1329
+#: common.opt:1333
 #, fuzzy
 #| msgid "Perform early inlining"
 msgid "Perform early inlining."
 msgstr "Erken satıriçine alma uygulanır"
 
-#: common.opt:1337
+#: common.opt:1341
 #, fuzzy
 #| msgid "Perform Interprocedural constant propagation"
 msgid "Perform interprocedural reduction of aggregates."
 msgstr "Yordamlar arası sabit girişim uygulanır"
 
-#: common.opt:1341
+#: common.opt:1345
 #, fuzzy
 #| msgid "Perform unused type elimination in debug info"
 msgid "Perform unused symbol elimination in debug info."
 msgstr "Hata ayıklama bilgilerinde kullanılmamış tür elemesi uygulanır"
 
-#: common.opt:1345
+#: common.opt:1349
 #, fuzzy
 #| msgid "Perform unused type elimination in debug info"
 msgid "Perform unused type elimination in debug info."
 msgstr "Hata ayıklama bilgilerinde kullanılmamış tür elemesi uygulanır"
 
-#: common.opt:1349
+#: common.opt:1353
 msgid "Do not suppress C++ class debug information."
 msgstr ""
 
-#: common.opt:1353
+#: common.opt:1357
 #, fuzzy
 #| msgid "Enable exception handling"
 msgid "Enable exception handling."
 msgstr "Olağan dışılıkların yakalanması etkinleştirilir"
 
-#: common.opt:1357
+#: common.opt:1361
 #, fuzzy
 #| msgid "Perform a number of minor, expensive optimizations"
 msgid "Perform a number of minor, expensive optimizations."
 msgstr "Masraflı eniyilemelerden birkaçını uygular"
 
-#: common.opt:1361
+#: common.opt:1365
 msgid "-fexcess-precision=[fast|standard]\tSpecify handling of excess floating-point precision."
 msgstr ""
 
-#: common.opt:1364
+#: common.opt:1368
 #, fuzzy, c-format
 #| msgid "unknown demangling style '%s'"
 msgid "unknown excess precision style %qs"
 msgstr "cendereleme tarzı %s bilinmiyor"
 
-#: common.opt:1376
+#: common.opt:1380
 msgid "-fpermitted-flt-eval-methods=[c11|ts-18661]\tSpecify which values of FLT_EVAL_METHOD are permitted."
 msgstr ""
 
-#: common.opt:1379
+#: common.opt:1383
 #, c-format
 msgid "unknown specification for the set of FLT_EVAL_METHOD values to permit %qs"
 msgstr ""
 
-#: common.opt:1392
+#: common.opt:1396
 msgid "Output lto objects containing both the intermediate language and binary output."
 msgstr ""
 
-#: common.opt:1396
+#: common.opt:1400
 #, fuzzy
 #| msgid "Assume no NaNs or infinities are generated"
 msgid "Assume no NaNs or infinities are generated."
 msgstr "NaNların ya da sonsuzların üretilmediği varsayılır"
 
-#: common.opt:1400
+#: common.opt:1404
 #, fuzzy
 #| msgid "Mark <register> as being unavailable to the compiler"
 msgid "-ffixed-<register>\tMark <register> as being unavailable to the compiler."
 msgstr "<yazmaç> derleyici için elverişsiz olarak imlenir"
 
-#: common.opt:1404
+#: common.opt:1408
 #, fuzzy
 #| msgid "Don't allocate floats and doubles in extended-precision registers"
 msgid "Don't allocate floats and doubles in extended-precision registers."
 msgstr "Ek duyarlık yazmaçlarında float'lar ve double'lar ayrılmaz"
 
-#: common.opt:1412
+#: common.opt:1416
 #, fuzzy
 #| msgid "Perform Value Range Propagation on trees"
 msgid "Perform a forward propagation pass on RTL."
 msgstr "Ağaçlarda Değer Aralığı Girişimi uygulanır"
 
-#: common.opt:1416
+#: common.opt:1420
 msgid "-ffp-contract=[off|on|fast]\tPerform floating-point expression contraction."
 msgstr ""
 
-#: common.opt:1419
+#: common.opt:1423
 #, fuzzy, c-format
 #| msgid "non-floating-point argument to function %qs"
 msgid "unknown floating point contraction style %qs"
 msgstr "%qs işlevine kayan noktalı olmayan argüman"
 
-#: common.opt:1433
+#: common.opt:1437
 msgid "Allow built-in functions ceil, floor, round, trunc to raise \"inexact\" exceptions."
 msgstr ""
 
-#: common.opt:1440
+#: common.opt:1444
 #, fuzzy
 #| msgid "Allow function addresses to be held in registers"
 msgid "Allow function addresses to be held in registers."
 msgstr "Yazmaçlarda tutulan işlev adreslerine izin verilir"
 
-#: common.opt:1444
+#: common.opt:1448
 #, fuzzy
 #| msgid "Place each function into its own section"
 msgid "Place each function into its own section."
 msgstr "Her işlev kendi bölümüne yerleştirilir"
 
-#: common.opt:1448
+#: common.opt:1452
 #, fuzzy
 #| msgid "Perform global common subexpression elimination"
 msgid "Perform global common subexpression elimination."
 msgstr "Global ortak alt ifade elemesi uygulanır"
 
-#: common.opt:1452
+#: common.opt:1456
 #, fuzzy
 #| msgid "Perform enhanced load motion during global common subexpression elimination"
 msgid "Perform enhanced load motion during global common subexpression elimination."
 msgstr "Global ortak alt ifade elemesi sırasında genişletilmiş yük hareketi uygulanır"
 
-#: common.opt:1456
+#: common.opt:1460
 #, fuzzy
 #| msgid "Perform store motion after global common subexpression elimination"
 msgid "Perform store motion after global common subexpression elimination."
 msgstr "Global ortak alt ifade elemesinden sonra saklama hareketi uygulanır"
 
-#: common.opt:1460
+#: common.opt:1464
 #, fuzzy
 #| msgid "Perform redundant load after store elimination in global common subexpression"
 msgid "Perform redundant load after store elimination in global common subexpression elimination."
 msgstr "Genel ortak alt ifade içindeki saklama elemesinden sonra gereğinden fazla yük uygulanır"
 
-#: common.opt:1465
+#: common.opt:1469
 #, fuzzy
 #| msgid "Perform global common subexpression elimination after register allocation"
 msgid "Perform global common subexpression elimination after register allocation has finished."
 msgstr "Global ortak alt ifade elemesi yazmaç ayırmasından sonra uygulanır"
 
-#: common.opt:1482
+#: common.opt:1486
 msgid "-fgnat-encodings=[all|gdb|minimal]\tSelect the balance between GNAT encodings and standard DWARF emitted in the debug information"
 msgstr ""
 
-#: common.opt:1487
+#: common.opt:1491
 #, fuzzy
 #| msgid "Enable dead store elimination"
 msgid "Enable in and out of Graphite representation."
 msgstr "Ölü saklama elemesi etkin olur"
 
-#: common.opt:1491
+#: common.opt:1495
 #, fuzzy
 #| msgid "Emit call graph information"
 msgid "Enable Graphite Identity transformation."
 msgstr "Çağrı çizge bilgisi üretir"
 
-#: common.opt:1495
+#: common.opt:1499
 #, fuzzy
 #| msgid "Enable conditional moves"
 msgid "Enable hoisting adjacent loads to encourage generating conditional move instructions."
 msgstr "Koşullu taşımalar etkin olur"
 
-#: common.opt:1504
+#: common.opt:1508
 msgid "Mark all loops as parallel."
 msgstr ""
 
-#: common.opt:1508 common.opt:1516 common.opt:2587
+#: common.opt:1512 common.opt:1520 common.opt:2591
 msgid "Enable loop nest transforms.  Same as -floop-nest-optimize."
 msgstr ""
 
-#: common.opt:1512
+#: common.opt:1516
 #, fuzzy
 #| msgid "Enable loop header copying on trees"
 msgid "Enable loop interchange on trees."
 msgstr "Ağaçlarda döngü başlığı kopyalaması etkin olur"
 
-#: common.opt:1520
+#: common.opt:1524
 #, fuzzy
 #| msgid "Perform loop unrolling for all loops"
 msgid "Perform unroll-and-jam on loops."
 msgstr "Tüm döngüler tersine uygulanır"
 
-#: common.opt:1524
+#: common.opt:1528
 msgid "Enable support for GNU transactional memory."
 msgstr ""
 
-#: common.opt:1528
+#: common.opt:1532
 msgid "Use STB_GNU_UNIQUE if supported by the assembler."
 msgstr ""
 
-#: common.opt:1536
+#: common.opt:1540
 #, fuzzy
 #| msgid "Enable label alignment optimizations"
 msgid "Enable the loop nest optimizer."
 msgstr "Yafta hizalama eniyilemesi etkin olur"
 
-#: common.opt:1540
+#: common.opt:1544
 msgid "Force bitfield accesses to match their type width."
 msgstr ""
 
-#: common.opt:1544
+#: common.opt:1548
 msgid "Merge adjacent stores."
 msgstr ""
 
-#: common.opt:1548
+#: common.opt:1552
 #, fuzzy
 #| msgid "Enable guessing of branch probabilities"
 msgid "Enable guessing of branch probabilities."
 msgstr "Dallanma olasılıklarının tahmini etkinleştirilir"
 
-#: common.opt:1556
+#: common.opt:1560
 #, fuzzy
 #| msgid "Process #ident directives"
 msgid "Process #ident directives."
 msgstr "#ident yönergeleri işlenir"
 
-#: common.opt:1560
+#: common.opt:1564
 #, fuzzy
 #| msgid "Perform conversion of conditional jumps to branchless equivalents"
 msgid "Perform conversion of conditional jumps to branchless equivalents."
 msgstr "Dallanmasız karşılıklara koşullu atlama dönüşümü uygulanır"
 
-#: common.opt:1564
+#: common.opt:1568
 #, fuzzy
 #| msgid "Perform conversion of conditional jumps to conditional execution"
 msgid "Perform conversion of conditional jumps to conditional execution."
 msgstr "Koşullu çalıştırmaya koşullu atlama dönüşümü uygulanır"
 
-#: common.opt:1568
+#: common.opt:1572
 msgid "-fstack-reuse=[all|named_vars|none]\tSet stack reuse level for local variables."
 msgstr ""
 
-#: common.opt:1571
+#: common.opt:1575
 #, fuzzy, c-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown Stack Reuse Level %qs"
 msgstr "%qs makine kipi bilinmiyor"
 
-#: common.opt:1584
+#: common.opt:1588
 #, fuzzy
 #| msgid "Perform conversion of conditional jumps to branchless equivalents"
 msgid "Convert conditional jumps in innermost loops to branchless equivalents."
 msgstr "Dallanmasız karşılıklara koşullu atlama dönüşümü uygulanır"
 
-#: common.opt:1596
+#: common.opt:1600
 #, fuzzy
 #| msgid "Do not generate .size directives"
 msgid "Do not generate .size directives."
 msgstr ".size yönergeleri üretilmez"
 
-#: common.opt:1600
+#: common.opt:1604
 #, fuzzy
 #| msgid "Perform early inlining"
 msgid "Perform indirect inlining."
 msgstr "Erken satıriçine alma uygulanır"
 
-#: common.opt:1606
+#: common.opt:1610
 msgid "Enable inlining of function declared \"inline\", disabling disables all inlining."
 msgstr ""
 
-#: common.opt:1610
+#: common.opt:1614
 #, fuzzy
 #| msgid "Integrate simple functions into their callers"
 msgid "Integrate functions into their callers when code size is known not to grow."
 msgstr "Basit işlevler onları çağıranların içine gömülür"
 
-#: common.opt:1614
+#: common.opt:1618
 #, fuzzy
 #| msgid "Integrate functions called once into their callers"
 msgid "Integrate functions not declared \"inline\" into their callers when profitable."
 msgstr "İşlevler onları çağıranların içine bir defa gömülür"
 
-#: common.opt:1618
+#: common.opt:1622
 #, fuzzy
 #| msgid "Integrate functions called once into their callers"
 msgid "Integrate functions only required by their single caller."
 msgstr "İşlevler onları çağıranların içine bir defa gömülür"
 
-#: common.opt:1625
+#: common.opt:1629
 #, fuzzy
 #| msgid "Limit the size of inlined functions to <number>"
 msgid "-finline-limit=<number>\tLimit the size of inlined functions to <number>."
 msgstr "Satıriçine alınacak işlevlerin uzunluğu <sayı> ile sınırlanır"
 
-#: common.opt:1629
+#: common.opt:1633
 msgid "Inline __atomic operations when a lock free instruction sequence is available."
 msgstr ""
 
-#: common.opt:1636
+#: common.opt:1640
 msgid "-fcf-protection=[full|branch|return|none]\tInstrument functions with checks to verify jump/call/return control-flow transfer instructions have valid targets."
 msgstr ""
 
-#: common.opt:1640
+#: common.opt:1644
 #, fuzzy, c-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown Control-Flow Protection Level %qs"
 msgstr "%qs makine kipi bilinmiyor"
 
-#: common.opt:1656
+#: common.opt:1660
 #, fuzzy
 #| msgid "Instrument function entry and exit with profiling calls"
 msgid "Instrument function entry and exit with profiling calls."
 msgstr "İşlevi giriş ve çıkışı ayrımlama çağrılarıyla yapılır"
 
-#: common.opt:1660
+#: common.opt:1664
 msgid "-finstrument-functions-exclude-function-list=name,...  Do not instrument listed functions."
 msgstr ""
 
-#: common.opt:1664
+#: common.opt:1668
 msgid "-finstrument-functions-exclude-file-list=filename,...  Do not instrument functions listed in files."
 msgstr ""
 
-#: common.opt:1668
+#: common.opt:1672
 #, fuzzy
 #| msgid "Perform Interprocedural constant propagation"
 msgid "Perform interprocedural constant propagation."
 msgstr "Yordamlar arası sabit girişim uygulanır"
 
-#: common.opt:1672
+#: common.opt:1676
 #, fuzzy
 #| msgid "Perform Interprocedural constant propagation"
 msgid "Perform cloning to make Interprocedural constant propagation stronger."
 msgstr "Yordamlar arası sabit girişim uygulanır"
 
-#: common.opt:1680
+#: common.opt:1684
 #, fuzzy
 #| msgid "Perform Interprocedural constant propagation"
 msgid "Perform interprocedural bitwise constant propagation."
 msgstr "Yordamlar arası sabit girişim uygulanır"
 
-#: common.opt:1684
+#: common.opt:1688
 #, fuzzy
 #| msgid "Perform Interprocedural constant propagation"
 msgid "Perform interprocedural profile propagation."
 msgstr "Yordamlar arası sabit girişim uygulanır"
 
-#: common.opt:1688
+#: common.opt:1692
 #, fuzzy
 #| msgid "Perform Interprocedural constant propagation"
 msgid "Perform interprocedural points-to analysis."
 msgstr "Yordamlar arası sabit girişim uygulanır"
 
-#: common.opt:1692
+#: common.opt:1696
 #, fuzzy
 #| msgid "Discover pure and const functions"
 msgid "Discover pure and const functions."
 msgstr "Saf ve sabit işlevler keşfedilir"
 
-#: common.opt:1696
+#: common.opt:1700
 #, fuzzy
 #| msgid "Perform loop unrolling for all loops"
 msgid "Perform Identical Code Folding for functions and read-only variables."
 msgstr "Tüm döngüler tersine uygulanır"
 
-#: common.opt:1700
+#: common.opt:1704
 #, fuzzy
 #| msgid "Perform loop unrolling for all loops"
 msgid "Perform Identical Code Folding for functions."
 msgstr "Tüm döngüler tersine uygulanır"
 
-#: common.opt:1704
+#: common.opt:1708
 #, fuzzy
 #| msgid "Perform loop unrolling for all loops"
 msgid "Perform Identical Code Folding for variables."
 msgstr "Tüm döngüler tersine uygulanır"
 
-#: common.opt:1708
+#: common.opt:1712
 #, fuzzy
 #| msgid "Discover readonly and non addressable static variables"
 msgid "Discover readonly and non addressable static variables."
 msgstr "Salt okunur ve adreslenemeyen durağan değişkenler keşfedilir"
 
-#: common.opt:1720
+#: common.opt:1724
 #, fuzzy
 #| msgid "Perform Value Range Propagation on trees"
 msgid "Perform IPA Value Range Propagation."
 msgstr "Ağaçlarda Değer Aralığı Girişimi uygulanır"
 
-#: common.opt:1724
+#: common.opt:1728
 msgid "-fira-algorithm=[CB|priority]\tSet the used IRA algorithm."
 msgstr ""
 
-#: common.opt:1727
+#: common.opt:1731
 #, fuzzy, c-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown IRA algorithm %qs"
 msgstr "%qs makine kipi bilinmiyor"
 
-#: common.opt:1737
+#: common.opt:1741
 msgid "-fira-region=[one|all|mixed]\tSet regions for IRA."
 msgstr ""
 
-#: common.opt:1740
+#: common.opt:1744
 #, fuzzy, c-format
 #| msgid "unknown register name: %s"
 msgid "unknown IRA region %qs"
 msgstr "bilinmeyen yazmaç ismi: %s"
 
-#: common.opt:1753
+#: common.opt:1757
 msgid "Use IRA based register pressure calculation in RTL hoist optimizations."
 msgstr ""
 
-#: common.opt:1758
+#: common.opt:1762
 msgid "Use IRA based register pressure calculation in RTL loop optimizations."
 msgstr ""
 
-#: common.opt:1763
+#: common.opt:1767
 msgid "Share slots for saving different hard registers."
 msgstr ""
 
-#: common.opt:1767
+#: common.opt:1771
 msgid "Share stack slots for spilled pseudo-registers."
 msgstr ""
 
-#: common.opt:1771
+#: common.opt:1775
 msgid "-fira-verbose=<number>\tControl IRA's level of diagnostic messages."
 msgstr ""
 
-#: common.opt:1775
+#: common.opt:1779
 #, fuzzy
 #| msgid "Optimize induction variables on trees"
 msgid "Optimize induction variables on trees."
 msgstr "Ağaçlarda tümevarım değişkenleri eniyilenir"
 
-#: common.opt:1779
+#: common.opt:1783
 #, fuzzy
 #| msgid "Use jump tables for sufficiently large switch statements"
 msgid "Use jump tables for sufficiently large switch statements."
 msgstr "Yeterince büyük switch deyimleri için sıçrama tabloları kullanılır"
 
-#: common.opt:1783
+#: common.opt:1787
 #, fuzzy
 #| msgid "Generate code for functions even if they are fully inlined"
 msgid "Generate code for functions even if they are fully inlined."
 msgstr "Tamamen satıriçi olsalar bile işlevler için kod üretilir"
 
-#: common.opt:1787
+#: common.opt:1791
 #, fuzzy
 #| msgid "Generate code for functions even if they are fully inlined"
 msgid "Generate code for static functions even if they are never called."
 msgstr "Tamamen satıriçi olsalar bile işlevler için kod üretilir"
 
-#: common.opt:1791
+#: common.opt:1795
 #, fuzzy
 #| msgid "Emit static const variables even if they are not used"
 msgid "Emit static const variables even if they are not used."
 msgstr "Kullanılmamış bile olsa statik sabit değişkenler içerilir"
 
-#: common.opt:1795
+#: common.opt:1799
 #, fuzzy
 #| msgid "Give external symbols a leading underscore"
 msgid "Give external symbols a leading underscore."
 msgstr "Alt çizgi ile başlayan harici simgeler verilir"
 
-#: common.opt:1803
+#: common.opt:1807
 msgid "Do CFG-sensitive rematerialization in LRA."
 msgstr ""
 
-#: common.opt:1807
+#: common.opt:1811
 #, fuzzy
 #| msgid "Enable linker optimizations"
 msgid "Enable link-time optimization."
 msgstr "İlintileyici en iyilemesi etkinleştirilir"
 
-#: common.opt:1811
+#: common.opt:1815
 msgid "Link-time optimization with number of parallel jobs or jobserver."
 msgstr ""
 
-#: common.opt:1814
+#: common.opt:1818
 #, fuzzy, c-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown LTO partitioning model %qs"
 msgstr "%qs makine kipi bilinmiyor"
 
-#: common.opt:1833
+#: common.opt:1837
 msgid "Specify the algorithm to partition symbols and vars at linktime."
 msgstr ""
 
-#: common.opt:1838
+#: common.opt:1842
 msgid "-flto-compression-level=<number>\tUse zlib compression level <number> for IL."
 msgstr ""
 
-#: common.opt:1842
+#: common.opt:1846
 msgid "Merge C++ types using One Definition Rule."
 msgstr ""
 
-#: common.opt:1846
+#: common.opt:1850
 #, fuzzy
 #| msgid "Perform a register renaming optimization pass"
 msgid "Report various link-time optimization statistics."
 msgstr "Yazmaç isimlendirme eniyileme aşaması uygulanır"
 
-#: common.opt:1850
+#: common.opt:1854
 #, fuzzy
 #| msgid "Perform a register renaming optimization pass"
 msgid "Report various link-time optimization statistics for WPA only."
 msgstr "Yazmaç isimlendirme eniyileme aşaması uygulanır"
 
-#: common.opt:1854
+#: common.opt:1858
 #, fuzzy
 #| msgid "Set errno after built-in math functions"
 msgid "Set errno after built-in math functions."
 msgstr "Yerleşik matematik işlevlerinden sonra errno kullanılır"
 
-#: common.opt:1858
+#: common.opt:1862
 msgid "-fmax-errors=<number>\tMaximum number of errors to report."
 msgstr ""
 
-#: common.opt:1862
+#: common.opt:1866
 #, fuzzy
 #| msgid "Report on permanent memory allocation"
 msgid "Report on permanent memory allocation."
 msgstr "Ayrılan kalıcı bellek miktarı raporlanır"
 
-#: common.opt:1866
+#: common.opt:1870
 #, fuzzy
 #| msgid "Report on permanent memory allocation"
 msgid "Report on permanent memory allocation in WPA only."
 msgstr "Ayrılan kalıcı bellek miktarı raporlanır"
 
-#: common.opt:1873
+#: common.opt:1877
 #, fuzzy
 #| msgid "Attempt to merge identical constants and constant variables"
 msgid "Attempt to merge identical constants and constant variables."
 msgstr "Özdeş sabitler ve sabit değişkenleri katıştırılmaya çalışılır"
 
-#: common.opt:1877
+#: common.opt:1881
 #, fuzzy
 #| msgid "Attempt to merge identical constants across compilation units"
 msgid "Attempt to merge identical constants across compilation units."
 msgstr "Özdeş sabitler derleme birimlerine karşın katıştırılmaya çalışılır"
 
-#: common.opt:1881
+#: common.opt:1885
 #, fuzzy
 #| msgid "Attempt to merge identical constants across compilation units"
 msgid "Attempt to merge identical debug strings across compilation units."
 msgstr "Özdeş sabitler derleme birimlerine karşın katıştırılmaya çalışılır"
 
-#: common.opt:1885
+#: common.opt:1889
 #, fuzzy
 #| msgid "Limit diagnostics to <number> characters per line.  0 suppresses line-wrapping"
 msgid "-fmessage-length=<number>\tLimit diagnostics to <number> characters per line.  0 suppresses line-wrapping."
 msgstr "Teşhis iletilerinin uzunluğu her satırda <sayı> karakterle sınırlanır. 0 satır sarmalamayı engeller"
 
-#: common.opt:1889
+#: common.opt:1893
 #, fuzzy
 #| msgid "Perform SMS based modulo scheduling before the first scheduling pass"
 msgid "Perform SMS based modulo scheduling before the first scheduling pass."
 msgstr "İlk zamanlama geçişinden önce SMS tabanlı artanlı zamanlama uygular"
 
-#: common.opt:1893
+#: common.opt:1897
 #, fuzzy
 #| msgid "Perform SMS based modulo scheduling before the first scheduling pass"
 msgid "Perform SMS based modulo scheduling with register moves allowed."
 msgstr "İlk zamanlama geçişinden önce SMS tabanlı artanlı zamanlama uygular"
 
-#: common.opt:1897
+#: common.opt:1901
 #, fuzzy
 #| msgid "Move loop invariant computations out of loops"
 msgid "Move loop invariant computations out of loops."
 msgstr "Döngü ile değişmeyen hesaplamalar döngü dışına taşınır"
 
-#: common.opt:1901
+#: common.opt:1905
 #, fuzzy
 #| msgid "Enable dead store elimination"
 msgid "Use the RTL dead code elimination pass."
 msgstr "Ölü saklama elemesi etkin olur"
 
-#: common.opt:1905
+#: common.opt:1909
 #, fuzzy
 #| msgid "Enable dead store elimination"
 msgid "Use the RTL dead store elimination pass."
 msgstr "Ölü saklama elemesi etkin olur"
 
-#: common.opt:1909
+#: common.opt:1913
 #, fuzzy
 #| msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling"
 msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling."
 msgstr "Zaten artanlı zamanlamaya tabi tutulmuş döngülerde geleneksel zamanlama etkin olur/iptal edilir"
 
-#: common.opt:1913
+#: common.opt:1917
 #, fuzzy
 #| msgid "Support synchronous non-call exceptions"
 msgid "Support synchronous non-call exceptions."
 msgstr "Eşzamanlı çağrısız olağandışılıklar desteklenir"
 
-#: common.opt:1916
+#: common.opt:1920
 #, fuzzy, c-format
 #| msgid "assertion missing after %qs"
 msgid "options or targets missing after %qs"
 msgstr "%qs den sonra olumlama eksik"
 
-#: common.opt:1917
+#: common.opt:1921
 msgid "-foffload=<targets>=<options>  Specify offloading targets and options for them."
 msgstr ""
 
-#: common.opt:1921
+#: common.opt:1925
 msgid "-foffload-abi=[lp64|ilp32]     Set the ABI to use in an offload compiler."
 msgstr ""
 
-#: common.opt:1924
+#: common.opt:1928
 #, fuzzy, c-format
 #| msgid "unknown tls-model \"%s\""
 msgid "unknown offload ABI %qs"
 msgstr "\"%s\" tls-modeli bilinmiyor"
 
-#: common.opt:1934
+#: common.opt:1938
 #, fuzzy
 #| msgid "When possible do not generate stack frames"
 msgid "When possible do not generate stack frames."
 msgstr "Mümkün olduğunca yığıt çerçeveleri üretilmez"
 
-#: common.opt:1938
+#: common.opt:1942
 #, fuzzy
 #| msgid "Enable loop optimizations on tree level"
 msgid "Enable all optimization info dumps on stderr."
 msgstr "Ağaç seviyesinde döngü eniyilemeleri etkinleştirilir"
 
-#: common.opt:1942
+#: common.opt:1946
 msgid "-fopt-info[-<type>=filename]\tDump compiler optimization details."
 msgstr ""
 
-#: common.opt:1950
+#: common.opt:1954
 #, fuzzy
 #| msgid "Optimize sibling and tail recursive calls"
 msgid "Optimize sibling and tail recursive calls."
 msgstr "Kardeş ve kuyruk özyinelemeli çağrıları eniyilenir"
 
-#: common.opt:1954
+#: common.opt:1958
 #, fuzzy
 #| msgid "Perform early inlining"
 msgid "Perform partial inlining."
 msgstr "Erken satıriçine alma uygulanır"
 
-#: common.opt:1958 common.opt:1962
+#: common.opt:1962 common.opt:1966
 msgid "Report on memory allocation before interprocedural optimization."
 msgstr ""
 
-#: common.opt:1966
+#: common.opt:1970
 #, fuzzy
 #| msgid "Pack structure members together without holes"
 msgid "Pack structure members together without holes."
 msgstr "Yapı üyelerini birlikte deliksiz paketler"
 
-#: common.opt:1970
+#: common.opt:1974
 #, fuzzy
 #| msgid "Set initial maximum structure member alignment"
 msgid "-fpack-struct=<number>\tSet initial maximum structure member alignment."
 msgstr "İlk azami yapı üyesi hizalaması belirtilir"
 
-#: common.opt:1974
+#: common.opt:1978
 #, fuzzy
 #| msgid "Return small aggregates in memory, not registers"
 msgid "Return small aggregates in memory, not registers."
 msgstr "Yazmaçlardaki değil bellekteki küçük kümeler döndürülür"
 
-#: common.opt:1978
+#: common.opt:1982
 #, fuzzy
 #| msgid "Perform loop peeling"
 msgid "Perform loop peeling."
 msgstr "Döngü soyması uygulanır"
 
-#: common.opt:1982
+#: common.opt:1986
 #, fuzzy
 #| msgid "Enable machine specific peephole optimizations"
 msgid "Enable machine specific peephole optimizations."
 msgstr "Makineye özel gözlem deliği eniyilemesi etkinleştirilir"
 
-#: common.opt:1986
+#: common.opt:1990
 #, fuzzy
 #| msgid "Enable an RTL peephole pass before sched2"
 msgid "Enable an RTL peephole pass before sched2."
 msgstr "sched2 öncesi bir rtl gözlem deliği aşaması etkin olur"
 
-#: common.opt:1990
+#: common.opt:1994
 #, fuzzy
 #| msgid "Generate position-independent code if possible (large mode)"
 msgid "Generate position-independent code if possible (large mode)."
 msgstr "Mümkünse, konumdan bağımsız kod üretilir (büyük kip)"
 
-#: common.opt:1994
+#: common.opt:1998
 #, fuzzy
 #| msgid "Generate position-independent code for executables if possible (large mode)"
 msgid "Generate position-independent code for executables if possible (large mode)."
 msgstr "Mümkünse, çalıştırılabilirler için konumdan bağımsız kod üretilir (büyük kip)"
 
-#: common.opt:1998
+#: common.opt:2002
 #, fuzzy
 #| msgid "Generate position-independent code if possible (small mode)"
 msgid "Generate position-independent code if possible (small mode)."
 msgstr "Mümkünse, konumdan bağımsız kod üretilir (küçük kip)"
 
-#: common.opt:2002
+#: common.opt:2006
 #, fuzzy
 #| msgid "Generate position-independent code for executables if possible (small mode)"
 msgid "Generate position-independent code for executables if possible (small mode)."
 msgstr "Mümkünse, çalıştırılabilirler için konumdan bağımsız kod üretilir (küçük kip)"
 
-#: common.opt:2006
+#: common.opt:2010
 msgid "Use PLT for PIC calls (-fno-plt: load the address from GOT at call site)."
 msgstr ""
 
-#: common.opt:2010
+#: common.opt:2014
 #, fuzzy
 #| msgid "Specify options to GNAT"
 msgid "Specify a plugin to load."
 msgstr "GNAT'a özgü seçenekler"
 
-#: common.opt:2014
+#: common.opt:2018
 msgid "-fplugin-arg-<name>-<key>[=<value>]\tSpecify argument <key>=<value> for plugin <name>."
 msgstr ""
 
-#: common.opt:2018
+#: common.opt:2022
 #, fuzzy
 #| msgid "Enables a register move optimization"
 msgid "Run predictive commoning optimization."
 msgstr "Yazmaç taşıma eniyilemesi etkinleştirilir"
 
-#: common.opt:2022
+#: common.opt:2026
 #, fuzzy
 #| msgid "Generate prefetch instructions, if available, for arrays in loops"
 msgid "Generate prefetch instructions, if available, for arrays in loops."
 msgstr "Mümkünse, döngülerdeki diziler için önalım komutları üretilir"
 
-#: common.opt:2026
+#: common.opt:2030
 #, fuzzy
 #| msgid "Enable basic program profiling code"
 msgid "Enable basic program profiling code."
 msgstr "Temel program profil çıkarma kodu etkinleştirilir"
 
-#: common.opt:2030
+#: common.opt:2034
 #, fuzzy
 #| msgid "Generate fast indirect calls"
 msgid "Generate absolute source path names for gcov."
 msgstr "Hızlı dolaylı çağrılar üretilir"
 
-#: common.opt:2034
+#: common.opt:2038
 #, fuzzy
 #| msgid "Insert arc-based program profiling code"
 msgid "Insert arc-based program profiling code."
 msgstr "arc-tabanlı yazılım ayrımlama kodu eklenir"
 
-#: common.opt:2038
+#: common.opt:2042
 msgid "Set the top-level directory for storing the profile data. The default is 'pwd'."
 msgstr ""
 
-#: common.opt:2043
+#: common.opt:2047
 msgid "Enable correction of flow inconsistent profile data input."
 msgstr ""
 
-#: common.opt:2047
+#: common.opt:2051
 msgid "-fprofile-update=[single|atomic|prefer-atomic]\tSet the profile update method."
 msgstr ""
 
-#: common.opt:2050
+#: common.opt:2054
 #, fuzzy, c-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown profile update method %qs"
 msgstr "%qs makine kipi bilinmiyor"
 
-#: common.opt:2063
+#: common.opt:2067
 #, fuzzy
 #| msgid "Enable common options for generating profile info for profile feedback directed optimizations"
 msgid "Enable common options for generating profile info for profile feedback directed optimizations."
 msgstr "Ayrımlama geribesleme yönlendirmeli eniyilemelerin ayrımlama bilgileri üretimi için ortak seçenekler etkinleştirilir"
 
-#: common.opt:2067
+#: common.opt:2071
 #, fuzzy
 #| msgid "Enable common options for generating profile info for profile feedback directed optimizations"
 msgid "Enable common options for generating profile info for profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr "Ayrımlama geribesleme yönlendirmeli eniyilemelerin ayrımlama bilgileri üretimi için ortak seçenekler etkinleştirilir"
 
-#: common.opt:2071
+#: common.opt:2075
 #, fuzzy
 #| msgid "Enable common options for performing profile feedback directed optimizations"
 msgid "Enable common options for performing profile feedback directed optimizations."
 msgstr "Ayrımlama geribesleme yönlendirmeli eniyilemelerin uygulanması için ortak seçenekler etkinleştirilir"
 
-#: common.opt:2075
+#: common.opt:2079
 #, fuzzy
 #| msgid "Enable common options for performing profile feedback directed optimizations"
 msgid "Enable common options for performing profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr "Ayrımlama geribesleme yönlendirmeli eniyilemelerin uygulanması için ortak seçenekler etkinleştirilir"
 
-#: common.opt:2079
+#: common.opt:2083
 #, fuzzy
 #| msgid "Insert code to profile values of expressions"
 msgid "Insert code to profile values of expressions."
 msgstr "Kod, ifade ayrımlama değerlerine yerleştirilir"
 
-#: common.opt:2083
+#: common.opt:2087
 #, fuzzy
 #| msgid "internal consistency failure"
 msgid "Report on consistency of profile."
 msgstr "dahili tutarlılık hatası"
 
-#: common.opt:2087
+#: common.opt:2091
 #, fuzzy
 #| msgid "Reorder functions to improve code placement"
 msgid "Enable function reordering that improves code placement."
 msgstr "Kod yerleşimini iyileştirecek işlevleri yeniden sıralar"
 
-#: common.opt:2091
+#: common.opt:2095
 #, fuzzy
 #| msgid "Reserve space for outgoing arguments in the function prologue"
 msgid "Insert NOP instructions at each function entry."
 msgstr "İşlev önbilgisinde çıkan argümanlar için ayrılmış alan"
 
-#: common.opt:2098
+#: common.opt:2102
 #, fuzzy
 #| msgid "Make compile reproducible using <string>"
 msgid "-frandom-seed=<string>\tMake compile reproducible using <string>."
 msgstr "<dizge> kullanılarak derleme yeniden türetilebilir yapılır"
 
-#: common.opt:2108
+#: common.opt:2112
 msgid "Record gcc command line switches in the object file."
 msgstr ""
 
-#: common.opt:2112
+#: common.opt:2116
 #, fuzzy
 #| msgid "Return small aggregates in registers"
 msgid "Return small aggregates in registers."
 msgstr "Yazmaçlardaki küçük kümeler döndürülür"
 
-#: common.opt:2120
+#: common.opt:2124
 msgid "Tell DSE that the storage for a C++ object is dead when the constructor starts and when the destructor finishes."
 msgstr ""
 
-#: common.opt:2128
+#: common.opt:2132
 msgid "Relief of register pressure through live range shrinkage."
 msgstr ""
 
-#: common.opt:2132
+#: common.opt:2136
 #, fuzzy
 #| msgid "Perform a register renaming optimization pass"
 msgid "Perform a register renaming optimization pass."
 msgstr "Yazmaç isimlendirme eniyileme aşaması uygulanır"
 
-#: common.opt:2136
+#: common.opt:2140
 #, fuzzy
 #| msgid "Perform a register renaming optimization pass"
 msgid "Perform a target dependent instruction fusion optimization pass."
 msgstr "Yazmaç isimlendirme eniyileme aşaması uygulanır"
 
-#: common.opt:2140
+#: common.opt:2144
 #, fuzzy
 #| msgid "Reorder basic blocks to improve code placement"
 msgid "Reorder basic blocks to improve code placement."
 msgstr "Kod yerleşimini iyileştirecek temel blokları yeniden sıralar"
 
-#: common.opt:2144
+#: common.opt:2148
 msgid "-freorder-blocks-algorithm=[simple|stc]\tSet the used basic block reordering algorithm."
 msgstr ""
 
-#: common.opt:2147
+#: common.opt:2151
 #, fuzzy, c-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown basic block reordering algorithm %qs"
 msgstr "%qs makine kipi bilinmiyor"
 
-#: common.opt:2157
+#: common.opt:2161
 #, fuzzy
 #| msgid "Reorder basic blocks and partition into hot and cold sections"
 msgid "Reorder basic blocks and partition into hot and cold sections."
 msgstr "Temel blokları ve parçaları sıcak ve soğuk bölümler halinde yeniden sıralar"
 
-#: common.opt:2161
+#: common.opt:2165
 #, fuzzy
 #| msgid "Reorder functions to improve code placement"
 msgid "Reorder functions to improve code placement."
 msgstr "Kod yerleşimini iyileştirecek işlevleri yeniden sıralar"
 
-#: common.opt:2165
+#: common.opt:2169
 #, fuzzy
 #| msgid "Add a common subexpression elimination pass after loop optimizations"
 msgid "Add a common subexpression elimination pass after loop optimizations."
 msgstr "Döngü eniyilemesinden sonra bir ortak alt ifade elemesi aşaması eklenir"
 
-#: common.opt:2173
+#: common.opt:2177
 #, fuzzy
 #| msgid "Disable optimizations that assume default FP rounding behavior"
 msgid "Disable optimizations that assume default FP rounding behavior."
 msgstr "Kayan nokta yuvarlama davranışını öntanımlı varsayan eniyilemeler yapılmaz"
 
-#: common.opt:2177
+#: common.opt:2181
 #, fuzzy
 #| msgid "Enable scheduling across basic blocks"
 msgid "Enable scheduling across basic blocks."
 msgstr "Temel bloklar arasında zamanlama etkinleştirilir"
 
-#: common.opt:2181
+#: common.opt:2185
 #, fuzzy
 #| msgid "Set the verbosity level of the scheduler"
 msgid "Enable register pressure sensitive insn scheduling."
 msgstr "Zamanlama için ayrıntı düzeyi belirtilir"
 
-#: common.opt:2185
+#: common.opt:2189
 #, fuzzy
 #| msgid "Allow speculative motion of non-loads"
 msgid "Allow speculative motion of non-loads."
 msgstr "Yük oluşturmayanların tahmini hareketine izin verilir"
 
-#: common.opt:2189
+#: common.opt:2193
 #, fuzzy
 #| msgid "Allow speculative motion of some loads"
 msgid "Allow speculative motion of some loads."
 msgstr "Bazı yüklerin tahmini hareketine izin verilir"
 
-#: common.opt:2193
+#: common.opt:2197
 #, fuzzy
 #| msgid "Allow speculative motion of more loads"
 msgid "Allow speculative motion of more loads."
 msgstr "Fazla yüklerin tahmini hareketine izin verilir"
 
-#: common.opt:2197
+#: common.opt:2201
 #, fuzzy
 #| msgid "Set the verbosity level of the scheduler"
 msgid "-fsched-verbose=<number>\tSet the verbosity level of the scheduler."
 msgstr "Zamanlama için ayrıntı düzeyi belirtilir"
 
-#: common.opt:2201
+#: common.opt:2205
 #, fuzzy
 #| msgid "If scheduling post reload, do superblock scheduling"
 msgid "If scheduling post reload, do superblock scheduling."
 msgstr "Sonradan yeniden yükleme zamanlaması varsa süper blok zamanlaması yapılır"
 
-#: common.opt:2209
+#: common.opt:2213
 #, fuzzy
 #| msgid "Reschedule instructions before register allocation"
 msgid "Reschedule instructions before register allocation."
 msgstr "Yazmaç tahsisinden önce komutları yeniden zamanlar"
 
-#: common.opt:2213
+#: common.opt:2217
 #, fuzzy
 #| msgid "Reschedule instructions after register allocation"
 msgid "Reschedule instructions after register allocation."
 msgstr "Yazmaç tahsisinden sonra komutları yeniden zamanlar"
 
-#: common.opt:2220
+#: common.opt:2224
 msgid "Schedule instructions using selective scheduling algorithm."
 msgstr ""
 
-#: common.opt:2224
+#: common.opt:2228
 msgid "Run selective scheduling after reload."
 msgstr ""
 
-#: common.opt:2228
+#: common.opt:2232
 msgid "Run self-tests, using the given path to locate test files."
 msgstr ""
 
-#: common.opt:2232
+#: common.opt:2236
 msgid "Perform software pipelining of inner loops during selective scheduling."
 msgstr ""
 
-#: common.opt:2236
+#: common.opt:2240
 msgid "Perform software pipelining of outer loops during selective scheduling."
 msgstr ""
 
-#: common.opt:2240
+#: common.opt:2244
 msgid "Reschedule pipelined regions without pipelining."
 msgstr ""
 
-#: common.opt:2244
+#: common.opt:2248
 msgid "Allow interposing function (or variables) by ones with different semantics (or initializer) respectively by dynamic linker."
 msgstr ""
 
-#: common.opt:2250
+#: common.opt:2254
 #, fuzzy
 #| msgid "Allow premature scheduling of queued insns"
 msgid "Allow premature scheduling of queued insns."
 msgstr "Kuyruklanmış komutların erken zamanlanmasına izin verilir"
 
-#: common.opt:2254
+#: common.opt:2258
 #, fuzzy
 #| msgid "Set number of queued insns that can be prematurely scheduled"
 msgid "-fsched-stalled-insns=<number>\tSet number of queued insns that can be prematurely scheduled."
 msgstr "Erken zamanlanabilen kuyruklanmış komutların sayısı belirtilir"
 
-#: common.opt:2262
+#: common.opt:2266
 #, fuzzy
 #| msgid "Set dependence distance checking in premature scheduling of queued insns"
 msgid "Set dependence distance checking in premature scheduling of queued insns."
 msgstr "Kuyruklanmış komutların erken zamanlanmasında bağımlılık aralığı denetimi yapılır"
 
-#: common.opt:2266
+#: common.opt:2270
 #, fuzzy
 #| msgid "Set dependence distance checking in premature scheduling of queued insns"
 msgid "-fsched-stalled-insns-dep=<number>\tSet dependence distance checking in premature scheduling of queued insns."
 msgstr "Kuyruklanmış komutların erken zamanlanmasında bağımlılık aralığı denetimi yapılır"
 
-#: common.opt:2270
+#: common.opt:2274
 #, fuzzy
 #| msgid "Set the verbosity level of the scheduler"
 msgid "Enable the group heuristic in the scheduler."
 msgstr "Zamanlama için ayrıntı düzeyi belirtilir"
 
-#: common.opt:2274
+#: common.opt:2278
 #, fuzzy
 #| msgid "Set the verbosity level of the scheduler"
 msgid "Enable the critical path heuristic in the scheduler."
 msgstr "Zamanlama için ayrıntı düzeyi belirtilir"
 
-#: common.opt:2278
+#: common.opt:2282
 #, fuzzy
 #| msgid "Set the verbosity level of the scheduler"
 msgid "Enable the speculative instruction heuristic in the scheduler."
 msgstr "Zamanlama için ayrıntı düzeyi belirtilir"
 
-#: common.opt:2282
+#: common.opt:2286
 #, fuzzy
 #| msgid "Set the verbosity level of the scheduler"
 msgid "Enable the rank heuristic in the scheduler."
 msgstr "Zamanlama için ayrıntı düzeyi belirtilir"
 
-#: common.opt:2286
+#: common.opt:2290
 #, fuzzy
 #| msgid "Set the verbosity level of the scheduler"
 msgid "Enable the last instruction heuristic in the scheduler."
 msgstr "Zamanlama için ayrıntı düzeyi belirtilir"
 
-#: common.opt:2290
+#: common.opt:2294
 #, fuzzy
 #| msgid "Set the verbosity level of the scheduler"
 msgid "Enable the dependent count heuristic in the scheduler."
 msgstr "Zamanlama için ayrıntı düzeyi belirtilir"
 
-#: common.opt:2294
+#: common.opt:2298
 msgid "Access data in the same section from shared anchor points."
 msgstr ""
 
-#: common.opt:2306
+#: common.opt:2310
 msgid "Turn on Redundant Extensions Elimination pass."
 msgstr ""
 
-#: common.opt:2310
+#: common.opt:2314
 #, fuzzy
 #| msgid "Show column numbers in diagnostics, when available.  Default on"
 msgid "Show column numbers in diagnostics, when available.  Default on."
 msgstr "Mümkünse, teşhiste sütun numaralarını gösterir. Öntanımlı"
 
-#: common.opt:2314
+#: common.opt:2318
 msgid "Emit function prologues only before parts of the function that need it, rather than at the top of the function."
 msgstr ""
 
-#: common.opt:2319
+#: common.opt:2323
 msgid "Shrink-wrap parts of the prologue and epilogue separately."
 msgstr ""
 
-#: common.opt:2323
+#: common.opt:2327
 #, fuzzy
 #| msgid "Disable optimizations observable by IEEE signaling NaNs"
 msgid "Disable optimizations observable by IEEE signaling NaNs."
 msgstr "IEEE sinyalleme NaNları tarafından farkedilebilen eniyilemeler iptal edilir"
 
-#: common.opt:2327
+#: common.opt:2331
 msgid "Disable floating point optimizations that ignore the IEEE signedness of zero."
 msgstr ""
 
-#: common.opt:2331
+#: common.opt:2335
 #, fuzzy
 #| msgid "Convert floating point constants to single precision constants"
 msgid "Convert floating point constants to single precision constants."
 msgstr "Kayan noktalı sabitler tek duyarlıklı sabitlere dönüştürülür"
 
-#: common.opt:2335
+#: common.opt:2339
 #, fuzzy
 #| msgid "Split lifetimes of induction variables when loops are unrolled"
 msgid "Split lifetimes of induction variables when loops are unrolled."
 msgstr "Döngüler geri sarılırken tümevarım ömrü bölünür"
 
-#: common.opt:2339
+#: common.opt:2343
 #, fuzzy
 #| msgid "Generate APCS conformant stack frames"
 msgid "Generate discontiguous stack frames."
 msgstr "APCS uyumlu yığıt çerçeveleri üretilir"
 
-#: common.opt:2343
+#: common.opt:2347
 msgid "Split wide types into independent registers."
 msgstr ""
 
-#: common.opt:2347
+#: common.opt:2351
 #, fuzzy
 #| msgid "Enable copy propagation on trees"
 msgid "Enable backward propagation of use properties at the SSA level."
 msgstr "Ağaçlarda kopyalama girişimi etkinleştirilir"
 
-#: common.opt:2351
+#: common.opt:2355
 msgid "Optimize conditional patterns using SSA PHI nodes."
 msgstr ""
 
-#: common.opt:2355
+#: common.opt:2359
 msgid "Optimize amount of stdarg registers saved to stack at start of function."
 msgstr ""
 
-#: common.opt:2359
+#: common.opt:2363
 #, fuzzy
 #| msgid "Apply variable expansion when loops are unrolled"
 msgid "Apply variable expansion when loops are unrolled."
 msgstr "Döngüler geri sarılırken değişken yorumlaması uygulanır"
 
-#: common.opt:2363
+#: common.opt:2367
 #, fuzzy
 #| msgid "Insert stack checking code into the program"
 msgid "-fstack-check=[no|generic|specific]\tInsert stack checking code into the program."
 msgstr "Programa yığıt sınama kodu yerleştirilir"
 
-#: common.opt:2367
+#: common.opt:2371
 #, fuzzy
 #| msgid "Insert stack checking code into the program"
 msgid "Insert stack checking code into the program.  Same as -fstack-check=specific."
 msgstr "Programa yığıt sınama kodu yerleştirilir"
 
-#: common.opt:2371
+#: common.opt:2375
 msgid "Insert code to probe each page of stack space as it is allocated to protect from stack-clash style attacks."
 msgstr ""
 
-#: common.opt:2379
+#: common.opt:2383
 #, fuzzy
 #| msgid "Trap if the stack goes past <register>"
 msgid "-fstack-limit-register=<register>\tTrap if the stack goes past <register>."
 msgstr "Yığıt <yazmaç> geçmişine giderse yakalanır"
 
-#: common.opt:2383
+#: common.opt:2387
 #, fuzzy
 #| msgid "Trap if the stack goes past symbol <name>"
 msgid "-fstack-limit-symbol=<name>\tTrap if the stack goes past symbol <name>."
 msgstr "Yığıt <isim> simgesinin geçmişine giderse yakalanır"
 
-#: common.opt:2387
+#: common.opt:2391
 #, fuzzy
 #| msgid "Use propolice as a stack protection method"
 msgid "Use propolice as a stack protection method."
 msgstr "Yığıt koruma yöntemi olarak propolice kullanılır"
 
-#: common.opt:2391
+#: common.opt:2395
 #, fuzzy
 #| msgid "Use a stack protection method for every function"
 msgid "Use a stack protection method for every function."
 msgstr "Her işlev için bir yığıt koruma yöntemi kullanılır"
 
-#: common.opt:2395
+#: common.opt:2399
 #, fuzzy
 #| msgid "Use a stack protection method for every function"
 msgid "Use a smart stack protection method for certain functions."
 msgstr "Her işlev için bir yığıt koruma yöntemi kullanılır"
 
-#: common.opt:2399
+#: common.opt:2403
 #, fuzzy
 #| msgid "Use a stack protection method for every function"
 msgid "Use stack protection method only for functions with the stack_protect attribute."
 msgstr "Her işlev için bir yığıt koruma yöntemi kullanılır"
 
-#: common.opt:2403
+#: common.opt:2407
 #, fuzzy
 #| msgid "Reuse r30 on a per function basis"
 msgid "Output stack usage information on a per-function basis."
 msgstr "Her işlev için r30 yeniden kullanılır"
 
-#: common.opt:2415
+#: common.opt:2419
 #, fuzzy
 #| msgid "Assume strict aliasing rules apply"
 msgid "Assume strict aliasing rules apply."
 msgstr "Sıkı takma ad kuralları uygulanacağı varsayılır"
 
-#: common.opt:2419
+#: common.opt:2423
 #, fuzzy
 #| msgid "Treat missing header files as generated files"
 msgid "Treat signed overflow as undefined.  Negated as -fwrapv -fwrapv-pointer."
 msgstr "Kayıp başlık dosyaları üretilen dosyalar olarak ele alınır"
 
-#: common.opt:2423
+#: common.opt:2427
 msgid "Implement __atomic operations via libcalls to legacy __sync functions."
 msgstr ""
 
-#: common.opt:2427
+#: common.opt:2431
 #, fuzzy
 #| msgid "Check for syntax errors, then stop"
 msgid "Check for syntax errors, then stop."
 msgstr "Sözdizimi denetimi yaptıktan sonra durur"
 
-#: common.opt:2431
+#: common.opt:2435
 #, fuzzy
 #| msgid "Create data files needed by \"gcov\""
 msgid "Create data files needed by \"gcov\"."
 msgstr "\"gcov\" için gereken veri dosyaları oluşturulur"
 
-#: common.opt:2435
+#: common.opt:2439
 #, fuzzy
 #| msgid "Perform jump threading optimizations"
 msgid "Perform jump threading optimizations."
 msgstr "Atlama evreleme eniyilemesi uygulanır"
 
-#: common.opt:2439
+#: common.opt:2443
 #, fuzzy
 #| msgid "Report the time taken by each compiler pass"
 msgid "Report the time taken by each compiler pass."
 msgstr "Her derleme aşaması için harcanan zaman raporlanır"
 
-#: common.opt:2443
+#: common.opt:2447
 msgid "Record times taken by sub-phases separately."
 msgstr ""
 
-#: common.opt:2447
+#: common.opt:2451
 #, fuzzy
 #| msgid "Set the default thread-local storage code generation model"
 msgid "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tSet the default thread-local storage code generation model."
 msgstr "Öntanımlı yerel-evreli saklama kodu üretim modeli belirtilir"
 
-#: common.opt:2450
+#: common.opt:2454
 #, fuzzy, c-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown TLS model %qs"
 msgstr "%qs makine kipi bilinmiyor"
 
-#: common.opt:2466
+#: common.opt:2470
 msgid "Reorder top level functions, variables, and asms."
 msgstr ""
 
-#: common.opt:2470
+#: common.opt:2474
 #, fuzzy
 #| msgid "Perform superblock formation via tail duplication"
 msgid "Perform superblock formation via tail duplication."
 msgstr "Kuyruk tekrarı üzerinden süper blok oluşumu uygulanır"
 
-#: common.opt:2474
+#: common.opt:2478
 msgid "For targets that normally need trampolines for nested functions, always generate them instead of using descriptors."
 msgstr ""
 
-#: common.opt:2482
+#: common.opt:2486
 #, fuzzy
 #| msgid "Assume floating-point operations can trap"
 msgid "Assume floating-point operations can trap."
 msgstr "Kayan nokta işlemlerinin yakalanabileceği varsayılır"
 
-#: common.opt:2486
+#: common.opt:2490
 #, fuzzy
 #| msgid "Trap for signed overflow in addition, subtraction and multiplication"
 msgid "Trap for signed overflow in addition, subtraction and multiplication."
 msgstr "Toplama, çıkartma, çarpmada signed taşması için kapan kurulur"
 
-#: common.opt:2490
+#: common.opt:2494
 #, fuzzy
 #| msgid "Enable SSA-CCP optimization on trees"
 msgid "Enable SSA-CCP optimization on trees."
 msgstr "Ağaçlarda SSA-CCP eniyilemesi etkinleştirilir"
 
-#: common.opt:2494
+#: common.opt:2498
 #, fuzzy
 #| msgid "Enable SSA-CCP optimization on trees"
 msgid "Enable SSA-BIT-CCP optimization on trees."
 msgstr "Ağaçlarda SSA-CCP eniyilemesi etkinleştirilir"
 
-#: common.opt:2502
+#: common.opt:2506
 #, fuzzy
 #| msgid "Enable loop header copying on trees"
 msgid "Enable loop header copying on trees."
 msgstr "Ağaçlarda döngü başlığı kopyalaması etkin olur"
 
-#: common.opt:2510
+#: common.opt:2514
 #, fuzzy
 #| msgid "Enable SSA code sinking on trees"
 msgid "Enable SSA coalescing of user variables."
 msgstr "Ağaçlarda SSA kod soğurumu etkinleştirilir"
 
-#: common.opt:2518
+#: common.opt:2522
 #, fuzzy
 #| msgid "Enable copy propagation on trees"
 msgid "Enable copy propagation on trees."
 msgstr "Ağaçlarda kopyalama girişimi etkinleştirilir"
 
-#: common.opt:2526
+#: common.opt:2530
 #, fuzzy
 #| msgid "Perform conversion of conditional jumps to conditional execution"
 msgid "Transform condition stores into unconditional ones."
 msgstr "Koşullu çalıştırmaya koşullu atlama dönüşümü uygulanır"
 
-#: common.opt:2530
+#: common.opt:2534
 #, fuzzy
 #| msgid "Perform conversion of conditional jumps to conditional execution"
 msgid "Perform conversions of switch initializations."
 msgstr "Koşullu çalıştırmaya koşullu atlama dönüşümü uygulanır"
 
-#: common.opt:2534
+#: common.opt:2538
 #, fuzzy
 #| msgid "Enable SSA dead code elimination optimization on trees"
 msgid "Enable SSA dead code elimination optimization on trees."
 msgstr "Ağaçlarda SSA ölü kod eleme eniyilemesi etkin olur"
 
-#: common.opt:2538
+#: common.opt:2542
 #, fuzzy
 #| msgid "Enable dominator optimizations"
 msgid "Enable dominator optimizations."
 msgstr "Baskınlık eniyilemeleri etkin olur"
 
-#: common.opt:2542
+#: common.opt:2546
 #, fuzzy
 #| msgid "Enable loop header copying on trees"
 msgid "Enable tail merging on trees."
 msgstr "Ağaçlarda döngü başlığı kopyalaması etkin olur"
 
-#: common.opt:2546
+#: common.opt:2550
 #, fuzzy
 #| msgid "Enable dead store elimination"
 msgid "Enable dead store elimination."
 msgstr "Ölü saklama elemesi etkin olur"
 
-#: common.opt:2550
+#: common.opt:2554
 #, fuzzy
 #| msgid "Enable copy propagation on trees"
 msgid "Enable forward propagation on trees."
 msgstr "Ağaçlarda kopyalama girişimi etkinleştirilir"
 
-#: common.opt:2554
+#: common.opt:2558
 #, fuzzy
 #| msgid "Enable Full Redundancy Elimination (FRE) on trees"
 msgid "Enable Full Redundancy Elimination (FRE) on trees."
 msgstr "Ağaçlarda Tam Artıklık Elemesi (TAE) etkin olur"
 
-#: common.opt:2558
+#: common.opt:2562
 #, fuzzy
 #| msgid "Enable SSA-CCP optimization on trees"
 msgid "Enable string length optimizations on trees."
 msgstr "Ağaçlarda SSA-CCP eniyilemesi etkinleştirilir"
 
-#: common.opt:2562
+#: common.opt:2566
 msgid "Detect paths that trigger erroneous or undefined behavior due to dereferencing a null pointer.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
-#: common.opt:2568
+#: common.opt:2572
 msgid "Detect paths that trigger erroneous or undefined behavior due to a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
-#: common.opt:2575
+#: common.opt:2579
 #, fuzzy
 #| msgid "Enable loop vectorization on trees"
 msgid "Enable loop distribution on trees."
 msgstr "Ağaçlarda döngü vektörleştirimi etkin olur"
 
-#: common.opt:2579
+#: common.opt:2583
 #, fuzzy
 #| msgid "Enable loop vectorization on trees"
 msgid "Enable loop distribution for patterns transformed into a library call."
 msgstr "Ağaçlarda döngü vektörleştirimi etkin olur"
 
-#: common.opt:2583
+#: common.opt:2587
 #, fuzzy
 #| msgid "Enable loop invariant motion on trees"
 msgid "Enable loop invariant motion on trees."
 msgstr "Ağaçlarda döngü içinde değişmez hareket etkin olur"
 
-#: common.opt:2591
+#: common.opt:2595
 #, fuzzy
 #| msgid "Create canonical induction variables in loops"
 msgid "Create canonical induction variables in loops."
 msgstr "Döngülerde meşru tümevarım değişkenleri oluşturulur"
 
-#: common.opt:2595
+#: common.opt:2599
 #, fuzzy
 #| msgid "Enable loop optimizations on tree level"
 msgid "Enable loop optimizations on tree level."
 msgstr "Ağaç seviyesinde döngü eniyilemeleri etkinleştirilir"
 
-#: common.opt:2599
+#: common.opt:2603
 #, fuzzy
 #| msgid "Enable automatic template instantiation"
 msgid "-ftree-parallelize-loops=<number>\tEnable automatic parallelization of loops."
 msgstr "Özdevinimli şablon örneklenimi etkin olur"
 
-#: common.opt:2603
+#: common.opt:2607
 #, fuzzy
 #| msgid "Enable conditional moves"
 msgid "Enable hoisting loads from conditional pointers."
 msgstr "Koşullu taşımalar etkin olur"
 
-#: common.opt:2607
+#: common.opt:2611
 #, fuzzy
 #| msgid "Enable SSA-PRE optimization on trees"
 msgid "Enable SSA-PRE optimization on trees."
 msgstr "Ağaçlarda SSA-PRE eniyilemesi etkinleştirilir"
 
-#: common.opt:2611
+#: common.opt:2615
 msgid "In SSA-PRE optimization on trees, enable partial-partial redundancy elimination."
 msgstr ""
 
-#: common.opt:2615
+#: common.opt:2619
 msgid "Perform function-local points-to analysis on trees."
 msgstr ""
 
-#: common.opt:2619
+#: common.opt:2623
 #, fuzzy
 #| msgid "Enable loop optimizations on tree level"
 msgid "Enable reassociation on tree level."
 msgstr "Ağaç seviyesinde döngü eniyilemeleri etkinleştirilir"
 
-#: common.opt:2627
+#: common.opt:2631
 #, fuzzy
 #| msgid "Enable SSA code sinking on trees"
 msgid "Enable SSA code sinking on trees."
 msgstr "Ağaçlarda SSA kod soğurumu etkinleştirilir"
 
-#: common.opt:2631
+#: common.opt:2635
 #, fuzzy
 #| msgid "Perform strength reduction optimizations"
 msgid "Perform straight-line strength reduction."
 msgstr "Güç azaltma eniyilemesi uygulanır"
 
-#: common.opt:2635
+#: common.opt:2639
 #, fuzzy
 #| msgid "Perform scalar replacement of aggregates"
 msgid "Perform scalar replacement of aggregates."
 msgstr "Ortak değerlerde sabit yer değiştirmesi yapılır"
 
-#: common.opt:2639
+#: common.opt:2643
 #, fuzzy
 #| msgid "Replace temporary expressions in the SSA->normal pass"
 msgid "Replace temporary expressions in the SSA->normal pass."
 msgstr "Geçici ifadeler SSA->normal geçişine yerleştirilir"
 
-#: common.opt:2643
+#: common.opt:2647
 #, fuzzy
 #| msgid "Perform live range splitting during the SSA->normal pass"
 msgid "Perform live range splitting during the SSA->normal pass."
 msgstr "SSA->normal aşamasında canlı aralık ayırması yapılır"
 
-#: common.opt:2647
+#: common.opt:2651
 #, fuzzy
 #| msgid "Perform Value Range Propagation on trees"
 msgid "Perform Value Range Propagation on trees."
 msgstr "Ağaçlarda Değer Aralığı Girişimi uygulanır"
 
-#: common.opt:2651
+#: common.opt:2655
 msgid "Split paths leading to loop backedges."
 msgstr ""
 
-#: common.opt:2655
+#: common.opt:2659
 msgid "Assume common declarations may be overridden with ones with a larger trailing array."
 msgstr ""
 
-#: common.opt:2660
+#: common.opt:2664
 #, fuzzy
 #| msgid "Compile whole compilation unit at a time"
 msgid "Compile whole compilation unit at a time."
 msgstr "Derleme biriminin tamamı bir defada derlenir"
 
-#: common.opt:2664
+#: common.opt:2668
 #, fuzzy
 #| msgid "Perform loop unrolling when iteration count is known"
 msgid "Perform loop unrolling when iteration count is known."
 msgstr "Yineleme sayısı bilindiğinde döngü tersine uygulanır"
 
-#: common.opt:2668
+#: common.opt:2672
 #, fuzzy
 #| msgid "Perform loop unrolling for all loops"
 msgid "Perform loop unrolling for all loops."
 msgstr "Tüm döngüler tersine uygulanır"
 
-#: common.opt:2679
+#: common.opt:2683
 msgid "Allow optimization for floating-point arithmetic which may change the result of the operation due to rounding."
 msgstr ""
 
-#: common.opt:2684
+#: common.opt:2688
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr ""
 
-#: common.opt:2692
+#: common.opt:2696
 #, fuzzy
 #| msgid "Allow math optimizations that may violate IEEE or ISO standards"
 msgid "Allow math optimizations that may violate IEEE or ISO standards."
 msgstr "IEEE veya ISO standartlarını bozabilen matematiksel eniyilemelere izin verilir"
 
-#: common.opt:2696
+#: common.opt:2700
 #, fuzzy
 #| msgid "Perform loop unswitching"
 msgid "Perform loop unswitching."
 msgstr "Döngü anahtarlamaması uygulanır"
 
-#: common.opt:2700
+#: common.opt:2704
 #, fuzzy
 #| msgid "Perform loop peeling"
 msgid "Perform loop splitting."
 msgstr "Döngü soyması uygulanır"
 
-#: common.opt:2704
+#: common.opt:2708
 #, fuzzy
 #| msgid "Just generate unwind tables for exception handling"
 msgid "Just generate unwind tables for exception handling."
 msgstr "Olağandışılıkların yakalanması için birbirlerini etkilemeyenlerin tablosu oluşturulur"
 
-#: common.opt:2708
+#: common.opt:2712
 msgid "Use the bfd linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2712
+#: common.opt:2716
 msgid "Use the gold linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2724
+#: common.opt:2728
 #, fuzzy
 #| msgid "Perform variable tracking"
 msgid "Perform variable tracking."
 msgstr "Değişken izleme uygulanır"
 
-#: common.opt:2732
+#: common.opt:2736
 #, fuzzy
 #| msgid "Perform variable tracking"
 msgid "Perform variable tracking by annotating assignments."
 msgstr "Değişken izleme uygulanır"
 
-#: common.opt:2738
+#: common.opt:2742
 msgid "Toggle -fvar-tracking-assignments."
 msgstr ""
 
-#: common.opt:2746
+#: common.opt:2750
 #, fuzzy
 #| msgid "Perform variable tracking"
 msgid "Perform variable tracking and also tag variables that are uninitialized."
 msgstr "Değişken izleme uygulanır"
 
-#: common.opt:2751
+#: common.opt:2755
 #, fuzzy
 #| msgid "Enable loop vectorization on trees"
 msgid "Enable vectorization on trees."
 msgstr "Ağaçlarda döngü vektörleştirimi etkin olur"
 
-#: common.opt:2759
+#: common.opt:2763
 #, fuzzy
 #| msgid "Enable loop vectorization on trees"
 msgid "Enable loop vectorization on trees."
 msgstr "Ağaçlarda döngü vektörleştirimi etkin olur"
 
-#: common.opt:2763
+#: common.opt:2767
 #, fuzzy
 #| msgid "Enable loop vectorization on trees"
 msgid "Enable basic block vectorization (SLP) on trees."
 msgstr "Ağaçlarda döngü vektörleştirimi etkin olur"
 
-#: common.opt:2767
+#: common.opt:2771
 msgid "Specifies the cost model for vectorization. -fvect-cost-model=[unlimited|dynamic|cheap]\tSpecifies the cost model for vectorization."
 msgstr ""
 
-#: common.opt:2772
+#: common.opt:2776
 msgid "-fsimd-cost-model=[unlimited|dynamic|cheap]\tSpecifies the vectorization cost model for code marked with a simd directive."
 msgstr ""
 
-#: common.opt:2775
+#: common.opt:2779
 #, fuzzy, c-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown vectorizer cost model %qs"
 msgstr "%qs makine kipi bilinmiyor"
 
-#: common.opt:2788
+#: common.opt:2792
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr ""
 
-#: common.opt:2796
+#: common.opt:2800
 #, fuzzy
 #| msgid "Enable copy propagation for stores and loads"
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr "Saklama ve yüklemelerde kopyalama girişimi etkinleştirilir"
 
-#: common.opt:2806
+#: common.opt:2810
 #, fuzzy
 #| msgid "Add extra commentary to assembler output"
 msgid "Add extra commentary to assembler output."
 msgstr "Çevirici çıktısına fazladan açıklama ekler"
 
-#: common.opt:2810
+#: common.opt:2814
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility."
 msgstr ""
 
-#: common.opt:2813
+#: common.opt:2817
 #, fuzzy, c-format
 #| msgid "unrecognized visibility value \"%s\""
 msgid "unrecognized visibility value %qs"
 msgstr "visibility değeri \"%s\" tanınmıyor"
 
-#: common.opt:2829
+#: common.opt:2833
 msgid "Validate vtable pointers before using them."
 msgstr ""
 
-#: common.opt:2832
+#: common.opt:2836
 #, fuzzy, c-format
 #| msgid "(near initialization for %qs)"
 msgid "unknown vtable verify initialization priority %qs"
 msgstr "(%qs için near ilklendirme)"
 
-#: common.opt:2845
+#: common.opt:2849
 msgid "Output vtable verification counters."
 msgstr ""
 
-#: common.opt:2849
+#: common.opt:2853
 msgid "Output vtable verification pointer sets information."
 msgstr ""
 
-#: common.opt:2853
+#: common.opt:2857
 #, fuzzy
 #| msgid "Use expression value profiles in optimizations"
 msgid "Use expression value profiles in optimizations."
 msgstr "Eniyilemelerde ifade değeri ayrımlaması kullanılır"
 
-#: common.opt:2857
+#: common.opt:2861
 #, fuzzy
 #| msgid "Construct webs and split unrelated uses of single variable"
 msgid "Construct webs and split unrelated uses of single variable."
 msgstr "Izgara oluşturur ve tek bir değişkenin ilgisiz kullanımlarını ayırır"
 
-#: common.opt:2861
+#: common.opt:2865
 #, fuzzy
 #| msgid "Enable SSA dead code elimination optimization on trees"
 msgid "Enable conditional dead code elimination for builtin calls."
 msgstr "Ağaçlarda SSA ölü kod eleme eniyilemesi etkin olur"
 
-#: common.opt:2865
+#: common.opt:2869
 #, fuzzy
 #| msgid "Perform whole program optimizations"
 msgid "Perform whole program optimizations."
 msgstr "Bütün yazılım eniyilemeleri uygulanır"
 
-#: common.opt:2869
+#: common.opt:2873
 #, fuzzy
 #| msgid "Assume signed arithmetic overflow wraps around"
 msgid "Assume pointer overflow wraps around."
 msgstr "İşaretli aritmetik taşmaların olurunun bulunduğu varsayılır"
 
-#: common.opt:2873
+#: common.opt:2877
 #, fuzzy
 #| msgid "Assume signed arithmetic overflow wraps around"
 msgid "Assume signed arithmetic overflow wraps around."
 msgstr "İşaretli aritmetik taşmaların olurunun bulunduğu varsayılır"
 
-#: common.opt:2877
+#: common.opt:2881
 #, fuzzy
 #| msgid "Put zero initialized data in the bss section"
 msgid "Put zero initialized data in the bss section."
 msgstr "bss bölümüne sıfır ilklendirmeli veri yerleştirilir"
 
-#: common.opt:2881
+#: common.opt:2885
 #, fuzzy
 #| msgid "Generate debug information in default format"
 msgid "Generate debug information in default format."
 msgstr "Öntanımlı biçimde hata ayıklama bilgisi üretir"
 
-#: common.opt:2885
+#: common.opt:2889
 msgid "Assume assembler support for (DWARF2+) .loc directives"
 msgstr ""
 
-#: common.opt:2889
+#: common.opt:2893
 msgid "Assume assembler support for view in (DWARF2+) .loc directives"
 msgstr ""
 
-#: common.opt:2892 common.opt:2896 common.opt:2900 common.opt:2904
+#: common.opt:2896 common.opt:2900 common.opt:2904 common.opt:2908
 #, fuzzy, c-format
 #| msgid "switch %qs is no longer supported"
 msgid "switch %qs no longer supported"
 msgstr "switch %qs artık desteklenmiyor"
 
-#: common.opt:2909
+#: common.opt:2913
 msgid "Record DW_AT_decl_column and DW_AT_call_column in DWARF."
 msgstr ""
 
-#: common.opt:2913
+#: common.opt:2917
 #, fuzzy
 #| msgid "Generate debug information in default format"
 msgid "Generate debug information in default version of DWARF format."
 msgstr "Öntanımlı biçimde hata ayıklama bilgisi üretir"
 
-#: common.opt:2917
+#: common.opt:2921
 #, fuzzy
 #| msgid "Generate debug information in DWARF v2 format"
 msgid "Generate debug information in DWARF v2 (or later) format."
 msgstr "DWARF v2 biçiminde hata ayıklama bilgisi üretir"
 
-#: common.opt:2921
+#: common.opt:2925
 #, fuzzy
 #| msgid "Generate debug information in default extended format"
 msgid "Generate debug information in default extended format."
 msgstr "Öntanımlı gelişmiş biçimde hata ayıklama bilgisi üretir"
 
-#: common.opt:2925
+#: common.opt:2929
 #, fuzzy
 #| msgid "Generate a single exit point for each function"
 msgid "Generate extended entry point information for inlined functions"
 msgstr "Her işlev için tek çıkış noktası üretilir"
 
-#: common.opt:2929
+#: common.opt:2933
 msgid "Compute locview reset points based on insn length estimates"
 msgstr ""
 
-#: common.opt:2937
+#: common.opt:2941
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:2941
+#: common.opt:2945
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:2945
+#: common.opt:2949
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr ""
 
-#: common.opt:2949
+#: common.opt:2953
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr ""
 
-#: common.opt:2953
+#: common.opt:2957
 #, fuzzy
 #| msgid "Generate debug information in default format"
 msgid "Generate debug information in separate .dwo files."
 msgstr "Öntanımlı biçimde hata ayıklama bilgisi üretir"
 
-#: common.opt:2957
+#: common.opt:2961
 #, fuzzy
 #| msgid "Generate debug information in STABS format"
 msgid "Generate debug information in STABS format."
 msgstr "STABS biçiminde hata ayıklama bilgisi üretir"
 
-#: common.opt:2961
+#: common.opt:2965
 #, fuzzy
 #| msgid "Generate debug information in extended STABS format"
 msgid "Generate debug information in extended STABS format."
 msgstr "Gelişmiş STABS biçiminde hata ayıklama bilgisi üretir"
 
-#: common.opt:2965
+#: common.opt:2969
 msgid "Emit progressive recommended breakpoint locations."
 msgstr ""
 
-#: common.opt:2969
+#: common.opt:2973
 msgid "Don't emit DWARF additions beyond selected version."
 msgstr ""
 
-#: common.opt:2973
+#: common.opt:2977
 #, fuzzy
 #| msgid "Generate debug information in VMS format"
 msgid "Toggle debug information generation."
 msgstr "VMS biçiminde hata ayıklama bilgisi üretir"
 
-#: common.opt:2977
+#: common.opt:2981
 msgid "Augment variable location lists with progressive views."
 msgstr ""
 
-#: common.opt:2984
+#: common.opt:2988
 #, fuzzy
 #| msgid "Generate debug information in VMS format"
 msgid "Generate debug information in VMS format."
 msgstr "VMS biçiminde hata ayıklama bilgisi üretir"
 
-#: common.opt:2988
+#: common.opt:2992
 #, fuzzy
 #| msgid "Generate debug information in XCOFF format"
 msgid "Generate debug information in XCOFF format."
 msgstr "XCOFF biçiminde hata ayıklama bilgisi üretir"
 
-#: common.opt:2992
+#: common.opt:2996
 #, fuzzy
 #| msgid "Generate debug information in extended XCOFF format"
 msgid "Generate debug information in extended XCOFF format."
 msgstr "Gelişmiş XCOFF biçiminde hata ayıklama bilgisi üretir"
 
-#: common.opt:3010
+#: common.opt:3014
 #, fuzzy
 #| msgid "Generate isel instructions"
 msgid "Generate compressed debug sections."
 msgstr "isel komutları üretilir"
 
-#: common.opt:3014
+#: common.opt:3018
 #, fuzzy
 #| msgid "Generate debug information in default format"
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>."
 msgstr "Öntanımlı biçimde hata ayıklama bilgisi üretir"
 
-#: common.opt:3021
+#: common.opt:3025
 #, fuzzy
 #| msgid "Set <dir> to be the system root directory"
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory."
 msgstr "<dizin> sistemin kök dizini olur"
 
-#: common.opt:3025
+#: common.opt:3029
 #, fuzzy
 #| msgid "Set <dir> to be the system root directory"
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory."
 msgstr "<dizin> sistemin kök dizini olur"
 
-#: common.opt:3047
+#: common.opt:3051
 #, fuzzy
 #| msgid "Place output into <file>"
 msgid "-o <file>\tPlace output into <file>."
 msgstr "Çıktı <dosya>ya yazılır"
 
-#: common.opt:3051
+#: common.opt:3055
 #, fuzzy
 #| msgid "Enable function profiling"
 msgid "Enable function profiling."
 msgstr "İşlev ayrımlama etkinleştirilir"
 
-#: common.opt:3061
+#: common.opt:3065
 #, fuzzy
 #| msgid "Like -pedantic but issue them as errors"
 msgid "Like -pedantic but issue them as errors."
 msgstr "-pedantic gibidir ancak uyarılar hata olarak ele alınır"
 
-#: common.opt:3101
+#: common.opt:3105
 #, fuzzy
 #| msgid "Do not display functions compiled or elapsed time"
 msgid "Do not display functions compiled or elapsed time."
 msgstr "Derlenen işlevler ve geçen zaman gösterilmez"
 
-#: common.opt:3133
+#: common.opt:3137
 #, fuzzy
 #| msgid "Enable verbose output"
 msgid "Enable verbose output."
 msgstr "Ayrıntılı çıktı verilir"
 
-#: common.opt:3137
+#: common.opt:3141
 #, fuzzy
 #| msgid "Display the compiler's version"
 msgid "Display the compiler's version."
 msgstr "Derleyici sürümünü gösterir."
 
-#: common.opt:3141
+#: common.opt:3145
 #, fuzzy
 #| msgid "Suppress warnings"
 msgid "Suppress warnings."
 msgstr "Uyarılar engellenir"
 
-#: common.opt:3151
+#: common.opt:3155
 #, fuzzy
 #| msgid "Enable ID based shared library"
 msgid "Create a shared library."
 msgstr "ID tabanlı paylaşımlı kütüphane etkin olur"
 
-#: common.opt:3196
+#: common.opt:3200
 #, fuzzy
 #| msgid "Generate position-independent code for executables if possible (large mode)"
 msgid "Don't create a dynamically linked position independent executable."
 msgstr "Mümkünse, çalıştırılabilirler için konumdan bağımsız kod üretilir (büyük kip)"
 
-#: common.opt:3200
+#: common.opt:3204
 #, fuzzy
 #| msgid "Generate position-independent code for executables if possible (large mode)"
 msgid "Create a dynamically linked position independent executable."
 msgstr "Mümkünse, çalıştırılabilirler için konumdan bağımsız kod üretilir (büyük kip)"
 
-#: common.opt:3204
+#: common.opt:3208
 #, fuzzy
 #| msgid "Generate position-independent code for executables if possible (large mode)"
 msgid "Create a static position independent executable."
 msgstr "Mümkünse, çalıştırılabilirler için konumdan bağımsız kod üretilir (büyük kip)"
 
-#: common.opt:3211
+#: common.opt:3215
 msgid "Use caller save register across calls if possible."
 msgstr ""
 
-#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:598 cp/cvt.c:1308
+#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:599 cp/cvt.c:1308
 #: cp/cvt.c:1561
 #, gcc-internal-format
 msgid "value computed is not used"
@@ -19789,7 +19790,7 @@
 msgstr "İfade türü umuluyordu"
 
 #: go/gofrontend/expressions.cc:4331 c/c-parser.c:13477 c/c-parser.c:13484
-#: cp/parser.c:33264 cp/parser.c:33271
+#: cp/parser.c:33261 cp/parser.c:33268
 #, fuzzy, gcc-internal-format
 #| msgid "Expected integer"
 msgid "expected integer"
@@ -20326,8 +20327,8 @@
 msgid "ignoring attribute %qE because it conflicts with attribute %qs"
 msgstr "%s özniteliği ile %s özniteliği %L'de çelişiyor"
 
-#: attribs.c:449 c-family/c-attribs.c:1894 cp/decl.c:13690 cp/friend.c:302
-#: cp/tree.c:4559
+#: attribs.c:449 c-family/c-attribs.c:1905 cp/decl.c:13714 cp/friend.c:302
+#: cp/tree.c:4607
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D here"
 msgid "previous declaration here"
@@ -20334,7 +20335,7 @@
 msgstr "buradaki önceki %q+#D bildirimi ile çelişiyor"
 
 #. Warn about and ignore all others for now, but store them.
-#: attribs.c:564 c-family/c-attribs.c:2717 objc/objc-act.c:4963
+#: attribs.c:564 c-family/c-attribs.c:2728 objc/objc-act.c:4963
 #: objc/objc-act.c:6932 objc/objc-act.c:8119 objc/objc-act.c:8170
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute directive ignored"
@@ -20356,18 +20357,18 @@
 #. This is a c++11 attribute that appertains to a
 #. type-specifier, outside of the definition of, a class
 #. type.  Ignore it.
-#: attribs.c:590 cp/decl.c:10999
+#: attribs.c:590 cp/decl.c:11023
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored"
 msgid "attribute ignored"
 msgstr "%qE özniteliği yoksayıldı"
 
-#: attribs.c:592 cp/decl.c:11000
+#: attribs.c:592 cp/decl.c:11024
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
 
-#: attribs.c:610 c-family/c-attribs.c:3219
+#: attribs.c:610 c-family/c-attribs.c:3230
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute does not apply to types"
 msgid "%qE attribute does not apply to types"
@@ -20386,40 +20387,40 @@
 msgstr "tür öznitelikleri sadece tür tanımlarında uygulanabilir"
 
 #: attribs.c:691 attribs.c:1622 attribs.c:1632 attribs.c:1642
-#: c-family/c-attribs.c:540 c-family/c-attribs.c:559 c-family/c-attribs.c:577
-#: c-family/c-attribs.c:607 c-family/c-attribs.c:628 c-family/c-attribs.c:649
-#: c-family/c-attribs.c:690 c-family/c-attribs.c:717 c-family/c-attribs.c:733
-#: c-family/c-attribs.c:750 c-family/c-attribs.c:766 c-family/c-attribs.c:792
-#: c-family/c-attribs.c:807 c-family/c-attribs.c:835 c-family/c-attribs.c:852
-#: c-family/c-attribs.c:870 c-family/c-attribs.c:893 c-family/c-attribs.c:931
-#: c-family/c-attribs.c:954 c-family/c-attribs.c:971 c-family/c-attribs.c:1000
-#: c-family/c-attribs.c:1021 c-family/c-attribs.c:1042
-#: c-family/c-attribs.c:1069 c-family/c-attribs.c:1099
-#: c-family/c-attribs.c:1136 c-family/c-attribs.c:1189
-#: c-family/c-attribs.c:1255 c-family/c-attribs.c:1313
-#: c-family/c-attribs.c:1402 c-family/c-attribs.c:1432
-#: c-family/c-attribs.c:1483 c-family/c-attribs.c:1998
-#: c-family/c-attribs.c:2035 c-family/c-attribs.c:2096
-#: c-family/c-attribs.c:2152 c-family/c-attribs.c:2230
-#: c-family/c-attribs.c:2312 c-family/c-attribs.c:2371
-#: c-family/c-attribs.c:2390 c-family/c-attribs.c:2498
-#: c-family/c-attribs.c:2514 c-family/c-attribs.c:2530
-#: c-family/c-attribs.c:2551 c-family/c-attribs.c:2608
-#: c-family/c-attribs.c:2635 c-family/c-attribs.c:2690
-#: c-family/c-attribs.c:2870 c-family/c-attribs.c:2891
-#: c-family/c-attribs.c:3004 c-family/c-attribs.c:3031
-#: c-family/c-attribs.c:3221 c-family/c-attribs.c:3239
-#: c-family/c-attribs.c:3262 c-family/c-attribs.c:3301
-#: c-family/c-attribs.c:3383 c-family/c-attribs.c:3439
-#: c-family/c-attribs.c:3455 c-family/c-attribs.c:3549
-#: c-family/c-common.c:5600 config/darwin.c:2072 config/arm/arm.c:6868
+#: c-family/c-attribs.c:547 c-family/c-attribs.c:566 c-family/c-attribs.c:584
+#: c-family/c-attribs.c:614 c-family/c-attribs.c:635 c-family/c-attribs.c:656
+#: c-family/c-attribs.c:697 c-family/c-attribs.c:728 c-family/c-attribs.c:744
+#: c-family/c-attribs.c:761 c-family/c-attribs.c:777 c-family/c-attribs.c:803
+#: c-family/c-attribs.c:818 c-family/c-attribs.c:846 c-family/c-attribs.c:863
+#: c-family/c-attribs.c:881 c-family/c-attribs.c:904 c-family/c-attribs.c:942
+#: c-family/c-attribs.c:965 c-family/c-attribs.c:982 c-family/c-attribs.c:1011
+#: c-family/c-attribs.c:1032 c-family/c-attribs.c:1053
+#: c-family/c-attribs.c:1080 c-family/c-attribs.c:1110
+#: c-family/c-attribs.c:1147 c-family/c-attribs.c:1200
+#: c-family/c-attribs.c:1266 c-family/c-attribs.c:1324
+#: c-family/c-attribs.c:1413 c-family/c-attribs.c:1443
+#: c-family/c-attribs.c:1494 c-family/c-attribs.c:2009
+#: c-family/c-attribs.c:2046 c-family/c-attribs.c:2107
+#: c-family/c-attribs.c:2163 c-family/c-attribs.c:2241
+#: c-family/c-attribs.c:2323 c-family/c-attribs.c:2382
+#: c-family/c-attribs.c:2401 c-family/c-attribs.c:2509
+#: c-family/c-attribs.c:2525 c-family/c-attribs.c:2541
+#: c-family/c-attribs.c:2562 c-family/c-attribs.c:2619
+#: c-family/c-attribs.c:2646 c-family/c-attribs.c:2701
+#: c-family/c-attribs.c:2881 c-family/c-attribs.c:2902
+#: c-family/c-attribs.c:3015 c-family/c-attribs.c:3042
+#: c-family/c-attribs.c:3232 c-family/c-attribs.c:3250
+#: c-family/c-attribs.c:3273 c-family/c-attribs.c:3312
+#: c-family/c-attribs.c:3394 c-family/c-attribs.c:3450
+#: c-family/c-attribs.c:3466 c-family/c-attribs.c:3560
+#: c-family/c-common.c:5598 config/darwin.c:2072 config/arm/arm.c:6868
 #: config/arm/arm.c:6896 config/arm/arm.c:6913 config/avr/avr.c:9698
-#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6497
-#: config/i386/i386.c:41520 config/ia64/ia64.c:788
-#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33056
-#: config/spu/spu.c:3743 ada/gcc-interface/utils.c:6244
-#: ada/gcc-interface/utils.c:6261 ada/gcc-interface/utils.c:6277
-#: ada/gcc-interface/utils.c:6303 brig/brig-lang.c:476 lto/lto-lang.c:283
+#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6500
+#: config/i386/i386.c:41514 config/ia64/ia64.c:788
+#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33112
+#: config/spu/spu.c:3743 ada/gcc-interface/utils.c:6249
+#: ada/gcc-interface/utils.c:6266 ada/gcc-interface/utils.c:6282
+#: ada/gcc-interface/utils.c:6308 brig/brig-lang.c:476 lto/lto-lang.c:283
 #, gcc-internal-format
 msgid "%qE attribute ignored"
 msgstr "%qE özniteliği yoksayıldı"
@@ -20810,97 +20811,113 @@
 msgid "%Kattempt to free a non-heap object"
 msgstr ""
 
-#: calls.c:1434
+#: calls.c:1291 file-prefix-map.c:50
 #, fuzzy, gcc-internal-format
+#| msgid "invalid IACC argument"
+msgid "invalid argument %qs to %qs"
+msgstr "IACC argümanı geçersiz"
+
+#: calls.c:1452
+#, fuzzy, gcc-internal-format
 #| msgid "Statement function at %L is recursive"
 msgid "%Kargument %i value %qE is negative"
 msgstr "%L'deki deyim işlevi iç içe"
 
-#: calls.c:1452
+#: calls.c:1470
 #, fuzzy, gcc-internal-format
 #| msgid "Second argument MOD at %L is zero"
 msgid "%Kargument %i value is zero"
 msgstr "%L'de ikinci MOD argümanı sıfırdır"
 
-#: calls.c:1469
+#: calls.c:1487
 #, gcc-internal-format
 msgid "%Kargument %i value %qE exceeds maximum object size %E"
 msgstr ""
 
-#: calls.c:1483
+#: calls.c:1501
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function at %L is recursive"
 msgid "%Kargument %i range [%E, %E] is negative"
 msgstr "%L'deki deyim işlevi iç içe"
 
-#: calls.c:1490
+#: calls.c:1508
 #, gcc-internal-format
 msgid "%Kargument %i range [%E, %E] exceeds maximum object size %E"
 msgstr ""
 
-#: calls.c:1520
+#: calls.c:1538
 #, gcc-internal-format
 msgid "%Kproduct %<%E * %E%> of arguments %i and %i exceeds %<SIZE_MAX%>"
 msgstr ""
 
-#: calls.c:1526
+#: calls.c:1544
 #, gcc-internal-format
 msgid "%Kproduct %<%E * %E%> of arguments %i and %i exceeds maximum object size %E"
 msgstr ""
 
-#: calls.c:1537 calls.c:1540
+#: calls.c:1555 calls.c:1558
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ATANH at %L must be inside the range -1 to 1"
 msgid "argument %i in the range [%E, %E]"
 msgstr "%L'deki ATANH argümanı -1 .. 1 aralığının içinde kalmalı"
 
-#: calls.c:1551
+#: calls.c:1569
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "in a call to built-in allocation function %qD"
 msgstr "işlev olmayan %qD ye çağrı"
 
-#: calls.c:1554
+#: calls.c:1572
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "in a call to allocation function %qD declared here"
 msgstr "yerleşik işlev `%q+D işlev olarak bildirilmemiş"
 
-#: calls.c:1711
+#: calls.c:1835
 #, gcc-internal-format
-msgid "%qD argument %i declared attribute %<nonstring%> is smaller than the specified bound %E"
+msgid "%qD argument %i declared attribute %<nonstring%> is smaller than the specified bound %wu"
 msgstr ""
 
-#: calls.c:1716
+#: calls.c:1841
+#, gcc-internal-format
+msgid "%qD argument %i declared attribute %<nonstring%> is smaller than the specified bound [%E, %E]"
+msgstr ""
+
+#: calls.c:1847
+#, gcc-internal-format
+msgid "%qD argument %i declared attribute %<nonstring%> may be smaller than the specified bound [%E, %E]"
+msgstr ""
+
+#: calls.c:1857
 #, fuzzy, gcc-internal-format
 #| msgid "%qD was not declared in this scope"
 msgid "%qD argument %i declared attribute %<nonstring%>"
 msgstr "%qD bu etki alanında bildirilmemiş"
 
-#: calls.c:1721
+#: calls.c:1862
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "argument %qD declared here"
 msgstr "burada bildirilmiş %q+D"
 
-#: calls.c:1735
+#: calls.c:1876
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "[cannot find %s]"
 msgid "cannot tail-call: %s"
 msgstr "[%s bulunamıyor]"
 
-#: calls.c:3365
+#: calls.c:3506
 #, gcc-internal-format
 msgid "function call has aggregate value"
 msgstr "işlev çağrısı küme değeri içeriyor"
 
-#: calls.c:4059
+#: calls.c:4200
 #, fuzzy, gcc-internal-format
 #| msgid "Pass arguments on the stack"
 msgid "passing too large argument on stack"
 msgstr "Yığıttaki argümanlar aktarılır"
 
-#: cfgexpand.c:1665 function.c:1002 varasm.c:2231
+#: cfgexpand.c:1665 function.c:1002 varasm.c:2242
 #, gcc-internal-format
 msgid "size of variable %q+D is too large"
 msgstr "%q+D değişkeninin boyutu çok geniş"
@@ -21511,245 +21528,245 @@
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr "komut zinciri (%d) içindeki bb notlarının sayısı != n_basic_blocks (%d)"
 
-#: cgraph.c:3051
+#: cgraph.c:3056
 #, fuzzy, gcc-internal-format
 #| msgid "caller edge count is negative"
 msgid "caller edge count invalid"
 msgstr "çağrıcı ayrıt sayısı negatif"
 
-#: cgraph.c:3135
+#: cgraph.c:3140
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr "ayrıt %s->%s için yardımcı alan belirtilmiş"
 
-#: cgraph.c:3142
+#: cgraph.c:3147
 #, gcc-internal-format
 msgid "cgraph count invalid"
 msgstr ""
 
-#: cgraph.c:3147
+#: cgraph.c:3152
 #, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr ""
 
-#: cgraph.c:3152
+#: cgraph.c:3157
 #, fuzzy, gcc-internal-format
 #| msgid "Assume symbols might be invalid"
 msgid "local symbols must be defined"
 msgstr "Tüm simgelerin geçersiz olabileceği varsayılır"
 
-#: cgraph.c:3157
+#: cgraph.c:3162
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr ""
 
-#: cgraph.c:3162
+#: cgraph.c:3167
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr ""
 
-#: cgraph.c:3167
+#: cgraph.c:3172
 #, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr ""
 
-#: cgraph.c:3174
+#: cgraph.c:3179
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "aux field set for edge %s->%s"
 msgid "aux field set for indirect edge from %s"
 msgstr "ayrıt %s->%s için yardımcı alan belirtilmiş"
 
-#: cgraph.c:3181
+#: cgraph.c:3186
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr ""
 
-#: cgraph.c:3196
+#: cgraph.c:3201
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr ""
 
-#: cgraph.c:3206
+#: cgraph.c:3211
 #, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr "inlined_to göstericisi yanlış"
 
-#: cgraph.c:3211
+#: cgraph.c:3216
 #, gcc-internal-format
 msgid "multiple inline callers"
 msgstr "çok sayıda satıriçi çağrısı"
 
-#: cgraph.c:3218
+#: cgraph.c:3223
 #, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr "Inlined_to göstericisi satıriçi olmayan çağrıcılar için belirtilmiş"
 
-#: cgraph.c:3239
+#: cgraph.c:3244
 #, fuzzy, gcc-internal-format
 #| msgid "incoming edge count does not match number of PHI arguments"
 msgid "caller edge count does not match BB count"
 msgstr "gelen ayrıt sayısı PHI argüman sayısı ile uyuşmuyor"
 
-#: cgraph.c:3261
+#: cgraph.c:3266
 #, fuzzy, gcc-internal-format
 #| msgid "incoming edge count does not match number of PHI arguments"
 msgid "indirect call count does not match BB count"
 msgstr "gelen ayrıt sayısı PHI argüman sayısı ile uyuşmuyor"
 
-#: cgraph.c:3272
+#: cgraph.c:3277
 #, fuzzy, gcc-internal-format
 #| msgid "inlined_to pointer is set but no predecesors found"
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr "inlined_to göstericisi var ama bir öncül yok"
 
-#: cgraph.c:3277
+#: cgraph.c:3282
 #, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr "Inlined_to göstericisi kendini gösteriyor"
 
-#: cgraph.c:3289
+#: cgraph.c:3294
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr ""
 
-#: cgraph.c:3301
+#: cgraph.c:3306
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr ""
 
-#: cgraph.c:3307
+#: cgraph.c:3312
 #, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr ""
 
-#: cgraph.c:3312
+#: cgraph.c:3317
 #, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr ""
 
-#: cgraph.c:3317
+#: cgraph.c:3322
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr ""
 
-#: cgraph.c:3329
+#: cgraph.c:3334
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr ""
 
-#: cgraph.c:3337
+#: cgraph.c:3342
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr ""
 
-#: cgraph.c:3342
+#: cgraph.c:3347
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr ""
 
-#: cgraph.c:3349
+#: cgraph.c:3354
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr ""
 
-#: cgraph.c:3358
+#: cgraph.c:3363
 #, gcc-internal-format
 msgid "Instrumentation clone does not reference original node"
 msgstr ""
 
-#: cgraph.c:3365
+#: cgraph.c:3370
 #, gcc-internal-format
 msgid "Not instrumented node has non-NULL original declaration"
 msgstr ""
 
-#: cgraph.c:3375
+#: cgraph.c:3380
 #, gcc-internal-format
 msgid "Instrumented node has wrong original declaration"
 msgstr ""
 
-#: cgraph.c:3393
+#: cgraph.c:3398
 #, gcc-internal-format
 msgid "Node has more than one chkp reference"
 msgstr ""
 
-#: cgraph.c:3398
+#: cgraph.c:3403
 #, gcc-internal-format
 msgid "Wrong node is referenced with chkp reference"
 msgstr ""
 
-#: cgraph.c:3406
+#: cgraph.c:3411
 #, gcc-internal-format
 msgid "Analyzed node has no reference to instrumented version"
 msgstr ""
 
-#: cgraph.c:3420
+#: cgraph.c:3425
 #, gcc-internal-format
 msgid "Alias chain for instrumented node is broken"
 msgstr ""
 
-#: cgraph.c:3429
+#: cgraph.c:3434
 #, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3434
+#: cgraph.c:3439
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3439
+#: cgraph.c:3444
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr ""
 
-#: cgraph.c:3445
+#: cgraph.c:3450
 #, gcc-internal-format
 msgid "Instrumentation thunk has wrong edge callee"
 msgstr ""
 
-#: cgraph.c:3481
+#: cgraph.c:3486
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr "paylaşımlı call_stmt:"
 
-#: cgraph.c:3489
+#: cgraph.c:3494
 #, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr "yanlış bildirimin köşeleri:"
 
-#: cgraph.c:3498
+#: cgraph.c:3503
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr ""
 
-#: cgraph.c:3508
+#: cgraph.c:3513
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr "çağrı deyimi için çağrı çizgesi ayrıtı eksik"
 
-#: cgraph.c:3518
+#: cgraph.c:3523
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "reference to dead statement"
 msgstr "deyim umuluyordu"
 
-#: cgraph.c:3531
+#: cgraph.c:3536
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr "ayrıt %s->%s için karşılığı olan çağrı deyimi yok"
 
-#: cgraph.c:3543
+#: cgraph.c:3548
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "edge %s->%s has no corresponding call_stmt"
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr "ayrıt %s->%s için karşılığı olan çağrı deyimi yok"
 
-#: cgraph.c:3554
+#: cgraph.c:3559
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr "verify_cgraph_node başarısız"
 
-#: cgraph.c:3661 varpool.c:306
+#: cgraph.c:3666 varpool.c:306
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument to '-%s' is missing"
 msgid "%s: section %s is missing"
@@ -21784,12 +21801,12 @@
 msgstr ""
 
 #. include_self=
-#: cgraphunit.c:981 c/c-decl.c:11282
+#: cgraphunit.c:981 c/c-decl.c:11302
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F işlevi tanımlanmadan kullanılmış"
 
-#: cgraphunit.c:983 c/c-decl.c:11291
+#: cgraphunit.c:983 c/c-decl.c:11311
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "%<static%> olarak bildirilen `%q+F hiç tanımlanmamış"
@@ -21919,13 +21936,13 @@
 msgid "cannot find '%s'"
 msgstr "'%s' bulunamıyor"
 
-#: collect-utils.c:183 collect2.c:2361 collect2.c:2560 gcc.c:3080 gcc.c:6856
+#: collect-utils.c:183 collect2.c:2387 collect2.c:2586 gcc.c:3080 gcc.c:6856
 #, fuzzy, gcc-internal-format
 #| msgid "pex_init failed"
 msgid "pex_init failed: %m"
 msgstr "pex_init başarısız"
 
-#: collect-utils.c:192 collect2.c:2370 collect2.c:2568 gcc.c:8498
+#: collect-utils.c:192 collect2.c:2396 collect2.c:2594 gcc.c:8498
 #, fuzzy, gcc-internal-format
 #| msgid "%s: %s"
 msgid "%s: %m"
@@ -21936,7 +21953,7 @@
 msgid "COLLECT_LTO_WRAPPER must be set"
 msgstr ""
 
-#: collect2.c:966 gcc.c:7382 lto-wrapper.c:1666
+#: collect2.c:969 gcc.c:7382 lto-wrapper.c:1692
 #: config/i386/intelmic-mkoffload.c:556 config/nvptx/mkoffload.c:405
 #, fuzzy, gcc-internal-format
 #| msgid "pex_init failed"
@@ -21943,92 +21960,92 @@
 msgid "atexit failed"
 msgstr "pex_init başarısız"
 
-#: collect2.c:1064
+#: collect2.c:1067
 #, gcc-internal-format
 msgid "no arguments"
 msgstr "argüman yok"
 
-#: collect2.c:1303 opts.c:904
+#: collect2.c:1311 opts.c:904
 #, fuzzy, gcc-internal-format
 #| msgid "-m%s not supported in this configuration"
 msgid "LTO support has not been enabled in this configuration"
 msgstr "-m%s bu yapılandırmada desteklenmiyor"
 
-#: collect2.c:1344
+#: collect2.c:1352
 #, gcc-internal-format
 msgid "can't open %s: %m"
 msgstr "%s açılamıyor: %m"
 
-#: collect2.c:1450
+#: collect2.c:1472
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown demangling style '%s'"
 msgstr "cendereleme tarzı %s bilinmiyor"
 
-#: collect2.c:1546 collect2.c:1729 collect2.c:1769
+#: collect2.c:1574 collect2.c:1757 collect2.c:1797
 #, fuzzy, gcc-internal-format
 #| msgid "fopen %s"
 msgid "fopen %s: %m"
 msgstr "fopen %s"
 
-#: collect2.c:1549 collect2.c:1734 collect2.c:1772
+#: collect2.c:1577 collect2.c:1762 collect2.c:1800
 #, fuzzy, gcc-internal-format
 #| msgid "fclose %s"
 msgid "fclose %s: %m"
 msgstr "fclose %s"
 
-#: collect2.c:2335
+#: collect2.c:2361
 #, gcc-internal-format
 msgid "cannot find 'nm'"
 msgstr "'nm' bulunamıyor"
 
-#: collect2.c:2383
+#: collect2.c:2409
 #, fuzzy, gcc-internal-format
 #| msgid "can't open nm output"
 msgid "can't open nm output: %m"
 msgstr "nm çıktısı açılamıyor"
 
-#: collect2.c:2467
+#: collect2.c:2493
 #, gcc-internal-format, gfc-internal-format
 msgid "init function found in object %s"
 msgstr "%s nesnesinde init işlevi bulundu"
 
-#: collect2.c:2478
+#: collect2.c:2504
 #, gcc-internal-format, gfc-internal-format
 msgid "fini function found in object %s"
 msgstr "%s nesnesinde fini işlevi bulundu"
 
-#: collect2.c:2535
+#: collect2.c:2561
 #, gcc-internal-format
 msgid "cannot find 'ldd'"
 msgstr "'ldd' bulunamıyor"
 
-#: collect2.c:2581
+#: collect2.c:2607
 #, fuzzy, gcc-internal-format
 #| msgid "can't open ldd output"
 msgid "can't open ldd output: %m"
 msgstr "ldd çıktısı açılamıyor"
 
-#: collect2.c:2599
+#: collect2.c:2625
 #, gcc-internal-format, gfc-internal-format
 msgid "dynamic dependency %s not found"
 msgstr "%s özdevimli bağımlılığı yok"
 
-#: collect2.c:2611
+#: collect2.c:2637
 #, gcc-internal-format, gfc-internal-format
 msgid "unable to open dynamic dependency '%s'"
 msgstr "'%s' özdevimli bağımlılığı açılamıyor"
 
-#: collect2.c:2765
+#: collect2.c:2791
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: not a COFF file"
 msgstr "%s: bir COFF dosyası değil"
 
-#: collect2.c:2930
+#: collect2.c:2961
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: cannot open as COFF file"
 msgstr "%s: bir COFF dosyası olarak açılamıyor"
 
-#: collect2.c:2989
+#: collect2.c:3020
 #, gcc-internal-format, gfc-internal-format
 msgid "library lib%s not found"
 msgstr "lib%s kitaplığı bulunamadı"
@@ -22250,12 +22267,12 @@
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr ""
 
-#: dwarf2out.c:10901
+#: dwarf2out.c:10909
 #, gcc-internal-format
 msgid "-gdwarf-6 is output as version 5 with incompatibilities"
 msgstr ""
 
-#: dwarf2out.c:14415
+#: dwarf2out.c:14423
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
@@ -22382,12 +22399,6 @@
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr "%q+D işlevinin yeniden bildirimi inline öznitelikli değil"
 
-#: file-prefix-map.c:50
-#, fuzzy, gcc-internal-format
-#| msgid "invalid IACC argument"
-msgid "invalid argument %qs to %qs"
-msgstr "IACC argümanı geçersiz"
-
 #: final.c:1868
 #, fuzzy, gcc-internal-format
 #| msgid "size of %q+D is larger than %wd bytes"
@@ -22412,42 +22423,42 @@
 msgid "large fixed-point constant implicitly truncated to fixed-point type"
 msgstr "büyük tamsayı örtük olarak unsigned türe indirgendi"
 
-#: fold-const.c:4151 fold-const.c:4161
+#: fold-const.c:4157 fold-const.c:4167
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d due to width of bit-field"
 msgstr "karşılaştırma bit alanının genişliğinden dolayı daima %d"
 
-#: fold-const.c:5478 tree-ssa-reassoc.c:2374 tree-ssa-reassoc.c:3214
+#: fold-const.c:5484 tree-ssa-reassoc.c:2379 tree-ssa-reassoc.c:3219
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
 
-#: fold-const.c:5928 fold-const.c:5942
+#: fold-const.c:5934 fold-const.c:5948
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr "karşılaştırma sonucu daima %d"
 
-#: fold-const.c:6085
+#: fold-const.c:6091
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr "eşleşmeyenlerin farklılık sınamalarının %<or%> sonucu daima 1 dir"
 
-#: fold-const.c:6090
+#: fold-const.c:6096
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr "bağdaşmayanların eşitlik sınamalarının %<and%> sonucu daima 0 dir"
 
-#: fold-const.c:8310
+#: fold-const.c:8316
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr ""
 
-#: fold-const.c:8710
+#: fold-const.c:8716
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr ""
 
-#: fold-const.c:12063
+#: fold-const.c:12069
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr "fold sınaması: özgün ağac fold tarafından değiştirildi"
@@ -22458,7 +22469,7 @@
 msgid "total size of local objects too large"
 msgstr "%Jyerel nesnelerin toplam boyutu çok büyük"
 
-#: function.c:1776 gimplify.c:6270
+#: function.c:1776 gimplify.c:6273
 #, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr "%<asm%> içindeki kısıt imnkansız"
@@ -22795,7 +22806,7 @@
 msgid "%s: linker input file unused because linking not done"
 msgstr "%s: ilintileme yapılmadığından ilintileyici girdi dosyası kullanılmadı"
 
-#: gcc.c:8420 c-family/c-opts.c:770
+#: gcc.c:8420 c-family/c-opts.c:768
 #, gcc-internal-format
 msgid "cannot use %<-%> as input filename for a precompiled header"
 msgstr ""
@@ -23059,7 +23070,7 @@
 msgid "%G%qD destination unchanged after copying no bytes"
 msgstr ""
 
-#: gimple-fold.c:2052 tree-ssa-strlen.c:2050
+#: gimple-fold.c:2052 tree-ssa-strlen.c:2074
 msgid "%G%qD specified bound %E equals destination size"
 msgstr ""
 
@@ -23083,12 +23094,12 @@
 msgid "null pointer dereference"
 msgstr "PRINT_OPERAND boş gösterici"
 
-#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12451
-#: tree.c:12488 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10147
-#: c/c-typeck.c:10164 c/gimple-parser.c:1616 c/gimple-parser.c:1624
+#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12455
+#: tree.c:12492 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10152
+#: c/c-typeck.c:10169 c/gimple-parser.c:1616 c/gimple-parser.c:1624
 #: cp/call.c:6493 cp/call.c:8098 cp/constexpr.c:820 cp/constexpr.c:2309
-#: cp/cvt.c:1015 cp/cvt.c:1042 cp/decl.c:7334 cp/decl2.c:5256 cp/pt.c:8334
-#: cp/semantics.c:1836 cp/semantics.c:4053 cp/typeck.c:1700 cp/typeck.c:1895
+#: cp/cvt.c:1015 cp/cvt.c:1042 cp/decl.c:7355 cp/decl2.c:5246 cp/pt.c:8348
+#: cp/semantics.c:1836 cp/semantics.c:4056 cp/typeck.c:1700 cp/typeck.c:1895
 #: cp/typeck.c:3837
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
@@ -23100,27 +23111,27 @@
 msgid "nonnull argument %qD compared to NULL"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2517 gimple-ssa-sprintf.c:2637
+#: gimple-ssa-sprintf.c:2555 gimple-ssa-sprintf.c:2675
 #, gcc-internal-format
 msgid "%qE output may be truncated before the last format character"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2519 gimple-ssa-sprintf.c:2639
+#: gimple-ssa-sprintf.c:2557 gimple-ssa-sprintf.c:2677
 #, gcc-internal-format
 msgid "%qE output truncated before the last format character"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2522 gimple-ssa-sprintf.c:2642
+#: gimple-ssa-sprintf.c:2560 gimple-ssa-sprintf.c:2680
 #, gcc-internal-format
 msgid "%qE may write a terminating nul past the end of the destination"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2524 gimple-ssa-sprintf.c:2644
+#: gimple-ssa-sprintf.c:2562 gimple-ssa-sprintf.c:2682
 #, gcc-internal-format
 msgid "%qE writing a terminating nul past the end of the destination"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2534
+#: gimple-ssa-sprintf.c:2572
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size %wu"
@@ -23127,7 +23138,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.c:2541
+#: gimple-ssa-sprintf.c:2579
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size %wu"
@@ -23134,7 +23145,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.c:2548
+#: gimple-ssa-sprintf.c:2586
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size %wu"
@@ -23141,67 +23152,67 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.c:2559
+#: gimple-ssa-sprintf.c:2597
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2562
+#: gimple-ssa-sprintf.c:2600
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2564
+#: gimple-ssa-sprintf.c:2602
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2576
+#: gimple-ssa-sprintf.c:2614
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2579
+#: gimple-ssa-sprintf.c:2617
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2582
+#: gimple-ssa-sprintf.c:2620
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2591
+#: gimple-ssa-sprintf.c:2629
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2594
+#: gimple-ssa-sprintf.c:2632
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2597
+#: gimple-ssa-sprintf.c:2635
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2606
+#: gimple-ssa-sprintf.c:2644
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2609
+#: gimple-ssa-sprintf.c:2647
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2611
+#: gimple-ssa-sprintf.c:2649
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2653
+#: gimple-ssa-sprintf.c:2691
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size between %wu and %wu"
@@ -23208,7 +23219,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.c:2660
+#: gimple-ssa-sprintf.c:2698
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size between %wu and %wu"
@@ -23215,7 +23226,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.c:2668
+#: gimple-ssa-sprintf.c:2706
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size between %wu and %wu"
@@ -23222,102 +23233,102 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.c:2680
+#: gimple-ssa-sprintf.c:2718
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2683
+#: gimple-ssa-sprintf.c:2721
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2686
+#: gimple-ssa-sprintf.c:2724
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2699
+#: gimple-ssa-sprintf.c:2737
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2702
+#: gimple-ssa-sprintf.c:2740
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2705
+#: gimple-ssa-sprintf.c:2743
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2715
+#: gimple-ssa-sprintf.c:2753
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2718
+#: gimple-ssa-sprintf.c:2756
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2721
+#: gimple-ssa-sprintf.c:2759
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2730
+#: gimple-ssa-sprintf.c:2768
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2733
+#: gimple-ssa-sprintf.c:2771
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2736
+#: gimple-ssa-sprintf.c:2774
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2825
+#: gimple-ssa-sprintf.c:2863
 #, gcc-internal-format
 msgid "%<%.*s%> directive argument is null"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2890
+#: gimple-ssa-sprintf.c:2928
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes exceeds minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2897
+#: gimple-ssa-sprintf.c:2935
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may exceed minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2900
+#: gimple-ssa-sprintf.c:2938
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes exceeds minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2929
+#: gimple-ssa-sprintf.c:2967
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2936
+#: gimple-ssa-sprintf.c:2974
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2939
+#: gimple-ssa-sprintf.c:2977
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may cause result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2949
+#: gimple-ssa-sprintf.c:2987
 #, gcc-internal-format
 msgid "assuming directive output of %wu byte"
 msgid_plural "assuming directive output of %wu bytes"
@@ -23324,80 +23335,80 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.c:2956
+#: gimple-ssa-sprintf.c:2994
 #, fuzzy, gcc-internal-format
 #| msgid "Too many arguments to %s at %L"
 msgid "directive argument %qE"
 msgstr "%s için argümanlar %L'de çok fazla"
 
-#: gimple-ssa-sprintf.c:2958
+#: gimple-ssa-sprintf.c:2996
 #, fuzzy, gcc-internal-format
 #| msgid "selector must be an integer constant in the range 0..%wi"
 msgid "directive argument in the range [%E, %E]"
 msgstr "seçici 0..%wi aralığında bir tamsayı sabit olmalı"
 
-#: gimple-ssa-sprintf.c:2962
+#: gimple-ssa-sprintf.c:3000
 #, gcc-internal-format
 msgid "using the range [%E, %E] for directive argument"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2982
+#: gimple-ssa-sprintf.c:3020
 #, gcc-internal-format
 msgid "%qE output %wu byte into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2983
+#: gimple-ssa-sprintf.c:3021
 #, gcc-internal-format
 msgid "%qE output %wu bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2987
+#: gimple-ssa-sprintf.c:3025
 #, gcc-internal-format
 msgid "%qE output between %wu and %wu bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2992
+#: gimple-ssa-sprintf.c:3030
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes (assuming %wu) into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2997
+#: gimple-ssa-sprintf.c:3035
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3368
+#: gimple-ssa-sprintf.c:3406
 #, gcc-internal-format
 msgid "%<%.*s%> directive width out of range"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3402
+#: gimple-ssa-sprintf.c:3440
 #, gcc-internal-format
 msgid "%<%.*s%> directive precision out of range"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3893
+#: gimple-ssa-sprintf.c:3931
 #, gcc-internal-format
 msgid "specified bound %wu exceeds maximum object size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3899
+#: gimple-ssa-sprintf.c:3937
 #, gcc-internal-format
 msgid "specified bound %wu exceeds %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3949
+#: gimple-ssa-sprintf.c:3987
 #, fuzzy, gcc-internal-format
 #| msgid "PRINT_OPERAND null pointer"
 msgid "null destination pointer"
 msgstr "PRINT_OPERAND boş gösterici"
 
-#: gimple-ssa-sprintf.c:3966
+#: gimple-ssa-sprintf.c:4004
 #, gcc-internal-format
 msgid "specified bound %wu exceeds the size %wu of the destination object"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3978
+#: gimple-ssa-sprintf.c:4016
 #, fuzzy, gcc-internal-format
 #| msgid "%s in format string at %C"
 msgid "null format string"
@@ -23623,10 +23634,10 @@
 msgstr ""
 
 #: gimple-ssa-warn-restrict.c:1678 c/c-decl.c:3603 c/c-decl.c:3874
-#: c/c-typeck.c:8345 cp/class.c:1346 cp/class.c:3098 cp/decl.c:3979
-#: cp/decl.c:10753 cp/decl.c:11151 cp/decl.c:11160 cp/friend.c:384
+#: c/c-typeck.c:8350 cp/class.c:1346 cp/class.c:3102 cp/decl.c:3979
+#: cp/decl.c:10777 cp/decl.c:11175 cp/decl.c:11184 cp/friend.c:384
 #: cp/friend.c:393 cp/parser.c:3275 cp/parser.c:3372 cp/parser.c:3422
-#: cp/parser.c:6327 cp/parser.c:21027
+#: cp/parser.c:6330 cp/parser.c:21024
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%qD declared here"
@@ -23703,235 +23714,235 @@
 msgid "using result of function returning %<void%>"
 msgstr "void olmayan dönüşlü işlevde `return' deyimi yok"
 
-#: gimplify.c:6128
+#: gimplify.c:6131
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid lvalue in asm output %d"
 msgstr "asm çıktısı %d içinde geçersiz sol değer"
 
-#: gimplify.c:6271
+#: gimplify.c:6274
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr ""
 
-#: gimplify.c:6311 gimplify.c:6320
+#: gimplify.c:6314 gimplify.c:6323
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr "bellek girdisi %d doğrudan adreslenebilir değil"
 
-#: gimplify.c:6928
+#: gimplify.c:6931
 #, fuzzy, gcc-internal-format
 #| msgid "register variable %qD used in nested function"
 msgid "threadprivate variable %qE used in target region"
 msgstr "yazmaç değişkeni %qD iç işlevde kullanılmış"
 
-#: gimplify.c:6930
+#: gimplify.c:6933
 #, gcc-internal-format
 msgid "enclosing target region"
 msgstr ""
 
-#: gimplify.c:6942
+#: gimplify.c:6945
 #, fuzzy, gcc-internal-format
 #| msgid "register variable %qD used in nested function"
 msgid "threadprivate variable %qE used in untied task"
 msgstr "yazmaç değişkeni %qD iç işlevde kullanılmış"
 
-#: gimplify.c:6944
+#: gimplify.c:6947
 #, gcc-internal-format
 msgid "enclosing task"
 msgstr ""
 
-#: gimplify.c:7016
+#: gimplify.c:7019
 #, fuzzy, gcc-internal-format
 #| msgid "%qD not declared"
 msgid "%qE not specified in enclosing %qs"
 msgstr "%qD bildirilmemiş"
 
-#: gimplify.c:7018
+#: gimplify.c:7021
 #, fuzzy, gcc-internal-format
 #| msgid "error closing %s: %m"
 msgid "enclosing %qs"
 msgstr "%s kapatılırken hata: %m"
 
-#: gimplify.c:7143
+#: gimplify.c:7146
 #, gcc-internal-format
 msgid "%qE not specified in enclosing OpenACC %qs construct"
 msgstr ""
 
-#: gimplify.c:7145
+#: gimplify.c:7148
 #, gcc-internal-format
 msgid "enclosing OpenACC %qs construct"
 msgstr ""
 
-#: gimplify.c:7198
+#: gimplify.c:7201
 #, gcc-internal-format
 msgid "%qE with %<link%> clause used in %<routine%> function"
 msgstr ""
 
-#: gimplify.c:7206
+#: gimplify.c:7209
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE undeclared (first use in this function)"
 msgid "%qE requires a %<declare%> directive for use in a %<routine%> function"
 msgstr "%H%qE bildirilmemiş (bu işlevde ilk kullanımı)"
 
-#: gimplify.c:7272 gimplify.c:7872
+#: gimplify.c:7275 gimplify.c:7875
 #, fuzzy, gcc-internal-format
 #| msgid "variable %q+D declared %<inline%>"
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr "%<inline%> bildirimli %q+D değişkeni"
 
-#: gimplify.c:7293
+#: gimplify.c:7296
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr ""
 
-#: gimplify.c:7411 gimplify.c:7443
+#: gimplify.c:7414 gimplify.c:7446
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "iteration variable %qE is predetermined linear"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: gimplify.c:7414
+#: gimplify.c:7417
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "iteration variable %qE should be private"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: gimplify.c:7428
+#: gimplify.c:7431
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "iteration variable %qE should not be firstprivate"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: gimplify.c:7431
+#: gimplify.c:7434
 #, fuzzy, gcc-internal-format
 #| msgid "register variable %qD used in nested function"
 msgid "iteration variable %qE should not be reduction"
 msgstr "yazmaç değişkeni %qD iç işlevde kullanılmış"
 
-#: gimplify.c:7434
+#: gimplify.c:7437
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "iteration variable %qE should not be linear"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: gimplify.c:7437
+#: gimplify.c:7440
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "iteration variable %qE should not be lastprivate"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: gimplify.c:7440
+#: gimplify.c:7443
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "iteration variable %qE should not be private"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: gimplify.c:7742
+#: gimplify.c:7745
 #, gcc-internal-format
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr ""
 
-#: gimplify.c:7949
+#: gimplify.c:7952
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr ""
 
-#: gimplify.c:8160
+#: gimplify.c:8163
 #, gcc-internal-format
 msgid "%qE appears more than once in map clauses"
 msgstr ""
 
-#: gimplify.c:8464
+#: gimplify.c:8467
 #, fuzzy, gcc-internal-format
 #| msgid "local variable %qD may not appear in this context"
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr "yerel değişken %qD bu kapsamda görünemez"
 
-#: gimplify.c:8484
+#: gimplify.c:8487
 #, fuzzy, gcc-internal-format
 #| msgid "local variable %qD may not appear in this context"
 msgid "%s variable %qE is private in outer context"
 msgstr "yerel değişken %qD bu kapsamda görünemez"
 
-#: gimplify.c:8510
+#: gimplify.c:8513
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr "%<,%> veya %<;%> umuluyordu"
 
-#: gimplify.c:8775
+#: gimplify.c:8778
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr ""
 
-#: gimplify.c:8808
+#: gimplify.c:8811
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:9000
+#: gimplify.c:9003
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:9051
+#: gimplify.c:9054
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr ""
 
-#: gimplify.c:9133
+#: gimplify.c:9136
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to present_or_copy"
 msgstr ""
 
-#: gimplify.c:9278
+#: gimplify.c:9281
 #, fuzzy, gcc-internal-format
 #| msgid "invalid template declaration of %qD"
 msgid "invalid private reduction on %qE"
 msgstr "%qD şablon bildirimi geçersiz"
 
-#: gimplify.c:11103 omp-low.c:2791
+#: gimplify.c:11106 omp-low.c:2791
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: gimplify.c:11121
+#: gimplify.c:11124
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr ""
 
-#: gimplify.c:11134
+#: gimplify.c:11137
 #, fuzzy, gcc-internal-format
 #| msgid "incoming edge count does not match number of PHI arguments"
 msgid "number of variables in %<depend(sink)%> clause does not match number of iteration variables"
 msgstr "gelen ayrıt sayısı PHI argüman sayısı ile uyuşmuyor"
 
-#: gimplify.c:11147
+#: gimplify.c:11150
 #, gcc-internal-format
 msgid "more than one %<depend(source)%> clause on an %<ordered%> construct"
 msgstr ""
 
-#: gimplify.c:11158
+#: gimplify.c:11161
 #, gcc-internal-format
 msgid "%<depend(source)%> clause specified together with %<depend(sink:)%> clauses on the same construct"
 msgstr ""
 
-#: gimplify.c:12393
+#: gimplify.c:12396
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr "gimpleme başarısız"
 
-#: gimplify.c:12936
+#: gimplify.c:12939
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr "%qT %<...%> üzerinden aktarılırken %qT'ye yükseltgenir"
 
-#: gimplify.c:12941
+#: gimplify.c:12944
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr "(bu durumda %<va_arg%>'a %qT değil %qT akarılmalı)"
 
-#: gimplify.c:12948
+#: gimplify.c:12951
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr "Bu kodun bitiminde uygulama çıkacak"
@@ -24433,49 +24444,49 @@
 msgid "Max. number of generated reload insns per insn is achieved (%d)\n"
 msgstr ""
 
-#: lto-cgraph.c:1294
+#: lto-cgraph.c:1296
 #, gcc-internal-format, gfc-internal-format
 msgid "bytecode stream: found multiple instances of cgraph node with uid %d"
 msgstr ""
 
-#: lto-cgraph.c:1472
+#: lto-cgraph.c:1474
 #, gcc-internal-format
 msgid "bytecode stream: no caller found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1478
+#: lto-cgraph.c:1480
 #, gcc-internal-format
 msgid "bytecode stream: no callee found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1552
+#: lto-cgraph.c:1554
 #, gcc-internal-format
 msgid "bytecode stream: found empty cgraph node"
 msgstr ""
 
-#: lto-cgraph.c:1730
+#: lto-cgraph.c:1732
 #, gcc-internal-format, gfc-internal-format
 msgid "At most %i profile runs is supported. Perhaps corrupted profile?"
 msgstr ""
 
-#: lto-cgraph.c:1817
+#: lto-cgraph.c:1819
 #, gcc-internal-format, gfc-internal-format
 msgid "Profile information in %s corrupted"
 msgstr ""
 
-#: lto-cgraph.c:1855
+#: lto-cgraph.c:1857
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot find class %qs"
 msgid "cannot find LTO cgraph in %s"
 msgstr "sınıf %qs bulunamıyor"
 
-#: lto-cgraph.c:1865
+#: lto-cgraph.c:1867
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot find protocol declaration for %qs"
 msgid "cannot find LTO section refs in %s"
 msgstr "%qs için protokol bildirimi bulunamıyor"
 
-#: lto-cgraph.c:1946
+#: lto-cgraph.c:1948
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid rotate insn"
 msgid "invalid offload table in %s"
@@ -24551,92 +24562,98 @@
 msgid "bytecode stream in file %qs generated with LTO version %d.%d instead of the expected %d.%d"
 msgstr ""
 
-#: lto-wrapper.c:117
+#: lto-wrapper.c:118
 #, fuzzy, gcc-internal-format
 #| msgid "opening output file %s: %m"
 msgid "deleting LTRANS file %s: %m"
 msgstr "`%s' çıktı dosyasının açılması: %m"
 
-#: lto-wrapper.c:154
+#: lto-wrapper.c:155
 #, gcc-internal-format
 msgid "malformed COLLECT_GCC_OPTIONS"
 msgstr ""
 
-#: lto-wrapper.c:308
+#: lto-wrapper.c:309
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "created and used with different endianness"
 msgid "Option %s with different values"
 msgstr "farklı bayt sıralaması ile oluşturulup kullanılmış"
 
-#: lto-wrapper.c:392
+#: lto-wrapper.c:393
 #, gcc-internal-format, gfc-internal-format
 msgid "Option %s not used consistently in all LTO input files"
 msgstr ""
 
-#: lto-wrapper.c:832
+#: lto-wrapper.c:833
 #, gcc-internal-format, gfc-internal-format
 msgid "problem with building target image for %s\n"
 msgstr ""
 
-#: lto-wrapper.c:852
+#: lto-wrapper.c:853
 #, fuzzy, gcc-internal-format
 #| msgid "no input files"
 msgid "reading input file"
 msgstr "girdi dosyası yok"
 
-#: lto-wrapper.c:857
+#: lto-wrapper.c:858
 #, fuzzy, gcc-internal-format
 #| msgid "%s:error writing output file '%s'\n"
 msgid "writing output file"
 msgstr "%s: çıktı dosyası '%s' yazılırken hata.\n"
 
-#: lto-wrapper.c:889
+#: lto-wrapper.c:890
 #, gcc-internal-format
 msgid "installation error, can't find crtoffloadtable.o"
 msgstr ""
 
-#: lto-wrapper.c:1000 lto-wrapper.c:1012
+#: lto-wrapper.c:1001 lto-wrapper.c:1013
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s: %s"
 msgid "%s: %s\n"
 msgstr "%s: %s"
 
-#: lto-wrapper.c:1056
+#: lto-wrapper.c:1064
 #, fuzzy, gcc-internal-format
 #| msgid "environment variable DJGPP not defined"
 msgid "environment variable COLLECT_GCC must be set"
 msgstr "ortam değişkeni DJGPP atanmamış"
 
-#: lto-wrapper.c:1060 config/nvptx/mkoffload.c:363
+#: lto-wrapper.c:1068 config/nvptx/mkoffload.c:363
 #, fuzzy, gcc-internal-format
 #| msgid "environment variable DJGPP not defined"
 msgid "environment variable COLLECT_GCC_OPTIONS must be set"
 msgstr "ortam değişkeni DJGPP atanmamış"
 
-#: lto-wrapper.c:1229 lto-wrapper.c:1285
+#: lto-wrapper.c:1237 lto-wrapper.c:1293
 #, fuzzy, gcc-internal-format
 #| msgid "can't open %s: %m"
 msgid "cannot open %s: %m"
 msgstr "%s açılamıyor: %m"
 
-#: lto-wrapper.c:1232 lto-wrapper.c:1291
+#: lto-wrapper.c:1240 lto-wrapper.c:1299
 #, fuzzy, gcc-internal-format
 #| msgid "can%'t read %s: %m"
 msgid "cannot read %s: %m"
 msgstr "`%s' okunamıyor: %m"
 
-#: lto-wrapper.c:1259
+#: lto-wrapper.c:1267
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid operand to %%R"
 msgid "invalid format of %s"
 msgstr "%%R için terim geçersiz"
 
-#: lto-wrapper.c:1482
+#: lto-wrapper.c:1491
 #, fuzzy, gcc-internal-format
 #| msgid "fopen %s"
 msgid "fopen: %s: %m"
 msgstr "fopen %s"
 
+#: lto-wrapper.c:1508
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "Could not open output file '%s'\n"
+msgid "Corrupted ltrans output file %s"
+msgstr "Çıktı dosyası '%s' açılamadı\n"
+
 #: multiple_target.c:76
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
@@ -25004,13 +25021,13 @@
 msgid "unrecognized argument in option %qs"
 msgstr "komut satırı seçeneği \"%s\" tanınmıyor"
 
-#: opts-common.c:1198 config/i386/i386.c:3206
+#: opts-common.c:1198 config/i386/i386.c:3209
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "%qs özniteliğinin argümanı geçersiz"
 
-#: opts-common.c:1201 config/i386/i386.c:3209
+#: opts-common.c:1201 config/i386/i386.c:3212
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %qs are: %s"
@@ -25653,22 +25670,22 @@
 msgid "output operand %d must use %<&%> constraint"
 msgstr "çıktı terimi %d %<&%> kısıtını kullanmalı"
 
-#: regcprop.c:1187
+#: regcprop.c:1193
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad next_regno for empty chain (%u)"
 msgstr "validate_value_data: [%u] Boş zincir için next_regno hatalı (%u)"
 
-#: regcprop.c:1199
+#: regcprop.c:1205
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: Loop in regno chain (%u)"
 msgstr "validate_value_data: regno zinciri içinde döngü (%u)"
 
-#: regcprop.c:1202
+#: regcprop.c:1208
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad oldest_regno (%u)"
 msgstr "validate_value_data: [%u] oldest_regno hatalı (%u)"
 
-#: regcprop.c:1214
+#: regcprop.c:1220
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Non-empty reg in chain (%s %u %i)"
 msgstr "validate_value_data: [%u] zincir içinde boş olmayan yazmaç (%s %u %i)"
@@ -25717,7 +25734,7 @@
 msgstr "yazmaç iki genel yazmaç değişkeni için kullanılmış"
 
 #: reginfo.c:789 config/powerpcspe/powerpcspe.c:32259
-#: config/rs6000/rs6000.c:29453
+#: config/rs6000/rs6000.c:29530
 #, fuzzy, gcc-internal-format
 #| msgid "  conflict with %q+D"
 msgid "conflicts with %qD"
@@ -25970,159 +25987,164 @@
 msgid "function symbol is not function"
 msgstr "bir işlev döndüren işlev"
 
-#: symtab.c:1006
+#: symtab.c:1005
+#, gcc-internal-format
+msgid "inconsistent `ifunc' attribute"
+msgstr ""
+
+#: symtab.c:1013
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to variables"
 msgid "variable symbol is not variable"
 msgstr "%qs özniteliği sadece değişkenlere uygulanır"
 
-#: symtab.c:1012
+#: symtab.c:1019
 #, gcc-internal-format
 msgid "node has unknown type"
 msgstr ""
 
-#: symtab.c:1021
+#: symtab.c:1028
 #, gcc-internal-format
 msgid "node not found node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.c:1029
+#: symtab.c:1036
 #, gcc-internal-format
 msgid "node differs from node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.c:1038
+#: symtab.c:1045
 #, gcc-internal-format
 msgid "assembler name hash list corrupted"
 msgstr ""
 
-#: symtab.c:1051
+#: symtab.c:1058
 #, gcc-internal-format
 msgid "node not found in symtab assembler name hash"
 msgstr ""
 
-#: symtab.c:1058
+#: symtab.c:1065
 #, gcc-internal-format
 msgid "double linked list of assembler names corrupted"
 msgstr ""
 
-#: symtab.c:1063
+#: symtab.c:1070
 #, gcc-internal-format
 msgid "node has body_removed but is definition"
 msgstr ""
 
-#: symtab.c:1068
+#: symtab.c:1075
 #, fuzzy, gcc-internal-format
 #| msgid "called object %qE is not a function"
 msgid "node is analyzed but it is not a definition"
 msgstr "çağrılan nesne %qE bir işlev değil"
 
-#: symtab.c:1073
+#: symtab.c:1080
 #, gcc-internal-format
 msgid "node is alias but not implicit alias"
 msgstr ""
 
-#: symtab.c:1078
+#: symtab.c:1085
 #, fuzzy, gcc-internal-format
 #| msgid "%Jold-style function definition"
 msgid "node is alias but not definition"
 msgstr "%Jeski tarz işlev tanımı"
 
-#: symtab.c:1083
+#: symtab.c:1090
 #, gcc-internal-format
 msgid "node is weakref but not an transparent_alias"
 msgstr ""
 
-#: symtab.c:1088
+#: symtab.c:1095
 #, fuzzy, gcc-internal-format
 #| msgid "%Jold-style function definition"
 msgid "node is transparent_alias but not an alias"
 msgstr "%Jeski tarz işlev tanımı"
 
-#: symtab.c:1097
+#: symtab.c:1104
 #, gcc-internal-format
 msgid "node is in same_comdat_group list but has no comdat_group"
 msgstr ""
 
-#: symtab.c:1102
+#: symtab.c:1109
 #, gcc-internal-format
 msgid "same_comdat_group list across different groups"
 msgstr ""
 
-#: symtab.c:1107
+#: symtab.c:1114
 #, gcc-internal-format
 msgid "mixing different types of symbol in same comdat groups is not supported"
 msgstr ""
 
-#: symtab.c:1112
+#: symtab.c:1119
 #, gcc-internal-format
 msgid "node is alone in a comdat group"
 msgstr ""
 
-#: symtab.c:1119
+#: symtab.c:1126
 #, gcc-internal-format
 msgid "same_comdat_group is not a circular list"
 msgstr ""
 
-#: symtab.c:1134
+#: symtab.c:1141
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local symbol referred to by %s outside its comdat"
 msgstr ""
 
-#: symtab.c:1144
+#: symtab.c:1151
 #, gcc-internal-format
 msgid "implicit_section flag is set but section isn't"
 msgstr ""
 
-#: symtab.c:1151
+#: symtab.c:1158
 #, gcc-internal-format
 msgid "Both section and comdat group is set"
 msgstr ""
 
-#: symtab.c:1163
+#: symtab.c:1170
 #, gcc-internal-format
 msgid "Alias and target's section differs"
 msgstr ""
 
-#: symtab.c:1170
+#: symtab.c:1177
 #, gcc-internal-format
 msgid "Alias and target's comdat groups differs"
 msgstr ""
 
-#: symtab.c:1185
+#: symtab.c:1192
 #, gcc-internal-format
 msgid "Transparent alias and target's assembler names differs"
 msgstr ""
 
-#: symtab.c:1193
+#: symtab.c:1200
 #, gcc-internal-format
 msgid "Chained transparent aliases"
 msgstr ""
 
-#: symtab.c:1216 symtab.c:1253
+#: symtab.c:1223 symtab.c:1260
 #, fuzzy, gcc-internal-format
 #| msgid "verify_ssa failed"
 msgid "symtab_node::verify failed"
 msgstr "verify_ssa başarısız"
 
-#: symtab.c:1249
+#: symtab.c:1256
 #, gcc-internal-format
 msgid "Two symbols with same comdat_group are not linked by the same_comdat_group list."
 msgstr ""
 
-#: symtab.c:1658
+#: symtab.c:1665
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared as inline"
 msgid "function %q+D part of alias cycle"
 msgstr "işlev %q+D 'inline' olarak yeniden bildirilmiş"
 
-#: symtab.c:1660
+#: symtab.c:1667
 #, fuzzy, gcc-internal-format
 #| msgid "variable %q+D declared %<inline%>"
 msgid "variable %q+D part of alias cycle"
 msgstr "%<inline%> bildirimli %q+D değişkeni"
 
-#: symtab.c:1688
+#: symtab.c:1695
 #, gcc-internal-format
 msgid "section of alias %q+D must match section of its target"
 msgstr ""
@@ -27010,7 +27032,7 @@
 msgid "the first argument of a VEC_COND_EXPR must be of a boolean vector type of the same number of elements as the result"
 msgstr ""
 
-#: tree-cfg.c:4395 c/c-typeck.c:5212
+#: tree-cfg.c:4395 c/c-typeck.c:5217
 #, gcc-internal-format
 msgid "type mismatch in conditional expression"
 msgstr "koşullu ifadede tür uyumsuzluğu"
@@ -27399,25 +27421,25 @@
 msgid "missing edge %i->%i"
 msgstr "ayrıt %i->%i eksik"
 
-#: tree-cfg.c:9379
+#: tree-cfg.c:9388
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<noreturn%> function does return"
 msgid "%<noreturn%> function does return"
 msgstr "%H%<noreturn%> işlev değer döndürüyor"
 
-#: tree-cfg.c:9400 tree-cfg.c:9432
+#: tree-cfg.c:9409 tree-cfg.c:9441
 #, fuzzy, gcc-internal-format
 #| msgid "%Hcontrol reaches end of non-void function"
 msgid "control reaches end of non-void function"
 msgstr "%Hdenetim void olmayan işlevin sonunu aşıyor"
 
-#: tree-cfg.c:9498 cp/cvt.c:1039
+#: tree-cfg.c:9507 cp/cvt.c:1039
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgstr "%H%qD dönüş değeri yoksayılıyor, warn_unused_result özniteliği ile bildirilmiş"
 
-#: tree-cfg.c:9503 cp/cvt.c:1046
+#: tree-cfg.c:9512 cp/cvt.c:1046
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of function declared with attribute warn_unused_result"
 msgid "ignoring return value of function declared with attribute warn_unused_result"
@@ -27701,47 +27723,47 @@
 msgid "stmt volatile flag not up-to-date"
 msgstr ""
 
-#: tree-ssa-strlen.c:1975
+#: tree-ssa-strlen.c:1999
 msgid "%G%qD output truncated before terminating nul copying %E byte from a string of the same length"
 msgid_plural "%G%qD output truncated before terminating nul copying %E bytes from a string of the same length"
 msgstr[0] ""
 msgstr[1] ""
 
-#: tree-ssa-strlen.c:1989
+#: tree-ssa-strlen.c:2013
 msgid "%G%qD output truncated copying %E byte from a string of length %wu"
 msgid_plural "%G%qD output truncated copying %E bytes from a string of length %wu"
 msgstr[0] ""
 msgstr[1] ""
 
-#: tree-ssa-strlen.c:1996
+#: tree-ssa-strlen.c:2020
 msgid "%G%qD output truncated copying between %wu and %wu bytes from a string of length %wu"
 msgstr ""
 
-#: tree-ssa-strlen.c:2008
+#: tree-ssa-strlen.c:2032
 msgid "%G%qD output may be truncated copying %E byte from a string of length %wu"
 msgid_plural "%G%qD output may be truncated copying %E bytes from a string of length %wu"
 msgstr[0] ""
 msgstr[1] ""
 
-#: tree-ssa-strlen.c:2015 tree-ssa-strlen.c:2029
+#: tree-ssa-strlen.c:2039 tree-ssa-strlen.c:2053
 msgid "%G%qD output may be truncated copying between %wu and %wu bytes from a string of length %wu"
 msgstr ""
 
-#: tree-ssa-strlen.c:2150
+#: tree-ssa-strlen.c:2174
 msgid "%G%qD output truncated before terminating nul copying as many bytes from a string as its length"
 msgstr ""
 
-#: tree-ssa-strlen.c:2156
+#: tree-ssa-strlen.c:2180
 msgid "%G%qD specified bound depends on the length of the source argument"
 msgstr ""
 
-#: tree-ssa-strlen.c:2163
+#: tree-ssa-strlen.c:2187
 #, fuzzy, gcc-internal-format
 #| msgid "length modifier"
 msgid "length computed here"
 msgstr "uzunluk değiştirici"
 
-#: tree-ssa-uninit.c:191 varasm.c:331
+#: tree-ssa-uninit.c:191 varasm.c:342
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%qD was declared here"
@@ -27923,27 +27945,27 @@
 msgid "target specific builtin not available"
 msgstr ""
 
-#: tree-vect-generic.c:287
+#: tree-vect-generic.c:283
 #, gcc-internal-format
 msgid "vector operation will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-generic.c:290
+#: tree-vect-generic.c:286
 #, gcc-internal-format
 msgid "vector operation will be expanded in parallel"
 msgstr ""
 
-#: tree-vect-generic.c:341
+#: tree-vect-generic.c:337
 #, gcc-internal-format
 msgid "vector operation will be expanded with a single scalar operation"
 msgstr ""
 
-#: tree-vect-generic.c:941
+#: tree-vect-generic.c:937
 #, gcc-internal-format
 msgid "vector condition will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-generic.c:1373
+#: tree-vect-generic.c:1369
 #, gcc-internal-format
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr ""
@@ -27953,31 +27975,31 @@
 msgid "vectorization did not happen for a simd loop"
 msgstr ""
 
-#: tree-vrp.c:4930 tree-vrp.c:4974
+#: tree-vrp.c:4931 tree-vrp.c:4975
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "array subscript %E is above array bounds of %qT"
 msgstr "dizi indisi bir tamsayı değil"
 
-#: tree-vrp.c:4956
+#: tree-vrp.c:4957
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "array subscript [%E, %E] is outside array bounds of %qT"
 msgstr "dizi indisi bir tamsayı değil"
 
-#: tree-vrp.c:4988
+#: tree-vrp.c:4989
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "array subscript %E is below array bounds of %qT"
 msgstr "dizi indisi bir tamsayı değil"
 
-#: tree-vrp.c:5046
+#: tree-vrp.c:5047
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "array subscript %wi is below array bounds of %qT"
 msgstr "dizi indisi bir tamsayı değil"
 
-#: tree-vrp.c:5060
+#: tree-vrp.c:5061
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "array subscript %wu is above array bounds of %qT"
@@ -27993,97 +28015,97 @@
 msgid "side-effects element in no-side-effects CONSTRUCTOR"
 msgstr ""
 
-#: tree.c:7852
+#: tree.c:7856
 #, gcc-internal-format
 msgid "arrays of functions are not meaningful"
 msgstr "işlev dizileri anlamlı değil"
 
-#: tree.c:8019
+#: tree.c:8023
 #, gcc-internal-format
 msgid "function return type cannot be function"
 msgstr "işlevin dönüş türü işlev olamaz"
 
-#: tree.c:9327 tree.c:9412 tree.c:9473
+#: tree.c:9331 tree.c:9416 tree.c:9477
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "tree check: %s, have %s in %s, at %s:%d"
 msgstr "ağaç denetimi: %1$s, %4$s dosyasının %5$d. satırında %3$s işlevinde %2$s var"
 
-#: tree.c:9364
+#: tree.c:9368
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected none of %s, have %s in %s, at %s:%d"
 msgstr "ağaç denetimi: %1$s umulmuyordu, %4$s dosyasının %5$d. satırında %3$s işlevinde %2$s var"
 
-#: tree.c:9377
+#: tree.c:9381
 #, fuzzy, gcc-internal-format
 msgid "tree check: expected class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "ağaç denetimi: %1$qs sınıfı umuluyordu, %5$s dosyasının %6$d. satırında %4$s işlevinde %2$qs (%3$s) var"
 
-#: tree.c:9426
+#: tree.c:9430
 #, fuzzy, gcc-internal-format
 msgid "tree check: did not expect class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "ağaç denetimi: %1$qs sınıfı umuluyordu, %5$s dosyasının %6$d. satırında %4$s işlevinde %2$qs (%3$s) var"
 
-#: tree.c:9439
+#: tree.c:9443
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected omp_clause %s, have %s in %s, at %s:%d"
 msgstr "ağaç denetimi: %1$s umulmuyordu, %4$s dosyasının %5$d. satırında %3$s işlevinde %2$s var"
 
-#: tree.c:9499
+#: tree.c:9503
 #, fuzzy, gcc-internal-format
 msgid "tree check: expected tree that contains %qs structure, have %qs in %s, at %s:%d"
 msgstr "ağaç denetimi: %1$qs yapısını içeren ağaç umuluyordu, %4$s dosyasının %5$d. satırında %3$s işlevinde %2$qs var"
 
-#: tree.c:9513
+#: tree.c:9517
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_int_cst with %d elts in %s, at %s:%d"
 msgstr "ağaç denetimi: %4$s dosyasının %5$d. satırında %3$s işlevinde %2$d öğelik ağaç vektörünün %1$d. öğesine erişildi"
 
-#: tree.c:9525
+#: tree.c:9529
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_vec with %d elts in %s, at %s:%d"
 msgstr "ağaç denetimi: %4$s dosyasının %5$d. satırında %3$s işlevinde %2$d öğelik ağaç vektörünün %1$d. öğesine erişildi"
 
-#: tree.c:9538
+#: tree.c:9542
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of %s with %d operands in %s, at %s:%d"
 msgstr "ağaç denetimi: %5$s dosyasının %6$d. satırında %4$s işlevinde %3$d terimli %2$s düğümünün %1$d. terimine erişildi"
 
-#: tree.c:9551
+#: tree.c:9555
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of omp_clause %s with %d operands in %s, at %s:%d"
 msgstr "ağaç denetimi: %5$s dosyasının %6$d. satırında %4$s işlevinde %3$d terimli %2$s düğümünün %1$d. terimine erişildi"
 
-#: tree.c:12446
+#: tree.c:12450
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated"
 msgid "%qD is deprecated: %s"
 msgstr "%qs önerilmiyor"
 
-#: tree.c:12449
+#: tree.c:12453
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated"
 msgid "%qD is deprecated"
 msgstr "%qs önerilmiyor"
 
-#: tree.c:12473 tree.c:12495
+#: tree.c:12477 tree.c:12499
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated"
 msgid "%qE is deprecated: %s"
 msgstr "%qs önerilmiyor"
 
-#: tree.c:12476 tree.c:12498
+#: tree.c:12480 tree.c:12502
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated"
 msgid "%qE is deprecated"
 msgstr "%qs önerilmiyor"
 
-#: tree.c:12482 tree.c:12503
+#: tree.c:12486 tree.c:12507
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "type is deprecated"
 msgid "type is deprecated: %s"
 msgstr "tür önerilmiyor"
 
-#: tree.c:12485 tree.c:12506
+#: tree.c:12489 tree.c:12510
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr "tür önerilmiyor"
@@ -28108,247 +28130,247 @@
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.c:13043
+#: tree.c:13047
 #, gcc-internal-format, gfc-internal-format
 msgid "type variant differs by %s"
 msgstr ""
 
-#: tree.c:13084
+#: tree.c:13088
 #, gcc-internal-format
 msgid "type variant has different TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13086
+#: tree.c:13090
 #, gcc-internal-format
 msgid "type variant's TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13088
+#: tree.c:13092
 #, gcc-internal-format
 msgid "type's TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13108
+#: tree.c:13112
 #, gcc-internal-format
 msgid "type variant with TYPE_ALIAS_SET_KNOWN_P"
 msgstr ""
 
-#: tree.c:13121
+#: tree.c:13125
 #, gcc-internal-format
 msgid "type variant has different TYPE_VFIELD"
 msgstr ""
 
-#: tree.c:13157
+#: tree.c:13161
 #, gcc-internal-format
 msgid "type variant has different TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13159
+#: tree.c:13163
 #, gcc-internal-format
 msgid "type variant's TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13161
+#: tree.c:13165
 #, gcc-internal-format
 msgid "type's TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13199
+#: tree.c:13203
 #, gcc-internal-format
 msgid "type variant has different TYPE_FIELDS"
 msgstr ""
 
-#: tree.c:13201
+#: tree.c:13205
 #, fuzzy, gcc-internal-format
 #| msgid "%s:stamp mismatch with graph file\n"
 msgid "first mismatch is field"
 msgstr "%s: zaman damgası çizge dosyası ile çelişiyor\n"
 
-#: tree.c:13203
+#: tree.c:13207
 #, gcc-internal-format
 msgid "and field"
 msgstr ""
 
-#: tree.c:13220
+#: tree.c:13224
 #, gcc-internal-format
 msgid "type variant has different TREE_TYPE"
 msgstr ""
 
-#: tree.c:13222 tree.c:13233
+#: tree.c:13226 tree.c:13237
 #, gcc-internal-format
 msgid "type variant's TREE_TYPE"
 msgstr ""
 
-#: tree.c:13224 tree.c:13235
+#: tree.c:13228 tree.c:13239
 #, gcc-internal-format
 msgid "type's TREE_TYPE"
 msgstr ""
 
-#: tree.c:13231
+#: tree.c:13235
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "type is not compatible with its variant"
 msgstr "-march=%s seçilen ABI ile uyumsuz"
 
-#: tree.c:13534
+#: tree.c:13538
 #, fuzzy, gcc-internal-format
 #| msgid "environment variable DJGPP not defined"
 msgid "Main variant is not defined"
 msgstr "ortam değişkeni DJGPP atanmamış"
 
-#: tree.c:13539
+#: tree.c:13543
 #, gcc-internal-format
 msgid "TYPE_MAIN_VARIANT has different TYPE_MAIN_VARIANT"
 msgstr ""
 
-#: tree.c:13551
+#: tree.c:13555
 #, gcc-internal-format
 msgid "TYPE_CANONICAL has different TYPE_CANONICAL"
 msgstr ""
 
-#: tree.c:13569
+#: tree.c:13573
 #, gcc-internal-format
 msgid "TYPE_CANONICAL is not compatible"
 msgstr ""
 
-#: tree.c:13577
+#: tree.c:13581
 #, gcc-internal-format
 msgid "TYPE_MODE of TYPE_CANONICAL is not compatible"
 msgstr ""
 
-#: tree.c:13583
+#: tree.c:13587
 #, gcc-internal-format
 msgid "TYPE_CANONICAL of main variant is not main variant"
 msgstr ""
 
-#: tree.c:13599
+#: tree.c:13603
 #, gcc-internal-format
 msgid "TYPE_VFIELD is not FIELD_DECL nor TREE_LIST"
 msgstr ""
 
-#: tree.c:13609
+#: tree.c:13613
 #, gcc-internal-format
 msgid "TYPE_NEXT_PTR_TO is not POINTER_TYPE"
 msgstr ""
 
-#: tree.c:13619
+#: tree.c:13623
 #, gcc-internal-format
 msgid "TYPE_NEXT_REF_TO is not REFERENCE_TYPE"
 msgstr ""
 
-#: tree.c:13640
+#: tree.c:13644
 #, gcc-internal-format
 msgid "TYPE_BINFO is not TREE_BINFO"
 msgstr ""
 
-#: tree.c:13646
+#: tree.c:13650
 #, gcc-internal-format
 msgid "TYPE_BINFO type is not TYPE_MAIN_VARIANT"
 msgstr ""
 
-#: tree.c:13657
+#: tree.c:13661
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not record nor union"
 msgstr ""
 
-#: tree.c:13668
+#: tree.c:13672
 #, gcc-internal-format
 msgid "TYPE_OFFSET_BASETYPE is not record nor union"
 msgstr ""
 
-#: tree.c:13686
+#: tree.c:13690
 #, gcc-internal-format
 msgid "TYPE_ARRAY_MAX_SIZE not INTEGER_CST"
 msgstr ""
 
-#: tree.c:13693
+#: tree.c:13697
 #, gcc-internal-format
 msgid "TYPE_MAX_VALUE_RAW non-NULL"
 msgstr ""
 
-#: tree.c:13700
+#: tree.c:13704
 #, gcc-internal-format
 msgid "TYPE_LANG_SLOT_1 (binfo) field is non-NULL"
 msgstr ""
 
-#: tree.c:13716
+#: tree.c:13720
 #, gcc-internal-format
 msgid "Enum value is not CONST_DECL or INTEGER_CST"
 msgstr ""
 
-#: tree.c:13724
+#: tree.c:13728
 #, gcc-internal-format
 msgid "Enum value type is not INTEGER_TYPE nor convertible to the enum"
 msgstr ""
 
-#: tree.c:13731
+#: tree.c:13735
 #, gcc-internal-format
 msgid "Enum value name is not IDENTIFIER_NODE"
 msgstr ""
 
-#: tree.c:13741
+#: tree.c:13745
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs has non-integer type"
 msgid "Array TYPE_DOMAIN is not integer type"
 msgstr "%qs dizisinin boyutu tamsayı tür değil"
 
-#: tree.c:13750
+#: tree.c:13754
 #, fuzzy, gcc-internal-format
 #| msgid "field %qs has incomplete type"
 msgid "TYPE_FIELDS defined in incomplete type"
 msgstr "%qs alanı tamamlanmamış türde"
 
-#: tree.c:13772
+#: tree.c:13776
 #, gcc-internal-format
 msgid "Wrong tree in TYPE_FIELDS list"
 msgstr ""
 
-#: tree.c:13787
+#: tree.c:13791
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is %i while TYPE_CACHED_VALUES is %p"
 msgstr ""
 
-#: tree.c:13793
+#: tree.c:13797
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES is not TREE_VEC"
 msgstr ""
 
-#: tree.c:13806
+#: tree.c:13810
 #, gcc-internal-format
 msgid "wrong TYPE_CACHED_VALUES entry"
 msgstr ""
 
-#: tree.c:13819
+#: tree.c:13823
 #, gcc-internal-format
 msgid "TREE_PURPOSE is non-NULL in TYPE_ARG_TYPES list"
 msgstr ""
 
-#: tree.c:13825
+#: tree.c:13829
 #, gcc-internal-format
 msgid "Wrong entry in TYPE_ARG_TYPES list"
 msgstr ""
 
-#: tree.c:13832
+#: tree.c:13836
 #, gcc-internal-format
 msgid "TYPE_VALUES_RAW field is non-NULL"
 msgstr ""
 
-#: tree.c:13844
+#: tree.c:13848
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is set while it should not"
 msgstr ""
 
-#: tree.c:13850
+#: tree.c:13854
 #, gcc-internal-format
 msgid "TYPE_STRING_FLAG is set on wrong type code"
 msgstr ""
 
-#: tree.c:13860
+#: tree.c:13864
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not main variant"
 msgstr ""
 
-#: tree.c:13867
+#: tree.c:13871
 #, fuzzy, gcc-internal-format
 #| msgid "verify_stmts failed"
 msgid "verify_type failed"
@@ -28376,199 +28398,199 @@
 msgid "corrupted value profile: %s profile counter (%d out of %d) inconsistent with basic-block count (%d)"
 msgstr "%HBozuk değer profili: %s profilcinin ne sayısı varsa (%d) BB sayısı (%d) ile uyuşmuyor"
 
-#: var-tracking.c:7166
+#: var-tracking.c:7184
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded with -fvar-tracking-assignments, retrying without"
 msgstr ""
 
-#: var-tracking.c:7170
+#: var-tracking.c:7188
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded"
 msgstr ""
 
-#: varasm.c:326
+#: varasm.c:337
 #, fuzzy, gcc-internal-format
 #| msgid "%+D causes a section type conflict"
 msgid "%+qD causes a section type conflict with %qD"
 msgstr "%+D bir bölüm türü çelişkiye sebep oluyor"
 
-#: varasm.c:329
+#: varasm.c:340
 #, fuzzy, gcc-internal-format
 #| msgid "  conflict with %q+D"
 msgid "section type conflict with %qD"
 msgstr "  %q+D ile çelişiyor"
 
-#: varasm.c:334
+#: varasm.c:345
 #, fuzzy, gcc-internal-format
 #| msgid "%+D causes a section type conflict"
 msgid "%+qD causes a section type conflict"
 msgstr "%+D bir bölüm türü çelişkiye sebep oluyor"
 
-#: varasm.c:336
+#: varasm.c:347
 #, fuzzy, gcc-internal-format
 #| msgid "%+D causes a section type conflict"
 msgid "section type conflict"
 msgstr "%+D bir bölüm türü çelişkiye sebep oluyor"
 
-#: varasm.c:1019
+#: varasm.c:1030
 #, fuzzy, gcc-internal-format
 #| msgid "alignment of %q+D is greater than maximum object file alignment.  Using %d"
 msgid "alignment of %q+D is greater than maximum object file alignment %d"
 msgstr "%q+D hizalaması azami nesne dosyası hizalamasından daha büyük. %d kullanılıyor"
 
-#: varasm.c:1172
+#: varasm.c:1183
 #, fuzzy, gcc-internal-format
 #| msgid "Put zero initialized data in the bss section"
 msgid "only zero initializers are allowed in section %qs"
 msgstr "bss bölümüne sıfır ilklendirmeli veri yerleştirilir"
 
-#: varasm.c:1378 varasm.c:1387
+#: varasm.c:1389 varasm.c:1398
 #, gcc-internal-format
 msgid "register name not specified for %q+D"
 msgstr "%q+D için yazmaç ismi belirtilmemiş"
 
-#: varasm.c:1389
+#: varasm.c:1400
 #, gcc-internal-format
 msgid "invalid register name for %q+D"
 msgstr "%q+D için yazmaç ismi geçersiz"
 
-#: varasm.c:1391
+#: varasm.c:1402
 #, gcc-internal-format
 msgid "data type of %q+D isn%'t suitable for a register"
 msgstr "%q+D veri türü bir yazmaç için uygun değil"
 
-#: varasm.c:1394
+#: varasm.c:1405
 #, fuzzy, gcc-internal-format
 #| msgid "register specified for %q+D isn%'t suitable for data type"
 msgid "the register specified for %q+D cannot be accessed by the current target"
 msgstr "%q+D için belirtilen yazmaç, veri türü için uygun değil"
 
-#: varasm.c:1397
+#: varasm.c:1408
 #, fuzzy, gcc-internal-format
 #| msgid "register used for two global register variables"
 msgid "the register specified for %q+D is not general enough to be used as a register variable"
 msgstr "yazmaç iki genel yazmaç değişkeni için kullanılmış"
 
-#: varasm.c:1400
+#: varasm.c:1411
 #, gcc-internal-format
 msgid "register specified for %q+D isn%'t suitable for data type"
 msgstr "%q+D için belirtilen yazmaç, veri türü için uygun değil"
 
-#: varasm.c:1410
+#: varasm.c:1421
 #, gcc-internal-format
 msgid "global register variable has initial value"
 msgstr "genel yazmaç değişkeni ilk değer içeriyor"
 
-#: varasm.c:1414
+#: varasm.c:1425
 #, gcc-internal-format
 msgid "optimization may eliminate reads and/or writes to register variables"
 msgstr "eniyileme yazmaç dağişkenleri üzerinde okuma/yazma işlemlerini eleyebilir"
 
-#: varasm.c:1460
+#: varasm.c:1471
 #, gcc-internal-format
 msgid "register name given for non-register variable %q+D"
 msgstr "yazmaç olmayan değişken %q+D için yazmaç ismi verilmiş"
 
-#: varasm.c:1870
+#: varasm.c:1881
 #, gcc-internal-format
 msgid "Patchable function entry > size"
 msgstr ""
 
-#: varasm.c:2069
+#: varasm.c:2080
 #, gcc-internal-format
 msgid "thread-local COMMON data not implemented"
 msgstr "yerel evreli COMMON verisi henüz gerçeklenmedi"
 
-#: varasm.c:2102
+#: varasm.c:2113
 #, gcc-internal-format
 msgid "requested alignment for %q+D is greater than implemented alignment of %wu"
 msgstr "%q+D için istenen hizalama gerçeklenmiş hizalama %wu'den daha büyük"
 
-#: varasm.c:2205 c/c-decl.c:5027 c/c-parser.c:1534
+#: varasm.c:2216 c/c-decl.c:5027 c/c-parser.c:1534
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t known"
 msgstr "%q+D nin saklama uzunluğu bilinmiyor"
 
-#: varasm.c:4910
+#: varasm.c:4921
 #, fuzzy, gcc-internal-format
 #| msgid "initializer for integer value is too complicated"
 msgid "initializer for integer/fixed-point value is too complicated"
 msgstr "tamsayı değer için ilklendirici fazla karmaşık"
 
-#: varasm.c:4915
+#: varasm.c:4926
 #, gcc-internal-format
 msgid "initializer for floating value is not a floating constant"
 msgstr "gerçel sayı için ilklendirici bir gerçel sayı sabit değil"
 
-#: varasm.c:5227
+#: varasm.c:5238
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initial value for member %qs"
 msgid "invalid initial value for member %qE"
 msgstr "üye %qs için ilk değer geçersiz"
 
-#: varasm.c:5487
+#: varasm.c:5498
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after being called"
 msgid "%+qD declared weak after being used"
 msgstr "%q+D çağrıdan sonra satıriçi bildirilmiş"
 
-#: varasm.c:5539
+#: varasm.c:5550
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D outside of class is not definition"
 msgid "weak declaration of %q+D being applied to a already existing, static definition"
 msgstr "sınıf dışında %q#D bildirimi bir tanım değildir"
 
-#: varasm.c:5575
+#: varasm.c:5586
 #, gcc-internal-format
 msgid "weak declaration of %q+D must be public"
 msgstr "%q+D zayıf bildirimi 'public' olmalı"
 
-#: varasm.c:5579
+#: varasm.c:5590
 #, gcc-internal-format
 msgid "weak declaration of %q+D not supported"
 msgstr "%q+D zayıf bildirimi desteklenmiyor"
 
-#: varasm.c:5608 varasm.c:5912
+#: varasm.c:5619 varasm.c:5926
 #, gcc-internal-format
 msgid "only weak aliases are supported in this configuration"
 msgstr "bu yapılandırmada sadece zayıf takma adlar destekleniyor"
 
-#: varasm.c:5802
+#: varasm.c:5813
 #, fuzzy, gcc-internal-format
 #| msgid "%Jweakref is not supported in this configuration"
 msgid "weakref is not supported in this configuration"
 msgstr "%Jweakref bu yapılandırmada desteklenmiyor"
 
-#: varasm.c:5834
+#: varasm.c:5846
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "ifunc is not supported on this target"
 msgstr "bu hedefte yığıt sınırları desteklenmiyor"
 
-#: varasm.c:5892
+#: varasm.c:5904
 #, gcc-internal-format
 msgid "weakref %q+D ultimately targets itself"
 msgstr "weakref %q+D eninde sonunda kendini hedefliyor"
 
-#: varasm.c:5894
+#: varasm.c:5906
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member function %qD to have static linkage"
 msgid "weakref %q+D must have static linkage"
 msgstr "üye işlev %qD static ilintilemeli olarak bildirilemez"
 
-#: varasm.c:5901
+#: varasm.c:5913
 #, fuzzy, gcc-internal-format
 #| msgid "%Jalias definitions not supported in this configuration"
 msgid "alias definitions not supported in this configuration"
 msgstr "%Jtakma ad tanımlamaları bu yapılandırmada desteklenmiyor"
 
-#: varasm.c:5909
+#: varasm.c:5923
 #, fuzzy, gcc-internal-format
 #| msgid "-m%s not supported in this configuration"
 msgid "ifunc is not supported in this configuration"
 msgstr "-m%s bu yapılandırmada desteklenmiyor"
 
-#: varasm.c:6127 config/sol2.c:159 config/i386/winnt.c:265
+#: varasm.c:6141 config/sol2.c:159 config/i386/winnt.c:265
 #, gcc-internal-format
 msgid "visibility attribute not supported in this configuration; ignored"
 msgstr "görünürlük özniteliği bu yapılandırmada desteklenmiyor; yoksayıldı"
@@ -28646,194 +28668,200 @@
 msgid "bytecode stream: tag %s is not in the expected range [%s, %s]"
 msgstr ""
 
-#: c-family/c-attribs.c:529
+#: c-family/c-attribs.c:524
 #, fuzzy, gcc-internal-format
+#| msgid "%qE attribute ignored for %qE"
+msgid "%qE attribute ignored for type %qT"
+msgstr "%qE özniteliği %qE için yoksayıldı"
+
+#: c-family/c-attribs.c:536
+#, fuzzy, gcc-internal-format
 msgid "%qE attribute ignored for field of type %qT"
 msgstr "%2$qT türünde alan için %1$qE özniteliği yoksayıldı"
 
-#: c-family/c-attribs.c:696
+#: c-family/c-attribs.c:706
 #, fuzzy, gcc-internal-format
 #| msgid "visibility argument not a string"
 msgid "no_sanitize argument not a string"
 msgstr "visibility argümanı bir dizge değil"
 
-#: c-family/c-attribs.c:826 ada/gcc-interface/utils.c:6235
+#: c-family/c-attribs.c:837 ada/gcc-interface/utils.c:6240
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "%qE attribute ignored due to conflict with attribute %qs"
 msgstr "%s özniteliği ile %s özniteliği %L'de çelişiyor"
 
-#: c-family/c-attribs.c:875
+#: c-family/c-attribs.c:886
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "%qE attribute ignored. Use -fcf-protection option to enable it"
 msgstr "%s özniteliği ile %s özniteliği %L'de çelişiyor"
 
-#: c-family/c-attribs.c:914 c-family/c-attribs.c:920 c-family/c-attribs.c:3388
-#: c-family/c-attribs.c:3423 c-family/c-attribs.c:3429
+#: c-family/c-attribs.c:925 c-family/c-attribs.c:931 c-family/c-attribs.c:3399
+#: c-family/c-attribs.c:3434 c-family/c-attribs.c:3440
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "%qE attribute ignored due to conflict with %qs attribute"
 msgstr "%s özniteliği ile %s özniteliği %L'de çelişiyor"
 
-#: c-family/c-attribs.c:976 brig/brig-lang.c:482 lto/lto-lang.c:288
+#: c-family/c-attribs.c:987 brig/brig-lang.c:482 lto/lto-lang.c:288
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute have effect only on public objects"
 msgid "%qE attribute has no effect on unit local functions"
 msgstr "%qE özniteliği sadece genel nesnelerde etkilidir"
 
-#: c-family/c-attribs.c:1130
+#: c-family/c-attribs.c:1141
 #, gcc-internal-format
 msgid "%qE attribute have effect only on public objects"
 msgstr "%qE özniteliği sadece genel nesnelerde etkilidir"
 
-#: c-family/c-attribs.c:1159
+#: c-family/c-attribs.c:1170
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to variables"
 msgid "%qE attribute only affects top level objects"
 msgstr "%qs özniteliği sadece değişkenlere uygulanır"
 
-#: c-family/c-attribs.c:1198 c-family/c-attribs.c:2682
+#: c-family/c-attribs.c:1209 c-family/c-attribs.c:2693
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "%qE attribute on function returning %<void%>"
 msgstr "void olmayan dönüşlü işlevde `return' deyimi yok"
 
-#: c-family/c-attribs.c:1221 c-family/c-pragma.c:419
+#: c-family/c-attribs.c:1232 c-family/c-pragma.c:419
 #, gcc-internal-format
 msgid "scalar_storage_order is not supported because endianness is not uniform"
 msgstr ""
 
-#: c-family/c-attribs.c:1238
+#: c-family/c-attribs.c:1249
 #, gcc-internal-format
 msgid "scalar_storage_order argument must be one of \"big-endian\" or \"little-endian\""
 msgstr ""
 
-#: c-family/c-attribs.c:1334
+#: c-family/c-attribs.c:1345
 #, fuzzy, gcc-internal-format
 #| msgid "trampolines not supported"
 msgid "destructor priorities are not supported"
 msgstr "trampolines desteklenmiyor"
 
-#: c-family/c-attribs.c:1336
+#: c-family/c-attribs.c:1347
 #, fuzzy, gcc-internal-format
 #| msgid "trampolines not supported"
 msgid "constructor priorities are not supported"
 msgstr "trampolines desteklenmiyor"
 
-#: c-family/c-attribs.c:1358
+#: c-family/c-attribs.c:1369
 #, gcc-internal-format, gfc-internal-format
 msgid "destructor priorities from 0 to %d are reserved for the implementation"
 msgstr ""
 
-#: c-family/c-attribs.c:1363
+#: c-family/c-attribs.c:1374
 #, gcc-internal-format, gfc-internal-format
 msgid "constructor priorities from 0 to %d are reserved for the implementation"
 msgstr ""
 
-#: c-family/c-attribs.c:1371
+#: c-family/c-attribs.c:1382
 #, gcc-internal-format, gfc-internal-format
 msgid "destructor priorities must be integers from 0 to %d inclusive"
 msgstr ""
 
-#: c-family/c-attribs.c:1374
+#: c-family/c-attribs.c:1385
 #, gcc-internal-format, gfc-internal-format
 msgid "constructor priorities must be integers from 0 to %d inclusive"
 msgstr ""
 
-#: c-family/c-attribs.c:1527
+#: c-family/c-attribs.c:1538
 #, fuzzy, gcc-internal-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown machine mode %qE"
 msgstr "%qs makine kipi bilinmiyor"
 
-#: c-family/c-attribs.c:1557
+#: c-family/c-attribs.c:1568
 #, gcc-internal-format
 msgid "specifying vector types with __attribute__ ((mode)) is deprecated"
 msgstr "vektör türlerin __attribute__ ((kip)) ile belirtilmesi artık önerilmiyor"
 
-#: c-family/c-attribs.c:1560
+#: c-family/c-attribs.c:1571
 #, gcc-internal-format
 msgid "use __attribute__ ((vector_size)) instead"
 msgstr "onun yerine __attribute__ ((vektör_boyutu)) kullanın"
 
-#: c-family/c-attribs.c:1569
+#: c-family/c-attribs.c:1580
 #, gcc-internal-format
 msgid "unable to emulate %qs"
 msgstr "%qs öykünümü mümkün değil"
 
-#: c-family/c-attribs.c:1582
+#: c-family/c-attribs.c:1593
 #, gcc-internal-format
 msgid "invalid pointer mode %qs"
 msgstr "gösterici kipi olarak %qs geçersiz"
 
-#: c-family/c-attribs.c:1599
+#: c-family/c-attribs.c:1610
 #, gcc-internal-format
 msgid "signedness of type and machine mode %qs don%'t match"
 msgstr ""
 
-#: c-family/c-attribs.c:1610
+#: c-family/c-attribs.c:1621
 #, gcc-internal-format
 msgid "no data type for mode %qs"
 msgstr "%qs kipi için bir veri türü yok"
 
-#: c-family/c-attribs.c:1620
+#: c-family/c-attribs.c:1631
 #, gcc-internal-format
 msgid "cannot use mode %qs for enumeral types"
 msgstr "%qs kipi sembolik sabit türler için kullanılamaz"
 
-#: c-family/c-attribs.c:1647
+#: c-family/c-attribs.c:1658
 #, gcc-internal-format
 msgid "mode %qs applied to inappropriate type"
 msgstr "%qs kipi ilgisiz türe uygulanmış"
 
-#: c-family/c-attribs.c:1669
+#: c-family/c-attribs.c:1680
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsection attributes are not supported for this target"
 msgid "section attributes are not supported for this target"
 msgstr "%Jbölüm öznitelikleri bu hedef için desteklenmiyor"
 
-#: c-family/c-attribs.c:1675
+#: c-family/c-attribs.c:1686
 #, gcc-internal-format
 msgid "section attribute not allowed for %q+D"
 msgstr "bölüm özniteliğine %q+D için izin verilmez"
 
-#: c-family/c-attribs.c:1681
+#: c-family/c-attribs.c:1692
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute argument not a string constant"
 msgid "section attribute argument not a string constant"
 msgstr "%qs öznitelik argümanı bir dizge sabit değil"
 
-#: c-family/c-attribs.c:1690
+#: c-family/c-attribs.c:1701
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsection attribute cannot be specified for local variables"
 msgid "section attribute cannot be specified for local variables"
 msgstr "%Jbölüm özniteliği yerel değişkenler için belirtilmiş olamaz"
 
-#: c-family/c-attribs.c:1700 config/bfin/bfin.c:4806 config/bfin/bfin.c:4857
+#: c-family/c-attribs.c:1711 config/bfin/bfin.c:4806 config/bfin/bfin.c:4857
 #: config/bfin/bfin.c:4883 config/bfin/bfin.c:4896
 #, gcc-internal-format
 msgid "section of %q+D conflicts with previous declaration"
 msgstr "%q+D bölümü önceki bildirimle çelişiyor"
 
-#: c-family/c-attribs.c:1708
+#: c-family/c-attribs.c:1719
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D cannot be overloaded"
 msgid "section of %q+D cannot be overridden"
 msgstr "%q+#D,"
 
-#: c-family/c-attribs.c:1773
+#: c-family/c-attribs.c:1784
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "requested alignment is too large"
 msgid "requested alignment %d is larger than %d"
 msgstr "istenen hizalama çok büyük"
 
-#: c-family/c-attribs.c:1866
+#: c-family/c-attribs.c:1877
 #, gcc-internal-format
 msgid "alignment may not be specified for %q+D"
 msgstr "hizalama, %q+D için belirtilmiş olmayabilir"
 
-#: c-family/c-attribs.c:1886
+#: c-family/c-attribs.c:1897
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "ignoring attribute %<%E (%u)%> because it conflicts with attribute %<%E (%u)%>"
@@ -28840,317 +28868,317 @@
 msgstr "%s özniteliği ile %s özniteliği %L'de çelişiyor"
 
 #. Do not error out for attribute warn_if_not_aligned.
-#: c-family/c-attribs.c:1891 c-family/c-attribs.c:1920
+#: c-family/c-attribs.c:1902 c-family/c-attribs.c:1931
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "alignment for %q+D must be at least %d"
 msgstr "`%s' için fiili argüman bir gösterici olmalı (%L'de)"
 
-#: c-family/c-attribs.c:1916
+#: c-family/c-attribs.c:1927
 #, gcc-internal-format
 msgid "alignment for %q+D was previously specified as %d and may not be decreased"
 msgstr ""
 
-#: c-family/c-attribs.c:1943
+#: c-family/c-attribs.c:1954
 #, fuzzy, gcc-internal-format
 #| msgid "alignment may not be specified for %q+D"
 msgid "%<warn_if_not_aligned%> may not be specified for %q+D"
 msgstr "hizalama, %q+D için belirtilmiş olmayabilir"
 
-#: c-family/c-attribs.c:1986
+#: c-family/c-attribs.c:1997
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "inline function %q+D declared weak"
 msgstr "yerleşik işlev `%q+D işlev olarak bildirilmemiş"
 
-#: c-family/c-attribs.c:1991
+#: c-family/c-attribs.c:2002
 #, fuzzy, gcc-internal-format
 #| msgid "function %qs cannot be declared %<mutable%>"
 msgid "indirect function %q+D cannot be declared weak"
 msgstr "işlev %qs %<mutable%> olarak bildirilemez"
 
-#: c-family/c-attribs.c:2015
+#: c-family/c-attribs.c:2026
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to functions"
 msgid "%qE attribute is only applicable on functions"
 msgstr "%qs özniteliği sadece işlevlere uygulanır"
 
-#: c-family/c-attribs.c:2046
+#: c-family/c-attribs.c:2057
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D defined both normally and as an alias"
 msgid "%q+D defined both normally and as %qE attribute"
 msgstr "%q+D hem normal hem de bir rumuz olarak tanımlanmış"
 
-#: c-family/c-attribs.c:2054
+#: c-family/c-attribs.c:2065
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D cannot be declared"
 msgid "weak %q+D cannot be defined %qE"
 msgstr "%q+#D bildirilemez"
 
-#: c-family/c-attribs.c:2071 c-family/c-attribs.c:2582
+#: c-family/c-attribs.c:2082 c-family/c-attribs.c:2593
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute argument not a string constant"
 msgid "attribute %qE argument not a string"
 msgstr "%qs öznitelik argümanı bir dizge sabit değil"
 
-#: c-family/c-attribs.c:2106
+#: c-family/c-attribs.c:2117
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after being called"
 msgid "%+qD declared alias after being used"
 msgstr "%q+D çağrıdan sonra satıriçi bildirilmiş"
 
-#: c-family/c-attribs.c:2108
+#: c-family/c-attribs.c:2119
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after being called"
 msgid "%+qD declared ifunc after being used"
 msgstr "%q+D çağrıdan sonra satıriçi bildirilmiş"
 
-#: c-family/c-attribs.c:2159
+#: c-family/c-attribs.c:2170
 #, fuzzy, gcc-internal-format
 #| msgid "function %qs cannot be declared %<mutable%>"
 msgid "indirect function %q+D cannot be declared weakref"
 msgstr "işlev %qs %<mutable%> olarak bildirilemez"
 
-#: c-family/c-attribs.c:2181
+#: c-family/c-attribs.c:2192
 #, fuzzy, gcc-internal-format
 #| msgid "%Jweakref attribute must appear before alias attribute"
 msgid "weakref attribute must appear before alias attribute"
 msgstr "%Jweakref özniteliği alias özniteliğinden önce olmalı"
 
-#: c-family/c-attribs.c:2193
+#: c-family/c-attribs.c:2204
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after being called"
 msgid "%+qD declared weakref after being used"
 msgstr "%q+D çağrıdan sonra satıriçi bildirilmiş"
 
-#: c-family/c-attribs.c:2217
+#: c-family/c-attribs.c:2228
 #, gcc-internal-format
 msgid "%qE attribute ignored on non-class types"
 msgstr "%qE özniteliği sınıf türleri dışında yoksayılır"
 
-#: c-family/c-attribs.c:2223
+#: c-family/c-attribs.c:2234
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute ignored because %qT is already defined"
 msgstr "%qE özniteliği sınıf türleri dışında yoksayılır"
 
-#: c-family/c-attribs.c:2236
+#: c-family/c-attribs.c:2247
 #, gcc-internal-format
 msgid "visibility argument not a string"
 msgstr "visibility argümanı bir dizge değil"
 
-#: c-family/c-attribs.c:2248
+#: c-family/c-attribs.c:2259
 #, gcc-internal-format
 msgid "%qE attribute ignored on types"
 msgstr "%qE özniteliği veri türlerinde yoksayılır"
 
-#: c-family/c-attribs.c:2264
+#: c-family/c-attribs.c:2275
 #, gcc-internal-format
 msgid "visibility argument must be one of \"default\", \"hidden\", \"protected\" or \"internal\""
 msgstr "visibility argümanı \"default\", \"hidden\", \"protected\" veya \"internal\" değerlerinden biri olmalıdır"
 
-#: c-family/c-attribs.c:2275
+#: c-family/c-attribs.c:2286
 #, fuzzy, gcc-internal-format
 #| msgid "%qD redeclared with different access"
 msgid "%qD redeclared with different visibility"
 msgstr "%qD farklı erişimle tekrar bildirilmiş"
 
-#: c-family/c-attribs.c:2278 c-family/c-attribs.c:2282
+#: c-family/c-attribs.c:2289 c-family/c-attribs.c:2293
 #, gcc-internal-format
 msgid "%qD was declared %qs which implies default visibility"
 msgstr ""
 
-#: c-family/c-attribs.c:2320
+#: c-family/c-attribs.c:2331
 #, gcc-internal-format
 msgid "tls_model argument not a string"
 msgstr "tls_model argümanı bir dizge değil"
 
-#: c-family/c-attribs.c:2333
+#: c-family/c-attribs.c:2344
 #, gcc-internal-format
 msgid "tls_model argument must be one of \"local-exec\", \"initial-exec\", \"local-dynamic\" or \"global-dynamic\""
 msgstr "tls_model argümanı \"local-exec\", \"initial-exec\", \"local-dynamic\" veya \"global-dynamic\" değerlerinden biri olmalı"
 
-#: c-family/c-attribs.c:2353 c-family/c-attribs.c:2656
-#: c-family/c-attribs.c:3497 config/m32c/m32c.c:2944
+#: c-family/c-attribs.c:2364 c-family/c-attribs.c:2667
+#: c-family/c-attribs.c:3508 config/m32c/m32c.c:2944
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qE attribute applies only to functions"
 msgid "%qE attribute applies only to functions"
 msgstr "%J%qE özniteliği sadece işlevlere uygulanır"
 
-#: c-family/c-attribs.c:2417
+#: c-family/c-attribs.c:2428
 #, gcc-internal-format
 msgid "alloc_size parameter outside range"
 msgstr ""
 
-#: c-family/c-attribs.c:2443
+#: c-family/c-attribs.c:2454
 #, gcc-internal-format
 msgid "alloc_align parameter outside range"
 msgstr ""
 
-#: c-family/c-attribs.c:2467
+#: c-family/c-attribs.c:2478
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute argument not an integer constant"
 msgid "assume_aligned parameter not integer constant"
 msgstr "%qs öznitelik argümanı bir tamsayı sabit değil"
 
-#: c-family/c-attribs.c:2595
+#: c-family/c-attribs.c:2606
 #, gcc-internal-format
 msgid "only %<inbranch%> and %<notinbranch%> flags are allowed for %<__simd__%> attribute"
 msgstr ""
 
-#: c-family/c-attribs.c:2662 c-family/c-attribs.c:3503
+#: c-family/c-attribs.c:2673 c-family/c-attribs.c:3514
 #, fuzzy, gcc-internal-format
 #| msgid "%Jcan%'t set %qE attribute after definition"
 msgid "can%'t set %qE attribute after definition"
 msgstr "%J%qE özniteliği tanımdan sonra atanamaz"
 
-#: c-family/c-attribs.c:2727
+#: c-family/c-attribs.c:2738
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored"
 msgid "%qE attribute duplicated"
 msgstr "%qE özniteliği yoksayıldı"
 
-#: c-family/c-attribs.c:2729
+#: c-family/c-attribs.c:2740
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored for %qE"
 msgid "%qE attribute follows %qE"
 msgstr "%qE özniteliği %qE için yoksayıldı"
 
-#: c-family/c-attribs.c:2828
+#: c-family/c-attribs.c:2839
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously declared here"
 msgid "type was previously declared %qE"
 msgstr "%q+#D evvelce burada bildirilmiş"
 
-#: c-family/c-attribs.c:2841 cp/class.c:4397
+#: c-family/c-attribs.c:2852 cp/class.c:4401
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
 msgstr "%qs sadece işlevler için belirtilebilir"
 
-#: c-family/c-attribs.c:2899
+#: c-family/c-attribs.c:2910
 #, fuzzy, gcc-internal-format
 #| msgid "cleanup argument not an identifier"
 msgid "%qE argument not an identifier"
 msgstr "cleanup argümanı bir betimleyici değil"
 
-#: c-family/c-attribs.c:2910
+#: c-family/c-attribs.c:2921
 #, fuzzy, gcc-internal-format
 #| msgid "assert: %s is assign compatible with %s"
 msgid "%qD is not compatible with %qD"
 msgstr "assert: %s %s ile uyumlu atanıyor"
 
-#: c-family/c-attribs.c:2913
+#: c-family/c-attribs.c:2924
 #, fuzzy, gcc-internal-format
 #| msgid "cleanup argument not a function"
 msgid "%qE argument is not a function"
 msgstr "cleanup argümanı bir işlev değil"
 
-#: c-family/c-attribs.c:2961
+#: c-family/c-attribs.c:2972
 #, fuzzy, gcc-internal-format
 #| msgid "requested alignment is not a constant"
 msgid "deprecated message is not a string"
 msgstr "istenen hizalama bir sabit değil"
 
-#: c-family/c-attribs.c:3002
+#: c-family/c-attribs.c:3013
 #, gcc-internal-format
 msgid "%qE attribute ignored for %qE"
 msgstr "%qE özniteliği %qE için yoksayıldı"
 
-#: c-family/c-attribs.c:3065
+#: c-family/c-attribs.c:3076
 #, gcc-internal-format
 msgid "invalid vector type for attribute %qE"
 msgstr "%qE özniteliği için vektör türü geçersiz"
 
-#: c-family/c-attribs.c:3071 ada/gcc-interface/utils.c:3896
+#: c-family/c-attribs.c:3082 ada/gcc-interface/utils.c:3899
 #, gcc-internal-format
 msgid "vector size not an integral multiple of component size"
 msgstr "vektör boyutu bileşen boyutunun katlarından biri değil"
 
-#: c-family/c-attribs.c:3077 ada/gcc-interface/utils.c:3903
+#: c-family/c-attribs.c:3088 ada/gcc-interface/utils.c:3906
 #, gcc-internal-format
 msgid "zero vector size"
 msgstr "vektör boyutu sıfır"
 
-#: c-family/c-attribs.c:3085
+#: c-family/c-attribs.c:3096
 #, gcc-internal-format
 msgid "number of components of the vector not a power of two"
 msgstr "vektör elemanlarının sayısı ikinin üstel katlarından biri değil"
 
-#: c-family/c-attribs.c:3118 ada/gcc-interface/utils.c:6092
+#: c-family/c-attribs.c:3129 ada/gcc-interface/utils.c:6098
 #, gcc-internal-format
 msgid "nonnull attribute without arguments on a non-prototype"
 msgstr "bir prototip olmayanda argümansız null olmayan öznitelik"
 
-#: c-family/c-attribs.c:3137 ada/gcc-interface/utils.c:6106
+#: c-family/c-attribs.c:3148 ada/gcc-interface/utils.c:6112
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument has invalid operand number (argument %lu)"
 msgstr "null olmayan argüman geçersiz sayıda terim içeriyor (%lu. argüman)"
 
-#: c-family/c-attribs.c:3159 ada/gcc-interface/utils.c:6128
+#: c-family/c-attribs.c:3170 ada/gcc-interface/utils.c:6134
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument with out-of-range operand number (argument %lu, operand %lu)"
 msgstr "null olmayan argüman aralığın dışında sayıda terim içeriyor (%lu. argüman, %lu terim)"
 
-#: c-family/c-attribs.c:3168 ada/gcc-interface/utils.c:6137
+#: c-family/c-attribs.c:3179 ada/gcc-interface/utils.c:6143
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument references non-pointer operand (argument %lu, operand %lu)"
 msgstr "null olmayan argüman gösterici olmayan terime başvuruyor (%lu. argüman, %lu. terim)"
 
-#: c-family/c-attribs.c:3208
+#: c-family/c-attribs.c:3219
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute ignored on objects of type %qT"
 msgstr "%2$qT türünde alan için %1$qE özniteliği yoksayıldı"
 
-#: c-family/c-attribs.c:3216
+#: c-family/c-attribs.c:3227
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to functions"
 msgid "%qE attribute does not apply to functions"
 msgstr "%qs özniteliği sadece işlevlere uygulanır"
 
-#: c-family/c-attribs.c:3273
+#: c-family/c-attribs.c:3284
 #, gcc-internal-format
 msgid "cleanup argument not an identifier"
 msgstr "cleanup argümanı bir betimleyici değil"
 
-#: c-family/c-attribs.c:3280
+#: c-family/c-attribs.c:3291
 #, gcc-internal-format
 msgid "cleanup argument not a function"
 msgstr "cleanup argümanı bir işlev değil"
 
-#: c-family/c-attribs.c:3317
+#: c-family/c-attribs.c:3328
 #, gcc-internal-format
 msgid "%qE attribute requires prototypes with named arguments"
 msgstr "%qE özniteliği isimli argümanları olan prototipler gerektirir"
 
-#: c-family/c-attribs.c:3325
+#: c-family/c-attribs.c:3336
 #, gcc-internal-format
 msgid "%qE attribute only applies to variadic functions"
 msgstr "%qE özniteliği sadece değişkin işlevlere uygulanır"
 
-#: c-family/c-attribs.c:3341 ada/gcc-interface/utils.c:6179
+#: c-family/c-attribs.c:3352 ada/gcc-interface/utils.c:6185
 #, gcc-internal-format
 msgid "requested position is not an integer constant"
 msgstr "istenen konum bir tamsayı sabit değil"
 
-#: c-family/c-attribs.c:3349 ada/gcc-interface/utils.c:6186
+#: c-family/c-attribs.c:3360 ada/gcc-interface/utils.c:6192
 #, gcc-internal-format
 msgid "requested position is less than zero"
 msgstr "istenen konum sıfırdan küçük"
 
-#: c-family/c-attribs.c:3404
+#: c-family/c-attribs.c:3415
 #, fuzzy, gcc-internal-format
 #| msgid "Expected terminating name at %C"
 msgid "empty string in attribute %<target%>"
 msgstr "%C'de sonlandıran isim umuluyordu"
 
-#: c-family/c-attribs.c:3520
+#: c-family/c-attribs.c:3531
 #, fuzzy, gcc-internal-format
 #| msgid "return-statement with a value, in function returning 'void'"
 msgid "returns_nonnull attribute on a function not returning a pointer"
 msgstr "'void' dönüşlu işlevde değer içeren `return' deyimi"
 
-#: c-family/c-attribs.c:3535
+#: c-family/c-attribs.c:3546
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to function types"
 msgid "%qE attribute is only valid on %<struct%> type"
@@ -29197,13 +29225,13 @@
 msgid "__builtin_shuffle argument vector(s) inner type must have the same size as inner type of the mask"
 msgstr ""
 
-#: c-family/c-common.c:1262 c-family/c-warn.c:1194
+#: c-family/c-common.c:1262 c-family/c-warn.c:1202
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT discards qualifiers"
 msgid "unsigned conversion from %qT to %qT changes value from %qE to %qE"
 msgstr "%qT türünden %qT türüne dönüşüm niteleyicileri iptal ediyor"
 
-#: c-family/c-common.c:1267 c-family/c-warn.c:1202
+#: c-family/c-common.c:1267 c-family/c-warn.c:1210
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "unsigned conversion from %qT to %qT changes the value of %qE"
@@ -29340,7 +29368,7 @@
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "atamayı sarmalayan parantezler muhtemelen doğruluk değeri olarak kullanılmış"
 
-#: c-family/c-common.c:3518 c/c-decl.c:4325 c/c-decl.c:6430 c/c-typeck.c:14177
+#: c-family/c-common.c:3518 c/c-decl.c:4325 c/c-decl.c:6450 c/c-typeck.c:14182
 #, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr "%<restrict%> kullanımı geçersiz"
@@ -29423,7 +29451,7 @@
 msgid "duplicate case value"
 msgstr "yinelenmiş case değeri"
 
-#: c-family/c-common.c:4867 c-family/c-warn.c:2216
+#: c-family/c-common.c:4867 c-family/c-warn.c:2225
 #, fuzzy, gcc-internal-format
 #| msgid "%Jpreviously used here"
 msgid "previously used here"
@@ -29472,214 +29500,214 @@
 msgid "missing sentinel in function call"
 msgstr "işlev çağrısında gözcü eksik"
 
-#: c-family/c-common.c:5411
+#: c-family/c-common.c:5409
 #, gcc-internal-format, gfc-internal-format
 msgid "null argument where non-null required (argument %lu)"
 msgstr "null olmayanı gerektiren yerde null argüman (%lu. argüman)"
 
-#: c-family/c-common.c:5506 c-family/c-common.c:5553
+#: c-family/c-common.c:5504 c-family/c-common.c:5551
 #, gcc-internal-format
 msgid "bad option %qs to attribute %<optimize%>"
 msgstr ""
 
-#: c-family/c-common.c:5509 c-family/c-common.c:5557
+#: c-family/c-common.c:5507 c-family/c-common.c:5555
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operation on %<__fpreg%>"
 msgid "bad option %qs to pragma %<optimize%>"
 msgstr "%<__fpreg%> üzerinde geçersiz işlem"
 
-#: c-family/c-common.c:5589
+#: c-family/c-common.c:5587
 #, gcc-internal-format
 msgid "%<fallthrough%> attribute specified multiple times"
 msgstr ""
 
-#: c-family/c-common.c:5593
+#: c-family/c-common.c:5591
 #, fuzzy, gcc-internal-format
 msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr "öntanımlı argüman %2$q#D bildiriminin %1$d. parametresi için"
 
-#: c-family/c-common.c:5733 c-family/c-common.c:6485 c-family/c-common.c:6558
+#: c-family/c-common.c:5731 c-family/c-common.c:6477 c-family/c-common.c:6550
 #: c/c-typeck.c:3555
 #, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr "%qE işlevi için çok az argüman belirtildi"
 
-#: c-family/c-common.c:5738 c-family/c-common.c:6584 c/c-typeck.c:3284
+#: c-family/c-common.c:5736 c-family/c-common.c:6576 c/c-typeck.c:3284
 #, gcc-internal-format
 msgid "too many arguments to function %qE"
 msgstr "%qE işlevi için çok fazla argüman belirtildi"
 
-#: c-family/c-common.c:5769
+#: c-family/c-common.c:5767
 #, fuzzy, gcc-internal-format
 #| msgid "third argument to %<__builtin_prefetch%> must be a constant"
 msgid "third argument to function %qE must be a constant integer"
 msgstr "%<__builtin_prefetch%> için 3. argüman bir sabit olmalı"
 
-#: c-family/c-common.c:5794
+#: c-family/c-common.c:5792
 #, gcc-internal-format
 msgid "second argument to function %qE must be a constant integer power of 2 between %qi and %qu bits"
 msgstr ""
 
-#: c-family/c-common.c:5815 c-family/c-common.c:5859
+#: c-family/c-common.c:5813 c-family/c-common.c:5857
 #, fuzzy, gcc-internal-format
 #| msgid "non-floating-point argument to function %qs"
 msgid "non-floating-point argument in call to function %qE"
 msgstr "%qs işlevine kayan noktalı olmayan argüman"
 
-#: c-family/c-common.c:5838
+#: c-family/c-common.c:5836
 #, fuzzy, gcc-internal-format
 #| msgid "non-floating-point argument to function %qs"
 msgid "non-floating-point arguments in call to function %qE"
 msgstr "%qs işlevine kayan noktalı olmayan argüman"
 
-#: c-family/c-common.c:5852
+#: c-family/c-common.c:5850
 #, fuzzy, gcc-internal-format
 #| msgid "non-floating-point argument to function %qs"
 msgid "non-const integer argument %u in call to function %qE"
 msgstr "%qs işlevine kayan noktalı olmayan argüman"
 
-#: c-family/c-common.c:5872
+#: c-family/c-common.c:5870
 #, fuzzy, gcc-internal-format
 #| msgid "non-floating-point argument to function %qs"
 msgid "non-integer argument 3 in call to function %qE"
 msgstr "%qs işlevine kayan noktalı olmayan argüman"
 
-#: c-family/c-common.c:5889 c-family/c-common.c:5925
+#: c-family/c-common.c:5887 c-family/c-common.c:5923
 #, gcc-internal-format
 msgid "argument %u in call to function %qE does not have integral type"
 msgstr ""
 
-#: c-family/c-common.c:5896
+#: c-family/c-common.c:5894
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "argument 3 in call to function %qE does not have pointer to integral type"
 msgstr "array new içindeki boyut bütünleyici türde olmalı"
 
-#: c-family/c-common.c:5902
+#: c-family/c-common.c:5900
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfirst argument of %D must be a pointer, second integer constant"
 msgid "argument 3 in call to function %qE has pointer to enumerated type"
 msgstr "%H%D için ilk argüman bir gösterici, ikinci argüman sabit olmalıdır"
 
-#: c-family/c-common.c:5908
+#: c-family/c-common.c:5906
 #, fuzzy, gcc-internal-format
 #| msgid "non-floating-point argument to function %qs"
 msgid "argument 3 in call to function %qE has pointer to boolean type"
 msgstr "%qs işlevine kayan noktalı olmayan argüman"
 
-#: c-family/c-common.c:5931
+#: c-family/c-common.c:5929
 #, fuzzy, gcc-internal-format
 #| msgid "non-floating-point argument to function %qs"
 msgid "argument 3 in call to function %qE has enumerated type"
 msgstr "%qs işlevine kayan noktalı olmayan argüman"
 
-#: c-family/c-common.c:5937
+#: c-family/c-common.c:5935
 #, fuzzy, gcc-internal-format
 #| msgid "non-floating-point argument to function %qs"
 msgid "argument 3 in call to function %qE has boolean type"
 msgstr "%qs işlevine kayan noktalı olmayan argüman"
 
-#: c-family/c-common.c:6184
+#: c-family/c-common.c:6183
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static data member %qD"
 msgid "cannot apply %<offsetof%> to static data member %qD"
 msgstr "static olmayan veri üyesi %qD kullanımı geçersiz"
 
-#: c-family/c-common.c:6189
+#: c-family/c-common.c:6188
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> when %<operator[]%> is overloaded"
 msgstr ""
 
-#: c-family/c-common.c:6196
+#: c-family/c-common.c:6195
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to a non constant address"
 msgstr ""
 
-#: c-family/c-common.c:6209
+#: c-family/c-common.c:6208
 #, gcc-internal-format
 msgid "attempt to take address of bit-field structure member %qD"
 msgstr "bit-alanı yapısının %qD üyesinin adresi alınmaya çalışılıyor"
 
-#: c-family/c-common.c:6261
+#: c-family/c-common.c:6260
 #, gcc-internal-format
 msgid "index %E denotes an offset greater than size of %qT"
 msgstr ""
 
-#: c-family/c-common.c:6427 cp/init.c:3004 cp/init.c:3023
+#: c-family/c-common.c:6419 cp/init.c:3020 cp/init.c:3039
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "size of array is too large"
 msgstr "%qs dizisinin boyutu çok büyük"
 
-#: c-family/c-common.c:6517
+#: c-family/c-common.c:6509
 #, fuzzy, gcc-internal-format
 msgid "operand type %qT is incompatible with argument %d of %qE"
 msgstr "%2$qE işlevinin %1$d. argümanı için tür uyumsuz"
 
-#: c-family/c-common.c:6651
+#: c-family/c-common.c:6643
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %qE"
 msgid "incorrect number of arguments to function %qE"
 msgstr "%qE işlevi için çok az argüman belirtildi"
 
-#: c-family/c-common.c:6665
+#: c-family/c-common.c:6657
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs must be a 2-bit unsigned literal"
 msgid "argument 1 of %qE must be a non-void pointer type"
 msgstr "%qs argümanı 2 bitlik işaretsiz bir sabit olmalı"
 
-#: c-family/c-common.c:6674
+#: c-family/c-common.c:6666
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfirst argument of %D must be a pointer, second integer constant"
 msgid "argument 1 of %qE must be a pointer to a constant size type"
 msgstr "%H%D için ilk argüman bir gösterici, ikinci argüman sabit olmalıdır"
 
-#: c-family/c-common.c:6685
+#: c-family/c-common.c:6677
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfirst argument of %D must be a pointer, second integer constant"
 msgid "argument 1 of %qE must be a pointer to a nonzero size object"
 msgstr "%H%D için ilk argüman bir gösterici, ikinci argüman sabit olmalıdır"
 
-#: c-family/c-common.c:6706
+#: c-family/c-common.c:6698
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must be a pointer type"
 msgstr "%2$qE işlevinin %1$d. argümanına uyumsuz gösterici türünde aktarım"
 
-#: c-family/c-common.c:6714
+#: c-family/c-common.c:6706
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfirst argument of %D must be a pointer, second integer constant"
 msgid "argument %d of %qE must be a pointer to a constant size type"
 msgstr "%H%D için ilk argüman bir gösterici, ikinci argüman sabit olmalıdır"
 
-#: c-family/c-common.c:6720
+#: c-family/c-common.c:6712
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a function"
 msgstr "%2$qE işlevinin %1$d. argümanına uyumsuz gösterici türünde aktarım"
 
-#: c-family/c-common.c:6728
+#: c-family/c-common.c:6720
 #, fuzzy, gcc-internal-format
 #| msgid "Type/rank mismatch in argument '%s' at %L"
 msgid "size mismatch in argument %d of %qE"
 msgstr "Argüman '%s' için tür/sira uyumsuzluğu (%L'de)"
 
-#: c-family/c-common.c:6740
+#: c-family/c-common.c:6732
 #, fuzzy, gcc-internal-format
 msgid "non-integer memory model argument %d of %qE"
 msgstr "%2$qE işlevinin %1$d. argümanı için tür uyumsuz"
 
-#: c-family/c-common.c:6753
+#: c-family/c-common.c:6745
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument of %qs"
 msgid "invalid memory model argument %d of %qE"
 msgstr "%qs için tür argümanı geçersiz"
 
-#: c-family/c-common.c:7672
+#: c-family/c-common.c:7664
 #, fuzzy, gcc-internal-format
 #| msgid "Substring end index at %L is out of bounds"
 msgid "index value is out of bound"
 msgstr "%L'deki altdizge son indisi sınırların dışında"
 
-#: c-family/c-common.c:7714 c-family/c-common.c:7763 c-family/c-common.c:7779
+#: c-family/c-common.c:7706 c-family/c-common.c:7755 c-family/c-common.c:7771
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "conversion of scalar %qT to vector %qT involves truncation"
@@ -29687,25 +29715,25 @@
 
 #. Reject arguments that are built-in functions with
 #. no library fallback.
-#: c-family/c-common.c:7867
+#: c-family/c-common.c:7859
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "built-in function %qE must be directly called"
 msgstr "yerleşik işlev `%q+D işlev olarak bildirilmemiş"
 
-#: c-family/c-common.c:7889 c/c-decl.c:6177
+#: c-family/c-common.c:7881 c/c-decl.c:6197
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "size of array %qE is too large"
 msgstr "%qs dizisinin boyutu çok büyük"
 
-#: c-family/c-common.c:7891 c/c-decl.c:6180
+#: c-family/c-common.c:7883 c/c-decl.c:6200
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "size of unnamed array is too large"
 msgstr "%qs dizisinin boyutu çok büyük"
 
-#: c-family/c-common.c:7921
+#: c-family/c-common.c:7913
 #, gcc-internal-format
 msgid "environment variable SOURCE_DATE_EPOCH must expand to a non-negative integer less than or equal to %wd"
 msgstr ""
@@ -30248,7 +30276,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr ""
 
-#: c-family/c-omp.c:557 cp/semantics.c:8186
+#: c-family/c-omp.c:557 cp/semantics.c:8189
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute %qE"
 msgid "invalid type for iteration variable %qE"
@@ -30266,24 +30294,24 @@
 msgid "%qE is not initialized"
 msgstr "ilklendirici yok"
 
-#: c-family/c-omp.c:599 cp/semantics.c:8076
+#: c-family/c-omp.c:599 cp/semantics.c:8079
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.c:704 cp/semantics.c:7732
+#: c-family/c-omp.c:704 cp/semantics.c:7735
 #, fuzzy, gcc-internal-format
 #| msgid "invalid conditional operand"
 msgid "invalid controlling predicate"
 msgstr "koşullu terim geçersiz"
 
-#: c-family/c-omp.c:711 cp/semantics.c:8082
+#: c-family/c-omp.c:711 cp/semantics.c:8085
 #, fuzzy, gcc-internal-format
 #| msgid "assignment suppression"
 msgid "missing increment expression"
 msgstr "atama engelleme"
 
-#: c-family/c-omp.c:775 cp/semantics.c:7847
+#: c-family/c-omp.c:775 cp/semantics.c:7850
 #, fuzzy, gcc-internal-format
 #| msgid "invalid truth-value expression"
 msgid "invalid increment expression"
@@ -30344,115 +30372,130 @@
 msgid "%<-Wabi=1%> is not supported, using =2"
 msgstr "static TPF-OS'da desteklenmiyor"
 
-#: c-family/c-opts.c:612 fortran/cpp.c:350
+#: c-family/c-opts.c:610 fortran/cpp.c:350
 #, gcc-internal-format
 msgid "output filename specified twice"
 msgstr "çıktı dosyasının ismi iki kere belirtilmiş"
 
-#: c-family/c-opts.c:799
+#: c-family/c-opts.c:797
 #, gcc-internal-format
 msgid "-fexcess-precision=standard for C++"
 msgstr ""
 
-#: c-family/c-opts.c:834
+#: c-family/c-opts.c:832
 #, gcc-internal-format
 msgid "-fno-gnu89-inline is only supported in GNU99 or C99 mode"
 msgstr ""
 
-#: c-family/c-opts.c:880
+#: c-family/c-opts.c:878
 #, gcc-internal-format
 msgid "-Wformat-y2k ignored without -Wformat"
 msgstr "-Wformat-y2k  -Wformat'sız yoksayıldı"
 
-#: c-family/c-opts.c:882
+#: c-family/c-opts.c:880
 #, gcc-internal-format
 msgid "-Wformat-extra-args ignored without -Wformat"
 msgstr "-Wformat-extra-args  -Wformat'sız yoksayıldı"
 
-#: c-family/c-opts.c:884
+#: c-family/c-opts.c:882
 #, gcc-internal-format
 msgid "-Wformat-zero-length ignored without -Wformat"
 msgstr "-Wformat-zero-length  -Wformat'sız yoksayıldı"
 
-#: c-family/c-opts.c:886
+#: c-family/c-opts.c:884
 #, gcc-internal-format
 msgid "-Wformat-nonliteral ignored without -Wformat"
 msgstr "-Wformat-nonliteral  -Wformat'sız yoksayıldı"
 
-#: c-family/c-opts.c:888
+#: c-family/c-opts.c:886
 #, fuzzy, gcc-internal-format
 #| msgid "-Wformat-nonliteral ignored without -Wformat"
 msgid "-Wformat-contains-nul ignored without -Wformat"
 msgstr "-Wformat-nonliteral  -Wformat'sız yoksayıldı"
 
-#: c-family/c-opts.c:890
+#: c-family/c-opts.c:888
 #, gcc-internal-format
 msgid "-Wformat-security ignored without -Wformat"
 msgstr "-Wformat-security  -Wformat'sız yoksayıldı"
 
-#: c-family/c-opts.c:928
+#: c-family/c-opts.c:918
 #, gcc-internal-format
 msgid "%<-fabi-compat-version=1%> is not supported, using =2"
 msgstr ""
 
-#: c-family/c-opts.c:988
+#: c-family/c-opts.c:944
+#, gcc-internal-format
+msgid "-Wabi won't warn about anything"
+msgstr ""
+
+#: c-family/c-opts.c:946
+#, gcc-internal-format
+msgid "-Wabi warns about differences from the most up-to-date ABI, which is also used by default"
+msgstr ""
+
+#: c-family/c-opts.c:949
+#, gcc-internal-format
+msgid "use e.g. -Wabi=11 to warn about changes from GCC 7"
+msgstr ""
+
+#: c-family/c-opts.c:1003
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "external TLS initialization functions not supported on this target"
 msgstr "bu hedefte yığıt sınırları desteklenmiyor"
 
-#: c-family/c-opts.c:1001
+#: c-family/c-opts.c:1016
 #, gcc-internal-format, gfc-internal-format
 msgid "too many filenames given.  Type %s --help for usage"
 msgstr "çok fazla dosyaismi verildi. Kullanım bilgileri için %s --help yazınız"
 
-#: c-family/c-opts.c:1016
+#: c-family/c-opts.c:1031
 #, gcc-internal-format
 msgid "opening output file %s: %m"
 msgstr "`%s' çıktı dosyasının açılması: %m"
 
-#: c-family/c-opts.c:1036
+#: c-family/c-opts.c:1051
 #, gcc-internal-format, gfc-internal-format
 msgid "the \"%s\" debug format cannot be used with pre-compiled headers"
 msgstr ""
 
-#: c-family/c-opts.c:1190
+#: c-family/c-opts.c:1205
 #, gcc-internal-format
 msgid "opening dependency file %s: %m"
 msgstr "%s bağımlılık dosyasının açılması: %m"
 
-#: c-family/c-opts.c:1201
+#: c-family/c-opts.c:1216
 #, gcc-internal-format
 msgid "closing dependency file %s: %m"
 msgstr "%s bağımlılık dosyasının kapatılması: %m"
 
-#: c-family/c-opts.c:1204
+#: c-family/c-opts.c:1219
 #, gcc-internal-format
 msgid "when writing output to %s: %m"
 msgstr "çıktı %s e yazılırken: %m"
 
-#: c-family/c-opts.c:1284
+#: c-family/c-opts.c:1299
 #, gcc-internal-format
 msgid "to generate dependencies you must specify either -M or -MM"
 msgstr "bağımlılıkları üretmek için ya -M ya da -MM belirtmelisiniz"
 
-#: c-family/c-opts.c:1307
+#: c-family/c-opts.c:1322
 #, fuzzy, gcc-internal-format
 #| msgid "-mn is used without -mh or -ms"
 msgid "-MG may only be used with -M or -MM"
 msgstr "-mn, -mh veya -ms olmaksızın kullanılmış"
 
-#: c-family/c-opts.c:1340
+#: c-family/c-opts.c:1355
 #, gcc-internal-format
 msgid "-fdirectives-only is incompatible with -Wunused_macros"
 msgstr ""
 
-#: c-family/c-opts.c:1342
+#: c-family/c-opts.c:1357
 #, gcc-internal-format
 msgid "-fdirectives-only is incompatible with -traditional"
 msgstr ""
 
-#: c-family/c-opts.c:1534
+#: c-family/c-opts.c:1549
 #, gcc-internal-format
 msgid "too late for # directive to set debug directory"
 msgstr "hata ayıklama dizinini belirten # yönergesi için çok gec"
@@ -30865,713 +30908,713 @@
 msgid "wrong type argument to %s"
 msgstr "abs'a yanlış türde argüman"
 
-#: c-family/c-warn.c:53 c-family/c-warn.c:66 cp/constexpr.c:1847
+#: c-family/c-warn.c:54 c-family/c-warn.c:67 cp/constexpr.c:1847
 #: cp/constexpr.c:4099
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "sabit ifadesinde taşma"
 
-#: c-family/c-warn.c:93
+#: c-family/c-warn.c:94
 #, fuzzy, gcc-internal-format
 #| msgid "integer overflow in expression"
 msgid "integer overflow in expression %qE of type %qT results in %qE"
 msgstr "ifadede tamsayı taşması"
 
-#: c-family/c-warn.c:95
+#: c-family/c-warn.c:96
 #, fuzzy, gcc-internal-format
 #| msgid "integer overflow in expression"
 msgid "integer overflow in expression of type %qT results in %qE"
 msgstr "ifadede tamsayı taşması"
 
-#: c-family/c-warn.c:101
+#: c-family/c-warn.c:102
 #, fuzzy, gcc-internal-format
 #| msgid "floating point overflow in expression"
 msgid "floating point overflow in expression %qE of type %qT results in %qE"
 msgstr "ifadede gerçel sayı taşması"
 
-#: c-family/c-warn.c:103
+#: c-family/c-warn.c:104
 #, fuzzy, gcc-internal-format
 #| msgid "floating point overflow in expression"
 msgid "floating point overflow in expression of type %qT results in %qE"
 msgstr "ifadede gerçel sayı taşması"
 
-#: c-family/c-warn.c:109
+#: c-family/c-warn.c:110
 #, fuzzy, gcc-internal-format
 #| msgid "floating point overflow in expression"
 msgid "fixed-point overflow in expression %qE of type %qT results in %qE"
 msgstr "ifadede gerçel sayı taşması"
 
-#: c-family/c-warn.c:111
+#: c-family/c-warn.c:112
 #, fuzzy, gcc-internal-format
 #| msgid "floating point overflow in expression"
 msgid "fixed-point overflow in expression of type %qT results in %qE"
 msgstr "ifadede gerçel sayı taşması"
 
-#: c-family/c-warn.c:117
+#: c-family/c-warn.c:118
 #, fuzzy, gcc-internal-format
 #| msgid "vector overflow in expression"
 msgid "vector overflow in expression %qE of type %qT results in %qE"
 msgstr "ifadede vektör taşması"
 
-#: c-family/c-warn.c:119
+#: c-family/c-warn.c:120
 #, fuzzy, gcc-internal-format
 #| msgid "vector overflow in expression"
 msgid "vector overflow in expression of type %qT results in %qE"
 msgstr "ifadede vektör taşması"
 
-#: c-family/c-warn.c:126
+#: c-family/c-warn.c:127
 #, fuzzy, gcc-internal-format
 #| msgid "integer overflow in expression"
 msgid "complex integer overflow in expression %qE of type %qT results in %qE"
 msgstr "ifadede tamsayı taşması"
 
-#: c-family/c-warn.c:128
+#: c-family/c-warn.c:129
 #, fuzzy, gcc-internal-format
 #| msgid "integer overflow in expression"
 msgid "complex integer overflow in expression of type %qT results in %qE"
 msgstr "ifadede tamsayı taşması"
 
-#: c-family/c-warn.c:132
+#: c-family/c-warn.c:133
 #, fuzzy, gcc-internal-format
 #| msgid "floating point overflow in expression"
 msgid "complex floating point overflow in expression %qE of type %qT results in %qE"
 msgstr "ifadede gerçel sayı taşması"
 
-#: c-family/c-warn.c:134
+#: c-family/c-warn.c:135
 #, fuzzy, gcc-internal-format
 #| msgid "floating point overflow in expression"
 msgid "complex floating point overflow in expression of type %qT results in %qE"
 msgstr "ifadede gerçel sayı taşması"
 
-#: c-family/c-warn.c:216
+#: c-family/c-warn.c:217
 #, gcc-internal-format
 msgid "logical %<or%> applied to non-boolean constant"
 msgstr ""
 
-#: c-family/c-warn.c:219
+#: c-family/c-warn.c:220
 #, gcc-internal-format
 msgid "logical %<and%> applied to non-boolean constant"
 msgstr ""
 
-#: c-family/c-warn.c:289
+#: c-family/c-warn.c:290
 #, fuzzy, gcc-internal-format
 #| msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgid "logical %<or%> of collectively exhaustive tests is always true"
 msgstr "bağdaşmayanların eşitlik sınamalarının %<and%> sonucu daima 0 dir"
 
-#: c-family/c-warn.c:293
+#: c-family/c-warn.c:294
 #, fuzzy, gcc-internal-format
 #| msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgid "logical %<and%> of mutually exclusive tests is always false"
 msgstr "bağdaşmayanların eşitlik sınamalarının %<and%> sonucu daima 0 dir"
 
-#: c-family/c-warn.c:303
+#: c-family/c-warn.c:304
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands to binary %s"
 msgid "logical %<or%> of equal expressions"
 msgstr "iki terimli %s için terimler geçersiz"
 
-#: c-family/c-warn.c:306
+#: c-family/c-warn.c:307
 #, fuzzy, gcc-internal-format
 #| msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgid "logical %<and%> of equal expressions"
 msgstr "bağdaşmayanların eşitlik sınamalarının %<and%> sonucu daima 0 dir"
 
-#: c-family/c-warn.c:384
+#: c-family/c-warn.c:385
 #, gcc-internal-format
 msgid "bitwise comparison always evaluates to false"
 msgstr ""
 
-#: c-family/c-warn.c:387
+#: c-family/c-warn.c:388
 #, fuzzy, gcc-internal-format
 #| msgid "the address of %qD, will always evaluate as %<true%>"
 msgid "bitwise comparison always evaluates to true"
 msgstr "%qD adresi, daima %<true%> olarak değerlendirilecek"
 
-#: c-family/c-warn.c:441
+#: c-family/c-warn.c:442
 #, fuzzy, gcc-internal-format
 #| msgid "user-defined %qD always evaluates both arguments"
 msgid "self-comparison always evaluates to true"
 msgstr "kullanıcı tanımlı %qD daima her iki argümanıyla birlikte değerlendirilir"
 
-#: c-family/c-warn.c:444
+#: c-family/c-warn.c:445
 #, fuzzy, gcc-internal-format
 #| msgid "user-defined %qD always evaluates both arguments"
 msgid "self-comparison always evaluates to false"
 msgstr "kullanıcı tanımlı %qD daima her iki argümanıyla birlikte değerlendirilir"
 
-#: c-family/c-warn.c:494
+#: c-family/c-warn.c:495
 #, gcc-internal-format
 msgid "logical not is only applied to the left hand side of comparison"
 msgstr ""
 
-#: c-family/c-warn.c:502
+#: c-family/c-warn.c:503
 #, gcc-internal-format
 msgid "add parentheses around left hand side expression to silence this warning"
 msgstr ""
 
-#: c-family/c-warn.c:636
+#: c-family/c-warn.c:637
 #, gcc-internal-format
 msgid "type-punning to incomplete type might break strict-aliasing rules"
 msgstr "içi boş türle tür tanımı yapmak adlandırma kurallarının katılığı ile bağdasmaz"
 
-#: c-family/c-warn.c:654
+#: c-family/c-warn.c:655
 #, gcc-internal-format
 msgid "dereferencing type-punned pointer will break strict-aliasing rules"
 msgstr "türü tanımlanmış göstericinin ilişkilendirilmesi adlandırmanın değişmezliği kurallarını bozacak"
 
-#: c-family/c-warn.c:662 c-family/c-warn.c:680
+#: c-family/c-warn.c:663 c-family/c-warn.c:681
 #, gcc-internal-format
 msgid "dereferencing type-punned pointer might break strict-aliasing rules"
 msgstr "türü tanımlanmış göstericinin ilişkilendirilmesi adlandırmanın değişmezliği kurallarını bozabilir"
 
-#: c-family/c-warn.c:803
+#: c-family/c-warn.c:811
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to use the size of the destination?"
 msgstr ""
 
-#: c-family/c-warn.c:834
+#: c-family/c-warn.c:842
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the destination; did you mean to remove the addressof?"
 msgstr ""
 
-#: c-family/c-warn.c:841
+#: c-family/c-warn.c:849
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the destination; did you mean to provide an explicit length?"
 msgstr ""
 
-#: c-family/c-warn.c:846
+#: c-family/c-warn.c:854
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the destination; did you mean to dereference it?"
 msgstr ""
 
-#: c-family/c-warn.c:858
+#: c-family/c-warn.c:866
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the destination; expected %qT or an explicit length"
 msgstr ""
 
-#: c-family/c-warn.c:874
+#: c-family/c-warn.c:882
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to remove the addressof?"
 msgstr ""
 
-#: c-family/c-warn.c:881
+#: c-family/c-warn.c:889
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to provide an explicit length?"
 msgstr ""
 
-#: c-family/c-warn.c:886
+#: c-family/c-warn.c:894
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to dereference it?"
 msgstr ""
 
-#: c-family/c-warn.c:898
+#: c-family/c-warn.c:906
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the source; expected %qT or an explicit length"
 msgstr ""
 
-#: c-family/c-warn.c:914
+#: c-family/c-warn.c:922
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the first source; did you mean to remove the addressof?"
 msgstr ""
 
-#: c-family/c-warn.c:921
+#: c-family/c-warn.c:929
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the first source; did you mean to provide an explicit length?"
 msgstr ""
 
-#: c-family/c-warn.c:926
+#: c-family/c-warn.c:934
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the first source; did you mean to dereference it?"
 msgstr ""
 
-#: c-family/c-warn.c:938
+#: c-family/c-warn.c:946
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the first source; expected %qT or an explicit length"
 msgstr ""
 
-#: c-family/c-warn.c:954
+#: c-family/c-warn.c:962
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the second source; did you mean to remove the addressof?"
 msgstr ""
 
-#: c-family/c-warn.c:961
+#: c-family/c-warn.c:969
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the second source; did you mean to provide an explicit length?"
 msgstr ""
 
-#: c-family/c-warn.c:966
+#: c-family/c-warn.c:974
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the second source; did you mean to dereference it?"
 msgstr ""
 
-#: c-family/c-warn.c:978
+#: c-family/c-warn.c:986
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the second source; expected %qT or an explicit length"
 msgstr ""
 
-#: c-family/c-warn.c:1007 c-family/c-warn.c:1014
+#: c-family/c-warn.c:1015 c-family/c-warn.c:1022
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter type %qT"
 msgid "%<_Atomic%>-qualified parameter type %qT of %q+D"
 msgstr "geçersiz parametre türü %qT"
 
-#: c-family/c-warn.c:1024
+#: c-family/c-warn.c:1032
 #, gcc-internal-format
 msgid "first argument of %q+D should be %<int%>"
 msgstr "%q+D için ilk argüman %<int%> olmalıydı"
 
-#: c-family/c-warn.c:1033
+#: c-family/c-warn.c:1041
 #, gcc-internal-format
 msgid "second argument of %q+D should be %<char **%>"
 msgstr "%q+D için ikinci argüman %<char **%> olmalıydı"
 
-#: c-family/c-warn.c:1042
+#: c-family/c-warn.c:1050
 #, gcc-internal-format
 msgid "third argument of %q+D should probably be %<char **%>"
 msgstr "%q+D için üçüncü argüman muhtemelen %<char **%> olmalıydı"
 
-#: c-family/c-warn.c:1053
+#: c-family/c-warn.c:1061
 #, gcc-internal-format
 msgid "%q+D takes only zero or two arguments"
 msgstr "%q+D ya iki argüman alır ya da hiç almaz"
 
-#: c-family/c-warn.c:1057
+#: c-family/c-warn.c:1065
 #, fuzzy, gcc-internal-format
 #| msgid "field %qs declared as a function"
 msgid "%q+D declared as variadic function"
 msgstr "%qs alanı bir işlev olarak bildirilmiş"
 
-#: c-family/c-warn.c:1099
+#: c-family/c-warn.c:1107
 #, fuzzy, gcc-internal-format
 #| msgid "converting to %qT from %qT"
 msgid "conversion to %qT from boolean expression"
 msgstr "%qT türüne %qT türünden dönüşüm"
 
-#: c-family/c-warn.c:1117 c-family/c-warn.c:1192
+#: c-family/c-warn.c:1125 c-family/c-warn.c:1200
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT discards qualifiers"
 msgid "conversion from %qT to %qT changes value from %qE to %qE"
 msgstr "%qT türünden %qT türüne dönüşüm niteleyicileri iptal ediyor"
 
-#: c-family/c-warn.c:1121 c-family/c-warn.c:1200
+#: c-family/c-warn.c:1129 c-family/c-warn.c:1208
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "conversion from %qT to %qT changes the value of %qE"
 msgstr "%qT türünden %qT türüne dönüşüm belirsiz"
 
-#: c-family/c-warn.c:1141
+#: c-family/c-warn.c:1149
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT discards qualifiers"
 msgid "conversion from %qT to %qT discards imaginary component"
 msgstr "%qT türünden %qT türüne dönüşüm niteleyicileri iptal ediyor"
 
-#: c-family/c-warn.c:1153
+#: c-family/c-warn.c:1161
 #, fuzzy, gcc-internal-format
 #| msgid "conversion of %qE from %qT to %qT is ambiguous"
 msgid "conversion from %qT to %qT may change value"
 msgstr "%qE ifadesinin %qT türünden %qT türüne dönüşümü belirsiz"
 
-#: c-family/c-warn.c:1213 c-family/c-warn.c:1230 c-family/c-warn.c:1247
+#: c-family/c-warn.c:1221 c-family/c-warn.c:1238 c-family/c-warn.c:1255
 #, fuzzy, gcc-internal-format
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "overflow in conversion from %qT to %qT changes value from %qE to %qE"
 msgstr "%qT türünden %qT türüne örtük dönüşüme C++'da izin verilmez"
 
-#: c-family/c-warn.c:1218 c-family/c-warn.c:1235 c-family/c-warn.c:1252
+#: c-family/c-warn.c:1226 c-family/c-warn.c:1243 c-family/c-warn.c:1260
 #, fuzzy, gcc-internal-format
 #| msgid "conversion of %qE from %qT to %qT is ambiguous"
 msgid "overflow in conversion from %qT to %qT changes the value of %qE"
 msgstr "%qE ifadesinin %qT türünden %qT türüne dönüşümü belirsiz"
 
-#: c-family/c-warn.c:1282
+#: c-family/c-warn.c:1290
 #, fuzzy, gcc-internal-format
 #| msgid "%Jcase value %qs not in enumerated type"
 msgid "case value %qs not in enumerated type"
 msgstr "%Jcase değeri %qs sembolik sabit türünde değil"
 
-#: c-family/c-warn.c:1287
+#: c-family/c-warn.c:1295
 #, fuzzy, gcc-internal-format
 #| msgid "%Jcase value %qs not in enumerated type %qT"
 msgid "case value %qs not in enumerated type %qT"
 msgstr "%Jcase değeri %qs, %qT sembolik sabit türünde değil"
 
-#: c-family/c-warn.c:1348
+#: c-family/c-warn.c:1356
 #, fuzzy, gcc-internal-format
 #| msgid "%Hswitch missing default case"
 msgid "switch missing default case"
 msgstr "%Hswitch içinde default eksik"
 
-#: c-family/c-warn.c:1393
+#: c-family/c-warn.c:1401
 #, gcc-internal-format
 msgid "switch condition has boolean value"
 msgstr ""
 
-#: c-family/c-warn.c:1466
+#: c-family/c-warn.c:1474
 #, fuzzy, gcc-internal-format
 #| msgid "%Henumeration value %qE not handled in switch"
 msgid "enumeration value %qE not handled in switch"
 msgstr "%Hsembolik sabit değeri %qE switch deyiminde elde edilemedi"
 
-#: c-family/c-warn.c:1494
+#: c-family/c-warn.c:1502
 #, gcc-internal-format
 msgid "the omitted middle operand in ?: will always be %<true%>, suggest explicit middle operand"
 msgstr ""
 
-#: c-family/c-warn.c:1515
+#: c-family/c-warn.c:1523
 #, fuzzy, gcc-internal-format
 #| msgid "assignment of read-only location"
 msgid "assignment of member %qD in read-only object"
 msgstr "salt-okunur konuma atama"
 
-#: c-family/c-warn.c:1517
+#: c-family/c-warn.c:1525
 #, fuzzy, gcc-internal-format
 #| msgid "increment of read-only location"
 msgid "increment of member %qD in read-only object"
 msgstr "salt-okunur konuma eksiltim"
 
-#: c-family/c-warn.c:1519
+#: c-family/c-warn.c:1527
 #, fuzzy, gcc-internal-format
 #| msgid "decrement of read-only location"
 msgid "decrement of member %qD in read-only object"
 msgstr "salt-okunur konuma arttırım"
 
-#: c-family/c-warn.c:1521
+#: c-family/c-warn.c:1529
 #, fuzzy, gcc-internal-format
 #| msgid "read-only location used as %<asm%> output"
 msgid "member %qD in read-only object used as %<asm%> output"
 msgstr "salt-okunur konum %<asm%> çıktısı olarak kullanılmış"
 
-#: c-family/c-warn.c:1525
+#: c-family/c-warn.c:1533
 #, gcc-internal-format
 msgid "assignment of read-only member %qD"
 msgstr "salt-okunur üye %qD için atama"
 
-#: c-family/c-warn.c:1526
+#: c-family/c-warn.c:1534
 #, gcc-internal-format
 msgid "increment of read-only member %qD"
 msgstr "salt-okunur üye %qD için eksiltme"
 
-#: c-family/c-warn.c:1527
+#: c-family/c-warn.c:1535
 #, gcc-internal-format
 msgid "decrement of read-only member %qD"
 msgstr "salt-okunur üye %qD için arttırım"
 
-#: c-family/c-warn.c:1528
+#: c-family/c-warn.c:1536
 #, gcc-internal-format
 msgid "read-only member %qD used as %<asm%> output"
 msgstr "salt-okunur üye %qD %<asm%> çıktısı olarak kullanılmış"
 
-#: c-family/c-warn.c:1532
+#: c-family/c-warn.c:1540
 #, gcc-internal-format
 msgid "assignment of read-only variable %qD"
 msgstr "salt-okunur değişken %qD için atama"
 
-#: c-family/c-warn.c:1533
+#: c-family/c-warn.c:1541
 #, gcc-internal-format
 msgid "increment of read-only variable %qD"
 msgstr "salt-okunur değişken %qD için eksiltme"
 
-#: c-family/c-warn.c:1534
+#: c-family/c-warn.c:1542
 #, gcc-internal-format
 msgid "decrement of read-only variable %qD"
 msgstr "salt-okunur değişken %qD için arttırım"
 
-#: c-family/c-warn.c:1535
+#: c-family/c-warn.c:1543
 #, gcc-internal-format
 msgid "read-only variable %qD used as %<asm%> output"
 msgstr "salt-okunur değişken %qD %<asm%> çıktısı olarak kullanılmış"
 
-#: c-family/c-warn.c:1538
+#: c-family/c-warn.c:1546
 #, fuzzy, gcc-internal-format
 #| msgid "assignment of read-only member %qD"
 msgid "assignment of read-only parameter %qD"
 msgstr "salt-okunur üye %qD için atama"
 
-#: c-family/c-warn.c:1539
+#: c-family/c-warn.c:1547
 #, fuzzy, gcc-internal-format
 #| msgid "increment of read-only member %qD"
 msgid "increment of read-only parameter %qD"
 msgstr "salt-okunur üye %qD için eksiltme"
 
-#: c-family/c-warn.c:1540
+#: c-family/c-warn.c:1548
 #, fuzzy, gcc-internal-format
 #| msgid "decrement of read-only member %qD"
 msgid "decrement of read-only parameter %qD"
 msgstr "salt-okunur üye %qD için arttırım"
 
-#: c-family/c-warn.c:1541
+#: c-family/c-warn.c:1549
 #, fuzzy, gcc-internal-format
 #| msgid "read-only member %qD used as %<asm%> output"
 msgid "read-only parameter %qD use as %<asm%> output"
 msgstr "salt-okunur üye %qD %<asm%> çıktısı olarak kullanılmış"
 
-#: c-family/c-warn.c:1546
+#: c-family/c-warn.c:1554
 #, fuzzy, gcc-internal-format
 #| msgid "assignment of read-only variable %qD"
 msgid "assignment of read-only named return value %qD"
 msgstr "salt-okunur değişken %qD için atama"
 
-#: c-family/c-warn.c:1548
+#: c-family/c-warn.c:1556
 #, fuzzy, gcc-internal-format
 #| msgid "increment of read-only variable %qD"
 msgid "increment of read-only named return value %qD"
 msgstr "salt-okunur değişken %qD için eksiltme"
 
-#: c-family/c-warn.c:1550
+#: c-family/c-warn.c:1558
 #, fuzzy, gcc-internal-format
 #| msgid "decrement of read-only variable %qD"
 msgid "decrement of read-only named return value %qD"
 msgstr "salt-okunur değişken %qD için arttırım"
 
-#: c-family/c-warn.c:1552
+#: c-family/c-warn.c:1560
 #, fuzzy, gcc-internal-format
 #| msgid "read-only variable %qD used as %<asm%> output"
 msgid "read-only named return value %qD used as %<asm%>output"
 msgstr "salt-okunur değişken %qD %<asm%> çıktısı olarak kullanılmış"
 
-#: c-family/c-warn.c:1557
+#: c-family/c-warn.c:1565
 #, fuzzy, gcc-internal-format
 #| msgid "assignment of read-only location"
 msgid "assignment of function %qD"
 msgstr "salt-okunur konuma atama"
 
-#: c-family/c-warn.c:1558
+#: c-family/c-warn.c:1566
 #, fuzzy, gcc-internal-format
 #| msgid "increment of read-only location"
 msgid "increment of function %qD"
 msgstr "salt-okunur konuma eksiltim"
 
-#: c-family/c-warn.c:1559
+#: c-family/c-warn.c:1567
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %qs"
 msgid "decrement of function %qD"
 msgstr "%qs işlevi için argümanlar çok az"
 
-#: c-family/c-warn.c:1560
+#: c-family/c-warn.c:1568
 #, fuzzy, gcc-internal-format
 #| msgid "read-only location used as %<asm%> output"
 msgid "function %qD used as %<asm%> output"
 msgstr "salt-okunur konum %<asm%> çıktısı olarak kullanılmış"
 
-#: c-family/c-warn.c:1563 c/c-typeck.c:4762
+#: c-family/c-warn.c:1571 c/c-typeck.c:4767
 #, fuzzy, gcc-internal-format
 #| msgid "assignment of read-only location"
 msgid "assignment of read-only location %qE"
 msgstr "salt-okunur konuma atama"
 
-#: c-family/c-warn.c:1564 c/c-typeck.c:4765
+#: c-family/c-warn.c:1572 c/c-typeck.c:4770
 #, fuzzy, gcc-internal-format
 #| msgid "increment of read-only location"
 msgid "increment of read-only location %qE"
 msgstr "salt-okunur konuma eksiltim"
 
-#: c-family/c-warn.c:1565 c/c-typeck.c:4768
+#: c-family/c-warn.c:1573 c/c-typeck.c:4773
 #, fuzzy, gcc-internal-format
 #| msgid "decrement of read-only location"
 msgid "decrement of read-only location %qE"
 msgstr "salt-okunur konuma arttırım"
 
-#: c-family/c-warn.c:1566
+#: c-family/c-warn.c:1574
 #, fuzzy, gcc-internal-format
 #| msgid "read-only location used as %<asm%> output"
 msgid "read-only location %qE used as %<asm%> output"
 msgstr "salt-okunur konum %<asm%> çıktısı olarak kullanılmış"
 
-#: c-family/c-warn.c:1580
+#: c-family/c-warn.c:1588
 #, fuzzy, gcc-internal-format
 #| msgid "invalid lvalue in assignment"
 msgid "lvalue required as left operand of assignment"
 msgstr "atamanın sol tarafı geçersiz"
 
-#: c-family/c-warn.c:1583
+#: c-family/c-warn.c:1591
 #, gcc-internal-format
 msgid "lvalue required as increment operand"
 msgstr ""
 
-#: c-family/c-warn.c:1586
+#: c-family/c-warn.c:1594
 #, gcc-internal-format
 msgid "lvalue required as decrement operand"
 msgstr ""
 
-#: c-family/c-warn.c:1589
+#: c-family/c-warn.c:1597
 #, gcc-internal-format
 msgid "lvalue required as unary %<&%> operand"
 msgstr ""
 
-#: c-family/c-warn.c:1592
+#: c-family/c-warn.c:1600
 #, fuzzy, gcc-internal-format
 #| msgid "invalid lvalue in asm statement"
 msgid "lvalue required in asm statement"
 msgstr "asm deyiminde geçersiz sol taraf"
 
-#: c-family/c-warn.c:1609
+#: c-family/c-warn.c:1617
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument of %qs"
 msgid "invalid type argument (have %qT)"
 msgstr "%qs için tür argümanı geçersiz"
 
-#: c-family/c-warn.c:1613
+#: c-family/c-warn.c:1621
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument of %qs"
 msgid "invalid type argument of array indexing (have %qT)"
 msgstr "%qs için tür argümanı geçersiz"
 
-#: c-family/c-warn.c:1618
+#: c-family/c-warn.c:1626
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument of %qs"
 msgid "invalid type argument of unary %<*%> (have %qT)"
 msgstr "%qs için tür argümanı geçersiz"
 
-#: c-family/c-warn.c:1623
+#: c-family/c-warn.c:1631
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument of %qs"
 msgid "invalid type argument of %<->%> (have %qT)"
 msgstr "%qs için tür argümanı geçersiz"
 
-#: c-family/c-warn.c:1628
+#: c-family/c-warn.c:1636
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument of %qs"
 msgid "invalid type argument of %<->*%> (have %qT)"
 msgstr "%qs için tür argümanı geçersiz"
 
-#: c-family/c-warn.c:1633
+#: c-family/c-warn.c:1641
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument of %qs"
 msgid "invalid type argument of implicit conversion (have %qT)"
 msgstr "%qs için tür argümanı geçersiz"
 
-#: c-family/c-warn.c:1654
+#: c-family/c-warn.c:1662
 #, gcc-internal-format
 msgid "array subscript has type %<char%>"
 msgstr "dizi indisi %<char%> türünde"
 
-#: c-family/c-warn.c:1689 c-family/c-warn.c:1692
+#: c-family/c-warn.c:1697 c-family/c-warn.c:1700
 #, fuzzy, gcc-internal-format
 #| msgid "suggest parentheses around + or - inside shift"
 msgid "suggest parentheses around %<+%> inside %<<<%>"
 msgstr "shift içindeki + ya da - çevresinde parantezler önerilir"
 
-#: c-family/c-warn.c:1695 c-family/c-warn.c:1698
+#: c-family/c-warn.c:1703 c-family/c-warn.c:1706
 #, fuzzy, gcc-internal-format
 #| msgid "suggest parentheses around + or - inside shift"
 msgid "suggest parentheses around %<-%> inside %<<<%>"
 msgstr "shift içindeki + ya da - çevresinde parantezler önerilir"
 
-#: c-family/c-warn.c:1704 c-family/c-warn.c:1707
+#: c-family/c-warn.c:1712 c-family/c-warn.c:1715
 #, fuzzy, gcc-internal-format
 #| msgid "suggest parentheses around + or - inside shift"
 msgid "suggest parentheses around %<+%> inside %<>>%>"
 msgstr "shift içindeki + ya da - çevresinde parantezler önerilir"
 
-#: c-family/c-warn.c:1710 c-family/c-warn.c:1713
+#: c-family/c-warn.c:1718 c-family/c-warn.c:1721
 #, fuzzy, gcc-internal-format
 #| msgid "suggest parentheses around + or - inside shift"
 msgid "suggest parentheses around %<-%> inside %<>>%>"
 msgstr "shift içindeki + ya da - çevresinde parantezler önerilir"
 
-#: c-family/c-warn.c:1719 c-family/c-warn.c:1722
+#: c-family/c-warn.c:1727 c-family/c-warn.c:1730
 #, fuzzy, gcc-internal-format
 #| msgid "suggest parentheses around && within ||"
 msgid "suggest parentheses around %<&&%> within %<||%>"
 msgstr "|| içindeki && çevresinde parantezler önerilir"
 
-#: c-family/c-warn.c:1729 c-family/c-warn.c:1733
+#: c-family/c-warn.c:1737 c-family/c-warn.c:1741
 #, fuzzy, gcc-internal-format
 #| msgid "suggest parentheses around arithmetic in operand of |"
 msgid "suggest parentheses around arithmetic in operand of %<|%>"
 msgstr "| terimindeki aritmetik çevresinde parantezler önerilir"
 
-#: c-family/c-warn.c:1737 c-family/c-warn.c:1740
+#: c-family/c-warn.c:1745 c-family/c-warn.c:1748
 #, fuzzy, gcc-internal-format
 #| msgid "suggest parentheses around comparison in operand of |"
 msgid "suggest parentheses around comparison in operand of %<|%>"
 msgstr "| terimindeki karşılaştırma çevresinde parantezler önerilir"
 
-#: c-family/c-warn.c:1745
+#: c-family/c-warn.c:1753
 #, gcc-internal-format
 msgid "suggest parentheses around operand of %<!%> or change %<|%> to %<||%> or %<!%> to %<~%>"
 msgstr ""
 
-#: c-family/c-warn.c:1753 c-family/c-warn.c:1757
+#: c-family/c-warn.c:1761 c-family/c-warn.c:1765
 #, fuzzy, gcc-internal-format
 #| msgid "suggest parentheses around arithmetic in operand of ^"
 msgid "suggest parentheses around arithmetic in operand of %<^%>"
 msgstr "^ terimindeki aritmetik çevresinde parantezler önerilir"
 
-#: c-family/c-warn.c:1761 c-family/c-warn.c:1764
+#: c-family/c-warn.c:1769 c-family/c-warn.c:1772
 #, fuzzy, gcc-internal-format
 #| msgid "suggest parentheses around comparison in operand of ^"
 msgid "suggest parentheses around comparison in operand of %<^%>"
 msgstr "^ terimindeki karşılaştırma çevresinde parantezler önerilir"
 
-#: c-family/c-warn.c:1770 c-family/c-warn.c:1773
+#: c-family/c-warn.c:1778 c-family/c-warn.c:1781
 #, fuzzy, gcc-internal-format
 #| msgid "suggest parentheses around + or - in operand of &"
 msgid "suggest parentheses around %<+%> in operand of %<&%>"
 msgstr "& terimindeki + veya - çevresinde parantezler önerilir"
 
-#: c-family/c-warn.c:1776 c-family/c-warn.c:1779
+#: c-family/c-warn.c:1784 c-family/c-warn.c:1787
 #, fuzzy, gcc-internal-format
 #| msgid "suggest parentheses around + or - in operand of &"
 msgid "suggest parentheses around %<-%> in operand of %<&%>"
 msgstr "& terimindeki + veya - çevresinde parantezler önerilir"
 
-#: c-family/c-warn.c:1783 c-family/c-warn.c:1786
+#: c-family/c-warn.c:1791 c-family/c-warn.c:1794
 #, fuzzy, gcc-internal-format
 #| msgid "suggest parentheses around comparison in operand of &"
 msgid "suggest parentheses around comparison in operand of %<&%>"
 msgstr "& terimindeki karşılaştırma çevresinde parantezler önerilir"
 
-#: c-family/c-warn.c:1791
+#: c-family/c-warn.c:1799
 #, gcc-internal-format
 msgid "suggest parentheses around operand of %<!%> or change %<&%> to %<&&%> or %<!%> to %<~%>"
 msgstr ""
 
-#: c-family/c-warn.c:1798 c-family/c-warn.c:1801
+#: c-family/c-warn.c:1806 c-family/c-warn.c:1809
 #, fuzzy, gcc-internal-format
 #| msgid "suggest parentheses around comparison in operand of |"
 msgid "suggest parentheses around comparison in operand of %<==%>"
 msgstr "| terimindeki karşılaştırma çevresinde parantezler önerilir"
 
-#: c-family/c-warn.c:1806 c-family/c-warn.c:1809
+#: c-family/c-warn.c:1814 c-family/c-warn.c:1817
 #, fuzzy, gcc-internal-format
 #| msgid "suggest parentheses around comparison in operand of |"
 msgid "suggest parentheses around comparison in operand of %<!=%>"
 msgstr "| terimindeki karşılaştırma çevresinde parantezler önerilir"
 
-#: c-family/c-warn.c:1819 c-family/c-warn.c:1825
+#: c-family/c-warn.c:1827 c-family/c-warn.c:1833
 #, fuzzy, gcc-internal-format
 #| msgid "comparisons like X<=Y<=Z do not have their mathematical meaning"
 msgid "comparisons like %<X<=Y<=Z%> do not have their mathematical meaning"
 msgstr "X<=Y<=Z gibi bir karşılaştırma matematiksel olarak anlamlı değil"
 
-#: c-family/c-warn.c:1841
+#: c-family/c-warn.c:1849
 #, gcc-internal-format
 msgid "label %q+D defined but not used"
 msgstr "%q+D yaftası tanımlı ama kullanılmamış"
 
-#: c-family/c-warn.c:1843
+#: c-family/c-warn.c:1851
 #, gcc-internal-format
 msgid "label %q+D declared but not defined"
 msgstr "%q+D yaftası tanımlanmadan bildirilmiş"
 
-#: c-family/c-warn.c:1866
+#: c-family/c-warn.c:1874
 #, gcc-internal-format
 msgid "division by zero"
 msgstr "sıfırla bölme"
 
-#: c-family/c-warn.c:1886
+#: c-family/c-warn.c:1894
 #, gcc-internal-format
 msgid "%<memset%> used with constant zero length parameter; this could be due to transposed parameters"
 msgstr ""
 
-#: c-family/c-warn.c:1909
+#: c-family/c-warn.c:1918
 #, gcc-internal-format
 msgid "%<memset%> used with length equal to number of elements without multiplication by element size"
 msgstr ""
 
-#: c-family/c-warn.c:1948 c/c-typeck.c:11499 c/c-typeck.c:11667
+#: c-family/c-warn.c:1957 c/c-typeck.c:11504 c/c-typeck.c:11672
 #: cp/typeck.c:5048
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between types %q#T and %q#T"
@@ -31578,80 +31621,80 @@
 msgid "comparison between types %qT and %qT"
 msgstr "%q#T ile %q#T türleri arasında karşılaştırma"
 
-#: c-family/c-warn.c:1998
+#: c-family/c-warn.c:2007
 #, gcc-internal-format
 msgid "comparison of integer expressions of different signedness: %qT and %qT"
 msgstr ""
 
-#: c-family/c-warn.c:2051
+#: c-family/c-warn.c:2060
 #, gcc-internal-format
 msgid "promoted ~unsigned is always non-zero"
 msgstr ""
 
-#: c-family/c-warn.c:2054
+#: c-family/c-warn.c:2063
 #, gcc-internal-format
 msgid "comparison of promoted ~unsigned with constant"
 msgstr "sabitle yükseltgenmiş ~unsigned karşılaştırması"
 
-#: c-family/c-warn.c:2064
+#: c-family/c-warn.c:2073
 #, gcc-internal-format
 msgid "comparison of promoted ~unsigned with unsigned"
 msgstr "unsigned ile ~unsigned'a yükseltgenmiş türlerin karşılaştırması"
 
-#: c-family/c-warn.c:2118
+#: c-family/c-warn.c:2127
 #, fuzzy, gcc-internal-format
 #| msgid "unused parameter %q+D"
 msgid "unused parameter %qD"
 msgstr "parametre %q+D kullanılmamış"
 
-#: c-family/c-warn.c:2180
+#: c-family/c-warn.c:2189
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D defined but not used"
 msgid "typedef %qD locally defined but not used"
 msgstr "%q+D tanımlanmış ama kullanılmamış"
 
-#: c-family/c-warn.c:2215
+#: c-family/c-warn.c:2224
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<const%>"
 msgid "duplicated %<if%> condition"
 msgstr "%<const%> yinelenmiş"
 
-#: c-family/c-warn.c:2244
+#: c-family/c-warn.c:2253
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D with attribute noinline follows inline declaration "
 msgid "optimization attribute on %qD follows definition but the attribute doesn%'t match"
 msgstr "%qD satıriçi öznitelikli olmayan bildirimi satıriçi bildirimi izliyor"
 
-#: c-family/c-warn.c:2254
+#: c-family/c-warn.c:2261
 #, fuzzy, gcc-internal-format
 #| msgid "inline declaration of %qD follows declaration with attribute noinline"
 msgid "inline declaration of %qD follows declaration with attribute %qs"
 msgstr "%qD satıriçi bildirimi satıriçi öznitelikli olmayan bildirimi izliyor"
 
-#: c-family/c-warn.c:2259
+#: c-family/c-warn.c:2266
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D with attribute noinline follows inline declaration "
 msgid "declaration of %q+D with attribute %qs follows inline declaration"
 msgstr "%qD satıriçi öznitelikli olmayan bildirimi satıriçi bildirimi izliyor"
 
-#: c-family/c-warn.c:2306
+#: c-family/c-warn.c:2313
 #, gcc-internal-format
 msgid "result of %qE requires %u bits to represent, but %qT only has %u bits"
 msgstr ""
 
-#: c-family/c-warn.c:2344 c-family/c-warn.c:2368
+#: c-family/c-warn.c:2351 c-family/c-warn.c:2375
 #, fuzzy, gcc-internal-format
 #| msgid "comparison of unsigned expression < 0 is always false"
 msgid "comparison of constant %qE with boolean expression is always false"
 msgstr "unsigned ifade < 0 karşılaştırması daima yanlıştır"
 
-#: c-family/c-warn.c:2347 c-family/c-warn.c:2365
+#: c-family/c-warn.c:2354 c-family/c-warn.c:2372
 #, fuzzy, gcc-internal-format
 #| msgid "comparison of unsigned expression >= 0 is always true"
 msgid "comparison of constant %qE with boolean expression is always true"
 msgstr "unsigned ifade >=0 karşılaştırması daima doğrudur"
 
-#: c-family/c-warn.c:2415
+#: c-family/c-warn.c:2422
 #, fuzzy
 msgid "passing argument %i to restrict-qualified parameter aliases with argument %Z"
 msgid_plural "passing argument %i to restrict-qualified parameter aliases with arguments %Z"
@@ -31658,17 +31701,17 @@
 msgstr[0] "%2$qE işlevinin %1$d. argümanına aktarım gösterici hedef türündeki niteleyicileri iptal ediyor"
 msgstr[1] "%2$qE işlevinin %1$d. argümanına aktarım gösterici hedef türündeki niteleyicileri iptal ediyor"
 
-#: c-family/c-warn.c:2480 c/c-typeck.c:5288 cp/call.c:5365
+#: c-family/c-warn.c:2487 c/c-typeck.c:5293 cp/call.c:5365
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr ""
 
-#: c-family/c-warn.c:2586
+#: c-family/c-warn.c:2593
 #, gcc-internal-format
 msgid "macro expands to multiple statements"
 msgstr ""
 
-#: c-family/c-warn.c:2587
+#: c-family/c-warn.c:2594
 #, gcc-internal-format
 msgid "some parts of macro expansion are not guarded by this %qs clause"
 msgstr ""
@@ -31684,7 +31727,7 @@
 msgid "too many input files"
 msgstr "girdi dosyası sayısı çok fazla"
 
-#: common/config/aarch64/aarch64-common.c:319 config/aarch64/aarch64.c:10686
+#: common/config/aarch64/aarch64-common.c:319 config/aarch64/aarch64.c:10702
 #, fuzzy, gcc-internal-format
 #| msgid "bad value %qs for -mcpu switch"
 msgid "unknown value %qs for -mcpu"
@@ -31717,7 +31760,7 @@
 msgstr ""
 
 #: common/config/arm/arm-common.c:322 common/config/arm/arm-common.c:376
-#: common/config/arm/arm-common.c:423 config/aarch64/aarch64.c:10639
+#: common/config/arm/arm-common.c:423 config/aarch64/aarch64.c:10655
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments are: %s; did you mean %qs?"
@@ -31724,7 +31767,7 @@
 msgstr "%qs özniteliğinin argümanı geçersiz"
 
 #: common/config/arm/arm-common.c:325 common/config/arm/arm-common.c:379
-#: common/config/arm/arm-common.c:426 config/aarch64/aarch64.c:10642
+#: common/config/arm/arm-common.c:426 config/aarch64/aarch64.c:10658
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments are: %s"
@@ -32230,13 +32273,13 @@
 msgid "profiler support for VxWorks"
 msgstr "VxWorks için profilci desteği"
 
-#: config/aarch64/aarch64-builtins.c:1109 config/arm/arm-builtins.c:2262
+#: config/aarch64/aarch64-builtins.c:1109 config/arm/arm-builtins.c:2272
 #, fuzzy, gcc-internal-format
 #| msgid "argument %qd is not a constant"
 msgid "%Kargument %d must be a constant immediate"
 msgstr "%qd argümanı bir sabit değil"
 
-#: config/aarch64/aarch64-builtins.c:1180 config/arm/arm-builtins.c:2492
+#: config/aarch64/aarch64-builtins.c:1180 config/arm/arm-builtins.c:2502
 #, fuzzy, gcc-internal-format
 #| msgid "mask must be an immediate"
 msgid "%Klane index must be a constant immediate"
@@ -32247,193 +32290,193 @@
 msgid "%Ktotal size and element size must be a non-zero constant immediate"
 msgstr ""
 
-#: config/aarch64/aarch64.c:1053
+#: config/aarch64/aarch64.c:1069
 #, fuzzy, gcc-internal-format
 #| msgid "assert: %s is assign compatible with %s"
 msgid "%qs is incompatible with %s %s"
 msgstr "assert: %s %s ile uyumlu atanıyor"
 
-#: config/aarch64/aarch64.c:1055
+#: config/aarch64/aarch64.c:1071
 #, fuzzy, gcc-internal-format
 #| msgid "assert: %s is assign compatible with %s"
 msgid "%qs feature modifier is incompatible with %s %s"
 msgstr "assert: %s %s ile uyumlu atanıyor"
 
-#: config/aarch64/aarch64.c:3772
+#: config/aarch64/aarch64.c:3788
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10287
+#: config/aarch64/aarch64.c:10303
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown flag passed in -moverride=%s (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10331
+#: config/aarch64/aarch64.c:10347
 #, gcc-internal-format, gfc-internal-format
 msgid "%s string ill-formed\n"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10388
+#: config/aarch64/aarch64.c:10404
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid floating point option: -mfpu=%s"
 msgid "tuning string missing in option (%s)"
 msgstr "geçersiz gerçel değer seçeneği: -mfpu=%s"
 
-#: config/aarch64/aarch64.c:10406
+#: config/aarch64/aarch64.c:10422
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unknown spec function '%s'"
 msgid "unknown tuning option (%s)"
 msgstr "bilinmeyen '%s' spec işlevi"
 
-#: config/aarch64/aarch64.c:10683
+#: config/aarch64/aarch64.c:10699
 #, fuzzy, gcc-internal-format
 #| msgid "missing path after %qs"
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr "%qs den sonra yol eksik"
 
-#: config/aarch64/aarch64.c:10690
+#: config/aarch64/aarch64.c:10706
 #, fuzzy, gcc-internal-format
 #| msgid "missing filename after %qs"
 msgid "invalid feature modifier in %<-mcpu=%s%>"
 msgstr "%qs den sonra dosyaismi yok"
 
-#: config/aarch64/aarch64.c:10717
+#: config/aarch64/aarch64.c:10733
 #, fuzzy, gcc-internal-format
 #| msgid "missing path after %qs"
 msgid "missing arch name in %<-march=%s%>"
 msgstr "%qs den sonra yol eksik"
 
-#: config/aarch64/aarch64.c:10720
+#: config/aarch64/aarch64.c:10736
 #, fuzzy, gcc-internal-format
 #| msgid "Unknown value %qs of -mmacosx-version-min"
 msgid "unknown value %qs for -march"
 msgstr "-mmacosx-version-min için %qs değeri bilinmiyor"
 
-#: config/aarch64/aarch64.c:10724
+#: config/aarch64/aarch64.c:10740
 #, fuzzy, gcc-internal-format
 #| msgid "missing filename after %qs"
 msgid "invalid feature modifier in %<-march=%s%>"
 msgstr "%qs den sonra dosyaismi yok"
 
-#: config/aarch64/aarch64.c:10750
+#: config/aarch64/aarch64.c:10766
 #, fuzzy, gcc-internal-format
 #| msgid "missing path after %qs"
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr "%qs den sonra yol eksik"
 
-#: config/aarch64/aarch64.c:10753
+#: config/aarch64/aarch64.c:10769
 #, fuzzy, gcc-internal-format
 #| msgid "Unknown value %qs of -mmacosx-version-min"
 msgid "unknown value %qs for -mtune"
 msgstr "-mmacosx-version-min için %qs değeri bilinmiyor"
 
-#: config/aarch64/aarch64.c:10871 config/arm/arm.c:3173
+#: config/aarch64/aarch64.c:10887 config/arm/arm.c:3173
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "switch -mcpu=%s conflicts with -march= switch"
 msgid "switch -mcpu=%s conflicts with -march=%s switch"
 msgstr "-mcpu=%s ile -march= seçenekleri çelişiyor"
 
-#: config/aarch64/aarch64.c:10906
+#: config/aarch64/aarch64.c:10922
 #, fuzzy, gcc-internal-format
 #| msgid "does not support multilib"
 msgid "assembler does not support -mabi=ilp32"
 msgstr "multilib desteklenmiyor"
 
-#: config/aarch64/aarch64.c:10913
+#: config/aarch64/aarch64.c:10929
 #, gcc-internal-format
 msgid "return address signing is only supported for -mabi=lp64"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10975
+#: config/aarch64/aarch64.c:10991
 #, gcc-internal-format
 msgid "code model %qs with -f%s"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11138
+#: config/aarch64/aarch64.c:11154
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11141
+#: config/aarch64/aarch64.c:11157
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11145 config/aarch64/aarch64.c:11184
-#: config/aarch64/aarch64.c:11257
+#: config/aarch64/aarch64.c:11161 config/aarch64/aarch64.c:11200
+#: config/aarch64/aarch64.c:11273
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "invalid value (\"%s\") in %<target()%> pragma or attribute"
 msgstr "%qs özniteliğinin argümanı geçersiz"
 
-#: config/aarch64/aarch64.c:11177
+#: config/aarch64/aarch64.c:11193
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11180
+#: config/aarch64/aarch64.c:11196
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11213
+#: config/aarch64/aarch64.c:11229
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"tune=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11253
+#: config/aarch64/aarch64.c:11269
 #, fuzzy, gcc-internal-format
 #| msgid "missing %<(%> after %<#pragma pack%> - ignored"
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr "%<#pragma pack%> sonrasında %<(%> eksik - yoksayıldı"
 
-#: config/aarch64/aarch64.c:11306 config/aarch64/aarch64.c:11483
+#: config/aarch64/aarch64.c:11322 config/aarch64/aarch64.c:11499
 #, fuzzy, gcc-internal-format
 #| msgid "malformed %<#pragma init%>"
 msgid "malformed %<target()%> pragma or attribute"
 msgstr "%<#pragma init%> bozuk"
 
-#: config/aarch64/aarch64.c:11354
+#: config/aarch64/aarch64.c:11370
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11362
+#: config/aarch64/aarch64.c:11378
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11416
+#: config/aarch64/aarch64.c:11432
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11473 config/arm/arm.c:30742
-#: config/i386/i386.c:5440 config/powerpcspe/powerpcspe.c:39760
-#: config/rs6000/rs6000.c:36904 config/s390/s390.c:15746
+#: config/aarch64/aarch64.c:11489 config/arm/arm.c:30742
+#: config/i386/i386.c:5443 config/powerpcspe/powerpcspe.c:39760
+#: config/rs6000/rs6000.c:36960 config/s390/s390.c:15746
 #, fuzzy, gcc-internal-format
 #| msgid "alias argument not a string"
 msgid "attribute %<target%> argument not a string"
 msgstr "alias argümanı bir dizge değil"
 
-#: config/aarch64/aarch64.c:11500
+#: config/aarch64/aarch64.c:11516
 #, fuzzy, gcc-internal-format
 #| msgid "alias argument not a string"
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr "alias argümanı bir dizge değil"
 
-#: config/aarch64/aarch64.c:11509
+#: config/aarch64/aarch64.c:11525
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13571
+#: config/aarch64/aarch64.c:13587
 #, gcc-internal-format
 msgid "%Klane %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13573
+#: config/aarch64/aarch64.c:13589
 #, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr ""
@@ -32494,8 +32537,8 @@
 msgid "bad value %qs for -mmemory-latency"
 msgstr "-mmemory-latency için değer %qs hatalı"
 
-#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6526
-#: config/arc/arc.c:6800 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
+#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6517
+#: config/arc/arc.c:6791 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
 #: config/tilepro/tilepro.c:3108
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -32614,11 +32657,11 @@
 #: config/arm/arm.c:7029 config/avr/avr.c:9718 config/avr/avr.c:9734
 #: config/bfin/bfin.c:4705 config/bfin/bfin.c:4766 config/bfin/bfin.c:4795
 #: config/epiphany/epiphany.c:491 config/h8300/h8300.c:5459
-#: config/i386/i386.c:6452 config/i386/i386.c:12479 config/i386/i386.c:41424
-#: config/i386/i386.c:41474 config/i386/i386.c:41544 config/m68k/m68k.c:780
+#: config/i386/i386.c:6455 config/i386/i386.c:12482 config/i386/i386.c:41418
+#: config/i386/i386.c:41468 config/i386/i386.c:41538 config/m68k/m68k.c:780
 #: config/mcore/mcore.c:3070 config/nvptx/nvptx.c:4611
 #: config/powerpcspe/powerpcspe.c:35785 config/riscv/riscv.c:2698
-#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:32982
+#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:33038
 #: config/rx/rx.c:2719 config/rx/rx.c:2745 config/s390/s390.c:1056
 #: config/s390/s390.c:1143 config/sh/sh.c:8428 config/sh/sh.c:8446
 #: config/sh/sh.c:8470 config/sh/sh.c:8541 config/sh/sh.c:8564
@@ -32629,124 +32672,124 @@
 msgid "%qE attribute only applies to functions"
 msgstr "%qs özniteliği sadece işlevlere uygulanır"
 
-#: config/arc/arc.c:6425
+#: config/arc/arc.c:6416
 #, fuzzy, gcc-internal-format
 #| msgid "%<__builtin_next_arg%> called without an argument"
 msgid "__builtin_arc_aligned with non-constant alignment"
 msgstr "%<__builtin_next_arg%> argümansız çağrılmış"
 
-#: config/arc/arc.c:6433
+#: config/arc/arc.c:6424
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to %<__builtin_frame_address%>"
 msgid "invalid alignment value for __builtin_arc_aligned"
 msgstr "%<__builtin_frame_address%>'e aktarılan argüman geçersiz"
 
-#: config/arc/arc.c:6596
+#: config/arc/arc.c:6587
 #, fuzzy, gcc-internal-format
 #| msgid "-frepo must be used with -c"
 msgid "operand 1 should be an unsigned 3-bit immediate"
 msgstr "-frepo, -c ile kullanilmalı"
 
-#: config/arc/arc.c:6637 config/arc/arc.c:6734
+#: config/arc/arc.c:6628 config/arc/arc.c:6725
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6670 config/arc/arc.c:6702
+#: config/arc/arc.c:6661 config/arc/arc.c:6693
 #, gcc-internal-format
 msgid "operand 1 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6674 config/arc/arc.c:6706
+#: config/arc/arc.c:6665 config/arc/arc.c:6697
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "operand 2 should be an unsigned 8-bit value"
 msgstr "2. argüman 5 bitlik bir işaretsiz sabit olmalı"
 
-#: config/arc/arc.c:6738
+#: config/arc/arc.c:6729
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "operand 3 should be an unsigned 8-bit value"
 msgstr "2. argüman 5 bitlik bir işaretsiz sabit olmalı"
 
-#: config/arc/arc.c:6771
+#: config/arc/arc.c:6762
 #, gcc-internal-format
 msgid "operand 4 should be an unsigned 8-bit value (0-255)"
 msgstr ""
 
-#: config/arc/arc.c:6775
+#: config/arc/arc.c:6766
 #, gcc-internal-format
 msgid "operand 3 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6782
+#: config/arc/arc.c:6773
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (subreg 0-7)"
 msgstr ""
 
-#: config/arc/arc.c:6785
+#: config/arc/arc.c:6776
 #, gcc-internal-format
 msgid "operand 2 should be an even 3-bit value (subreg 0,2,4,6)"
 msgstr ""
 
-#: config/arc/arc.c:6832
+#: config/arc/arc.c:6823
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "long long constant not a valid immediate operand"
 msgid "builtin requires an immediate for operand %d"
 msgstr "long long sabit geçerli bir anlık terim değil"
 
-#: config/arc/arc.c:6837
+#: config/arc/arc.c:6828
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "operand %d should be a 6 bit unsigned immediate"
 msgstr "2. argüman 5 bitlik bir işaretsiz sabit olmalı"
 
-#: config/arc/arc.c:6841
+#: config/arc/arc.c:6832
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "operand %d should be a 8 bit unsigned immediate"
 msgstr "2. argüman 5 bitlik bir işaretsiz sabit olmalı"
 
-#: config/arc/arc.c:6845
+#: config/arc/arc.c:6836
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "operand %d should be a 3 bit unsigned immediate"
 msgstr "2. argüman 5 bitlik bir işaretsiz sabit olmalı"
 
-#: config/arc/arc.c:6848
+#: config/arc/arc.c:6839
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown builtin immediate operand type for operand %d"
 msgstr ""
 
-#: config/arc/arc.c:6899
+#: config/arc/arc.c:6890
 #, gcc-internal-format
 msgid "register number must be a compile-time constant. Try giving higher optimization levels"
 msgstr ""
 
-#: config/arc/arc.c:7685
+#: config/arc/arc.c:7747
 #, gcc-internal-format
 msgid "Insn addresses not set after shorten_branches"
 msgstr ""
 
-#: config/arc/arc.c:7894
+#: config/arc/arc.c:7956
 #, fuzzy, gcc-internal-format
 #| msgid "pre-increment address is not a register"
 msgid "insn addresses not freed"
 msgstr "ön arttırımlı adres bir yazmaç değil"
 
-#: config/arc/arc.c:10682
+#: config/arc/arc.c:10670
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to variables"
 msgid "%qE attribute only valid for ARCv2 architecture"
 msgstr "%qs özniteliği sadece değişkenlere uygulanır"
 
-#: config/arc/arc.c:10690 config/arc/arc.c:10729
+#: config/arc/arc.c:10678 config/arc/arc.c:10717
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "argument of %qE attribute is missing"
 msgstr "%qs özniteliğinin argümanı bir dizge sabiti değil"
 
-#: config/arc/arc.c:10701 config/arc/arc.c:10740 config/arc/arc.c:10842
+#: config/arc/arc.c:10689 config/arc/arc.c:10728 config/arc/arc.c:10830
 #: config/avr/avr.c:9790
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
@@ -32753,25 +32796,25 @@
 msgid "%qE attribute allows only an integer constant argument"
 msgstr "%qs özniteliği bir tamsayı sabit argüman gerektirir"
 
-#: config/arc/arc.c:10721
+#: config/arc/arc.c:10709
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to function types"
 msgid "%qE attribute only valid for ARC EM architecture"
 msgstr "%qs özniteliği sadece işlev türlerine uygulanır"
 
-#: config/arc/arc.c:10776
+#: config/arc/arc.c:10764
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to function types"
 msgid "%qE attribute only applies to types"
 msgstr "%qs özniteliği sadece işlev türlerine uygulanır"
 
-#: config/arc/arc.c:10782
+#: config/arc/arc.c:10770
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored"
 msgid "argument of %qE attribute ignored"
 msgstr "%qE özniteliği yoksayıldı"
 
-#: config/arc/arc.c:10832 config/avr/avr.c:9777 config/bfin/bfin.c:4827
+#: config/arc/arc.c:10820 config/avr/avr.c:9777 config/bfin/bfin.c:4827
 #: config/i386/winnt.c:63 config/msp430/msp430.c:2018
 #: config/nvptx/nvptx.c:4634
 #, fuzzy, gcc-internal-format
@@ -32779,175 +32822,175 @@
 msgid "%qE attribute only applies to variables"
 msgstr "%qs özniteliği sadece değişkenlere uygulanır"
 
-#: config/arm/arm-builtins.c:2370
+#: config/arm/arm-builtins.c:2380
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "this builtin is not supported for this target"
 msgstr "bu hedefte yığıt sınırları desteklenmiyor"
 
-#: config/arm/arm-builtins.c:2475
+#: config/arm/arm-builtins.c:2485
 #, gcc-internal-format
 msgid "You must enable NEON instructions (e.g. -mfloat-abi=softfp -mfpu=neon) to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2513
+#: config/arm/arm-builtins.c:2523
 #, gcc-internal-format
 msgid "You must enable VFP instructions to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2573
+#: config/arm/arm-builtins.c:2583
 #, gcc-internal-format
 msgid "You must enable crypto instructions (e.g. include -mfloat-abi=softfp -mfpu=crypto-neon...) to use these intrinsics."
 msgstr ""
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:2633 config/arm/arm-builtins.c:2737
+#: config/arm/arm-builtins.c:2643 config/arm/arm-builtins.c:2747
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr "seçici bir anlık değer olmalı"
 
-#: config/arm/arm-builtins.c:2641 config/arm/arm-builtins.c:2686
-#: config/arm/arm-builtins.c:2744 config/arm/arm-builtins.c:2753
+#: config/arm/arm-builtins.c:2651 config/arm/arm-builtins.c:2696
+#: config/arm/arm-builtins.c:2754 config/arm/arm-builtins.c:2763
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2646 config/arm/arm-builtins.c:2755
+#: config/arm/arm-builtins.c:2656 config/arm/arm-builtins.c:2765
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2651 config/arm/arm-builtins.c:2757
+#: config/arm/arm-builtins.c:2661 config/arm/arm-builtins.c:2767
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2823
+#: config/arm/arm-builtins.c:2833
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr "mask bir anlık değer olmalı"
 
-#: config/arm/arm-builtins.c:2828
+#: config/arm/arm-builtins.c:2838
 #, gcc-internal-format
 msgid "the range of mask should be in 0 to 255"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3016
+#: config/arm/arm-builtins.c:3026
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3018
+#: config/arm/arm-builtins.c:3028
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3020
+#: config/arm/arm-builtins.c:3030
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3022
+#: config/arm/arm-builtins.c:3032
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3028
+#: config/arm/arm-builtins.c:3038
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3030
+#: config/arm/arm-builtins.c:3040
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3035
+#: config/arm/arm-builtins.c:3045
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3037
+#: config/arm/arm-builtins.c:3047
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3039
+#: config/arm/arm-builtins.c:3049
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3041
+#: config/arm/arm-builtins.c:3051
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3043
+#: config/arm/arm-builtins.c:3053
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3045
+#: config/arm/arm-builtins.c:3055
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3047
+#: config/arm/arm-builtins.c:3057
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3049
+#: config/arm/arm-builtins.c:3059
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3051
+#: config/arm/arm-builtins.c:3061
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3053
+#: config/arm/arm-builtins.c:3063
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3055
+#: config/arm/arm-builtins.c:3065
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3057
+#: config/arm/arm-builtins.c:3067
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3059
+#: config/arm/arm-builtins.c:3069
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3061
+#: config/arm/arm-builtins.c:3071
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3063
+#: config/arm/arm-builtins.c:3073
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3065
+#: config/arm/arm-builtins.c:3075
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3067
+#: config/arm/arm-builtins.c:3077
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3069
+#: config/arm/arm-builtins.c:3079
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr ""
@@ -33940,18 +33983,18 @@
 msgid "can%'t set position in PCH file: %m"
 msgstr "PCH dosyası içinde konum belirlenemiyor: %m"
 
-#: config/i386/i386.c:3177
+#: config/i386/i386.c:3180
 #, fuzzy, gcc-internal-format
 #| msgid "error in args to spec function '%s'"
 msgid "wrong argument %qs to option %qs"
 msgstr "'%s' spec işlevi için argümanlar hatalı"
 
-#: config/i386/i386.c:3183
+#: config/i386/i386.c:3186
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr ""
 
-#: config/i386/i386.c:3193
+#: config/i386/i386.c:3196
 #, fuzzy, gcc-internal-format
 #| msgid "register name not specified for %q+D"
 msgid "wrong strategy name %qs specified for option %qs"
@@ -33958,594 +34001,594 @@
 msgstr "%q+D için yazmaç ismi belirtilmemiş"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3219
+#: config/i386/i386.c:3222
 #, fuzzy, gcc-internal-format
 #| msgid "register name not specified for %q+D"
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr "%q+D için yazmaç ismi belirtilmemiş"
 
-#: config/i386/i386.c:3232
+#: config/i386/i386.c:3235
 #, fuzzy, gcc-internal-format
 #| msgid "alignment may not be specified for %q+D"
 msgid "unknown alignment %qs specified for option %qs"
 msgstr "hizalama, %q+D için belirtilmiş olmayabilir"
 
-#: config/i386/i386.c:3242
+#: config/i386/i386.c:3245
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr ""
 
-#: config/i386/i386.c:3249
+#: config/i386/i386.c:3252
 #, fuzzy, gcc-internal-format
 #| msgid "no class name specified with %qs"
 msgid "too many size ranges specified in option %qs"
 msgstr "%qs ile belirtilmiş sınıf ismi yok"
 
-#: config/i386/i386.c:3302
+#: config/i386/i386.c:3305
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unknown register name: %s"
 msgid "unknown parameter to option -mtune-ctrl: %s"
 msgstr "bilinmeyen yazmaç ismi: %s"
 
-#: config/i386/i386.c:3726
+#: config/i386/i386.c:3729
 #, fuzzy, gcc-internal-format
 #| msgid "64-bit ABI not supported in ESA/390 mode"
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "ESA/390 kipinde 64 bitlik ABI desteklenmiyor."
 
-#: config/i386/i386.c:3775
+#: config/i386/i386.c:3778
 #, fuzzy, gcc-internal-format
 #| msgid "This switch is deprecated; use -Wextra instead"
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "Önerilmiyor; yerine -Wextra kullanın"
 
-#: config/i386/i386.c:3777
+#: config/i386/i386.c:3780
 #, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr ""
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3804
+#: config/i386/i386.c:3807
 #, gcc-internal-format
 msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386.c:3821
+#: config/i386/i386.c:3824
 #, fuzzy, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "%2$s bit kipinde %1$qs kod modeli desteklenmiyor"
 
-#: config/i386/i386.c:3833
+#: config/i386/i386.c:3836
 #, fuzzy, gcc-internal-format
 #| msgid "static is not supported on TPF-OS"
 msgid "-mabi=ms not supported with X32 ABI"
 msgstr "static TPF-OS'da desteklenmiyor"
 
-#: config/i386/i386.c:3851 config/i386/i386.c:3860 config/i386/i386.c:3872
-#: config/i386/i386.c:3883 config/i386/i386.c:3894
+#: config/i386/i386.c:3854 config/i386/i386.c:3863 config/i386/i386.c:3875
+#: config/i386/i386.c:3886 config/i386/i386.c:3897
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "%2$s bit kipinde %1$qs kod modeli desteklenmiyor"
 
-#: config/i386/i386.c:3863 config/i386/i386.c:3875
+#: config/i386/i386.c:3866 config/i386/i386.c:3878
 #, fuzzy, gcc-internal-format
 #| msgid "code model %s not supported in PIC mode"
 msgid "code model %qs not supported in x32 mode"
 msgstr "PIC kipinde %s kod modeli desteklenmiyor"
 
-#: config/i386/i386.c:3881 config/i386/i386.c:3890 config/i386/i386.c:5213
+#: config/i386/i386.c:3884 config/i386/i386.c:3893 config/i386/i386.c:5216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "code model %s not supported in PIC mode"
 msgid "code model %s does not support PIC mode"
 msgstr "PIC kipinde %s kod modeli desteklenmiyor"
 
-#: config/i386/i386.c:3918
+#: config/i386/i386.c:3921
 #, fuzzy, gcc-internal-format
 #| msgid "-m%s not supported in this configuration"
 msgid "-masm=intel not supported in this configuration"
 msgstr "-m%s bu yapılandırmada desteklenmiyor"
 
-#: config/i386/i386.c:3923
+#: config/i386/i386.c:3926
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "%i bitlik kip bunun içinde derlenmiş değil:"
 
-#: config/i386/i386.c:3932
+#: config/i386/i386.c:3935
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386.c:3934
+#: config/i386/i386.c:3937
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386.c:3941
+#: config/i386/i386.c:3944
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386.c:3943
+#: config/i386/i386.c:3946
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386.c:3951 config/i386/i386.c:4265
+#: config/i386/i386.c:3954 config/i386/i386.c:4268
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "Seçtiginiz işlemci  x86-64 komutlarını desteklemiyor."
 
-#: config/i386/i386.c:4197 config/i386/i386.c:4200
+#: config/i386/i386.c:4200 config/i386/i386.c:4203
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "Intel MPX does not support x32"
 msgstr "%s %s desteği vermiyor"
 
-#: config/i386/i386.c:4205
+#: config/i386/i386.c:4208
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "bad value (%qs) for %<-march=%> switch"
 msgstr "-march= seçeneğinin değeri (%s) hatalı"
 
-#: config/i386/i386.c:4206
+#: config/i386/i386.c:4209
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "bad value (%qs) for %<target(\"arch=\")%> attribute"
 msgstr "-march= seçeneğinin değeri (%s) hatalı"
 
-#: config/i386/i386.c:4228
+#: config/i386/i386.c:4231
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "%qs özniteliğinin argümanı geçersiz"
 
-#: config/i386/i386.c:4230
+#: config/i386/i386.c:4233
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4235
+#: config/i386/i386.c:4238
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "%qs özniteliğinin argümanı geçersiz"
 
-#: config/i386/i386.c:4236
+#: config/i386/i386.c:4239
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "%qs özniteliğinin argümanı geçersiz"
 
-#: config/i386/i386.c:4284
+#: config/i386/i386.c:4287
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -mtune= switch"
 msgid "bad value (%qs) for %<-mtune=%> switch"
 msgstr "-mtune= seçeneğinin değeri (%s) hatalı"
 
-#: config/i386/i386.c:4285
+#: config/i386/i386.c:4288
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -mtune= switch"
 msgid "bad value (%qs) for %<target(\"tune=\")%> attribute"
 msgstr "-mtune= seçeneğinin değeri (%s) hatalı"
 
-#: config/i386/i386.c:4305
+#: config/i386/i386.c:4308
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "%qs özniteliğinin argümanı geçersiz"
 
-#: config/i386/i386.c:4307
+#: config/i386/i386.c:4310
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4312
+#: config/i386/i386.c:4315
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "%qs özniteliğinin argümanı geçersiz"
 
-#: config/i386/i386.c:4313
+#: config/i386/i386.c:4316
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "%qs özniteliğinin argümanı geçersiz"
 
-#: config/i386/i386.c:4379
+#: config/i386/i386.c:4382
 #, gcc-internal-format
 msgid "-mregparm is ignored in 64-bit mode"
 msgstr ""
 
-#: config/i386/i386.c:4381
+#: config/i386/i386.c:4384
 #, gcc-internal-format
 msgid "-mregparm is ignored for Intel MCU psABI"
 msgstr ""
 
-#: config/i386/i386.c:4384
+#: config/i386/i386.c:4387
 #, gcc-internal-format, gfc-internal-format
 msgid "-mregparm=%d is not between 0 and %d"
 msgstr "-mregparm=%d, 0 ile %d arasında değil"
 
-#: config/i386/i386.c:4417
+#: config/i386/i386.c:4420
 #, fuzzy, gcc-internal-format
 #| msgid "typedef declaration invalid in parameter declaration"
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "typedef bildirimi parametre bildiriminde geçersiz"
 
-#: config/i386/i386.c:4418
+#: config/i386/i386.c:4421
 #, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr ""
 
-#: config/i386/i386.c:4497
+#: config/i386/i386.c:4500
 #, fuzzy, gcc-internal-format
 #| msgid "-fprefetch-loop-arrays not supported for this target"
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "bu hedefte -fprefetch-loop-arrays desteklenmiyor"
 
-#: config/i386/i386.c:4500
+#: config/i386/i386.c:4503
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and 12"
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d, %d ile 12 arasında değil"
 
-#: config/i386/i386.c:4523
+#: config/i386/i386.c:4526
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and 12"
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr "-mpreferred-stack-boundary=%d, %d ile 12 arasında değil"
 
-#: config/i386/i386.c:4536
+#: config/i386/i386.c:4539
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "-march=%s seçilen ABI ile uyumsuz"
 
-#: config/i386/i386.c:4539
+#: config/i386/i386.c:4542
 #, fuzzy, gcc-internal-format
 #| msgid "inter-module optimizations not implemented for C++"
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr "modüller arası eniyilemeler henüz C++ için gerçeklenmedi"
 
-#: config/i386/i386.c:4545
+#: config/i386/i386.c:4548
 #, fuzzy, gcc-internal-format
 #| msgid "-msseregparm used without SSE enabled"
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "-msseregparm SSE etkin değilken kullanılmış"
 
-#: config/i386/i386.c:4546
+#: config/i386/i386.c:4549
 #, fuzzy, gcc-internal-format
 #| msgid "-msseregparm used without SSE enabled"
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "-msseregparm SSE etkin değilken kullanılmış"
 
-#: config/i386/i386.c:4556
+#: config/i386/i386.c:4559
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "SSE komut kümesi iptal edildi, 387 aritmetiği kullanılıyor"
 
-#: config/i386/i386.c:4563
+#: config/i386/i386.c:4566
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "387 komut kümesi iptal edildi, SSE aritmetiği kullanılıyor"
 
-#: config/i386/i386.c:4613
+#: config/i386/i386.c:4616
 #, fuzzy, gcc-internal-format
 #| msgid "unwind tables currently require either a frame pointer or -maccumulate-outgoing-args for correctness"
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr "birbirlerini etkilemeyenler tabloları doğruluk için ya bir çerçeve göstericisi ya da -maccumulate-outgoing-args gerektirir"
 
-#: config/i386/i386.c:4615
+#: config/i386/i386.c:4618
 #, fuzzy, gcc-internal-format
 #| msgid "unwind tables currently require either a frame pointer or -maccumulate-outgoing-args for correctness"
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr "birbirlerini etkilemeyenler tabloları doğruluk için ya bir çerçeve göstericisi ya da -maccumulate-outgoing-args gerektirir"
 
-#: config/i386/i386.c:4629
+#: config/i386/i386.c:4632
 #, fuzzy, gcc-internal-format
 #| msgid "unwind tables currently require either a frame pointer or -maccumulate-outgoing-args for correctness"
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr "birbirlerini etkilemeyenler tabloları doğruluk için ya bir çerçeve göstericisi ya da -maccumulate-outgoing-args gerektirir"
 
-#: config/i386/i386.c:4631
+#: config/i386/i386.c:4634
 #, fuzzy, gcc-internal-format
 #| msgid "unwind tables currently require either a frame pointer or -maccumulate-outgoing-args for correctness"
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr "birbirlerini etkilemeyenler tabloları doğruluk için ya bir çerçeve göstericisi ya da -maccumulate-outgoing-args gerektirir"
 
-#: config/i386/i386.c:4741
+#: config/i386/i386.c:4744
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr ""
 
-#: config/i386/i386.c:4744
+#: config/i386/i386.c:4747
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr ""
 
-#: config/i386/i386.c:4748
+#: config/i386/i386.c:4751
 #, gcc-internal-format
 msgid "-mcall-ms2sysv-xlogues isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386.c:4813 config/powerpcspe/powerpcspe.c:5663
+#: config/i386/i386.c:4816 config/powerpcspe/powerpcspe.c:5663
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unknown -m%s= option specified: '%s'"
 msgid "unknown option for -mrecip=%s"
 msgstr "bilinmeyen -m%s= seçeneği belirtilmiş: '%s'"
 
-#: config/i386/i386.c:4870 config/powerpcspe/powerpcspe.c:5339
+#: config/i386/i386.c:4873 config/powerpcspe/powerpcspe.c:5339
 #, gcc-internal-format
 msgid "%qs is not a valid number in -mstack-protector-guard-offset="
 msgstr ""
 
-#: config/i386/i386.c:4875 config/powerpcspe/powerpcspe.c:5344
+#: config/i386/i386.c:4878 config/powerpcspe/powerpcspe.c:5344
 #, fuzzy, gcc-internal-format
 #| msgid "\"%s\" is not a valid option to the preprocessor"
 msgid "%qs is not a valid offset in -mstack-protector-guard-offset="
 msgstr "\"%s\" önişlemci için geçerli bir seçenek değil"
 
-#: config/i386/i386.c:4907 config/powerpcspe/powerpcspe.c:5356
+#: config/i386/i386.c:4910 config/powerpcspe/powerpcspe.c:5356
 #, gcc-internal-format
 msgid "%qs is not a valid base register in -mstack-protector-guard-reg="
 msgstr ""
 
-#: config/i386/i386.c:5506 config/i386/i386.c:5553 config/s390/s390.c:15812
+#: config/i386/i386.c:5509 config/i386/i386.c:5556 config/s390/s390.c:15812
 #: config/s390/s390.c:15862 config/s390/s390.c:15879
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr ""
 
-#: config/i386/i386.c:5534
+#: config/i386/i386.c:5537
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ACCESS specification at %L was already specified"
 msgid "option(\"%s\") was already specified"
 msgstr "ACCESS belirtimi %L'de zaten belirtilmiş"
 
-#: config/i386/i386.c:5837
+#: config/i386/i386.c:5840
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and cdecl attributes are not compatible"
 msgid "interrupt and naked attributes are not compatible"
 msgstr "stdcall ve cdecl öznitelikleri uyumsuz"
 
-#: config/i386/i386.c:5852
+#: config/i386/i386.c:5855
 #, gcc-internal-format
 msgid "Only DWARF debug format is supported for interrupt service routine."
 msgstr ""
 
-#: config/i386/i386.c:5901
+#: config/i386/i386.c:5904
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s ile -mcall-%s uyumsuz."
 
-#: config/i386/i386.c:5913
+#: config/i386/i386.c:5916
 #, gcc-internal-format
 msgid "%<-mindirect-branch=thunk-extern%>, %<-fcf-protection=branch%> and %<-fcheck-pointer-bounds%> are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5949
+#: config/i386/i386.c:5952
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s ile -mcall-%s uyumsuz."
 
-#: config/i386/i386.c:6047
+#: config/i386/i386.c:6050
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "standard conversions are not allowed in this context"
 msgid "%s instructions aren't allowed in %s service routine"
 msgstr "standart uzlaşımlara bu bağlam içinde izin verilmez"
 
-#: config/i386/i386.c:6051
+#: config/i386/i386.c:6054
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Use a stack protection method for every function"
 msgid "%s instructions aren't allowed in function with no_caller_saved_registers attribute"
 msgstr "Her işlev için bir yığıt koruma yöntemi kullanılır"
 
-#: config/i386/i386.c:6465 config/i386/i386.c:6516
+#: config/i386/i386.c:6468 config/i386/i386.c:6519
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "fastcall ve regparm öznitelikleri uyumlu değil"
 
-#: config/i386/i386.c:6470
+#: config/i386/i386.c:6473
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "fastcall ve stdcall öznitelikleri uyumsuz"
 
-#: config/i386/i386.c:6477 config/i386/i386.c:41444
+#: config/i386/i386.c:6480 config/i386/i386.c:41438
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
 msgid "%qE attribute requires an integer constant argument"
 msgstr "%qs özniteliği bir tamsayı sabit argüman gerektirir"
 
-#: config/i386/i386.c:6483
+#: config/i386/i386.c:6486
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs attribute larger than %d"
 msgid "argument to %qE attribute larger than %d"
 msgstr "%qs özniteliğine argüman %d den büyük"
 
-#: config/i386/i386.c:6508 config/i386/i386.c:6551
+#: config/i386/i386.c:6511 config/i386/i386.c:6554
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "fastcall ve cdecl öznitelikleri uyumsuz"
 
-#: config/i386/i386.c:6512
+#: config/i386/i386.c:6515
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "fastcall ve stdcall öznitelikleri uyumsuz"
 
-#: config/i386/i386.c:6520 config/i386/i386.c:6569
+#: config/i386/i386.c:6523 config/i386/i386.c:6572
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "fastcall ve stdcall öznitelikleri uyumsuz"
 
-#: config/i386/i386.c:6530 config/i386/i386.c:6547
+#: config/i386/i386.c:6533 config/i386/i386.c:6550
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "stdcall ve cdecl öznitelikleri uyumsuz"
 
-#: config/i386/i386.c:6534
+#: config/i386/i386.c:6537
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "fastcall ve stdcall öznitelikleri uyumsuz"
 
-#: config/i386/i386.c:6538 config/i386/i386.c:6565
+#: config/i386/i386.c:6541 config/i386/i386.c:6568
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and fastcall attributes are not compatible"
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "fastcall ve stdcall öznitelikleri uyumsuz"
 
-#: config/i386/i386.c:6555 config/i386/i386.c:6573
+#: config/i386/i386.c:6558 config/i386/i386.c:6576
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and fastcall attributes are not compatible"
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "fastcall ve stdcall öznitelikleri uyumsuz"
 
-#: config/i386/i386.c:6561
+#: config/i386/i386.c:6564
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute is used for non-class method"
 msgstr "%qE özniteliği sınıf türleri dışında yoksayılır"
 
-#: config/i386/i386.c:6805
+#: config/i386/i386.c:6808
 #, fuzzy, gcc-internal-format
 #| msgid "Calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "SSE/SSE2 etkin değilken sseregparm öznitelikli %qD çağrısı"
 
-#: config/i386/i386.c:6808
+#: config/i386/i386.c:6811
 #, fuzzy, gcc-internal-format
 #| msgid "Calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "SSE/SSE2 etkin değilken sseregparm öznitelikli %qT çağrısı"
 
-#: config/i386/i386.c:7126
+#: config/i386/i386.c:7129
 #, fuzzy, gcc-internal-format
 #| msgid "does not support multilib"
 msgid "X32 does not support ms_abi attribute"
 msgstr "multilib desteklenmiyor"
 
-#: config/i386/i386.c:7160
+#: config/i386/i386.c:7163
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr "-march=%s seçilen ABI ile uyumsuz"
 
-#: config/i386/i386.c:7502
+#: config/i386/i386.c:7505
 #, fuzzy, gcc-internal-format
 #| msgid "MMX vector argument without MMX enabled changes the ABI"
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr "MMX etkin değilken MMX vektör argümanı ABI'yi değiştirir"
 
-#: config/i386/i386.c:7508
+#: config/i386/i386.c:7511
 #, fuzzy, gcc-internal-format
 #| msgid "MMX vector return without MMX enabled changes the ABI"
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr "MMX etkin değilken MMX vektör dönüşü ABI'yi değiştirir"
 
-#: config/i386/i386.c:7522
+#: config/i386/i386.c:7525
 #, fuzzy, gcc-internal-format
 #| msgid "MMX vector argument without MMX enabled changes the ABI"
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr "MMX etkin değilken MMX vektör argümanı ABI'yi değiştirir"
 
-#: config/i386/i386.c:7528
+#: config/i386/i386.c:7531
 #, fuzzy, gcc-internal-format
 #| msgid "MMX vector return without MMX enabled changes the ABI"
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr "MMX etkin değilken MMX vektör dönüşü ABI'yi değiştirir"
 
-#: config/i386/i386.c:7544
+#: config/i386/i386.c:7547
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr "SSE etkin değilken SSE vektör argümanı ABI'yi değiştirir"
 
-#: config/i386/i386.c:7550
+#: config/i386/i386.c:7553
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr "SSE etkin değilken SSE vektör dönüşü ABI'yi değiştirir"
 
-#: config/i386/i386.c:7566
+#: config/i386/i386.c:7569
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr "MMX etkin değilken MMX vektör argümanı ABI'yi değiştirir"
 
-#: config/i386/i386.c:7572
+#: config/i386/i386.c:7575
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr "MMX etkin değilken MMX vektör dönüşü ABI'yi değiştirir"
 
-#: config/i386/i386.c:7754
+#: config/i386/i386.c:7757
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:7871
+#: config/i386/i386.c:7874
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:7989
+#: config/i386/i386.c:7992
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:8152
+#: config/i386/i386.c:8155
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr "SSE etkin değilken SSE yazmaç dönüşü"
 
-#: config/i386/i386.c:8158
+#: config/i386/i386.c:8161
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr "SSE etkin değilken SSE yazmaç argümanı"
 
-#: config/i386/i386.c:8174
+#: config/i386/i386.c:8177
 #, fuzzy, gcc-internal-format
 #| msgid "SSE register return with SSE disabled"
 msgid "x87 register return with x87 disabled"
 msgstr "SSE etkin değilken SSE yazmaç dönüşü"
 
-#: config/i386/i386.c:8471 config/i386/i386.c:8750 config/i386/i386.c:9276
+#: config/i386/i386.c:8474 config/i386/i386.c:8753 config/i386/i386.c:9279
 #, fuzzy, gcc-internal-format
 #| msgid "Calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr "SSE/SSE2 etkin değilken sseregparm öznitelikli %qD çağrısı"
 
-#: config/i386/i386.c:8473 config/i386/i386.c:8752 config/i386/i386.c:9278
+#: config/i386/i386.c:8476 config/i386/i386.c:8755 config/i386/i386.c:9281
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr ""
 
-#: config/i386/i386.c:9178
+#: config/i386/i386.c:9181
 #, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr ""
 
-#: config/i386/i386.c:11601
+#: config/i386/i386.c:11604
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "assert: %s is assign compatible with %s"
 msgid "-mcall-ms2sysv-xlogues is not compatible with %s"
 msgstr "assert: %s %s ile uyumlu atanıyor"
 
-#: config/i386/i386.c:13593
+#: config/i386/i386.c:13596
 #, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr ""
 
-#: config/i386/i386.c:13683
+#: config/i386/i386.c:13686
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr ""
 
-#: config/i386/i386.c:14970
+#: config/i386/i386.c:14973
 #, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr ""
 
-#: config/i386/i386.c:14990
+#: config/i386/i386.c:14993
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
 msgstr ""
@@ -34552,266 +34595,266 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:15001
+#: config/i386/i386.c:15004
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr "ISO C90 esnek dizi üyelerini desteklemez"
 
-#: config/i386/i386.c:17939
+#: config/i386/i386.c:17942
 #, gcc-internal-format
 msgid "'V' modifier on non-integer register"
 msgstr ""
 
-#: config/i386/i386.c:17950 config/i386/i386.c:17964
+#: config/i386/i386.c:17953 config/i386/i386.c:17967
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported operand size for extended register"
 msgid "unsupported size for integer register"
 msgstr "ek yazmaç için desteklenmeyen terim boyutu"
 
-#: config/i386/i386.c:17996
+#: config/i386/i386.c:17999
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr "ek yazmaçların yüksek yarıları yok"
 
-#: config/i386/i386.c:18011
+#: config/i386/i386.c:18014
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr "ek yazmaç için desteklenmeyen terim boyutu"
 
-#: config/i386/i386.c:18202
+#: config/i386/i386.c:18205
 #, gcc-internal-format
 msgid "non-integer operand used with operand code 'z'"
 msgstr ""
 
-#: config/i386/i386.c:28467
+#: config/i386/i386.c:28470
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine can't be called directly"
 msgstr "sistem kesmesi Servis İşlemleri Thumb kipinde kodlanamaz"
 
-#: config/i386/i386.c:29995
+#: config/i386/i386.c:29998
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in -fabi-version=12 (GCC 8)"
 msgstr ""
 
-#: config/i386/i386.c:32435
+#: config/i386/i386.c:32438
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr ""
 
-#: config/i386/i386.c:32485
+#: config/i386/i386.c:32488
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for %s"
 msgstr ""
 
-#: config/i386/i386.c:32495
+#: config/i386/i386.c:32498
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr ""
 
-#: config/i386/i386.c:32657
+#: config/i386/i386.c:32660
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386.c:32662 config/i386/i386.c:32938
-#: config/rs6000/rs6000.c:37850
+#: config/i386/i386.c:32665 config/i386/i386.c:32941
+#: config/rs6000/rs6000.c:37906
 #, fuzzy, gcc-internal-format
 #| msgid "stack limit expression is not supported"
 msgid "Virtual function multiversioning not supported"
 msgstr "yığıt sınırlama ifadesi desteklenmiyor"
 
-#: config/i386/i386.c:32795 config/rs6000/rs6000.c:37607
+#: config/i386/i386.c:32798 config/rs6000/rs6000.c:37663
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "__builtin_eh_return bu hedefte desteklenmiyor"
 
-#: config/i386/i386.c:33207
+#: config/i386/i386.c:33210
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs must be a 2-bit unsigned literal"
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr "%qs argümanı 2 bitlik işaretsiz bir sabit olmalı"
 
-#: config/i386/i386.c:33232 config/i386/i386.c:33282
+#: config/i386/i386.c:33235 config/i386/i386.c:33285
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument to -ffpe-trap is not valid: %s"
 msgid "Parameter to builtin not valid: %s"
 msgstr "-ffpe-trap seçeneğinin argümanı geçersiz: %s"
 
-#: config/i386/i386.c:33975 config/i386/i386.c:35415
+#: config/i386/i386.c:33978 config/i386/i386.c:35418
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 2-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386.c:34370
+#: config/i386/i386.c:34373
 #, fuzzy, gcc-internal-format
 #| msgid "shift must be an immediate"
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "shift bir anlık değer olmalı"
 
-#: config/i386/i386.c:34465
+#: config/i386/i386.c:34468
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the third argument must be an 8-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386.c:35346
+#: config/i386/i386.c:35349
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be an 1-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386.c:35361
+#: config/i386/i386.c:35364
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 3-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386.c:35394
+#: config/i386/i386.c:35397
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "the last argument must be a 4-bit immediate"
 msgstr "3. argüman 4 bitlik bir işaretsiz sabit olmalı"
 
-#: config/i386/i386.c:35434
+#: config/i386/i386.c:35437
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 1-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386.c:35447
+#: config/i386/i386.c:35450
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 5-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386.c:35457
+#: config/i386/i386.c:35460
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386.c:35462 config/i386/i386.c:36249
+#: config/i386/i386.c:35465 config/i386/i386.c:36252
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be an 8-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386.c:35596
+#: config/i386/i386.c:35599
 #, fuzzy, gcc-internal-format
 #| msgid "third argument to %<__builtin_prefetch%> must be a constant"
 msgid "the third argument must be comparison constant"
 msgstr "%<__builtin_prefetch%> için 3. argüman bir sabit olmalı"
 
-#: config/i386/i386.c:35601
+#: config/i386/i386.c:35604
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect comparison mode"
 msgstr "yanlış komut:"
 
-#: config/i386/i386.c:35607 config/i386/i386.c:35814
+#: config/i386/i386.c:35610 config/i386/i386.c:35817
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect sharing of tree nodes"
 msgid "incorrect rounding operand"
 msgstr "Ağaç düğümlerinin paylaşımı yanlış"
 
-#: config/i386/i386.c:35796
+#: config/i386/i386.c:35799
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "3. argüman 4 bitlik bir işaretsiz sabit olmalı"
 
-#: config/i386/i386.c:35802
+#: config/i386/i386.c:35805
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386.c:35805
+#: config/i386/i386.c:35808
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386.c:36247
+#: config/i386/i386.c:36250
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 32-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386.c:36329 config/powerpcspe/powerpcspe.c:16219
-#: config/rs6000/rs6000.c:15304
+#: config/i386/i386.c:36332 config/powerpcspe/powerpcspe.c:16219
+#: config/rs6000/rs6000.c:15348
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr "seçici 0..%wi aralığında bir tamsayı sabit olmalı"
 
-#: config/i386/i386.c:36539
+#: config/i386/i386.c:36542
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr ""
 
-#: config/i386/i386.c:36543
+#: config/i386/i386.c:36546
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr ""
 
-#: config/i386/i386.c:37381
+#: config/i386/i386.c:37375
 #, fuzzy, gcc-internal-format
 #| msgid "mask must be an immediate"
 msgid "last argument must be an immediate"
 msgstr "mask bir anlık değer olmalı"
 
-#: config/i386/i386.c:38108 config/i386/i386.c:38290
+#: config/i386/i386.c:38102 config/i386/i386.c:38284
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386.c:38343
+#: config/i386/i386.c:38337
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386.c:38349
+#: config/i386/i386.c:38343
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect hint operand"
 msgstr "yanlış komut:"
 
-#: config/i386/i386.c:38368
+#: config/i386/i386.c:38362
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386.c:41431
+#: config/i386/i386.c:41425
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to variables"
 msgid "%qE attribute only available for 32-bit"
 msgstr "%qs özniteliği sadece değişkenlere uygulanır"
 
-#: config/i386/i386.c:41452
+#: config/i386/i386.c:41446
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "%qs özniteliğinin argümanı bir dizge sabiti değil"
 
-#: config/i386/i386.c:41485 config/i386/i386.c:41494
+#: config/i386/i386.c:41479 config/i386/i386.c:41488
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr "fastcall ve stdcall öznitelikleri uyumsuz"
 
-#: config/i386/i386.c:41530 config/powerpcspe/powerpcspe.c:35868
-#: config/rs6000/rs6000.c:33065
+#: config/i386/i386.c:41524 config/powerpcspe/powerpcspe.c:35868
+#: config/rs6000/rs6000.c:33121
 #, fuzzy, gcc-internal-format
 #| msgid "%qs incompatible attribute ignored"
 msgid "%qE incompatible attribute ignored"
 msgstr "%qs uyumsuz özniteliği yoksayıldı"
 
-#: config/i386/i386.c:41555 config/i386/i386.c:41577 config/ia64/ia64.c:815
+#: config/i386/i386.c:41549 config/i386/i386.c:41571 config/ia64/ia64.c:815
 #: config/s390/s390.c:1153
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
@@ -34818,86 +34861,86 @@
 msgid "%qE attribute requires a string constant argument"
 msgstr "%qs özniteliği bir tamsayı sabit argüman gerektirir"
 
-#: config/i386/i386.c:41565 config/i386/i386.c:41587 config/s390/s390.c:1182
+#: config/i386/i386.c:41559 config/i386/i386.c:41581 config/s390/s390.c:1182
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "%qs özniteliğinin argümanı bir dizge sabiti değil"
 
-#: config/i386/i386.c:41619
+#: config/i386/i386.c:41613
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386.c:41626
+#: config/i386/i386.c:41620
 #, gcc-internal-format, gfc-internal-format
 msgid "interrupt service routine should have unsigned %sint as the second argument"
 msgstr ""
 
-#: config/i386/i386.c:41636
+#: config/i386/i386.c:41630
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386.c:41639
+#: config/i386/i386.c:41633
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine can't have non-void return value"
 msgstr "sistem kesmesi Servis İşlemleri Thumb kipinde kodlanamaz"
 
-#: config/i386/i386.c:44676
+#: config/i386/i386.c:44670
 #, fuzzy, gcc-internal-format
 #| msgid "standard conversions are not allowed in this context"
 msgid "alternatives not allowed in asm flag output"
 msgstr "standart uzlaşımlara bu bağlam içinde izin verilmez"
 
-#: config/i386/i386.c:44740
+#: config/i386/i386.c:44734
 #, fuzzy, gcc-internal-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown asm flag output %qs"
 msgstr "%qs makine kipi bilinmiyor"
 
-#: config/i386/i386.c:44769
+#: config/i386/i386.c:44763
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "invalid type for asm flag output"
 msgstr "tür argümanı geçersiz"
 
-#: config/i386/i386.c:50634
+#: config/i386/i386.c:50628
 #, fuzzy, gcc-internal-format
 #| msgid "no class name specified with %qs"
 msgid "unknown architecture specific memory model"
 msgstr "%qs ile belirtilmiş sınıf ismi yok"
 
-#: config/i386/i386.c:50641
+#: config/i386/i386.c:50635
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50647
+#: config/i386/i386.c:50641
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50671 config/i386/i386.c:50787
+#: config/i386/i386.c:50665 config/i386/i386.c:50781
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "unsupported simdlen %d"
 msgstr "desteklenmeyen birleşim: %s"
 
-#: config/i386/i386.c:50690
+#: config/i386/i386.c:50684
 #, fuzzy, gcc-internal-format
 #| msgid "unused arguments in $-style format"
 msgid "unsupported return type %qT for simd"
 msgstr "$ tarzı biçimde kullanılmamış argümanlar"
 
-#: config/i386/i386.c:50712
+#: config/i386/i386.c:50706
 #, fuzzy, gcc-internal-format
 #| msgid "unused arguments in $-style format"
 msgid "unsupported argument type %qT for simd"
 msgstr "$ tarzı biçimde kullanılmamış argümanlar"
 
-#: config/i386/i386.c:51033
+#: config/i386/i386.c:51027
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr ""
@@ -35144,7 +35187,7 @@
 msgstr ""
 
 #: config/m68k/m68k.c:1128 config/powerpcspe/powerpcspe.c:28512
-#: config/rs6000/rs6000.c:25791
+#: config/rs6000/rs6000.c:25868
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "yığıt sınırlama ifadesi desteklenmiyor"
@@ -35769,10 +35812,10 @@
 
 #. Trampoline is not supported on reduced-set registers yet.
 #: config/nds32/nds32.c:2327 config/nds32/nds32.c:2381
-#: config/nds32/nds32.c:3127 config/nds32/nds32.c:3201
-#: config/nds32/nds32.c:3216 config/nds32/nds32.c:3222
-#: config/nds32/nds32.c:3284 config/nds32/nds32.c:3290
-#: config/nds32/nds32.c:3322
+#: config/nds32/nds32.c:3128 config/nds32/nds32.c:3202
+#: config/nds32/nds32.c:3217 config/nds32/nds32.c:3223
+#: config/nds32/nds32.c:3285 config/nds32/nds32.c:3291
+#: config/nds32/nds32.c:3323
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "a nested function is not supported for reduced registers"
@@ -35779,55 +35822,55 @@
 msgstr "bu hedefte -fdata-sections desteklenmiyor"
 
 #. The enum index value for array size is out of range.
-#: config/nds32/nds32.c:3025
+#: config/nds32/nds32.c:3026
 #, fuzzy, gcc-internal-format
 #| msgid "invalid register in the instruction"
 msgid "intrinsic register index is out of range"
 msgstr "komuttaki yazmaç geçersiz"
 
-#: config/nds32/nds32.c:3041 config/nds32/nds32.c:3048
-#: config/nds32/nds32.c:3055 config/nds32/nds32.c:3062
-#: config/nds32/nds32.c:3069
+#: config/nds32/nds32.c:3042 config/nds32/nds32.c:3049
+#: config/nds32/nds32.c:3056 config/nds32/nds32.c:3063
+#: config/nds32/nds32.c:3070
 #, fuzzy, gcc-internal-format
 #| msgid "invalid register in the instruction"
 msgid "CCTL intrinsic function subtype out of range!"
 msgstr "komuttaki yazmaç geçersiz"
 
-#: config/nds32/nds32.c:3508
+#: config/nds32/nds32.c:3509
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute %qE"
 msgid "invalid id value for interrupt/exception attribute"
 msgstr "%qE özniteliği için vektör türü geçersiz"
 
-#: config/nds32/nds32.c:3536
+#: config/nds32/nds32.c:3537
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "invalid id value for reset attribute"
 msgstr "%qs özniteliğinin argümanı geçersiz"
 
-#: config/nds32/nds32.c:3552
+#: config/nds32/nds32.c:3553
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "invalid nmi function for reset attribute"
 msgstr "%qs özniteliğinin argümanı geçersiz"
 
-#: config/nds32/nds32.c:3565
+#: config/nds32/nds32.c:3566
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "invalid warm function for reset attribute"
 msgstr "%qs özniteliğinin argümanı geçersiz"
 
-#: config/nds32/nds32.c:3638
+#: config/nds32/nds32.c:3639
 #, gcc-internal-format
 msgid "Disable FPU ISA, the ABI option must be enable '-mfloat-abi=soft'"
 msgstr ""
 
-#: config/nds32/nds32.c:3641
+#: config/nds32/nds32.c:3642
 #, gcc-internal-format
 msgid "'-mabi=2fp+' option only support when FPU available, must be enable '-mext-fpu-sp' or '-mext-fpu-dp'"
 msgstr ""
 
-#: config/nds32/nds32.c:3647
+#: config/nds32/nds32.c:3648
 #, fuzzy, gcc-internal-format
 #| msgid "Generate position-independent code if possible (large mode)"
 msgid "position-independent code not supported"
@@ -36181,12 +36224,12 @@
 msgid "junk at end of #pragma longcall"
 msgstr "'#pragma longcall' sonunda karışıklik"
 
-#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6154
+#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6152
 #, gcc-internal-format
 msgid "vec_lvsl is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6158
+#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6156
 #, gcc-internal-format
 msgid "vec_lvsr is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
@@ -36243,7 +36286,7 @@
 msgid "vec_insert only accepts 3 arguments"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6868
+#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6866
 #, fuzzy, gcc-internal-format
 msgid "passing arg %d of %qE discards qualifiers from pointer target type"
 msgstr "%2$qE işlevinin %1$d. argümanın aktarımı gösterici hedef türündeki niteleyicileri iptal ediyor"
@@ -36333,7 +36376,7 @@
 msgid "target attribute or pragma changes SPE ABI"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4351 config/rs6000/rs6000.c:4223
+#: config/powerpcspe/powerpcspe.c:4351 config/rs6000/rs6000.c:4243
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "AltiVec not supported in this target"
@@ -36498,7 +36541,7 @@
 msgid "-mvsx-small-integer requires -mpower8-vector, -mupper-regs-di, and -mdirect-move"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4959 config/rs6000/rs6000.c:4601
+#: config/powerpcspe/powerpcspe.c:4959 config/rs6000/rs6000.c:4628
 #, gcc-internal-format
 msgid "target attribute or pragma changes long double size"
 msgstr ""
@@ -36540,22 +36583,22 @@
 msgstr ""
 
 #: config/powerpcspe/powerpcspe.c:5140 config/powerpcspe/powerpcspe.c:5155
-#: config/rs6000/rs6000.c:4766 config/rs6000/rs6000.c:4781
+#: config/rs6000/rs6000.c:4791 config/rs6000/rs6000.c:4806
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:5168 config/rs6000/rs6000.c:4794
+#: config/powerpcspe/powerpcspe.c:5168 config/rs6000/rs6000.c:4819
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:5234 config/rs6000/rs6000.c:4828
+#: config/powerpcspe/powerpcspe.c:5234 config/rs6000/rs6000.c:4853
 #, gcc-internal-format
 msgid "target attribute or pragma changes single precision floating point"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:5237 config/rs6000/rs6000.c:4831
+#: config/powerpcspe/powerpcspe.c:5237 config/rs6000/rs6000.c:4856
 #, gcc-internal-format
 msgid "target attribute or pragma changes double precision floating point"
 msgstr ""
@@ -36565,12 +36608,12 @@
 msgid "-mstack-protector-guard=tls needs a valid base register"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:8415 config/rs6000/rs6000.c:7925
+#: config/powerpcspe/powerpcspe.c:8415 config/rs6000/rs6000.c:7950
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11237
+#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11269
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC vektörü başvurusu tarafından döndürüldü: bir uyumluluk garanti etmeksizin standartdışı ABI eklentisi"
@@ -36580,7 +36623,7 @@
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "AltiVec komutları iptal edildiğinden vektör yazmaçındaki değer döndürülemez, komutları etkinleştirmek için -maltivec kullanın"
 
-#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11595
+#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11633
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr ""
@@ -36590,12 +36633,12 @@
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "AltiVec komutları iptal edildiğinden vektör yazmacındaki argüman aktarılamaz, komutları etkinleştirmek için -maltivec kullanın"
 
-#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12604
+#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12648
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12779
+#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12823
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC vektörü başvurusu tarafından aktarıldı: bir uyumluluk garanti etmeksizin standartdışı ABI eklentisi"
@@ -36606,30 +36649,30 @@
 msgid "internal error: builtin function %s already processed"
 msgstr "Girdi dosyaları evvelce önişlemden geçirilmiş kabul edilir"
 
-#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:13971
+#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:14015
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "argument 1 must be an 8-bit field value"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14015
+#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14059
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
 #: config/powerpcspe/powerpcspe.c:14934 config/powerpcspe/powerpcspe.c:16803
-#: config/rs6000/rs6000.c:14101
+#: config/rs6000/rs6000.c:14145
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "2. argüman 5 bitlik bir işaretsiz sabit olmalı"
 
-#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14119
+#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14163
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "2. argüman 5 bitlik bir işaretsiz sabit olmalı"
 
-#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14135
+#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14179
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 7-bit unsigned literal"
@@ -36650,13 +36693,13 @@
 msgid "builtin %s is only valid in 64-bit mode"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14791
+#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14835
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument %d must be an unsigned literal"
 msgstr "2. argüman 5 bitlik bir işaretsiz sabit olmalı"
 
-#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14793
+#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14837
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument %d is an unsigned literal that is out of range"
@@ -36682,60 +36725,60 @@
 msgid "hwcap %s is an invalid argument to builtin %s"
 msgstr "yerleşik işleve aktarılan argüman geçersiz"
 
-#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15065
+#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15109
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "3. argüman 4 bitlik bir işaretsiz sabit olmalı"
 
-#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15090
+#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15134
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "3. argüman 4 bitlik bir işaretsiz sabit olmalı"
 
-#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15110
+#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15154
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "3. argüman 4 bitlik bir işaretsiz sabit olmalı"
 
-#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15122
+#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15166
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "argument 1 must be 0 or 2"
 msgstr "sayı 0 ya da 1 olmalı"
 
-#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15134
+#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15178
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "2. argüman 5 bitlik bir işaretsiz sabit olmalı"
 
-#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15148
+#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15192
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "2. argüman 5 bitlik bir işaretsiz sabit olmalı"
 
-#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15160
+#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15204
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "argument 2 must be 0 or 1"
 msgstr "sayı 0 ya da 1 olmalı"
 
-#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15168
+#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15212
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ATANH at %L must be inside the range -1 to 1"
 msgid "argument 3 must be in the range 0..15"
 msgstr "%L'deki ATANH argümanı -1 .. 1 aralığının içinde kalmalı"
 
-#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15237
-#: config/rs6000/rs6000.c:15569
+#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15281
+#: config/rs6000/rs6000.c:15613
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "%qs argümanı 2 bitlik işaretsiz bir sabit olmalı"
 
-#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15394
+#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15438
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr "Altivec yerleşiği %qF için çözümlenmemiş aşırı yükleme"
@@ -36874,7 +36917,7 @@
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25758
+#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25835
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr "yığıt çerçevesi çok büyük"
@@ -36885,13 +36928,13 @@
 msgid "-fsplit-stack uses register r29"
 msgstr "ISO C90 esnek dizi üyelerini desteklemez"
 
-#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29459
+#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29536
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma extern_prefix not supported on this target"
 msgid "Stack frame larger than 2G is not supported for -fsplit-stack"
 msgstr "#pragma extern_prefix bu hedefte desteklenmiyor"
 
-#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30447
+#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30524
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "bu ABI için 64 bitlik profilleme kodu yok"
@@ -36901,22 +36944,22 @@
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32830
+#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32907
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "AltiVec türlerde %<long double%> kullanımı geçersiz"
 
-#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32832
+#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32909
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "AltiVec türlerde mantıksal türlerin kullanımı geçersiz"
 
-#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32834
+#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32911
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "AltiVec türlerde %<complex%> kullanımı geçersiz"
 
-#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32836
+#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32913
 #, fuzzy, gcc-internal-format
 #| msgid "use of boolean types in AltiVec types is invalid"
 msgid "use of decimal floating point types in AltiVec types is invalid"
@@ -36928,7 +36971,7 @@
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr "AltiVec türlerde %<long%> kullanımı 64 bitlik kod için geçersiz"
 
-#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32845
+#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32922
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "AltiVec türlerde %<long%> kullanımı önerilmiyor; %<int%> kullanın"
@@ -37491,81 +37534,81 @@
 "Please use an explicit cpu name.  Valid cpu names are: %s"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6168 config/rs6000/rs6000-c.c:6219
-#: config/rs6000/rs6000-c.c:6489 config/rs6000/rs6000-c.c:6555
-#: config/rs6000/rs6000-c.c:6916 config/rs6000/rs6000-c.c:6963
+#: config/rs6000/rs6000-c.c:6166 config/rs6000/rs6000-c.c:6217
+#: config/rs6000/rs6000-c.c:6487 config/rs6000/rs6000-c.c:6553
+#: config/rs6000/rs6000-c.c:6914 config/rs6000/rs6000-c.c:6961
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D takes only zero or two arguments"
 msgid "builtin %qs only accepts 2 arguments"
 msgstr "%q+D ya iki argüman alır ya da hiç almaz"
 
-#: config/rs6000/rs6000-c.c:6292 config/rs6000/rs6000-c.c:6375
-#: config/rs6000/rs6000-c.c:6736
+#: config/rs6000/rs6000-c.c:6290 config/rs6000/rs6000-c.c:6373
+#: config/rs6000/rs6000-c.c:6734
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D takes only zero or two arguments"
 msgid "builtin %qs only accepts 3 arguments"
 msgstr "%q+D ya iki argüman alır ya da hiç almaz"
 
-#: config/rs6000/rs6000-c.c:6484
+#: config/rs6000/rs6000-c.c:6482
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D takes only zero or two arguments"
 msgid "builtin %qs only accepts 1 argument"
 msgstr "%q+D ya iki argüman alır ya da hiç almaz"
 
-#: config/rs6000/rs6000-c.c:7054
+#: config/rs6000/rs6000-c.c:7052
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' requires an argument list at %C"
 msgid "builtin %qs requires builtin %qs"
 msgstr "'%s' işlevi %C'de bir argüman listesi gerektiriyor"
 
-#: config/rs6000/rs6000-c.c:7058
+#: config/rs6000/rs6000-c.c:7056
 #, fuzzy, gcc-internal-format
 #| msgid "-m%s not supported in this configuration"
 msgid "builtin function %qs not supported in this compiler configuration"
 msgstr "-m%s bu yapılandırmada desteklenmiyor"
 
-#: config/rs6000/rs6000-c.c:7068
+#: config/rs6000/rs6000-c.c:7066
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter combination for AltiVec intrinsic"
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr "AltiVec yerleşiği için parametre birleşimi geçersiz"
 
-#: config/rs6000/rs6000.c:3754 config/rs6000/rs6000.c:3757
-#: config/rs6000/rs6000.c:3760
+#: config/rs6000/rs6000.c:3772 config/rs6000/rs6000.c:3775
+#: config/rs6000/rs6000.c:3778
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type %qT"
 msgid "%qs requires %qs or %qs"
 msgstr "%s %qT referans türünde şekilleniyor"
 
-#: config/rs6000/rs6000.c:3861
+#: config/rs6000/rs6000.c:3879
 #, fuzzy, gcc-internal-format
 #| msgid "-m64 requires PowerPC64 architecture, enabling"
 msgid "%qs requires PowerPC64 architecture, enabling"
 msgstr "-m64 seçeneği PowerPC64 mimarisini gerektirir, etkinleştiriliyor"
 
-#: config/rs6000/rs6000.c:4037
+#: config/rs6000/rs6000.c:4057
 #, gcc-internal-format
 msgid "%qs command-line option is deprecated"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4048
+#: config/rs6000/rs6000.c:4068
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-power is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgid "%qs is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr "-malign-power 64 bitlik Darwin için desteklenmiyor; kurulu C ve C++ kütüphaneleri ile uyumsuz"
 
-#: config/rs6000/rs6000.c:4147
+#: config/rs6000/rs6000.c:4167
 #, gcc-internal-format
 msgid "will not generate %qs instructions because assembler lacks %qs support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4240
+#: config/rs6000/rs6000.c:4260
 #, fuzzy, gcc-internal-format
 #| msgid "-mstring is not supported on little endian systems"
 msgid "%qs is not supported on little endian systems"
 msgstr "-mstring kıymetsiz baytın başta olduğu sistemlerde desteklenmez"
 
-#: config/rs6000/rs6000.c:4333
+#: config/rs6000/rs6000.c:4353
 #, gcc-internal-format
 msgid "power9 target option is incompatible with %<%s=<xxx>%> for <xxx> less than power9"
 msgstr ""
@@ -37572,7 +37615,7 @@
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:4341
+#: config/rs6000/rs6000.c:4361
 #, fuzzy, gcc-internal-format
 #| msgid "Emit code compatible with TI tools"
 msgid "%qs incompatible with explicitly disabled options"
@@ -37582,129 +37625,129 @@
 #. error messages.  However, if users have managed to select
 #. power9-fusion without selecting power8-fusion, they
 #. already know about undocumented flags.
-#: config/rs6000/rs6000.c:4366 config/rs6000/rs6000.c:4373
-#: config/rs6000/rs6000.c:4380 config/rs6000/rs6000.c:4388
-#: config/rs6000/rs6000.c:4407 config/rs6000/rs6000.c:4464
-#: config/rs6000/rs6000.c:4468 config/rs6000/rs6000.c:4485
-#: config/rs6000/rs6000.c:4538 config/rs6000/rs6000.c:4565
-#: config/rs6000/rs6000.c:4580 config/rs6000/rs6000.c:4588
-#: config/rs6000/rs6000.c:4684
+#: config/rs6000/rs6000.c:4386 config/rs6000/rs6000.c:4393
+#: config/rs6000/rs6000.c:4400 config/rs6000/rs6000.c:4408
+#: config/rs6000/rs6000.c:4427 config/rs6000/rs6000.c:4484
+#: config/rs6000/rs6000.c:4488 config/rs6000/rs6000.c:4505
+#: config/rs6000/rs6000.c:4558 config/rs6000/rs6000.c:4585
+#: config/rs6000/rs6000.c:4600 config/rs6000/rs6000.c:4608
+#: config/rs6000/rs6000.c:4709
 #, fuzzy, gcc-internal-format
 #| msgid "%qT referred to as %qs"
 msgid "%qs requires %qs"
 msgstr "%qT türüne %qs olarak başvuruluyor"
 
-#: config/rs6000/rs6000.c:4625
+#: config/rs6000/rs6000.c:4650
 #, fuzzy, gcc-internal-format
 #| msgid "Using IEEE extended precision long double"
 msgid "Using IEEE extended precision long double"
 msgstr "IEEE ek duyarlıklı long double kullanılıyor"
 
-#: config/rs6000/rs6000.c:4627
+#: config/rs6000/rs6000.c:4652
 #, fuzzy, gcc-internal-format
 #| msgid "Using IBM extended precision long double"
 msgid "Using IBM extended precision long double"
 msgstr "IBM ek duyarlıklı long double kullanılıyor"
 
-#: config/rs6000/rs6000.c:4644
+#: config/rs6000/rs6000.c:4669
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "%qs requires VSX support"
 msgstr "%s %s desteği vermiyor"
 
-#: config/rs6000/rs6000.c:4653
+#: config/rs6000/rs6000.c:4678
 #, gcc-internal-format
 msgid "The -mfloat128 option may not be fully supported"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4676
+#: config/rs6000/rs6000.c:4701
 #, gcc-internal-format
 msgid "%qs requires full ISA 3.0 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4743
+#: config/rs6000/rs6000.c:4768
 #, gcc-internal-format
 msgid "unknown vectorization library ABI type (%qs) for %qs switch"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4930
+#: config/rs6000/rs6000.c:4955
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid output file"
 msgid "%qs is not a valid number in %qs"
 msgstr "%qs geçerli bir çıktı dosyası değil"
 
-#: config/rs6000/rs6000.c:4935
+#: config/rs6000/rs6000.c:4960
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid output file"
 msgid "%qs is not a valid offset in %qs"
 msgstr "%qs geçerli bir çıktı dosyası değil"
 
-#: config/rs6000/rs6000.c:4947
+#: config/rs6000/rs6000.c:4972
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid class name"
 msgid "%qs is not a valid base register in %qs"
 msgstr "%qs geçerli bir sınıf ismi değil"
 
-#: config/rs6000/rs6000.c:4955
+#: config/rs6000/rs6000.c:4980
 #, fuzzy, gcc-internal-format
 #| msgid "Need a call-clobbered target register"
 msgid "%qs needs a valid base register"
 msgstr "Çağrı taşırmalı hedef yazmacı gerekir"
 
-#: config/rs6000/rs6000.c:5253
+#: config/rs6000/rs6000.c:5278
 #, fuzzy, gcc-internal-format
 #| msgid "unknown -m%s= option specified: '%s'"
 msgid "unknown option for %<%s=%s%>"
 msgstr "bilinmeyen -m%s= seçeneği belirtilmiş: '%s'"
 
-#: config/rs6000/rs6000.c:5290
+#: config/rs6000/rs6000.c:5315
 #, fuzzy, gcc-internal-format
 #| msgid "Deprecated.  This switch has no effect"
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr "Önerilmiyor. Bu seçenek etkisizdir."
 
-#: config/rs6000/rs6000.c:11401
+#: config/rs6000/rs6000.c:11439
 #, fuzzy, gcc-internal-format
 #| msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgid "cannot return value in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr "AltiVec komutları iptal edildiğinden vektör yazmaçındaki değer döndürülemez, komutları etkinleştirmek için -maltivec kullanın"
 
-#: config/rs6000/rs6000.c:11862
+#: config/rs6000/rs6000.c:11906
 #, fuzzy, gcc-internal-format
 #| msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr "AltiVec komutları iptal edildiğinden vektör yazmacındaki argüman aktarılamaz, komutları etkinleştirmek için -maltivec kullanın"
 
-#: config/rs6000/rs6000.c:13572
+#: config/rs6000/rs6000.c:13616
 #, fuzzy, gcc-internal-format
 #| msgid "Treat the input file as already preprocessed"
 msgid "internal error: builtin function %qs already processed"
 msgstr "Girdi dosyaları evvelce önişlemden geçirilmiş kabul edilir"
 
-#: config/rs6000/rs6000.c:14150
+#: config/rs6000/rs6000.c:14194
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 1-bit unsigned literal"
 msgstr "2. argüman 5 bitlik bir işaretsiz sabit olmalı"
 
-#: config/rs6000/rs6000.c:14189
+#: config/rs6000/rs6000.c:14233
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qs must be a constant"
 msgstr "%2$qE işlevinin %1$d. argümanına uyumsuz gösterici türünde aktarım"
 
-#: config/rs6000/rs6000.c:14247 config/rs6000/rs6000.c:15898
+#: config/rs6000/rs6000.c:14291 config/rs6000/rs6000.c:15942
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument 1 of %qs is out of range"
 msgstr "__builtin_spe_predicate'in 1. argümanı aralık dışında"
 
-#: config/rs6000/rs6000.c:14742
+#: config/rs6000/rs6000.c:14786
 #, fuzzy, gcc-internal-format
 #| msgid "this builtin function is only available on the fr450"
 msgid "builtin %qs is only valid in 64-bit mode"
 msgstr "bu yerleşik işlev sadece fr450 üzerinde kullanılabilir"
 
-#: config/rs6000/rs6000.c:14939
+#: config/rs6000/rs6000.c:14983
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D takes only zero or two arguments"
 msgid "builtin %qs only accepts a string argument"
@@ -37711,7 +37754,7 @@
 msgstr "%q+D ya iki argüman alır ya da hiç almaz"
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000.c:14958
+#: config/rs6000/rs6000.c:15002
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to builtin function"
 msgid "cpu %qs is an invalid argument to builtin %qs"
@@ -37718,141 +37761,142 @@
 msgstr "yerleşik işleve aktarılan argüman geçersiz"
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000.c:14986
+#: config/rs6000/rs6000.c:15030
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to builtin function"
 msgid "%s %qs is an invalid argument to builtin %qs"
 msgstr "yerleşik işleve aktarılan argüman geçersiz"
 
-#: config/rs6000/rs6000.c:15012
+#: config/rs6000/rs6000.c:15056
 #, gcc-internal-format
 msgid "builtin %qs needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15616
+#: config/rs6000/rs6000.c:15660
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "second argument to %qs must be 0..12"
 msgstr "sayı 0 ya da 1 olmalı"
 
-#: config/rs6000/rs6000.c:15631
+#: config/rs6000/rs6000.c:15675
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "third argument to %qs must be 0..12"
 msgstr "sayı 0 ya da 1 olmalı"
 
-#: config/rs6000/rs6000.c:15850
+#: config/rs6000/rs6000.c:15894
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument 1 of %s must be a constant"
 msgstr "%2$qE işlevinin %1$d. argümanına uyumsuz gösterici türünde aktarım"
 
-#: config/rs6000/rs6000.c:15932
+#: config/rs6000/rs6000.c:15976
 #, fuzzy, gcc-internal-format
 #| msgid "this builtin function is only available on the fr450"
 msgid "builtin function %qs is only valid for the cell processor"
 msgstr "bu yerleşik işlev sadece fr450 üzerinde kullanılabilir"
 
-#: config/rs6000/rs6000.c:15934 config/rs6000/rs6000.c:15936
-#: config/rs6000/rs6000.c:15938 config/rs6000/rs6000.c:15940
-#: config/rs6000/rs6000.c:15946 config/rs6000/rs6000.c:15948
-#: config/rs6000/rs6000.c:15955 config/rs6000/rs6000.c:15962
-#: config/rs6000/rs6000.c:15969 config/rs6000/rs6000.c:15975
+#: config/rs6000/rs6000.c:15978 config/rs6000/rs6000.c:15980
+#: config/rs6000/rs6000.c:15982 config/rs6000/rs6000.c:15984
+#: config/rs6000/rs6000.c:15990 config/rs6000/rs6000.c:15992
+#: config/rs6000/rs6000.c:15999 config/rs6000/rs6000.c:16006
+#: config/rs6000/rs6000.c:16011 config/rs6000/rs6000.c:16014
+#: config/rs6000/rs6000.c:16018 config/rs6000/rs6000.c:16024
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "builtin function %qs requires the %qs option"
 msgstr "yerleşik işlev `%q+D işlev olarak bildirilmemiş"
 
-#: config/rs6000/rs6000.c:15943 config/rs6000/rs6000.c:15952
-#: config/rs6000/rs6000.c:15959 config/rs6000/rs6000.c:15966
+#: config/rs6000/rs6000.c:15987 config/rs6000/rs6000.c:15996
+#: config/rs6000/rs6000.c:16003
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "builtin function %qs requires the %qs and %qs options"
 msgstr "yerleşik işlev `%q+D işlev olarak bildirilmemiş"
 
-#: config/rs6000/rs6000.c:15972
+#: config/rs6000/rs6000.c:16021
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "builtin function %qs requires ISA 3.0 IEEE 128-bit floating point"
 msgstr "yerleşik işlev `%q+D işlev olarak bildirilmemiş"
 
-#: config/rs6000/rs6000.c:15978
+#: config/rs6000/rs6000.c:16027
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "builtin function %qs requires the %qs (or newer), and %qs or %qs options"
 msgstr "yerleşik işlev `%q+D işlev olarak bildirilmemiş"
 
-#: config/rs6000/rs6000.c:15982
+#: config/rs6000/rs6000.c:16031
 #, fuzzy, gcc-internal-format
 #| msgid "command line option %qs is not supported by this configuration"
 msgid "builtin function %qs is not supported with the current options"
 msgstr "komut satırı seçeneği %qs bu yapılandırmada desteklenmiyor"
 
-#: config/rs6000/rs6000.c:18218
+#: config/rs6000/rs6000.c:18290
 #, fuzzy, gcc-internal-format
 #| msgid "internal error: sideeffect-insn affecting main effect"
 msgid "internal error: builtin function %qs had an unexpected return type %qs"
 msgstr "iç hata: yan etkili komut main etkisi oluşturuyor"
 
-#: config/rs6000/rs6000.c:18235
+#: config/rs6000/rs6000.c:18307
 #, fuzzy, gcc-internal-format
 #| msgid "internal error: sideeffect-insn affecting main effect"
 msgid "internal error: builtin function %qs, argument %d had unexpected argument type %qs"
 msgstr "iç hata: yan etkili komut main etkisi oluşturuyor"
 
-#: config/rs6000/rs6000.c:29451
+#: config/rs6000/rs6000.c:29528
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<register%>"
 msgid "%qs uses register r29"
 msgstr "%<__thread%> %<register%> ile kullanılmış"
 
-#: config/rs6000/rs6000.c:32748
+#: config/rs6000/rs6000.c:32825
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "bir sağ taraf ifadesi olan %<this%>'in adresi alınamaz"
 
-#: config/rs6000/rs6000.c:32842
+#: config/rs6000/rs6000.c:32919
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long%> in AltiVec types is invalid for 64-bit code"
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "AltiVec türlerde %<long%> kullanımı 64 bitlik kod için geçersiz"
 
-#: config/rs6000/rs6000.c:32850
+#: config/rs6000/rs6000.c:32927
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long long%> in AltiVec types is invalid"
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "AltiVec türlerde %<long long%> kullanımı geçersiz"
 
-#: config/rs6000/rs6000.c:32853
+#: config/rs6000/rs6000.c:32930
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<double%> in AltiVec types is invalid"
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "AltiVec türlerde %<double%> kullanımı geçersiz"
 
-#: config/rs6000/rs6000.c:36876
+#: config/rs6000/rs6000.c:36932
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<::%>"
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "%<::%> kullanımı geçersiz"
 
-#: config/rs6000/rs6000.c:36879
+#: config/rs6000/rs6000.c:36935
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma%> is not allowed here"
 msgid "%s%qs%s is not allowed"
 msgstr "%<#pragma%> burada kullanılamaz"
 
-#: config/rs6000/rs6000.c:36881
+#: config/rs6000/rs6000.c:36937
 #, fuzzy, gcc-internal-format
 #| msgid "spec '%s' is invalid"
 msgid "%s%qs%s is invalid"
 msgstr "spec '%s' geçersiz"
 
-#: config/rs6000/rs6000.c:37416
+#: config/rs6000/rs6000.c:37472
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:37575
+#: config/rs6000/rs6000.c:37631
 #, gcc-internal-format
 msgid "target_clones attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
@@ -38650,53 +38694,53 @@
 msgid "subprogram %q+F not marked Inline"
 msgstr ""
 
-#: ada/gcc-interface/trans.c:6404
+#: ada/gcc-interface/trans.c:6401
 #, gcc-internal-format
 msgid "out-of-bounds access may be optimized away"
 msgstr ""
 
-#: ada/gcc-interface/trans.c:6406
+#: ada/gcc-interface/trans.c:6403
 #, gcc-internal-format
 msgid "containing loop"
 msgstr ""
 
-#: ada/gcc-interface/utils.c:3887
+#: ada/gcc-interface/utils.c:3890
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute %qE"
 msgid "invalid element type for attribute %qs"
 msgstr "%qE özniteliği için vektör türü geçersiz"
 
-#: ada/gcc-interface/utils.c:3911
+#: ada/gcc-interface/utils.c:3914
 #, fuzzy, gcc-internal-format
 #| msgid "number of components of the vector not a power of two"
 msgid "number of components of vector not a power of two"
 msgstr "vektör elemanlarının sayısı ikinin üstel katlarından biri değil"
 
-#: ada/gcc-interface/utils.c:6037 ada/gcc-interface/utils.c:6215
-#: ada/gcc-interface/utils.c:6322
+#: ada/gcc-interface/utils.c:6043 ada/gcc-interface/utils.c:6220
+#: ada/gcc-interface/utils.c:6327
 #, gcc-internal-format
 msgid "%qs attribute ignored"
 msgstr "%qs özniteliği yoksayıldı"
 
-#: ada/gcc-interface/utils.c:6158
+#: ada/gcc-interface/utils.c:6164
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute requires prototypes with named arguments"
 msgid "%qs attribute requires prototypes with named arguments"
 msgstr "%qE özniteliği isimli argümanları olan prototipler gerektirir"
 
-#: ada/gcc-interface/utils.c:6167
+#: ada/gcc-interface/utils.c:6173
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to variadic functions"
 msgid "%qs attribute only applies to variadic functions"
 msgstr "%qE özniteliği sadece değişkin işlevlere uygulanır"
 
-#: ada/gcc-interface/utils.c:6282
+#: ada/gcc-interface/utils.c:6287
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored"
 msgid "%qE attribute has no effect"
 msgstr "%qE özniteliği yoksayıldı"
 
-#: ada/gcc-interface/utils.c:6406
+#: ada/gcc-interface/utils.c:6411
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to variables"
 msgid "attribute %qs applies to array types only"
@@ -38713,7 +38757,7 @@
 #. an unprototyped function, it is compile-time undefined;
 #. making it a constraint in that case was rejected in
 #. DR#252.
-#: c/c-convert.c:101 c/c-typeck.c:2175 c/c-typeck.c:6507 c/c-typeck.c:12138
+#: c/c-convert.c:101 c/c-typeck.c:2175 c/c-typeck.c:6512 c/c-typeck.c:12143
 #: cp/typeck.c:2027 cp/typeck.c:7977 cp/typeck.c:8742
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
@@ -38776,7 +38820,7 @@
 msgid "type of array %q+D completed incompatibly with implicit initialization"
 msgstr "%q+D dizisinin türü örtük ilklendirme ile uyumsuz olarak tamamlanmış"
 
-#: c/c-decl.c:1567 c/c-decl.c:6701 c/c-decl.c:7574 c/c-decl.c:8381
+#: c/c-decl.c:1567 c/c-decl.c:6721 c/c-decl.c:7594 c/c-decl.c:8401
 #, fuzzy, gcc-internal-format
 #| msgid "%J  original definition appeared here"
 msgid "originally defined here"
@@ -39206,16 +39250,11 @@
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.c:4548 c/c-decl.c:7147
+#: c/c-decl.c:4548 c/c-decl.c:7167
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr ""
 
-#: c/c-decl.c:4635 cp/decl2.c:1520
-#, gcc-internal-format
-msgid "%q+D in declare target directive does not have mappable type"
-msgstr ""
-
 #: c/c-decl.c:4693
 #, gcc-internal-format
 msgid "%q+D is usually a function"
@@ -39241,7 +39280,7 @@
 #. of VLAs themselves count as VLAs, it does not make
 #. sense to permit them to be initialized given that
 #. ordinary VLAs may not be initialized.
-#: c/c-decl.c:4732 c/c-decl.c:4747 c/c-typeck.c:7630
+#: c/c-decl.c:4732 c/c-decl.c:4747 c/c-typeck.c:7635
 #, gcc-internal-format
 msgid "variable-sized object may not be initialized"
 msgstr "değişken uzunluklu nesne ilklendirilemeyebilir"
@@ -39304,224 +39343,229 @@
 msgid "uninitialized const %qD is invalid in C++"
 msgstr "ilklendirilmemiş sabit %qD"
 
-#: c/c-decl.c:5268
+#: c/c-decl.c:5224 cp/decl.c:7318
 #, gcc-internal-format
+msgid "%q+D in declare target directive does not have mappable type"
+msgstr ""
+
+#: c/c-decl.c:5288
+#, gcc-internal-format
 msgid "ISO C forbids forward parameter declarations"
 msgstr "ISO C ileriye dönük parametre bildirimlerine izin vermez"
 
-#: c/c-decl.c:5371
+#: c/c-decl.c:5391
 #, gcc-internal-format
 msgid "defining a type in a compound literal is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:5425 c/c-decl.c:5440
+#: c/c-decl.c:5445 c/c-decl.c:5460
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant"
 msgstr "%qs bit alanı genişliği bir tamsayı sabit değil"
 
-#: c/c-decl.c:5435
+#: c/c-decl.c:5455
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qs width not an integer constant"
 msgid "bit-field %qs width not an integer constant expression"
 msgstr "%qs bit alanı genişliği bir tamsayı sabit değil"
 
-#: c/c-decl.c:5446
+#: c/c-decl.c:5466
 #, gcc-internal-format
 msgid "negative width in bit-field %qs"
 msgstr "%qs bit alanının genişliği negatif"
 
-#: c/c-decl.c:5451
+#: c/c-decl.c:5471
 #, gcc-internal-format
 msgid "zero width for bit-field %qs"
 msgstr "bit alanı %qs için sıfır genişlik"
 
-#: c/c-decl.c:5461
+#: c/c-decl.c:5481
 #, gcc-internal-format
 msgid "bit-field %qs has invalid type"
 msgstr "%qs bit alanı geçersiz tür içeriyor"
 
-#: c/c-decl.c:5467
+#: c/c-decl.c:5487
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare bit-field %qD with function type"
 msgid "cannot declare bit-field %qs with %<warn_if_not_aligned%> type"
 msgstr "bit alanı %qD işlev türü ile bildirilemez"
 
-#: c/c-decl.c:5478
+#: c/c-decl.c:5498
 #, gcc-internal-format
 msgid "type of bit-field %qs is a GCC extension"
 msgstr "%qs bit alanı türü bir GCC oluşumudur"
 
-#: c/c-decl.c:5484
+#: c/c-decl.c:5504
 #, gcc-internal-format
 msgid "width of %qs exceeds its type"
 msgstr "%qs in genişliği türünü aşıyor"
 
-#: c/c-decl.c:5497
+#: c/c-decl.c:5517
 #, gcc-internal-format
 msgid "%qs is narrower than values of its type"
 msgstr "%qs genişliği türününkinden daha dar"
 
-#: c/c-decl.c:5512
+#: c/c-decl.c:5532
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids array %qs whose size can%'t be evaluated"
 msgid "ISO C90 forbids array %qE whose size can%'t be evaluated"
 msgstr "ISO C90 değerlendirilemeyen boyutlu %qs dizisini yasaklar"
 
-#: c/c-decl.c:5515
+#: c/c-decl.c:5535
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids array %qs whose size can%'t be evaluated"
 msgid "ISO C90 forbids array whose size can%'t be evaluated"
 msgstr "ISO C90 değerlendirilemeyen boyutlu %qs dizisini yasaklar"
 
-#: c/c-decl.c:5522
+#: c/c-decl.c:5542
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable-size array %qs"
 msgid "ISO C90 forbids variable length array %qE"
 msgstr "ISO C90 değişken boyutlu %qs dizisini yasaklar"
 
-#: c/c-decl.c:5524
+#: c/c-decl.c:5544
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable-size array %qs"
 msgid "ISO C90 forbids variable length array"
 msgstr "ISO C90 değişken boyutlu %qs dizisini yasaklar"
 
-#: c/c-decl.c:5733 c/c-decl.c:6107 c/c-decl.c:6117
+#: c/c-decl.c:5753 c/c-decl.c:6127 c/c-decl.c:6137
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is a variably modified type"
 msgid "variably modified %qE at file scope"
 msgstr "%qT değişkene göre değişen türde"
 
-#: c/c-decl.c:5735
+#: c/c-decl.c:5755
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is a variably modified type"
 msgid "variably modified field at file scope"
 msgstr "%qT değişkene göre değişen türde"
 
-#: c/c-decl.c:5755
+#: c/c-decl.c:5775
 #, fuzzy, gcc-internal-format
 #| msgid "type defaults to %<int%> in declaration of %qs"
 msgid "type defaults to %<int%> in declaration of %qE"
 msgstr "%qs bildiriminde tür öntanımlı olarak %<int%>"
 
-#: c/c-decl.c:5759
+#: c/c-decl.c:5779
 #, fuzzy, gcc-internal-format
 #| msgid "type defaults to %<int%> in declaration of %qs"
 msgid "type defaults to %<int%> in type name"
 msgstr "%qs bildiriminde tür öntanımlı olarak %<int%>"
 
-#: c/c-decl.c:5791
+#: c/c-decl.c:5811
 #, gcc-internal-format
 msgid "duplicate %<const%>"
 msgstr "%<const%> yinelenmiş"
 
-#: c/c-decl.c:5793
+#: c/c-decl.c:5813
 #, gcc-internal-format
 msgid "duplicate %<restrict%>"
 msgstr "%<restrict%> yinelenmiş"
 
-#: c/c-decl.c:5795
+#: c/c-decl.c:5815
 #, gcc-internal-format
 msgid "duplicate %<volatile%>"
 msgstr "%<volatile%> yinelenmiş"
 
-#: c/c-decl.c:5797
+#: c/c-decl.c:5817
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<restrict%>"
 msgid "duplicate %<_Atomic%>"
 msgstr "%<restrict%> yinelenmiş"
 
-#: c/c-decl.c:5800
+#: c/c-decl.c:5820
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "conflicting super class name %qs"
 msgid "conflicting named address spaces (%s vs %s)"
 msgstr "super sınıf ismi %qs çelişiyor"
 
-#: c/c-decl.c:5823 c/c-parser.c:2821
+#: c/c-decl.c:5843 c/c-parser.c:2821
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified array type"
 msgstr ""
 
-#: c/c-decl.c:5837
+#: c/c-decl.c:5857
 #, gcc-internal-format
 msgid "function definition declared %<auto%>"
 msgstr "%<auto%> bildirimli işlev tanımı"
 
-#: c/c-decl.c:5839
+#: c/c-decl.c:5859
 #, gcc-internal-format
 msgid "function definition declared %<register%>"
 msgstr "%<register%> bildirimli işlev tanımı"
 
-#: c/c-decl.c:5841
+#: c/c-decl.c:5861
 #, gcc-internal-format
 msgid "function definition declared %<typedef%>"
 msgstr "%<typedef%> bildirimli işlev tanımı"
 
-#: c/c-decl.c:5843
+#: c/c-decl.c:5863
 #, fuzzy, gcc-internal-format
 #| msgid "function definition declared %<auto%>"
 msgid "function definition declared %qs"
 msgstr "%<auto%> bildirimli işlev tanımı"
 
-#: c/c-decl.c:5861
+#: c/c-decl.c:5881
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for structure field %qs"
 msgid "storage class specified for structure field %qE"
 msgstr "%qs yapı alan için saklama sınıfı belirtilmiş"
 
-#: c/c-decl.c:5864
+#: c/c-decl.c:5884
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for structure field %qs"
 msgid "storage class specified for structure field"
 msgstr "%qs yapı alan için saklama sınıfı belirtilmiş"
 
-#: c/c-decl.c:5868
+#: c/c-decl.c:5888
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "storage class specified for parameter %qE"
 msgstr "%qs parametresi için saklama sınıfı belirtilmiş"
 
-#: c/c-decl.c:5871
+#: c/c-decl.c:5891
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "storage class specified for unnamed parameter"
 msgstr "%qs parametresi için saklama sınıfı belirtilmiş"
 
-#: c/c-decl.c:5874 cp/decl.c:10935
+#: c/c-decl.c:5894 cp/decl.c:10959
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "veri türü ismi için saklama sınıfı belirtildi"
 
-#: c/c-decl.c:5891
+#: c/c-decl.c:5911
 #, fuzzy, gcc-internal-format
 #| msgid "%qs initialized and declared %<extern%>"
 msgid "%qE initialized and declared %<extern%>"
 msgstr "%qs ilklendirilmiş ve %<extern%> bildirilmiş"
 
-#: c/c-decl.c:5895
+#: c/c-decl.c:5915
 #, fuzzy, gcc-internal-format
 #| msgid "%qs has both %<extern%> and initializer"
 msgid "%qE has both %<extern%> and initializer"
 msgstr "%qs hem %<extern%> olarak bildirilmiş hem de ilklendrilmiş"
 
-#: c/c-decl.c:5900
+#: c/c-decl.c:5920
 #, fuzzy, gcc-internal-format
 #| msgid "file-scope declaration of %qs specifies %<auto%>"
 msgid "file-scope declaration of %qE specifies %<auto%>"
 msgstr "%qs için dosya etki alanı bildirimi %<auto%> belirtiyor"
 
-#: c/c-decl.c:5904
+#: c/c-decl.c:5924
 #, fuzzy, gcc-internal-format
 #| msgid "file-scope declaration of %qs specifies %<register%>"
 msgid "file-scope declaration of %qE specifies %<register%>"
 msgstr "%qs için dosya etki alanı bildirimi %<register%> belirtiyor"
 
-#: c/c-decl.c:5909
+#: c/c-decl.c:5929
 #, fuzzy, gcc-internal-format
 #| msgid "nested function %qs declared %<extern%>"
 msgid "nested function %qE declared %<extern%>"
 msgstr "iç işlev %qs %<extern%> olarak bildirilmiş"
 
-#: c/c-decl.c:5912
+#: c/c-decl.c:5932
 #, fuzzy, gcc-internal-format
 #| msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgid "function-scope %qE implicitly auto and declared %qs"
@@ -39530,781 +39574,781 @@
 #. Only the innermost declarator (making a parameter be of
 #. array type which is converted to pointer type)
 #. may have static or type qualifiers.
-#: c/c-decl.c:5959 c/c-decl.c:6328
+#: c/c-decl.c:5979 c/c-decl.c:6348
 #, gcc-internal-format
 msgid "static or type qualifiers in non-parameter array declarator"
 msgstr "parametresiz dizi bildirimi içinde 'static' veya tür niteleyiciler"
 
-#: c/c-decl.c:6007
+#: c/c-decl.c:6027
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of voids"
 msgid "declaration of %qE as array of voids"
 msgstr "void dizisi olarak %qs bildirimi"
 
-#: c/c-decl.c:6009
+#: c/c-decl.c:6029
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of voids"
 msgid "declaration of type name as array of voids"
 msgstr "void dizisi olarak %qs bildirimi"
 
-#: c/c-decl.c:6016
+#: c/c-decl.c:6036
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of %qE as array of functions"
 msgstr "işlev dizisi olarak %qs bildirimi"
 
-#: c/c-decl.c:6019
+#: c/c-decl.c:6039
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of type name as array of functions"
 msgstr "işlev dizisi olarak %qs bildirimi"
 
-#: c/c-decl.c:6027 c/c-decl.c:8085
+#: c/c-decl.c:6047 c/c-decl.c:8105
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr "esnek dizi üyeli yapı kullanımı geçersiz"
 
-#: c/c-decl.c:6053
+#: c/c-decl.c:6073
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs has non-integer type"
 msgid "size of array %qE has non-integer type"
 msgstr "%qs dizisinin boyutu tamsayı tür değil"
 
-#: c/c-decl.c:6057
+#: c/c-decl.c:6077
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs has non-integer type"
 msgid "size of unnamed array has non-integer type"
 msgstr "%qs dizisinin boyutu tamsayı tür değil"
 
-#: c/c-decl.c:6064
+#: c/c-decl.c:6084
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs has non-integer type"
 msgid "size of array %qE has incomplete type"
 msgstr "%qs dizisinin boyutu tamsayı tür değil"
 
-#: c/c-decl.c:6067
+#: c/c-decl.c:6087
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs has non-integer type"
 msgid "size of unnamed array has incomplete type"
 msgstr "%qs dizisinin boyutu tamsayı tür değil"
 
-#: c/c-decl.c:6078
+#: c/c-decl.c:6098
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids zero-size array %qs"
 msgid "ISO C forbids zero-size array %qE"
 msgstr "ISO C sıfır boyutlu %qs dizisini yasaklar"
 
-#: c/c-decl.c:6081
+#: c/c-decl.c:6101
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids zero-size array"
 msgid "ISO C forbids zero-size array"
 msgstr "ISO C++'da sıfır boyutlu dizi yasaktır"
 
-#: c/c-decl.c:6090
+#: c/c-decl.c:6110
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is negative"
 msgid "size of array %qE is negative"
 msgstr "%qs dizisinin boyutu negatif"
 
-#: c/c-decl.c:6092
+#: c/c-decl.c:6112
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is negative"
 msgid "size of unnamed array is negative"
 msgstr "dizi boyutu negatif"
 
-#: c/c-decl.c:6216 c/c-decl.c:6871
+#: c/c-decl.c:6236 c/c-decl.c:6891
 #, gcc-internal-format
 msgid "ISO C90 does not support flexible array members"
 msgstr "ISO C90 esnek dizi üyelerini desteklemez"
 
 #. C99 6.7.5.2p4
-#: c/c-decl.c:6238
+#: c/c-decl.c:6258
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<[*]%> not in a declaration"
 msgstr "boş bildirimde %<inline%>"
 
-#: c/c-decl.c:6251
+#: c/c-decl.c:6271
 #, fuzzy, gcc-internal-format
 #| msgid "array type has incomplete element type"
 msgid "array type has incomplete element type %qT"
 msgstr "dizi türü içi boş öğe türü içeriyor"
 
-#: c/c-decl.c:6257
+#: c/c-decl.c:6277
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgid "declaration of %qE as multidimensional array must have bounds for all dimensions except the first"
 msgstr "çok boyutlu dizi olarak %qD bildiriminde ilki dışında tüm boyutlar sınırlanmış olmalıdır"
 
-#: c/c-decl.c:6261
+#: c/c-decl.c:6281
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgid "declaration of multidimensional array must have bounds for all dimensions except the first"
 msgstr "çok boyutlu dizi olarak %qD bildiriminde ilki dışında tüm boyutlar sınırlanmış olmalıdır"
 
-#: c/c-decl.c:6364
+#: c/c-decl.c:6384
 #, fuzzy, gcc-internal-format
 #| msgid "%qs declared as function returning a function"
 msgid "%qE declared as function returning a function"
 msgstr "%qs işlevle dönen işlev olarak bildirilmiş"
 
-#: c/c-decl.c:6367
+#: c/c-decl.c:6387
 #, fuzzy, gcc-internal-format
 #| msgid "%qs declared as function returning a function"
 msgid "type name declared as function returning a function"
 msgstr "%qs işlevle dönen işlev olarak bildirilmiş"
 
-#: c/c-decl.c:6374
+#: c/c-decl.c:6394
 #, fuzzy, gcc-internal-format
 #| msgid "%qs declared as function returning an array"
 msgid "%qE declared as function returning an array"
 msgstr "%qs dizi ile dönen işlev olarak bildirilmiş"
 
-#: c/c-decl.c:6377
+#: c/c-decl.c:6397
 #, fuzzy, gcc-internal-format
 #| msgid "%qs declared as function returning an array"
 msgid "type name declared as function returning an array"
 msgstr "%qs dizi ile dönen işlev olarak bildirilmiş"
 
-#: c/c-decl.c:6418
+#: c/c-decl.c:6438
 #, gcc-internal-format
 msgid "function definition has qualified void return type"
 msgstr "işlev tanımı nitelikli void dönüş türü içeriyor"
 
-#: c/c-decl.c:6421 cp/decl.c:11201
+#: c/c-decl.c:6441 cp/decl.c:11225
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "tür niteleyicileri işlev dönüş türünde yok sayıldı"
 
-#: c/c-decl.c:6459 c/c-decl.c:6668 c/c-decl.c:6721 c/c-decl.c:6805
-#: c/c-decl.c:6926 c/c-parser.c:2823
+#: c/c-decl.c:6479 c/c-decl.c:6688 c/c-decl.c:6741 c/c-decl.c:6825
+#: c/c-decl.c:6946 c/c-parser.c:2823
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids qualified function types"
 msgid "%<_Atomic%>-qualified function type"
 msgstr "ISO C nitelikli işlev türlerini yasaklar"
 
-#: c/c-decl.c:6465 c/c-decl.c:6674 c/c-decl.c:6810 c/c-decl.c:6931
+#: c/c-decl.c:6485 c/c-decl.c:6694 c/c-decl.c:6830 c/c-decl.c:6951
 #, gcc-internal-format
 msgid "ISO C forbids qualified function types"
 msgstr "ISO C nitelikli işlev türlerini yasaklar"
 
-#: c/c-decl.c:6559
+#: c/c-decl.c:6579
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting type qualifiers for %q+D"
 msgid "%qs combined with %<auto%> qualifier for %qE"
 msgstr "%q+D için çelişen tür niteleyiciler"
 
-#: c/c-decl.c:6563
+#: c/c-decl.c:6583
 #, gcc-internal-format
 msgid "%qs combined with %<register%> qualifier for %qE"
 msgstr ""
 
-#: c/c-decl.c:6569
+#: c/c-decl.c:6589
 #, fuzzy, gcc-internal-format
 #| msgid "illegal aggregate type %qs specified for instance variable %qs"
 msgid "%qs specified for auto variable %qE"
 msgstr "kümeleme türü %qs gerçeklenim değişkeni %qs için kuraldışı"
 
-#: c/c-decl.c:6585
+#: c/c-decl.c:6605
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "%qs specified for parameter %qE"
 msgstr "%qs parametresi için saklama sınıfı belirtilmiş"
 
-#: c/c-decl.c:6588
+#: c/c-decl.c:6608
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "%qs specified for unnamed parameter"
 msgstr "%qs parametresi için saklama sınıfı belirtilmiş"
 
-#: c/c-decl.c:6594
+#: c/c-decl.c:6614
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for structure field %qs"
 msgid "%qs specified for structure field %qE"
 msgstr "%qs yapı alan için saklama sınıfı belirtilmiş"
 
-#: c/c-decl.c:6597
+#: c/c-decl.c:6617
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for structure field %qs"
 msgid "%qs specified for structure field"
 msgstr "%qs yapı alan için saklama sınıfı belirtilmiş"
 
-#: c/c-decl.c:6612
+#: c/c-decl.c:6632
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qs has invalid type"
 msgid "bit-field %qE has atomic type"
 msgstr "%qs bit alanı geçersiz tür içeriyor"
 
-#: c/c-decl.c:6614
+#: c/c-decl.c:6634
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qs has invalid type"
 msgid "bit-field has atomic type"
 msgstr "%qs bit alanı geçersiz tür içeriyor"
 
-#: c/c-decl.c:6623
+#: c/c-decl.c:6643
 #, fuzzy, gcc-internal-format
 #| msgid "alignment may not be specified for %q+D"
 msgid "alignment specified for typedef %qE"
 msgstr "hizalama, %q+D için belirtilmiş olmayabilir"
 
-#: c/c-decl.c:6625
+#: c/c-decl.c:6645
 #, fuzzy, gcc-internal-format
 #| msgid "alignment may not be specified for %q+D"
 msgid "alignment specified for %<register%> object %qE"
 msgstr "hizalama, %q+D için belirtilmiş olmayabilir"
 
-#: c/c-decl.c:6630
+#: c/c-decl.c:6650
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "alignment specified for parameter %qE"
 msgstr "%qs parametresi için saklama sınıfı belirtilmiş"
 
-#: c/c-decl.c:6632
+#: c/c-decl.c:6652
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "alignment specified for unnamed parameter"
 msgstr "%qs parametresi için saklama sınıfı belirtilmiş"
 
-#: c/c-decl.c:6637
+#: c/c-decl.c:6657
 #, fuzzy, gcc-internal-format
 #| msgid "alignment may not be specified for %q+D"
 msgid "alignment specified for bit-field %qE"
 msgstr "hizalama, %q+D için belirtilmiş olmayabilir"
 
-#: c/c-decl.c:6639
+#: c/c-decl.c:6659
 #, fuzzy, gcc-internal-format
 #| msgid "%<__alignof%> applied to a bit-field"
 msgid "alignment specified for unnamed bit-field"
 msgstr "%<__alignof%> bir bit-alanına uygulanmış"
 
-#: c/c-decl.c:6642
+#: c/c-decl.c:6662
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "alignment specified for function %qE"
 msgstr "%qs sadece işlevler için belirtilebilir"
 
-#: c/c-decl.c:6649
+#: c/c-decl.c:6669
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of %qE"
 msgstr ""
 
-#: c/c-decl.c:6652
+#: c/c-decl.c:6672
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of unnamed field"
 msgstr ""
 
-#: c/c-decl.c:6683
+#: c/c-decl.c:6703
 #, gcc-internal-format
 msgid "typedef %q+D declared %<inline%>"
 msgstr "%<inline%> bildirimli typedef %q+D"
 
-#: c/c-decl.c:6685
+#: c/c-decl.c:6705
 #, fuzzy, gcc-internal-format
 #| msgid "typedef %q+D declared %<inline%>"
 msgid "typedef %q+D declared %<_Noreturn%>"
 msgstr "%<inline%> bildirimli typedef %q+D"
 
-#: c/c-decl.c:6727
+#: c/c-decl.c:6747
 #, gcc-internal-format
 msgid "ISO C forbids const or volatile function types"
 msgstr "ISO C 'const' ya da 'volatile' işlev türlerini yasaklar"
 
 #. C99 6.7.2.1p8
-#: c/c-decl.c:6738
+#: c/c-decl.c:6758
 #, fuzzy, gcc-internal-format
 #| msgid "data member may not have variably modified type %qT"
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "veri üyesi değişken olarak değiştirilmiş %qT türünde olamayabilir"
 
-#: c/c-decl.c:6755 cp/decl.c:9989
+#: c/c-decl.c:6775 cp/decl.c:10010
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "void bildirimli değişken ya da alan %qE"
 
-#: c/c-decl.c:6795
+#: c/c-decl.c:6815
 #, gcc-internal-format
 msgid "attributes in parameter array declarator ignored"
 msgstr "parametre dizisi bildirimindeki öznitelikler yoksayıldı"
 
-#: c/c-decl.c:6837
+#: c/c-decl.c:6857
 #, gcc-internal-format
 msgid "parameter %q+D declared %<inline%>"
 msgstr "%<inline%> bildirimli %q+D parametresi"
 
-#: c/c-decl.c:6839
+#: c/c-decl.c:6859
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared %<inline%>"
 msgid "parameter %q+D declared %<_Noreturn%>"
 msgstr "%<inline%> bildirimli %q+D parametresi"
 
-#: c/c-decl.c:6852
+#: c/c-decl.c:6872
 #, fuzzy, gcc-internal-format
 #| msgid "field %qs declared as a function"
 msgid "field %qE declared as a function"
 msgstr "%qs alanı bir işlev olarak bildirilmiş"
 
-#: c/c-decl.c:6859
+#: c/c-decl.c:6879
 #, fuzzy, gcc-internal-format
 #| msgid "field %qs has incomplete type"
 msgid "field %qE has incomplete type"
 msgstr "%qs alanı tamamlanmamış türde"
 
-#: c/c-decl.c:6861
+#: c/c-decl.c:6881
 #, fuzzy, gcc-internal-format
 #| msgid "name %qT has incomplete type"
 msgid "unnamed field has incomplete type"
 msgstr "%qT ismi içi boş türde"
 
-#: c/c-decl.c:6897 c/c-decl.c:6908 c/c-decl.c:6911
+#: c/c-decl.c:6917 c/c-decl.c:6928 c/c-decl.c:6931
 #, fuzzy, gcc-internal-format
 #| msgid "invalid storage class for function %qs"
 msgid "invalid storage class for function %qE"
 msgstr "%qs işlevi için geçersiz saklama sınıfı"
 
-#: c/c-decl.c:6968
+#: c/c-decl.c:6988
 #, gcc-internal-format
 msgid "cannot inline function %<main%>"
 msgstr "%<main%> satıriçi işlev olamaz"
 
-#: c/c-decl.c:6970
+#: c/c-decl.c:6990
 #, fuzzy, gcc-internal-format
 #| msgid "%qs initialized and declared %<extern%>"
 msgid "%<main%> declared %<_Noreturn%>"
 msgstr "%qs ilklendirilmiş ve %<extern%> bildirilmiş"
 
-#: c/c-decl.c:6981
+#: c/c-decl.c:7001
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<long long%>"
 msgid "ISO C99 does not support %<_Noreturn%>"
 msgstr "ISO C90 %<long long%>'u desteklemez"
 
-#: c/c-decl.c:6984
+#: c/c-decl.c:7004
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<long long%>"
 msgid "ISO C90 does not support %<_Noreturn%>"
 msgstr "ISO C90 %<long long%>'u desteklemez"
 
-#: c/c-decl.c:7013
+#: c/c-decl.c:7033
 #, gcc-internal-format
 msgid "variable previously declared %<static%> redeclared %<extern%>"
 msgstr "evvelce %<static%> bildirilmiş değişken %<extern%> olarak yeniden bildirilmiş"
 
-#: c/c-decl.c:7023
+#: c/c-decl.c:7043
 #, gcc-internal-format
 msgid "variable %q+D declared %<inline%>"
 msgstr "%<inline%> bildirimli %q+D değişkeni"
 
-#: c/c-decl.c:7025
+#: c/c-decl.c:7045
 #, fuzzy, gcc-internal-format
 #| msgid "variable %q+D declared %<inline%>"
 msgid "variable %q+D declared %<_Noreturn%>"
 msgstr "%<inline%> bildirimli %q+D değişkeni"
 
-#: c/c-decl.c:7060
+#: c/c-decl.c:7080
 #, fuzzy, gcc-internal-format
 #| msgid "jump into scope of identifier with variably modified type"
 msgid "non-nested function with variably modified type"
 msgstr "değişkene göre değişen türde betimleyici etki alanına jump"
 
-#: c/c-decl.c:7062
+#: c/c-decl.c:7082
 #, gcc-internal-format
 msgid "object with variably modified type must have no linkage"
 msgstr ""
 
-#: c/c-decl.c:7153 c/c-decl.c:8821
+#: c/c-decl.c:7173 c/c-decl.c:8841
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr "işlev bildirimi bir prototip değil"
 
-#: c/c-decl.c:7163
+#: c/c-decl.c:7183
 #, gcc-internal-format
 msgid "parameter names (without types) in function declaration"
 msgstr "işlev bildiriminde (türleri belirtmeksizin) parametre isimleri"
 
-#: c/c-decl.c:7201
+#: c/c-decl.c:7221
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has incomplete type"
 msgstr "%u. parametre (%q+D) tamamlanmamış türde"
 
-#: c/c-decl.c:7205
+#: c/c-decl.c:7225
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%Jparameter %u has incomplete type"
 msgid "parameter %u has incomplete type"
 msgstr "%J%u. parametre tamamlanmamış türde"
 
-#: c/c-decl.c:7216
+#: c/c-decl.c:7236
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has void type"
 msgstr "%u. parametre (%q+D) void türde"
 
-#: c/c-decl.c:7220
+#: c/c-decl.c:7240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%Jparameter %u has void type"
 msgid "parameter %u has void type"
 msgstr "%J%u. parametre void türde"
 
-#: c/c-decl.c:7294
+#: c/c-decl.c:7314
 #, gcc-internal-format
 msgid "%<void%> as only parameter may not be qualified"
 msgstr "tek parametre olarak %<void%> yeterli olmayabilir"
 
-#: c/c-decl.c:7298 c/c-decl.c:7334
+#: c/c-decl.c:7318 c/c-decl.c:7354
 #, gcc-internal-format
 msgid "%<void%> must be the only parameter"
 msgstr "%<void%> tek parametre olmalıdır"
 
-#: c/c-decl.c:7328
+#: c/c-decl.c:7348
 #, gcc-internal-format
 msgid "parameter %q+D has just a forward declaration"
 msgstr "%q+D parametresi tam bir ilerletme bildirimine sahip"
 
-#: c/c-decl.c:7374
+#: c/c-decl.c:7394
 #, gcc-internal-format
 msgid "%<%s %E%> declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr ""
 
-#: c/c-decl.c:7380
+#: c/c-decl.c:7400
 #, gcc-internal-format, gfc-internal-format
 msgid "anonymous %s declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr ""
 
-#: c/c-decl.c:7482
+#: c/c-decl.c:7502
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "enum type defined here"
 msgstr "%q+#D evvelce burada tanımlanmış"
 
-#: c/c-decl.c:7488
+#: c/c-decl.c:7508
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "struct defined here"
 msgstr "%q+#D evvelce burada tanımlanmış"
 
-#: c/c-decl.c:7494
+#: c/c-decl.c:7514
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "union defined here"
 msgstr "%q+#D evvelce burada tanımlanmış"
 
-#: c/c-decl.c:7570
+#: c/c-decl.c:7590
 #, gcc-internal-format
 msgid "redefinition of %<union %E%>"
 msgstr "%<union %E%> yeniden tanımlanmış"
 
-#: c/c-decl.c:7572
+#: c/c-decl.c:7592
 #, gcc-internal-format
 msgid "redefinition of %<struct %E%>"
 msgstr "%<struct %E%> yeniden tanımlanmış"
 
-#: c/c-decl.c:7581
+#: c/c-decl.c:7601
 #, gcc-internal-format
 msgid "nested redefinition of %<union %E%>"
 msgstr "%<union %E%> iç içe yeniden tanımlanmış"
 
-#: c/c-decl.c:7583
+#: c/c-decl.c:7603
 #, gcc-internal-format
 msgid "nested redefinition of %<struct %E%>"
 msgstr "%<struct %E%> iç içe yeniden tanımlanmış"
 
-#: c/c-decl.c:7613 c/c-decl.c:8400
+#: c/c-decl.c:7633 c/c-decl.c:8420
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:7680 cp/decl.c:4802
+#: c/c-decl.c:7700 cp/decl.c:4802
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "bildirim hiçbir şey bildirmiyor"
 
-#: c/c-decl.c:7685
+#: c/c-decl.c:7705
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C doesn%'t support unnamed structs/unions"
 msgid "ISO C99 doesn%'t support unnamed structs/unions"
 msgstr "ISO C isimsiz struct/union'lara izin vermez"
 
-#: c/c-decl.c:7688
+#: c/c-decl.c:7708
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C doesn%'t support unnamed structs/unions"
 msgid "ISO C90 doesn%'t support unnamed structs/unions"
 msgstr "ISO C isimsiz struct/union'lara izin vermez"
 
-#: c/c-decl.c:7781 c/c-decl.c:7799 c/c-decl.c:7860
+#: c/c-decl.c:7801 c/c-decl.c:7819 c/c-decl.c:7880
 #, gcc-internal-format
 msgid "duplicate member %q+D"
 msgstr "yinelenmiş üye %q+D"
 
-#: c/c-decl.c:7886
+#: c/c-decl.c:7906
 #, gcc-internal-format
 msgid "empty struct has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.c:7889
+#: c/c-decl.c:7909
 #, gcc-internal-format
 msgid "empty union has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.c:7994
+#: c/c-decl.c:8014
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr "union hiç isimli üye içermiyor"
 
-#: c/c-decl.c:7996
+#: c/c-decl.c:8016
 #, gcc-internal-format
 msgid "union has no members"
 msgstr "union hiç üye içermiyor"
 
-#: c/c-decl.c:8001
+#: c/c-decl.c:8021
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr "yapı hiç isimli üye içermiyor"
 
-#: c/c-decl.c:8003
+#: c/c-decl.c:8023
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr "yapı hiç üye içermiyor"
 
-#: c/c-decl.c:8064 cp/decl.c:12069
+#: c/c-decl.c:8084 cp/decl.c:12093
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in union"
 msgid "flexible array member in union"
 msgstr "%Junion içinde esnek dizi üye"
 
-#: c/c-decl.c:8070
+#: c/c-decl.c:8090
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member not at end of struct"
 msgid "flexible array member not at end of struct"
 msgstr "%Jesnek dizi yapının son üyesi değil"
 
-#: c/c-decl.c:8076
+#: c/c-decl.c:8096
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in union"
 msgid "flexible array member in a struct with no named members"
 msgstr "%Junion içinde esnek dizi üye"
 
-#: c/c-decl.c:8107
+#: c/c-decl.c:8127
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "type %qT is too large"
 msgstr "%qs dizisinin boyutu çok büyük"
 
-#: c/c-decl.c:8230
+#: c/c-decl.c:8250
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr "birleşik yapı şeffaf olamaz"
 
-#: c/c-decl.c:8372
+#: c/c-decl.c:8392
 #, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr "%<enum %E%> iç içe yeniden tanımlanmış"
 
 #. This enum is a named one that has been declared already.
-#: c/c-decl.c:8379
+#: c/c-decl.c:8399
 #, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr "%<enum %E%> yeniden bildirilmiş"
 
-#: c/c-decl.c:8458 cp/decl.c:14423
+#: c/c-decl.c:8478 cp/decl.c:14447
 #, gcc-internal-format
 msgid "specified mode too small for enumeral values"
 msgstr "belirtilen kip sırali sayısal değerler için çok küçük"
 
-#: c/c-decl.c:8473
+#: c/c-decl.c:8493
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr "sembolik sabit grubunun değerleri en büyük tamsayı aralığını aşıyor."
 
-#: c/c-decl.c:8587 c/c-decl.c:8603
+#: c/c-decl.c:8607 c/c-decl.c:8623
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr "%qE için sembolik sabit değeri bir tamsayı sabit değil"
 
-#: c/c-decl.c:8598
+#: c/c-decl.c:8618
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qE is not an integer constant"
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr "%qE için sembolik sabit değeri bir tamsayı sabit değil"
 
-#: c/c-decl.c:8622
+#: c/c-decl.c:8642
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr "sembolik sabit listesi değerlerinde taşma"
 
-#: c/c-decl.c:8630
+#: c/c-decl.c:8650
 #, gcc-internal-format
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "ISO C sembolik sabit grubunun değerlerini %<int%> kapsamında sınırlar"
 
-#: c/c-decl.c:8715 cp/decl.c:5104 cp/decl.c:14955
+#: c/c-decl.c:8735 cp/decl.c:5104 cp/decl.c:14979
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D given attribute noinline"
 msgid "inline function %qD given attribute noinline"
 msgstr "satıriçi %q+D işlevine satıriçi olmayan öznitelik verilmiş"
 
-#: c/c-decl.c:8733
+#: c/c-decl.c:8753
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr "dönüş türü, bir içi boş tür"
 
-#: c/c-decl.c:8744
+#: c/c-decl.c:8764
 #, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr "dönen tür %<int%> türüne öntanımlıdir"
 
-#: c/c-decl.c:8771
+#: c/c-decl.c:8791
 #, fuzzy, gcc-internal-format
 #| msgid "field %qs declared as a function"
 msgid "%q+D defined as variadic function without prototype"
 msgstr "%qs alanı bir işlev olarak bildirilmiş"
 
-#: c/c-decl.c:8830
+#: c/c-decl.c:8850
 #, fuzzy, gcc-internal-format
 #| msgid "no previous prototype for %q+D"
 msgid "no previous prototype for %qD"
 msgstr "%q+D için önceki prototip yok"
 
-#: c/c-decl.c:8839
+#: c/c-decl.c:8859
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was used with no prototype before its definition"
 msgid "%qD was used with no prototype before its definition"
 msgstr "%q+D tanımlanmadan önce prototipsiz kullanılmış"
 
-#: c/c-decl.c:8847 cp/decl.c:15090
+#: c/c-decl.c:8867 cp/decl.c:15114
 #, fuzzy, gcc-internal-format
 #| msgid "no previous declaration for %q+D"
 msgid "no previous declaration for %qD"
 msgstr "%q+D için evvelce bildirim yok"
 
-#: c/c-decl.c:8857
+#: c/c-decl.c:8877
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was used with no declaration before its definition"
 msgid "%qD was used with no declaration before its definition"
 msgstr "%q+D tanımından önce bildirimsiz kullanılmış"
 
-#: c/c-decl.c:8876
+#: c/c-decl.c:8896
 #, fuzzy, gcc-internal-format
 #| msgid "return type of %q+D is not %<int%>"
 msgid "return type of %qD is not %<int%>"
 msgstr "%q+D için dönüş türü %<int%> değil"
 
-#: c/c-decl.c:8878
+#: c/c-decl.c:8898
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr ""
 
-#: c/c-decl.c:8885
+#: c/c-decl.c:8905
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is normally a non-static function"
 msgid "%qD is normally a non-static function"
 msgstr "%q+D normalde bir static olmayan işlevdir"
 
-#: c/c-decl.c:8922
+#: c/c-decl.c:8942
 #, fuzzy, gcc-internal-format
 #| msgid "%Jold-style parameter declarations in prototyped function definition"
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr "%Jprototipli işlev tanımında eski tarz parametre bildirimi"
 
-#: c/c-decl.c:8937
+#: c/c-decl.c:8957
 #, fuzzy, gcc-internal-format
 #| msgid "%Jtraditional C rejects ISO C style function definitions"
 msgid "traditional C rejects ISO C style function definitions"
 msgstr "%Jgeleneksel C, ISO C tarzı işlev tanımlarına izin vermez"
 
-#: c/c-decl.c:8953
+#: c/c-decl.c:8973
 #, fuzzy, gcc-internal-format
 #| msgid "%Jparameter name omitted"
 msgid "parameter name omitted"
 msgstr "%Jparametre ismi atlandı"
 
-#: c/c-decl.c:8990
+#: c/c-decl.c:9010
 #, fuzzy, gcc-internal-format
 #| msgid "%Jold-style function definition"
 msgid "old-style function definition"
 msgstr "%Jeski tarz işlev tanımı"
 
-#: c/c-decl.c:8999
+#: c/c-decl.c:9019
 #, fuzzy, gcc-internal-format
 #| msgid "%Jparameter name missing from parameter list"
 msgid "parameter name missing from parameter list"
 msgstr "%Jparametre ismi parametre listesinde yok"
 
-#: c/c-decl.c:9015
+#: c/c-decl.c:9035
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a non-parameter"
 msgid "%qD declared as a non-parameter"
 msgstr "%q+D bir parametre olarak bildirilmemiş"
 
-#: c/c-decl.c:9023
+#: c/c-decl.c:9043
 #, fuzzy, gcc-internal-format
 #| msgid "multiple parameters named %q+D"
 msgid "multiple parameters named %qD"
 msgstr "%q+D isimli çok sayıda parametre"
 
-#: c/c-decl.c:9032
+#: c/c-decl.c:9052
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared with void type"
 msgid "parameter %qD declared with void type"
 msgstr "%q+D parametresi void olarak bildirilmiş"
 
-#: c/c-decl.c:9061 c/c-decl.c:9066
+#: c/c-decl.c:9081 c/c-decl.c:9086
 #, fuzzy, gcc-internal-format
 #| msgid "type of %q+D defaults to %<int%>"
 msgid "type of %qD defaults to %<int%>"
 msgstr "%q+D için tür öntanımlı olarak %<int%>"
 
-#: c/c-decl.c:9086
+#: c/c-decl.c:9106
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D has incomplete type"
 msgid "parameter %qD has incomplete type"
 msgstr "%q+D parametresi tamamlanmamış türde"
 
-#: c/c-decl.c:9093
+#: c/c-decl.c:9113
 #, fuzzy, gcc-internal-format
 #| msgid "declaration for parameter %q+D but no such parameter"
 msgid "declaration for parameter %qD but no such parameter"
 msgstr "%q+D parametresi için bildirim var ama böyle bir parametre yok"
 
-#: c/c-decl.c:9146
+#: c/c-decl.c:9166
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr "argüman sayısı yerleşik prototiple uyumsuz"
 
-#: c/c-decl.c:9157
+#: c/c-decl.c:9177
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr "argüman sayısı prototiple uyumsuz"
 
-#: c/c-decl.c:9160 c/c-decl.c:9207 c/c-decl.c:9221
+#: c/c-decl.c:9180 c/c-decl.c:9227 c/c-decl.c:9241
 #, fuzzy, gcc-internal-format
 #| msgid "%Hprototype declaration"
 msgid "prototype declaration"
 msgstr "%Hprototip bildirimi"
 
-#: c/c-decl.c:9199
+#: c/c-decl.c:9219
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr "yükseltgenmiş argüman %qD yerleşik prototiple uyumsuz"
 
-#: c/c-decl.c:9204
+#: c/c-decl.c:9224
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr "yükseltgenmiş argüman %qD prototiple uyumsuz"
 
-#: c/c-decl.c:9214
+#: c/c-decl.c:9234
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr "%qD argümanı yerleşik prototiple eslesmiyor"
 
-#: c/c-decl.c:9219
+#: c/c-decl.c:9239
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr "%qD argümanı prototiple uyumsuz"
 
-#: c/c-decl.c:9470 cp/decl.c:15873
+#: c/c-decl.c:9490 cp/decl.c:15897
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "void olmayan dönüşlü işlevde `return' deyimi yok"
 
-#: c/c-decl.c:9490 cp/decl.c:15905
+#: c/c-decl.c:9510 cp/decl.c:15929
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD is initialized"
 msgid "parameter %qD set but not used"
@@ -40313,270 +40357,270 @@
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:9586
+#: c/c-decl.c:9606
 #, fuzzy, gcc-internal-format
 #| msgid "%<for%> loop initial declaration used outside C99 mode"
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "%<for%> döngüsünün ilk bildirimi C99 kipinin dışında kullanılmış"
 
-#: c/c-decl.c:9591
+#: c/c-decl.c:9611
 #, gcc-internal-format
 msgid "use option -std=c99, -std=gnu99, -std=c11 or -std=gnu11 to compile your code"
 msgstr ""
 
-#: c/c-decl.c:9626
+#: c/c-decl.c:9646
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of static variable %q+D in %<for%> loop initial declaration"
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "%<for%> döngüsünün ilk bildiriminde statik değişken %q+D bildirimi"
 
-#: c/c-decl.c:9630
+#: c/c-decl.c:9650
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %<extern%> variable %q+D in %<for%> loop initial declaration"
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "%<for%> döngüsünün ilk bildiriminde %<extern%> değişken %q+D bildirimi"
 
-#: c/c-decl.c:9637
+#: c/c-decl.c:9657
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "%<struct %E%> %<for%> döngüsünün ilk bildiriminde bildirilmiş"
 
-#: c/c-decl.c:9642
+#: c/c-decl.c:9662
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "%<union %E%> %<for%> döngüsünün ilk bildiriminde bildirilmiş"
 
-#: c/c-decl.c:9646
+#: c/c-decl.c:9666
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "%<enum %E%> %<for%> döngüsünün ilk bildiriminde bildirilmiş"
 
-#: c/c-decl.c:9650
+#: c/c-decl.c:9670
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of non-variable %q+D in %<for%> loop initial declaration"
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "%<for%> döngüsünün ilk bildiriminde değişken olmayan %q+D bildirimi"
 
-#: c/c-decl.c:9900
+#: c/c-decl.c:9920
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr ""
 
-#: c/c-decl.c:9958 c/c-decl.c:9965
+#: c/c-decl.c:9978 c/c-decl.c:9985
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "duplicate %qE declaration specifier"
 msgstr "bildirim belirteçleri umuluyordu"
 
-#: c/c-decl.c:9992 c/c-decl.c:10376 c/c-decl.c:10766
+#: c/c-decl.c:10012 c/c-decl.c:10396 c/c-decl.c:10786
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr "bildirim belirteçleri içinde iki veya daha fazla veri türü"
 
-#: c/c-decl.c:10004 cp/parser.c:28261
+#: c/c-decl.c:10024 cp/parser.c:28258
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> GCC için çok uzun"
 
-#: c/c-decl.c:10017
+#: c/c-decl.c:10037
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C90 %<long long%>'u desteklemez"
 
-#: c/c-decl.c:10246 c/c-parser.c:8848
+#: c/c-decl.c:10266 c/c-parser.c:8848
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C90 karmaşık türleri desteklemez"
 
-#: c/c-decl.c:10292
+#: c/c-decl.c:10312
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support saturating types"
 msgstr "ISO C karmaşık tamsayı türleri desteklemez"
 
-#: c/c-decl.c:10363 c/c-decl.c:10923
+#: c/c-decl.c:10383 c/c-decl.c:10943
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "%qE yinelenmiş"
 
-#: c/c-decl.c:10419
+#: c/c-decl.c:10439
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C karmaşık tamsayı türleri desteklemez"
 
-#: c/c-decl.c:10441
+#: c/c-decl.c:10461
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "%<__int%d%> is not supported on this target"
 msgstr "bu hedefte yığıt sınırları desteklenmiyor"
 
-#: c/c-decl.c:10484
+#: c/c-decl.c:10504
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support complex types"
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C90 karmaşık türleri desteklemez"
 
-#: c/c-decl.c:10603
+#: c/c-decl.c:10623
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support the %<_Float%d%s%> type"
 msgstr "ISO C karmaşık tamsayı türleri desteklemez"
 
-#: c/c-decl.c:10653
+#: c/c-decl.c:10673
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "bu hedefte yığıt sınırları desteklenmiyor"
 
-#: c/c-decl.c:10724
+#: c/c-decl.c:10744
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<long long%>"
 msgid "ISO C does not support decimal floating point"
 msgstr "ISO C90 %<long long%>'u desteklemez"
 
-#: c/c-decl.c:10747 c/c-decl.c:11013 c/c-parser.c:7842
+#: c/c-decl.c:10767 c/c-decl.c:11033 c/c-parser.c:7842
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "fixed-point types not supported for this target"
 msgstr "bu hedefte -fdata-sections desteklenmiyor"
 
-#: c/c-decl.c:10749
+#: c/c-decl.c:10769
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C karmaşık tamsayı türleri desteklemez"
 
-#: c/c-decl.c:10784
+#: c/c-decl.c:10804
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr ""
 
-#: c/c-decl.c:10797
+#: c/c-decl.c:10817
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr "%qE bir typedef veya yerleşik veri türü olarak başarısız"
 
-#: c/c-decl.c:10845
+#: c/c-decl.c:10865
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qE bildirimin başlangıcında değil"
 
-#: c/c-decl.c:10866
+#: c/c-decl.c:10886
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<auto%>"
 msgid "%qE used with %<auto%>"
 msgstr "%<__thread%> %<auto%> ile kullanılmış"
 
-#: c/c-decl.c:10868
+#: c/c-decl.c:10888
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<register%>"
 msgid "%qE used with %<register%>"
 msgstr "%<__thread%> %<register%> ile kullanılmış"
 
-#: c/c-decl.c:10870
+#: c/c-decl.c:10890
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<typedef%>"
 msgid "%qE used with %<typedef%>"
 msgstr "%<__thread%> %<typedef%> ile kullanılmış"
 
-#: c/c-decl.c:10884 c/c-parser.c:7360
+#: c/c-decl.c:10904 c/c-parser.c:7360
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "ISO C99 does not support %qE"
 msgstr "%s %s desteği vermiyor"
 
-#: c/c-decl.c:10887 c/c-parser.c:7363
+#: c/c-decl.c:10907 c/c-parser.c:7363
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<long long%>"
 msgid "ISO C90 does not support %qE"
 msgstr "ISO C90 %<long long%>'u desteklemez"
 
-#: c/c-decl.c:10899
+#: c/c-decl.c:10919
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<extern%> öncesinde %<__thread%>"
 
-#: c/c-decl.c:10908
+#: c/c-decl.c:10928
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<static%>  öncesinde %<__thread%>"
 
-#: c/c-decl.c:10921
+#: c/c-decl.c:10941
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr ""
 
-#: c/c-decl.c:10929
+#: c/c-decl.c:10949
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr "bildirim belirteçlerinde çok sayıda saklama sınıfı"
 
-#: c/c-decl.c:10937
+#: c/c-decl.c:10957
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %qE"
 msgid "%qs used with %qE"
 msgstr "%<__thread%> %qE ile kullanılmış"
 
-#: c/c-decl.c:11010
+#: c/c-decl.c:11030
 #, fuzzy, gcc-internal-format
 #| msgid "%<@try%> without %<@catch%> or %<@finally%>"
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "%<@catch%> veya %<@finally%> olmaksızın %<@try%>"
 
-#: c/c-decl.c:11025
+#: c/c-decl.c:11045
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C salt %<complex%>i %<double complex%> anlamında desteklemez"
 
-#: c/c-decl.c:11076 c/c-decl.c:11092 c/c-decl.c:11118
+#: c/c-decl.c:11096 c/c-decl.c:11112 c/c-decl.c:11138
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C karmaşık tamsayı türleri desteklemez"
 
-#: c/c-decl.c:11514 cp/semantics.c:5348
+#: c/c-decl.c:11534 cp/semantics.c:5351
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:11518 cp/semantics.c:5352
+#: c/c-decl.c:11538 cp/semantics.c:5355
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.c:385 c/c-typeck.c:11426 cp/typeck.c:4680
+#: c/c-fold.c:385 c/c-typeck.c:11431 cp/typeck.c:4680
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count is negative"
 msgid "left shift of negative value"
 msgstr "sola kaydırma sayısı negatif"
 
-#: c/c-fold.c:395 c/c-typeck.c:11435 cp/typeck.c:4688
+#: c/c-fold.c:395 c/c-typeck.c:11440 cp/typeck.c:4688
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "sola kaydırma sayısı negatif"
 
-#: c/c-fold.c:396 c/c-typeck.c:11365 cp/typeck.c:4633
+#: c/c-fold.c:396 c/c-typeck.c:11370 cp/typeck.c:4633
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "sağa kaydırma sayısı negatif"
 
-#: c/c-fold.c:404 c/c-typeck.c:11454 cp/typeck.c:4696
+#: c/c-fold.c:404 c/c-typeck.c:11459 cp/typeck.c:4696
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "sola kaydırma sayısı tür genişliğinden büyük ya da eşit"
 
-#: c/c-fold.c:405 c/c-typeck.c:11389 cp/typeck.c:4641
+#: c/c-fold.c:405 c/c-typeck.c:11394 cp/typeck.c:4641
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "sağa kaydırma sayısı tür genişliğinden büyük ya da eşit"
 
-#: c/c-fold.c:412 c/c-typeck.c:11446
+#: c/c-fold.c:412 c/c-typeck.c:11451
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count >= width of type"
 msgid "left shift count >= width of vector element"
 msgstr "sola kaydırma sayısı tür genişliğinden büyük ya da eşit"
 
-#: c/c-fold.c:413 c/c-typeck.c:11376
+#: c/c-fold.c:413 c/c-typeck.c:11381
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count >= width of type"
 msgid "right shift count >= width of vector element"
@@ -40598,7 +40642,7 @@
 msgid "to match this %qs"
 msgstr "%J  diğer tür burada"
 
-#: c/c-parser.c:1216 cp/parser.c:28484
+#: c/c-parser.c:1216 cp/parser.c:28481
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of module"
 msgid "expected end of line"
@@ -40643,7 +40687,7 @@
 msgstr "bilinmeyen yazmaç ismi: %s"
 
 #: c/c-parser.c:1848 c/c-parser.c:11129 c/c-parser.c:16147 c/c-parser.c:16585
-#: c/c-parser.c:17061 cp/parser.c:36007 cp/parser.c:38993
+#: c/c-parser.c:17061 cp/parser.c:36004 cp/parser.c:38990
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "bildirim belirteçleri umuluyordu"
@@ -40660,7 +40704,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "betimleyici veya %<(%> umuluyordu"
 
-#: c/c-parser.c:1906 cp/parser.c:30161 cp/parser.c:30235
+#: c/c-parser.c:1906 cp/parser.c:30158 cp/parser.c:30232
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored for %qE"
 msgid "prefix attributes are ignored for methods"
@@ -40721,7 +40765,7 @@
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr ""
 
-#: c/c-parser.c:2220 cp/parser.c:13002 cp/parser.c:13159
+#: c/c-parser.c:2220 cp/parser.c:12999 cp/parser.c:13156
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "%<,%> veya %<;%> umuluyordu"
@@ -40751,7 +40795,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C90 %<long long%>'u desteklemez"
 
-#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38634
+#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38631
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr "dizge sabiti umuluyordu"
@@ -40823,13 +40867,13 @@
 #: c/c-parser.c:10745 c/c-parser.c:10798 c/c-parser.c:10814 c/c-parser.c:10860
 #: c/c-parser.c:11496 c/c-parser.c:11537 c/c-parser.c:13445 c/c-parser.c:13681
 #: c/c-parser.c:15544 c/c-parser.c:18218 c/gimple-parser.c:1058
-#: c/gimple-parser.c:1096 cp/parser.c:28487 cp/parser.c:31013
-#: cp/parser.c:31043 cp/parser.c:31113 cp/parser.c:33230 cp/parser.c:38350
+#: c/gimple-parser.c:1096 cp/parser.c:28484 cp/parser.c:31010
+#: cp/parser.c:31040 cp/parser.c:31110 cp/parser.c:33227 cp/parser.c:38347
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "betimleyici umuluyordu"
 
-#: c/c-parser.c:2995 cp/parser.c:18384
+#: c/c-parser.c:2995 cp/parser.c:18381
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "sembolik sabitler listesinin sonunda virgul"
@@ -41003,13 +41047,13 @@
 msgid "expected statement"
 msgstr "deyim umuluyordu"
 
-#: c/c-parser.c:5639 cp/parser.c:12516
+#: c/c-parser.c:5639 cp/parser.c:12513
 #, fuzzy, gcc-internal-format
 #| msgid "%Hempty body in an if-statement"
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "%Hif deyiminin gövdesi boş"
 
-#: c/c-parser.c:5681 cp/parser.c:12519
+#: c/c-parser.c:5681 cp/parser.c:12516
 #, fuzzy, gcc-internal-format
 #| msgid "%Hempty body in an else-statement"
 msgid "suggest braces around empty body in an %<else%> statement"
@@ -41388,7 +41432,7 @@
 msgid "%<__builtin_complex%> operands of different types"
 msgstr "?: için terimler farklı türde"
 
-#: c/c-parser.c:8891 cp/parser.c:6918
+#: c/c-parser.c:8891 cp/parser.c:6921
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for %qs attribute"
 msgid "wrong number of arguments to %<__builtin_shuffle%>"
@@ -41452,85 +41496,85 @@
 msgid "no type or storage class may be specified here,"
 msgstr "%qs için saklatım sınıfı belirtilmiş"
 
-#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31073
+#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31070
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr ""
 
-#: c/c-parser.c:10682 cp/parser.c:31033
+#: c/c-parser.c:10682 cp/parser.c:31030
 #, fuzzy, gcc-internal-format
 #| msgid "missing %<(%> after %<#pragma pack%> - ignored"
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "%<#pragma pack%> sonrasında %<(%> eksik - yoksayıldı"
 
-#: c/c-parser.c:10685 cp/parser.c:31036
+#: c/c-parser.c:10685 cp/parser.c:31033
 #, fuzzy, gcc-internal-format
 #| msgid "missing %<(%> after %<#pragma pack%> - ignored"
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "%<#pragma pack%> sonrasında %<(%> eksik - yoksayıldı"
 
-#: c/c-parser.c:10699 cp/parser.c:31051
+#: c/c-parser.c:10699 cp/parser.c:31048
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsection attribute cannot be specified for local variables"
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "%Jbölüm özniteliği yerel değişkenler için belirtilmiş olamaz"
 
-#: c/c-parser.c:10704 cp/parser.c:31057
+#: c/c-parser.c:10704 cp/parser.c:31054
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.c:10711 cp/parser.c:31065
+#: c/c-parser.c:10711 cp/parser.c:31062
 #, fuzzy, gcc-internal-format
 #| msgid "%Jaddress area attribute cannot be specified for functions"
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "%Jadres alanı özelliği işlevler için belirtilemez"
 
-#: c/c-parser.c:10905 cp/parser.c:38674
+#: c/c-parser.c:10905 cp/parser.c:38671
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
 #: c/c-parser.c:10949 c/c-parser.c:16582 c/c-parser.c:16840 c/c-parser.c:16899
-#: c/c-parser.c:16983 cp/parser.c:36004 cp/parser.c:36298 cp/parser.c:36386
-#: cp/parser.c:36457 cp/parser.c:38721 cp/parser.c:38736 cp/parser.c:38752
-#: cp/parser.c:38768 cp/parser.c:38784 cp/parser.c:38811 cp/parser.c:38824
-#: cp/parser.c:38847 cp/parser.c:38860
+#: c/c-parser.c:16983 cp/parser.c:36001 cp/parser.c:36295 cp/parser.c:36383
+#: cp/parser.c:36454 cp/parser.c:38718 cp/parser.c:38733 cp/parser.c:38749
+#: cp/parser.c:38765 cp/parser.c:38781 cp/parser.c:38808 cp/parser.c:38821
+#: cp/parser.c:38844 cp/parser.c:38857
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "bu kapsamda %<this%> kullanılamaz"
 
-#: c/c-parser.c:10972 cp/parser.c:38837
+#: c/c-parser.c:10972 cp/parser.c:38834
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC memregs must precede any function decls"
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "#pragma GCC memregs bir işlev bildirimi ile öncelenmeli"
 
-#: c/c-parser.c:11050 cp/parser.c:38918
+#: c/c-parser.c:11050 cp/parser.c:38915
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr ""
 
-#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38947 cp/parser.c:38980
+#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38944 cp/parser.c:38977
 #, fuzzy, gcc-internal-format
 #| msgid "%s statement expected at %L"
 msgid "for, while or do statement expected"
 msgstr "%s deyimi %L'de umuluyordu"
 
-#: c/c-parser.c:11111 cp/parser.c:38711
+#: c/c-parser.c:11111 cp/parser.c:38708
 #, fuzzy, gcc-internal-format
 #| msgid "malformed #pragma GCC pch_preprocess, ignored"
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "#pragma GCC pch_preprocess bozuk, yoksayıldı"
 
-#: c/c-parser.c:11421 cp/parser.c:31457
+#: c/c-parser.c:11421 cp/parser.c:31454
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %qs clauses"
 msgstr "girdi dosyası sayısı çok fazla"
 
-#: c/c-parser.c:11443 cp/parser.c:31994
+#: c/c-parser.c:11443 cp/parser.c:31991
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "expected integer expression before ')'"
@@ -41548,61 +41592,61 @@
 msgid "%qD is not a variable"
 msgstr "%qD bir şablon değil"
 
-#: c/c-parser.c:11746 cp/semantics.c:6808
+#: c/c-parser.c:11746 cp/semantics.c:6811
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template"
 msgid "%qD is not a pointer variable"
 msgstr "%qD bir şablon değil"
 
-#: c/c-parser.c:11788 cp/parser.c:32073
+#: c/c-parser.c:11788 cp/parser.c:32070
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between signed and unsigned integer expressions"
 msgid "collapse argument needs positive constant integer expression"
 msgstr "işaretli ve işaretsiz tamsayı ifadeler arasında karşılaştırma"
 
-#: c/c-parser.c:11865 cp/parser.c:32137
+#: c/c-parser.c:11865 cp/parser.c:32134
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<none%> or %<present%>"
 msgstr "%<,%> veya %<;%> umuluyordu"
 
-#: c/c-parser.c:11867 cp/parser.c:32139
+#: c/c-parser.c:11867 cp/parser.c:32136
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<none%> or %<shared%>"
 msgstr "%<,%> veya %<;%> umuluyordu"
 
-#: c/c-parser.c:11968 cp/parser.c:32242
+#: c/c-parser.c:11968 cp/parser.c:32239
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "%<,%>, %<;%> veya %<}%> umuluyordu"
 
-#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32260
-#: cp/parser.c:36290 cp/parser.c:36378
+#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32257
+#: cp/parser.c:36287 cp/parser.c:36375
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<data%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.c:12035 cp/parser.c:32313
+#: c/c-parser.c:12035 cp/parser.c:32310
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:12042 cp/parser.c:32320
+#: c/c-parser.c:12042 cp/parser.c:32317
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %<if%> clauses"
 msgstr "girdi dosyası sayısı çok fazla"
 
-#: c/c-parser.c:12044 cp/parser.c:32322
+#: c/c-parser.c:12044 cp/parser.c:32319
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %<if%> clauses without modifier"
 msgstr "girdi dosyası sayısı çok fazla"
 
-#: c/c-parser.c:12050 cp/parser.c:32328
+#: c/c-parser.c:12050 cp/parser.c:32325
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -41626,93 +41670,93 @@
 msgid "%<num_tasks%> value must be positive"
 msgstr "%s etiketi (%L'de) %s türünde olmalı"
 
-#: c/c-parser.c:12229 cp/semantics.c:6992
+#: c/c-parser.c:12229 cp/semantics.c:6995
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC memregs must precede any function decls"
 msgid "%<grainsize%> value must be positive"
 msgstr "#pragma GCC memregs bir işlev bildirimi ile öncelenmeli"
 
-#: c/c-parser.c:12276 cp/semantics.c:7021
+#: c/c-parser.c:12276 cp/semantics.c:7024
 #, fuzzy, gcc-internal-format
 #| msgid "%s at %L must be a scalar"
 msgid "%<priority%> value must be non-negative"
 msgstr "%s' (%L'de) bir değişmez olmalıdır"
 
-#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32545 cp/parser.c:32552
+#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32542 cp/parser.c:32549
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<tofrom%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32561 cp/parser.c:32568
+#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32558 cp/parser.c:32565
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<scalar%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.c:12425 cp/semantics.c:6299
+#: c/c-parser.c:12425 cp/semantics.c:6302
 #, fuzzy, gcc-internal-format
 #| msgid "Expression at %L must be scalar"
 msgid "%qs expression must be integral"
 msgstr "%L'deki ifade değişmez olmalı"
 
-#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6331
+#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6334
 #, fuzzy, gcc-internal-format
 #| msgid "%s tag at %L must be of type %s"
 msgid "%qs value must be positive"
 msgstr "%s etiketi (%L'de) %s türünde olmalı"
 
-#: c/c-parser.c:12499 cp/parser.c:31853
+#: c/c-parser.c:12499 cp/parser.c:31850
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments for format"
 msgid "too many %<static%> arguments"
 msgstr "biçim için argüman sayısı çok fazla"
 
-#: c/c-parser.c:12533 cp/parser.c:31886
+#: c/c-parser.c:12533 cp/parser.c:31883
 #, fuzzy, gcc-internal-format
 #| msgid "Expected attribute bit name"
 msgid "unexpected argument"
 msgstr "Öznitelik bit ismi umuluyordu"
 
-#: c/c-parser.c:12699 cp/semantics.c:7120
+#: c/c-parser.c:12699 cp/semantics.c:7123
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute argument not an integer constant"
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "%qs öznitelik argümanı bir tamsayı sabit değil"
 
-#: c/c-parser.c:12765 cp/parser.c:32626
+#: c/c-parser.c:12765 cp/parser.c:32623
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between signed and unsigned integer expressions"
 msgid "ordered argument needs positive constant integer expression"
 msgstr "işaretli ve işaretsiz tamsayı ifadeler arasında karşılaştırma"
 
-#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37643
+#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37640
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr ""
 
-#: c/c-parser.c:12967 cp/parser.c:32840
+#: c/c-parser.c:12967 cp/parser.c:32837
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr ""
 
-#: c/c-parser.c:13021 cp/parser.c:32856
+#: c/c-parser.c:13021 cp/parser.c:32853
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:13025 cp/parser.c:32859
+#: c/c-parser.c:13025 cp/parser.c:32856
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:13037 cp/semantics.c:6389
+#: c/c-parser.c:13037 cp/semantics.c:6392
 #, fuzzy, gcc-internal-format
 #| msgid "%s tag at %L must be of type %s"
 msgid "chunk size value must be positive"
 msgstr "%s etiketi (%L'de) %s türünde olmalı"
 
-#: c/c-parser.c:13060 cp/parser.c:32879
+#: c/c-parser.c:13060 cp/parser.c:32876
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_double operand"
 msgid "invalid schedule kind"
@@ -41723,12 +41767,12 @@
 msgid "%<num_teams%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:13226 cp/semantics.c:6479
+#: c/c-parser.c:13226 cp/semantics.c:6482
 #, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:13271 cp/semantics.c:6589
+#: c/c-parser.c:13271 cp/semantics.c:6592
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr ""
@@ -41748,19 +41792,19 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:13584 cp/parser.c:33374 cp/parser.c:33599
+#: c/c-parser.c:13584 cp/parser.c:33371 cp/parser.c:33596
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%d operand"
 msgid "invalid depend kind"
 msgstr "geçersiz %%d terimi"
 
-#: c/c-parser.c:13669 cp/parser.c:33447
+#: c/c-parser.c:13669 cp/parser.c:33444
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mask"
 msgid "invalid map kind"
 msgstr "mask geçersiz"
 
-#: c/c-parser.c:13767 cp/parser.c:33546
+#: c/c-parser.c:13767 cp/parser.c:33543
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_double operand"
 msgid "invalid dist_schedule kind"
@@ -41772,74 +41816,74 @@
 msgid "invalid proc_bind kind"
 msgstr "geçersiz döngü komutu"
 
-#: c/c-parser.c:14059 cp/parser.c:33825
+#: c/c-parser.c:14059 cp/parser.c:33822
 #, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr ""
 
-#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33836 cp/parser.c:34143
+#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33833 cp/parser.c:34140
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid output file"
 msgid "%qs is not valid for %qs"
 msgstr "%qs geçerli bir çıktı dosyası değil"
 
-#: c/c-parser.c:14214 cp/parser.c:34010
+#: c/c-parser.c:14214 cp/parser.c:34007
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a nested class of %qT"
 msgid "%qs must be the first clause of %qs"
 msgstr "%qT %qT'nin alt sınıfı değil"
 
-#: c/c-parser.c:14334 cp/parser.c:34132
+#: c/c-parser.c:14334 cp/parser.c:34129
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr ""
 
-#: c/c-parser.c:14472 cp/parser.c:36803
+#: c/c-parser.c:14472 cp/parser.c:36800
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14482 cp/parser.c:36813
+#: c/c-parser.c:14482 cp/parser.c:36810
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD shadows a global declaration"
 msgid "array section in %<#pragma acc declare%>"
 msgstr "%qD bildirimi bir global bildirimi gölgeliyor"
 
-#: c/c-parser.c:14502 cp/parser.c:36833
+#: c/c-parser.c:14502 cp/parser.c:36830
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr ""
 
-#: c/c-parser.c:14513 cp/parser.c:36844
+#: c/c-parser.c:14513 cp/parser.c:36841
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is a variably modified type"
 msgid "invalid OpenACC clause at file scope"
 msgstr "%qT değişkene göre değişen türde"
 
-#: c/c-parser.c:14520 cp/parser.c:36851
+#: c/c-parser.c:14520 cp/parser.c:36848
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %<extern%> variable %q+D in %<for%> loop initial declaration"
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "%<for%> döngüsünün ilk bildiriminde %<extern%> değişken %q+D bildirimi"
 
-#: c/c-parser.c:14528 cp/parser.c:36859
+#: c/c-parser.c:14528 cp/parser.c:36856
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member %q+D in static member function"
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "statik üye işlevde üye %q+D kullanımı geçersiz"
 
-#: c/c-parser.c:14540 cp/parser.c:36871
+#: c/c-parser.c:14540 cp/parser.c:36868
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14632 cp/parser.c:36957
+#: c/c-parser.c:14632 cp/parser.c:36954
 #, fuzzy, gcc-internal-format
 #| msgid "expected string literal"
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "dizge sabiti umuluyordu"
 
-#: c/c-parser.c:14648 cp/parser.c:36974
+#: c/c-parser.c:14648 cp/parser.c:36971
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr ""
@@ -41856,7 +41900,7 @@
 msgid "expected function name"
 msgstr "umulmadık düğüm"
 
-#: c/c-parser.c:14893 cp/parser.c:38064
+#: c/c-parser.c:14893 cp/parser.c:38061
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qD does not refer to a function"
@@ -41868,47 +41912,47 @@
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr "bir işlev tanımıda özniteliklere izin verilmez"
 
-#: c/c-parser.c:14953 cp/parser.c:38118 cp/parser.c:38160
+#: c/c-parser.c:14953 cp/parser.c:38115 cp/parser.c:38157
 #, fuzzy, gcc-internal-format
 #| msgid "attributes are not allowed on a function-definition"
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr "bir işlev tanımıda özniteliklere izin verilmez"
 
-#: c/c-parser.c:14970 cp/parser.c:38174
+#: c/c-parser.c:14970 cp/parser.c:38171
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> already applied to %qD"
 msgstr ""
 
-#: c/c-parser.c:14979 cp/parser.c:38183
+#: c/c-parser.c:14979 cp/parser.c:38180
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC memregs must precede any function decls"
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr "#pragma GCC memregs bir işlev bildirimi ile öncelenmeli"
 
-#: c/c-parser.c:14980 cp/parser.c:38184
+#: c/c-parser.c:14980 cp/parser.c:38181
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC memregs must precede any function decls"
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "#pragma GCC memregs bir işlev bildirimi ile öncelenmeli"
 
-#: c/c-parser.c:15023 cp/parser.c:37152
+#: c/c-parser.c:15023 cp/parser.c:37149
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
 
-#: c/c-parser.c:15435 cp/parser.c:34511 cp/parser.c:34537
+#: c/c-parser.c:15435 cp/parser.c:34508 cp/parser.c:34534
 #, fuzzy, gcc-internal-format
 #| msgid "malformed %<#pragma align%>"
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "%<#pragma align%> bozuk"
 
-#: c/c-parser.c:15439 cp/parser.c:34568 cp/parser.c:34584
+#: c/c-parser.c:15439 cp/parser.c:34565 cp/parser.c:34581
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operation on %<__fpreg%>"
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "%<__fpreg%> üzerinde geçersiz işlem"
 
-#: c/c-parser.c:15488 cp/semantics.c:8401 cp/semantics.c:8411
+#: c/c-parser.c:15488 cp/semantics.c:8404 cp/semantics.c:8414
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
@@ -41919,23 +41963,23 @@
 msgid "expected %<(%> or end of line"
 msgstr "Beklenmeyen modül sonu"
 
-#: c/c-parser.c:15619 cp/parser.c:35103
+#: c/c-parser.c:15619 cp/parser.c:35100
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:15630 cp/parser.c:35114
+#: c/c-parser.c:15630 cp/parser.c:35111
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:15648 cp/parser.c:35141
+#: c/c-parser.c:15648 cp/parser.c:35138
 #, fuzzy, gcc-internal-format
 #| msgid "%s statement expected at %L"
 msgid "for statement expected"
 msgstr "%s deyimi %L'de umuluyordu"
 
-#: c/c-parser.c:15718 cp/semantics.c:8066 cp/semantics.c:8153
+#: c/c-parser.c:15718 cp/semantics.c:8069 cp/semantics.c:8156
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration or statement"
 msgid "expected iteration declaration or initialization"
@@ -41946,76 +41990,76 @@
 msgid "not enough perfectly nested loops"
 msgstr ""
 
-#: c/c-parser.c:15862 cp/parser.c:35364
+#: c/c-parser.c:15862 cp/parser.c:35361
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.c:15909 cp/parser.c:35184 cp/parser.c:35226 cp/pt.c:16385
+#: c/c-parser.c:15909 cp/parser.c:35181 cp/parser.c:35223 cp/pt.c:16407
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: c/c-parser.c:16000 cp/parser.c:35437
+#: c/c-parser.c:16000 cp/parser.c:35434
 #, fuzzy, gcc-internal-format
 #| msgid "%<void%> as only parameter may not be qualified"
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "tek parametre olarak %<void%> yeterli olmayabilir"
 
-#: c/c-parser.c:16166 cp/parser.c:35600
+#: c/c-parser.c:16166 cp/parser.c:35597
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:16374 cp/parser.c:35799
+#: c/c-parser.c:16374 cp/parser.c:35796
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<for%> after %qs"
 msgstr "%<,%> veya %<;%> umuluyordu"
 
-#: c/c-parser.c:16573 cp/parser.c:35995
+#: c/c-parser.c:16573 cp/parser.c:35992
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<point%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.c:16793 cp/parser.c:36232
+#: c/c-parser.c:16793 cp/parser.c:36229
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16806 cp/parser.c:36245
+#: c/c-parser.c:16806 cp/parser.c:36242
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16853 cp/parser.c:36470
+#: c/c-parser.c:16853 cp/parser.c:36467
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:16925 cp/parser.c:36325
+#: c/c-parser.c:16925 cp/parser.c:36322
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16937 cp/parser.c:36337
+#: c/c-parser.c:16937 cp/parser.c:36334
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17011 cp/parser.c:36414
+#: c/c-parser.c:17011 cp/parser.c:36411
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17024 cp/parser.c:36427
+#: c/c-parser.c:17024 cp/parser.c:36424
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17238 cp/parser.c:36680
+#: c/c-parser.c:17238 cp/parser.c:36677
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -42036,34 +42080,34 @@
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17395 cp/parser.c:37273
+#: c/c-parser.c:17395 cp/parser.c:37270
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17474 cp/parser.c:37343
+#: c/c-parser.c:17474 cp/parser.c:37340
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> with clauses in between %<#pragma omp declare target%> without clauses and %<#pragma omp end declare target%>"
 msgstr ""
 
-#: c/c-parser.c:17493 cp/parser.c:37362
+#: c/c-parser.c:17493 cp/parser.c:37359
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17534 cp/parser.c:37409
+#: c/c-parser.c:17534 cp/parser.c:37406
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<target%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.c:17541 cp/parser.c:37416
+#: c/c-parser.c:17541 cp/parser.c:37413
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<declare%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.c:17547 cp/parser.c:37423
+#: c/c-parser.c:17547 cp/parser.c:37420
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr ""
@@ -42120,51 +42164,51 @@
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:17947 cp/parser.c:37868
+#: c/c-parser.c:17947 cp/parser.c:37865
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr "%<,%>, %<;%> veya %<}%> umuluyordu"
 
-#: c/c-parser.c:18162 cp/semantics.c:7531
+#: c/c-parser.c:18162 cp/semantics.c:7534
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%<static%> olarak bildirilen `%q+F hiç tanımlanmamış"
 
-#: c/c-parser.c:18164 cp/semantics.c:7533
+#: c/c-parser.c:18164 cp/semantics.c:7536
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: c/c-parser.c:18168 cp/semantics.c:7535
+#: c/c-parser.c:18168 cp/semantics.c:7538
 #, fuzzy, gcc-internal-format
 #| msgid "%Jparameter %u has incomplete type"
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%J%u. parametre tamamlanmamış türde"
 
-#: c/c-parser.c:18368 cp/parser.c:38565
+#: c/c-parser.c:18368 cp/parser.c:38562
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:18374 cp/parser.c:38571
+#: c/c-parser.c:18374 cp/parser.c:38568
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
 
-#: c/c-parser.c:18383 cp/parser.c:38580
+#: c/c-parser.c:18383 cp/parser.c:38577
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.c:18385 cp/parser.c:38583
+#: c/c-parser.c:18385 cp/parser.c:38580
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.c:18391 cp/parser.c:38589
+#: c/c-parser.c:18391 cp/parser.c:38586
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
@@ -42180,7 +42224,7 @@
 msgid "%qD has an incomplete type %qT"
 msgstr "%qD bir tamamlanmamış tür içeriyor"
 
-#: c/c-typeck.c:237 c/c-typeck.c:9994 c/c-typeck.c:10036 cp/call.c:4147
+#: c/c-typeck.c:237 c/c-typeck.c:9999 c/c-typeck.c:10041 cp/call.c:4147
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "void ifade kullanımı geçersiz"
@@ -42259,13 +42303,13 @@
 msgid "converting an array compound literal to a pointer is ill-formed in C++"
 msgstr ""
 
-#: c/c-typeck.c:2417 c/c-typeck.c:8641
+#: c/c-typeck.c:2417 c/c-typeck.c:8646
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%qT has no member named %qE; did you mean %qE?"
 msgstr "%qT türü %qE isimli üye içermiyor"
 
-#: c/c-typeck.c:2421 c/c-typeck.c:8645
+#: c/c-typeck.c:2421 c/c-typeck.c:8650
 #, gcc-internal-format
 msgid "%qT has no member named %qE"
 msgstr "%qT türü %qE isimli üye içermiyor"
@@ -42476,498 +42520,498 @@
 msgid "pointer to a function used in subtraction"
 msgstr "çıkartmada işlev göstericisi kullanılmış"
 
-#: c/c-typeck.c:3847
+#: c/c-typeck.c:3852
 #, gcc-internal-format
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "bir içi boş tür göstericisi üzerinde aritmetik"
 
-#: c/c-typeck.c:3852 cp/typeck.c:5562
+#: c/c-typeck.c:3857 cp/typeck.c:5562
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr "bir içi boş tür göstericisi üzerinde aritmetik"
 
-#: c/c-typeck.c:4283
+#: c/c-typeck.c:4288
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "%<~%> on a boolean expression"
 msgstr "ifade umuluyordu"
 
-#: c/c-typeck.c:4287
+#: c/c-typeck.c:4292
 #, gcc-internal-format
 msgid "did you mean to use logical not?"
 msgstr ""
 
-#: c/c-typeck.c:4296
+#: c/c-typeck.c:4301
 #, gcc-internal-format
 msgid "ISO C does not support %<~%> for complex conjugation"
 msgstr "ISO C karmaşık sayıların mantıksal çarpımında %<~%> desteklemez"
 
-#: c/c-typeck.c:4335
+#: c/c-typeck.c:4340
 #, gcc-internal-format
 msgid "wrong type argument to unary exclamation mark"
 msgstr "tek terimli tümleyen için yanlış türde argüman"
 
-#: c/c-typeck.c:4393
+#: c/c-typeck.c:4398
 #, gcc-internal-format
 msgid "increment of enumeration value is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:4396
+#: c/c-typeck.c:4401
 #, gcc-internal-format
 msgid "decrement of enumeration value is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:4403
+#: c/c-typeck.c:4408
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "increment of a boolean expression"
 msgstr "ifade umuluyordu"
 
-#: c/c-typeck.c:4406
+#: c/c-typeck.c:4411
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "decrement of a boolean expression"
 msgstr "ifade umuluyordu"
 
-#: c/c-typeck.c:4422
+#: c/c-typeck.c:4427
 #, gcc-internal-format
 msgid "ISO C does not support %<++%> and %<--%> on complex types"
 msgstr "ISO C karmaşık sayı türlerinde %<++%> ve %<--%> desteklemez"
 
-#: c/c-typeck.c:4447 c/c-typeck.c:4481
+#: c/c-typeck.c:4452 c/c-typeck.c:4486
 #, gcc-internal-format
 msgid "wrong type argument to increment"
 msgstr "arttırımda yanlış türde argüman"
 
-#: c/c-typeck.c:4449 c/c-typeck.c:4484
+#: c/c-typeck.c:4454 c/c-typeck.c:4489
 #, gcc-internal-format
 msgid "wrong type argument to decrement"
 msgstr "eksiltmede yanlış türde argüman"
 
-#: c/c-typeck.c:4469
+#: c/c-typeck.c:4474
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "increment of pointer to an incomplete type %qT"
 msgstr "bir içi boş tür göstericisi üzerinde aritmetik"
 
-#: c/c-typeck.c:4473
+#: c/c-typeck.c:4478
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "decrement of pointer to an incomplete type %qT"
 msgstr "bir içi boş tür göstericisi üzerinde aritmetik"
 
-#: c/c-typeck.c:4577
+#: c/c-typeck.c:4582
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of expression of type %<void%>"
 msgstr "gecicinin adresi alıniyor"
 
-#: c/c-typeck.c:4636
+#: c/c-typeck.c:4641
 #, gcc-internal-format
 msgid "cannot take address of bit-field %qD"
 msgstr "%qD bit-alanının adresi alınamaz"
 
-#: c/c-typeck.c:4649
+#: c/c-typeck.c:4654
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgid "cannot take address of scalar with reverse storage order"
 msgstr "bir sağ taraf ifadesi olan %<this%>'in adresi alınamaz"
 
-#: c/c-typeck.c:4657
+#: c/c-typeck.c:4662
 #, fuzzy, gcc-internal-format
 #| msgid "address of register variable %qD requested"
 msgid "address of array with reverse scalar storage order requested"
 msgstr "%qD yazmaç değişkeninin adresi istendi"
 
-#: c/c-typeck.c:4838
+#: c/c-typeck.c:4843
 #, gcc-internal-format
 msgid "global register variable %qD used in nested function"
 msgstr "genel yazmaç değişkeni %qD iç işlevde kullanılmış"
 
-#: c/c-typeck.c:4841
+#: c/c-typeck.c:4846
 #, gcc-internal-format
 msgid "register variable %qD used in nested function"
 msgstr "yazmaç değişkeni %qD iç işlevde kullanılmış"
 
-#: c/c-typeck.c:4846
+#: c/c-typeck.c:4851
 #, gcc-internal-format
 msgid "address of global register variable %qD requested"
 msgstr "%qD genel yazmaç değişkeninin adresi istenmiş"
 
-#: c/c-typeck.c:4848
+#: c/c-typeck.c:4853
 #, gcc-internal-format
 msgid "address of register variable %qD requested"
 msgstr "%qD yazmaç değişkeninin adresi istendi"
 
-#: c/c-typeck.c:4951
+#: c/c-typeck.c:4956
 #, gcc-internal-format
 msgid "non-lvalue array in conditional expression"
 msgstr "koşullu ifadede sol değersiz dizi"
 
-#: c/c-typeck.c:5033
+#: c/c-typeck.c:5038
 #, fuzzy, gcc-internal-format
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "implicit conversion from %qT to %qT to match other result of conditional"
 msgstr "%qT türünden %qT türüne örtük dönüşüme C++'da izin verilmez"
 
-#: c/c-typeck.c:5092 c/c-typeck.c:5098
+#: c/c-typeck.c:5097 c/c-typeck.c:5103
 #, gcc-internal-format
 msgid "operand of ?: changes signedness from %qT to %qT due to unsignedness of other operand"
 msgstr ""
 
-#: c/c-typeck.c:5115
+#: c/c-typeck.c:5120
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr with only one void side"
 msgstr "ISO C tek taraflı void tür içeren koşullu ifadelere izin vermez"
 
-#: c/c-typeck.c:5132
+#: c/c-typeck.c:5137
 #, fuzzy, gcc-internal-format
 #| msgid "pointer type mismatch in conditional expression"
 msgid "pointers to disjoint address spaces used in conditional expression"
 msgstr "koşullu ifadede gösterici türü uyumsuzluğu"
 
-#: c/c-typeck.c:5143 c/c-typeck.c:5160
+#: c/c-typeck.c:5148 c/c-typeck.c:5165
 #, fuzzy, gcc-internal-format
 #| msgid "pointer type mismatch in conditional expression"
 msgid "pointer to array loses qualifier in conditional expression"
 msgstr "koşullu ifadede gösterici türü uyumsuzluğu"
 
-#: c/c-typeck.c:5148 c/c-typeck.c:5165
+#: c/c-typeck.c:5153 c/c-typeck.c:5170
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr between %<void *%> and function pointer"
 msgstr "ISO C %<void *%> ve işlev göstericisi arasında koşullu ifadelere izin vermez"
 
-#: c/c-typeck.c:5178
+#: c/c-typeck.c:5183
 #, gcc-internal-format
 msgid "pointer type mismatch in conditional expression"
 msgstr "koşullu ifadede gösterici türü uyumsuzluğu"
 
-#: c/c-typeck.c:5187 c/c-typeck.c:5198
+#: c/c-typeck.c:5192 c/c-typeck.c:5203
 #, gcc-internal-format
 msgid "pointer/integer type mismatch in conditional expression"
 msgstr "koşullu ifadede gösterici/tamsayı tür uyumsuzluğu"
 
-#: c/c-typeck.c:5336
+#: c/c-typeck.c:5341
 #, gcc-internal-format
 msgid "left-hand operand of comma expression has no effect"
 msgstr "virgüllü ifadenin sol terimi etkisiz"
 
-#: c/c-typeck.c:5354 c/c-typeck.c:10636
+#: c/c-typeck.c:5359 c/c-typeck.c:10641
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "right-hand operand of comma expression has no effect"
 msgstr "virgüllü ifadenin sol terimi etkisiz"
 
-#: c/c-typeck.c:5423
+#: c/c-typeck.c:5428
 #, fuzzy
 #| msgid "cast adds new qualifiers to function type"
 msgid "cast adds %q#v qualifier to function type"
 msgstr "tür dönüşümü, işlev türüne yeni niteleyiciler ekliyor"
 
-#: c/c-typeck.c:5429
+#: c/c-typeck.c:5434
 #, fuzzy
 #| msgid "cast discards qualifiers from pointer target type"
 msgid "cast discards %qv qualifier from pointer target type"
 msgstr "tür dönüşümü, gösterici hedef türünden niteleyicileri iptal ediyor"
 
-#: c/c-typeck.c:5464
+#: c/c-typeck.c:5469
 #, gcc-internal-format
 msgid "to be safe all intermediate pointers in cast from %qT to %qT must be %<const%> qualified"
 msgstr ""
 
-#: c/c-typeck.c:5554
+#: c/c-typeck.c:5559
 #, gcc-internal-format
 msgid "cast specifies array type"
 msgstr "tür dönüşümü dizi belirtiyor"
 
-#: c/c-typeck.c:5560
+#: c/c-typeck.c:5565
 #, gcc-internal-format
 msgid "cast specifies function type"
 msgstr "tür dönüşümü işlev belirtiyor"
 
-#: c/c-typeck.c:5575
+#: c/c-typeck.c:5580
 #, gcc-internal-format
 msgid "ISO C forbids casting nonscalar to the same type"
 msgstr "ISO C skalar olmayandan aynı türe dönüşüme izin vermez"
 
-#: c/c-typeck.c:5595
+#: c/c-typeck.c:5600
 #, gcc-internal-format
 msgid "ISO C forbids casts to union type"
 msgstr "ISO C union türe dönüşüme izin vermez"
 
-#: c/c-typeck.c:5605
+#: c/c-typeck.c:5610
 #, gcc-internal-format
 msgid "cast to union type from type not present in union"
 msgstr "union içinde mevcut olmayan türden union türe dönüşüm"
 
-#: c/c-typeck.c:5640
+#: c/c-typeck.c:5645
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint generic address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5645
+#: c/c-typeck.c:5650
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to generic address space pointer from disjoint %s address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5650
+#: c/c-typeck.c:5655
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint %s address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5670
+#: c/c-typeck.c:5675
 #, gcc-internal-format
 msgid "cast increases required alignment of target type"
 msgstr "tür dönüşümü hedef türün gerekli hizalamasını azaltıyor"
 
-#: c/c-typeck.c:5681
+#: c/c-typeck.c:5686
 #, gcc-internal-format
 msgid "cast from pointer to integer of different size"
 msgstr "göstericiden farklı tamsayı türlere dönüşüm"
 
-#: c/c-typeck.c:5686
+#: c/c-typeck.c:5691
 #, gcc-internal-format
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "%qT türündeki işlev çağrısından eşleşmeyen %qT türüne dönüşüm"
 
-#: c/c-typeck.c:5695 cp/typeck.c:7811
+#: c/c-typeck.c:5700 cp/typeck.c:7811
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "farklı boyuttaki tamsayı türden göstericiye dönüşüm"
 
-#: c/c-typeck.c:5709
+#: c/c-typeck.c:5714
 #, gcc-internal-format
 msgid "ISO C forbids conversion of function pointer to object pointer type"
 msgstr "ISO C işlev göstericisinin nesne göstericisine dönüştürülmesini yasaklar"
 
-#: c/c-typeck.c:5718
+#: c/c-typeck.c:5723
 #, gcc-internal-format
 msgid "ISO C forbids conversion of object pointer to function pointer type"
 msgstr "ISO C nesne göstericisinin işlev göstericisine dönüştürülmesini yasaklar"
 
-#: c/c-typeck.c:5728
+#: c/c-typeck.c:5733
 #, fuzzy, gcc-internal-format
 #| msgid "can't convert from incomplete type %qT to %qT"
 msgid "cast between incompatible function types from %qT to %qT"
 msgstr "içi boş %qT türünden %qT türüne dönüşüm yapılamaz"
 
-#: c/c-typeck.c:5815
+#: c/c-typeck.c:5820
 #, gcc-internal-format
 msgid "defining a type in a cast is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:5856
+#: c/c-typeck.c:5861
 #, fuzzy, gcc-internal-format
 #| msgid "assignment suppression"
 msgid "assignment to expression with array type"
 msgstr "atama engelleme"
 
-#: c/c-typeck.c:5982
+#: c/c-typeck.c:5987
 #, gcc-internal-format
 msgid "enum conversion in assignment is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:6180 c/c-typeck.c:6202 c/c-typeck.c:6226
+#: c/c-typeck.c:6185 c/c-typeck.c:6207 c/c-typeck.c:6231
 #, gcc-internal-format
 msgid "(near initialization for %qs)"
 msgstr "(%qs için near ilklendirme)"
 
-#: c/c-typeck.c:6241
+#: c/c-typeck.c:6246
 #, gcc-internal-format
 msgid "array initialized from parenthesized string constant"
 msgstr "parantezli dizge sabitten ilklendirmeli dizi"
 
-#: c/c-typeck.c:6284 c/c-typeck.c:6476 c/c-typeck.c:6908
+#: c/c-typeck.c:6289 c/c-typeck.c:6481 c/c-typeck.c:6913
 #, fuzzy, gcc-internal-format
 #| msgid "format %q.*s expects type %<%T%s%>, but argument %d has type %qT"
 msgid "expected %qT but argument is of type %qT"
 msgstr "%q.*s biçiminin %<%T%s%> türünde olması umuluyor, ama %d. argüman %qT türünde"
 
-#: c/c-typeck.c:6471
+#: c/c-typeck.c:6476
 #, fuzzy, gcc-internal-format
 msgid "enum conversion when passing argument %d of %qE is invalid in C++"
 msgstr "%2$qE işlevinin %1$d. argümanının aktarımında gösterici hedefleri farklı sign'lıkta"
 
-#: c/c-typeck.c:6480
+#: c/c-typeck.c:6485
 #, fuzzy, gcc-internal-format
 msgid "enum conversion from %qT to %qT in assignment is invalid in C++"
 msgstr "%2$qE işlevinin %1$d. argümanının aktarımında gösterici hedefleri farklı sign'lıkta"
 
-#: c/c-typeck.c:6484
+#: c/c-typeck.c:6489
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "enum conversion from %qT to %qT in initialization is invalid in C++"
 msgstr "%qT %qT'ye %s içinde dönüştürülemez"
 
-#: c/c-typeck.c:6489
+#: c/c-typeck.c:6494
 #, fuzzy, gcc-internal-format
 msgid "enum conversion from %qT to %qT in return is invalid in C++"
 msgstr "%2$qE işlevinin %1$d. argümanının aktarımında gösterici hedefleri farklı sign'lıkta"
 
-#: c/c-typeck.c:6523
+#: c/c-typeck.c:6528
 #, gcc-internal-format
 msgid "cannot pass rvalue to reference parameter"
 msgstr "sağ taraf değeri, başvuru parametresine aktarılamaz"
 
-#: c/c-typeck.c:6656 c/c-typeck.c:6942
+#: c/c-typeck.c:6661 c/c-typeck.c:6947
 #, fuzzy
 msgid "passing argument %d of %qE makes %q#v qualified function pointer from unqualified"
 msgstr "%2$qE işlevinin %1$d. argümanına aktarım niteliksiz göstericiyi nitelikli yapıyor"
 
-#: c/c-typeck.c:6659 c/c-typeck.c:6945
+#: c/c-typeck.c:6664 c/c-typeck.c:6950
 #, fuzzy
 #| msgid "assignment makes qualified function pointer from unqualified"
 msgid "assignment makes %q#v qualified function pointer from unqualified"
 msgstr "atama niteliksiz işlev göstericisini nitelikli yapıyor"
 
-#: c/c-typeck.c:6662 c/c-typeck.c:6947
+#: c/c-typeck.c:6667 c/c-typeck.c:6952
 #, fuzzy
 #| msgid "initialization makes qualified function pointer from unqualified"
 msgid "initialization makes %q#v qualified function pointer from unqualified"
 msgstr "ilklendirme niteliksiz işlev göstericisini nitelikli yapıyor"
 
-#: c/c-typeck.c:6665 c/c-typeck.c:6949
+#: c/c-typeck.c:6670 c/c-typeck.c:6954
 #, fuzzy
 #| msgid "return makes qualified function pointer from unqualified"
 msgid "return makes %q#v qualified function pointer from unqualified"
 msgstr "dönüş değeri niteliksiz işlev göstericisini nitelikli yapıyor"
 
-#: c/c-typeck.c:6673 c/c-typeck.c:6840 c/c-typeck.c:6883
+#: c/c-typeck.c:6678 c/c-typeck.c:6845 c/c-typeck.c:6888
 #, fuzzy
 msgid "passing argument %d of %qE discards %qv qualifier from pointer target type"
 msgstr "%2$qE işlevinin %1$d. argümanına aktarım gösterici hedef türündeki niteleyicileri iptal ediyor"
 
-#: c/c-typeck.c:6675 c/c-typeck.c:6842 c/c-typeck.c:6885
+#: c/c-typeck.c:6680 c/c-typeck.c:6847 c/c-typeck.c:6890
 #, fuzzy
 #| msgid "assignment discards qualifiers from pointer target type"
 msgid "assignment discards %qv qualifier from pointer target type"
 msgstr "atama gösterici hedef türündeki niteleyicileri iptal ediyor"
 
-#: c/c-typeck.c:6677 c/c-typeck.c:6844 c/c-typeck.c:6887
+#: c/c-typeck.c:6682 c/c-typeck.c:6849 c/c-typeck.c:6892
 #, fuzzy
 #| msgid "initialization discards qualifiers from pointer target type"
 msgid "initialization discards %qv qualifier from pointer target type"
 msgstr "ilklendirme gösterici hedef türündeki niteleyicileri iptal ediyor"
 
-#: c/c-typeck.c:6679 c/c-typeck.c:6846 c/c-typeck.c:6889
+#: c/c-typeck.c:6684 c/c-typeck.c:6851 c/c-typeck.c:6894
 #, fuzzy
 #| msgid "return discards qualifiers from pointer target type"
 msgid "return discards %qv qualifier from pointer target type"
 msgstr "dönüş değeri gösterici hedef türündeki niteleyicileri iptal ediyor"
 
-#: c/c-typeck.c:6688
+#: c/c-typeck.c:6693
 #, gcc-internal-format
 msgid "ISO C prohibits argument conversion to union type"
 msgstr "ISO C union türe argüman dönüşümünü yasaklar"
 
-#: c/c-typeck.c:6750
+#: c/c-typeck.c:6755
 #, gcc-internal-format
 msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgstr "%qT türünden %qT türüne örtük dönüşüme C++'da izin verilmez"
 
-#: c/c-typeck.c:6762
+#: c/c-typeck.c:6767
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE from pointer to non-enclosed address space"
 msgstr "%2$qE işlevinin %1$d. argümanına uyumsuz gösterici türünde aktarım"
 
-#: c/c-typeck.c:6766
+#: c/c-typeck.c:6771
 #, fuzzy, gcc-internal-format
 #| msgid "cast from pointer to integer of different size"
 msgid "assignment from pointer to non-enclosed address space"
 msgstr "göstericiden farklı tamsayı türlere dönüşüm"
 
-#: c/c-typeck.c:6770
+#: c/c-typeck.c:6775
 #, fuzzy, gcc-internal-format
 #| msgid "initialization from incompatible pointer type"
 msgid "initialization from pointer to non-enclosed address space"
 msgstr "uyumsuz gösterici türünde ilklendirme"
 
-#: c/c-typeck.c:6774
+#: c/c-typeck.c:6779
 #, gcc-internal-format
 msgid "return from pointer to non-enclosed address space"
 msgstr ""
 
-#: c/c-typeck.c:6792
+#: c/c-typeck.c:6797
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE might be a candidate for a format attribute"
 msgstr "%2$qE işlevinin %1$d. argümanı bir biçim özniteliği adayı olabilir"
 
-#: c/c-typeck.c:6798
+#: c/c-typeck.c:6803
 #, gcc-internal-format
 msgid "assignment left-hand side might be a candidate for a format attribute"
 msgstr "atamada sol taraf bir biçim özniteliği adayı olabilir"
 
-#: c/c-typeck.c:6803
+#: c/c-typeck.c:6808
 #, gcc-internal-format
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "ilklendirmede sol taraf bir biçim özniteliği adayı olabilir"
 
-#: c/c-typeck.c:6808 cp/typeck.c:8891
+#: c/c-typeck.c:6813 cp/typeck.c:8891
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "dönüş türü bir biçim özniteliği adayı olabilir"
 
-#: c/c-typeck.c:6857
+#: c/c-typeck.c:6862
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids passing argument %d of %qE between function pointer and %<void *%>"
 msgstr "ISO C işlev göstericisi ile  %<void *%> arasında %2$qE işlevinin %1$d. argümanının  aktarımına izin vermez"
 
-#: c/c-typeck.c:6860
+#: c/c-typeck.c:6865
 #, gcc-internal-format
 msgid "ISO C forbids assignment between function pointer and %<void *%>"
 msgstr "ISO C de işlev göstericisi ile %<void *%> arasında atama yasaktır"
 
-#: c/c-typeck.c:6862
+#: c/c-typeck.c:6867
 #, gcc-internal-format
 msgid "ISO C forbids initialization between function pointer and %<void *%>"
 msgstr "ISO C de işlev göstericisi ile %<void *%> arasında ilklendirme yasaktır"
 
-#: c/c-typeck.c:6864
+#: c/c-typeck.c:6869
 #, gcc-internal-format
 msgid "ISO C forbids return between function pointer and %<void *%>"
 msgstr "ISO C de işlev göstericisi ile %<void *%> arasında return yasaktır"
 
-#: c/c-typeck.c:6904
+#: c/c-typeck.c:6909
 #, fuzzy, gcc-internal-format
 msgid "pointer targets in passing argument %d of %qE differ in signedness"
 msgstr "%2$qE işlevinin %1$d. argümanının aktarımında gösterici hedefleri farklı sign'lıkta"
 
-#: c/c-typeck.c:6913
+#: c/c-typeck.c:6918
 #, fuzzy, gcc-internal-format
 #| msgid "pointer targets in assignment differ in signedness"
 msgid "pointer targets in assignment from %qT to %qT differ in signedness"
 msgstr "atama sırasında gösterici hedefleri farklı signed'lıkta"
 
-#: c/c-typeck.c:6918
+#: c/c-typeck.c:6923
 #, fuzzy, gcc-internal-format
 #| msgid "pointer targets in initialization differ in signedness"
 msgid "pointer targets in initialization of %qT from %qT differ in signedness"
 msgstr "ilklendirmede gösterici hedefleri farklı signed'lıkta"
 
-#: c/c-typeck.c:6923
+#: c/c-typeck.c:6928
 #, fuzzy, gcc-internal-format
 msgid "pointer targets in returning %qT from a function with return type %qT differ in signedness"
 msgstr "%2$qE işlevinin %1$d. argümanının aktarımında gösterici hedefleri farklı sign'lıkta"
 
-#: c/c-typeck.c:6961
+#: c/c-typeck.c:6966
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE from incompatible pointer type"
 msgstr "%2$qE işlevinin %1$d. argümanına uyumsuz gösterici türünde aktarım"
 
-#: c/c-typeck.c:6967
+#: c/c-typeck.c:6972
 #, fuzzy, gcc-internal-format
 #| msgid "assignment from incompatible pointer type"
 msgid "assignment to %qT from incompatible pointer type %qT"
 msgstr "uyumsuz gösterici türünde atama"
 
-#: c/c-typeck.c:6972
+#: c/c-typeck.c:6977
 #, fuzzy, gcc-internal-format
 #| msgid "initialization from incompatible pointer type"
 msgid "initialization of %qT from incompatible pointer type %qT"
 msgstr "uyumsuz gösterici türünde ilklendirme"
 
-#: c/c-typeck.c:6977
+#: c/c-typeck.c:6982
 #, fuzzy, gcc-internal-format
 #| msgid "%<return%> with a value, in function returning void"
 msgid "returning %qT from a function with incompatible return type %qT"
@@ -42975,835 +43019,835 @@
 
 #. ??? This should not be an error when inlining calls to
 #. unprototyped functions.
-#: c/c-typeck.c:6991 c/c-typeck.c:7514 cp/typeck.c:2063
+#: c/c-typeck.c:6996 c/c-typeck.c:7519 cp/typeck.c:2063
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "sol değersiz dizi kullanımı geçersiz"
 
-#: c/c-typeck.c:7004
+#: c/c-typeck.c:7009
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE makes pointer from integer without a cast"
 msgstr "%2$qE işlevinin %1$d. argümanının aktarımı sırasında bir tür dönüşümü olmaksızın tamsayıdan gösterici yapılıyor"
 
-#: c/c-typeck.c:7010
+#: c/c-typeck.c:7015
 #, fuzzy, gcc-internal-format
 #| msgid "assignment makes pointer from integer without a cast"
 msgid "assignment to %qT from %qT makes pointer from integer without a cast"
 msgstr "atama bir tür dönüşümü olmaksızın tamsayıdan gösterici yapıyor"
 
-#: c/c-typeck.c:7015
+#: c/c-typeck.c:7020
 #, fuzzy, gcc-internal-format
 #| msgid "initialization makes pointer from integer without a cast"
 msgid "initialization of %qT from %qT makes pointer from integer without a cast"
 msgstr "ilklendirme bir tür dönüşümü olmaksızın tamsayıdan gösterici yapıyor"
 
-#: c/c-typeck.c:7019
+#: c/c-typeck.c:7024
 #, fuzzy, gcc-internal-format
 msgid "returning %qT from a function with return type %qT makes pointer from integer without a cast"
 msgstr "%2$qE işlevinin %1$d. argümanının aktarımı sırasında bir tür dönüşümü olmaksızın tamsayıdan gösterici yapılıyor"
 
-#: c/c-typeck.c:7035
+#: c/c-typeck.c:7040
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE makes integer from pointer without a cast"
 msgstr "%2$qE işlevinin %1$d. argümanının aktarımı sırasında bir tür dönüşümü olmaksızın göstericiden tamsayı yapılıyor"
 
-#: c/c-typeck.c:7041
+#: c/c-typeck.c:7046
 #, fuzzy, gcc-internal-format
 #| msgid "assignment makes integer from pointer without a cast"
 msgid "assignment to %qT from %qT makes integer from pointer without a cast"
 msgstr "atamada bir tür dönüşümü olmaksızın göstericiden tamsayı yapılıyor"
 
-#: c/c-typeck.c:7046
+#: c/c-typeck.c:7051
 #, fuzzy, gcc-internal-format
 #| msgid "initialization makes integer from pointer without a cast"
 msgid "initialization of %qT from %qT makes integer from pointer without a cast"
 msgstr "ilklendirmede bir tür dönüşümü olmaksızın göstericiden tamsayı yapılıyor"
 
-#: c/c-typeck.c:7050
+#: c/c-typeck.c:7055
 #, fuzzy, gcc-internal-format
 msgid "returning %qT from a function with return type %qT makes integer from pointer without a cast"
 msgstr "%2$qE işlevinin %1$d. argümanının aktarımı sırasında bir tür dönüşümü olmaksızın göstericiden tamsayı yapılıyor"
 
-#: c/c-typeck.c:7073
+#: c/c-typeck.c:7078
 #, fuzzy, gcc-internal-format
 msgid "incompatible type for argument %d of %qE"
 msgstr "%2$qE işlevinin %1$d. argümanı için tür uyumsuz"
 
-#: c/c-typeck.c:7078
+#: c/c-typeck.c:7083
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible types in assignment of %qT to %qT"
 msgid "incompatible types when assigning to type %qT from type %qT"
 msgstr "%qT'nin %qT'ye atanmasında türler uyumsuz"
 
-#: c/c-typeck.c:7083
+#: c/c-typeck.c:7088
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible types in initialization"
 msgid "incompatible types when initializing type %qT using type %qT"
 msgstr "ilklendirmede uyumsuz türler"
 
-#: c/c-typeck.c:7088
+#: c/c-typeck.c:7093
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible types in assignment of %qT to %qT"
 msgid "incompatible types when returning type %qT but %qT was expected"
 msgstr "%qT'nin %qT'ye atanmasında türler uyumsuz"
 
-#: c/c-typeck.c:7152
+#: c/c-typeck.c:7157
 #, gcc-internal-format
 msgid "traditional C rejects automatic aggregate initialization"
 msgstr "geleneksel C özdevinimli ortak değer ilklendirmesini reddeder"
 
-#: c/c-typeck.c:7388 c/c-typeck.c:8284 cp/typeck2.c:1045
+#: c/c-typeck.c:7393 c/c-typeck.c:8289 cp/typeck2.c:1045
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "esnek dizi üyesi ilklendirmesi"
 
-#: c/c-typeck.c:7398 cp/typeck2.c:1059
+#: c/c-typeck.c:7403 cp/typeck2.c:1059
 #, gcc-internal-format
 msgid "char-array initialized from wide string"
 msgstr "karakter dizisinin ilklendiricisi olarak geniş dizge kullanılmış"
 
-#: c/c-typeck.c:7407
+#: c/c-typeck.c:7412
 #, fuzzy, gcc-internal-format
 #| msgid "wchar_t-array initialized from non-wide string"
 msgid "wide character array initialized from non-wide string"
 msgstr "geniş karakterli olmayan dizgeden ilklendirmeli wchar_t-array"
 
-#: c/c-typeck.c:7413
+#: c/c-typeck.c:7418
 #, fuzzy, gcc-internal-format
 #| msgid "wchar_t-array initialized from non-wide string"
 msgid "wide character array initialized from incompatible wide string"
 msgstr "geniş karakterli olmayan dizgeden ilklendirmeli wchar_t-array"
 
-#: c/c-typeck.c:7446
+#: c/c-typeck.c:7451
 #, gcc-internal-format
 msgid "array of inappropriate type initialized from string constant"
 msgstr "dizge sabitten ilgisiz türde ilklendirilmiş dizi"
 
-#: c/c-typeck.c:7533 c/c-typeck.c:7557 c/c-typeck.c:7560 c/c-typeck.c:7568
-#: c/c-typeck.c:7608 c/c-typeck.c:9131 c/c-typeck.c:9181
+#: c/c-typeck.c:7538 c/c-typeck.c:7562 c/c-typeck.c:7565 c/c-typeck.c:7573
+#: c/c-typeck.c:7613 c/c-typeck.c:9136 c/c-typeck.c:9186
 #, gcc-internal-format
 msgid "initializer element is not constant"
 msgstr "ilklendirici öğe bir sabit değil"
 
-#: c/c-typeck.c:7542
+#: c/c-typeck.c:7547
 #, gcc-internal-format
 msgid "array initialized from non-constant array expression"
 msgstr "dizi sabit olmayan dizi ifadesinden ilklendirilmiş"
 
-#: c/c-typeck.c:7573 c/c-typeck.c:7621 c/c-typeck.c:9191
+#: c/c-typeck.c:7578 c/c-typeck.c:7626 c/c-typeck.c:9196
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not constant"
 msgid "initializer element is not a constant expression"
 msgstr "ilklendirici öğe bir sabit değil"
 
-#: c/c-typeck.c:7615 c/c-typeck.c:9186
+#: c/c-typeck.c:7620 c/c-typeck.c:9191
 #, gcc-internal-format
 msgid "initializer element is not computable at load time"
 msgstr "ilkledirici öğe yükleme sırasında hesaplanabilir değil"
 
-#: c/c-typeck.c:7634
+#: c/c-typeck.c:7639
 #, gcc-internal-format
 msgid "invalid initializer"
 msgstr "geçersiz ilklendirici"
 
-#: c/c-typeck.c:7912 cp/decl.c:6396
+#: c/c-typeck.c:7917 cp/decl.c:6396
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "opak vektör türleri ilklendirilemez"
 
-#: c/c-typeck.c:8132
+#: c/c-typeck.c:8137
 #, gcc-internal-format
 msgid "extra brace group at end of initializer"
 msgstr "ilklendiricinin sonunda fazladan parantezli grup"
 
-#: c/c-typeck.c:8215
+#: c/c-typeck.c:8220
 #, gcc-internal-format
 msgid "braces around scalar initializer"
 msgstr "skalar ilklendiriciyi kuşatan parantezler"
 
-#: c/c-typeck.c:8281 c/c-typeck.c:9615 cp/typeck2.c:1084 cp/typeck2.c:1297
+#: c/c-typeck.c:8286 c/c-typeck.c:9620 cp/typeck2.c:1084 cp/typeck2.c:1297
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "iç içe bağlam içinde esnek dizi üyesi ilklendirmesi"
 
-#: c/c-typeck.c:8318
+#: c/c-typeck.c:8323
 #, gcc-internal-format
 msgid "missing braces around initializer"
 msgstr "ilklendiriciyi çevreleyen parantezler yok"
 
-#: c/c-typeck.c:8341
+#: c/c-typeck.c:8346
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "missing initializer for field %qD of %qT"
 msgstr "uye %qD için ilklendirici eksik"
 
-#: c/c-typeck.c:8365
+#: c/c-typeck.c:8370
 #, gcc-internal-format
 msgid "empty scalar initializer"
 msgstr "skalar ilklendirici boş"
 
-#: c/c-typeck.c:8370
+#: c/c-typeck.c:8375
 #, gcc-internal-format
 msgid "extra elements in scalar initializer"
 msgstr "skalar ilklendiricide fazladan öğeler"
 
-#: c/c-typeck.c:8483 c/c-typeck.c:8565
+#: c/c-typeck.c:8488 c/c-typeck.c:8570
 #, gcc-internal-format
 msgid "array index in non-array initializer"
 msgstr "dizi olmayan ilklendiricide dizi indisi"
 
-#: c/c-typeck.c:8488 c/c-typeck.c:8627
+#: c/c-typeck.c:8493 c/c-typeck.c:8632
 #, gcc-internal-format
 msgid "field name not in record or union initializer"
 msgstr "alan ismi kayıt ya da union ilklendiricisinde kullanılmamış"
 
-#: c/c-typeck.c:8538
+#: c/c-typeck.c:8543
 #, gcc-internal-format
 msgid "array index in initializer not of integer type"
 msgstr "ilklendiricideki dizi indisi tamsayı türünde değil"
 
-#: c/c-typeck.c:8547 c/c-typeck.c:8556
+#: c/c-typeck.c:8552 c/c-typeck.c:8561
 #, fuzzy, gcc-internal-format
 #| msgid "array index in initializer not of integer type"
 msgid "array index in initializer is not an integer constant expression"
 msgstr "ilklendiricideki dizi indisi tamsayı türünde değil"
 
-#: c/c-typeck.c:8561 c/c-typeck.c:8563
+#: c/c-typeck.c:8566 c/c-typeck.c:8568
 #, gcc-internal-format
 msgid "nonconstant array index in initializer"
 msgstr "ilklendiricide sabit olmayan dizi indisi"
 
-#: c/c-typeck.c:8567 c/c-typeck.c:8570
+#: c/c-typeck.c:8572 c/c-typeck.c:8575
 #, gcc-internal-format
 msgid "array index in initializer exceeds array bounds"
 msgstr "ilklendiricideki dizi indisi dizi sınırlarının dışında"
 
-#: c/c-typeck.c:8589
+#: c/c-typeck.c:8594
 #, gcc-internal-format
 msgid "empty index range in initializer"
 msgstr "ilklendiricide indis aralığı boş"
 
-#: c/c-typeck.c:8598
+#: c/c-typeck.c:8603
 #, gcc-internal-format
 msgid "array index range in initializer exceeds array bounds"
 msgstr "ilklendiricideki dizi indisi aralığı dizi sınırlarını aşıyor"
 
-#: c/c-typeck.c:8700 c/c-typeck.c:8730 c/c-typeck.c:9274
+#: c/c-typeck.c:8705 c/c-typeck.c:8735 c/c-typeck.c:9279
 #, gcc-internal-format
 msgid "initialized field with side-effects overwritten"
 msgstr "yan etkili ilklendirilmiş alanın üzerine yazıldı"
 
-#: c/c-typeck.c:8704 c/c-typeck.c:8734 c/c-typeck.c:9277
+#: c/c-typeck.c:8709 c/c-typeck.c:8739 c/c-typeck.c:9282
 #, fuzzy, gcc-internal-format
 #| msgid "initialized field with side-effects overwritten"
 msgid "initialized field overwritten"
 msgstr "yan etkili ilklendirilmiş alanın üzerine yazıldı"
 
-#: c/c-typeck.c:9208
+#: c/c-typeck.c:9213
 #, gcc-internal-format
 msgid "enum conversion in initialization is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:9496
+#: c/c-typeck.c:9501
 #, gcc-internal-format
 msgid "excess elements in char array initializer"
 msgstr "karakter dizisi ilklendiricide gereğinden fazla öğe"
 
-#: c/c-typeck.c:9503 c/c-typeck.c:9574
+#: c/c-typeck.c:9508 c/c-typeck.c:9579
 #, gcc-internal-format
 msgid "excess elements in struct initializer"
 msgstr "struct ilklendiricide gereğinden fazla öğe"
 
-#: c/c-typeck.c:9518
+#: c/c-typeck.c:9523
 #, gcc-internal-format
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr ""
 
-#: c/c-typeck.c:9589
+#: c/c-typeck.c:9594
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr "esnek dizi üyesinin statik olmayan ilklendirmesi"
 
-#: c/c-typeck.c:9687
+#: c/c-typeck.c:9692
 #, gcc-internal-format
 msgid "excess elements in union initializer"
 msgstr "union ilklendiricide gereğinden fazla öğe"
 
-#: c/c-typeck.c:9709
+#: c/c-typeck.c:9714
 #, gcc-internal-format
 msgid "traditional C rejects initialization of unions"
 msgstr "geleneksel C union ilklendirmesini reddeder"
 
-#: c/c-typeck.c:9777
+#: c/c-typeck.c:9782
 #, gcc-internal-format
 msgid "excess elements in array initializer"
 msgstr "dizi ilklendiricide gereğinden fazla öğe"
 
-#: c/c-typeck.c:9811
+#: c/c-typeck.c:9816
 #, gcc-internal-format
 msgid "excess elements in vector initializer"
 msgstr "vektör ilklendiricide gereğinden fazla öğe"
 
-#: c/c-typeck.c:9843
+#: c/c-typeck.c:9848
 #, gcc-internal-format
 msgid "excess elements in scalar initializer"
 msgstr "skalar ilklendiricide gereğinden fazla öğe"
 
-#: c/c-typeck.c:10086
+#: c/c-typeck.c:10091
 #, gcc-internal-format
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C %<goto *expr;%> kullanımına izin vermez"
 
-#: c/c-typeck.c:10113 c/gimple-parser.c:1604 cp/typeck.c:9113
+#: c/c-typeck.c:10118 c/gimple-parser.c:1604 cp/typeck.c:9113
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "%<noreturn%> olarak bildirilmiş işlev %<return%> deyimi içeriyor"
 
-#: c/c-typeck.c:10139 c/c-typeck.c:10143
+#: c/c-typeck.c:10144 c/c-typeck.c:10148
 #, gcc-internal-format
 msgid "%<return%> with no value, in function returning non-void"
 msgstr "dönüş değeri void olmayan işlevde %<return%> değer içermiyor"
 
-#: c/c-typeck.c:10157 c/gimple-parser.c:1614
+#: c/c-typeck.c:10162 c/gimple-parser.c:1614
 #, gcc-internal-format
 msgid "%<return%> with a value, in function returning void"
 msgstr "void dönüşlü işlevde %<return%> değer içeriyor"
 
-#: c/c-typeck.c:10160
+#: c/c-typeck.c:10165
 #, fuzzy, gcc-internal-format
 #| msgid "%<return%> with a value, in function returning void"
 msgid "ISO C forbids %<return%> with expression, in function returning void"
 msgstr "void dönüşlü işlevde %<return%> değer içeriyor"
 
-#: c/c-typeck.c:10236
+#: c/c-typeck.c:10241
 #, fuzzy, gcc-internal-format
 #| msgid "function returns address of local variable"
 msgid "function returns address of label"
 msgstr "işlev yerel değişkenin adresi ile dönüyor"
 
-#: c/c-typeck.c:10327 cp/semantics.c:1171
+#: c/c-typeck.c:10332 cp/semantics.c:1171
 #, gcc-internal-format
 msgid "switch quantity not an integer"
 msgstr "switch miktarı bir tamsayı değil"
 
-#: c/c-typeck.c:10352
+#: c/c-typeck.c:10357
 #, gcc-internal-format
 msgid "%<long%> switch expression not converted to %<int%> in ISO C"
 msgstr "ISO C'de %<long%> switch ifadesi %<int%> türüne dönüştürülmez"
 
-#: c/c-typeck.c:10390 c/c-typeck.c:10398
+#: c/c-typeck.c:10395 c/c-typeck.c:10403
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "case label is not an integer constant expression"
 msgstr "dizi boyutu bir tümleyen sabit ifadesi değil"
 
-#: c/c-typeck.c:10404 cp/parser.c:11067
+#: c/c-typeck.c:10409 cp/parser.c:11067
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "case etiketi bir switch deyimi içinde değil"
 
-#: c/c-typeck.c:10406
+#: c/c-typeck.c:10411
 #, gcc-internal-format
 msgid "%<default%> label not within a switch statement"
 msgstr "%<default%> etiketi bir switch deyimi içinde değil"
 
-#: c/c-typeck.c:10578 cp/parser.c:12356
+#: c/c-typeck.c:10583 cp/parser.c:12353
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "break deyimi switch ya da döngü içinde değil"
 
-#: c/c-typeck.c:10580 cp/parser.c:12379
+#: c/c-typeck.c:10585 cp/parser.c:12376
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "continue deyimi bir döngü içinde değil"
 
-#: c/c-typeck.c:10585 cp/parser.c:12369
+#: c/c-typeck.c:10590 cp/parser.c:12366
 #, fuzzy, gcc-internal-format
 #| msgid "break statement not within loop or switch"
 msgid "break statement used with OpenMP for loop"
 msgstr "break deyimi switch ya da döngü içinde değil"
 
-#: c/c-typeck.c:10590
+#: c/c-typeck.c:10595
 #, fuzzy, gcc-internal-format
 #| msgid "break statement not within loop or switch"
 msgid "break statement within %<#pragma simd%> loop body"
 msgstr "break deyimi switch ya da döngü içinde değil"
 
-#: c/c-typeck.c:10592
+#: c/c-typeck.c:10597
 #, fuzzy, gcc-internal-format
 #| msgid "continue statement not within a loop"
 msgid "continue statement within %<#pragma simd%> loop body"
 msgstr "continue deyimi bir döngü içinde değil"
 
-#: c/c-typeck.c:10618 cp/cp-gimplify.c:432
+#: c/c-typeck.c:10623 cp/cp-gimplify.c:432
 #, gcc-internal-format
 msgid "statement with no effect"
 msgstr "deyim etkisiz"
 
-#: c/c-typeck.c:10662
+#: c/c-typeck.c:10667
 #, gcc-internal-format
 msgid "expression statement has incomplete type"
 msgstr "ifade deyimi boş tür içeriyor"
 
-#: c/c-typeck.c:11476 c/c-typeck.c:11644 cp/typeck.c:5017
+#: c/c-typeck.c:11481 c/c-typeck.c:11649 cp/typeck.c:5017
 #, fuzzy, gcc-internal-format
 #| msgid "operands to ?: have different types"
 msgid "comparing vectors with different element types"
 msgstr "?: için terimler farklı türde"
 
-#: c/c-typeck.c:11484 c/c-typeck.c:11652 cp/typeck.c:5030
+#: c/c-typeck.c:11489 c/c-typeck.c:11657 cp/typeck.c:5030
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr ""
 
-#: c/c-typeck.c:11509 c/c-typeck.c:11677 cp/typeck.c:5058
+#: c/c-typeck.c:11514 c/c-typeck.c:11682 cp/typeck.c:5058
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr ""
 
-#: c/c-typeck.c:11523 cp/typeck.c:4743
+#: c/c-typeck.c:11528 cp/typeck.c:4743
 #, gcc-internal-format
 msgid "comparing floating point with == or != is unsafe"
 msgstr "== veya != ile karşılaştırma gerçel sayılarda güvenli değil"
 
-#: c/c-typeck.c:11541 c/c-typeck.c:11562
+#: c/c-typeck.c:11546 c/c-typeck.c:11567
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<false%> for the address of %qD will never be NULL"
 msgstr ""
 
-#: c/c-typeck.c:11547 c/c-typeck.c:11568
+#: c/c-typeck.c:11552 c/c-typeck.c:11573
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<true%> for the address of %qD will never be NULL"
 msgstr ""
 
-#: c/c-typeck.c:11589 c/c-typeck.c:11718
+#: c/c-typeck.c:11594 c/c-typeck.c:11723
 #, fuzzy, gcc-internal-format
 #| msgid "comparison of distinct pointer types lacks a cast"
 msgid "comparison of pointers to disjoint address spaces"
 msgstr "bir tür dönüşümü olmaksızın ayrı gösterici türlerinin karşılaştırması"
 
-#: c/c-typeck.c:11596 c/c-typeck.c:11602
+#: c/c-typeck.c:11601 c/c-typeck.c:11607
 #, gcc-internal-format
 msgid "ISO C forbids comparison of %<void *%> with function pointer"
 msgstr "ISO C %<void *%> ile işlev göstericisinin karşılaştırılmasına izin vermez"
 
-#: c/c-typeck.c:11609 c/c-typeck.c:11728
+#: c/c-typeck.c:11614 c/c-typeck.c:11733
 #, gcc-internal-format
 msgid "comparison of distinct pointer types lacks a cast"
 msgstr "bir tür dönüşümü olmaksızın ayrı gösterici türlerinin karşılaştırması"
 
-#: c/c-typeck.c:11621 c/c-typeck.c:11626 c/c-typeck.c:11754 c/c-typeck.c:11759
+#: c/c-typeck.c:11626 c/c-typeck.c:11631 c/c-typeck.c:11759 c/c-typeck.c:11764
 #, gcc-internal-format
 msgid "comparison between pointer and integer"
 msgstr "gösterici ile tamsayı arasında karşılaştırma"
 
-#: c/c-typeck.c:11706
+#: c/c-typeck.c:11711
 #, gcc-internal-format
 msgid "comparison of complete and incomplete pointers"
 msgstr "tamamlanmış ve içi boş göstericilerin karşılaştırılması"
 
-#: c/c-typeck.c:11708
+#: c/c-typeck.c:11713
 #, gcc-internal-format
 msgid "ISO C forbids ordered comparisons of pointers to functions"
 msgstr "ISO C işlev göstericilerinin sıralı karşılaştırmalarına izin vermez"
 
-#: c/c-typeck.c:11713
+#: c/c-typeck.c:11718
 #, fuzzy, gcc-internal-format
 #| msgid "ordered comparison of pointer with integer zero"
 msgid "ordered comparison of pointer with null pointer"
 msgstr "tamsayı sıfır ile sıralı gösterici karşılaştırması"
 
-#: c/c-typeck.c:11736 c/c-typeck.c:11739 c/c-typeck.c:11746 c/c-typeck.c:11749
+#: c/c-typeck.c:11741 c/c-typeck.c:11744 c/c-typeck.c:11751 c/c-typeck.c:11754
 #: cp/typeck.c:5081 cp/typeck.c:5088
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "tamsayı sıfır ile sıralı gösterici karşılaştırması"
 
-#: c/c-typeck.c:11811
+#: c/c-typeck.c:11816
 #, fuzzy, gcc-internal-format
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
 msgstr "%qT türünden %qT türüne örtük dönüşüme C++'da izin verilmez"
 
-#: c/c-typeck.c:12126
+#: c/c-typeck.c:12131
 #, gcc-internal-format
 msgid "used array that cannot be converted to pointer where scalar is required"
 msgstr "doğrudan değer gereken yerde göstericiye dönüştürülemeyen dizi kullanılmış"
 
-#: c/c-typeck.c:12130
+#: c/c-typeck.c:12135
 #, gcc-internal-format
 msgid "used struct type value where scalar is required"
 msgstr "doğrudan değer gereken yerde yapı türünde değer kullanılmış"
 
-#: c/c-typeck.c:12134
+#: c/c-typeck.c:12139
 #, gcc-internal-format
 msgid "used union type value where scalar is required"
 msgstr "doğrudan değer gereken yerde union türünde değer kullanılmış"
 
-#: c/c-typeck.c:12150
+#: c/c-typeck.c:12155
 #, fuzzy, gcc-internal-format
 #| msgid "used struct type value where scalar is required"
 msgid "used vector type where scalar is required"
 msgstr "doğrudan değer gereken yerde yapı türünde değer kullanılmış"
 
-#: c/c-typeck.c:12340 cp/semantics.c:8508
+#: c/c-typeck.c:12345 cp/semantics.c:8511
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12379 cp/semantics.c:8545
+#: c/c-typeck.c:12384 cp/semantics.c:8548
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12423 c/c-typeck.c:13581 c/c-typeck.c:13642 c/c-typeck.c:13704
+#: c/c-typeck.c:12428 c/c-typeck.c:13586 c/c-typeck.c:13647 c/c-typeck.c:13709
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "girdi dosyası sayısı çok fazla"
 
-#: c/c-typeck.c:12436 c/c-typeck.c:13628 cp/semantics.c:4546
-#: cp/semantics.c:6717
+#: c/c-typeck.c:12441 c/c-typeck.c:13633 cp/semantics.c:4549
+#: cp/semantics.c:6720
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qs has invalid type"
 msgid "bit-field %qE in %qs clause"
 msgstr "%qs bit alanı geçersiz tür içeriyor"
 
-#: c/c-typeck.c:12445 c/c-typeck.c:13652 cp/semantics.c:4556
-#: cp/semantics.c:6735
+#: c/c-typeck.c:12450 c/c-typeck.c:13657 cp/semantics.c:4559
+#: cp/semantics.c:6738
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qE is a member of a union"
 msgstr "%qD bir üye şablon işlevi değil"
 
-#: c/c-typeck.c:12455 cp/semantics.c:4570 cp/semantics.c:6760
+#: c/c-typeck.c:12460 cp/semantics.c:4573 cp/semantics.c:6763
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must not have variable number of arguments"
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD değişken sayıda argümana sahip olmamalı"
 
-#: c/c-typeck.c:12459 c/c-typeck.c:13669 cp/semantics.c:4574
-#: cp/semantics.c:6763
+#: c/c-typeck.c:12464 c/c-typeck.c:13674 cp/semantics.c:4577
+#: cp/semantics.c:6766
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' is not a valid class name"
 msgid "%qE is not a variable in %qs clause"
 msgstr "'%s' geçerli bir sınıf ismi değil"
 
-#: c/c-typeck.c:12466
+#: c/c-typeck.c:12471
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "%<_Atomic%> %qD in %qs clause"
 msgstr "girdi dosyası sayısı çok fazla"
 
-#: c/c-typeck.c:12475 c/c-typeck.c:13676 c/c-typeck.c:13778
-#: cp/semantics.c:4591 cp/semantics.c:6769 cp/semantics.c:6931
+#: c/c-typeck.c:12480 c/c-typeck.c:13681 c/c-typeck.c:13783
+#: cp/semantics.c:4594 cp/semantics.c:6772 cp/semantics.c:6934
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must not have variable number of arguments"
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD değişken sayıda argümana sahip olmamalı"
 
-#: c/c-typeck.c:12511 cp/semantics.c:4623
+#: c/c-typeck.c:12516 cp/semantics.c:4626
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "low bound %qE of array section does not have integral type"
 msgstr "array new içindeki boyut bütünleyici türde olmalı"
 
-#: c/c-typeck.c:12518 cp/semantics.c:4630
+#: c/c-typeck.c:12523 cp/semantics.c:4633
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "length %qE of array section does not have integral type"
 msgstr "array new içindeki boyut bütünleyici türde olmalı"
 
-#: c/c-typeck.c:12545 c/c-typeck.c:12609 c/c-typeck.c:12867
-#: cp/semantics.c:4666 cp/semantics.c:4730
+#: c/c-typeck.c:12550 c/c-typeck.c:12614 c/c-typeck.c:12872
+#: cp/semantics.c:4669 cp/semantics.c:4733
 #, fuzzy, gcc-internal-format
 #| msgid "Copy array sections into a contiguous block on procedure entry"
 msgid "zero length array section in %qs clause"
 msgstr "Dizi bölümlerini yordam girdisinde sürekli bir blokun içine kopyalar"
 
-#: c/c-typeck.c:12564 cp/semantics.c:4685
+#: c/c-typeck.c:12569 cp/semantics.c:4688
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12572 cp/semantics.c:4693
+#: c/c-typeck.c:12577 cp/semantics.c:4696
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12581 c/c-typeck.c:12691 cp/semantics.c:4702
-#: cp/semantics.c:4812
+#: c/c-typeck.c:12586 c/c-typeck.c:12696 cp/semantics.c:4705
+#: cp/semantics.c:4815
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12598 cp/semantics.c:4719
+#: c/c-typeck.c:12603 cp/semantics.c:4722
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12635 cp/semantics.c:4756
+#: c/c-typeck.c:12640 cp/semantics.c:4759
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12650 cp/semantics.c:4771
+#: c/c-typeck.c:12655 cp/semantics.c:4774
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12683 cp/semantics.c:4804
+#: c/c-typeck.c:12688 cp/semantics.c:4807
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12701 c/c-typeck.c:12810 cp/semantics.c:4822
-#: cp/semantics.c:4934
+#: c/c-typeck.c:12706 c/c-typeck.c:12815 cp/semantics.c:4825
+#: cp/semantics.c:4937
 #, fuzzy, gcc-internal-format
 #| msgid "Copy array sections into a contiguous block on procedure entry"
 msgid "array section is not contiguous in %qs clause"
 msgstr "Dizi bölümlerini yordam girdisinde sürekli bir blokun içine kopyalar"
 
-#: c/c-typeck.c:12709 cp/semantics.c:4830
+#: c/c-typeck.c:12714 cp/semantics.c:4833
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not have class type"
 msgid "%qE does not have pointer or array type"
 msgstr "%qE sınıf türüne sahip değil"
 
-#: c/c-typeck.c:13103 c/c-typeck.c:13113
+#: c/c-typeck.c:13108 c/c-typeck.c:13118
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qD in %<reduction%> clause is a zero size array"
 msgstr "vektör silme işlemi için tür ne gösterici ne de dizi"
 
-#: c/c-typeck.c:13130
+#: c/c-typeck.c:13135
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids qualified function types"
 msgid "%<_Atomic%> %qE in %<reduction%> clause"
 msgstr "ISO C nitelikli işlev türlerini yasaklar"
 
-#: c/c-typeck.c:13178
+#: c/c-typeck.c:13183
 #, gcc-internal-format
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr ""
 
-#: c/c-typeck.c:13187 cp/semantics.c:5755
+#: c/c-typeck.c:13192 cp/semantics.c:5758
 #, fuzzy, gcc-internal-format
 #| msgid "reference to %qD is ambiguous"
 msgid "user defined reduction not found for %qE"
 msgstr "%qD ile ilişkilendirme belirsiz"
 
-#: c/c-typeck.c:13275
+#: c/c-typeck.c:13280
 #, gcc-internal-format
 msgid "variable length element type in array %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13293 c/c-typeck.c:13836 cp/semantics.c:7249
+#: c/c-typeck.c:13298 c/c-typeck.c:13841 cp/semantics.c:7252
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13305 cp/semantics.c:7289
+#: c/c-typeck.c:13310 cp/semantics.c:7292
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr ""
 
-#: c/c-typeck.c:13319 cp/semantics.c:5929
+#: c/c-typeck.c:13324 cp/semantics.c:5932
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr ""
 
-#: c/c-typeck.c:13327
+#: c/c-typeck.c:13332
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with type %qT"
 msgstr ""
 
-#: c/c-typeck.c:13335
+#: c/c-typeck.c:13340
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13354 cp/semantics.c:5999
+#: c/c-typeck.c:13359 cp/semantics.c:6002
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr "vektör silme işlemi için tür ne gösterici ne de dizi"
 
-#: c/c-typeck.c:13384 c/c-typeck.c:13771 cp/semantics.c:6083
-#: cp/semantics.c:6924
+#: c/c-typeck.c:13389 c/c-typeck.c:13776 cp/semantics.c:6086
+#: cp/semantics.c:6927
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not an accessible base of %qT"
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qT erişilebilir bir %qT tabanı değil"
 
-#: c/c-typeck.c:13393 cp/semantics.c:6092
+#: c/c-typeck.c:13398 cp/semantics.c:6095
 #, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr ""
 
-#: c/c-typeck.c:13404 c/c-typeck.c:13434 c/c-typeck.c:13463
+#: c/c-typeck.c:13409 c/c-typeck.c:13439 c/c-typeck.c:13468
 #, gcc-internal-format
 msgid "%qE appears more than once in data clauses"
 msgstr ""
 
-#: c/c-typeck.c:13411 c/c-typeck.c:13440 c/c-typeck.c:13600 c/c-typeck.c:13714
-#: c/c-typeck.c:13720 c/c-typeck.c:13733 c/c-typeck.c:13742
-#: cp/semantics.c:6102 cp/semantics.c:6109 cp/semantics.c:6160
-#: cp/semantics.c:6166 cp/semantics.c:6203 cp/semantics.c:6680
-#: cp/semantics.c:6817 cp/semantics.c:6823 cp/semantics.c:6836
-#: cp/semantics.c:6845
+#: c/c-typeck.c:13416 c/c-typeck.c:13445 c/c-typeck.c:13605 c/c-typeck.c:13719
+#: c/c-typeck.c:13725 c/c-typeck.c:13738 c/c-typeck.c:13747
+#: cp/semantics.c:6105 cp/semantics.c:6112 cp/semantics.c:6163
+#: cp/semantics.c:6169 cp/semantics.c:6206 cp/semantics.c:6683
+#: cp/semantics.c:6820 cp/semantics.c:6826 cp/semantics.c:6839
+#: cp/semantics.c:6848
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
-#: c/c-typeck.c:13413 c/c-typeck.c:13442 c/c-typeck.c:13722 c/c-typeck.c:13744
-#: cp/semantics.c:6111 cp/semantics.c:6168 cp/semantics.c:6825
-#: cp/semantics.c:6847
+#: c/c-typeck.c:13418 c/c-typeck.c:13447 c/c-typeck.c:13727 c/c-typeck.c:13749
+#: cp/semantics.c:6114 cp/semantics.c:6171 cp/semantics.c:6828
+#: cp/semantics.c:6850
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr ""
 
-#: c/c-typeck.c:13427 cp/semantics.c:6154
+#: c/c-typeck.c:13432 cp/semantics.c:6157
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: c/c-typeck.c:13456 cp/semantics.c:6197
+#: c/c-typeck.c:13461 cp/semantics.c:6200
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: c/c-typeck.c:13475 cp/semantics.c:6545
+#: c/c-typeck.c:13480 cp/semantics.c:6548
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' is not a valid class name"
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "'%s' geçerli bir sınıf ismi değil"
 
-#: c/c-typeck.c:13482
+#: c/c-typeck.c:13487
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array"
 msgstr "vektör silme işlemi için tür ne gösterici ne de dizi"
 
-#: c/c-typeck.c:13489
+#: c/c-typeck.c:13494
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must not have variable number of arguments"
 msgid "%<_Atomic%> %qD in %<aligned%> clause"
 msgstr "%qD değişken sayıda argümana sahip olmamalı"
 
-#: c/c-typeck.c:13496
+#: c/c-typeck.c:13501
 #, gcc-internal-format
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:13551 cp/semantics.c:6627
+#: c/c-typeck.c:13556 cp/semantics.c:6630
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' is not a valid class name"
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr "'%s' geçerli bir sınıf ismi değil"
 
-#: c/c-typeck.c:13573 cp/semantics.c:6658
+#: c/c-typeck.c:13578 cp/semantics.c:6661
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13597 c/c-typeck.c:13731 cp/semantics.c:6677
-#: cp/semantics.c:6834
+#: c/c-typeck.c:13602 c/c-typeck.c:13736 cp/semantics.c:6680
+#: cp/semantics.c:6837
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr ""
 
-#: c/c-typeck.c:13603 c/c-typeck.c:13735 cp/semantics.c:6683
-#: cp/semantics.c:6838
+#: c/c-typeck.c:13608 c/c-typeck.c:13740 cp/semantics.c:6686
+#: cp/semantics.c:6841
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr ""
 
-#: c/c-typeck.c:13635 cp/semantics.c:6724
+#: c/c-typeck.c:13640 cp/semantics.c:6727
 #, fuzzy, gcc-internal-format
 #| msgid "%qD does not declare a template type"
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qD bir şablon türü bildirmiyor"
 
-#: c/c-typeck.c:13695 c/c-typeck.c:13785 cp/semantics.c:6799
-#: cp/semantics.c:6938
+#: c/c-typeck.c:13700 c/c-typeck.c:13790 cp/semantics.c:6802
+#: cp/semantics.c:6941
 #, fuzzy, gcc-internal-format
 #| msgid "%qD does not declare a template type"
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD bir şablon türü bildirmiyor"
 
-#: c/c-typeck.c:13766 cp/semantics.c:6918
+#: c/c-typeck.c:13771 cp/semantics.c:6921
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not an accessible base of %qT"
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qT erişilebilir bir %qT tabanı değil"
 
-#: c/c-typeck.c:13794 cp/semantics.c:6947
+#: c/c-typeck.c:13799 cp/semantics.c:6950
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr ""
 
-#: c/c-typeck.c:13808 cp/semantics.c:6962
+#: c/c-typeck.c:13813 cp/semantics.c:6965
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD bir işlev şablonu değil"
 
-#: c/c-typeck.c:13811 cp/semantics.c:6964
+#: c/c-typeck.c:13816 cp/semantics.c:6967
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13826
+#: c/c-typeck.c:13831
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "vektör silme işlemi için tür ne gösterici ne de dizi"
 
-#: c/c-typeck.c:13900 cp/semantics.c:6359
+#: c/c-typeck.c:13905 cp/semantics.c:6362
 #, gcc-internal-format
 msgid "%<nonmonotonic%> modifier specified for %qs schedule kind"
 msgstr ""
 
-#: c/c-typeck.c:13931 cp/semantics.c:7141
+#: c/c-typeck.c:13936 cp/semantics.c:7144
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:13981 cp/semantics.c:7332
+#: c/c-typeck.c:13986 cp/semantics.c:7335
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr ""
 
-#: c/c-typeck.c:14001 cp/semantics.c:7223
+#: c/c-typeck.c:14006 cp/semantics.c:7226
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:14013 cp/semantics.c:7236
+#: c/c-typeck.c:14018 cp/semantics.c:7239
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14031 cp/semantics.c:7203
+#: c/c-typeck.c:14036 cp/semantics.c:7206
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14204
+#: c/c-typeck.c:14209
 #, gcc-internal-format
 msgid "cannot use %<va_arg%> with reverse storage order"
 msgstr ""
 
-#: c/c-typeck.c:14209
+#: c/c-typeck.c:14214
 #, fuzzy, gcc-internal-format
 #| msgid "first argument to %<va_arg%> not of type %<va_list%>"
 msgid "second argument to %<va_arg%> is of incomplete type %qT"
 msgstr "%<va_arg%>'ın ilk argümanının türü %<va_list%> değil"
 
-#: c/c-typeck.c:14215
+#: c/c-typeck.c:14220
 #, gcc-internal-format
 msgid "C++ requires promoted type, not enum type, in %<va_arg%>"
 msgstr ""
@@ -43937,7 +43981,7 @@
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "  %qT türünden %qT türüne dönüşüm için seçiliyor,"
 
-#: cp/call.c:3441 cp/pt.c:6495
+#: cp/call.c:3441 cp/pt.c:6509
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -44253,7 +44297,7 @@
 msgid "%q#D is private within this context"
 msgstr "bu bağlamda"
 
-#: cp/call.c:6478 cp/decl.c:7343
+#: cp/call.c:6478 cp/decl.c:7364
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "declared private here"
@@ -44265,7 +44309,7 @@
 msgid "%q#D is protected within this context"
 msgstr "bu bağlamda"
 
-#: cp/call.c:6486 cp/decl.c:7344
+#: cp/call.c:6486 cp/decl.c:7365
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "declared protected here"
@@ -44598,7 +44642,7 @@
 msgid "call to non-function %qD"
 msgstr "işlev olmayan %qD ye çağrı"
 
-#: cp/call.c:9119 cp/pt.c:15053 cp/typeck.c:2901
+#: cp/call.c:9119 cp/pt.c:15075 cp/typeck.c:2901
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
@@ -44837,282 +44881,282 @@
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr "taban %qT türünden türetilmiş %qT türüne dönüşüm sanal taban %qT üzerinden yapılamaz"
 
-#: cp/class.c:2098
+#: cp/class.c:2103
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr "sınıf %qT içindeki tüm üye işlevler 'private'"
 
-#: cp/class.c:2110
+#: cp/class.c:2115
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr "%q#T sadece private bir yıkıcı tanımlıyor ve kardeşleri yok"
 
-#: cp/class.c:2152
+#: cp/class.c:2156
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr "%q#T sadece private kurucular tanımlıyor ve kardeşleri yok"
 
-#: cp/class.c:2156
+#: cp/class.c:2160
 #, gcc-internal-format
 msgid "%q#D is public, but requires an existing %q#T object"
 msgstr ""
 
-#: cp/class.c:2430
+#: cp/class.c:2434
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr "%qD için %qT içinde eşsiz bir son değiştirici yok"
 
-#: cp/class.c:2785
+#: cp/class.c:2789
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D cannot be overloaded"
 msgid "%qD can be marked override"
 msgstr "%q+#D,"
 
-#: cp/class.c:2797
+#: cp/class.c:2801
 #, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr ""
 
-#: cp/class.c:2799
+#: cp/class.c:2803
 #, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr ""
 
-#: cp/class.c:2861
+#: cp/class.c:2865
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was hidden"
 msgid "%qD was hidden"
 msgstr "%q+D"
 
-#: cp/class.c:2863
+#: cp/class.c:2867
 #, fuzzy, gcc-internal-format
 #| msgid "  by %q+D"
 msgid "  by %qD"
 msgstr "  %q+D tarafından gizlendi"
 
-#: cp/class.c:2896
+#: cp/class.c:2900
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D invalid; an anonymous union can only have non-static data members"
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "%q+#D geçersiz; bir anonim union sadece statik olmayan veri üyeleri içerebilir"
 
-#: cp/class.c:2906 cp/name-lookup.c:3293 cp/parser.c:19720
+#: cp/class.c:2910 cp/name-lookup.c:3293 cp/parser.c:19717
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
 
-#: cp/class.c:3097
+#: cp/class.c:3101
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr ""
 
-#: cp/class.c:3213
+#: cp/class.c:3217
 #, gcc-internal-format
 msgid "bit-field %q+#D with non-integral type"
 msgstr "bit-alanı %q+#D tümleyen türde değil"
 
-#: cp/class.c:3229
+#: cp/class.c:3233
 #, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr "bit alanı %q+D için genişlik bir tamsayı sabit değil"
 
-#: cp/class.c:3234
+#: cp/class.c:3238
 #, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr "bit alanı %q+D için genişlik negatif"
 
-#: cp/class.c:3239
+#: cp/class.c:3243
 #, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr "bit alanı %q+D için sıfır genişlik"
 
-#: cp/class.c:3249
+#: cp/class.c:3253
 #, fuzzy, gcc-internal-format
 #| msgid "width of %q+D exceeds its type"
 msgid "width of %qD exceeds its type"
 msgstr "%q+D kendi türünden geniş"
 
-#: cp/class.c:3255
+#: cp/class.c:3259
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is too small to hold all values of %q#T"
 msgid "%qD is too small to hold all values of %q#T"
 msgstr "%q+D alanı %#T türünün tüm değerlerini tutmak için çok küçük"
 
-#: cp/class.c:3316
+#: cp/class.c:3320
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr "union içinde kuruculu üye %q+#D olamaz"
 
-#: cp/class.c:3319
+#: cp/class.c:3323
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr "union içinde yıkıcılı üye %q+#D olamaz"
 
-#: cp/class.c:3321
+#: cp/class.c:3325
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr "union içinde kopya atama isleçli üye %q+#D olamaz"
 
-#: cp/class.c:3325
+#: cp/class.c:3329
 #, gcc-internal-format
 msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/class.c:3453
+#: cp/class.c:3457
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D may not be static because it is a member of a union"
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr "%q+D bir union üyesi olduğundan static olmayabilir"
 
-#: cp/class.c:3460
+#: cp/class.c:3464
 #, fuzzy, gcc-internal-format
 #| msgid "invalid access to non-static data member %qD of NULL object"
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr "NULL nesnenin static olmayan veri üyesi  %qD'ye erişim geçersiz"
 
-#: cp/class.c:3470
+#: cp/class.c:3474
 #, gcc-internal-format
 msgid "field %q+D invalidly declared function type"
 msgstr "%q+D alanı ile geçersiz olarak işlev türü bildirildi"
 
-#: cp/class.c:3476
+#: cp/class.c:3480
 #, gcc-internal-format
 msgid "field %q+D invalidly declared method type"
 msgstr "%q+D alanı ile geçersiz olarak yöntem türü bildirildi"
 
-#: cp/class.c:3536
+#: cp/class.c:3540
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring packed attribute on unpacked non-POD field %q+#D"
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr "paketsiz POD olmayan %q+#D alanı üzerinde paketli öznitelik yoksayılıyor"
 
-#: cp/class.c:3585
+#: cp/class.c:3589
 #, fuzzy, gcc-internal-format
 #| msgid "non-member %qs cannot be declared %<mutable%>"
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr "üye olmayan %qs, %<mutable%> olarak bildirilemez"
 
-#: cp/class.c:3591
+#: cp/class.c:3595
 #, fuzzy, gcc-internal-format
 #| msgid "non-member %qs cannot be declared %<mutable%>"
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr "üye olmayan %qs, %<mutable%> olarak bildirilemez"
 
-#: cp/class.c:3617
+#: cp/class.c:3621
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr "union %qT içinde çok sayıda alan ilklendirildi"
 
-#: cp/class.c:3658
+#: cp/class.c:3662
 #, fuzzy, gcc-internal-format
 #| msgid "field %q+#D with same name as class"
 msgid "field %q#D with same name as class"
 msgstr "%q+#D alanı sınıf ile aynı isimde"
 
-#: cp/class.c:3681
+#: cp/class.c:3685
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr "%q#T gösterici veri üyeleri içeriyor"
 
-#: cp/class.c:3686
+#: cp/class.c:3690
 #, gcc-internal-format
 msgid "  but does not override %<%T(const %T&)%>"
 msgstr "  ama %<%T(const %T&)%>ye değiştirilmiyor"
 
-#: cp/class.c:3688
+#: cp/class.c:3692
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr "  ya da %<operator=(const %T&)%> içeriyor"
 
-#: cp/class.c:3692
+#: cp/class.c:3696
 #, gcc-internal-format
 msgid "  but does not override %<operator=(const %T&)%>"
 msgstr "  ama %<operator=(const %T&)%>ye değiştirilmiyor"
 
-#: cp/class.c:4097
+#: cp/class.c:4101
 #, gcc-internal-format
 msgid "alignment of %qD increased in -fabi-version=9 (GCC 5.2)"
 msgstr ""
 
-#: cp/class.c:4100
+#: cp/class.c:4104
 #, gcc-internal-format
 msgid "alignment of %qD will increase in -fabi-version=9"
 msgstr ""
 
-#: cp/class.c:4378
+#: cp/class.c:4382
 #, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "sanal olmayan yöntem %q+D için ilklendirici belirtilmiş"
 
-#: cp/class.c:4813
+#: cp/class.c:4817
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr ""
 
-#: cp/class.c:4834
+#: cp/class.c:4838
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr ""
 
-#: cp/class.c:5350 cp/constexpr.c:237
+#: cp/class.c:5367 cp/constexpr.c:237
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "enclosing class of %<constexpr%> non-static member function %q+#D is not a literal type"
 msgstr "static olmayan üye işlev %qD kullanımı geçersiz"
 
-#: cp/class.c:5374
+#: cp/class.c:5391
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a base of %qT"
 msgid "%q+T is not literal because:"
 msgstr "%qT %qT tabanında değil"
 
-#: cp/class.c:5377
+#: cp/class.c:5394
 #, gcc-internal-format
 msgid "  %qT is a closure type, which is only literal in C++17 and later"
 msgstr ""
 
-#: cp/class.c:5380
+#: cp/class.c:5397
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "  %q+T has a non-trivial destructor"
 msgstr "taban sınıf %q#T bir sanal olmayan yıkıcıya sahip"
 
-#: cp/class.c:5387
+#: cp/class.c:5404
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no %<constexpr%> constructor that is not a copy or move constructor"
 msgstr ""
 
-#: cp/class.c:5420
+#: cp/class.c:5437
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "taban sınıf %q#T bir sanal olmayan yıkıcıya sahip"
 
-#: cp/class.c:5435
+#: cp/class.c:5452
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static data member %q+D"
 msgid "  non-static data member %qD has non-literal type"
 msgstr "static olmayan veri üyesi %q+D kullanımı geçersiz"
 
-#: cp/class.c:5442
+#: cp/class.c:5459
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static data member %q+D"
 msgid "  non-static data member %qD has volatile type"
 msgstr "static olmayan veri üyesi %q+D kullanımı geçersiz"
 
-#: cp/class.c:5561
+#: cp/class.c:5578
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "taban sınıf %q#T bir sanal olmayan yıkıcıya sahip"
 
-#: cp/class.c:5590
+#: cp/class.c:5607
 #, fuzzy, gcc-internal-format
 #| msgid "non-static reference %q+#D in class without a constructor"
 msgid "non-static reference %q#D in class without a constructor"
 msgstr "bir kurucu olmaksızın sınıf içinde static olmayan başvuru %q+#D"
 
-#: cp/class.c:5596
+#: cp/class.c:5613
 #, fuzzy, gcc-internal-format
 #| msgid "non-static const member %q+#D in class without a constructor"
 msgid "non-static const member %q#D in class without a constructor"
@@ -45120,167 +45164,167 @@
 
 #. If the function is defaulted outside the class, we just
 #. give the synthesis error.
-#: cp/class.c:5624
+#: cp/class.c:5641
 #, gcc-internal-format
 msgid "%q+D declared to take const reference, but implicit declaration would take non-const"
 msgstr ""
 
-#: cp/class.c:5898
+#: cp/class.c:5915
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr "doğrudan taban %qT belirsizlikten dolayı %qT içinde erişilebilir değil"
 
-#: cp/class.c:5910
+#: cp/class.c:5927
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr "sanal taban %qT belirsizlikten dolayı %qT içinde erişilebilir değil"
 
-#: cp/class.c:6133
+#: cp/class.c:6150
 #, fuzzy, gcc-internal-format
 #| msgid "offset of %q+D is not ABI-compliant and may change in a future version of GCC"
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr "%q+D alanının göreli konumu ABI-uyumlu değil ve bu GCC'nin gelecek sürümünde değişebilir"
 
-#: cp/class.c:6291
+#: cp/class.c:6308
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr "%qs dizisinin boyutu çok büyük"
 
-#: cp/class.c:6576
+#: cp/class.c:6593
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<this%> at top level"
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr "tepe seviyede %<this%> kullanımı geçersiz"
 
-#: cp/class.c:6578
+#: cp/class.c:6595
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of structure with flexible array member"
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr "esnek dizi üyeli yapı kullanımı geçersiz"
 
-#: cp/class.c:6583
+#: cp/class.c:6600
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD declared void"
 msgid "array member %q#D declared here"
 msgstr "parametre %qD void olarak bildirilmiş"
 
-#: cp/class.c:6610
+#: cp/class.c:6627
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member not at end of struct"
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr "%Jesnek dizi yapının son üyesi değil"
 
-#: cp/class.c:6612
+#: cp/class.c:6629
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in otherwise empty struct"
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr "%Jbaşka bir boş yapı içinde esnek dizi"
 
-#: cp/class.c:6620 cp/class.c:6650
+#: cp/class.c:6637 cp/class.c:6667
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %q#T"
 msgid "in the definition of %q#T"
 msgstr "%q#T sınıfın yeniden tanımı"
 
-#: cp/class.c:6628
+#: cp/class.c:6645
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member not at end of struct"
 msgid "flexible array member %qD not at end of %q#T"
 msgstr "%Jesnek dizi yapının son üyesi değil"
 
-#: cp/class.c:6630
+#: cp/class.c:6647
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in otherwise empty struct"
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr "%Jbaşka bir boş yapı içinde esnek dizi"
 
-#: cp/class.c:6648
+#: cp/class.c:6665
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "next member %q#D declared here"
 msgstr "burada bildirilmiş %q+D"
 
-#: cp/class.c:6760 cp/parser.c:23239
+#: cp/class.c:6777 cp/parser.c:23236
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "%q#T sınıfın yeniden tanımı"
 
-#: cp/class.c:6897
+#: cp/class.c:6914
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T has virtual functions but non-virtual destructor"
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "%q#T sanal olmayan kuruculu sanal işlevler içeriyor"
 
-#: cp/class.c:6925
+#: cp/class.c:6942
 #, fuzzy, gcc-internal-format
 #| msgid "class %qT does not have any field named %qD"
 msgid "type transparent %q#T does not have any fields"
 msgstr "sınıf %qT %qD isminde alan içermiyor"
 
-#: cp/class.c:6931
+#: cp/class.c:6948
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr ""
 
-#: cp/class.c:6935
+#: cp/class.c:6952
 #, fuzzy, gcc-internal-format
 #| msgid "type %qs has virtual member functions"
 msgid "type transparent class %qT has virtual functions"
 msgstr "%qs türü sanal üye işlevlere sahip"
 
-#: cp/class.c:6941
+#: cp/class.c:6958
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:7071
+#: cp/class.c:7088
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D definition is marked dllimport"
 msgid "definition of %qD does not match %<#include <initializer_list>%>"
 msgstr "%q+D işlevinin tanımı dllimport imli"
 
-#: cp/class.c:7082
+#: cp/class.c:7099
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr "yapı tamamlanmaya çalışılırken önceki ayrıştırma hatalarından dolayı kesildi"
 
-#: cp/class.c:7582
+#: cp/class.c:7599
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "dil dizgesi %<\"%E\"%> tanınmıyor"
 
-#: cp/class.c:7672
+#: cp/class.c:7689
 #, fuzzy, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr "%2$qT türüne dönüşüme dayalı aşırı yüklü %1$qD işlevi çözümlenemiyor"
 
-#: cp/class.c:7817
+#: cp/class.c:7834
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr "%qD işlevinin %q#T türüne dönüşümü için eşleşme yok"
 
-#: cp/class.c:7844
+#: cp/class.c:7861
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "aşırı yüklü %qD işlevinin %q#T türüne dönüşümü belirsiz"
 
-#: cp/class.c:7870
+#: cp/class.c:7887
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "%qD üyesine gösterici varsayılıyor"
 
-#: cp/class.c:7873
+#: cp/class.c:7890
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(bir üye göstericisi sadece %<&%E%> ile şekillendirilebilir)"
 
-#: cp/class.c:7948 cp/class.c:7990
+#: cp/class.c:7965 cp/class.c:8007
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "tür bilgisi yetersiz"
 
-#: cp/class.c:7968
+#: cp/class.c:7985
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "%qE ifadesi %qT türünden %qT türüne dönüştürülemez"
@@ -45290,12 +45334,12 @@
 #. A name N used in a class S shall refer to the same declaration
 #. in its context and when re-evaluated in the completed scope of
 #. S.
-#: cp/class.c:8235
+#: cp/class.c:8252
 #, gcc-internal-format
 msgid "declaration of %q#D"
 msgstr "%q#D yeniden bildirimi"
 
-#: cp/class.c:8237
+#: cp/class.c:8254
 #, fuzzy, gcc-internal-format
 #| msgid "changes meaning of %qD from %q+#D"
 msgid "changes meaning of %qD from %q#D"
@@ -45745,17 +45789,17 @@
 msgid "unexpected AST of kind %s"
 msgstr "'%s' de umulmadık dosya sonu"
 
-#: cp/cp-gimplify.c:1415
+#: cp/cp-gimplify.c:1416
 #, gcc-internal-format
 msgid "throw will always call terminate()"
 msgstr ""
 
-#: cp/cp-gimplify.c:1418
+#: cp/cp-gimplify.c:1419
 #, gcc-internal-format
 msgid "in C++11 destructors default to noexcept"
 msgstr ""
 
-#: cp/cp-gimplify.c:1429
+#: cp/cp-gimplify.c:1430
 #, gcc-internal-format
 msgid "in C++11 this throw will terminate because destructors default to noexcept"
 msgstr ""
@@ -46210,7 +46254,7 @@
 msgid "redeclaration %qD differs in %<constexpr%> from previous declaration"
 msgstr "bir şablon olmayan olarak yeniden %qT bildirimi"
 
-#: cp/decl.c:1304 cp/decl.c:13843
+#: cp/decl.c:1304 cp/decl.c:13867
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D"
 msgid "previous declaration %qD"
@@ -46580,7 +46624,7 @@
 msgid "  enters OpenMP structured block"
 msgstr "  try blokuna giriliyor"
 
-#: cp/decl.c:3434 cp/parser.c:12366 cp/parser.c:12387
+#: cp/decl.c:3434 cp/parser.c:12363 cp/parser.c:12384
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr ""
@@ -46591,7 +46635,7 @@
 msgid "%qD is not a type"
 msgstr "%qD bir şablon değil"
 
-#: cp/decl.c:3838 cp/parser.c:6366
+#: cp/decl.c:3838 cp/parser.c:6369
 #, gcc-internal-format
 msgid "%qD used without template parameters"
 msgstr "%qD şablon parametreleri olmaksızın kullanılmış"
@@ -47007,8 +47051,8 @@
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.c:6011 cp/decl.c:6234 cp/typeck2.c:1310 cp/typeck2.c:1590
-#: cp/typeck2.c:1638 cp/typeck2.c:1685
+#: cp/decl.c:6011 cp/decl.c:6234 cp/typeck2.c:1310 cp/typeck2.c:1593
+#: cp/typeck2.c:1641 cp/typeck2.c:1688
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "%qT için ilklendirici sayısı çok fazla"
@@ -47091,13 +47135,13 @@
 msgid "assignment (not initialization) in declaration"
 msgstr "bildirim içinde atama (ilklendirme değil)"
 
-#: cp/decl.c:6873 cp/decl.c:12605
+#: cp/decl.c:6873 cp/decl.c:12629
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C++ tasarlanmış ilkendiricilere izin vermez"
 
-#: cp/decl.c:6877 cp/decl.c:12609
+#: cp/decl.c:6877 cp/decl.c:12633
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for %qs"
 msgid "%<register%> storage class specifier used"
@@ -47125,46 +47169,46 @@
 msgid "function %q#D is initialized like a variable"
 msgstr "%q#D işlevi bir değişken gibi ilklendirilmiş"
 
-#: cp/decl.c:7329
+#: cp/decl.c:7350
 #, fuzzy, gcc-internal-format
 #| msgid "  cannot use obsolete binding at %q+D because it has a destructor"
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "  %q+D'deki atıl baglantı bir yıkıcıya sahip olduğundan kullanılamaz"
 
-#: cp/decl.c:7332
+#: cp/decl.c:7353
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.c:7339
+#: cp/decl.c:7360
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is an inaccessible base of %qT"
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "%qT, bir erişilemeyen %qT tabanıdır"
 
-#: cp/decl.c:7365
+#: cp/decl.c:7386
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:7374
+#: cp/decl.c:7395
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:7592
+#: cp/decl.c:7613
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing pointer to incomplete type"
 msgid "structured binding refers to incomplete type %qT"
 msgstr "içi boş ture gösterici ilişkilendirme"
 
-#: cp/decl.c:7608
+#: cp/decl.c:7629
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable-size array %qs"
 msgid "cannot decompose variable length array %qT"
 msgstr "ISO C90 değişken boyutlu %qs dizisini yasaklar"
 
-#: cp/decl.c:7617 cp/decl.c:7702
+#: cp/decl.c:7638 cp/decl.c:7723
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "storage class specified for structure field %qs"
 msgid "%u name provided for structured binding"
@@ -47172,7 +47216,7 @@
 msgstr[0] "%qs yapı alan için saklama sınıfı belirtilmiş"
 msgstr[1] "%qs yapı alan için saklama sınıfı belirtilmiş"
 
-#: cp/decl.c:7621
+#: cp/decl.c:7642
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
@@ -47179,7 +47223,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:7624
+#: cp/decl.c:7645
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
@@ -47186,976 +47230,976 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:7669
+#: cp/decl.c:7690
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to %q#T"
 msgid "cannot decompose variable length vector %qT"
 msgstr "%q#T türüne gösterici bildirilemez"
 
-#: cp/decl.c:7695
+#: cp/decl.c:7716
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "dizi boyutu bir tümleyen sabit ifadesi değil"
 
-#: cp/decl.c:7704
+#: cp/decl.c:7725
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.c:7725
+#: cp/decl.c:7746
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type %qT"
 msgid "in initialization of structured binding variable %qD"
 msgstr "%qT işlev türüne dönüşüm geçersiz"
 
-#: cp/decl.c:7751
+#: cp/decl.c:7772
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare bit-field %qD with function type"
 msgid "cannot decompose union type %qT"
 msgstr "bit alanı %qD işlev türü ile bildirilemez"
 
-#: cp/decl.c:7756
+#: cp/decl.c:7777
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "sınıf olmayan %qT türünde üye göstericisi oluşturulması"
 
-#: cp/decl.c:7761
+#: cp/decl.c:7782
 #, fuzzy, gcc-internal-format
 #| msgid "cannot decompose address"
 msgid "cannot decompose lambda closure type %qT"
 msgstr "adres çözümlenemez"
 
-#: cp/decl.c:7765
+#: cp/decl.c:7786
 #, fuzzy, gcc-internal-format
 #| msgid "return type is an incomplete type"
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "dönüş türü, bir içi boş tür"
 
-#: cp/decl.c:7774
+#: cp/decl.c:7795
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static data member %qD"
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "static olmayan veri üyesi %qD kullanımı geçersiz"
 
-#: cp/decl.c:8213
+#: cp/decl.c:8234
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:8216
+#: cp/decl.c:8237
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:8222
+#: cp/decl.c:8243
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:8450
+#: cp/decl.c:8471
 #, fuzzy, gcc-internal-format
 #| msgid "initializer fails to determine size of %qD"
 msgid "initializer fails to determine size of %qT"
 msgstr "ilklendirici %qD bildiriminin boyutunu saptayamıyor"
 
-#: cp/decl.c:8454
+#: cp/decl.c:8475
 #, fuzzy, gcc-internal-format
 #| msgid "array size missing in %qD"
 msgid "array size missing in %qT"
 msgstr "%qD bildiriminde dizi boyutu eksik"
 
-#: cp/decl.c:8457
+#: cp/decl.c:8478
 #, fuzzy, gcc-internal-format
 #| msgid "zero-size array %qD"
 msgid "zero-size array %qT"
 msgstr "sıfır boyutlu dizi %qD"
 
-#: cp/decl.c:8473
+#: cp/decl.c:8494
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "yabancı sınıf %qT için yıkıcı, bir üye olamaz"
 
-#: cp/decl.c:8475
+#: cp/decl.c:8496
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "yabancı sınıf %qT için kurucu, bir üye olamaz"
 
-#: cp/decl.c:8499
+#: cp/decl.c:8520
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD bir %<virtual%> %s olarak bildirilmiş"
 
-#: cp/decl.c:8501
+#: cp/decl.c:8522
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "%2$s bildirimindeki %<const%> ve %<volatile%> işlev belirtecleri %1$qD için geçersiz"
 
-#: cp/decl.c:8506
+#: cp/decl.c:8527
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD bir %<virtual%> %s olarak bildirilmiş"
 
-#: cp/decl.c:8508
+#: cp/decl.c:8529
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD nesnesi bir %<inline%> %s olarak bildirilmiş"
 
-#: cp/decl.c:8510
+#: cp/decl.c:8531
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "%2$s bildirimindeki %<const%> ve %<volatile%> işlev belirtecleri %1$qD için geçersiz"
 
-#: cp/decl.c:8515
+#: cp/decl.c:8536
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD bir %<virtual%> %s olarak bildirilmiş"
 
-#: cp/decl.c:8517
+#: cp/decl.c:8538
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD nesnesi bir %<inline%> %s olarak bildirilmiş"
 
-#: cp/decl.c:8519
+#: cp/decl.c:8540
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "%2$s bildirimindeki %<const%> ve %<volatile%> işlev belirtecleri %1$qD için geçersiz"
 
-#: cp/decl.c:8524
+#: cp/decl.c:8545
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD bir %<virtual%> %s olarak bildirilmiş"
 
-#: cp/decl.c:8526
+#: cp/decl.c:8547
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD nesnesi bir %<inline%> %s olarak bildirilmiş"
 
-#: cp/decl.c:8528
+#: cp/decl.c:8549
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "%2$s bildirimindeki %<const%> ve %<volatile%> işlev belirtecleri %1$qD için geçersiz"
 
-#: cp/decl.c:8535
+#: cp/decl.c:8556
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D bir kardeş olarak bildirilmiş"
 
-#: cp/decl.c:8542
+#: cp/decl.c:8563
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D bir olağandışılık belirtimi ile bildirilmiş"
 
-#: cp/decl.c:8574
+#: cp/decl.c:8595
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "%qD tanımı %qT bağlamını kapsayan isim alanınında değil"
 
-#: cp/decl.c:8614
+#: cp/decl.c:8635
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "statik üye işlev %q#D tür niteleyicilerle bildirilmiş"
 
-#: cp/decl.c:8624
+#: cp/decl.c:8645
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a non-parameter"
 msgid "concept %q#D declared with function parameters"
 msgstr "%q+D bir parametre olarak bildirilmemiş"
 
-#: cp/decl.c:8630
+#: cp/decl.c:8651
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared with void type"
 msgid "concept %q#D declared with a deduced return type"
 msgstr "%q+D parametresi void olarak bildirilmiş"
 
-#: cp/decl.c:8632
+#: cp/decl.c:8653
 #, fuzzy, gcc-internal-format
 #| msgid "Java method %qD has non-Java return type %qT"
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "Java yöntemi %qD Java olmayan %qT dönüş türünü içeriyor"
 
-#: cp/decl.c:8703
+#: cp/decl.c:8724
 #, fuzzy, gcc-internal-format
 #| msgid "%Jold-style function definition"
 msgid "concept %qD has no definition"
 msgstr "%Jeski tarz işlev tanımı"
 
-#: cp/decl.c:8772
+#: cp/decl.c:8793
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "%qD doğrudan özelleştirmesinin kardeş bildirimde tanımı"
 
 #. Something like `template <class T> friend void f<T>()'.
-#: cp/decl.c:8782
+#: cp/decl.c:8803
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "birincil şablon bildiriminde %qD şablon kimliğinin kullanımı geçersiz"
 
-#: cp/decl.c:8800
+#: cp/decl.c:8821
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "öntanımlı argümanlara kardeş şablon özelleştirmesi %qD bildiriminde izin verilmez"
 
-#: cp/decl.c:8808
+#: cp/decl.c:8829
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "kardeş şablon özelleştirmesi %qD bildiriminde %<inline%> kullanılamaz"
 
-#: cp/decl.c:8857
+#: cp/decl.c:8878
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "%<::main%> bir şablon olarak bildirilemez"
 
-#: cp/decl.c:8859
+#: cp/decl.c:8880
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "%<::main%> inline olarak bildirilemez"
 
-#: cp/decl.c:8861
+#: cp/decl.c:8882
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be inline"
 msgid "cannot declare %<::main%> to be %<constexpr%>"
 msgstr "%<::main%> inline olarak bildirilemez"
 
-#: cp/decl.c:8863
+#: cp/decl.c:8884
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "%<::main%> static olarak bildirilemez"
 
-#: cp/decl.c:8920
+#: cp/decl.c:8941
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "%süye işlev %qD cv niteleyicisini içeremez"
 
-#: cp/decl.c:8921
+#: cp/decl.c:8942
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "%süye işlev %qD cv niteleyicisini içeremez"
 
-#: cp/decl.c:8929
+#: cp/decl.c:8950
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "%süye işlev %qD cv niteleyicisini içeremez"
 
-#: cp/decl.c:8930
+#: cp/decl.c:8951
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "%süye işlev %qD cv niteleyicisini içeremez"
 
-#: cp/decl.c:8940
+#: cp/decl.c:8961
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %qD in different namespace"
 msgid "deduction guide %qD must be declared at namespace scope"
 msgstr "farklı isim alanında %qD özelleştirmesi"
 
-#: cp/decl.c:8946
+#: cp/decl.c:8967
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "deduction guide %qD must not have a function body"
 msgstr "işlev olmayan olarak %qD bildirimi"
 
-#: cp/decl.c:8959
+#: cp/decl.c:8980
 #, fuzzy, gcc-internal-format
 #| msgid "template with C linkage"
 msgid "literal operator with C linkage"
 msgstr "C ilintilemeli şablon"
 
-#: cp/decl.c:8969
+#: cp/decl.c:8990
 #, fuzzy, gcc-internal-format
 #| msgid "invalid option argument %qs"
 msgid "%qD has invalid argument list"
 msgstr "seçenek argümanı %qs geçersiz"
 
-#: cp/decl.c:8977
+#: cp/decl.c:8998
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:8983
+#: cp/decl.c:9004
 #, gcc-internal-format
 msgid "floating point suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:8991
+#: cp/decl.c:9012
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/decl.c:8996
+#: cp/decl.c:9017
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a nonstatic member function"
 msgid "%qD must be a non-member function"
 msgstr "%qD static olmayan bir üye işlev olmalıdır"
 
-#: cp/decl.c:9076
+#: cp/decl.c:9097
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> %<int%> döndürmeli"
 
-#: cp/decl.c:9116
+#: cp/decl.c:9137
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "dolaylı bildirimli %qD tanımı"
 
-#: cp/decl.c:9121
+#: cp/decl.c:9142
 #, fuzzy, gcc-internal-format
 #| msgid "definition of implicitly-declared %qD"
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "dolaylı bildirimli %qD tanımı"
 
-#: cp/decl.c:9123
+#: cp/decl.c:9144
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "%q#D explicitly defaulted here"
 msgstr "%q+#D evvelce burada tanımlanmış"
 
-#: cp/decl.c:9140
+#: cp/decl.c:9161
 #, fuzzy, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "sınıf %2$qT içinde bildirilmiş %1$q#D diye bir üye işlev yok"
 
-#: cp/decl.c:9329
+#: cp/decl.c:9350
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be a template"
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "%<::main%> bir şablon olarak bildirilemez"
 
-#: cp/decl.c:9337
+#: cp/decl.c:9358
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: cp/decl.c:9344
+#: cp/decl.c:9365
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.c:9464
+#: cp/decl.c:9485
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "tümleyen olmayan %qT türündeki statik veri üyesinin sınıf içi ilklendirmesi geçersiz"
 
-#: cp/decl.c:9468
+#: cp/decl.c:9489
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "tümleyen olmayan %qT türündeki statik veri üyesinin sınıf içi ilklendirmesi geçersiz"
 
-#: cp/decl.c:9472
+#: cp/decl.c:9493
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "tümleyen olmayan %qT türündeki statik veri üyesinin sınıf içi ilklendirmesi geçersiz"
 
-#: cp/decl.c:9486
+#: cp/decl.c:9507
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "tümleyen olmayan %qT türündeki statik veri üyesinin sınıf içi ilklendirmesi geçersiz"
 
-#: cp/decl.c:9493
+#: cp/decl.c:9514
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ISO C++ sabit olmayan statik %qD üyesinin sınıf içi ilklendirmesine izin vermez"
 
-#: cp/decl.c:9498
+#: cp/decl.c:9519
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO C++ tümlemeyen %2$qT türündeki %1$qD üye sabitinin ilklendirilmesine izin vermez"
 
-#: cp/decl.c:9598
+#: cp/decl.c:9619
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "%qD dizisinin boyutu tümlemeyen %qT türünde"
 
-#: cp/decl.c:9600
+#: cp/decl.c:9621
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "dizi boyutu tümlemeyen %qT türünde"
 
-#: cp/decl.c:9630 cp/decl.c:9680
+#: cp/decl.c:9651 cp/decl.c:9701
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "dizi boyutu bir tümleyen sabit ifadesi değil"
 
-#: cp/decl.c:9646
+#: cp/decl.c:9667
 #, gcc-internal-format
 msgid "size of array %qD is negative"
 msgstr "%qD dizisinin boyutu negatif"
 
-#: cp/decl.c:9648 cp/init.c:3651
+#: cp/decl.c:9669 cp/init.c:3667
 #, gcc-internal-format
 msgid "size of array is negative"
 msgstr "dizi boyutu negatif"
 
-#: cp/decl.c:9662
+#: cp/decl.c:9683
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C++ da sıfır boyutlu %qD dizisi yasaktır"
 
-#: cp/decl.c:9664
+#: cp/decl.c:9685
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++'da sıfır boyutlu dizi yasaktır"
 
-#: cp/decl.c:9677
+#: cp/decl.c:9698
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "%qD dizisinin boyutu bir tümleyen sabit ifadesi değil"
 
-#: cp/decl.c:9686
+#: cp/decl.c:9707
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids variable-size array %qD"
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++ değişken boyutlu %qD dizisine izin vermez"
 
-#: cp/decl.c:9688
+#: cp/decl.c:9709
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids variable-size array"
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++  değişken boyutlu diziye izin vermez"
 
-#: cp/decl.c:9694
+#: cp/decl.c:9715
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr ""
 
-#: cp/decl.c:9697
+#: cp/decl.c:9718
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr ""
 
-#: cp/decl.c:9746
+#: cp/decl.c:9767
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "dizi boyutunda taşma"
 
-#: cp/decl.c:9799
+#: cp/decl.c:9820
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "%qD declared as array of %qT"
 msgstr "%q+D bir kardeş olarak bildirilmiş"
 
-#: cp/decl.c:9809
+#: cp/decl.c:9830
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of voids"
 msgid "declaration of %qD as array of void"
 msgstr "void dizisi olarak %qs bildirimi"
 
-#: cp/decl.c:9811
+#: cp/decl.c:9832
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of %qT"
 msgid "creating array of void"
 msgstr "%qT dizisi oluşturulması"
 
-#: cp/decl.c:9816
+#: cp/decl.c:9837
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of %qD as array of functions"
 msgstr "işlev dizisi olarak %qs bildirimi"
 
-#: cp/decl.c:9818
+#: cp/decl.c:9839
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of %qT"
 msgid "creating array of functions"
 msgstr "%qT dizisi oluşturulması"
 
-#: cp/decl.c:9823
+#: cp/decl.c:9844
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of %qD as array of references"
 msgstr "işlev dizisi olarak %qs bildirimi"
 
-#: cp/decl.c:9825
+#: cp/decl.c:9846
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of %qT"
 msgid "creating array of references"
 msgstr "%qT dizisi oluşturulması"
 
-#: cp/decl.c:9830
+#: cp/decl.c:9851
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of %qD as array of function members"
 msgstr "işlev dizisi olarak %qs bildirimi"
 
-#: cp/decl.c:9832
+#: cp/decl.c:9853
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "creating array of function members"
 msgstr "işlev dizisi olarak %qs bildirimi"
 
-#: cp/decl.c:9846
+#: cp/decl.c:9867
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "çok boyutlu dizi olarak %qD bildiriminde ilki dışında tüm boyutlar sınırlanmış olmalıdır"
 
-#: cp/decl.c:9850
+#: cp/decl.c:9871
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "çok boyutlu dizi bildiriminde ilki dışında tüm boyutlar sınırlanmış olmalıdır"
 
-#: cp/decl.c:9909
+#: cp/decl.c:9930
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "kurucu için dönüş türü belirtimi geçersiz"
 
-#: cp/decl.c:9912
+#: cp/decl.c:9933
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "%<operator %T%> bildiriminde niteleyicilere izin verilmez"
 
-#: cp/decl.c:9922
+#: cp/decl.c:9943
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "yıkıcı için dönüş türü belirtimi geçersiz"
 
-#: cp/decl.c:9925
+#: cp/decl.c:9946
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "%<operator %T%> bildiriminde niteleyicilere izin verilmez"
 
-#: cp/decl.c:9937
+#: cp/decl.c:9958
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "%<operator %T%> için dönüş türü belirtilmiş"
 
-#: cp/decl.c:9940
+#: cp/decl.c:9961
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "%<operator %T%> bildiriminde niteleyicilere izin verilmez"
 
-#: cp/decl.c:9948
+#: cp/decl.c:9969
 #, fuzzy, gcc-internal-format
 #| msgid "return type specification for destructor invalid"
 msgid "return type specified for deduction guide"
 msgstr "yıkıcı için dönüş türü belirtimi geçersiz"
 
-#: cp/decl.c:9951
+#: cp/decl.c:9972
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "%<operator %T%> bildiriminde niteleyicilere izin verilmez"
 
-#: cp/decl.c:9955
+#: cp/decl.c:9976
 #, fuzzy, gcc-internal-format
 #| msgid "too many template parameter lists in declaration of %qD"
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "%qD bildiriminde çok fazla şablon parametresi listeleniyor"
 
-#: cp/decl.c:9964
+#: cp/decl.c:9985
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "decl-specifier in declaration of deduction guide"
 msgstr "%q#D bildirimi çelişkili"
 
-#: cp/decl.c:9985
+#: cp/decl.c:10006
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "void bildirimli adsız değişken ya da alan"
 
-#: cp/decl.c:9992
+#: cp/decl.c:10013
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "void bildirimli değişken ya da alan"
 
-#: cp/decl.c:10007
+#: cp/decl.c:10028
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "genel kapsam dışında bildirilen %qs işlevi için %<inline%> belirteci geçersiz"
 
-#: cp/decl.c:10013
+#: cp/decl.c:10034
 #, gcc-internal-format
 msgid "inline variables are only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/decl.c:10268
+#: cp/decl.c:10292
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<::%>"
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "%<::%> kullanımı geçersiz"
 
-#: cp/decl.c:10271 cp/decl.c:10291
+#: cp/decl.c:10295 cp/decl.c:10315
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of undefined type %<%s %E%>"
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "tanımsız tür %<%s %E%> kullanımı geçersiz"
 
-#: cp/decl.c:10274
+#: cp/decl.c:10298
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of undefined type %<%s %E%>"
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "tanımsız tür %<%s %E%> kullanımı geçersiz"
 
-#: cp/decl.c:10283
+#: cp/decl.c:10307
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a class or namespace"
 msgid "%q#T is not a class or a namespace"
 msgstr "%qT bir sınıf ya da isim alanı değil"
 
-#: cp/decl.c:10305 cp/decl.c:10398 cp/decl.c:10407 cp/decl.c:11970
+#: cp/decl.c:10329 cp/decl.c:10422 cp/decl.c:10431 cp/decl.c:11994
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "işlev olmayan olarak %qD bildirimi"
 
-#: cp/decl.c:10311
+#: cp/decl.c:10335
 #, gcc-internal-format
 msgid "declaration of %qD as non-member"
 msgstr "üye olmayan olarak %qD bildirimi"
 
-#: cp/decl.c:10339
+#: cp/decl.c:10363
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "bildirimci kimliği eksik; yedek sözcük %qD kullanılıyor"
 
-#: cp/decl.c:10390
+#: cp/decl.c:10414
 #, fuzzy, gcc-internal-format
 #| msgid "function definition declared %<register%>"
 msgid "function definition does not declare parameters"
 msgstr "%<register%> bildirimli işlev tanımı"
 
-#: cp/decl.c:10415
+#: cp/decl.c:10439
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "%2$s olarak %1$qD bildirimi"
 
-#: cp/decl.c:10420
+#: cp/decl.c:10444
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of %qD as parameter"
 msgstr "%q+D bildirimi bir parametreyi gölgeliyor"
 
-#: cp/decl.c:10454
+#: cp/decl.c:10478
 #, fuzzy, gcc-internal-format
 #| msgid "a template-id may not appear in a using-declaration"
 msgid "%<concept%> cannot appear in a typedef declaration"
 msgstr "using bildiriminde bir şablon kimliği bulunamaz"
 
-#: cp/decl.c:10460
+#: cp/decl.c:10484
 #, fuzzy, gcc-internal-format
 #| msgid "a template-id may not appear in a using-declaration"
 msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgstr "using bildiriminde bir şablon kimliği bulunamaz"
 
-#: cp/decl.c:10468
+#: cp/decl.c:10492
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "%qs bildiriminde iki veya daha fazla veri türü"
 
-#: cp/decl.c:10474
+#: cp/decl.c:10498
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting declaration %q#D"
 msgid "conflicting specifiers in declaration of %qs"
 msgstr "%q#D bildirimi çelişkili"
 
-#: cp/decl.c:10515
+#: cp/decl.c:10539
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C salt %<complex%>i %<double complex%> anlamında desteklemez"
 
-#: cp/decl.c:10564 cp/decl.c:10567 cp/decl.c:10570
+#: cp/decl.c:10588 cp/decl.c:10591 cp/decl.c:10594
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ türsüz %qs bildirimine izin verilmez"
 
-#: cp/decl.c:10586
+#: cp/decl.c:10610
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_saveregs not supported by this target"
 msgid "%<__int%d%> is not supported by this target"
 msgstr "__builtin_saveregs bu hedef tarafından desteklenmiyor"
 
-#: cp/decl.c:10592
+#: cp/decl.c:10616
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not support %<long long%>"
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ %<long long%> desteklemez"
 
-#: cp/decl.c:10614 cp/decl.c:10634
+#: cp/decl.c:10638 cp/decl.c:10658
 #, fuzzy, gcc-internal-format
 #| msgid "short, signed or unsigned invalid for %qs"
 msgid "%<signed%> or %<unsigned%> invalid for %qs"
 msgstr "%qs için short, signed veya unsigned geçersiz"
 
-#: cp/decl.c:10616
+#: cp/decl.c:10640
 #, fuzzy, gcc-internal-format
 #| msgid "signed and unsigned given together for %qs"
 msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgstr "%qs için signed ve unsigned birlikte verilmiş"
 
-#: cp/decl.c:10618
+#: cp/decl.c:10642
 #, fuzzy, gcc-internal-format
 #| msgid "complex invalid for %qs"
 msgid "%<long long%> invalid for %qs"
 msgstr "%qs için complex geçersiz"
 
-#: cp/decl.c:10620
+#: cp/decl.c:10644
 #, fuzzy, gcc-internal-format
 #| msgid "complex invalid for %qs"
 msgid "%<long%> invalid for %qs"
 msgstr "%qs için complex geçersiz"
 
-#: cp/decl.c:10622
+#: cp/decl.c:10646
 #, fuzzy, gcc-internal-format
 #| msgid "complex invalid for %qs"
 msgid "%<short%> invalid for %qs"
 msgstr "%qs için complex geçersiz"
 
-#: cp/decl.c:10624
+#: cp/decl.c:10648
 #, fuzzy, gcc-internal-format
 #| msgid "long, short, signed or unsigned invalid for %qs"
 msgid "%<long%> or %<short%> invalid for %qs"
 msgstr "%qs için long, short, signed ya da unsigned geçersiz"
 
-#: cp/decl.c:10626
+#: cp/decl.c:10650
 #, fuzzy, gcc-internal-format
 #| msgid "long, short, signed or unsigned invalid for %qs"
 msgid "%<long%>, %<int%>, %<short%>, or %<char%> invalid for %qs"
 msgstr "%qs için long, short, signed ya da unsigned geçersiz"
 
-#: cp/decl.c:10628
+#: cp/decl.c:10652
 #, fuzzy, gcc-internal-format
 #| msgid "long or short specified with char for %qs"
 msgid "%<long%> or %<short%> specified with char for %qs"
 msgstr "%qs için char ile long veya short belirtilmiş"
 
-#: cp/decl.c:10630
+#: cp/decl.c:10654
 #, fuzzy, gcc-internal-format
 #| msgid "long and short specified together for %qs"
 msgid "%<long%> and %<short%> specified together for %qs"
 msgstr "%qs için long ve short birlikte belirtilmiş"
 
-#: cp/decl.c:10636
+#: cp/decl.c:10660
 #, fuzzy, gcc-internal-format
 #| msgid "short, signed or unsigned invalid for %qs"
 msgid "%<short%> or %<long%> invalid for %qs"
 msgstr "%qs için short, signed veya unsigned geçersiz"
 
-#: cp/decl.c:10644
+#: cp/decl.c:10668
 #, gcc-internal-format
 msgid "long, short, signed or unsigned used invalidly for %qs"
 msgstr "%qs için long, short, signed ya da unsigned geçersiz olarak kullanılmış"
 
-#: cp/decl.c:10712
+#: cp/decl.c:10736
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "%qs için complex geçersiz"
 
-#: cp/decl.c:10751
+#: cp/decl.c:10775
 #, gcc-internal-format
 msgid "template placeholder type %qT must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.c:10769
+#: cp/decl.c:10793
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "üye %qD, hem virtual hem de static olarak bildirilemez"
 
-#: cp/decl.c:10775
+#: cp/decl.c:10799
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD cannot be declared both %<virtual%> and %<constexpr%>"
 msgstr "üye %qD, hem virtual hem de static olarak bildirilemez"
 
-#: cp/decl.c:10785
+#: cp/decl.c:10809
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "typedef bildirimi parametre bildiriminde geçersiz"
 
-#: cp/decl.c:10790
+#: cp/decl.c:10814
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "storage class specified for template parameter %qs"
 msgstr "%qs parametresi için saklama sınıfı belirtilmiş"
 
-#: cp/decl.c:10796
+#: cp/decl.c:10820
 #, gcc-internal-format
 msgid "storage class specifiers invalid in parameter declarations"
 msgstr "saklatım sınıfı belirteçleri parametre bildiriminde geçersiz"
 
-#: cp/decl.c:10800
+#: cp/decl.c:10824
 #, fuzzy, gcc-internal-format
 #| msgid "non-member %qs cannot be declared %<mutable%>"
 msgid "a parameter cannot be declared %<concept%>"
 msgstr "üye olmayan %qs, %<mutable%> olarak bildirilemez"
 
-#: cp/decl.c:10805
+#: cp/decl.c:10829
 #, fuzzy, gcc-internal-format
 #| msgid "non-member %qs cannot be declared %<mutable%>"
 msgid "a parameter cannot be declared %<constexpr%>"
 msgstr "üye olmayan %qs, %<mutable%> olarak bildirilemez"
 
-#: cp/decl.c:10815
+#: cp/decl.c:10839
 #, fuzzy, gcc-internal-format
 #| msgid "virtual outside class declaration"
 msgid "%<virtual%> outside class declaration"
 msgstr "sanal dış sınıf bildirimi"
 
-#: cp/decl.c:10825
+#: cp/decl.c:10849
 #, fuzzy, gcc-internal-format
 #| msgid "Warn when an inlined function cannot be inlined"
 msgid "structured binding declaration cannot be %<inline%>"
 msgstr "Bir satıriçi işlev satıriçi olamadığında uyarır"
 
-#: cp/decl.c:10828
+#: cp/decl.c:10852
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %qs"
 msgid "structured binding declaration cannot be %<typedef%>"
 msgstr "%qs şablon bildirimi"
 
-#: cp/decl.c:10830
+#: cp/decl.c:10854
 #, fuzzy, gcc-internal-format
 #| msgid "Constructor can't be %s"
 msgid "structured binding declaration cannot be %<constexpr%>"
 msgstr "Kurucu %s olmayabilir"
 
-#: cp/decl.c:10834
+#: cp/decl.c:10858
 #, fuzzy, gcc-internal-format
 #| msgid "attribute ignored in declaration of %q+#T"
 msgid "structured binding declaration cannot be %qs"
 msgstr "%q+#T bildiriminde öznitelik yoksayıldı"
 
-#: cp/decl.c:10839
+#: cp/decl.c:10863
 #, fuzzy, gcc-internal-format
 #| msgid "Constructor can't be %s"
 msgid "structured binding declaration cannot be %<concept%>"
 msgstr "Kurucu %s olmayabilir"
 
-#: cp/decl.c:10845
+#: cp/decl.c:10869
 #, fuzzy, gcc-internal-format
 #| msgid "subscripting array declared %<register%>"
 msgid "structured binding declaration cannot be %<register%>"
 msgstr "%<register%> olarak bildirilmiş dizi indislemesi"
 
-#: cp/decl.c:10849
+#: cp/decl.c:10873
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<static%>"
 msgstr ""
 
-#: cp/decl.c:10853
+#: cp/decl.c:10877
 #, fuzzy, gcc-internal-format
 #| msgid "nested function %qs declared %<extern%>"
 msgid "structured binding declaration cannot be %<extern%>"
 msgstr "iç işlev %qs %<extern%> olarak bildirilmiş"
 
-#: cp/decl.c:10857
+#: cp/decl.c:10881
 #, fuzzy, gcc-internal-format
 #| msgid "function %qs cannot be declared %<mutable%>"
 msgid "structured binding declaration cannot be %<mutable%>"
 msgstr "işlev %qs %<mutable%> olarak bildirilemez"
 
-#: cp/decl.c:10861
+#: cp/decl.c:10885
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10872
+#: cp/decl.c:10896
 #, fuzzy, gcc-internal-format
 #| msgid "attribute ignored in declaration of %q+#T"
 msgid "structured binding declaration cannot have type %qT"
 msgstr "%q+#T bildiriminde öznitelik yoksayıldı"
 
-#: cp/decl.c:10875
+#: cp/decl.c:10899
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10906
+#: cp/decl.c:10930
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "%qs bildiriminde çok sayıda saklama sınıfı"
 
-#: cp/decl.c:10929
+#: cp/decl.c:10953
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "%qs için saklatım sınıfı belirtilmiş"
 
-#: cp/decl.c:10933
+#: cp/decl.c:10957
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "%qs parametresi için saklama sınıfı belirtilmiş"
 
-#: cp/decl.c:10946
+#: cp/decl.c:10970
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "iç işlev %qs %<extern%> olarak bildirilmiş"
 
-#: cp/decl.c:10950
+#: cp/decl.c:10974
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "%qs için tepe-seviye bildirim %<auto%> belirtiyor"
 
-#: cp/decl.c:10957
+#: cp/decl.c:10981
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "%qs işlevinin etki alanı dolaylı olarak auto ve %<__thread%> bildirimli"
 
-#: cp/decl.c:10969
+#: cp/decl.c:10993
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "saklatım sınıfı belirteçleri kardeş işlev bildirimlerinde geçersiz"
 
-#: cp/decl.c:11050
+#: cp/decl.c:11074
 #, fuzzy, gcc-internal-format
 #| msgid "multiple storage classes in declaration of %qs"
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "%qs bildiriminde çok sayıda saklama sınıfı"
 
-#: cp/decl.c:11098
+#: cp/decl.c:11122
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on types"
 msgid "requires-clause on return type"
 msgstr "%qE özniteliği veri türlerinde yoksayılır"
 
-#: cp/decl.c:11118
+#: cp/decl.c:11142
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.c:11121
+#: cp/decl.c:11145
 #, gcc-internal-format
 msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/decl.c:11127
+#: cp/decl.c:11151
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual function cannot have deduced return type"
 msgstr "sanal işlevler kardeş işlev olamaz"
 
-#: cp/decl.c:11134
+#: cp/decl.c:11158
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:11147
+#: cp/decl.c:11171
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "deduced class type %qD in function return type"
 msgstr "tür niteleyicileri işlev dönüş türünde yok sayıldı"
 
-#: cp/decl.c:11156
+#: cp/decl.c:11180
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr ""
 
-#: cp/decl.c:11169
+#: cp/decl.c:11193
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
@@ -48162,59 +48206,59 @@
 
 #. Not using maybe_warn_cpp0x because this should
 #. always be an error.
-#: cp/decl.c:11180
+#: cp/decl.c:11204
 #, gcc-internal-format
 msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/decl.c:11183
+#: cp/decl.c:11207
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.c:11212
+#: cp/decl.c:11236
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs işlevle dönen işlev olarak bildirilmiş"
 
-#: cp/decl.c:11218
+#: cp/decl.c:11242
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs dizi ile dönen işlev olarak bildirilmiş"
 
-#: cp/decl.c:11247
+#: cp/decl.c:11271
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "yıkıcı bir statik üye işlev olamaz"
 
-#: cp/decl.c:11248
+#: cp/decl.c:11272
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "kurucu bir statik üye işlev olamaz"
 
-#: cp/decl.c:11252
+#: cp/decl.c:11276
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "yıkıcılar cv-nitelemeli olmayabilir"
 
-#: cp/decl.c:11253
+#: cp/decl.c:11277
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "kurucular cv-nitelemeli olmayabilir"
 
-#: cp/decl.c:11261
+#: cp/decl.c:11285
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "destructors may not be ref-qualified"
 msgstr "yıkıcılar cv-nitelemeli olmayabilir"
 
-#: cp/decl.c:11262
+#: cp/decl.c:11286
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "constructors may not be ref-qualified"
 msgstr "yıkıcılar cv-nitelemeli olmayabilir"
 
-#: cp/decl.c:11280
+#: cp/decl.c:11304
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructors cannot be declared %<virtual%>"
@@ -48221,265 +48265,265 @@
 msgstr "kurucular virtual olarak bildirilemez"
 
 #. Cannot be both friend and virtual.
-#: cp/decl.c:11295
+#: cp/decl.c:11319
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "sanal işlevler kardeş işlev olamaz"
 
-#: cp/decl.c:11299
+#: cp/decl.c:11323
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "kardeş bildirimi sınıf bildiriminde değil"
 
-#: cp/decl.c:11301
+#: cp/decl.c:11325
 #, fuzzy, gcc-internal-format
 #| msgid "can't define friend function %qs in a local class definition"
 msgid "can%'t define friend function %qs in a local class definition"
 msgstr "yerel sınıf tanımı içinde kardeş işlev %qs tanımlanamaz"
 
-#: cp/decl.c:11313
+#: cp/decl.c:11337
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "a conversion function cannot have a trailing return type"
 msgstr "sanal işlevler kardeş işlev olamaz"
 
-#: cp/decl.c:11339
+#: cp/decl.c:11363
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "yıkıcılar parametre almayabilir"
 
-#: cp/decl.c:11379
+#: cp/decl.c:11403
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "%q#T türüne gösterici bildirilemez"
 
-#: cp/decl.c:11392 cp/decl.c:11399
+#: cp/decl.c:11416 cp/decl.c:11423
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "%q#T türüne başvuru bildirilemez"
 
-#: cp/decl.c:11401
+#: cp/decl.c:11425
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "%q#T üyeye gösterici bildirilemez"
 
-#: cp/decl.c:11430
+#: cp/decl.c:11454
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "%q#T türüne başvuru bildirilemez"
 
-#: cp/decl.c:11431
+#: cp/decl.c:11455
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare bit-field %qD with function type"
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "bit alanı %qD işlev türü ile bildirilemez"
 
-#: cp/decl.c:11504
+#: cp/decl.c:11528
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.c:11574
+#: cp/decl.c:11598
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "şablon kimliği %qD bir bildirici olarak kullanılmış"
 
-#: cp/decl.c:11599
+#: cp/decl.c:11623
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "üye işlevler sınıflarının örtük kardeşleridir"
 
-#: cp/decl.c:11605
+#: cp/decl.c:11629
 #, fuzzy, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "üye %2$qs üzerinde fazladan niteleme %<%1$T::%>"
 
-#: cp/decl.c:11635
+#: cp/decl.c:11659
 #, fuzzy, gcc-internal-format
 #| msgid "cannot define member function %<%T::%s%> within %<%T%>"
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "üye işlev %<%T::%s%> %<%T%> içinde tanımlanamaz"
 
-#: cp/decl.c:11637
+#: cp/decl.c:11661
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member function %<%T::%s%> within %<%T%>"
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "uye işlev %<%T::%s%> %<%T%> içinde bildirilemez"
 
-#: cp/decl.c:11645
+#: cp/decl.c:11669
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "üye %<%T::%s%> %qT içinde bildirilemez"
 
-#: cp/decl.c:11685
+#: cp/decl.c:11709
 #, fuzzy, gcc-internal-format
 #| msgid "data member %qD cannot be a member template"
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "veri üyesi %qD bir üye şablon olamaz"
 
-#: cp/decl.c:11693
+#: cp/decl.c:11717
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "veri üyesi değişken olarak değiştirilmiş %qT türünde olamayabilir"
 
-#: cp/decl.c:11695
+#: cp/decl.c:11719
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "parametre değişken olarak değiştirilmiş %qT türünde olamayabilir"
 
-#: cp/decl.c:11706
+#: cp/decl.c:11730
 #, fuzzy, gcc-internal-format
 #| msgid "virtual outside class declaration"
 msgid "%<explicit%> outside class declaration"
 msgstr "sanal dış sınıf bildirimi"
 
-#: cp/decl.c:11709
+#: cp/decl.c:11733
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<explicit%> in friend declaration"
 msgstr "boş bildirimde %<inline%>"
 
-#: cp/decl.c:11712
+#: cp/decl.c:11736
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be %<explicit%>"
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "sadece kurucuların bildirimleri %<explicit%> olabilir"
 
-#: cp/decl.c:11721
+#: cp/decl.c:11745
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "üye olmayan %qs, %<mutable%> olarak bildirilemez"
 
-#: cp/decl.c:11726
+#: cp/decl.c:11750
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "nesne olmayan üye %qs %<mutable%> olarak bildirilemez"
 
-#: cp/decl.c:11732
+#: cp/decl.c:11756
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "işlev %qs %<mutable%> olarak bildirilemez"
 
-#: cp/decl.c:11737
+#: cp/decl.c:11761
 #, gcc-internal-format
 msgid "static %qs cannot be declared %<mutable%>"
 msgstr "static %qs %<mutable%> olarak bildirilemez"
 
-#: cp/decl.c:11742
+#: cp/decl.c:11766
 #, gcc-internal-format
 msgid "const %qs cannot be declared %<mutable%>"
 msgstr "sabit %qs %<mutable%> olarak bildirilemez"
 
-#: cp/decl.c:11747
+#: cp/decl.c:11771
 #, fuzzy, gcc-internal-format
 #| msgid "function %qs cannot be declared %<mutable%>"
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "işlev %qs %<mutable%> olarak bildirilemez"
 
-#: cp/decl.c:11778
+#: cp/decl.c:11802
 #, fuzzy, gcc-internal-format
 #| msgid "typedef %q+D declared %<inline%>"
 msgid "typedef declared %<auto%>"
 msgstr "%<inline%> bildirimli typedef %q+D"
 
-#: cp/decl.c:11783
+#: cp/decl.c:11807
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.c:11787
+#: cp/decl.c:11811
 #, fuzzy, gcc-internal-format
 #| msgid "%Jtypedef name may not be a nested-name-specifier"
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "%Jtypedef ismi bir iç içe isimli belirteç olmayabilir"
 
-#: cp/decl.c:11813
+#: cp/decl.c:11837
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ISO C++ kapsayan sınıf ile aynı isimde yuvalanmış %qD türüne izin vermez"
 
-#: cp/decl.c:11900
+#: cp/decl.c:11924
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "kardeş sınıf bildirimi için %<inline%> belirtilmiş"
 
-#: cp/decl.c:11908
+#: cp/decl.c:11932
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "şablon parametreleri kardeş olamazlar"
 
-#: cp/decl.c:11910
+#: cp/decl.c:11934
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "friend bildirimi sınıf anahtarı gerektirir, %<friend class %T::%D%> gibi"
 
-#: cp/decl.c:11914
+#: cp/decl.c:11938
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "friend bildirimi %<friend %#T%> gibi bir sınıf anahtarı gerektirir"
 
-#: cp/decl.c:11927
+#: cp/decl.c:11951
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "sınıf %qT genel bağlamın kardeşi yapılmaya çalışılıyor"
 
-#: cp/decl.c:11947
+#: cp/decl.c:11971
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "üye olmayan işlev türünde niteleyiciler geçersiz"
 
-#: cp/decl.c:11951
+#: cp/decl.c:11975
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.c:11961
+#: cp/decl.c:11985
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "mutlak bildirimci %qT bildirim olarak kullanılmış"
 
-#: cp/decl.c:11976
+#: cp/decl.c:12000
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type %qT"
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "%qT işlev türüne dönüşüm geçersiz"
 
-#: cp/decl.c:11995
+#: cp/decl.c:12019
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "parametre bildiriminde %<::%> kullanılamaz"
 
-#: cp/decl.c:12001
+#: cp/decl.c:12025
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "bu kapsamda %<this%> kullanılamaz"
 
-#: cp/decl.c:12003
+#: cp/decl.c:12027
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared %<inline%>"
 msgid "parameter declared %<auto%>"
 msgstr "%<inline%> bildirimli %q+D parametresi"
 
-#: cp/decl.c:12052 cp/parser.c:3270
+#: cp/decl.c:12076 cp/parser.c:3270
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "bir argüman listesi olmaksızın %qE şablon isminin kullanımı geçersiz"
 
-#: cp/decl.c:12056
+#: cp/decl.c:12080
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "non-static data member declared with placeholder %qT"
 msgstr "statik üye %qD %<register%> olarak bildirilmiş"
 
-#: cp/decl.c:12080
+#: cp/decl.c:12104
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids zero-size array %qD"
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C++ da sıfır boyutlu %qD dizisi yasaktır"
 
-#: cp/decl.c:12083
+#: cp/decl.c:12107
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array members"
@@ -48486,177 +48530,177 @@
 msgstr "ISO C90 esnek dizi üyelerini desteklemez"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:12099
+#: cp/decl.c:12123
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "%<::%> kullanımı geçersiz"
 
-#: cp/decl.c:12121
+#: cp/decl.c:12145
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of C function %q#D conflicts with"
 msgid "declaration of function %qD in invalid context"
 msgstr "C işlevi %q#D bildirimi"
 
-#: cp/decl.c:12130
+#: cp/decl.c:12154
 #, fuzzy, gcc-internal-format
 #| msgid "function %qD declared virtual inside a union"
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "işlev %qD bir union içinde virtual olarak bildirilmiş"
 
-#: cp/decl.c:12139
+#: cp/decl.c:12163
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be declared virtual, since it is always static"
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%qD daima static olduğundan sanal olarak bildirilemez"
 
-#: cp/decl.c:12153
+#: cp/decl.c:12177
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "yıkıcı %qD için kardeş bildiriminde nitelikli isim umuluyordu"
 
-#: cp/decl.c:12160
+#: cp/decl.c:12184
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "%2$qT üyesi olarak %1$qD bildirimi"
 
-#: cp/decl.c:12166
+#: cp/decl.c:12190
 #, fuzzy, gcc-internal-format
 #| msgid "Constructor can't be %s"
 msgid "a destructor cannot be %<concept%>"
 msgstr "Kurucu %s olmayabilir"
 
-#: cp/decl.c:12171
+#: cp/decl.c:12195
 #, fuzzy, gcc-internal-format
 #| msgid "Constructor can't be %s"
 msgid "a destructor cannot be %<constexpr%>"
 msgstr "Kurucu %s olmayabilir"
 
-#: cp/decl.c:12177
+#: cp/decl.c:12201
 #, fuzzy, gcc-internal-format
 #| msgid "expected qualified name in friend declaration for destructor %qD"
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "yıkıcı %qD için kardeş bildiriminde nitelikli isim umuluyordu"
 
-#: cp/decl.c:12185
+#: cp/decl.c:12209
 #, fuzzy, gcc-internal-format
 #| msgid "Constructor can't be %s"
 msgid "a constructor cannot be %<concept%>"
 msgstr "Kurucu %s olmayabilir"
 
-#: cp/decl.c:12190
+#: cp/decl.c:12214
 #, fuzzy, gcc-internal-format
 #| msgid "constructor cannot be static member function"
 msgid "a concept cannot be a member function"
 msgstr "kurucu bir statik üye işlev olamaz"
 
-#: cp/decl.c:12199
+#: cp/decl.c:12223
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of implicitly-declared special member function"
 msgid "specialization of variable template %qD declared as function"
 msgstr "örtük bildirimli özel üye işlev özelleştirmesi"
 
-#: cp/decl.c:12202
+#: cp/decl.c:12226
 #, fuzzy, gcc-internal-format
 #| msgid "variable or field declared void"
 msgid "variable template declared here"
 msgstr "void bildirimli değişken ya da alan"
 
-#: cp/decl.c:12257
+#: cp/decl.c:12281
 #, fuzzy, gcc-internal-format
 #| msgid "field %qD has incomplete type"
 msgid "field %qD has incomplete type %qT"
 msgstr "%qD alanı içi boş türde"
 
-#: cp/decl.c:12262
+#: cp/decl.c:12286
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "%qT ismi içi boş türde"
 
-#: cp/decl.c:12272
+#: cp/decl.c:12296
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE ne işlev ne de üye işlev; friend olarak bildirilemez"
 
-#: cp/decl.c:12318
+#: cp/decl.c:12342
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "static data member %qE declared %<concept%>"
 msgstr "statik üye %qD %<register%> olarak bildirilmiş"
 
-#: cp/decl.c:12322
+#: cp/decl.c:12346
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L cannot have an initializer"
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "Yerleşik '%s' %L'de bir ilklendiriciye sahip olamaz"
 
-#: cp/decl.c:12350
+#: cp/decl.c:12374
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "non-static data member %qE declared %<concept%>"
 msgstr "statik üye %qD %<register%> olarak bildirilmiş"
 
-#: cp/decl.c:12354
+#: cp/decl.c:12378
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "non-static data member %qE declared %<constexpr%>"
 msgstr "statik üye %qD %<register%> olarak bildirilmiş"
 
-#: cp/decl.c:12409
+#: cp/decl.c:12433
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "saklama sınıfı %<auto%> %qs işlevi için geçersiz"
 
-#: cp/decl.c:12411
+#: cp/decl.c:12435
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "saklama sınıfı %<register%> %qs işlevi için geçersiz"
 
-#: cp/decl.c:12415
+#: cp/decl.c:12439
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "saklama sınıfı %<__thread%> %qs işlevi için geçersiz"
 
-#: cp/decl.c:12418
+#: cp/decl.c:12442
 #, fuzzy, gcc-internal-format
 #| msgid "storage class %<__thread%> invalid for function %qs"
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "saklama sınıfı %<__thread%> %qs işlevi için geçersiz"
 
-#: cp/decl.c:12423
+#: cp/decl.c:12447
 #, fuzzy, gcc-internal-format
 #| msgid "an asm-specification is not allowed on a function-definition"
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "bir işlev tanımında bir asm belirtimine izin verilmez"
 
-#: cp/decl.c:12434
+#: cp/decl.c:12458
 #, fuzzy, gcc-internal-format
 #| msgid "%<static%> specified invalid for function %qs declared out of global scope"
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "genel kapsam dışında bildirilen %qs işlevi için %<static%> belirteci geçersiz"
 
-#: cp/decl.c:12438
+#: cp/decl.c:12462
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "genel kapsam dışında bildirilen %qs işlevi için %<inline%> belirteci geçersiz"
 
-#: cp/decl.c:12446
+#: cp/decl.c:12470
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "sınıf olmayan sanal işlev %qs"
 
-#: cp/decl.c:12453
+#: cp/decl.c:12477
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qs defined in a non-class scope"
 msgstr "%qE özniteliği sınıf türleri dışında yoksayılır"
 
-#: cp/decl.c:12454
+#: cp/decl.c:12478
 #, fuzzy, gcc-internal-format
 #| msgid "%qD was not declared in this scope"
 msgid "%qs declared in a non-class scope"
 msgstr "%qD bu etki alanında bildirilmemiş"
 
-#: cp/decl.c:12489
+#: cp/decl.c:12513
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "üye işlev %qD static ilintilemeli olarak bildirilemez"
@@ -48663,82 +48707,82 @@
 
 #. 7.1.1: There can be no static function declarations within a
 #. block.
-#: cp/decl.c:12497
+#: cp/decl.c:12521
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "statik işlev başka bir işlevin içinde bildirilemez"
 
-#: cp/decl.c:12533
+#: cp/decl.c:12557
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "bir statik veri üyesi tanımlarken (bildirime zit olarak) %<static%> kullanılamayabilir"
 
-#: cp/decl.c:12540
+#: cp/decl.c:12564
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "statik üye %qD %<register%> olarak bildirilmiş"
 
-#: cp/decl.c:12546
+#: cp/decl.c:12570
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "üye %q#D harici ilintilemeli olarak doğrudan bildirilemez"
 
-#: cp/decl.c:12553
+#: cp/decl.c:12577
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D outside of class is not definition"
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "sınıf dışında %q#D bildirimi bir tanım değildir"
 
-#: cp/decl.c:12574
+#: cp/decl.c:12598
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D has %<extern%> and is initialized"
 msgid "declaration of %q#D has no initializer"
 msgstr "%q#D hem %<extern%> olarak bildirilmiş hem de ilklendirilmiş"
 
-#: cp/decl.c:12585
+#: cp/decl.c:12609
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs ilklendirilmiş ve %<extern%> bildirilmiş"
 
-#: cp/decl.c:12589
+#: cp/decl.c:12613
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs hem %<extern%> olarak bildirilmiş hem de ilklendrilmiş"
 
-#: cp/decl.c:12754
+#: cp/decl.c:12778
 #, fuzzy, gcc-internal-format
 #| msgid "default argument %qE uses local variable %qD"
 msgid "default argument %qE uses %qD"
 msgstr "öntanımlı argüman %qE %qD yerel değişkenini kullanıyor"
 
-#: cp/decl.c:12757
+#: cp/decl.c:12781
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "öntanımlı argüman %qE %qD yerel değişkenini kullanıyor"
 
-#: cp/decl.c:12841
+#: cp/decl.c:12865
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<virtual%> in template declaration of %q#D"
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "%<virtual%> kullanımı %q#D şablon bildiriminde geçersiz"
 
-#: cp/decl.c:12845
+#: cp/decl.c:12869
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<virtual%> in template declaration of %q#D"
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "%<virtual%> kullanımı %q#D şablon bildiriminde geçersiz"
 
-#: cp/decl.c:12868
+#: cp/decl.c:12892
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "parametre %qD geçersiz olarak yöntem türünde bildirilmiş"
 
-#: cp/decl.c:12895
+#: cp/decl.c:12919
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "parametre %1$qD bilinmeyen sınırlı %3$qT dizisine %2$s içeriyor"
 
-#: cp/decl.c:12897
+#: cp/decl.c:12921
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "parametre %1$qD bilinmeyen sınırlı %3$qT dizisine %2$s içeriyor"
@@ -48758,184 +48802,184 @@
 #. or implicitly defined), there's no need to worry about their
 #. existence.  Theoretically, they should never even be
 #. instantiated, but that's hard to forestall.
-#: cp/decl.c:13150
+#: cp/decl.c:13174
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "kurucu geçersiz; muhtemelen %<%T (const %T&)%> anlamında kullandınız"
 
-#: cp/decl.c:13228
+#: cp/decl.c:13252
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD bir isim alanı içinde bildirilemeyebilir"
 
-#: cp/decl.c:13234
+#: cp/decl.c:13258
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD static olarak bildirilemeyebilir"
 
-#: cp/decl.c:13261
+#: cp/decl.c:13285
 #, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr "%qD static olmayan bir üye işlev olmalıdır"
 
-#: cp/decl.c:13267
+#: cp/decl.c:13291
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD ya bir statik olmayan üye işlev ya da üye olmayan işlev olmalıdır"
 
-#: cp/decl.c:13277
+#: cp/decl.c:13301
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD ya bir sınıf argümanına sahip olmalı ya da enum türünde olmalı"
 
 #. 13.4.0.3
-#: cp/decl.c:13303
+#: cp/decl.c:13327
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading operator ?:"
 msgstr "ISO C++ ?: üç terimlisinin aşırı yüklenmesini yasaklar"
 
 #. Variadic.
-#: cp/decl.c:13314
+#: cp/decl.c:13338
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD değişken sayıda argümana sahip olmamalı"
 
-#: cp/decl.c:13338
+#: cp/decl.c:13362
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either zero or one argument"
 msgid "%qD must have either zero or one argument"
 msgstr "%qD ya hiç argüman almamalı ya da bir argüman almalı"
 
-#: cp/decl.c:13339
+#: cp/decl.c:13363
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either one or two arguments"
 msgid "%qD must have either one or two arguments"
 msgstr "%qD ya bir ya da iki argüman almalı"
 
-#: cp/decl.c:13350
+#: cp/decl.c:13374
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its argument"
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "sonek %qD argüman olarak %<int%> almalı"
 
-#: cp/decl.c:13351
+#: cp/decl.c:13375
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its second argument"
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "sonek %qD ikinci argümanı olarak %<int%> almalı"
 
-#: cp/decl.c:13361
+#: cp/decl.c:13385
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have no arguments"
 msgstr "%qD sadece ve sadece iki argüman almalı"
 
-#: cp/decl.c:13362 cp/decl.c:13371
+#: cp/decl.c:13386 cp/decl.c:13395
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly one argument"
 msgid "%qD must have exactly one argument"
 msgstr "%qD sadece ve sadece bir argüman almalı"
 
-#: cp/decl.c:13372
+#: cp/decl.c:13396
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have exactly two arguments"
 msgstr "%qD sadece ve sadece iki argüman almalı"
 
-#: cp/decl.c:13389 cp/decl.c:13392
+#: cp/decl.c:13413 cp/decl.c:13416
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD öntanımlı argümanlara sahip olamaz"
 
-#: cp/decl.c:13419
+#: cp/decl.c:13443
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to a reference to void will never use a type conversion operator"
 msgstr "%s%s'ya dönüşüm asla bir tür dönüşüm işleci kullanmayacak"
 
-#: cp/decl.c:13421
+#: cp/decl.c:13445
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to void will never use a type conversion operator"
 msgstr "%s%s'ya dönüşüm asla bir tür dönüşüm işleci kullanmayacak"
 
-#: cp/decl.c:13428
+#: cp/decl.c:13452
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgstr "%s%s'ya dönüşüm asla bir tür dönüşüm işleci kullanmayacak"
 
-#: cp/decl.c:13430
+#: cp/decl.c:13454
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to the same type will never use a type conversion operator"
 msgstr "%s%s'ya dönüşüm asla bir tür dönüşüm işleci kullanmayacak"
 
-#: cp/decl.c:13438
+#: cp/decl.c:13462
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgstr "%s%s'ya dönüşüm asla bir tür dönüşüm işleci kullanmayacak"
 
-#: cp/decl.c:13440
+#: cp/decl.c:13464
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to a base class will never use a type conversion operator"
 msgstr "%s%s'ya dönüşüm asla bir tür dönüşüm işleci kullanmayacak"
 
-#: cp/decl.c:13455
+#: cp/decl.c:13479
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "kullanıcı tanımlı %qD daima her iki argümanıyla birlikte değerlendirilir"
 
-#: cp/decl.c:13474
+#: cp/decl.c:13498
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "önek %qD %qT döndürmeli"
 
-#: cp/decl.c:13480
+#: cp/decl.c:13504
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "sonek %qD %qT döndürmeli"
 
-#: cp/decl.c:13492
+#: cp/decl.c:13516
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD değeriyle döndürülmeli"
 
-#: cp/decl.c:13547
+#: cp/decl.c:13571
 #, fuzzy, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "%2$qs sonrası şablon türü %1$qT parametresi kullanımı"
 
-#: cp/decl.c:13570
+#: cp/decl.c:13594
 #, fuzzy, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "%2$q+D için şablon özelleştirmesi %1$qD belirsiz"
 
-#: cp/decl.c:13573
+#: cp/decl.c:13597
 #, fuzzy, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "%2$qs sonrası typedef-ismi %1$qD kullanımı"
 
-#: cp/decl.c:13575
+#: cp/decl.c:13599
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D has a previous declaration here"
 msgid "%qD has a previous declaration here"
 msgstr "%q+D için burada önceki bir bildirim var"
 
-#: cp/decl.c:13583
+#: cp/decl.c:13607
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "%qT türüne %qs olarak başvuruluyor"
 
-#: cp/decl.c:13584 cp/decl.c:13591
+#: cp/decl.c:13608 cp/decl.c:13615
 #, fuzzy, gcc-internal-format
 #| msgid "%q+T has a previous declaration here"
 msgid "%qT has a previous declaration here"
 msgstr "%q+T için burada önceki bir bildirim var"
 
-#: cp/decl.c:13590
+#: cp/decl.c:13614
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "%qT türüne enum olarak başvuruluyor"
@@ -48947,97 +48991,97 @@
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:13605
+#: cp/decl.c:13629
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "%<%s %T%> için şablon argüman gerekli"
 
-#: cp/decl.c:13659 cp/name-lookup.c:4652
+#: cp/decl.c:13683 cp/name-lookup.c:4652
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD bildirildiği sınıf ile aynı isimde"
 
-#: cp/decl.c:13689 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6425
-#: cp/pt.c:9209
+#: cp/decl.c:13713 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6428
+#: cp/pt.c:9223
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT bir şablon değil"
 
-#: cp/decl.c:13694
+#: cp/decl.c:13718
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:13703 cp/name-lookup.c:4079 cp/name-lookup.c:4086
-#: cp/name-lookup.c:4939 cp/parser.c:6376 cp/parser.c:26300
+#: cp/decl.c:13727 cp/name-lookup.c:4079 cp/name-lookup.c:4086
+#: cp/name-lookup.c:4939 cp/parser.c:6379 cp/parser.c:26297
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "%qD ile ilişkilendirme belirsiz"
 
-#: cp/decl.c:13806
+#: cp/decl.c:13830
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "önceden bildirim olmaksızın enum %q#D kullanımı"
 
-#: cp/decl.c:13842
+#: cp/decl.c:13866
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "bir şablon olmayan olarak yeniden %qT bildirimi"
 
-#: cp/decl.c:13982
+#: cp/decl.c:14006
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "türetilmiş union %qT geçersiz"
 
-#: cp/decl.c:13989
+#: cp/decl.c:14013
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is already defined in the class %qT"
 msgid "%qT defined with multiple direct bases"
 msgstr "%qD zaten sınıf %qT içinde tanımlı"
 
-#: cp/decl.c:14000
+#: cp/decl.c:14024
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not a direct or virtual base of %qT"
 msgid "%qT defined with direct virtual base"
 msgstr "%qT türü bir doğrudan ya da dolaylı %qT tabanı değil"
 
-#: cp/decl.c:14025
+#: cp/decl.c:14049
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "taban tür %qT bir yapı veya sınıf türü olarak hatalı"
 
-#: cp/decl.c:14055
+#: cp/decl.c:14079
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "ardışık tür %qT tanımsız"
 
-#: cp/decl.c:14057
+#: cp/decl.c:14081
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "yinelenmiş taban türü %qT geçersiz"
 
-#: cp/decl.c:14202
+#: cp/decl.c:14226
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14205 cp/decl.c:14213 cp/decl.c:14225 cp/parser.c:18284
+#: cp/decl.c:14229 cp/decl.c:14237 cp/decl.c:14249 cp/parser.c:18281
 #, fuzzy, gcc-internal-format
 #| msgid "%Jprevious definition here"
 msgid "previous definition here"
 msgstr "%Jönceden burada tanımlı"
 
-#: cp/decl.c:14210
+#: cp/decl.c:14234
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14222
+#: cp/decl.c:14246
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14300
+#: cp/decl.c:14324
 #, fuzzy, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr "%2$qE işlevinin %1$d. argümanına uyumsuz gösterici türünde aktarım"
@@ -49046,84 +49090,84 @@
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:14447
+#: cp/decl.c:14471
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "%qT için simgesel sabit değerlerinin tamamını hiçbir tümleyen tür temsil edemez"
 
-#: cp/decl.c:14619
+#: cp/decl.c:14643
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qE is not an integer constant"
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "%qE için sembolik sabit değeri bir tamsayı sabit değil"
 
-#: cp/decl.c:14629
+#: cp/decl.c:14653
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qE is not an integer constant"
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "%qE için sembolik sabit değeri bir tamsayı sabit değil"
 
-#: cp/decl.c:14678
+#: cp/decl.c:14702
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C restricts enumerator values to range of %<int%>"
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "ISO C sembolik sabit grubunun değerlerini %<int%> kapsamında sınırlar"
 
-#: cp/decl.c:14679
+#: cp/decl.c:14703
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C restricts enumerator values to range of %<int%>"
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "ISO C sembolik sabit grubunun değerlerini %<int%> kapsamında sınırlar"
 
-#: cp/decl.c:14690
+#: cp/decl.c:14714
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "%qD'de simgesel sabit değerlerinde taşma"
 
-#: cp/decl.c:14710
+#: cp/decl.c:14734
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qE is not an integer constant"
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "%qE için sembolik sabit değeri bir tamsayı sabit değil"
 
-#: cp/decl.c:14821
+#: cp/decl.c:14845
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "dönüş türü %q#T bir içi boş türdür"
 
-#: cp/decl.c:14999 cp/typeck.c:9286
+#: cp/decl.c:15023 cp/typeck.c:9286
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%>, %<*this%> için bir başvuru döndürmeli"
 
-#: cp/decl.c:15344
+#: cp/decl.c:15368
 #, gcc-internal-format
 msgid "invalid function declaration"
 msgstr "işlev bildirimi geçersiz"
 
-#: cp/decl.c:15786
+#: cp/decl.c:15810
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statements in function returning %qT"
 msgstr "void olmayan dönüşlü işlevde `return' deyimi yok"
 
-#: cp/decl.c:15788 cp/typeck.c:9166
+#: cp/decl.c:15812 cp/typeck.c:9166
 #, fuzzy, gcc-internal-format
 #| msgid "function return types not compatible due to %<volatile%>"
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "işlevin dönüş türü %<volatile%> den dolayı uyumsuz"
 
-#: cp/decl.c:15996
+#: cp/decl.c:16020
 #, gcc-internal-format
 msgid "invalid member function declaration"
 msgstr "geçersiz üye işlev bildirimi"
 
-#: cp/decl.c:16010
+#: cp/decl.c:16034
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD zaten %qT sınıfında tanımlı"
 
-#: cp/decl.c:16386
+#: cp/decl.c:16410
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -49164,7 +49208,7 @@
 msgid "deleting %qT is undefined"
 msgstr "%qT silinmesi tanımsız"
 
-#: cp/decl2.c:585 cp/pt.c:5552
+#: cp/decl2.c:585 cp/pt.c:5566
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "%q#D şablon bildirimi"
@@ -49178,7 +49222,7 @@
 #. [temp.mem]
 #.
 #. A destructor shall not be a member template.
-#: cp/decl2.c:640 cp/pt.c:5511
+#: cp/decl2.c:640 cp/pt.c:5525
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "yıkıcı %qD üye şablon olarak bildirilmiş"
@@ -49366,47 +49410,47 @@
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "%<operator delete%> ilk parametreyi %qT türünde alır"
 
-#: cp/decl2.c:2660
+#: cp/decl2.c:2650
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2664
+#: cp/decl2.c:2654
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2669
+#: cp/decl2.c:2659
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2677
+#: cp/decl2.c:2667
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr ""
 
-#: cp/decl2.c:2695
+#: cp/decl2.c:2685
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2699
+#: cp/decl2.c:2689
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2704
+#: cp/decl2.c:2694
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2711
+#: cp/decl2.c:2701
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr ""
 
-#: cp/decl2.c:4309
+#: cp/decl2.c:4299
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%q#D, declared using unnamed type, is used but never defined"
@@ -49416,67 +49460,67 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4318
+#: cp/decl2.c:4308
 #, fuzzy, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr "%2$qL ilintili önceki %1$q+#D bildirimi"
 
-#: cp/decl2.c:4322
+#: cp/decl2.c:4312
 #, fuzzy, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr "%2$qL ilintili önceki %1$q+#D bildirimi"
 
-#: cp/decl2.c:4326
+#: cp/decl2.c:4316
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D does not refer to the unqualified type, so it is not used for linkage"
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr "%q+#D niteliksiz türe başvurmuyor, dolasıyla ilintileme için kullanılmaz"
 
-#: cp/decl2.c:4334
+#: cp/decl2.c:4324
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "%<static%> olarak bildirilen `%q+F hiç tanımlanmamış"
 
-#: cp/decl2.c:4338
+#: cp/decl2.c:4328
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4341
+#: cp/decl2.c:4331
 #, fuzzy, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "%2$qL ilintili önceki %1$q+#D bildirimi"
 
-#: cp/decl2.c:4529
+#: cp/decl2.c:4519
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D conflicts with previous using declaration %q#D"
 msgid "mangling of %q#D as %qE conflicts with a previous mangle"
 msgstr "%q#D önceki using bildirimi %q#D ile çelişiyor"
 
-#: cp/decl2.c:4532
+#: cp/decl2.c:4522
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D"
 msgid "previous mangling %q#D"
 msgstr "önceden %q+D bildirimi"
 
-#: cp/decl2.c:4534
+#: cp/decl2.c:4524
 #, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr ""
 
-#: cp/decl2.c:4606 cp/decl2.c:4609
+#: cp/decl2.c:4596 cp/decl2.c:4599
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.c:4956
+#: cp/decl2.c:4946
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D used but never defined"
 msgid "inline function %qD used but never defined"
 msgstr "satıriçi işlev %q+D tanımlanmadan kullanılmış"
 
-#: cp/decl2.c:5143
+#: cp/decl2.c:5133
 #, fuzzy, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr "%2$q+#D'nin %1$P. parametresi için öntanımlı argüman eksik"
@@ -49483,19 +49527,19 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5251
+#: cp/decl2.c:5241
 #, fuzzy, gcc-internal-format
 #| msgid "converting NULL to non-pointer type"
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr "NULL'dan gösterici olmayan türe dönüşüm"
 
-#: cp/decl2.c:5254
+#: cp/decl2.c:5244
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "use of deleted function %qD"
 msgstr "static olmayan üye işlev %qD kullanımı geçersiz"
 
-#: cp/decl2.c:5307
+#: cp/decl2.c:5297
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr ""
@@ -49794,48 +49838,48 @@
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr "%q#D için öntanımlı argümanın yeniden tanımı"
 
-#: cp/init.c:613
+#: cp/init.c:629
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr ""
 
-#: cp/init.c:615
+#: cp/init.c:631
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "defined here"
 msgstr "%q+#D evvelce burada tanımlanmış"
 
-#: cp/init.c:673
+#: cp/init.c:689
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initial value for member %qs"
 msgid "initializer for flexible array member %q#D"
 msgstr "üye %qs için ilk değer geçersiz"
 
-#: cp/init.c:699
+#: cp/init.c:715
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qD should be initialized in the member initialization list"
 msgid "%qD should be initialized in the member initialization list"
 msgstr "%J%qD üye ilklendirme listesinde ilklendirilmiş olmalı"
 
-#: cp/init.c:720
+#: cp/init.c:736
 #, fuzzy, gcc-internal-format
 #| msgid "class %qT is implicitly friends with itself"
 msgid "%qD is initialized with itself"
 msgstr "sınıf %T kendisiyle dolaylı kardeş"
 
-#: cp/init.c:831
+#: cp/init.c:847
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initial value for member %qs"
 msgid "invalid initializer for array member %q#D"
 msgstr "üye %qs için ilk değer geçersiz"
 
-#: cp/init.c:845 cp/init.c:869 cp/init.c:2410 cp/method.c:1368
+#: cp/init.c:861 cp/init.c:885 cp/init.c:2427 cp/method.c:1368
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const member %qD"
 msgid "uninitialized const member in %q#T"
 msgstr "ilklendirilmemiş sabit üyesi %qD"
 
-#: cp/init.c:847 cp/init.c:864 cp/init.c:871 cp/init.c:2395 cp/init.c:2423
+#: cp/init.c:863 cp/init.c:880 cp/init.c:887 cp/init.c:2412 cp/init.c:2440
 #: cp/method.c:1371 cp/method.c:1382
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D will be initialized after"
@@ -49842,311 +49886,311 @@
 msgid "%q#D should be initialized"
 msgstr "%q+D sonradan ilklendirilmiş olacak"
 
-#: cp/init.c:862 cp/init.c:2382 cp/method.c:1379
+#: cp/init.c:878 cp/init.c:2399 cp/method.c:1379
 #, fuzzy, gcc-internal-format
 #| msgid "%Juninitialized reference member %qD"
 msgid "uninitialized reference member in %q#T"
 msgstr "%Jilklendirilmemiş referans üye %qD"
 
-#: cp/init.c:1041
+#: cp/init.c:1057
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D will be initialized after"
 msgid "%qD will be initialized after"
 msgstr "%q+D sonradan ilklendirilmiş olacak"
 
-#: cp/init.c:1044
+#: cp/init.c:1060
 #, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr "taban %qT sonradan ilklendirilmiş olacak"
 
-#: cp/init.c:1048
+#: cp/init.c:1064
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D"
 msgid "  %q#D"
 msgstr "  %q+#D"
 
-#: cp/init.c:1050
+#: cp/init.c:1066
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr "  taban %qT"
 
-#: cp/init.c:1052
+#: cp/init.c:1068
 #, fuzzy, gcc-internal-format
 #| msgid "%J  when initialized here"
 msgid "  when initialized here"
 msgstr "%J  burada ilklendirildiğinde"
 
-#: cp/init.c:1069
+#: cp/init.c:1085
 #, fuzzy, gcc-internal-format
 #| msgid "%Jmultiple initializations given for %qD"
 msgid "multiple initializations given for %qD"
 msgstr "%J%qD için çok sayıda ilklendirici belirtilmiş"
 
-#: cp/init.c:1073
+#: cp/init.c:1089
 #, fuzzy, gcc-internal-format
 #| msgid "%Jmultiple initializations given for base %qT"
 msgid "multiple initializations given for base %qT"
 msgstr "%Jtaban %qT için çok sayıda ilklendirici belirtilmiş"
 
-#: cp/init.c:1158
+#: cp/init.c:1174
 #, fuzzy, gcc-internal-format
 #| msgid "%Jinitializations for multiple members of %qT"
 msgid "initializations for multiple members of %qT"
 msgstr "%J%qT'nin çok sayıda üyesi için ilklendirmeler"
 
-#: cp/init.c:1255
+#: cp/init.c:1271
 #, fuzzy, gcc-internal-format
 #| msgid "%Jbase class %q#T should be explicitly initialized in the copy constructor"
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr "%Jtaban sınıf %q#T kopyalama kurucusunda doğrudan ilklendirilmiş olmalı"
 
-#: cp/init.c:1482 cp/init.c:1501
+#: cp/init.c:1498 cp/init.c:1517
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr "sınıf %qT %qD isminde alan içermiyor"
 
-#: cp/init.c:1488
+#: cp/init.c:1504
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr "%q#D bir static veri üyesidir; sadece tanımında ilklendirilebilir"
 
-#: cp/init.c:1495
+#: cp/init.c:1511
 #, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr "%q#D %qT'nin bir static olmayan üyesi değildir"
 
-#: cp/init.c:1534
+#: cp/init.c:1550
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr "taban sınıfı olmayan %qT için isimsiz ilklendirici"
 
-#: cp/init.c:1542
+#: cp/init.c:1558
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr "çoklu miras kullanan %qT için isimsiz ilklendirici"
 
-#: cp/init.c:1589
+#: cp/init.c:1605
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr "%qD  hem doğrudan hem de dolaylı sanal taban"
 
-#: cp/init.c:1597
+#: cp/init.c:1613
 #, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr "%qT türü bir doğrudan ya da dolaylı %qT tabanı değil"
 
-#: cp/init.c:1600
+#: cp/init.c:1616
 #, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr "%qT türü bir doğrudan %qT tabanı değil"
 
-#: cp/init.c:1710 cp/init.c:4386 cp/typeck2.c:1175
+#: cp/init.c:1727 cp/init.c:4402 cp/typeck2.c:1175
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
 
-#: cp/init.c:2019 cp/semantics.c:3268
+#: cp/init.c:2036 cp/semantics.c:3271
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not have class type"
 msgid "%qT is not a class type"
 msgstr "%qE sınıf türüne sahip değil"
 
-#: cp/init.c:2075
+#: cp/init.c:2092
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr "içi boş tür %qT üye %qD'yi içermiyor"
 
-#: cp/init.c:2089
+#: cp/init.c:2106
 #, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr "%qD bit alanına gösterici geçersiz"
 
-#: cp/init.c:2175 cp/typeck.c:1893
+#: cp/init.c:2192 cp/typeck.c:1893
 #, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "static olmayan üye işlev %qD kullanımı geçersiz"
 
-#: cp/init.c:2182 cp/semantics.c:1835
+#: cp/init.c:2199 cp/semantics.c:1835
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "static olmayan veri üyesi %qD kullanımı geçersiz"
 
-#: cp/init.c:2379
+#: cp/init.c:2396
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2387
+#: cp/init.c:2404
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2391
+#: cp/init.c:2408
 #, fuzzy, gcc-internal-format
 #| msgid "%Juninitialized reference member %qD"
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr "%Jilklendirilmemiş referans üye %qD"
 
-#: cp/init.c:2407
+#: cp/init.c:2424
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const in %<new%> of %q#T"
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr "%q#T  %<new%>'u içinde ilklendirmesiz sabit"
 
-#: cp/init.c:2415
+#: cp/init.c:2432
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2419
+#: cp/init.c:2436
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const in %<new%> of %q#T"
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr "%q#T  %<new%>'u içinde ilklendirmesiz sabit"
 
-#: cp/init.c:2710
+#: cp/init.c:2727
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2721
+#: cp/init.c:2738
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2732
+#: cp/init.c:2749
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2880
+#: cp/init.c:2896
 #, fuzzy, gcc-internal-format
 #| msgid "integer overflow in expression"
 msgid "integer overflow in array size"
 msgstr "ifadede tamsayı taşması"
 
-#: cp/init.c:2890
+#: cp/init.c:2906
 #, gcc-internal-format
 msgid "array size in new-expression must be constant"
 msgstr ""
 
-#: cp/init.c:2904
+#: cp/init.c:2920
 #, gcc-internal-format
 msgid "variably modified type not allowed in new-expression"
 msgstr ""
 
-#: cp/init.c:2920
+#: cp/init.c:2936
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by typedef"
 msgstr ""
 
-#: cp/init.c:2922
+#: cp/init.c:2938
 #, fuzzy, gcc-internal-format
 #| msgid "try removing the parentheses around the type-id"
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr "tür kimliğini sarmalayan parantezleri kaldırmayı deneyin"
 
-#: cp/init.c:2932
+#: cp/init.c:2948
 #, gcc-internal-format
 msgid "invalid type %<void%> for new"
 msgstr "new için %<void%> türü geçersiz"
 
-#: cp/init.c:2975
+#: cp/init.c:2991
 #, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr "%q#T  %<new%>'u içinde ilklendirmesiz sabit"
 
-#: cp/init.c:3101
+#: cp/init.c:3117
 #, fuzzy, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr "%2$qT sınıfında uygun bir %1$qD yok"
 
-#: cp/init.c:3108 cp/search.c:1023
+#: cp/init.c:3124 cp/search.c:1026
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "üye %qD için istek belirsiz"
 
-#: cp/init.c:3181
+#: cp/init.c:3197
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr ""
 
-#: cp/init.c:3184
+#: cp/init.c:3200
 #, fuzzy, gcc-internal-format
 #| msgid "class %qT does not have any field named %qD"
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr "sınıf %qT %qD isminde alan içermiyor"
 
-#: cp/init.c:3187
+#: cp/init.c:3203
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr ""
 
-#: cp/init.c:3370
+#: cp/init.c:3386
 #, fuzzy, gcc-internal-format
 #| msgid "attributes after parenthesized initializer ignored"
 msgid "parenthesized initializer in array new"
 msgstr "parantezli ilklendiriciden sonraki öznitelikler yoksayıldı"
 
-#: cp/init.c:3633
+#: cp/init.c:3649
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr "array new içindeki boyut bütünleyici türde olmalı"
 
-#: cp/init.c:3665
+#: cp/init.c:3681
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr "new bir referans türe uygulanamaz"
 
-#: cp/init.c:3674
+#: cp/init.c:3690
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr "new bir işlev türe uygulanamaz"
 
-#: cp/init.c:3743
+#: cp/init.c:3759
 #, fuzzy, gcc-internal-format
 #| msgid "possible problem detected in invocation of delete operator:"
 msgid "possible problem detected in invocation of delete [] operator:"
 msgstr "silme işlecinin çağrısında bir sorun saptandı:"
 
-#: cp/init.c:3747
+#: cp/init.c:3763
 #, fuzzy, gcc-internal-format
 #| msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined."
 msgid "neither the destructor nor the class-specific operator delete [] will be called, even if they are declared when the class is defined"
 msgstr "sınıf tanımlanırken bildirilmiş olsalar bile, ne yıkıcı ne de sınıfa özel silme işleci çağrılır."
 
-#: cp/init.c:4295
+#: cp/init.c:4311
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "ilklendirici erken sonlanıyor"
 
-#: cp/init.c:4599
+#: cp/init.c:4615
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr "delete içindeki dizi boyutu bilinmiyor"
 
-#: cp/init.c:4623
+#: cp/init.c:4639
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete operator:"
 msgstr "silme işlecinin çağrısında bir sorun saptandı:"
 
-#: cp/init.c:4628
+#: cp/init.c:4644
 #, fuzzy, gcc-internal-format
 #| msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined."
 msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
 msgstr "sınıf tanımlanırken bildirilmiş olsalar bile, ne yıkıcı ne de sınıfa özel silme işleci çağrılır."
 
-#: cp/init.c:4642
+#: cp/init.c:4658
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4647
+#: cp/init.c:4663
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4954
+#: cp/init.c:4970
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "vektör silme işlemi için tür ne gösterici ne de dizi"
@@ -50655,7 +50699,7 @@
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr ""
 
-#: cp/name-lookup.c:5111 cp/name-lookup.c:7065
+#: cp/name-lookup.c:5111 cp/name-lookup.c:7073
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "%qD öznitelik yönergesi yoksayıldı"
@@ -50706,58 +50750,58 @@
 msgid "it was later defined here"
 msgstr "%q+#D evvelce burada tanımlanmış"
 
-#: cp/name-lookup.c:6687
+#: cp/name-lookup.c:6695
 #, gcc-internal-format
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn't a template"
 msgstr ""
 
-#: cp/name-lookup.c:7059
+#: cp/name-lookup.c:7067
 #, fuzzy, gcc-internal-format
 #| msgid "switch %qs is no longer supported"
 msgid "strong using directive no longer supported"
 msgstr "switch %qs artık desteklenmiyor"
 
-#: cp/name-lookup.c:7062
+#: cp/name-lookup.c:7070
 #, gcc-internal-format
 msgid "you may use an inline namespace instead"
 msgstr ""
 
-#: cp/name-lookup.c:7079
+#: cp/name-lookup.c:7087
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "attributes ignored on local using directive"
 msgstr "%qE özniteliği sınıf türleri dışında yoksayılır"
 
-#: cp/name-lookup.c:7163
+#: cp/name-lookup.c:7171
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "burada isim alanı rumuzu %qD kullanılamaz, %qD varsayılıyor"
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:7183
+#: cp/name-lookup.c:7191
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qD may not be declared within a namespace"
 msgid "cannot nest more than %d namespaces"
 msgstr "%qD bir isim alanı içinde bildirilemeyebilir"
 
-#: cp/name-lookup.c:7218
+#: cp/name-lookup.c:7226
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsection attribute cannot be specified for local variables"
 msgid "inline namespace must be specified at initial definition"
 msgstr "%Jbölüm özniteliği yerel değişkenler için belirtilmiş olamaz"
 
-#: cp/name-lookup.c:7219
+#: cp/name-lookup.c:7227
 #, fuzzy, gcc-internal-format
 #| msgid "label %q+D defined but not used"
 msgid "%qD defined here"
 msgstr "%q+D yaftası tanımlı ama kullanılmamış"
 
-#: cp/name-lookup.c:7292
+#: cp/name-lookup.c:7300
 #, gcc-internal-format
 msgid "XXX entering pop_everything ()\n"
 msgstr "XXX, pop_everything () işlevine giriyor\n"
 
-#: cp/name-lookup.c:7301
+#: cp/name-lookup.c:7309
 #, gcc-internal-format
 msgid "XXX leaving pop_everything ()\n"
 msgstr "XXX, pop_everything () işlevini bırakıyor\n"
@@ -50778,7 +50822,7 @@
 msgid "LEXER_DEBUGGING_ENABLED_P is not set to true"
 msgstr ""
 
-#: cp/parser.c:1352 cp/parser.c:37254
+#: cp/parser.c:1352 cp/parser.c:37251
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -50805,7 +50849,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr "sınıf olmayan %2$qT türündeki %1$qD üyesi için istek"
 
-#: cp/parser.c:2949 cp/parser.c:18221
+#: cp/parser.c:2949 cp/parser.c:18218
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> has not been declared"
 msgid "%<%T::%E%> has not been declared"
@@ -50897,7 +50941,7 @@
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/parser.c:3143 cp/pt.c:17853
+#: cp/parser.c:3143 cp/pt.c:17890
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr ""
@@ -51145,7 +51189,7 @@
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr ""
 
-#: cp/parser.c:4587 cp/parser.c:12940
+#: cp/parser.c:4587 cp/parser.c:12937
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "expected declaration"
@@ -51203,7 +51247,7 @@
 msgid "fold-expressions only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:5275 cp/parser.c:5452 cp/parser.c:5630 cp/semantics.c:3612
+#: cp/parser.c:5275 cp/parser.c:5452 cp/parser.c:5633 cp/semantics.c:3615
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "expected primary-expression"
@@ -51225,103 +51269,103 @@
 msgid "local variable %qD may not appear in this context"
 msgstr "yerel değişken %qD bu kapsamda görünemez"
 
-#: cp/parser.c:5787
+#: cp/parser.c:5790
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "expected id-expression"
 msgstr "ifade umuluyordu"
 
-#: cp/parser.c:5919
+#: cp/parser.c:5922
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a class or namespace"
 msgid "scope %qT before %<~%> is not a class-name"
 msgstr "%qT bir sınıf ya da isim alanı değil"
 
-#: cp/parser.c:5948 cp/parser.c:7860
+#: cp/parser.c:5951 cp/parser.c:7860
 #, gcc-internal-format
 msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:6059
+#: cp/parser.c:6062
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<~%T%> as member of %qT"
 msgstr "%2$qT üyesi olarak %<~%1$T%> bildirimi"
 
-#: cp/parser.c:6074
+#: cp/parser.c:6077
 #, gcc-internal-format
 msgid "typedef-name %qD used as destructor declarator"
 msgstr "typedef ismi %qD yıkıcı bildiricisi olarak kullanılmış"
 
-#: cp/parser.c:6111 cp/parser.c:20249
+#: cp/parser.c:6114 cp/parser.c:20246
 #, fuzzy, gcc-internal-format
 #| msgid "expected specifier-qualifier-list"
 msgid "expected unqualified-id"
 msgstr "belirteç niteleyici listesi umuluyordu"
 
-#: cp/parser.c:6220
+#: cp/parser.c:6223
 #, gcc-internal-format
 msgid "found %<:%> in nested-name-specifier, expected %<::%>"
 msgstr ""
 
-#: cp/parser.c:6288
+#: cp/parser.c:6291
 #, fuzzy, gcc-internal-format
 #| msgid "%qT resolves to %qT, which is not an enumeration type"
 msgid "decltype evaluates to %qT, which is not a class or enumeration type"
 msgstr "%qT bir enum türü olmayan %qT türüne çözümleniyor"
 
-#: cp/parser.c:6314
+#: cp/parser.c:6317
 #, fuzzy, gcc-internal-format
 #| msgid "incomplete type %qT used in nested name specifier"
 msgid "function template-id %qD in nested-name-specifier"
 msgstr "içi boş %qT türü alt isim belirtecinde kullanılmış"
 
-#: cp/parser.c:6322
+#: cp/parser.c:6325
 #, fuzzy, gcc-internal-format
 #| msgid "incomplete type %qT used in nested name specifier"
 msgid "variable template-id %qD in nested-name-specifier"
 msgstr "içi boş %qT türü alt isim belirtecinde kullanılmış"
 
-#: cp/parser.c:6426 cp/typeck.c:2684 cp/typeck.c:2687 cp/typeck.c:2704
+#: cp/parser.c:6429 cp/typeck.c:2684 cp/typeck.c:2687 cp/typeck.c:2704
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD bir şablon değil"
 
-#: cp/parser.c:6504
+#: cp/parser.c:6507
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "expected nested-name-specifier"
 msgstr "bildirim belirteçleri umuluyordu"
 
-#: cp/parser.c:6711 cp/parser.c:8950
+#: cp/parser.c:6714 cp/parser.c:8950
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in casts"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:6797
+#: cp/parser.c:6800
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in a %<typeid%> expression"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:6889
+#: cp/parser.c:6892
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for %qs attribute"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "%qs özniteliği için belirtilen argüman sayısı yanlış"
 
-#: cp/parser.c:6901 cp/pt.c:18416
+#: cp/parser.c:6904 cp/pt.c:18453
 #, fuzzy, gcc-internal-format
 #| msgid "wrong type argument to bit-complement"
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "bit-tümler için yanlış türde argüman"
 
-#: cp/parser.c:6995
+#: cp/parser.c:6998
 #, gcc-internal-format
 msgid "ISO C++ forbids compound-literals"
 msgstr "ISO C++ birleşik sabitlere izin vermez"
 
-#: cp/parser.c:7054
+#: cp/parser.c:7057
 #, gcc-internal-format
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
@@ -51464,7 +51508,7 @@
 msgid "capture of non-variable %qE"
 msgstr "salt-okunur değişken %qD için eksiltme"
 
-#: cp/parser.c:10391 cp/parser.c:10401 cp/semantics.c:3453 cp/semantics.c:3465
+#: cp/parser.c:10391 cp/parser.c:10401 cp/semantics.c:3456 cp/semantics.c:3468
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%q#D declared here"
@@ -51555,7 +51599,7 @@
 msgid "init-statement in selection statements only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:11546 cp/parser.c:28490
+#: cp/parser.c:11546 cp/parser.c:28487
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration or statement"
 msgid "expected selection-statement"
@@ -51578,215 +51622,215 @@
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:12250 cp/parser.c:28493
+#: cp/parser.c:12250 cp/parser.c:28490
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration or statement"
 msgid "expected iteration-statement"
 msgstr "bildirim veya deyim umuluyordu"
 
-#: cp/parser.c:12298
+#: cp/parser.c:12297
 #, gcc-internal-format
 msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/parser.c:12426
+#: cp/parser.c:12423
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr ""
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:12434
+#: cp/parser.c:12431
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ hesaplanmış goto'lara izin vermez"
 
-#: cp/parser.c:12447 cp/parser.c:28496
+#: cp/parser.c:12444 cp/parser.c:28493
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected jump-statement"
 msgstr "deyim umuluyordu"
 
-#: cp/parser.c:12620 cp/parser.c:23584
+#: cp/parser.c:12617 cp/parser.c:23581
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "fazladan %<;%>"
 
-#: cp/parser.c:12863
+#: cp/parser.c:12860
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr ""
 
-#: cp/parser.c:13083
+#: cp/parser.c:13080
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:13103
+#: cp/parser.c:13100
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr ""
 
-#: cp/parser.c:13124
+#: cp/parser.c:13121
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr "karışık bildirimler ve işlev tanımları yasaktır"
 
-#: cp/parser.c:13148
+#: cp/parser.c:13145
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in a for-range-declaration"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:13203
+#: cp/parser.c:13200
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13206
+#: cp/parser.c:13203
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13257
+#: cp/parser.c:13254
 #, gcc-internal-format
 msgid "structured bindings only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:13306
+#: cp/parser.c:13303
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "empty structured binding declaration"
 msgstr "boş bildirim"
 
-#: cp/parser.c:13324
+#: cp/parser.c:13321
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initial value for member %qs"
 msgid "invalid initializer for structured binding declaration"
 msgstr "üye %qs için ilk değer geçersiz"
 
-#: cp/parser.c:13491
+#: cp/parser.c:13488
 #, fuzzy, gcc-internal-format
 #| msgid "%<friend%> can only be specified inside a class"
 msgid "%<friend%> used outside of class"
 msgstr "%<friend%> sadece bir sınıf içinde belirtilebilir"
 
-#: cp/parser.c:13558
+#: cp/parser.c:13555
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr ""
 
-#: cp/parser.c:13594
+#: cp/parser.c:13591
 #, fuzzy, gcc-internal-format
 #| msgid "pure-specifier on function-definition"
 msgid "decl-specifier invalid in condition"
 msgstr "işlev tanımında pure belirteci"
 
-#: cp/parser.c:13600
+#: cp/parser.c:13597
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D invalid in %q#T"
 msgid "%qD invalid in lambda"
 msgstr "%q+D %q#T içinde geçersiz"
 
-#: cp/parser.c:13693
+#: cp/parser.c:13690
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "sınıf tanımı kardeş olarak bildirilemeyebilir"
 
-#: cp/parser.c:13763 cp/parser.c:24064
+#: cp/parser.c:13760 cp/parser.c:24061
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:13805
+#: cp/parser.c:13802
 #, fuzzy, gcc-internal-format
 #| msgid "invalid base-class specification"
 msgid "invalid linkage-specification"
 msgstr "taban sınıf belirtimi geçersiz"
 
-#: cp/parser.c:13909
+#: cp/parser.c:13906
 #, gcc-internal-format
 msgid "static_assert without a message only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:14111
+#: cp/parser.c:14108
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:14264
+#: cp/parser.c:14261
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in a conversion-type-id"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:14291
+#: cp/parser.c:14288
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<this%> in non-member function"
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "üye olmayan işlevde %<this%> kullanımı geçersiz"
 
-#: cp/parser.c:14295
+#: cp/parser.c:14292
 #, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr ""
 
-#: cp/parser.c:14379
+#: cp/parser.c:14376
 #, fuzzy, gcc-internal-format
 #| msgid "only constructors take base initializers"
 msgid "only constructors take member initializers"
 msgstr "temel ilklendiricileri sadece kurucular alır"
 
-#: cp/parser.c:14406
+#: cp/parser.c:14403
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "cannot expand initializer for member %qD"
 msgstr "uye %qD için ilklendirici eksik"
 
-#: cp/parser.c:14418 cp/pt.c:24255
+#: cp/parser.c:14415 cp/pt.c:24333
 #, fuzzy, gcc-internal-format
 #| msgid "static declaration of %q+D follows non-static declaration"
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "%q+D statik bildirimi statik olmayan bildirimi izliyor"
 
-#: cp/parser.c:14430 cp/pt.c:24267
+#: cp/parser.c:14427 cp/pt.c:24345
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
 
-#: cp/parser.c:14482
+#: cp/parser.c:14479
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr "artık tarih olmuş eski tarz temel sınıf ilklendiricisi"
 
-#: cp/parser.c:14552
+#: cp/parser.c:14549
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr "%<typename%> anahtar sözcüğüne bu bağlamda izin verilmez (bir nitelikli üye ilklendirici örtük olarak bir tür olduğundan)"
 
-#: cp/parser.c:14927
+#: cp/parser.c:14924
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr ""
 
-#: cp/parser.c:14933
+#: cp/parser.c:14930
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier"
 msgid "expected suffix identifier"
 msgstr "betimleyici umuluyordu"
 
-#: cp/parser.c:14942
+#: cp/parser.c:14939
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr ""
 
-#: cp/parser.c:14948
+#: cp/parser.c:14945
 #, fuzzy, gcc-internal-format
 #| msgid "invalid conditional operand"
 msgid "invalid encoding prefix in literal operator"
 msgstr "koşullu terim geçersiz"
 
-#: cp/parser.c:14975
+#: cp/parser.c:14972
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected operator"
@@ -51793,75 +51837,75 @@
 msgstr "beklenmeyen terim"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:15020
+#: cp/parser.c:15017
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "%<export%> anahtar sözcüğü gerçekleştirilmedi ve yoksayılacak"
 
-#: cp/parser.c:15190
+#: cp/parser.c:15187
 #, fuzzy, gcc-internal-format
 #| msgid "invalid catch parameter"
 msgid "invalid constrained type parameter"
 msgstr "yakalama parametresi geçersiz"
 
-#: cp/parser.c:15198
+#: cp/parser.c:15195
 #, fuzzy, gcc-internal-format
 #| msgid "invalid catch parameter"
 msgid "cv-qualified type parameter"
 msgstr "yakalama parametresi geçersiz"
 
-#: cp/parser.c:15283
+#: cp/parser.c:15280
 #, gcc-internal-format
 msgid "variadic constraint introduced without %<...%>"
 msgstr ""
 
-#: cp/parser.c:15347
+#: cp/parser.c:15344
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<virtual%> in template declaration of %q#D"
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "%<virtual%> kullanımı %q#D şablon bildiriminde geçersiz"
 
-#: cp/parser.c:15582 cp/parser.c:15668 cp/parser.c:21694
+#: cp/parser.c:15579 cp/parser.c:15665 cp/parser.c:21691
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "%qD öntanımlı argümanlara sahip olamaz"
 
-#: cp/parser.c:15586 cp/parser.c:15672
+#: cp/parser.c:15583 cp/parser.c:15669
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "template parameter packs cannot have default arguments"
 msgstr "şablon parametreleri kardeş olamazlar"
 
-#: cp/parser.c:15738
+#: cp/parser.c:15735
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected template-id"
 msgstr "deyim umuluyordu"
 
-#: cp/parser.c:15798
+#: cp/parser.c:15795
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "%<<::%> bir şablon argüman listesi başlatamaz"
 
-#: cp/parser.c:15802
+#: cp/parser.c:15799
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr "%<<:%> ile %<[%> aynı şeyi gösterir. %<<%> ile %<::%> arasında boşluk bırakın"
 
-#: cp/parser.c:15806
+#: cp/parser.c:15803
 #, fuzzy, gcc-internal-format
 #| msgid "(if you use -fpermissive G++ will accept your code)"
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr "(-fpermissive kullanırsanız G++ kodunuzu kabul edecek)"
 
-#: cp/parser.c:15924
+#: cp/parser.c:15921
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "şablon argüman listesinde çözümleme hatası"
 
 #. The name does not name a template.
-#: cp/parser.c:15992 cp/parser.c:16122 cp/parser.c:16337
+#: cp/parser.c:15989 cp/parser.c:16119 cp/parser.c:16334
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected template-name"
@@ -51868,325 +51912,325 @@
 msgstr "deyim umuluyordu"
 
 #. Explain what went wrong.
-#: cp/parser.c:16038
+#: cp/parser.c:16035
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr "şablon olarak şablon olmayan %qD kullanılmış"
 
-#: cp/parser.c:16040
+#: cp/parser.c:16037
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr "bir şablon olduğunu belirtmek için %<%T::template %D%> kullanın"
 
-#: cp/parser.c:16189
+#: cp/parser.c:16186
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers or %<...%>"
 msgid "expected parameter pack before %<...%>"
 msgstr "bildirim belirteçleri veya %<...%> umuluyordu"
 
-#: cp/parser.c:16298 cp/parser.c:16316 cp/parser.c:16483
+#: cp/parser.c:16295 cp/parser.c:16313 cp/parser.c:16480
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected template-argument"
 msgstr "deyim umuluyordu"
 
-#: cp/parser.c:16458
+#: cp/parser.c:16455
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "invalid non-type template argument"
 msgstr "tür argümanı geçersiz"
 
-#: cp/parser.c:16585
+#: cp/parser.c:16582
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type %qT"
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "şablon olmayan tür %qT'nin doğrudan örneklenimi"
 
-#: cp/parser.c:16589
+#: cp/parser.c:16586
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type %qT"
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "şablon olmayan tür %qT'nin doğrudan örneklenimi"
 
-#: cp/parser.c:16648
+#: cp/parser.c:16645
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr "C ilintileme ile şablon özelleştirmesi"
 
-#: cp/parser.c:16869
+#: cp/parser.c:16866
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "expected type specifier"
 msgstr "bildirim belirteçleri umuluyordu"
 
-#: cp/parser.c:17053
+#: cp/parser.c:17050
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:17059
+#: cp/parser.c:17056
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:17064
+#: cp/parser.c:17061
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids forward parameter declarations"
 msgid "use of %<auto%> in parameter declaration only available with -fconcepts"
 msgstr "ISO C ileriye dönük parametre bildirimlerine izin vermez"
 
-#: cp/parser.c:17209
+#: cp/parser.c:17206
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "expected template-id for type"
 msgstr "İfade türü umuluyordu"
 
-#: cp/parser.c:17278
+#: cp/parser.c:17275
 #, fuzzy, gcc-internal-format
 #| msgid "Expected name"
 msgid "expected type-name"
 msgstr "Umulmadık isim"
 
-#: cp/parser.c:17631
+#: cp/parser.c:17628
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr ""
 
-#: cp/parser.c:17854
+#: cp/parser.c:17851
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "declaration %qD does not declare anything"
 msgstr "bildirim hiçbir şey bildirmiyor"
 
-#: cp/parser.c:17942
+#: cp/parser.c:17939
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "attributes ignored on uninstantiated type"
 msgstr "%qE özniteliği sınıf türleri dışında yoksayılır"
 
-#: cp/parser.c:17946
+#: cp/parser.c:17943
 #, fuzzy, gcc-internal-format
 #| msgid "storage class %qD applied to template instantiation"
 msgid "attributes ignored on template instantiation"
 msgstr "saklama sınıfı %qD şablon örneklenimine uygulanmış"
 
-#: cp/parser.c:17951
+#: cp/parser.c:17948
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr ""
 
-#: cp/parser.c:18085
+#: cp/parser.c:18082
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%qD is an enumeration template"
 msgstr "%qD bir işlev şablonu değil"
 
-#: cp/parser.c:18096
+#: cp/parser.c:18093
 #, fuzzy, gcc-internal-format
 #| msgid "expression in new-declarator must have integral or enumeration type"
 msgid "%qD does not name an enumeration in %qT"
 msgstr "new bildirimli ifade bütünleyici ya da numaralama türünde olmalı"
 
-#: cp/parser.c:18111
+#: cp/parser.c:18108
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma%> is not allowed here"
 msgid "unnamed scoped enum is not allowed"
 msgstr "%<#pragma%> burada kullanılamaz"
 
-#: cp/parser.c:18166
+#: cp/parser.c:18163
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<;%> or %<{%>"
 msgstr "%<,%> veya %<;%> umuluyordu"
 
-#: cp/parser.c:18215
+#: cp/parser.c:18212
 #, fuzzy, gcc-internal-format
 #| msgid "Enable automatic template instantiation"
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "Özdevinimli şablon örneklenimi etkin olur"
 
-#: cp/parser.c:18229
+#: cp/parser.c:18226
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration does not name a class or function"
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "kardeş bildirimi bir sınıf veya işlevi isimlendirmiyor"
 
-#: cp/parser.c:18241 cp/parser.c:23070
+#: cp/parser.c:18238 cp/parser.c:23067
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "%3$qD'yi kapsamayan %2$qD etki alanı içinde %1$qD türünde bildirim"
 
-#: cp/parser.c:18246 cp/parser.c:23075
+#: cp/parser.c:18243 cp/parser.c:23072
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "%3$qD'yi kapsamayan %2$qD etki alanı içinde %1$qD türünde bildirim"
 
-#: cp/parser.c:18258 cp/parser.c:23089
+#: cp/parser.c:18255 cp/parser.c:23086
 #, fuzzy, gcc-internal-format
 #| msgid "extra qualification ignored"
 msgid "extra qualification not allowed"
 msgstr "fazladan niteleme yoksayıldı"
 
-#: cp/parser.c:18282
+#: cp/parser.c:18279
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "çok sayıda %q#T tanımı"
 
-#: cp/parser.c:18295
+#: cp/parser.c:18292
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing an enum"
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO C++ bir enum'um %s-lenmesine izin vermez"
 
-#: cp/parser.c:18315
+#: cp/parser.c:18312
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:18318
+#: cp/parser.c:18315
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:18497
+#: cp/parser.c:18494
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD bir isim alanı ismi değil"
 
-#: cp/parser.c:18503
+#: cp/parser.c:18500
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected namespace-name"
 msgstr "sınıf ismi umuluyordu"
 
-#: cp/parser.c:18570
+#: cp/parser.c:18567
 #, gcc-internal-format
 msgid "nested namespace definitions only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:18578
+#: cp/parser.c:18575
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "nested namespace name required"
 msgstr "sınıf ismi umuluyordu"
 
-#: cp/parser.c:18583
+#: cp/parser.c:18580
 #, gcc-internal-format
 msgid "namespace name required"
 msgstr ""
 
-#: cp/parser.c:18587
+#: cp/parser.c:18584
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma%> is not allowed here"
 msgid "a nested namespace definition cannot have attributes"
 msgstr "%<#pragma%> burada kullanılamaz"
 
-#: cp/parser.c:18590
+#: cp/parser.c:18587
 #, fuzzy, gcc-internal-format
 #| msgid "Warn when an inlined function cannot be inlined"
 msgid "a nested namespace definition cannot be inline"
 msgstr "Bir satıriçi işlev satıriçi olamadığında uyarır"
 
-#: cp/parser.c:18597
+#: cp/parser.c:18594
 #, fuzzy, gcc-internal-format
 #| msgid "use of namespace %qD as expression"
 msgid "namespace %qD entered"
 msgstr "isim alanı %qD'nin ifade olarak kullanımı"
 
-#: cp/parser.c:18652
+#: cp/parser.c:18649
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma%> is not allowed here"
 msgid "%<namespace%> definition is not allowed here"
 msgstr "%<#pragma%> burada kullanılamaz"
 
-#: cp/parser.c:18803
+#: cp/parser.c:18800
 #, gcc-internal-format
 msgid "pack expansion in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:18818
+#: cp/parser.c:18815
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "using bildiriminde bir şablon kimliği bulunamaz"
 
-#: cp/parser.c:18865
+#: cp/parser.c:18862
 #, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:18875
+#: cp/parser.c:18872
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:18940
+#: cp/parser.c:18937
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in alias template declarations"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:19106
+#: cp/parser.c:19103
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:19493
+#: cp/parser.c:19490
 #, fuzzy, gcc-internal-format
 #| msgid "%s: function definition not converted\n"
 msgid "a function-definition is not allowed here"
 msgstr "%s: işlev tanımı dönüştürülmedi\n"
 
-#: cp/parser.c:19504
+#: cp/parser.c:19501
 #, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr "bir işlev tanımında bir asm belirtimine izin verilmez"
 
-#: cp/parser.c:19508
+#: cp/parser.c:19505
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "bir işlev tanımıda özniteliklere izin verilmez"
 
-#: cp/parser.c:19559
+#: cp/parser.c:19556
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
 #. Anything else is an error.
-#: cp/parser.c:19598 cp/parser.c:21906
+#: cp/parser.c:19595 cp/parser.c:21903
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier"
 msgid "expected initializer"
 msgstr "betimleyici umuluyordu"
 
-#: cp/parser.c:19679
+#: cp/parser.c:19676
 #, fuzzy, gcc-internal-format
 #| msgid "can't initialize friend function %qs"
 msgid "initializer provided for function"
 msgstr "kardeş işlev %qs ilklendirilemiyor"
 
-#: cp/parser.c:19713
+#: cp/parser.c:19710
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "parantezli ilklendiriciden sonraki öznitelikler yoksayıldı"
 
-#: cp/parser.c:19727
+#: cp/parser.c:19724
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared as inline"
 msgid "non-function %qD declared as implicit template"
 msgstr "işlev %q+D 'inline' olarak yeniden bildirilmiş"
 
-#: cp/parser.c:20169
+#: cp/parser.c:20166
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "dizi sınırı bir tamsayı sabit değil"
 
-#: cp/parser.c:20295
+#: cp/parser.c:20292
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type %qT"
 msgid "cannot define member of dependent typedef %qT"
 msgstr "%qT üye referans türünde gösterici oluşturulması"
 
-#: cp/parser.c:20299
+#: cp/parser.c:20296
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a type"
 msgid "%<%T::%E%> is not a type"
@@ -52196,18 +52240,18 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:20328
+#: cp/parser.c:20325
 #, fuzzy, gcc-internal-format
 #| msgid "invalid function declaration"
 msgid "invalid declarator"
 msgstr "işlev bildirimi geçersiz"
 
-#: cp/parser.c:20336
+#: cp/parser.c:20333
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "kurucunun şablon olarak kullanımı geçersiz"
 
-#: cp/parser.c:20338
+#: cp/parser.c:20335
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr ""
@@ -52214,427 +52258,427 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:20410
+#: cp/parser.c:20407
 #, fuzzy, gcc-internal-format
 #| msgid "invalid function declaration"
 msgid "qualified-id in declaration"
 msgstr "işlev bildirimi geçersiz"
 
-#: cp/parser.c:20435
+#: cp/parser.c:20432
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "expected declarator"
 msgstr "bildirim belirteçleri umuluyordu"
 
-#: cp/parser.c:20554
+#: cp/parser.c:20551
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD bir isim alanıdır"
 
-#: cp/parser.c:20556
+#: cp/parser.c:20553
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "sınıf olmayan %qT türünde üye göstericisi oluşturulması"
 
-#: cp/parser.c:20577
+#: cp/parser.c:20574
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected ptr-operator"
 msgstr "beklenmeyen terim"
 
-#: cp/parser.c:20638
+#: cp/parser.c:20635
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "cv-niteleyici yinelenmiş"
 
-#: cp/parser.c:20692
+#: cp/parser.c:20689
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate cv-qualifier"
 msgid "multiple ref-qualifiers"
 msgstr "cv-niteleyici yinelenmiş"
 
-#: cp/parser.c:20729
+#: cp/parser.c:20726
 #, gcc-internal-format
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr ""
 
-#: cp/parser.c:20787
+#: cp/parser.c:20784
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate cv-qualifier"
 msgid "duplicate virt-specifier"
 msgstr "cv-niteleyici yinelenmiş"
 
-#: cp/parser.c:21025
+#: cp/parser.c:21022
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for %q#D has type %qT"
 msgid "missing template arguments after %qT"
 msgstr "%q#D için öntanımlı argüman %qT türünde"
 
-#: cp/parser.c:21031 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2090
+#: cp/parser.c:21028 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2093
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qD"
 msgid "invalid use of %qT"
 msgstr "%qD kullanımı geçersiz"
 
-#: cp/parser.c:21052
+#: cp/parser.c:21049
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in template arguments"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:21057
+#: cp/parser.c:21054
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<virtual%> in template declaration of %q#D"
 msgid "invalid use of %<auto%> in template argument"
 msgstr "%<virtual%> kullanımı %q#D şablon bildiriminde geçersiz"
 
-#: cp/parser.c:21145
+#: cp/parser.c:21142
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier"
 msgid "expected type-specifier"
 msgstr "betimleyici umuluyordu"
 
-#: cp/parser.c:21429
+#: cp/parser.c:21426
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<...%>"
 msgid "expected %<,%> or %<...%>"
 msgstr "%<:%> veya %<...%> umuluyordu"
 
-#: cp/parser.c:21504
+#: cp/parser.c:21501
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in parameter types"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:21678
+#: cp/parser.c:21675
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "öntanımlı argümanlara sadece işlev parametresi olarak izin verilir"
 
-#: cp/parser.c:21696
+#: cp/parser.c:21693
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "%qD öntanımlı argümanlara sahip olamaz"
 
-#: cp/parser.c:21702
+#: cp/parser.c:21699
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "template parameter pack cannot have a default argument"
 msgstr "şablon parametreleri kardeş olamazlar"
 
-#: cp/parser.c:21704
+#: cp/parser.c:21701
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "parameter pack cannot have a default argument"
 msgstr "%qD öntanımlı argümanlara sahip olamaz"
 
-#: cp/parser.c:22131
+#: cp/parser.c:22128
 #, gcc-internal-format
 msgid "C++ designated initializers only available with -std=c++2a or -std=gnu++2a"
 msgstr ""
 
-#: cp/parser.c:22151
+#: cp/parser.c:22148
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr "ISO C++ tasarlanmış ilkendiricilere izin vermez"
 
-#: cp/parser.c:22189
+#: cp/parser.c:22186
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C++ tasarlanmış ilkendiricilere izin vermez"
 
-#: cp/parser.c:22203
+#: cp/parser.c:22200
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr ""
 
-#: cp/parser.c:22228
+#: cp/parser.c:22225
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "%<...%> not allowed in designated initializer list"
 msgstr "ISO C++ tasarlanmış ilkendiricilere izin vermez"
 
-#: cp/parser.c:22266
+#: cp/parser.c:22263
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr ""
 
-#: cp/parser.c:22322 cp/parser.c:22448
+#: cp/parser.c:22319 cp/parser.c:22445
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected class-name"
 msgstr "sınıf ismi umuluyordu"
 
-#: cp/parser.c:22650
+#: cp/parser.c:22647
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "expected %<;%> after class definition"
 msgstr "%q+D tanımlandıktan sonra satıriçi bildirilmiş"
 
-#: cp/parser.c:22653
+#: cp/parser.c:22650
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "expected %<;%> after struct definition"
 msgstr "%q+D tanımlandıktan sonra satıriçi bildirilmiş"
 
-#: cp/parser.c:22656
+#: cp/parser.c:22653
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected junk after function declaration at %C"
 msgid "expected %<;%> after union definition"
 msgstr "%C'deki işlev bildiriminden sonra umulmayan döküntü"
 
-#: cp/parser.c:23012
+#: cp/parser.c:23009
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<{%> or %<:%>"
 msgstr "%<,%> veya %<;%> umuluyordu"
 
-#: cp/parser.c:23023
+#: cp/parser.c:23020
 #, fuzzy, gcc-internal-format
 #| msgid "cannot find file for class %s"
 msgid "cannot specify %<override%> for a class"
 msgstr "sınıf %s için dosya bulunamıyor"
 
-#: cp/parser.c:23031
+#: cp/parser.c:23028
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:23038
+#: cp/parser.c:23035
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration does not name a class or function"
 msgid "qualified name does not name a class"
 msgstr "kardeş bildirimi bir sınıf veya işlevi isimlendirmiyor"
 
-#: cp/parser.c:23050
+#: cp/parser.c:23047
 #, fuzzy, gcc-internal-format
 #| msgid "keyword %<typename%> not allowed outside of templates"
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr "şablonlar dışında %<typename%> kullanımına izin verilmez"
 
-#: cp/parser.c:23056
+#: cp/parser.c:23053
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "%qD bildirimindeki sınıf ismi geçersiz"
 
-#: cp/parser.c:23114
+#: cp/parser.c:23111
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "bir doğrudan özelleştirme %<template <>%> ile öncelenmeli"
 
-#: cp/parser.c:23146
+#: cp/parser.c:23143
 #, fuzzy, gcc-internal-format
 #| msgid "non-template %qD used as template"
 msgid "function template %qD redeclared as a class template"
 msgstr "şablon olarak şablon olmayan %qD kullanılmış"
 
-#: cp/parser.c:23182
+#: cp/parser.c:23179
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr ""
 
-#: cp/parser.c:23241
+#: cp/parser.c:23238
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+#T"
 msgid "previous definition of %q#T"
 msgstr "%q+#T türünde önceden tanım"
 
-#: cp/parser.c:23331 cp/parser.c:28499
+#: cp/parser.c:23328 cp/parser.c:28496
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected class-key"
 msgstr "sınıf ismi umuluyordu"
 
-#: cp/parser.c:23355
+#: cp/parser.c:23352
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:23359
+#: cp/parser.c:23356
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<class%> or %<typename%>"
 msgstr "%<,%> veya %<;%> umuluyordu"
 
-#: cp/parser.c:23605
+#: cp/parser.c:23602
 #, fuzzy, gcc-internal-format
 #| msgid "a class-key must be used when declaring a friend"
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr "bir kardeş bildirilirken bir sınıf anahtarı kullanılmalıdır"
 
-#: cp/parser.c:23623
+#: cp/parser.c:23620
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "kardeş bildirimi bir sınıf veya işlevi isimlendirmiyor"
 
-#: cp/parser.c:23641
+#: cp/parser.c:23638
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:23738
+#: cp/parser.c:23735
 #, gcc-internal-format
 msgid "default member initializers for bit-fields only available with -std=c++2a or -std=gnu++2a"
 msgstr ""
 
-#: cp/parser.c:23745
+#: cp/parser.c:23742
 #, fuzzy, gcc-internal-format
 #| msgid "%<__alignof%> applied to a bit-field"
 msgid "default member initializer for unnamed bit-field"
 msgstr "%<__alignof%> bir bit-alanına uygulanmış"
 
-#: cp/parser.c:23758
+#: cp/parser.c:23755
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr ""
 
-#: cp/parser.c:23903
+#: cp/parser.c:23900
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr "işlev tanımında pure belirteci"
 
-#: cp/parser.c:23923
+#: cp/parser.c:23920
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "extra %<;%> after in-class function definition"
 msgstr "%q+D tanımlandıktan sonra satıriçi bildirilmiş"
 
-#: cp/parser.c:23970
+#: cp/parser.c:23967
 #, fuzzy, gcc-internal-format
 #| msgid "cannot use %<::%> in parameter declaration"
 msgid "stray %<,%> at end of member declaration"
 msgstr "parametre bildiriminde %<::%> kullanılamaz"
 
-#: cp/parser.c:23984
+#: cp/parser.c:23981
 #, fuzzy, gcc-internal-format
 #| msgid "cannot use %<::%> in parameter declaration"
 msgid "expected %<;%> at end of member declaration"
 msgstr "parametre bildiriminde %<::%> kullanılamaz"
 
-#: cp/parser.c:24058
+#: cp/parser.c:24055
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr ""
 
-#: cp/parser.c:24093
+#: cp/parser.c:24090
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr ""
 
-#: cp/parser.c:24223
+#: cp/parser.c:24220
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr ""
 
-#: cp/parser.c:24243
+#: cp/parser.c:24240
 #, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr ""
 
-#: cp/parser.c:24267
+#: cp/parser.c:24264
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "şablonlar dışında %<typename%> kullanımına izin verilmez"
 
-#: cp/parser.c:24270
+#: cp/parser.c:24267
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "%<typename%> anahtar sözcüğüne bu bağlamda izin verilmez (taban sınıfı örtük olarak bir türdür)"
 
-#: cp/parser.c:24364 cp/parser.c:24442
+#: cp/parser.c:24361 cp/parser.c:24439
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in an exception-specification"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:24450
+#: cp/parser.c:24447
 #, fuzzy, gcc-internal-format
 #| msgid "Generate code to check exception specifications"
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "Olağan dışılık belirtimlerini sınayacak kod üretilir"
 
-#: cp/parser.c:24456
+#: cp/parser.c:24453
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr ""
 
-#: cp/parser.c:24500
+#: cp/parser.c:24497
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<this%> in non-member function"
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "üye olmayan işlevde %<this%> kullanımı geçersiz"
 
-#: cp/parser.c:24539
+#: cp/parser.c:24536
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:24650
+#: cp/parser.c:24647
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in exception-declarations"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:25203
+#: cp/parser.c:25200
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr "%s özniteliği ile %s özniteliği %L'de çelişiyor"
 
-#: cp/parser.c:25217
+#: cp/parser.c:25214
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier or %<(%>"
 msgid "expected an identifier for the attribute name"
 msgstr "betimleyici veya %<(%> umuluyordu"
 
-#: cp/parser.c:25301
+#: cp/parser.c:25298
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:25305
+#: cp/parser.c:25302
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:25342
+#: cp/parser.c:25339
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers or %<...%>"
 msgid "expected attribute before %<...%>"
 msgstr "bildirim belirteçleri veya %<...%> umuluyordu"
 
-#: cp/parser.c:25403
+#: cp/parser.c:25400
 #, gcc-internal-format
 msgid "attribute using prefix only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:25721
+#: cp/parser.c:25718
 #, gcc-internal-format
 msgid "%<requires%> only available with -fconcepts"
 msgstr ""
 
-#: cp/parser.c:25753
+#: cp/parser.c:25750
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "a requires expression cannot appear outside a template"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/parser.c:26467
+#: cp/parser.c:26464
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:26472
+#: cp/parser.c:26469
 #, fuzzy, gcc-internal-format
 #| msgid "invalid redeclaration of %q+D"
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "yeniden %q+D bildirimi geçersiz"
 
-#: cp/parser.c:26476
+#: cp/parser.c:26473
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "şablon parametresi listesi çok az"
@@ -52643,459 +52687,459 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:26483
+#: cp/parser.c:26480
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "şablon parametresi listesi çok fazla"
 
-#: cp/parser.c:26832
+#: cp/parser.c:26829
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "isimli dönüş değerleri artık desteklenmiyor"
 
-#: cp/parser.c:26991
+#: cp/parser.c:26988
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr ""
 
-#: cp/parser.c:26996
+#: cp/parser.c:26993
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr ""
 
-#: cp/parser.c:27066
+#: cp/parser.c:27063
 #, fuzzy, gcc-internal-format
 #| msgid "Enable fused multiply/add instructions"
 msgid "empty introduction-list"
 msgstr "Birleşik çarpma/toplama komutları etkinleştirilir"
 
-#: cp/parser.c:27090
+#: cp/parser.c:27087
 #, fuzzy, gcc-internal-format
 #| msgid "no matching template for %qD found"
 msgid "no matching concept for template-introduction"
 msgstr "%qD için eşleşen bir şablon yok"
 
-#: cp/parser.c:27112
+#: cp/parser.c:27109
 #, fuzzy, gcc-internal-format
 #| msgid "invalid declaration of member template %q#D in local class"
 msgid "invalid declaration of member template in local class"
 msgstr "yerel sınıf içinde %q#D üye şablonu bildirimi geçersiz"
 
-#: cp/parser.c:27121
+#: cp/parser.c:27118
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "C ilintilemeli şablon"
 
-#: cp/parser.c:27141
+#: cp/parser.c:27138
 #, fuzzy, gcc-internal-format
 #| msgid "invalid base-class specification"
 msgid "invalid explicit specialization"
 msgstr "taban sınıf belirtimi geçersiz"
 
-#: cp/parser.c:27245
+#: cp/parser.c:27242
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %qs"
 msgid "template declaration of %<typedef%>"
 msgstr "%qs şablon bildirimi"
 
-#: cp/parser.c:27296
+#: cp/parser.c:27293
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "a class template declaration must not declare anything else"
 msgstr "bildirim hiçbir şey bildirmiyor"
 
-#: cp/parser.c:27342
+#: cp/parser.c:27339
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization in non-namespace scope %qD"
 msgid "explicit template specialization cannot have a storage class"
 msgstr "isim alanı olmayan %qD kapsamında doğrudan özelleştirme"
 
-#: cp/parser.c:27650
+#: cp/parser.c:27647
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<>>%> should be %<> >%> within a nested template argument list"
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%H%<>>%> alt şablon argüman listesinde %<> >%> olmalıydı"
 
-#: cp/parser.c:27663
+#: cp/parser.c:27660
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "sahte  %<>>%>, bir şablon argüman listesini sonlandırmak için %<>%> kullanın"
 
-#: cp/parser.c:27958
+#: cp/parser.c:27955
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:28118
+#: cp/parser.c:28115
 #, fuzzy, gcc-internal-format
 #| msgid "invalid base-class specification"
 msgid "invalid use of %qD in linkage specification"
 msgstr "taban sınıf belirtimi geçersiz"
 
-#: cp/parser.c:28133
+#: cp/parser.c:28130
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> before %<extern%>"
 msgid "%<__thread%> before %qD"
 msgstr "%<extern%> öncesinde %<__thread%>"
 
-#: cp/parser.c:28267
+#: cp/parser.c:28264
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not support %<long long%>"
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ %<long long%> desteklemez"
 
-#: cp/parser.c:28275
+#: cp/parser.c:28272
 #, fuzzy, gcc-internal-format
 #| msgid "both %<short%> and %<char%> in declaration specifiers"
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "bildirim belirteçlerinde hem %<short%> hem de %<char%>"
 
-#: cp/parser.c:28280
+#: cp/parser.c:28277
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %qE"
 msgid "duplicate %qD"
 msgstr "%qE yinelenmiş"
 
-#: cp/parser.c:28304
+#: cp/parser.c:28301
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "%qs yinelenmiş"
 
-#: cp/parser.c:28356
+#: cp/parser.c:28353
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<new%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:28359
+#: cp/parser.c:28356
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<delete%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:28362
+#: cp/parser.c:28359
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<return%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:28368
+#: cp/parser.c:28365
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<extern%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:28371
+#: cp/parser.c:28368
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected %<static_assert%>"
 msgstr "deyim umuluyordu"
 
-#: cp/parser.c:28374
+#: cp/parser.c:28371
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<decltype%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:28377
+#: cp/parser.c:28374
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<operator%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:28380
+#: cp/parser.c:28377
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<class%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:28383
+#: cp/parser.c:28380
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<template%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:28386
+#: cp/parser.c:28383
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<namespace%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:28389
+#: cp/parser.c:28386
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<using%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:28392
+#: cp/parser.c:28389
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<asm%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:28395
+#: cp/parser.c:28392
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<try%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:28398
+#: cp/parser.c:28395
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<catch%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:28401
+#: cp/parser.c:28398
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<throw%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:28404
+#: cp/parser.c:28401
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<__label__%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:28407
+#: cp/parser.c:28404
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@try%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:28410
+#: cp/parser.c:28407
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@synchronized%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:28413
+#: cp/parser.c:28410
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@throw%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:28416
+#: cp/parser.c:28413
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.c:28419
+#: cp/parser.c:28416
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr ""
 
-#: cp/parser.c:28451
+#: cp/parser.c:28448
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<::%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:28463
+#: cp/parser.c:28460
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<...%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:28466
+#: cp/parser.c:28463
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<*%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:28469
+#: cp/parser.c:28466
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<~%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:28475
+#: cp/parser.c:28472
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<...%>"
 msgid "expected %<:%> or %<::%>"
 msgstr "%<:%> veya %<...%> umuluyordu"
 
-#: cp/parser.c:28502
+#: cp/parser.c:28499
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "%<,%>, %<;%> veya %<}%> umuluyordu"
 
-#: cp/parser.c:28772
+#: cp/parser.c:28769
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "%qs yaftası %q#T isimlemesinde kullanılmış"
 
-#: cp/parser.c:28777
+#: cp/parser.c:28774
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously declared here"
 msgid "%q#T was previously declared here"
 msgstr "%q+#D evvelce burada bildirilmiş"
 
-#: cp/parser.c:28798
+#: cp/parser.c:28795
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD farklı erişimle tekrar bildirilmiş"
 
-#: cp/parser.c:28819
+#: cp/parser.c:28816
 #, fuzzy, gcc-internal-format
 #| msgid "%<template%> (as a disambiguator) is only allowed within templates"
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "%<template%> (bir belirsizlik giderici olarak) sadece şablonlarda kullanılabilir"
 
-#: cp/parser.c:29062
+#: cp/parser.c:29059
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "öntanımlı argüman içinde dosya sonu"
 
-#: cp/parser.c:29303 cp/parser.c:30620 cp/parser.c:30808
+#: cp/parser.c:29300 cp/parser.c:30617 cp/parser.c:30805
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "yanlış yere konmuş %<@%D%> Nesnel-C++ oluşumu"
 
-#: cp/parser.c:29372
+#: cp/parser.c:29369
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr ""
 
-#: cp/parser.c:29442
+#: cp/parser.c:29439
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:29473
+#: cp/parser.c:29470
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "%<@encode%> bir argüman olarak bir tür belirtmeli"
 
-#: cp/parser.c:29883
+#: cp/parser.c:29880
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "Nesnel-C++ seçici ismi geçersiz"
 
-#: cp/parser.c:29958 cp/parser.c:29976
+#: cp/parser.c:29955 cp/parser.c:29973
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "objective-c++ method declaration is expected"
 msgstr "bildirim belirteçleri umuluyordu"
 
-#: cp/parser.c:29970 cp/parser.c:30035
+#: cp/parser.c:29967 cp/parser.c:30032
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsection attribute cannot be specified for local variables"
 msgid "method attributes must be specified at the end"
 msgstr "%Jbölüm özniteliği yerel değişkenler için belirtilmiş olamaz"
 
-#: cp/parser.c:30078
+#: cp/parser.c:30075
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:30284 cp/parser.c:30291 cp/parser.c:30298
+#: cp/parser.c:30281 cp/parser.c:30288 cp/parser.c:30295
 #, fuzzy, gcc-internal-format
 #| msgid "illegal reference type specified for instance variable %qs"
 msgid "invalid type for instance variable"
 msgstr "gerçekleme değişkeni %qs için ilişkilendirme türü kuraldışı"
 
-#: cp/parser.c:30413
+#: cp/parser.c:30410
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "%<@protocol%> sonrasında betimleyici umuluyordu"
 
-#: cp/parser.c:30585
+#: cp/parser.c:30582
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:30592
+#: cp/parser.c:30589
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored for %qE"
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "%qE özniteliği %qE için yoksayıldı"
 
-#: cp/parser.c:30867 cp/parser.c:30874 cp/parser.c:30881
+#: cp/parser.c:30864 cp/parser.c:30871 cp/parser.c:30878
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "invalid type for property"
 msgstr "tür argümanı geçersiz"
 
-#: cp/parser.c:32011
+#: cp/parser.c:32008
 #, fuzzy, gcc-internal-format
 #| msgid "STAT expression at %C must be a variable"
 msgid "%<wait%> expression must be integral"
 msgstr "%C'deki STAT ifadesi bir değişken olmalıdır"
 
-#: cp/parser.c:32724
+#: cp/parser.c:32721
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid reduction-identifier"
 msgstr "geçersiz ilklendirici"
 
-#: cp/parser.c:34911
+#: cp/parser.c:34908
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:35231 cp/pt.c:16392
+#: cp/parser.c:35228 cp/pt.c:16414
 #, fuzzy, gcc-internal-format
 #| msgid "register variable %qD used in nested function"
 msgid "iteration variable %qD should not be reduction"
 msgstr "yazmaç değişkeni %qD iç işlevde kullanılmış"
 
-#: cp/parser.c:35316
+#: cp/parser.c:35313
 #, fuzzy, gcc-internal-format
 #| msgid "not enough type information"
 msgid "not enough for loops to collapse"
 msgstr "tür bilgisi yetersiz"
 
-#: cp/parser.c:37521
+#: cp/parser.c:37518
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer clause"
 msgstr "geçersiz ilklendirici"
 
-#: cp/parser.c:37549
+#: cp/parser.c:37546
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "expected id-expression (arguments)"
 msgstr "ifade umuluyordu"
 
-#: cp/parser.c:37561
+#: cp/parser.c:37558
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:37662
+#: cp/parser.c:37659
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in declare reduction type list"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:37682 cp/semantics.c:5405
+#: cp/parser.c:37679 cp/semantics.c:5408
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37687 cp/semantics.c:5414
+#: cp/parser.c:37684 cp/semantics.c:5417
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37690 cp/pt.c:12944 cp/semantics.c:5420
+#: cp/parser.c:37687 cp/pt.c:12966 cp/semantics.c:5423
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37693 cp/semantics.c:5426
+#: cp/parser.c:37690 cp/semantics.c:5429
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:38047
+#: cp/parser.c:38044
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:38057
+#: cp/parser.c:38054
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qD does not refer to a namespace scope function"
@@ -53102,50 +53146,50 @@
 msgstr "%qD bir üye şablon işlevi değil"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:38392
+#: cp/parser.c:38389
 #, gcc-internal-format
 msgid "atomic_cancel"
 msgstr ""
 
-#: cp/parser.c:38435 cp/semantics.c:8575
+#: cp/parser.c:38432 cp/semantics.c:8578
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:38437 cp/semantics.c:8577
+#: cp/parser.c:38434 cp/semantics.c:8580
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:38631
+#: cp/parser.c:38628
 #, fuzzy, gcc-internal-format
 #| msgid "junk at end of %<#pragma pack%>"
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "%<#pragma pack%> sonunda döküntü"
 
-#: cp/parser.c:38927
+#: cp/parser.c:38924
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC memregs must precede any function decls"
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "#pragma GCC memregs bir işlev bildirimi ile öncelenmeli"
 
-#: cp/parser.c:38959
+#: cp/parser.c:38956
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC memregs must precede any function decls"
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr "#pragma GCC memregs bir işlev bildirimi ile öncelenmeli"
 
-#: cp/parser.c:39039
+#: cp/parser.c:39036
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "modüller arası eniyilemeler henüz C++ için gerçeklenmedi"
 
-#: cp/parser.c:39295
+#: cp/parser.c:39292
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:39351
+#: cp/parser.c:39348
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
@@ -53237,7 +53281,7 @@
 msgid "specialization of %qD after instantiation"
 msgstr "örneklenim sonrası %qD özelleştirmesi"
 
-#: cp/pt.c:1954 cp/semantics.c:5274
+#: cp/pt.c:1954 cp/semantics.c:5277
 #, fuzzy, gcc-internal-format
 #| msgid "%s %+#D"
 msgid "%s %#qD"
@@ -53417,118 +53461,118 @@
 msgid "argument to __integer_pack must be between 0 and %d"
 msgstr "%L'deki ACOS argümanı -1 .. 1 arasında olmalı"
 
-#: cp/pt.c:3942
+#: cp/pt.c:3955
 #, gcc-internal-format
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr ""
 
-#: cp/pt.c:4010
+#: cp/pt.c:4023
 #, fuzzy, gcc-internal-format
 #| msgid "data member %qD cannot be a member template"
 msgid "expansion pattern %qT contains no argument packs"
 msgstr "veri üyesi %qD bir üye şablon olamaz"
 
-#: cp/pt.c:4012
+#: cp/pt.c:4025
 #, fuzzy, gcc-internal-format
 #| msgid "data member %qD cannot be a member template"
 msgid "expansion pattern %qE contains no argument packs"
 msgstr "veri üyesi %qD bir üye şablon olamaz"
 
-#: cp/pt.c:4063
+#: cp/pt.c:4077
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr ""
 
-#: cp/pt.c:4080 cp/pt.c:4835
+#: cp/pt.c:4094 cp/pt.c:4849
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
 
-#: cp/pt.c:4082
+#: cp/pt.c:4096
 #, fuzzy, gcc-internal-format
 #| msgid "<anonymous>"
 msgid "        <anonymous>"
 msgstr "<anonim>"
 
-#: cp/pt.c:4208
+#: cp/pt.c:4222
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr "%q+D bildirimi bir parametreyi gölgeliyor"
 
-#: cp/pt.c:4211
+#: cp/pt.c:4225
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of %q+#D shadows template parameter"
 msgstr "%q+D bildirimi bir parametreyi gölgeliyor"
 
-#: cp/pt.c:4213
+#: cp/pt.c:4227
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter type %qT declared %<friend%>"
 msgid "template parameter %qD declared here"
 msgstr "şablon parametre türü %qT %<friend%> bildirimli"
 
-#: cp/pt.c:4771
+#: cp/pt.c:4785
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template %q#D"
 msgid "specialization of variable concept %q#D"
 msgstr "%q#D şablon bildirimi"
 
-#: cp/pt.c:4830
+#: cp/pt.c:4844
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "template parameters not deducible in partial specialization:"
 msgstr "kismi özelleştirmede kullanılmayan şablon parametreleri:"
 
-#: cp/pt.c:4854
+#: cp/pt.c:4868
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr "kısmi özelleştirme %qT hiç bir şablon argümanını özelleştirmiyor"
 
-#: cp/pt.c:4858
+#: cp/pt.c:4872
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:4862 cp/pt.c:4873
+#: cp/pt.c:4876 cp/pt.c:4887
 #, gcc-internal-format
 msgid "primary template here"
 msgstr ""
 
-#: cp/pt.c:4870
+#: cp/pt.c:4884
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:4885
+#: cp/pt.c:4899
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "partial specialization %qD is not more specialized than"
 msgstr "kısmi özelleştirme %qT hiç bir şablon argümanını özelleştirmiyor"
 
-#: cp/pt.c:4887
+#: cp/pt.c:4901
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate label %qD"
 msgid "primary template %qD"
 msgstr "yinelenmiş %qD yaftası"
 
-#: cp/pt.c:4934
+#: cp/pt.c:4948
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:4937
+#: cp/pt.c:4951
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:4958
+#: cp/pt.c:4972
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr "şablon argümanı %qE şablon parametre(ler)ini içine alıyor"
 
-#: cp/pt.c:5004
+#: cp/pt.c:5018
 #, fuzzy, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
@@ -53535,19 +53579,19 @@
 msgstr[0] "%2$qE şablon argümanının %1$qT türü şablon parametre(ler)ine bağımlı oluyor"
 msgstr[1] "%2$qE şablon argümanının %1$qT türü şablon parametre(ler)ine bağımlı oluyor"
 
-#: cp/pt.c:5066
+#: cp/pt.c:5080
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "%q#T için sınıf şablonu örneklenimi belirsiz"
 
-#: cp/pt.c:5070
+#: cp/pt.c:5084
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %qD after instantiation"
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "örneklenim sonrası %qD özelleştirmesi"
 
-#: cp/pt.c:5247
+#: cp/pt.c:5261
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "%qD için öntanımlı argüman yok"
@@ -53555,53 +53599,53 @@
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5269
+#: cp/pt.c:5283
 #, fuzzy, gcc-internal-format
 #| msgid "%qD used without template parameters"
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "%qD şablon parametreleri olmaksızın kullanılmış"
 
-#: cp/pt.c:5305
+#: cp/pt.c:5319
 #, fuzzy, gcc-internal-format
 #| msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "öntanımlı argümanlara kardeş şablon özelleştirmesi %qD bildiriminde izin verilmez"
 
-#: cp/pt.c:5308
+#: cp/pt.c:5322
 #, fuzzy, gcc-internal-format
 #| msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "öntanımlı argümanlara kardeş şablon özelleştirmesi %qD bildiriminde izin verilmez"
 
-#: cp/pt.c:5311
+#: cp/pt.c:5325
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/pt.c:5314
+#: cp/pt.c:5328
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "default template arguments may not be used in partial specializations"
 msgstr "kismi özelleştirmede kullanılmayan şablon parametreleri:"
 
-#: cp/pt.c:5317 cp/pt.c:5375
+#: cp/pt.c:5331 cp/pt.c:5389
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for parameter of type %qT has type %qT"
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "%qT türündeki parametre için öntanımlı argüman %qT türünde"
 
-#: cp/pt.c:5489
+#: cp/pt.c:5503
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD declared void"
 msgid "template %qD declared"
 msgstr "parametre %qD void olarak bildirilmiş"
 
-#: cp/pt.c:5496
+#: cp/pt.c:5510
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "bir isim olmaksızın şablon sınıfı"
 
-#: cp/pt.c:5504
+#: cp/pt.c:5518
 #, fuzzy, gcc-internal-format
 #| msgid "%smember function %qD cannot have cv-qualifier"
 msgid "member template %qD may not have virt-specifiers"
@@ -53612,59 +53656,59 @@
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5526
+#: cp/pt.c:5540
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "%qD şablon bildirimi geçersiz"
 
-#: cp/pt.c:5669
+#: cp/pt.c:5683
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "şablon olmayan %q#D için şablon tanımı"
 
-#: cp/pt.c:5712
+#: cp/pt.c:5726
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "%d seviye umulurken %q#D için şablon parametresi seviyesi olarak %d seviye alındı"
 
-#: cp/pt.c:5726
+#: cp/pt.c:5740
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "%d şablon parametresi %q#D için alındı"
 
-#: cp/pt.c:5729
+#: cp/pt.c:5743
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "%d şablon parametresi %q#T için alındı"
 
-#: cp/pt.c:5731
+#: cp/pt.c:5745
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  ama %d gerekiyordu"
 
-#: cp/pt.c:5752
+#: cp/pt.c:5766
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters do not match template"
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "şablon parametreleri bu şablonla uyuşmuyor:"
 
-#: cp/pt.c:5755
+#: cp/pt.c:5769
 #, fuzzy, gcc-internal-format
 #| msgid "enclosing class templates are not explicitly specialized"
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "sınıf sablonlarının kapsanması doğrudan özelleştirilmez"
 
-#: cp/pt.c:5882
+#: cp/pt.c:5896
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT bir şablon türü değil"
 
-#: cp/pt.c:5895
+#: cp/pt.c:5909
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "%qD bildiriminde şablon belirteçleri belirtilmemiş"
 
-#: cp/pt.c:5906
+#: cp/pt.c:5920
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qD used without template parameters"
 msgid "redeclared with %d template parameter"
@@ -53672,7 +53716,7 @@
 msgstr[0] "%qD şablon parametreleri olmaksızın kullanılmış"
 msgstr[1] "%qD şablon parametreleri olmaksızın kullanılmış"
 
-#: cp/pt.c:5910
+#: cp/pt.c:5924
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D here"
 msgid "previous declaration %qD used %d template parameter"
@@ -53680,12 +53724,12 @@
 msgstr[0] "buradaki önceki %q+#D bildirimi ile çelişiyor"
 msgstr[1] "buradaki önceki %q+#D bildirimi ile çelişiyor"
 
-#: cp/pt.c:5947
+#: cp/pt.c:5961
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "şablon parametresi %q+#D"
 
-#: cp/pt.c:5948
+#: cp/pt.c:5962
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "burada %q#D olarak yeniden bildirilmiş"
@@ -53694,132 +53738,132 @@
 #.
 #. A template-parameter may not be given default arguments
 #. by two different declarations in the same scope.
-#: cp/pt.c:5958
+#: cp/pt.c:5972
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "%q#D için öntanımlı argümanın yeniden tanımı"
 
-#: cp/pt.c:5960
+#: cp/pt.c:5974
 #, fuzzy, gcc-internal-format
 #| msgid "%J  original definition appeared here"
 msgid "original definition appeared here"
 msgstr "%J  ozgun tanımı burada görüldü"
 
-#: cp/pt.c:5988
+#: cp/pt.c:6002
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of %qT as a non-template"
 msgid "redeclaration %q#D with different constraints"
 msgstr "bir şablon olmayan olarak yeniden %qT bildirimi"
 
-#: cp/pt.c:5991
+#: cp/pt.c:6005
 #, fuzzy, gcc-internal-format
 #| msgid "%J  original definition appeared here"
 msgid "original declaration appeared here"
 msgstr "%J  ozgun tanımı burada görüldü"
 
-#: cp/pt.c:6250 cp/pt.c:6318
+#: cp/pt.c:6264 cp/pt.c:6332
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü o bir göstericidir"
 
-#: cp/pt.c:6253
+#: cp/pt.c:6267
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6256
+#: cp/pt.c:6270
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6268
+#: cp/pt.c:6282
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü %qD nesnesi için harici ilintileme yok"
 
-#: cp/pt.c:6272
+#: cp/pt.c:6286
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü %qD nesnesi için harici ilintileme yok"
 
-#: cp/pt.c:6321
+#: cp/pt.c:6335
 #, fuzzy, gcc-internal-format
 #| msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "(bir üye göstericisi sadece %<&%E%> ile şekillendirilebilir)"
 
-#: cp/pt.c:6323
+#: cp/pt.c:6337
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qT"
 msgid "because it is a member of %qT"
 msgstr "%qD %qT'nin bir üyesi değil"
 
-#: cp/pt.c:6383
+#: cp/pt.c:6397
 #, fuzzy, gcc-internal-format
 #| msgid "got %d template parameters for %q#D"
 msgid "  couldn't deduce template parameter %qD"
 msgstr "%d şablon parametresi %q#D için alındı"
 
-#: cp/pt.c:6392
+#: cp/pt.c:6406
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.c:6401
+#: cp/pt.c:6415
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between types %q#T and %q#T"
 msgid "  mismatched types %qT and %qT"
 msgstr "%q#T ile %q#T türleri arasında karşılaştırma"
 
-#: cp/pt.c:6410
+#: cp/pt.c:6424
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr ""
 
-#: cp/pt.c:6421
+#: cp/pt.c:6435
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %qE involves template parameter(s)"
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "şablon argümanı %qE şablon parametre(ler)ini içine alıyor"
 
-#: cp/pt.c:6431
+#: cp/pt.c:6445
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a base of %qT"
 msgid "  %qE is not equivalent to %qE"
 msgstr "%qT %qT tabanında değil"
 
-#: cp/pt.c:6440
+#: cp/pt.c:6454
 #, fuzzy, gcc-internal-format
 #| msgid "Inconsistent ranks for operator at %L and %L"
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr "%L ve %L'de işliçler için sıralar uyumsuz"
 
-#: cp/pt.c:6452
+#: cp/pt.c:6466
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.c:6456
+#: cp/pt.c:6470
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.c:6467
+#: cp/pt.c:6481
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "kısmi özelleştirme %qT hiç bir şablon argümanını özelleştirmiyor"
 
-#: cp/pt.c:6478
+#: cp/pt.c:6492
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' at %L is not allowed as an actual argument"
 msgid "  member function type %qT is not a valid template argument"
 msgstr "'%s' beyan işlevine bir fiili argüman olarak izin verilmez (%L'de)"
 
-#: cp/pt.c:6490
+#: cp/pt.c:6504
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
@@ -53826,324 +53870,324 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/pt.c:6521
+#: cp/pt.c:6535
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert type %qT to type %qT"
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "%qT türü %qT türüne dönüştürülemiyor"
 
-#: cp/pt.c:6534
+#: cp/pt.c:6548
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is an ambiguous base of %qT"
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "%qT bir belirsiz %qT tabanıdır"
 
-#: cp/pt.c:6538
+#: cp/pt.c:6552
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not derived from type %qT"
 msgid "  %qT is not derived from %qT"
 msgstr "%qT türü %qT türünden türetilmemiş"
 
-#: cp/pt.c:6549
+#: cp/pt.c:6563
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.c:6559
+#: cp/pt.c:6573
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type %qT"
 msgid "  can't deduce a template for %qT from non-template type %qT"
 msgstr "%s içi boş %qT türüne bir gösterici olamaz"
 
-#: cp/pt.c:6569
+#: cp/pt.c:6583
 #, fuzzy, gcc-internal-format
 #| msgid "argument of type %qT does not match %qT"
 msgid "  template argument %qE does not match %qE"
 msgstr "%qT türündeki argüman %qT ile eşleşmiyor"
 
-#: cp/pt.c:6609
+#: cp/pt.c:6623
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü bu bağlamda dizge sabitler kullanılamaz"
 
-#: cp/pt.c:6758
+#: cp/pt.c:6772
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for %q#D has type %qT"
 msgid "in template argument for type %qT"
 msgstr "%q#D için öntanımlı argüman %qT türünde"
 
-#: cp/pt.c:6772
+#: cp/pt.c:6786
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for %q#D has type %qT"
 msgid "template argument %qE for type %qT not a constant integer"
 msgstr "%q#D için öntanımlı argüman %qT türünde"
 
-#: cp/pt.c:6833
+#: cp/pt.c:6847
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is not a lvalue"
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil cunku o bir sol taraf terimi değil"
 
-#: cp/pt.c:6841
+#: cp/pt.c:6855
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is not a lvalue"
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil cunku o bir sol taraf terimi değil"
 
-#: cp/pt.c:6857
+#: cp/pt.c:6871
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is not a lvalue"
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil cunku o bir sol taraf terimi değil"
 
-#: cp/pt.c:6864
+#: cp/pt.c:6878
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü %qD nesnesi için harici ilintileme yok"
 
-#: cp/pt.c:6873
+#: cp/pt.c:6887
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü %qD nesnesi için harici ilintileme yok"
 
-#: cp/pt.c:6888
+#: cp/pt.c:6902
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "the address of %qD is not a valid template argument"
 msgstr "kısmi özelleştirme %qT hiç bir şablon argümanını özelleştirmiyor"
 
-#: cp/pt.c:6897
+#: cp/pt.c:6911
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr "kısmi özelleştirme %qT hiç bir şablon argümanını özelleştirmiyor"
 
-#: cp/pt.c:6904
+#: cp/pt.c:6918
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü %qD nesnesi için harici ilintileme yok"
 
-#: cp/pt.c:6933
+#: cp/pt.c:6947
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "cv nitelemesinde çeliştiğinden dolayı %qE %qT türü için geçerli bir şablon argümanı değildir"
 
-#: cp/pt.c:6941
+#: cp/pt.c:6955
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is not a lvalue"
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil cunku o bir sol taraf terimi değil"
 
-#: cp/pt.c:6959
+#: cp/pt.c:6973
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is not a constant pointer"
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü o bir sabit göstericisi değildir"
 
-#: cp/pt.c:6975
+#: cp/pt.c:6989
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "%qE is not a valid template argument for type %qT because it is not an object with linkage"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü %qD nesnesi için harici ilintileme yok"
 
-#: cp/pt.c:6986
+#: cp/pt.c:7000
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "%qE is not a valid template argument for type %qT because object %qD does not have linkage"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü %qD nesnesi için harici ilintileme yok"
 
-#: cp/pt.c:7036
+#: cp/pt.c:7050
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü o bir göstericidir"
 
-#: cp/pt.c:7038
+#: cp/pt.c:7052
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "yerine %qE kullanmayı deneyin"
 
-#: cp/pt.c:7092
+#: cp/pt.c:7106
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü %qT türündedir"
 
-#: cp/pt.c:7654
+#: cp/pt.c:7668
 #, fuzzy, gcc-internal-format
 #| msgid "applying attributes to template parameters is not implemented"
 msgid "ignoring attributes on template argument %qT"
 msgstr "özniteliklerin şablon parametrelerine uygulanması gerçeklenmedi"
 
-#: cp/pt.c:7670
+#: cp/pt.c:7684
 #, fuzzy, gcc-internal-format
 #| msgid "applying attributes to template parameters is not implemented"
 msgid "ignoring attributes in template argument %qE"
 msgstr "özniteliklerin şablon parametrelerine uygulanması gerçeklenmedi"
 
-#: cp/pt.c:7805
+#: cp/pt.c:7819
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr ""
 
-#: cp/pt.c:7834
+#: cp/pt.c:7848
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of constructor as a template"
 msgid "invalid use of destructor %qE as a type"
 msgstr "kurucunun şablon olarak kullanımı geçersiz"
 
-#: cp/pt.c:7839
+#: cp/pt.c:7853
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "bir şablon parametresinin bir tür üyesine basvurmak için %<typename %E%> kullanın"
 
-#: cp/pt.c:7855 cp/pt.c:7877 cp/pt.c:7931
+#: cp/pt.c:7869 cp/pt.c:7891 cp/pt.c:7945
 #, fuzzy, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "%2$qD için şablon parametre listesindeki %1$d. argümanda tür/değer uyumsuzluğu"
 
-#: cp/pt.c:7860
+#: cp/pt.c:7874
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  %qT türünde bir sabit umulurken %qT alındı"
 
-#: cp/pt.c:7865
+#: cp/pt.c:7879
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  bir sınıf sablonu umulurken %qE alındı"
 
-#: cp/pt.c:7868
+#: cp/pt.c:7882
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  bir tür umulurken %qE alındı"
 
-#: cp/pt.c:7882
+#: cp/pt.c:7896
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  bir tür umulurken %qT alındı"
 
-#: cp/pt.c:7885
+#: cp/pt.c:7899
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  bir sınıf sablonu umulurken %qT alındı"
 
-#: cp/pt.c:7935
+#: cp/pt.c:7949
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a template of type %qD, got %qD"
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  %qD türünde bir şablon umulurken %qD alındı"
 
-#: cp/pt.c:7949
+#: cp/pt.c:7963
 #, fuzzy, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "%2$qD için şablon parametre listesindeki %1$d. argümanda tür/değer uyumsuzluğu"
 
-#: cp/pt.c:7952
+#: cp/pt.c:7966
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a type, got %qE"
 msgid "  expected %qD but got %qD"
 msgstr "  bir tür umulurken %qE alındı"
 
-#: cp/pt.c:8012
+#: cp/pt.c:8026
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert template argument %qE to %qT"
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "şablon argümanı %qE %qT'ye dönüştürülemedi"
 
-#: cp/pt.c:8149 cp/pt.c:8465
+#: cp/pt.c:8163 cp/pt.c:8479
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "%d. şablon argümanı geçersiz"
 
-#: cp/pt.c:8164 cp/pt.c:8298
+#: cp/pt.c:8178 cp/pt.c:8312
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "yanlış sayıda şablon argümanı (%d yerine %d olmalıydı)"
 
-#: cp/pt.c:8294
+#: cp/pt.c:8308
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "yanlış sayıda şablon argümanı (%d yerine %d olmalıydı)"
 
-#: cp/pt.c:8303
+#: cp/pt.c:8317
 #, fuzzy, gcc-internal-format
 #| msgid "provided for %q+D"
 msgid "provided for %qD"
 msgstr "%q+D için sağlanmış"
 
-#: cp/pt.c:8328
+#: cp/pt.c:8342
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:8332
+#: cp/pt.c:8346
 #, fuzzy, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "öntanımlı argüman %2$q#D bildiriminin %1$d. parametresi için"
 
-#: cp/pt.c:8431
+#: cp/pt.c:8445
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:9054
+#: cp/pt.c:9068
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%q#D is not a function template"
 msgstr "%qD bir işlev şablonu değil"
 
-#: cp/pt.c:9221
+#: cp/pt.c:9235
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "şablon olarak şablon olmayan tür %qT kullanılmış"
 
-#: cp/pt.c:9223
+#: cp/pt.c:9237
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "%q+D şablon bildirimi için"
 
-#: cp/pt.c:9346
+#: cp/pt.c:9360
 #, fuzzy, gcc-internal-format
 #| msgid "internal consistency failure"
 msgid "template constraint failure"
 msgstr "dahili tutarlılık hatası"
 
-#: cp/pt.c:9697
+#: cp/pt.c:9718
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template"
 msgid "use of invalid variable template %qE"
 msgstr "%qD bir şablon değil"
 
-#: cp/pt.c:10125
+#: cp/pt.c:10148
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating %qD"
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr "%d lik azami şablon örneklenim derinliği %qD örnekleniminde aşılıyor (azami değeri arttırmak için -ftemplate-depth-NN kullanın)"
 
-#: cp/pt.c:11202
+#: cp/pt.c:11225
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in union"
 msgid "flexible array member %qD in union"
 msgstr "%Junion içinde esnek dizi üye"
 
-#: cp/pt.c:11691
+#: cp/pt.c:11713
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:12160
+#: cp/pt.c:12182
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr ""
 
-#: cp/pt.c:12163
+#: cp/pt.c:12185
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr ""
 
-#: cp/pt.c:12747
+#: cp/pt.c:12769
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for %q#D"
 msgid "  when instantiating default argument for call to %qD"
@@ -54162,294 +54206,294 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:13708
+#: cp/pt.c:13730
 #, fuzzy, gcc-internal-format
 #| msgid "variable %qD has initializer but incomplete type"
 msgid "variable %qD has function type"
 msgstr "%qD değişkeni ilklendiricili ama içi boş türde"
 
-#: cp/pt.c:13881
+#: cp/pt.c:13903
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "geçersiz parametre türü %qT"
 
-#: cp/pt.c:13883
+#: cp/pt.c:13905
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "%q+D bildiriminde"
 
-#: cp/pt.c:14001
+#: cp/pt.c:14023
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "bir dizi döndüren işlev"
 
-#: cp/pt.c:14003
+#: cp/pt.c:14025
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "bir işlev döndüren işlev"
 
-#: cp/pt.c:14043
+#: cp/pt.c:14065
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "sınıf olmayan %qT türünde üye işlev göstericisi oluşturulması"
 
-#: cp/pt.c:14637
+#: cp/pt.c:14659
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "void'e referans oluşturuluyor"
 
-#: cp/pt.c:14639
+#: cp/pt.c:14661
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type %qT"
 msgid "forming pointer to reference type %qT"
 msgstr "%s %qT referans türünde şekilleniyor"
 
-#: cp/pt.c:14641
+#: cp/pt.c:14663
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type %qT"
 msgid "forming reference to reference type %qT"
 msgstr "%s %qT referans türünde şekilleniyor"
 
-#: cp/pt.c:14654
+#: cp/pt.c:14676
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "%2$qT işlev türüne ekli %1$qV niteleyicileri yoksayılıyor"
 
-#: cp/pt.c:14657
+#: cp/pt.c:14679
 #, fuzzy, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "%2$qT işlev türüne ekli %1$qV niteleyicileri yoksayılıyor"
 
-#: cp/pt.c:14705
+#: cp/pt.c:14727
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "sınıf olmayan %qT türünde üye göstericisi oluşturulması"
 
-#: cp/pt.c:14711
+#: cp/pt.c:14733
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "%qT üye referans türünde gösterici oluşturulması"
 
-#: cp/pt.c:14717
+#: cp/pt.c:14739
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "void türünde üyeye gösterici oluşturulması"
 
-#: cp/pt.c:14783
+#: cp/pt.c:14805
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "%qT dizisi oluşturulması"
 
-#: cp/pt.c:14816
+#: cp/pt.c:14838
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT ne bir class, ne struct, ne de union türünde"
 
-#: cp/pt.c:14853
+#: cp/pt.c:14875
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT bir enum türü olmayan %qT türüne çözümleniyor"
 
-#: cp/pt.c:14861
+#: cp/pt.c:14883
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr "%qT bir sınıf türü olmayan %qT türüne çözümleniyor"
 
-#: cp/pt.c:14925
+#: cp/pt.c:14947
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.c:15000
+#: cp/pt.c:15022
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "şablonda %qs kullanımı"
 
-#: cp/pt.c:15178
+#: cp/pt.c:15200
 #, fuzzy, gcc-internal-format
 #| msgid "qualified type %qT does not match destructor name ~%qT"
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "yetkin tür %qT, yıkıcı ismi ~%qT ile eslesmiyor"
 
-#: cp/pt.c:15193
+#: cp/pt.c:15215
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "%qE bağımlı ismi bir tür olarak çözümlenmedi ama örneklenim onun bir tür olmasını istiyor"
 
-#: cp/pt.c:15195
+#: cp/pt.c:15217
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "eğer bu bir tür anlamındaysa %<typename %E%> deyin"
 
-#: cp/pt.c:15394
+#: cp/pt.c:15416
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "geçersiz alan %qD kullanımı"
 
-#: cp/pt.c:15883 cp/pt.c:17386
+#: cp/pt.c:15905 cp/pt.c:17408
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of void expression"
 msgid "invalid use of pack expansion expression"
 msgstr "void ifade kullanımı geçersiz"
 
-#: cp/pt.c:15887 cp/pt.c:17390
+#: cp/pt.c:15909 cp/pt.c:17412
 #, fuzzy, gcc-internal-format
 #| msgid "%<...%> as arguments.)"
 msgid "use %<...%> to expand argument pack"
 msgstr "%<...%> kabul edeceği varsayılacak.)"
 
-#: cp/pt.c:18334
+#: cp/pt.c:18371
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:18362
+#: cp/pt.c:18399
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:18367
+#: cp/pt.c:18404
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.c:18370
+#: cp/pt.c:18407
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a type"
 msgid "use %<%T::%D%> instead"
 msgstr "%<%T::%D%> bir tür değil"
 
-#: cp/pt.c:18375
+#: cp/pt.c:18412
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "%qD declared here, later in the translation unit"
 msgstr "%q+D tanımlandıktan sonra satıriçi bildirilmiş"
 
-#: cp/pt.c:18712
+#: cp/pt.c:18752
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT bir sınıf ya da isim alanı değil"
 
-#: cp/pt.c:18715
+#: cp/pt.c:18755
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD ne bir sınıf ne de isim alanı"
 
-#: cp/pt.c:19026
+#: cp/pt.c:19066
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is/uses anonymous type"
 msgid "%qT is/uses unnamed type"
 msgstr "%qT anonim türdür/tür kullanır"
 
-#: cp/pt.c:19028
+#: cp/pt.c:19068
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for %q#D has type %qT"
 msgid "template argument for %qD uses local type %qT"
 msgstr "%q#D için öntanımlı argüman %qT türünde"
 
-#: cp/pt.c:19038
+#: cp/pt.c:19078
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT değişkene göre değişen türde"
 
-#: cp/pt.c:19053
+#: cp/pt.c:19093
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "bütünleyen ifade %qE bir sabit değil"
 
-#: cp/pt.c:19071
+#: cp/pt.c:19111
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  %qD örneklenmeye çalışılıyor"
 
-#: cp/pt.c:22972
+#: cp/pt.c:23050
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#T"
 msgstr "%q#T için sınıf şablonu örneklenimi belirsiz"
 
-#: cp/pt.c:22974
+#: cp/pt.c:23052
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#D"
 msgstr "%q#T için sınıf şablonu örneklenimi belirsiz"
 
-#: cp/pt.c:22980
+#: cp/pt.c:23058
 #, fuzzy
 #| msgid "%s %+#D"
 msgid "%s %#qS"
 msgstr "%s %+#D"
 
-#: cp/pt.c:23004 cp/pt.c:23091
+#: cp/pt.c:23082 cp/pt.c:23169
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "şablon olmayan %q#D'nin doğrudan örneklenimi"
 
-#: cp/pt.c:23023
+#: cp/pt.c:23101
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D is not a non-static data member of %qT"
 msgid "%qD is not a static data member of a class template"
 msgstr "%q#D %qT'nin bir static olmayan üyesi değildir"
 
-#: cp/pt.c:23029 cp/pt.c:23086
+#: cp/pt.c:23107 cp/pt.c:23164
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "%qD için eşleşen bir şablon yok"
 
-#: cp/pt.c:23034
+#: cp/pt.c:23112
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type %qT"
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "şablon olmayan tür %qT'nin doğrudan örneklenimi"
 
-#: cp/pt.c:23042
+#: cp/pt.c:23120
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "%q#D'nin doğrudan örneklenimi"
 
-#: cp/pt.c:23078
+#: cp/pt.c:23156
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "yinelenmiş doğrudan %q#D örneklenimi"
 
-#: cp/pt.c:23101 cp/pt.c:23187
+#: cp/pt.c:23179 cp/pt.c:23265
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids the use of %<extern%> on explicit instantiations"
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ doğrudan örneklenimlerde %<extern%> kullanımına izin vermez"
 
-#: cp/pt.c:23106 cp/pt.c:23204
+#: cp/pt.c:23184 cp/pt.c:23282
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "saklama sınıfı %qD şablon örneklenimine uygulanmış"
 
-#: cp/pt.c:23163
+#: cp/pt.c:23241
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template %q#D"
 msgid "explicit instantiation of non-class template %qD"
 msgstr "şablon olmayan %q#D'nin doğrudan örneklenimi"
 
-#: cp/pt.c:23165
+#: cp/pt.c:23243
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "şablon olmayan tür %qT'nin doğrudan örneklenimi"
 
-#: cp/pt.c:23174
+#: cp/pt.c:23252
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "şablon tanımından önce %q#T'nin doğrudan örneklenimi"
 
-#: cp/pt.c:23192
+#: cp/pt.c:23270
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ doğrudan örneklenimlerde %qE kullanımına izin vermez"
 
-#: cp/pt.c:23238
+#: cp/pt.c:23316
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "yinelenmiş doğrudan %q#T örneklenimi"
 
-#: cp/pt.c:23536
+#: cp/pt.c:23614
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "exception specification of %qD depends on itself"
@@ -54462,120 +54506,120 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:23842
+#: cp/pt.c:23920
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "bir tanımlama olmadan %qD'nin doğrudan örneklenimi"
 
-#: cp/pt.c:24043
+#: cp/pt.c:24121
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth-NN to increase the maximum)"
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr "%d lik azami şablon örneklenim derinliği %q+D örnekleniminde aşılıyor (azami değeri arttırmak için -ftemplate-depth-NN kullanın)"
 
-#: cp/pt.c:24418
+#: cp/pt.c:24496
 #, fuzzy, gcc-internal-format
 #| msgid "invalid catch parameter"
 msgid "invalid template non-type parameter"
 msgstr "yakalama parametresi geçersiz"
 
-#: cp/pt.c:24420
+#: cp/pt.c:24498
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a valid type for a template constant parameter"
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T bir şablon sabiti parametresi için geçerli bir tür değildir"
 
-#: cp/pt.c:25723
+#: cp/pt.c:25802
 #, fuzzy, gcc-internal-format
 #| msgid "keyword %<typename%> not allowed outside of templates"
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "şablonlar dışında %<typename%> kullanımına izin verilmez"
 
-#: cp/pt.c:25961
+#: cp/pt.c:26040
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/pt.c:26440
+#: cp/pt.c:26519
 #, fuzzy, gcc-internal-format
 #| msgid "non-template %qD used as template"
 msgid "non-class template %qT used without template arguments"
 msgstr "şablon olarak şablon olmayan %qD kullanılmış"
 
-#: cp/pt.c:26586
+#: cp/pt.c:26665
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:26593
+#: cp/pt.c:26672
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü %qD nesnesi için harici ilintileme yok"
 
-#: cp/pt.c:26607
+#: cp/pt.c:26686
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "class template argument deduction failed:"
 msgstr "%d. şablon argümanı geçersiz"
 
-#: cp/pt.c:26614
+#: cp/pt.c:26693
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "işlev satıriçine alınma sırasında görmezden gelinir"
 
-#: cp/pt.c:26676
+#: cp/pt.c:26755
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:26679
+#: cp/pt.c:26758
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:26711
+#: cp/pt.c:26790
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/pt.c:26746
+#: cp/pt.c:26825
 #, fuzzy, gcc-internal-format
 #| msgid "invalid covariant return type for %q+#D"
 msgid "unable to deduce lambda return type from %qE"
 msgstr "%q+#D için ortak değişen dönüş türü geçersiz"
 
-#: cp/pt.c:26748
+#: cp/pt.c:26827
 #, fuzzy, gcc-internal-format
 #| msgid "unable to emulate %qs"
 msgid "unable to deduce %qT from %qE"
 msgstr "%qs öykünümü mümkün değil"
 
-#: cp/pt.c:26781
+#: cp/pt.c:26860
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:26785
+#: cp/pt.c:26864
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "komut kendi kısıtlarını gözönüne almıyor:"
 
-#: cp/pt.c:26789
+#: cp/pt.c:26868
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "komut kendi kısıtlarını gözönüne almıyor:"
 
-#: cp/pt.c:26793
+#: cp/pt.c:26872
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "komut kendi kısıtlarını gözönüne almıyor:"
 
-#: cp/pt.c:26912
+#: cp/pt.c:26991
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<virtual%> in template declaration of %q#D"
 msgid "invalid use of %qT in template argument"
@@ -54637,86 +54681,86 @@
 msgid "cannot dynamic_cast %qE (of type %q#T) to type %q#T (%s)"
 msgstr "%2$q#T türündeki %1$qE'nin %3$q#T türüne özdevimli dönüşümü yapılamaz (%4$s)"
 
-#: cp/search.c:240
+#: cp/search.c:243
 #, gcc-internal-format
 msgid "%qT is an ambiguous base of %qT"
 msgstr "%qT bir belirsiz %qT tabanıdır"
 
-#: cp/search.c:256
+#: cp/search.c:259
 #, gcc-internal-format
 msgid "%qT is an inaccessible base of %qT"
 msgstr "%qT, bir erişilemeyen %qT tabanıdır"
 
-#: cp/search.c:1905
+#: cp/search.c:1908
 #, fuzzy, gcc-internal-format
 #| msgid "invalid covariant return type for %q+#D"
 msgid "invalid covariant return type for %q#D"
 msgstr "%q+#D için ortak değişen dönüş türü geçersiz"
 
-#: cp/search.c:1907 cp/search.c:1922 cp/search.c:1928 cp/search.c:1957
+#: cp/search.c:1910 cp/search.c:1925 cp/search.c:1931 cp/search.c:1960
 #, fuzzy, gcc-internal-format
 #| msgid "shadowing %s function %q#D"
 msgid "overridden function is %q#D"
 msgstr "%s %q#D işlevini gölgeliyor"
 
-#: cp/search.c:1920
+#: cp/search.c:1923
 #, gcc-internal-format
 msgid "invalid covariant return type for %q+#D"
 msgstr "%q+#D için ortak değişen dönüş türü geçersiz"
 
-#: cp/search.c:1926
+#: cp/search.c:1929
 #, gcc-internal-format
 msgid "conflicting return type specified for %q+#D"
 msgstr "%q+#D için belirtilen dönüş türü çelişiyor"
 
-#: cp/search.c:1942
+#: cp/search.c:1945
 #, gcc-internal-format
 msgid "looser throw specifier for %q+#F"
 msgstr "%q+#F için throw belirteci daha gevşek"
 
-#: cp/search.c:1944
+#: cp/search.c:1947
 #, fuzzy, gcc-internal-format
 #| msgid "shadowing %s function %q#D"
 msgid "overridden function is %q#F"
 msgstr "%s %q#D işlevini gölgeliyor"
 
-#: cp/search.c:1955
+#: cp/search.c:1958
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting return type specified for %q+#D"
 msgid "conflicting type attributes specified for %q+#D"
 msgstr "%q+#D için belirtilen dönüş türü çelişiyor"
 
-#: cp/search.c:1972
+#: cp/search.c:1975
 #, fuzzy, gcc-internal-format
 #| msgid "%qD was declared %<extern%> and later %<static%>"
 msgid "%qD declared %<transaction_safe_dynamic%>"
 msgstr "%qD önce %<extern%> sonra da %<static%> bildirilmiş"
 
-#: cp/search.c:1974
+#: cp/search.c:1977
 #, fuzzy, gcc-internal-format
 #| msgid "variable %q+D declared %<inline%>"
 msgid "overriding %qD declared %<transaction_safe%>"
 msgstr "%<inline%> bildirimli %q+D değişkeni"
 
-#: cp/search.c:1981
+#: cp/search.c:1984
 #, fuzzy, gcc-internal-format
 #| msgid "virtual non-class function %qs"
 msgid "deleted function %q+D overriding non-deleted function"
 msgstr "sınıf olmayan sanal işlev %qs"
 
-#: cp/search.c:1984 cp/search.c:1992 cp/search.c:2000
+#: cp/search.c:1987 cp/search.c:1995 cp/search.c:2003
 #, fuzzy, gcc-internal-format
 #| msgid "shadowing %s function %q#D"
 msgid "overridden function is %qD"
 msgstr "%s %q#D işlevini gölgeliyor"
 
-#: cp/search.c:1989
+#: cp/search.c:1992
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "non-deleted function %q+D overriding deleted function"
 msgstr "işlev olmayan %qD ye çağrı"
 
-#: cp/search.c:1998
+#: cp/search.c:2001
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "virtual function %q+D overriding final function"
@@ -54724,12 +54768,12 @@
 
 #. A static member function cannot match an inherited
 #. virtual member function.
-#: cp/search.c:2082
+#: cp/search.c:2085
 #, gcc-internal-format
 msgid "%q+#D cannot be declared"
 msgstr "%q+#D bildirilemez"
 
-#: cp/search.c:2083
+#: cp/search.c:2086
 #, gcc-internal-format
 msgid "  since %q+#D declared in base class"
 msgstr "  `%q+#D' taban sınıfta bildirildiğinden"
@@ -54773,159 +54817,159 @@
 msgid "invalid use of member %qD in static member function"
 msgstr "statik üye işlevde üye %q+D kullanımı geçersiz"
 
-#: cp/semantics.c:2153
+#: cp/semantics.c:2156
 #, gcc-internal-format
 msgid "a statement expression is an insufficient context for overload resolution"
 msgstr ""
 
-#: cp/semantics.c:2540
+#: cp/semantics.c:2543
 #, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr "yıkıcıların argümanı olmaz"
 
-#: cp/semantics.c:2622
+#: cp/semantics.c:2625
 #, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr "statik üye işlevlerde %<this%> kullanılmaz"
 
-#: cp/semantics.c:2624
+#: cp/semantics.c:2627
 #, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr "üye olmayan işlevde %<this%> kullanımı geçersiz"
 
-#: cp/semantics.c:2626
+#: cp/semantics.c:2629
 #, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr "tepe seviyede %<this%> kullanımı geçersiz"
 
-#: cp/semantics.c:2648
+#: cp/semantics.c:2651
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "sözde yıkıcı isminde niteleyen etki alanı geçersiz"
 
-#: cp/semantics.c:2656 cp/typeck.c:2604
+#: cp/semantics.c:2659 cp/typeck.c:2604
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "yetkin tür %qT, yıkıcı ismi ~%qT ile eslesmiyor"
 
-#: cp/semantics.c:2678
+#: cp/semantics.c:2681
 #, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr "%qE %qT türünde değil"
 
-#: cp/semantics.c:2751
+#: cp/semantics.c:2754
 #, fuzzy, gcc-internal-format
 #| msgid "compound literal has variable size"
 msgid "compound literal of non-object type %qT"
 msgstr "bileşik sabit değişken boyuta sahip"
 
-#: cp/semantics.c:2892
+#: cp/semantics.c:2895
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr "şablon türü parametrelerde %<class%> ya da %<typename%> sözcüğü kullanılmalı"
 
-#: cp/semantics.c:2942
+#: cp/semantics.c:2945
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr "bir şablonun şablon parametresinin öntanımlı değeri olarak %qT türünün kullanımı geçersiz"
 
-#: cp/semantics.c:2945
+#: cp/semantics.c:2948
 #, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr "bir şablonun şablon parametresi için öntanımlı argüman geçersiz"
 
-#: cp/semantics.c:2962
+#: cp/semantics.c:2965
 #, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr "şablon parametre listesi içinde %q#T tanımı"
 
-#: cp/semantics.c:2993
+#: cp/semantics.c:2996
 #, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr "nitelikli tür %qT tanımı geçersiz"
 
-#: cp/semantics.c:3263
+#: cp/semantics.c:3266
 #, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "taban sınıf belirtimi geçersiz"
 
-#: cp/semantics.c:3423
+#: cp/semantics.c:3426
 #, fuzzy, gcc-internal-format
 #| msgid "protected member %q+#D in anonymous union"
 msgid "cannot capture member %qD of anonymous union"
 msgstr "anonim union içinde protected üye %q+#D"
 
-#: cp/semantics.c:3443 cp/semantics.c:9269
+#: cp/semantics.c:3446 cp/semantics.c:9272
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template"
 msgid "%qD is not captured"
 msgstr "%qD bir şablon değil"
 
-#: cp/semantics.c:3448
+#: cp/semantics.c:3451
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.c:3450
+#: cp/semantics.c:3453
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.c:3462
+#: cp/semantics.c:3465
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<auto%> variable from containing function"
 msgid "use of local variable with automatic storage from containing function"
 msgstr "iceren işlevden %<auto%> kullanımı"
 
-#: cp/semantics.c:3464
+#: cp/semantics.c:3467
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr "iceren işlevden parametre kullanımı"
 
-#: cp/semantics.c:3596
+#: cp/semantics.c:3599
 #, fuzzy, gcc-internal-format
 #| msgid "use of parameter from containing function"
 msgid "use of parameter outside function body"
 msgstr "iceren işlevden parametre kullanımı"
 
-#: cp/semantics.c:3606
+#: cp/semantics.c:3609
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "missing template arguments"
 msgstr "tür argümanı geçersiz"
 
-#: cp/semantics.c:3633
+#: cp/semantics.c:3636
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr "%qD şablon parametresi %qT türündeyse butunleyen ya da sırali türde olmadığından bir butunleyen sabit ifadesinde kullanılmaz"
 
-#: cp/semantics.c:3664
+#: cp/semantics.c:3667
 #, gcc-internal-format
 msgid "use of namespace %qD as expression"
 msgstr "isim alanı %qD'nin ifade olarak kullanımı"
 
-#: cp/semantics.c:3669
+#: cp/semantics.c:3672
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr "sınıf sablonu %qT'nin ifade olarak kullanımı"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:3675
+#: cp/semantics.c:3678
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "uye %qD için istek çoklu miras kafesi içinde belirsiz"
 
-#: cp/semantics.c:3702
+#: cp/semantics.c:3705
 #, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "%qD bir sabit ifadesinde bulunamaz"
 
-#: cp/semantics.c:3841
+#: cp/semantics.c:3844
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "%qE türü bilinmiyor"
 
-#: cp/semantics.c:3870
+#: cp/semantics.c:3873
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a template type"
 msgid "%qT is not an enumeration type"
@@ -54932,474 +54976,490 @@
 msgstr "%qT bir şablon türü değil"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4009
+#: cp/semantics.c:4012
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specifiers invalid in parameter declarations"
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr "saklatım sınıfı belirteçleri parametre bildiriminde geçersiz"
 
-#: cp/semantics.c:4038
+#: cp/semantics.c:4041
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr ""
 
-#: cp/semantics.c:4052
+#: cp/semantics.c:4055
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "static olmayan üye işlev %qD kullanımı geçersiz"
 
-#: cp/semantics.c:4056
+#: cp/semantics.c:4059
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "cannot apply %<offsetof%> to member function"
 msgstr "static olmayan üye işlev %qD kullanımı geçersiz"
 
-#: cp/semantics.c:4061
+#: cp/semantics.c:4064
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr "static olmayan üye işlev %qD kullanımı geçersiz"
 
-#: cp/semantics.c:4072
+#: cp/semantics.c:4075
 #, fuzzy, gcc-internal-format
 #| msgid "cannot receive objects of non-POD type %q#T through %<...%>; call will abort at runtime"
 msgid "offsetof within non-standard-layout type %qT is conditionally-supported"
 msgstr "POD olmayan %q#T türünün nesneleri %<...%> üzerinden alınamaz; çalışma anında çağrı çıkış yaptıracak"
 
-#: cp/semantics.c:4583 cp/semantics.c:6069 cp/semantics.c:6140
-#: cp/semantics.c:6183 cp/semantics.c:6533 cp/semantics.c:6632
-#: cp/semantics.c:6775
+#: cp/semantics.c:4586 cp/semantics.c:6072 cp/semantics.c:6143
+#: cp/semantics.c:6186 cp/semantics.c:6536 cp/semantics.c:6635
+#: cp/semantics.c:6778
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5271
+#: cp/semantics.c:5274
 #, fuzzy, gcc-internal-format
 #| msgid "reference to %qD is ambiguous"
 msgid "user defined reduction lookup is ambiguous"
 msgstr "%qD ile ilişkilendirme belirsiz"
 
-#: cp/semantics.c:5544
+#: cp/semantics.c:5547
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr "vektör silme işlemi için tür ne gösterici ne de dizi"
 
-#: cp/semantics.c:5592
+#: cp/semantics.c:5595
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<restrict%>"
 msgid "%qE has const type for %<reduction%>"
 msgstr "%<restrict%> kullanımı geçersiz"
 
-#: cp/semantics.c:5707
+#: cp/semantics.c:5710
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:5941
+#: cp/semantics.c:5944
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5955
+#: cp/semantics.c:5958
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5977
+#: cp/semantics.c:5980
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6080
+#: cp/semantics.c:6083
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not an accessible base of %qT"
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qT erişilebilir bir %qT tabanı değil"
 
-#: cp/semantics.c:6152
+#: cp/semantics.c:6155
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: cp/semantics.c:6195
+#: cp/semantics.c:6198
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: cp/semantics.c:6240
+#: cp/semantics.c:6243
 #, fuzzy, gcc-internal-format
 #| msgid "STAT expression at %C must be a variable"
 msgid "%<gang%> static expression must be integral"
 msgstr "%C'deki STAT ifadesi bir değişken olmalıdır"
 
-#: cp/semantics.c:6254
+#: cp/semantics.c:6257
 #, fuzzy, gcc-internal-format
 #| msgid "%s tag at %L must be of type %s"
 msgid "%<gang%> static value must be positive"
 msgstr "%s etiketi (%L'de) %s türünde olmalı"
 
-#: cp/semantics.c:6288
+#: cp/semantics.c:6291
 #, fuzzy, gcc-internal-format
 #| msgid "STAT expression at %C must be a variable"
 msgid "%<gang%> num expression must be integral"
 msgstr "%C'deki STAT ifadesi bir değişken olmalıdır"
 
-#: cp/semantics.c:6291
+#: cp/semantics.c:6294
 #, fuzzy, gcc-internal-format
 #| msgid "STAT expression at %C must be a variable"
 msgid "%<vector%> length expression must be integral"
 msgstr "%C'deki STAT ifadesi bir değişken olmalıdır"
 
-#: cp/semantics.c:6295
+#: cp/semantics.c:6298
 #, fuzzy, gcc-internal-format
 #| msgid "STAT expression at %C must be a variable"
 msgid "%<worker%> num expression must be integral"
 msgstr "%C'deki STAT ifadesi bir değişken olmalıdır"
 
-#: cp/semantics.c:6317
+#: cp/semantics.c:6320
 #, fuzzy, gcc-internal-format
 #| msgid "%s tag at %L must be of type %s"
 msgid "%<gang%> num value must be positive"
 msgstr "%s etiketi (%L'de) %s türünde olmalı"
 
-#: cp/semantics.c:6321
+#: cp/semantics.c:6324
 #, fuzzy, gcc-internal-format
 #| msgid "stack size must be an exact power of 2"
 msgid "%<vector%> length value must be positive"
 msgstr "yığıt boyutu ikinin üstel katlarında olmalı"
 
-#: cp/semantics.c:6326
+#: cp/semantics.c:6329
 #, gcc-internal-format
 msgid "%<worker%> num value must be positive"
 msgstr ""
 
-#: cp/semantics.c:6376
+#: cp/semantics.c:6379
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6406
+#: cp/semantics.c:6409
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6419
+#: cp/semantics.c:6422
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "%s ifade listesi bilesik ifade olarak ele alıniyor"
 
-#: cp/semantics.c:6438
+#: cp/semantics.c:6441
 #, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6466
+#: cp/semantics.c:6469
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6495
+#: cp/semantics.c:6498
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr ""
 
-#: cp/semantics.c:6516
+#: cp/semantics.c:6519
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6543
+#: cp/semantics.c:6546
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must not have variable number of arguments"
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qD değişken sayıda argümana sahip olmamalı"
 
-#: cp/semantics.c:6557
+#: cp/semantics.c:6560
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:6563
+#: cp/semantics.c:6566
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: cp/semantics.c:6576
+#: cp/semantics.c:6579
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6625
+#: cp/semantics.c:6628
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must not have variable number of arguments"
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr "%qD değişken sayıda argümana sahip olmamalı"
 
-#: cp/semantics.c:6910
+#: cp/semantics.c:6913
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "template %qE in clause %qs"
 msgstr "girdi dosyası sayısı çok fazla"
 
-#: cp/semantics.c:6914
+#: cp/semantics.c:6917
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6979
+#: cp/semantics.c:6982
 #, fuzzy, gcc-internal-format
 #| msgid "STAT expression at %C must be a variable"
 msgid "%<grainsize%> expression must be integral"
 msgstr "%C'deki STAT ifadesi bir değişken olmalıdır"
 
-#: cp/semantics.c:7008
+#: cp/semantics.c:7011
 #, fuzzy, gcc-internal-format
 #| msgid "STAT expression at %C must be a variable"
 msgid "%<priority%> expression must be integral"
 msgstr "%C'deki STAT ifadesi bir değişken olmalıdır"
 
-#: cp/semantics.c:7037
+#: cp/semantics.c:7040
 #, fuzzy, gcc-internal-format
 #| msgid "STAT expression at %C must be a variable"
 msgid "%<num_tasks%> expression must be integral"
 msgstr "%C'deki STAT ifadesi bir değişken olmalıdır"
 
-#: cp/semantics.c:7066
+#: cp/semantics.c:7069
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:7105
+#: cp/semantics.c:7108
 #, fuzzy, gcc-internal-format
 #| msgid "%<tree%> is not defined as a pointer type"
 msgid "%<tile%> argument needs integral type"
 msgstr "%<tree%> bir gösterici türü olarak tanımlı değil"
 
-#: cp/semantics.c:7524
+#: cp/semantics.c:7527
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.c:7538
+#: cp/semantics.c:7541
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr ""
 
-#: cp/semantics.c:7743
+#: cp/semantics.c:7746
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.c:8171
+#: cp/semantics.c:8174
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.c:8398 cp/semantics.c:8408
+#: cp/semantics.c:8401 cp/semantics.c:8411
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.c:8702
+#: cp/semantics.c:8705
 #, fuzzy, gcc-internal-format
 #| msgid "CRIS-port assertion failed: "
 msgid "static assertion failed"
 msgstr "CRIS-port olumlaması başarısız: "
 
-#: cp/semantics.c:8704
+#: cp/semantics.c:8707
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CRIS-port assertion failed: "
 msgid "static assertion failed: %s"
 msgstr "CRIS-port olumlaması başarısız: "
 
-#: cp/semantics.c:8709
+#: cp/semantics.c:8712
 #, fuzzy, gcc-internal-format
 #| msgid "non-static declaration of %q+D follows static declaration"
 msgid "non-constant condition for static assertion"
 msgstr "%q+D statik olmayan bildirim statik bildirimi izliyor"
 
-#: cp/semantics.c:8739
+#: cp/semantics.c:8742
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgid "argument to decltype must be an expression"
 msgstr "%L'deki SELECT deyiminin argümanı bir sabit ifadesi olmalı"
 
-#: cp/semantics.c:8767
+#: cp/semantics.c:8770
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "decltype cannot resolve address of overloaded function"
 msgstr "%s aşırı yüklü işlevin adresini çözümleyemiyor"
 
-#: cp/semantics.c:9308
+#: cp/semantics.c:9311
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "virgüllü ifadenin sol terimi etkisiz"
 
-#: cp/semantics.c:9361
+#: cp/semantics.c:9364
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %qE involves template parameter(s)"
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "şablon argümanı %qE şablon parametre(ler)ini içine alıyor"
 
-#: cp/semantics.c:9363
+#: cp/semantics.c:9366
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:9381
+#: cp/semantics.c:9384
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %<__builtin_return_address%>"
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "%<__builtin_return_address%>'e aktarılan argüman desteklenmiyor"
 
-#: cp/tree.c:1276
+#: cp/tree.c:1295
 #, gcc-internal-format
 msgid "%qV qualifiers cannot be applied to %qT"
 msgstr "%qV niteleyicileri %qT'ye uygulanamaz"
 
-#: cp/tree.c:1788
+#: cp/tree.c:1807
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "lambda-expression in a constant expression"
 msgstr "Sabit ifadesinde tür hatalı"
 
-#: cp/tree.c:1792
+#: cp/tree.c:1811
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "statement-expression in a constant expression"
 msgstr "Sabit ifadesinde tür hatalı"
 
-#: cp/tree.c:4050
+#: cp/tree.c:4083
 #, gcc-internal-format
-msgid "the calling convention for %qT changes in -fabi-version=12 (GCC 8)"
+msgid "-fabi-version=13 (GCC 8.2) fixes the calling convention for %qT, which was accidentally changed in 8.1"
 msgstr ""
 
-#: cp/tree.c:4055
+#: cp/tree.c:4087
 #, gcc-internal-format
+msgid "-fabi-version=12 (GCC 8.1) accidentally changes the calling convention for %qT"
+msgstr ""
+
+#: cp/tree.c:4090
+#, fuzzy, gcc-internal-format
+#| msgid "%q+D declared here"
+msgid " declared here"
+msgstr "burada bildirilmiş %q+D"
+
+#: cp/tree.c:4094
+#, gcc-internal-format
+msgid "the calling convention for %qT changes in -fabi-version=13 (GCC 8.2)"
+msgstr ""
+
+#: cp/tree.c:4096
+#, gcc-internal-format
 msgid " because all of its copy and move constructors are deleted"
 msgstr ""
 
-#: cp/tree.c:4416
+#: cp/tree.c:4464
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on types"
 msgid "%qE attribute applied to %qD with void return type"
 msgstr "%qE özniteliği veri türlerinde yoksayılır"
 
-#: cp/tree.c:4423
+#: cp/tree.c:4471
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr "%qE özniteliği sadece sınıf tanımlarına uygulanabilir"
 
-#: cp/tree.c:4475
+#: cp/tree.c:4523
 #, gcc-internal-format
 msgid "requested init_priority is not an integer constant"
 msgstr "istenen init_priority bir tamsayı sabit değil"
 
-#: cp/tree.c:4497
+#: cp/tree.c:4545
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr "%qE özniteliği sadece sınıf türünde nesnelerin dosya bağlamı tanımlarında kullanılabilir"
 
-#: cp/tree.c:4505
+#: cp/tree.c:4553
 #, gcc-internal-format
 msgid "requested init_priority is out of range"
 msgstr "istenen init_priority aralık dışında"
 
-#: cp/tree.c:4515
+#: cp/tree.c:4563
 #, gcc-internal-format
 msgid "requested init_priority is reserved for internal use"
 msgstr "istenen init_priority iç kullanim için ayrilmiştir"
 
-#: cp/tree.c:4526
+#: cp/tree.c:4574
 #, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr "bu platformda %qE özniteliği desteklenmiyor"
 
-#: cp/tree.c:4553
+#: cp/tree.c:4601
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %qE"
 msgstr "%2$s olarak %1$qD bildirimi"
 
-#: cp/tree.c:4573
+#: cp/tree.c:4621
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute requires prototypes with named arguments"
 msgid "the %qE attribute requires arguments"
 msgstr "%qE özniteliği isimli argümanları olan prototipler gerektirir"
 
-#: cp/tree.c:4584
+#: cp/tree.c:4632
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "%qs özniteliğinin argümanı bir dizge sabiti değil"
 
-#: cp/tree.c:4597 cp/tree.c:4610
+#: cp/tree.c:4645 cp/tree.c:4658
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "%qs özniteliğinin argümanı bir dizge sabiti değil"
 
-#: cp/tree.c:4599
+#: cp/tree.c:4647
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a valid declarator"
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "%<%T::%D%> geçerli bir bildirici değil"
 
-#: cp/tree.c:4612
+#: cp/tree.c:4660
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a valid declarator"
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "%<%T::%D%> geçerli bir bildirici değil"
 
-#: cp/tree.c:4636
+#: cp/tree.c:4684
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "%qE özniteliği sınıf türleri dışında yoksayılır"
 
-#: cp/tree.c:4642
+#: cp/tree.c:4690
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "%qE özniteliği sadece sınıf tanımlarına uygulanabilir"
 
-#: cp/tree.c:4649
+#: cp/tree.c:4697
 #, fuzzy, gcc-internal-format
 #| msgid "storage class %qD applied to template instantiation"
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "saklama sınıfı %qD şablon örneklenimine uygulanmış"
 
-#: cp/tree.c:4656
+#: cp/tree.c:4704
 #, fuzzy, gcc-internal-format
 #| msgid "storage class %qD applied to template instantiation"
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "saklama sınıfı %qD şablon örneklenimine uygulanmış"
 
-#: cp/tree.c:4678
+#: cp/tree.c:4726
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qE attribute applies only to functions"
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "%J%qE özniteliği sadece işlevlere uygulanır"
 
-#: cp/tree.c:4684
+#: cp/tree.c:4732
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qE attribute applies only to functions"
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "%J%qE özniteliği sadece işlevlere uygulanır"
 
-#: cp/tree.c:5440
+#: cp/tree.c:5488
 #, fuzzy, gcc-internal-format
 #| msgid "array bound is not an integer constant"
 msgid "zero as null pointer constant"
 msgstr "dizi sınırı bir tamsayı sabit değil"
 
-#: cp/tree.c:5453
+#: cp/tree.c:5501
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr "lang_* denetimi: %2$s dosyasının %3$d. satırındaki %1$s içinde başarısız"
@@ -56619,116 +56679,116 @@
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "bir bileşik sabitli %qT türündeki küme ilklendirilemez"
 
-#: cp/typeck2.c:1496 cp/typeck2.c:1523
+#: cp/typeck2.c:1499 cp/typeck2.c:1526
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "uye %qD için ilklendirici eksik"
 
-#: cp/typeck2.c:1504
+#: cp/typeck2.c:1507
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "uye %qD ilklendirilmemiş referanstir"
 
-#: cp/typeck2.c:1511
+#: cp/typeck2.c:1514
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD is uninitialized reference"
 msgid "member %qD with uninitialized reference fields"
 msgstr "uye %qD ilklendirilmemiş referanstir"
 
-#: cp/typeck2.c:1587
+#: cp/typeck2.c:1590
 #, fuzzy, gcc-internal-format
 #| msgid "template-id %qD for %q+D does not match any template declaration"
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "şablon kimliği %qD %q+D için hiçbir şablon bildirimi ile eşleşmiyor"
 
-#: cp/typeck2.c:1660
+#: cp/typeck2.c:1663
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "ilklendirilen union içinde %qD diye bir alan yok"
 
-#: cp/typeck2.c:1671
+#: cp/typeck2.c:1674
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "birlesik yapı ilklendiricideki alan isminin yerine index değeri"
 
-#: cp/typeck2.c:1858
+#: cp/typeck2.c:1861
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "döngüsel gösterici görevlendirmesi saptandi"
 
-#: cp/typeck2.c:1872
+#: cp/typeck2.c:1875
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "%<->%> için taban terim gösterici olmayan %qT türünde"
 
-#: cp/typeck2.c:1898
+#: cp/typeck2.c:1901
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr " %<operator->()%> gösterici olmayan sonuc veriyor"
 
-#: cp/typeck2.c:1900
+#: cp/typeck2.c:1903
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "%<->%> için taban terim bir gösterici değil"
 
-#: cp/typeck2.c:1927
+#: cp/typeck2.c:1930
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE bir üye göstericisi olarak kullanilamaz, cunku %qT türünde"
 
-#: cp/typeck2.c:1936
+#: cp/typeck2.c:1939
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply member pointer %qE to %qE, which is of non-aggregate type %qT"
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "uye göstericisi %qE %qE'ye kümeleme türü olmayan %qT türünde uygulanamaz"
 
-#: cp/typeck2.c:1958
+#: cp/typeck2.c:1961
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "%qT üye türünde gösterici nesne türü %qT ile uyumsuz"
 
-#: cp/typeck2.c:2018
+#: cp/typeck2.c:2021
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "aritmetikte üye işlev göstericisi kullanılmış"
 
-#: cp/typeck2.c:2029
+#: cp/typeck2.c:2032
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "aritmetikte üye işlev göstericisi kullanılmış"
 
-#: cp/typeck2.c:2037
+#: cp/typeck2.c:2040
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue before C++2a"
 msgstr "aritmetikte üye işlev göstericisi kullanılmış"
 
-#: cp/typeck2.c:2080
+#: cp/typeck2.c:2083
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type %qT"
 msgid "functional cast to array type %qT"
 msgstr "%qT işlev türüne dönüşüm geçersiz"
 
-#: cp/typeck2.c:2096
+#: cp/typeck2.c:2099
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for %q#D has type %qT"
 msgid "cannot deduce template arguments for %qT from ()"
 msgstr "%q#D için öntanımlı argüman %qT türünde"
 
-#: cp/typeck2.c:2114
+#: cp/typeck2.c:2117
 #, fuzzy, gcc-internal-format
 #| msgid "%Jdefault-initialization of %q#D, which has reference type"
 msgid "invalid value-initialization of reference type"
 msgstr "%Jreferans ture sahip %q#D'nin default ilklendirmesi"
 
-#: cp/typeck2.c:2341
+#: cp/typeck2.c:2344
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "%qD işlevine çağrı (ici boş tür `%q#T' yakalanırken)"
 
-#: cp/typeck2.c:2344
+#: cp/typeck2.c:2347
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "ici boş tür `%q#T' yakalanırken işleve çağrı"
@@ -56956,11 +57016,11 @@
 msgstr "%C'deki dizi başvurusu %d boyuttan fazlasını içeremez"
 
 #: fortran/array.c:221 fortran/array.c:661 fortran/check.c:2849
-#: fortran/check.c:5222 fortran/check.c:5260 fortran/check.c:5302
-#: fortran/check.c:5329 fortran/check.c:5529 fortran/match.c:1821
+#: fortran/check.c:5225 fortran/check.c:5263 fortran/check.c:5305
+#: fortran/check.c:5332 fortran/check.c:5532 fortran/match.c:1821
 #: fortran/match.c:3174 fortran/match.c:3516 fortran/match.c:3712
-#: fortran/simplify.c:2909 fortran/simplify.c:2939 fortran/simplify.c:5764
-#: fortran/simplify.c:7658
+#: fortran/simplify.c:2909 fortran/simplify.c:2939 fortran/simplify.c:5769
+#: fortran/simplify.c:7663
 #, gcc-internal-format
 msgid "Coarrays disabled at %C, use %<-fcoarray=%> to enable"
 msgstr ""
@@ -57107,127 +57167,133 @@
 msgid "DO-iterator %qs at %L is inside iterator of the same name"
 msgstr "DO yineleyicisi '%s' %L'de aynı isimli yineleyicinin içinde"
 
-#: fortran/array.c:1073 fortran/array.c:1255
+#: fortran/array.c:1073 fortran/array.c:1264
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in array constructor at %C"
 msgstr "%C'deki dizi kurucuda sözdizimi hatası"
 
-#: fortran/array.c:1129
+#: fortran/array.c:1105
 #, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "ENTRY statement at %C cannot appear in a contained procedure"
+msgid "NULL() at %C cannot appear in an array constructor"
+msgstr "%C'deki ENTRY deyimi bir içerilmiş işlevde görünemez"
+
+#: fortran/array.c:1138
+#, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "New in Fortran 2003: [...] style array constructors at %C"
 msgid "[...] style array constructors at %C"
 msgstr "Fortran 2003'te yeni: %C'de [...] tarzı dizi kurucular"
 
-#: fortran/array.c:1149
+#: fortran/array.c:1158
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in character length specification at %C"
 msgid "Array constructor including type specification at %C"
 msgstr "%C'deki karakter uzunluğu belirtiminde sözdizimi hatası"
 
-#: fortran/array.c:1155 fortran/match.c:4148
+#: fortran/array.c:1164 fortran/match.c:4148
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Type-spec at %L cannot contain a deferred type parameter"
 msgstr "'%s' dizisi %L'de ertelenmiş bir biçimde olamaz"
 
-#: fortran/array.c:1163
+#: fortran/array.c:1172
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Type-spec at %L cannot contain an asterisk for a type parameter"
 msgstr "'%s' dizisi %L'de ertelenmiş bir biçimde olamaz"
 
-#: fortran/array.c:1181
+#: fortran/array.c:1190
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty array constructor at %C is not allowed"
 msgstr "%C'de boş dizi kurucuya izin verilmiyor"
 
-#: fortran/array.c:1218 fortran/array.c:1228
+#: fortran/array.c:1227 fortran/array.c:1237
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Incompatible typespec for array element at %L"
 msgstr "%2$qE işlevinin %1$d. argümanı için tür uyumsuz"
 
-#: fortran/array.c:1302
+#: fortran/array.c:1311
 #, gcc-internal-format, gfc-internal-format
 msgid "Element in %s array constructor at %L is %s"
 msgstr "%s dizi kurucudaki öğe (%L'deki) %s"
 
-#: fortran/array.c:1633
+#: fortran/array.c:1642
 #, gcc-internal-format, gfc-internal-format
 msgid "Iterator step at %L cannot be zero"
 msgstr "%L'deki yineleyici adımı sıfır olamaz"
 
-#: fortran/array.c:1770
+#: fortran/array.c:1779
 #, gcc-internal-format
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit.   See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/array.c:1940
+#: fortran/array.c:1949
 #, gcc-internal-format, gfc-internal-format
 msgid "AC-IMPLIED-DO initial expression references control variable at %L"
 msgstr ""
 
-#: fortran/array.c:1947
+#: fortran/array.c:1956
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "expresion reference type error at %L"
 msgid "AC-IMPLIED-DO final expression references control variable at %L"
 msgstr "%L'de ifade başvuru türü hatası"
 
-#: fortran/array.c:1954
+#: fortran/array.c:1963
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "expresion reference type error at %L"
 msgid "AC-IMPLIED-DO step expression references control variable at %L"
 msgstr "%L'de ifade başvuru türü hatası"
 
-#: fortran/array.c:1966
+#: fortran/array.c:1975
 #, gcc-internal-format, gfc-internal-format
 msgid "Array constructor value at %L shall not be unlimited polymorphic [F2008: C4106]"
 msgstr ""
 
-#: fortran/array.c:2055
+#: fortran/array.c:2067
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Element in %s array constructor at %L is %s"
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor at %L"
 msgstr "%s dizi kurucudaki öğe (%L'deki) %s"
 
-#: fortran/array.c:2174
+#: fortran/array.c:2186
 #, gcc-internal-format
 msgid "spec_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2233
+#: fortran/array.c:2245
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2237
+#: fortran/array.c:2249
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad array reference at %L"
 msgid "Bad array dimension at %L"
 msgstr "%L'de hatalı dizi başvurusu"
 
-#: fortran/array.c:2264 fortran/data.c:552 fortran/data.c:571
-#: fortran/data.c:585 fortran/data.c:714
+#: fortran/array.c:2276 fortran/data.c:563 fortran/data.c:582
+#: fortran/data.c:596 fortran/data.c:725
 #, fuzzy, gcc-internal-format
 #| msgid "gimplification failed"
 msgid "Simplification error"
 msgstr "gimpleme başarısız"
 
-#: fortran/array.c:2376
+#: fortran/array.c:2388
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimen_type"
 msgstr ""
 
-#: fortran/array.c:2427
+#: fortran/array.c:2439
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2472
+#: fortran/array.c:2484
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad EXPR_ARRAY expr"
 msgstr ""
 
-#: fortran/array.c:2620
+#: fortran/array.c:2632
 #, gcc-internal-format
 msgid "gfc_find_array_ref(): No ref found"
 msgstr ""
@@ -57286,7 +57352,7 @@
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or PROCEDURE"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) INTEGER veya PROCEDURE olmalı"
 
-#: fortran/check.c:205 fortran/check.c:6658
+#: fortran/check.c:205 fortran/check.c:6661
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a constant"
 msgid "%qs argument of %qs intrinsic at %L must be a constant"
@@ -57421,7 +57487,7 @@
 msgid "Unequal character lengths (%ld/%ld) in %s at %L"
 msgstr "%L'deki gösterici atamasında farklı karakter uzunlukları"
 
-#: fortran/check.c:946 fortran/check.c:6602
+#: fortran/check.c:946 fortran/check.c:6605
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' and '%s' arguments of '%s' intrinsic at %L must have the same type"
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have the same type"
@@ -57681,9 +57747,9 @@
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) 1. veya 2. sırada olmalı"
 
 #: fortran/check.c:1939 fortran/check.c:2525 fortran/check.c:2628
-#: fortran/check.c:2835 fortran/check.c:2880 fortran/check.c:4256
-#: fortran/check.c:4390 fortran/check.c:4445 fortran/check.c:5515
-#: fortran/check.c:5644
+#: fortran/check.c:2835 fortran/check.c:2880 fortran/check.c:4259
+#: fortran/check.c:4393 fortran/check.c:4448 fortran/check.c:5518
+#: fortran/check.c:5647
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "%qs intrinsic with KIND argument at %L"
@@ -57910,7 +57976,7 @@
 msgid "NULL intrinsic with allocatable MOLD at %L"
 msgstr ""
 
-#: fortran/check.c:3768 fortran/check.c:5591
+#: fortran/check.c:3768 fortran/check.c:5594
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be the same type and kind as '%s'"
 msgid "%qs argument of %qs intrinsic at %L must provide at least as many elements as there are .TRUE. values in %qs (%ld/%d)"
@@ -57934,405 +58000,405 @@
 msgid "%qs argument of %qs intrinsic at %L must not be a subobject of %qs"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) %s olmalı"
 
-#: fortran/check.c:3901
+#: fortran/check.c:3904
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a variable"
 msgid "The argument of the RANK intrinsic at %L must be a data object"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) bir değişken olmalı"
 
-#: fortran/check.c:4005
+#: fortran/check.c:4008
 #, fuzzy, gcc-internal-format
 #| msgid "'shape' argument of 'reshape' intrinsic at %L must be an array of constant size"
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L must be an array of constant size"
 msgstr "%L'de 'reshape' yerleşiğinin 'shape' argümanı sabit boyutlu bir dizi olmalı"
 
-#: fortran/check.c:4015
+#: fortran/check.c:4018
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be %s"
 msgid "%qs argument of %qs intrinsic at %L is empty"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) %s olmalı"
 
-#: fortran/check.c:4022
+#: fortran/check.c:4025
 #, fuzzy, gcc-internal-format
 #| msgid "'shape' argument of 'reshape' intrinsic at %L has more than %d elements"
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L has more than %d elements"
 msgstr "%L'de 'reshape' yerleşiğinin 'shape' argümanı d elemandan fazlasını içeriyor"
 
-#: fortran/check.c:4039
+#: fortran/check.c:4042
 #, fuzzy, gcc-internal-format
 #| msgid "'a%d' argument of '%s' intrinsic at %L must be %s(%d)"
 msgid "%qs argument of %qs intrinsic at %L has negative element (%d)"
 msgstr "`a%d' argümanı `%s' yerleşiği için  (%L'de) %s(%d) olmalı"
 
-#: fortran/check.c:4071
+#: fortran/check.c:4074
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Complex argument of LOG at %L cannot be zero"
 msgid "Element %d of actual argument of RESHAPE at %L cannot be negative"
 msgstr "%L'de LOG'un karmaşık argümanı sıfır olamaz"
 
-#: fortran/check.c:4109
+#: fortran/check.c:4112
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be of rank %d"
 msgid "%qs argument of %qs intrinsic at %L has wrong number of elements (%d/%d)"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) %d. sırada olmalı"
 
-#: fortran/check.c:4127
+#: fortran/check.c:4130
 #, fuzzy, gcc-internal-format
 #| msgid "'dim' argument of '%s' intrinsic at %L is not a valid dimension index"
 msgid "%qs argument of %qs intrinsic at %L has out-of-range dimension (%d)"
 msgstr "`dim' argümanı `%s' yerleşiği için  (%L'de) geçerli bir boyut indisi değil"
 
-#: fortran/check.c:4136
+#: fortran/check.c:4139
 #, fuzzy, gcc-internal-format
 #| msgid "'dim' argument of '%s' intrinsic at %L is not a valid dimension index"
 msgid "%qs argument of %qs intrinsic at %L has invalid permutation of dimensions (dimension %qd duplicated)"
 msgstr "`dim' argümanı `%s' yerleşiği için  (%L'de) geçerli bir boyut indisi değil"
 
-#: fortran/check.c:4172
+#: fortran/check.c:4175
 #, gcc-internal-format, gfc-internal-format
 msgid "Without padding, there are not enough elements in the intrinsic RESHAPE source at %L to match the shape"
 msgstr ""
 
-#: fortran/check.c:4189 fortran/check.c:4208
+#: fortran/check.c:4192 fortran/check.c:4211
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be %s"
 msgid "%qs argument of %qs intrinsic at %L cannot be of type %s"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) %s olmalı"
 
-#: fortran/check.c:4199 fortran/check.c:4218
+#: fortran/check.c:4202 fortran/check.c:4221
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a numeric type"
 msgid "%qs argument of %qs intrinsic at %L must be of an extensible type"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) sayısal bir tür olmalı"
 
-#: fortran/check.c:4317
+#: fortran/check.c:4320
 #, gcc-internal-format
 msgid "SELECTED_REAL_KIND with neither %<P%> nor %<R%> argument at %L"
 msgstr ""
 
-#: fortran/check.c:4348
+#: fortran/check.c:4351
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "%qs intrinsic with RADIX argument at %L"
 msgstr "%s özniteliği ile %s özniteliği %L'de çelişiyor"
 
-#: fortran/check.c:4383
+#: fortran/check.c:4386
 #, fuzzy, gcc-internal-format
 #| msgid "'source' argument of 'shape' intrinsic at %L must not be an assumed size array"
 msgid "%<source%> argument of %<shape%> intrinsic at %L must not be an assumed size array"
 msgstr "%L'de 'shape' yerleşiğinin 'source' argümanı tahmini boyutlu bir dizi olmalı"
 
-#: fortran/check.c:4460 fortran/check.c:6641
+#: fortran/check.c:4463 fortran/check.c:6644
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a scalar"
 msgid "%qs argument of %qs intrinsic at %L shall not be a procedure"
 msgstr "`%s' argümanı `%s' yerleşiği için  %L'de bir değişmez olmalı"
 
-#: fortran/check.c:4473 fortran/check.c:4612 fortran/check.c:6633
+#: fortran/check.c:4476 fortran/check.c:4615 fortran/check.c:6636
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L cannot be INTENT(IN)"
 msgid "%qs argument of %qs intrinsic at %L shall not be TYPE(*)"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) INTENT(IN) olamaz"
 
-#: fortran/check.c:4484 fortran/check.c:4624
+#: fortran/check.c:4487 fortran/check.c:4627
 #, fuzzy, gcc-internal-format
 #| msgid "'source' argument of 'shape' intrinsic at %L must not be an assumed size array"
 msgid "%qs argument of %qs intrinsic at %L shall not be an assumed-size array"
 msgstr "%L'de 'shape' yerleşiğinin 'source' argümanı tahmini boyutlu bir dizi olmalı"
 
-#: fortran/check.c:4554
+#: fortran/check.c:4557
 #, gcc-internal-format
 msgid "is_c_interoperable(): gfc_simplify_expr failed"
 msgstr ""
 
-#: fortran/check.c:4603
+#: fortran/check.c:4606
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a non-derived type"
 msgid "%qs argument of %qs intrinsic at %L must be an interoperable data entity: %s"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) türetilmemiş bir türde olmalı"
 
-#: fortran/check.c:4642
+#: fortran/check.c:4645
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_1 at %L to C_ASSOCIATED shall have the type TYPE(C_PTR) or TYPE(C_FUNPTR)"
 msgstr ""
 
-#: fortran/check.c:4656
+#: fortran/check.c:4659
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_2 at %L to C_ASSOCIATED shall have the same type as C_PTR_1: %s instead of %s"
 msgstr ""
 
-#: fortran/check.c:4680
+#: fortran/check.c:4683
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_POINTER shall have the type TYPE(C_PTR)"
 msgstr ""
 
-#: fortran/check.c:4692
+#: fortran/check.c:4695
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument dim at %L must be scalar"
 msgid "Argument FPTR at %L to C_F_POINTER must be a pointer"
 msgstr "%L'de boyut argümanı değişmez olmalı"
 
-#: fortran/check.c:4699
+#: fortran/check.c:4702
 #, gcc-internal-format, gfc-internal-format
 msgid "FPTR argument at %L to C_F_POINTER shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:4706
+#: fortran/check.c:4709
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:4713
+#: fortran/check.c:4716
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected SHAPE argument at %L to C_F_POINTER with scalar FPTR"
 msgstr ""
 
-#: fortran/check.c:4719
+#: fortran/check.c:4722
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected SHAPE argument to C_F_POINTER with array FPTR at %L"
 msgstr ""
 
-#: fortran/check.c:4738
+#: fortran/check.c:4741
 #, gcc-internal-format, gfc-internal-format
 msgid "SHAPE argument at %L to C_F_POINTER must have the same size as the RANK of FPTR"
 msgstr ""
 
-#: fortran/check.c:4748
+#: fortran/check.c:4751
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic FPTR at %L to C_F_POINTER"
 msgstr ""
 
-#: fortran/check.c:4753
+#: fortran/check.c:4756
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array FPTR at %L to C_F_POINTER: %s"
 msgstr ""
 
-#: fortran/check.c:4769
+#: fortran/check.c:4772
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_PROCPOINTER shall have the type TYPE(C_FUNPTR)"
 msgstr ""
 
-#: fortran/check.c:4781
+#: fortran/check.c:4784
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall be a procedure pointer"
 msgstr ""
 
-#: fortran/check.c:4788
+#: fortran/check.c:4791
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:4794
+#: fortran/check.c:4797
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure pointer at %L to C_F_PROCPOINTER"
 msgstr ""
 
-#: fortran/check.c:4808
+#: fortran/check.c:4811
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:4823
+#: fortran/check.c:4826
 #, gcc-internal-format
 msgid "Function result %qs at %L is invalid as X argument to C_FUNLOC"
 msgstr ""
 
-#: fortran/check.c:4831
+#: fortran/check.c:4834
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall be a procedure or a procedure pointer"
 msgstr ""
 
-#: fortran/check.c:4837
+#: fortran/check.c:4840
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "User operator procedure '%s' at %L must be a FUNCTION"
 msgid "Noninteroperable procedure at %L to C_FUNLOC"
 msgstr "Yerleşik işleç arayüzü '%s' %L'de bir FUNCTION olmalı"
 
-#: fortran/check.c:4851
+#: fortran/check.c:4854
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:4857
+#: fortran/check.c:4860
 #, gcc-internal-format, gfc-internal-format
 msgid "X argument at %L to C_LOC shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:4868
+#: fortran/check.c:4871
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Component at %C must have the POINTER attribute"
 msgid "Argument X at %L to C_LOC shall have either the POINTER or the TARGET attribute"
 msgstr "%C'deki bileşen POINTER özniteliğinde olmalı"
 
-#: fortran/check.c:4876
+#: fortran/check.c:4879
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall be not be a zero-sized string"
 msgstr ""
 
-#: fortran/check.c:4885
+#: fortran/check.c:4888
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument at %L to C_LOC shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:4892
+#: fortran/check.c:4895
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array at %L as argument to C_LOC: %s"
 msgstr ""
 
-#: fortran/check.c:4903
+#: fortran/check.c:4906
 #, gcc-internal-format, gfc-internal-format
 msgid "Array of interoperable type at %L to C_LOC which is nonallocatable and neither assumed size nor explicit size"
 msgstr ""
 
-#: fortran/check.c:4908
+#: fortran/check.c:4911
 #, gcc-internal-format, gfc-internal-format
 msgid "Array section at %L to C_LOC"
 msgstr ""
 
-#: fortran/check.c:4936
+#: fortran/check.c:4939
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing arguments to %s intrinsic at %L"
 msgid "non double precision REAL argument to %s intrinsic at %L"
 msgstr "`%s' yerleşiği için (%L'de) argümanlar eksik"
 
-#: fortran/check.c:4949
+#: fortran/check.c:4952
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be less than rank %d"
 msgid "%qs argument of %qs intrinsic at %L must be less than rank %d"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) %d. sıradan önce olmalı"
 
-#: fortran/check.c:4968
+#: fortran/check.c:4971
 #, fuzzy, gcc-internal-format
 #| msgid "'dim' argument of '%s' intrinsic at %L is not a valid dimension index"
 msgid "%qs argument of %qs intrinsic at %L is not a valid dimension index"
 msgstr "`dim' argümanı `%s' yerleşiği için  (%L'de) geçerli bir boyut indisi değil"
 
-#: fortran/check.c:5231
+#: fortran/check.c:5234
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "%s argument to IMAGE_INDEX must be a rank one array at %L"
 msgstr "`%s' için fiili argüman bir gösterici olmalı (%L'de)"
 
-#: fortran/check.c:5242
+#: fortran/check.c:5245
 #, gcc-internal-format, gfc-internal-format
 msgid "The number of array elements of the SUB argument to IMAGE_INDEX at %L shall be %d (corank) not %d"
 msgstr ""
 
-#: fortran/check.c:5275
+#: fortran/check.c:5278
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to NUM_IMAGES at %L"
 msgstr ""
 
-#: fortran/check.c:5288
+#: fortran/check.c:5291
 #, gcc-internal-format, gfc-internal-format
 msgid "FAILED= argument to NUM_IMAGES at %L"
 msgstr ""
 
-#: fortran/check.c:5312
+#: fortran/check.c:5315
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be of kind %d"
 msgid "TEAM argument at %L to the intrinsic TEAM_NUMBER shall be of type TEAM_TYPE"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) %d. çeşitte olmalı"
 
-#: fortran/check.c:5338
+#: fortran/check.c:5341
 #, gcc-internal-format, gfc-internal-format
 msgid "DIM argument without COARRAY argument not allowed for THIS_IMAGE intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:5345
+#: fortran/check.c:5348
 #, gcc-internal-format, gfc-internal-format
 msgid "The DISTANCE argument may not be specified together with the COARRAY or DIM argument in intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:5356
+#: fortran/check.c:5359
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk in formal argument list at %C"
 msgid "Unexpected DIM argument with noncoarray argument at %L"
 msgstr "%C'deki biçimsel argüman listesinde umulmadık döküntü"
 
-#: fortran/check.c:5374
+#: fortran/check.c:5377
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to THIS_IMAGE at %L"
 msgstr ""
 
-#: fortran/check.c:5454
+#: fortran/check.c:5457
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be %s"
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L must not be %s"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) %s olmalı"
 
-#: fortran/check.c:5483
+#: fortran/check.c:5486
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic TRANSFER at %L has partly undefined result: source size %ld < result size %ld"
 msgstr ""
 
-#: fortran/check.c:5605
+#: fortran/check.c:5608
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be the same kind as '%s'"
 msgid "%qs argument of %qs intrinsic at %L must have the same rank as %qs or be a scalar"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) %s ile aynı çeşit olmalı"
 
-#: fortran/check.c:5618
+#: fortran/check.c:5621
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' and '%s' arguments of '%s' intrinsic at %L must have the same type"
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have identical shape."
 msgstr "`%s' ve '%s' argümanları `%s' yerleşiği için  (%L'de) aynı türde olmalı"
 
-#: fortran/check.c:5861 fortran/check.c:5893
+#: fortran/check.c:5864 fortran/check.c:5896
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be %s"
 msgid "Size of %qs argument of %qs intrinsic at %L too small (%i/%i)"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) %s olmalı"
 
-#: fortran/check.c:5901
+#: fortran/check.c:5904
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many arguments to %s at %L"
 msgstr "%s için argümanlar %L'de çok fazla"
 
-#: fortran/check.c:5919
+#: fortran/check.c:5922
 #, gcc-internal-format
 msgid "fe_runtime_error string must be null terminated"
 msgstr ""
 
-#: fortran/check.c:5931
+#: fortran/check.c:5934
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "fe_runtime_error: Wrong number of arguments (%d instead of %d)"
 msgstr "yanlış sayıda şablon argümanı (%d yerine %d olmalıydı)"
 
-#: fortran/check.c:5971
+#: fortran/check.c:5974
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:5990
+#: fortran/check.c:5993
 #, gcc-internal-format, gfc-internal-format
 msgid "Real COUNT_RATE argument to SYSTEM_CLOCK at %L"
 msgstr ""
 
-#: fortran/check.c:6000
+#: fortran/check.c:6003
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT_RATE argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:6017
+#: fortran/check.c:6020
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT_MAX argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:6234
+#: fortran/check.c:6237
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be of kind %d"
 msgid "%qs argument of %qs intrinsic at %L must be of a kind not wider than the default kind (%d)"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) %d. çeşitte olmalı"
 
-#: fortran/check.c:6586 fortran/check.c:6594
+#: fortran/check.c:6589 fortran/check.c:6597
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be INTEGER or LOGICAL"
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or LOGICAL"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) INTEGER veya LOGICAL olmalı"
 
-#: fortran/check.c:6625
+#: fortran/check.c:6628
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic function NULL at %L cannot be an actual argument to STORAGE_SIZE, because it returns a disassociated pointer"
 msgstr ""
@@ -58344,7 +58410,7 @@
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:727 fortran/decl.c:3636 fortran/decl.c:10066
+#: fortran/class.c:727 fortran/decl.c:3655 fortran/decl.c:10091
 #, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr ""
@@ -58371,46 +58437,52 @@
 msgid "non-constant array in DATA statement %L"
 msgstr "DATA deyimi %L içinde sabit olmayan dizi"
 
-#: fortran/data.c:137
+#: fortran/data.c:140
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array specification required in ALLOCATE statement at %L"
 msgid "failure to simplify substring reference in DATA statement at %L"
 msgstr "%L'deki ALLOCATE deyimde dizi belirtimi gerekli "
 
-#: fortran/data.c:170
+#: fortran/data.c:173
 #, gcc-internal-format, gfc-internal-format
 msgid "Unused initialization string at %L because variable has zero length"
 msgstr ""
 
-#: fortran/data.c:176
+#: fortran/data.c:179
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Initialization at %C isn't for a pointer variable"
 msgid "Initialization string at %L was truncated to fit the variable (%ld/%ld)"
 msgstr "%C'deki ilklendirme bir gösterici değişkeni için değil"
 
-#: fortran/data.c:265
+#: fortran/data.c:268
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %C is already defined at %L"
 msgid "%qs at %L already is initialized at %L"
 msgstr "işlev `%s' (%C'deki) zaten %L'de tanımlı"
 
-#: fortran/data.c:289
+#: fortran/data.c:292
 #, gcc-internal-format, gfc-internal-format
 msgid "Data element below array lower bound at %L"
 msgstr ""
 
-#: fortran/data.c:306 fortran/data.c:395
+#: fortran/data.c:309 fortran/data.c:398
 #, gcc-internal-format, gfc-internal-format
 msgid "Data element above array upper bound at %L"
 msgstr ""
 
-#: fortran/data.c:336 fortran/data.c:505
+#: fortran/data.c:339 fortran/data.c:496
 #, fuzzy, gcc-internal-format
 #| msgid "Extension: re-initialization of '%s' at %L"
 msgid "re-initialization of %qs at %L"
 msgstr "Ek:`%s' için (%L'de) yeniden ilklendirme"
 
-#: fortran/data.c:727
+#: fortran/data.c:515
+#, fuzzy, gcc-internal-format
+#| msgid "Variable '%s' at %C with an initializer already appears in a DATA statement"
+msgid "Nonpointer object %qs with default initialization shall not appear in a DATA statement at %L"
+msgstr "Değişken '%s' %C'de bir ilklendirici ile zaten bir DATA deyiminde görünüyor"
+
+#: fortran/data.c:738
 #, gcc-internal-format
 msgid "TODO: Vector sections in data statements"
 msgstr ""
@@ -58439,861 +58511,861 @@
 msgid "Invalid initializer %s in Data statement at %C"
 msgstr "asm deyiminde geçersiz sol taraf"
 
-#: fortran/decl.c:536
+#: fortran/decl.c:537
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C is not allowed in a PURE procedure"
 msgstr "%C'de ilklendirmeye bir PURE işlevinde izin verilmez"
 
-#: fortran/decl.c:573
+#: fortran/decl.c:574
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgid "DATA statement at %C cannot appear within an INTERFACE"
 msgstr "%C'deki ENTRY deyimi bir INTERFACE bloku içindeymiş gibi görünmüyor"
 
-#: fortran/decl.c:597
+#: fortran/decl.c:598
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid lvalue in asm statement"
 msgid "Invalid substring in data-implied-do at %L in DATA statement"
 msgstr "asm deyiminde geçersiz sol taraf"
 
-#: fortran/decl.c:619
+#: fortran/decl.c:620
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %C is not allowed in a PURE procedure"
 msgstr "%C'de DATA deyimi için bir PURE işlevinde izin verilmez"
 
-#: fortran/decl.c:664
+#: fortran/decl.c:662
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Old-style initialization at %C"
 msgid "Empty old style initializer list at %C"
 msgstr "Genişletme: %C'de eski tarz ilklendirme"
 
-#: fortran/decl.c:684
+#: fortran/decl.c:671
 #, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "Array component of structure at %C must have an explicit shape"
+msgid "Array in initializer list at %L must have an explicit shape"
+msgstr "Yapının dizi bileşeni %C'de dolaysız durumda olmalı"
+
+#: fortran/decl.c:694
+#, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "extra elements in scalar initializer"
 msgid "Repeat spec invalid in scalar initializer at %C"
 msgstr "skalar ilklendiricide fazladan öğeler"
 
-#: fortran/decl.c:689
+#: fortran/decl.c:699
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "selector must be an integer constant in the range 0..%wi"
 msgid "Repeat spec must be an integer at %C"
 msgstr "seçici 0..%wi aralığında bir tamsayı sabit olmalı"
 
-#: fortran/decl.c:698
+#: fortran/decl.c:710
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected alternate return label at %C"
 msgid "Expected data constant after repeat spec at %C"
 msgstr "%C'de diğer return yaftası umuluyordu"
 
-#: fortran/decl.c:729
+#: fortran/decl.c:742
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected scalar initialization expression at %C"
 msgid "End of scalar initializer expected at %C"
 msgstr "%C'deki ilklendirme ifadesinin değişmez olması umuluyordu"
 
-#: fortran/decl.c:758
+#: fortran/decl.c:773
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "nonconstant array index in initializer"
-msgid "Expected constant array-spec in initializer list at %L"
-msgstr "ilklendiricide sabit olmayan dizi indisi"
-
-#: fortran/decl.c:767
-#, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "excess elements in array initializer"
 msgid "Not enough elements in array initializer at %C"
 msgstr "dizi ilklendiricide gereğinden fazla öğe"
 
-#: fortran/decl.c:769
+#: fortran/decl.c:775
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "excess elements in array initializer"
 msgid "Too many elements in array initializer at %C"
 msgstr "dizi ilklendiricide gereğinden fazla öğe"
 
-#: fortran/decl.c:790
+#: fortran/decl.c:795
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in argument list at %C"
 msgid "Syntax error in old style initializer list at %C"
 msgstr "%C'deki argüman listesinde söz dizimi hatası"
 
-#: fortran/decl.c:812
+#: fortran/decl.c:821
 #, gcc-internal-format, gfc-internal-format
 msgid "The assumed-rank array at %C shall not have a codimension"
 msgstr ""
 
-#: fortran/decl.c:876
+#: fortran/decl.c:885
 #, gcc-internal-format, gfc-internal-format
 msgid "Sum of array rank %d and corank %d at %C exceeds maximum allowed dimensions of %d"
 msgstr ""
 
-#: fortran/decl.c:900
+#: fortran/decl.c:909
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad INTENT specification at %C"
 msgstr "%C'deki INTENT belirtimi hatalı"
 
-#: fortran/decl.c:921
+#: fortran/decl.c:930
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "deferred type parameter at %C"
 msgstr "%2$qs sonrası şablon türü %1$qT parametresi kullanımı"
 
-#: fortran/decl.c:1004 fortran/resolve.c:11705
+#: fortran/decl.c:1013 fortran/resolve.c:11725
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
 
-#: fortran/decl.c:1030
+#: fortran/decl.c:1039
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Illegal character in BOZ constant at %C"
 msgid "Old-style character length at %C"
 msgstr "%C'de BOZ sabitinde kuraldışı karakter"
 
-#: fortran/decl.c:1061
+#: fortran/decl.c:1070
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in character length specification at %C"
 msgstr "%C'deki karakter uzunluğu belirtiminde sözdizimi hatası"
 
-#: fortran/decl.c:1212 fortran/decl.c:1217 fortran/decl.c:1266
+#: fortran/decl.c:1221 fortran/decl.c:1226 fortran/decl.c:1275
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %C is already defined at %L"
 msgid "Procedure %qs at %C is already defined at %L"
 msgstr "işlev `%s' (%C'deki) zaten %L'de tanımlı"
 
-#: fortran/decl.c:1222
+#: fortran/decl.c:1231
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %C is already defined at %L"
 msgid "Contained procedure %qs at %C clashes with procedure defined at %L"
 msgstr "işlev `%s' (%C'deki) zaten %L'de tanımlı"
 
-#: fortran/decl.c:1231
+#: fortran/decl.c:1240
 #, fuzzy, gcc-internal-format
 #| msgid "Global name '%s' at %L is already being used as a %s at %L"
 msgid "Name %qs at %C is already defined as a generic interface at %L"
 msgstr "Genel isim '%s' (%L'de), zaten %s (%L'de) olarak kullanılıyor"
 
-#: fortran/decl.c:1244
+#: fortran/decl.c:1253
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %C has an explicit interface and must not have attributes declared at %L"
 msgid "Procedure %qs at %C has an explicit interface from a previous declaration"
 msgstr "işlev '%s' (%C'deki) bir dolaysız arayüze sahip ve %L'de bildirilmiş özniteliklere sahip olmamalı"
 
-#: fortran/decl.c:1257
+#: fortran/decl.c:1266
 #, gcc-internal-format
 msgid "Procedure %qs defined in interface body at %L clashes with internal procedure defined at %C"
 msgstr ""
 
-#: fortran/decl.c:1335
+#: fortran/decl.c:1344
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgid "Procedure %qs at %L must have the BIND(C) attribute to be C interoperable"
 msgstr "Türetilmiş tür değişkeni '%s' %L'de bir EQUIVALENCE nesnesi olarak SEQUENCE özniteliğine sahip olmalı"
 
-#: fortran/decl.c:1362
+#: fortran/decl.c:1371
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because derived type %qs is not C interoperable"
 msgstr ""
 
-#: fortran/decl.c:1369
+#: fortran/decl.c:1378
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because it is polymorphic"
 msgstr ""
 
-#: fortran/decl.c:1376
+#: fortran/decl.c:1385
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument of the BIND(C) procedure %qs but may not be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:1391
+#: fortran/decl.c:1400
 #, gcc-internal-format
 msgid "Character argument %qs at %L must be length 1 because procedure %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1404
+#: fortran/decl.c:1413
 #, gcc-internal-format
 msgid "Variable %qs at %L with ALLOCATABLE attribute in procedure %qs with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1412
+#: fortran/decl.c:1421
 #, gcc-internal-format
 msgid "Variable %qs at %L with POINTER attribute in procedure %qs with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1421
+#: fortran/decl.c:1430
 #, gcc-internal-format
 msgid "Scalar variable %qs at %L with POINTER or ALLOCATABLE in procedure %qs with BIND(C) is not yet supported"
 msgstr ""
 
-#: fortran/decl.c:1430
+#: fortran/decl.c:1439
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the OPTIONAL and the VALUE attribute because procedure %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1437
+#: fortran/decl.c:1446
 #, gcc-internal-format
 msgid "Variable %qs at %L with OPTIONAL attribute in procedure %qs which is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1448
+#: fortran/decl.c:1457
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-shape array %qs at %L as dummy argument to the BIND(C) procedure %qs at %L"
 msgstr "Tahmini boyutlu dizi bir sözde argüman olmalı"
 
-#: fortran/decl.c:1516
+#: fortran/decl.c:1525
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L already has basic type of %s"
 msgid "Symbol %qs at %C also declared as a type at %L"
 msgstr "'%s' simgesi %L'de zaten temel %s türünde"
 
-#: fortran/decl.c:1575
+#: fortran/decl.c:1584
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %C must be declared with a C interoperable kind since common block %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1615
+#: fortran/decl.c:1624
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Element in %s array constructor at %L is %s"
 msgid "CHARACTER length must be a constant at %L"
 msgstr "%s dizi kurucudaki öğe (%L'deki) %s"
 
-#: fortran/decl.c:1630
+#: fortran/decl.c:1639
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression at %L is being truncated (%ld/%ld)"
 msgstr ""
 
-#: fortran/decl.c:1638
+#: fortran/decl.c:1647
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' and '%s' arguments of '%s' intrinsic at %L must have the same type"
 msgid "The CHARACTER elements of the array constructor at %L must have the same length (%ld/%ld)"
 msgstr "`%s' ve '%s' argümanları `%s' yerleşiği için  (%L'de) aynı türde olmalı"
 
-#: fortran/decl.c:1729
+#: fortran/decl.c:1738
 #, fuzzy, gcc-internal-format
 #| msgid "Initializer not allowed for PARAMETER '%s' at %C"
 msgid "Initializer not allowed for PARAMETER %qs at %C"
 msgstr "PARAMETER `%s' için %C'de ilklendirme yapılamaz"
 
-#: fortran/decl.c:1739
+#: fortran/decl.c:1748
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER at %L is missing an initializer"
 msgstr "%L'deki PARAMETER bir ilklendirici kaybediyor"
 
-#: fortran/decl.c:1749
+#: fortran/decl.c:1758
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %C with an initializer already appears in a DATA statement"
 msgid "Variable %qs at %C with an initializer already appears in a DATA statement"
 msgstr "Değişken '%s' %C'de bir ilklendirici ile zaten bir DATA deyiminde görünüyor"
 
-#: fortran/decl.c:1792
+#: fortran/decl.c:1801
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot initialize multi-dimensional array with initializer"
 msgid "Cannot initialize parameter array at %L with variable length elements"
 msgstr "çok boyutlu diziler ilklendiricilerle ilklendirilemez"
 
-#: fortran/decl.c:1861
+#: fortran/decl.c:1870
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot initialize multi-dimensional array with initializer"
 msgid "Can't initialize implied-shape array at %L with scalar"
 msgstr "çok boyutlu diziler ilklendiricilerle ilklendirilemez"
 
-#: fortran/decl.c:1896
+#: fortran/decl.c:1905
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in data declaration at %C"
 msgid "Non-constant lower bound in implied-shape declaration at %L"
 msgstr "%C'deki veri bildiriminde sözdizimi hatası"
 
-#: fortran/decl.c:1982 fortran/decl.c:1989
+#: fortran/decl.c:1991 fortran/decl.c:1998
 #, gcc-internal-format, gfc-internal-format
 msgid "Component at %C must have the POINTER attribute"
 msgstr "%C'deki bileşen POINTER özniteliğinde olmalı"
 
-#: fortran/decl.c:1998
+#: fortran/decl.c:2007
 #, fuzzy, gcc-internal-format
 #| msgid "Array pointer '%s' at %L must have a deferred shape"
 msgid "Component %qs with CLASS at %C must be allocatable or pointer"
 msgstr "'%s' dizi göstericisi %L'de ertelenmiş bir biçimde olmalı"
 
-#: fortran/decl.c:2007
+#: fortran/decl.c:2016
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr "Yapının dizi bileşeni %C'de dolaysız ya da ertelenmiş durumda olmalı"
 
-#: fortran/decl.c:2031 fortran/symbol.c:2230
+#: fortran/decl.c:2040 fortran/symbol.c:2244
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C already declared at %L"
 msgid "Component %qs at %C already declared at %L"
 msgstr "'%s' bileşeni (%C'deki) zaten %L'de bildirilmiş"
 
-#: fortran/decl.c:2079
+#: fortran/decl.c:2088
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer array component of structure at %C must have a deferred shape"
 msgstr "Yapının gösterici dizisi bileşeni %C'de ertelenmiş durumda olmalı"
 
-#: fortran/decl.c:2088
+#: fortran/decl.c:2097
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer array component of structure at %C must have a deferred shape"
 msgid "Allocatable component of structure at %C must have a deferred shape"
 msgstr "Yapının gösterici dizisi bileşeni %C'de ertelenmiş durumda olmalı"
 
-#: fortran/decl.c:2097
+#: fortran/decl.c:2106
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have an explicit shape"
 msgstr "Yapının dizi bileşeni %C'de dolaysız durumda olmalı"
 
-#: fortran/decl.c:2114
+#: fortran/decl.c:2123
 #, fuzzy, gcc-internal-format
 #| msgid "a parameter list with an ellipsis can%'t match an empty parameter name list declaration"
 msgid "Type parameter %qs at %C has no corresponding entry in the type parameter name list at %L"
 msgstr "Üç nokta imli bir parametre listesi bir boş parametre isim listesi bildirimi ile eşleşemez"
 
-#: fortran/decl.c:2171
+#: fortran/decl.c:2180
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C is ambiguous"
 msgstr "NULL() ilklendirme %C'de belirsiz"
 
-#: fortran/decl.c:2188
+#: fortran/decl.c:2197
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "NULL() initialization at %C is ambiguous"
 msgid "NULL() initialization at %C may not have MOLD"
 msgstr "NULL() ilklendirme %C'de belirsiz"
 
-#: fortran/decl.c:2205
+#: fortran/decl.c:2214
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of pointer at %C is not allowed in a PURE procedure"
 msgstr "%C'deki gösterici ilklendirmesi bir PURE yordamında olamaz"
 
-#: fortran/decl.c:2226
+#: fortran/decl.c:2235
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Old-style initialization at %C"
 msgid "Error in pointer initialization at %C"
 msgstr "Genişletme: %C'de eski tarz ilklendirme"
 
-#: fortran/decl.c:2233
+#: fortran/decl.c:2242
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Old-style initialization at %C"
 msgid "non-NULL pointer initialization at %C"
 msgstr "Genişletme: %C'de eski tarz ilklendirme"
 
-#: fortran/decl.c:2256
+#: fortran/decl.c:2265
 #, gcc-internal-format
 msgid "RESULT variable %qs at %L prohibits FUNCTION name %qs at %C from appearing in a specification statement"
 msgstr ""
 
-#: fortran/decl.c:2318
+#: fortran/decl.c:2327
 #, fuzzy, gcc-internal-format
 #| msgid "%s statement not allowed in PURE procedure at %C"
 msgid "%qs not allowed outside STRUCTURE at %C"
 msgstr "PURE yordamda %s deyimine izin verilmez (%C'de)"
 
-#: fortran/decl.c:2320
+#: fortran/decl.c:2329
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is not a member of the '%s' structure"
 msgid "%qs at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr "'%s' (%C'deki) '%s' yapısının bir üyesi değil"
 
-#: fortran/decl.c:2327
+#: fortran/decl.c:2336
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "%qs entity cannot have attributes at %C"
 msgstr "%qD öntanımlı argümanlara sahip olamaz"
 
-#: fortran/decl.c:2367
+#: fortran/decl.c:2376
 #, gcc-internal-format
 msgid "Non-PARAMETER symbol %qs at %L can't be implied-shape"
 msgstr ""
 
-#: fortran/decl.c:2377
+#: fortran/decl.c:2386
 #, gcc-internal-format, gfc-internal-format
 msgid "Implied-shape array at %L"
 msgstr ""
 
-#: fortran/decl.c:2422
+#: fortran/decl.c:2431
 #, gcc-internal-format, gfc-internal-format
 msgid "Explicit shaped array with nonconstant bounds at %C"
 msgstr ""
 
-#: fortran/decl.c:2501
+#: fortran/decl.c:2510
 #, gcc-internal-format
 msgid "%qs at %C is a redefinition of the declaration in the corresponding interface for MODULE PROCEDURE %qs"
 msgstr ""
 
-#: fortran/decl.c:2512
+#: fortran/decl.c:2521
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "%qs entity cannot have an initializer at %C"
 msgstr "Sözde '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/decl.c:2538 fortran/decl.c:8369
+#: fortran/decl.c:2547 fortran/decl.c:8388
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate array spec for Cray pointee at %C."
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr "Cray göstericileri için dizi belirtimi %C'de yinelenmiş"
 
-#: fortran/decl.c:2546
+#: fortran/decl.c:2555
 #, gcc-internal-format
 msgid "Couldn't set pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:2609
+#: fortran/decl.c:2618
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Old-style initialization at %C"
 msgid "Old-style initialization at %C"
 msgstr "Genişletme: %C'de eski tarz ilklendirme"
 
-#: fortran/decl.c:2617
+#: fortran/decl.c:2626
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr "%qT türündeki başvurunun %qT türündeki ifadeden ilklendirilmesi geçersiz"
 
-#: fortran/decl.c:2630
+#: fortran/decl.c:2639
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Old-style initialization at %C"
 msgid "Syntax error in old style initialization of %s at %C"
 msgstr "Genişletme: %C'de eski tarz ilklendirme"
 
-#: fortran/decl.c:2650 fortran/decl.c:6661
+#: fortran/decl.c:2659 fortran/decl.c:6680
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr "%C'deki ilklendirme bir gösterici değişkeni için değil"
 
-#: fortran/decl.c:2663
+#: fortran/decl.c:2672
 #, fuzzy, gcc-internal-format
 #| msgid "Pointer initialization at %C requires '=>', not '='"
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr "%C'deki gösterici ilklendirmesi bir '=>' gerektirir, '=' değil"
 
-#: fortran/decl.c:2672 fortran/decl.c:10240
+#: fortran/decl.c:2681 fortran/decl.c:10265
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr "%C'de bir ilklendirme ifadesi umuluyordu"
 
-#: fortran/decl.c:2679
+#: fortran/decl.c:2688
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr "%C'deki değişken ilklendirmesi bir PURE yordamında olamaz"
 
-#: fortran/decl.c:2696
+#: fortran/decl.c:2705
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr "%C'deki değişken ilklendirmesi bir PURE yordamında olamaz"
 
-#: fortran/decl.c:2710
+#: fortran/decl.c:2719
 #, gcc-internal-format, gfc-internal-format
 msgid "The component with KIND or LEN attribute at %C does not not appear in the type parameter list at %L"
 msgstr ""
 
-#: fortran/decl.c:2718
+#: fortran/decl.c:2727
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C that appears in the type parameter list at %L has neither the KIND nor LEN attribute"
 msgstr ""
 
-#: fortran/decl.c:2726
+#: fortran/decl.c:2735
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The derived type '%s' at %L is of type '%s', which has not been defined."
 msgid "The component at %C which is a type parameter must be a scalar"
 msgstr "Türetilmiş '%s' türü (%L'de) tanımlanmamış olan '%s' türündedir."
 
-#: fortran/decl.c:2789 fortran/decl.c:2825
+#: fortran/decl.c:2798 fortran/decl.c:2834
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr "Eski tarz tür bildirimi %s*%d %C'de desteklenmiyor"
 
-#: fortran/decl.c:2831
+#: fortran/decl.c:2840
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr "%s*%d %C'de standartdısı tür bildirimi"
 
-#: fortran/decl.c:2890 fortran/decl.c:2967
+#: fortran/decl.c:2899 fortran/decl.c:2976
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing right paren at %C"
 msgid "Missing right parenthesis at %C"
 msgstr "%C'de sağ parantez eksik"
 
-#: fortran/decl.c:2903 fortran/decl.c:3038
+#: fortran/decl.c:2912 fortran/decl.c:3047
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr "%C'de ilklendirme ifadesi umuluyordu"
 
-#: fortran/decl.c:2911 fortran/decl.c:3044
+#: fortran/decl.c:2920 fortran/decl.c:3053
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr "%C'deki ilklendirme ifadesinin değişmez olması umuluyordu"
 
-#: fortran/decl.c:2941 fortran/decl.c:3657
+#: fortran/decl.c:2950 fortran/decl.c:3676
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr "%d. çeşit, %s türü için (%C'de) desteklenmiyor"
 
-#: fortran/decl.c:2954
+#: fortran/decl.c:2963
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Different kind type parameters in pointer assignment at %L"
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr "%L'deki gösterici atamasında parametreler farklı çeşit türlerinde"
 
-#: fortran/decl.c:2965
+#: fortran/decl.c:2974
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing right paren at %C"
 msgid "Missing right parenthesis or comma at %C"
 msgstr "%C'de sağ parantez eksik"
 
-#: fortran/decl.c:3070
+#: fortran/decl.c:3079
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Kind %d not supported for type %s at %C"
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr "%d. çeşit, %s türü için (%C'de) desteklenmiyor"
 
-#: fortran/decl.c:3202
+#: fortran/decl.c:3211
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr "%C'deki CHARACTER bildiriminde sözdizimi hatası"
 
-#: fortran/decl.c:3291
+#: fortran/decl.c:3310
 #, gcc-internal-format, gfc-internal-format
 msgid "RECORD at %C is an extension, enable it with -fdec-structure"
 msgstr ""
 
-#: fortran/decl.c:3304
+#: fortran/decl.c:3323
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "identifier expected after %<@protocol%>"
 msgid "Structure name expected after RECORD at %C"
 msgstr "%<@protocol%> sonrasında betimleyici umuluyordu"
 
-#: fortran/decl.c:3417
+#: fortran/decl.c:3436
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C cannot contain both ASSUMED and DEFERRED parameters"
 msgstr ""
 
-#: fortran/decl.c:3441
+#: fortran/decl.c:3460
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C does not contain enough parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3465
+#: fortran/decl.c:3484
 #, fuzzy, gcc-internal-format
 #| msgid "second parameter of %<va_start%> not last named argument"
 msgid "The derived parameter %qs at %C does not have a default value"
 msgstr "%<va_start%>'in ikinci parametresi isimli son argüman değil"
 
-#: fortran/decl.c:3497
+#: fortran/decl.c:3516
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression at %L must be of INTEGER type"
 msgid "The parameter expression at %C must be of INTEGER type and not %s type"
 msgstr "%L'deki ifade INTEGER türünde olmalı"
 
-#: fortran/decl.c:3525
+#: fortran/decl.c:3544
 #, gcc-internal-format
 msgid "The KIND parameter %qs at %C cannot either be ASSUMED or DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:3532
+#: fortran/decl.c:3551
 #, fuzzy, gcc-internal-format
 #| msgid "Parameter '%s' at %L has not been declared or is a variable, which does not reduce to a constant expression"
 msgid "The value for the KIND parameter %qs at %C does not reduce to a constant expression"
 msgstr "Bir sabit ifadesine indirgenmeyen '%s' parametresi %L'de ya bildirilmemiş ya da değişken değil"
 
-#: fortran/decl.c:3547
+#: fortran/decl.c:3566
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C contains too many parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3556
+#: fortran/decl.c:3575
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid type argument"
 msgid "Parameterized derived type at %C is ambiguous"
 msgstr "tür argümanı geçersiz"
 
-#: fortran/decl.c:3819
+#: fortran/decl.c:3838
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: BYTE type at %C"
 msgid "BYTE type at %C"
 msgstr "Genişletme: %C'de BYTE türü"
 
-#: fortran/decl.c:3824
+#: fortran/decl.c:3843
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr "%C'de hedef makinede desteklenmeyen BYTE türü kullanılmış"
 
-#: fortran/decl.c:3846
+#: fortran/decl.c:3865
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Derived type definition at %C has no components"
 msgid "Assumed type at %C is not allowed for components"
 msgstr "%C'deki türetilmiş tür tanımının hiç bileşeni yok"
 
-#: fortran/decl.c:3849
+#: fortran/decl.c:3868
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr ""
 
-#: fortran/decl.c:3872 fortran/decl.c:3903 fortran/decl.c:3932
-#: fortran/decl.c:4216
+#: fortran/decl.c:3891 fortran/decl.c:3922 fortran/decl.c:3951
+#: fortran/decl.c:4235
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr ""
 
-#: fortran/decl.c:3928
+#: fortran/decl.c:3947
 #, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr ""
 
-#: fortran/decl.c:3971 fortran/decl.c:4107 fortran/decl.c:4119
-#: fortran/decl.c:4133 fortran/decl.c:4611 fortran/decl.c:4619
+#: fortran/decl.c:3990 fortran/decl.c:4126 fortran/decl.c:4138
+#: fortran/decl.c:4152 fortran/decl.c:4630 fortran/decl.c:4638
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C is ambiguous"
 msgid "Type name %qs at %C is ambiguous"
 msgstr "Tür ismi '%s' %C'de belirsiz"
 
-#: fortran/decl.c:4066
+#: fortran/decl.c:4085
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected CASE statement at %C"
 msgid "CLASS statement at %C"
 msgstr "%C'de umulmadık CASE deyimi"
 
-#: fortran/decl.c:4148
+#: fortran/decl.c:4167
 #, gcc-internal-format
 msgid "Type name %qs at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr ""
 
-#: fortran/decl.c:4287
+#: fortran/decl.c:4306
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr "%C'de IMPLICIT NONE deyimi yinelenmiş"
 
-#: fortran/decl.c:4296
+#: fortran/decl.c:4315
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr ""
 
-#: fortran/decl.c:4355
+#: fortran/decl.c:4374
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr "%C'deki IMPLICIT içinde karakter aralığı eksik"
 
-#: fortran/decl.c:4401
+#: fortran/decl.c:4420
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr "%C'deki IMPLICIT deyiminde harfler alfabetik sırada olmalı"
 
-#: fortran/decl.c:4454
+#: fortran/decl.c:4473
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "SAVE statement at %C follows blanket SAVE statement"
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr "%C'deki SAVE deyiminden önce bir kapsamlı SAVE deyimi var"
 
-#: fortran/decl.c:4464
+#: fortran/decl.c:4483
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr "%C'deki IMPLICIT deyimi boş"
 
-#: fortran/decl.c:4570
+#: fortran/decl.c:4589
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr "%C'deki ENTRY deyimi bir INTERFACE bloku içindeymiş gibi görünmüyor"
 
-#: fortran/decl.c:4577
+#: fortran/decl.c:4596
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgid "F2008: C1210 IMPORT statement at %C is not permitted in a module procedure interface body"
 msgstr "%C'deki ENTRY deyimi bir INTERFACE bloku içindeymiş gibi görünmüyor"
 
-#: fortran/decl.c:4582
+#: fortran/decl.c:4601
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "IMPORT statement at %C"
 msgstr "%C'deki IMPLICIT deyimi boş"
 
-#: fortran/decl.c:4596
+#: fortran/decl.c:4615
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting %s statement at %C"
 msgid "Expecting list of named entities at %C"
 msgstr "%s deyimi umuluyordu (%C'de)"
 
-#: fortran/decl.c:4625
+#: fortran/decl.c:4644
 #, gcc-internal-format
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr ""
 
-#: fortran/decl.c:4632
+#: fortran/decl.c:4651
 #, gcc-internal-format
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr ""
 
-#: fortran/decl.c:4673
+#: fortran/decl.c:4692
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in %s statement at %C"
 msgid "Syntax error in IMPORT statement at %C"
 msgstr "%s deyiminde sözdizimi hatası (%C'de)"
 
-#: fortran/decl.c:5010
+#: fortran/decl.c:5029
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing dimension specification at %C"
 msgid "Missing codimension specification at %C"
 msgstr "%C'de boyut belirtimi eksik"
 
-#: fortran/decl.c:5012
+#: fortran/decl.c:5031
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr "%C'de boyut belirtimi eksik"
 
-#: fortran/decl.c:5107
+#: fortran/decl.c:5126
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr "%s özniteliği %L'de yinelenmiş"
 
-#: fortran/decl.c:5124
+#: fortran/decl.c:5143
 #, gcc-internal-format
 msgid "%s at %L is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:5141
+#: fortran/decl.c:5160
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr "%L'deki öznitelik bir TYPE tanımında kullanılamaz"
 
-#: fortran/decl.c:5150
+#: fortran/decl.c:5169
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "KIND attribute at %C in a TYPE definition"
 msgstr "%L'deki öznitelik bir TYPE tanımında kullanılamaz"
 
-#: fortran/decl.c:5158
+#: fortran/decl.c:5177
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a POINTER"
 msgid "Component with KIND attribute at %C must be INTEGER"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) bir POINTER olmalı"
 
-#: fortran/decl.c:5165
+#: fortran/decl.c:5184
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5174
+#: fortran/decl.c:5193
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "LEN attribute at %C in a TYPE definition"
 msgstr "%L'deki öznitelik bir TYPE tanımında kullanılamaz"
 
-#: fortran/decl.c:5182
+#: fortran/decl.c:5201
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a POINTER"
 msgid "Component with LEN attribute at %C must be INTEGER"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) bir POINTER olmalı"
 
-#: fortran/decl.c:5189
+#: fortran/decl.c:5208
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5198
+#: fortran/decl.c:5217
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr "%L'deki öznitelik bir TYPE tanımında kullanılamaz"
 
-#: fortran/decl.c:5216
+#: fortran/decl.c:5235
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr "%L'deki öznitelik bir TYPE tanımında kullanılamaz"
 
-#: fortran/decl.c:5226
+#: fortran/decl.c:5245
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s attribute at %L is not allowed outside of a MODULE"
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr "%s özniteliği ('%L'de) bir MODULE dışında kullanılamaz"
 
-#: fortran/decl.c:5236
+#: fortran/decl.c:5255
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "Attribute at %L is not allowed outside a TYPE definition"
 msgstr "%L'deki öznitelik bir TYPE tanımında kullanılamaz"
 
-#: fortran/decl.c:5249
+#: fortran/decl.c:5268
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5260
+#: fortran/decl.c:5279
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5315 fortran/decl.c:8673
+#: fortran/decl.c:5334 fortran/decl.c:8692
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:5321
+#: fortran/decl.c:5340
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate %s attribute at %L"
 msgid "PROTECTED attribute at %C"
 msgstr "%s özniteliği %L'de yinelenmiş"
 
-#: fortran/decl.c:5355
+#: fortran/decl.c:5374
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Line truncated at %C"
 msgid "VALUE attribute at %C"
 msgstr "%C'deki satır kırpıldı"
 
-#: fortran/decl.c:5362
+#: fortran/decl.c:5381
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5369
+#: fortran/decl.c:5388
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr ""
 
-#: fortran/decl.c:5410
+#: fortran/decl.c:5429
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:5508
+#: fortran/decl.c:5527
 #, gcc-internal-format
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:5530
+#: fortran/decl.c:5549
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5539
+#: fortran/decl.c:5558
 #, gcc-internal-format
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5543
+#: fortran/decl.c:5562
 #, gcc-internal-format
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5555
+#: fortran/decl.c:5574
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr ""
 
-#: fortran/decl.c:5569
+#: fortran/decl.c:5588
 #, fuzzy, gcc-internal-format
 #| msgid "Loop variable at %C cannot have the POINTER attribute"
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr "%C'deki döngü değişkeni POINTER özniteliğinde olamaz"
 
-#: fortran/decl.c:5577
+#: fortran/decl.c:5596
 #, fuzzy, gcc-internal-format
 #| msgid "Loop variable at %C cannot have the POINTER attribute"
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr "%C'deki döngü değişkeni POINTER özniteliğinde olamaz"
 
-#: fortran/decl.c:5589
+#: fortran/decl.c:5608
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be array-valued"
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr "CHARACTER(*) işlevi '%s'  %L'de dizi değerli olamaz"
 
-#: fortran/decl.c:5597
+#: fortran/decl.c:5616
 #, fuzzy, gcc-internal-format
 #| msgid "Specification function '%s' at %L cannot be a statement function"
 msgid "Return type of BIND(C) function %qs at %L cannot be a character string"
@@ -59301,367 +59373,367 @@
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:5608
+#: fortran/decl.c:5627
 #, gcc-internal-format
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr ""
 
-#: fortran/decl.c:5682
+#: fortran/decl.c:5701
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5727
+#: fortran/decl.c:5746
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing generic specification in USE statement at %C"
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr "%C'deki USE deyiminde soysal belirtim eksik"
 
-#: fortran/decl.c:5734
+#: fortran/decl.c:5753
 #, fuzzy, gcc-internal-format
 #| msgid "missing number"
 msgid "Missing symbol"
 msgstr "sayı eksik"
 
-#: fortran/decl.c:5763
+#: fortran/decl.c:5782
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "BIND(C) statement at %C"
 msgstr "%C'deki IMPLICIT deyimi boş"
 
-#: fortran/decl.c:5850
+#: fortran/decl.c:5869
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition."
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr "%C'deki türetilmiş tür evvelce tanımlanmış olmamalıydı, bu durumda bir türetilmiş tür tanımı içinde görünemez"
 
-#: fortran/decl.c:5892
+#: fortran/decl.c:5911
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in data declaration at %C"
 msgid "Syntax error in anonymous structure declaration at %C"
 msgstr "%C'deki veri bildiriminde sözdizimi hatası"
 
-#: fortran/decl.c:5901
+#: fortran/decl.c:5920
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr "%C'deki veri bildiriminde sözdizimi hatası"
 
-#: fortran/decl.c:5951
+#: fortran/decl.c:5970
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "procedure name = %s"
 msgid "MODULE prefix at %C"
 msgstr "yordam ismi = %s"
 
-#: fortran/decl.c:5996
+#: fortran/decl.c:6015
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "procedure name = %s"
 msgid "IMPURE procedure at %C"
 msgstr "yordam ismi = %s"
 
-#: fortran/decl.c:6008
+#: fortran/decl.c:6027
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr ""
 
-#: fortran/decl.c:6054
+#: fortran/decl.c:6073
 #, gcc-internal-format, gfc-internal-format
 msgid "ELEMENTAL prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6061
+#: fortran/decl.c:6080
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6068
+#: fortran/decl.c:6087
 #, gcc-internal-format, gfc-internal-format
 msgid "RECURSIVE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6134 fortran/primary.c:1820
+#: fortran/decl.c:6153 fortran/primary.c:1820
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected alternate return label at %C"
 msgid "Alternate-return argument at %C"
 msgstr "%C'de diğer return yaftası umuluyordu"
 
-#: fortran/decl.c:6140 fortran/decl.c:6148
+#: fortran/decl.c:6159 fortran/decl.c:6167
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "template argument required for %<%s %T%>"
 msgid "A parameter name is required at %C"
 msgstr "%<%s %T%> için şablon argüman gerekli"
 
-#: fortran/decl.c:6188
+#: fortran/decl.c:6207
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is the name of the procedure"
 msgid "Name %qs at %C is the name of the procedure"
 msgstr "İsim '%s' %C'de işlev ismidir"
 
-#: fortran/decl.c:6201
+#: fortran/decl.c:6220
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected another dimension in array declaration at %C"
 msgid "Expected parameter list in type declaration at %C"
 msgstr "%C'deki dizi bildiriminde farklı bir boyut umuluyordu"
 
-#: fortran/decl.c:6204
+#: fortran/decl.c:6223
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr "%C'deki biçimsel argüman listesinde umulmadık döküntü"
 
-#: fortran/decl.c:6222
+#: fortran/decl.c:6241
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate %s specification at %C"
 msgid "Duplicate name %qs in parameter list at %C"
 msgstr "%s belirtimi %C'de yinelenmiş"
 
-#: fortran/decl.c:6225
+#: fortran/decl.c:6244
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate symbol '%s' in formal argument list at %C"
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr "Sembol '%s' %C'deki biçimsel argüman listesinde yinelenmiş"
 
-#: fortran/decl.c:6264
+#: fortran/decl.c:6283
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in MODULE PROCEDURE formal argument names (%s/%s) at %C"
 msgstr ""
 
-#: fortran/decl.c:6270
+#: fortran/decl.c:6289
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in number of MODULE PROCEDURE formal arguments at %C"
 msgstr ""
 
-#: fortran/decl.c:6309
+#: fortran/decl.c:6328
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr "%C'deki RESULT değişkeninin ismi işlev isminden farklı olmalı"
 
-#: fortran/decl.c:6386
+#: fortran/decl.c:6405
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr "%C'deki işlev bildiriminden sonra umulmayan döküntü"
 
-#: fortran/decl.c:6396 fortran/decl.c:7494
+#: fortran/decl.c:6415 fortran/decl.c:7513
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "SAVE attribute at %L cannot be specified in a PURE procedure"
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr "%L'deki SAVE özniteliği bir PURE yordamında belirtilemez"
 
-#: fortran/decl.c:6600
+#: fortran/decl.c:6619
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:6607
+#: fortran/decl.c:6626
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:6613
+#: fortran/decl.c:6632
 #, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr ""
 
-#: fortran/decl.c:6636
+#: fortran/decl.c:6655
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L already has basic type of %s"
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr "'%s' simgesi %L'de zaten temel %s türünde"
 
-#: fortran/decl.c:6682 fortran/decl.c:6870 fortran/decl.c:10723
+#: fortran/decl.c:6701 fortran/decl.c:6889 fortran/decl.c:10748
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr "%C'deki SAVE deyiminde sözdizimi hatası"
 
-#: fortran/decl.c:6731 fortran/decl.c:10623
+#: fortran/decl.c:6750 fortran/decl.c:10648
 #, fuzzy, gcc-internal-format
 #| msgid "Expected terminating name at %C"
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr "%C'de sonlandıran isim umuluyordu"
 
-#: fortran/decl.c:6738
+#: fortran/decl.c:6757
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr ""
 
-#: fortran/decl.c:6742
+#: fortran/decl.c:6761
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected structure component name at %C"
 msgid "Procedure pointer component at %C"
 msgstr "%C'de yapı bileşeni ismi umuluyordu"
 
-#: fortran/decl.c:6814
+#: fortran/decl.c:6833
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in structure constructor at %C"
 msgid "Syntax error in procedure pointer component at %C"
 msgstr "%C'deki yapı kurucuda söz dizimi hatası"
 
-#: fortran/decl.c:6832
+#: fortran/decl.c:6851
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr "%C'deki MODULE PROCEDURE bir soysal modül arayüzü olmalı"
 
-#: fortran/decl.c:6841 fortran/decl.c:9392
+#: fortran/decl.c:6860 fortran/decl.c:9411
 #, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr ""
 
-#: fortran/decl.c:6911
+#: fortran/decl.c:6930
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Obsolete: PAUSE statement at %C"
 msgid "PROCEDURE statement at %C"
 msgstr "Atıl: %C'deki PAUSE deyimi"
 
-#: fortran/decl.c:6983
+#: fortran/decl.c:7002
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr "%C'deki işlev tanımında biçimsel argüman listesi umuluyordu"
 
-#: fortran/decl.c:7007 fortran/decl.c:7011 fortran/decl.c:7266
-#: fortran/decl.c:7270 fortran/decl.c:7462 fortran/decl.c:7466
-#: fortran/symbol.c:1875
+#: fortran/decl.c:7026 fortran/decl.c:7030 fortran/decl.c:7285
+#: fortran/decl.c:7289 fortran/decl.c:7481 fortran/decl.c:7485
+#: fortran/symbol.c:1889
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr ""
 
-#: fortran/decl.c:7164
+#: fortran/decl.c:7183
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "ENTRY statement at %C"
 msgstr "%C'deki IMPLICIT deyimi boş"
 
-#: fortran/decl.c:7173
+#: fortran/decl.c:7192
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr "%C'deki ENTRY deyimi bir PROGRAM içindeymiş gibi görünmüyor"
 
-#: fortran/decl.c:7176
+#: fortran/decl.c:7195
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr "%C'deki ENTRY deyimi bir MODULE içindeymiş gibi görünmüyor"
 
-#: fortran/decl.c:7179
+#: fortran/decl.c:7198
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgid "ENTRY statement at %C cannot appear within a SUBMODULE"
 msgstr "%C'deki ENTRY deyimi bir MODULE içindeymiş gibi görünmüyor"
 
-#: fortran/decl.c:7182
+#: fortran/decl.c:7201
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr "%C'deki ENTRY deyimi bir BLOCK DATA içindeymiş gibi görünmüyor"
 
-#: fortran/decl.c:7186 fortran/decl.c:7231
+#: fortran/decl.c:7205 fortran/decl.c:7250
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr "%C'deki ENTRY deyimi bir INTERFACE bloku içindeymiş gibi görünmüyor"
 
-#: fortran/decl.c:7190
+#: fortran/decl.c:7209
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgid "ENTRY statement at %C cannot appear within a STRUCTURE block"
 msgstr "%C'deki ENTRY deyimi bir SELECT bloku içindeymiş gibi görünmüyor"
 
-#: fortran/decl.c:7194
+#: fortran/decl.c:7213
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr "%C'deki ENTRY deyimi bir DERIVED TYPE bloku içindeymiş gibi görünmüyor"
 
-#: fortran/decl.c:7198
+#: fortran/decl.c:7217
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr "%C'deki ENTRY deyimi bir IF-THEN bloku içindeymiş gibi görünmüyor"
 
-#: fortran/decl.c:7203
+#: fortran/decl.c:7222
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr "%C'deki ENTRY deyimi bir DO bloku içinde görünemez"
 
-#: fortran/decl.c:7207
+#: fortran/decl.c:7226
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr "%C'deki ENTRY deyimi bir SELECT bloku içindeymiş gibi görünmüyor"
 
-#: fortran/decl.c:7211
+#: fortran/decl.c:7230
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr "%C'deki ENTRY deyimi bir FORALL bloku içindeymiş gibi görünmüyor"
 
-#: fortran/decl.c:7215
+#: fortran/decl.c:7234
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr "%C'deki ENTRY deyimi bir WHERE bloku içindeymiş gibi görünmüyor"
 
-#: fortran/decl.c:7219
+#: fortran/decl.c:7238
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr "%C'deki ENTRY deyimi bir içerilmiş altyordamın içinde görünemez"
 
-#: fortran/decl.c:7223
+#: fortran/decl.c:7242
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected END statement at %C"
 msgid "Unexpected ENTRY statement at %C"
 msgstr "%C'de beklenmeyen END deyimi"
 
-#: fortran/decl.c:7244
+#: fortran/decl.c:7263
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr "%C'deki ENTRY deyimi bir içerilmiş işlevde görünemez"
 
-#: fortran/decl.c:7295 fortran/decl.c:7501
+#: fortran/decl.c:7314 fortran/decl.c:7520
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7563 fortran/decl.c:7570
+#: fortran/decl.c:7582 fortran/decl.c:7589
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:7610
+#: fortran/decl.c:7629
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CASE-specification at %C"
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr "%C'deki CASE belirtiminde sözdizimi hatası"
 
-#: fortran/decl.c:7626
+#: fortran/decl.c:7645
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr ""
 
-#: fortran/decl.c:7634
+#: fortran/decl.c:7653
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr ""
 
-#: fortran/decl.c:7653
+#: fortran/decl.c:7672
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing format label at %C"
 msgid "Missing closing paren for binding label at %C"
 msgstr "%C'de biçim yaftası eksik"
 
-#: fortran/decl.c:7659
+#: fortran/decl.c:7678
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Function name '%s' not allowed at %C"
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr "'%s' işlev ismi olarak %C'de kullanılamaz"
 
-#: fortran/decl.c:7665
+#: fortran/decl.c:7684
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7694
+#: fortran/decl.c:7713
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr ""
 
-#: fortran/decl.c:7939
+#: fortran/decl.c:7958
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr "%C'de beklenmeyen END deyimi"
 
-#: fortran/decl.c:7948
+#: fortran/decl.c:7967
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement at %C cannot follow %s statement at %L"
 msgid "END statement instead of %s statement at %L"
@@ -59668,176 +59740,176 @@
 msgstr "%s deyimi (%C'deki), %s deyimini (%L'deki) izlemiyor"
 
 #. We would have required END [something].
-#: fortran/decl.c:7957
+#: fortran/decl.c:7976
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr "%s deyimi %L'de umuluyordu"
 
-#: fortran/decl.c:7968
+#: fortran/decl.c:7987
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting %s statement at %C"
 msgid "Expecting %s statement at %L"
 msgstr "%s deyimi umuluyordu (%C'de)"
 
-#: fortran/decl.c:7988
+#: fortran/decl.c:8007
 #, fuzzy, gcc-internal-format
 #| msgid "Expected block name of '%s' in %s statement at %C"
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr "'%s' için %s deyiminde (%C'de) blok ismi umuluyordu"
 
-#: fortran/decl.c:8005
+#: fortran/decl.c:8024
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr "%C'de sonlandıran isim umuluyordu"
 
-#: fortran/decl.c:8019 fortran/decl.c:8027
+#: fortran/decl.c:8038 fortran/decl.c:8046
 #, fuzzy, gcc-internal-format
 #| msgid "Expected label '%s' for %s statement at %C"
 msgid "Expected label %qs for %s statement at %C"
 msgstr "'%s' etiketi umuluyordu (%s deyiminde, %C'de)"
 
-#: fortran/decl.c:8126
+#: fortran/decl.c:8145
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr "DIMENSION deyiminde %L'de dizi belirtimi eksik"
 
-#: fortran/decl.c:8134
+#: fortran/decl.c:8153
 #, gcc-internal-format, gfc-internal-format
 msgid "Dimensions specified for %s at %L after its initialization"
 msgstr ""
 
-#: fortran/decl.c:8142
+#: fortran/decl.c:8161
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing array specification at %L in DIMENSION statement"
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr "DIMENSION deyiminde %L'de dizi belirtimi eksik"
 
-#: fortran/decl.c:8151
+#: fortran/decl.c:8170
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr "Dizi belirtimi %L'de ertelenmiş olmalı"
 
-#: fortran/decl.c:8249
+#: fortran/decl.c:8268
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr "%C'deki değişken listesinde umulmadık karakter"
 
-#: fortran/decl.c:8286
+#: fortran/decl.c:8305
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "Expected %<(%> at %C"
 msgstr "%C'de '(' umuluyordu"
 
-#: fortran/decl.c:8300 fortran/decl.c:8340
+#: fortran/decl.c:8319 fortran/decl.c:8359
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr "%C'de değişken ismi umuluyordu"
 
-#: fortran/decl.c:8316
+#: fortran/decl.c:8335
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Cray pointer at %C must be an integer."
 msgid "Cray pointer at %C must be an integer"
 msgstr "%C'deki Cray göstericisi bir tamsayı olmalı."
 
-#: fortran/decl.c:8320
+#: fortran/decl.c:8339
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes."
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr "%C'deki Cray göstericisi %d baytlık hassasiyete sahip ancak bellek adresi %d bayt gerektiriyor"
 
-#: fortran/decl.c:8326
+#: fortran/decl.c:8345
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr "%C'de \",\" umuluyordu"
 
-#: fortran/decl.c:8365
+#: fortran/decl.c:8384
 #, gcc-internal-format
 msgid "Couldn't set Cray pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:8389
+#: fortran/decl.c:8408
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr "%C'de \")\" umuluyordu"
 
-#: fortran/decl.c:8401
+#: fortran/decl.c:8420
 #, fuzzy, gcc-internal-format
 #| msgid "Expected \",\" or end of statement at %C"
 msgid "Expected %<,%> or end of statement at %C"
 msgstr "%C'de \",\" veya deyim sonu umuluyordu"
 
-#: fortran/decl.c:8427
+#: fortran/decl.c:8446
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:8459
+#: fortran/decl.c:8478
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:8478
+#: fortran/decl.c:8497
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Cray pointer declaration at %C requires -fcray-pointer flag."
 msgid "Cray pointer declaration at %C requires -fcray-pointer flag"
 msgstr "%C'deki Cray göstericisi bildirimi -fcray-pointer seçeneğini gerektiriyor"
 
-#: fortran/decl.c:8517
+#: fortran/decl.c:8536
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Obsolete: PAUSE statement at %C"
 msgid "CONTIGUOUS statement at %C"
 msgstr "Atıl: %C'deki PAUSE deyimi"
 
-#: fortran/decl.c:8623
+#: fortran/decl.c:8642
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr "%s işlecinin erişim belirtimi %C'de zaten belirtilmişti"
 
-#: fortran/decl.c:8640
+#: fortran/decl.c:8659
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr ".%s. işlecinin erişim belirtimi %C'de zaten belirtilmişti"
 
-#: fortran/decl.c:8679
+#: fortran/decl.c:8698
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "PROTECTED statement at %C"
 msgstr "%C'deki IMPLICIT deyimi boş"
 
-#: fortran/decl.c:8717
+#: fortran/decl.c:8736
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr "%C'deki SAVE deyiminde sözdizimi hatası"
 
-#: fortran/decl.c:8741
+#: fortran/decl.c:8760
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "DATA statement at %C is not allowed in a PURE procedure"
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr "%C'de DATA deyimi için bir PURE işlevinde izin verilmez"
 
-#: fortran/decl.c:8778
+#: fortran/decl.c:8797
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "DATA statement at %C is not allowed in a PURE procedure"
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr "%C'de DATA deyimi için bir PURE işlevinde izin verilmez"
 
-#: fortran/decl.c:8806
+#: fortran/decl.c:8825
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr "%C'de PARAMETER deyiminde değişken ismi umuluyordu"
 
-#: fortran/decl.c:8813
+#: fortran/decl.c:8832
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr "%C'deki PARAMETER deyiminde = işareti umuluyordu"
 
-#: fortran/decl.c:8819
+#: fortran/decl.c:8838
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr "%C'deki PARAMETER deyiminde ifade umuluyordu"
 
-#: fortran/decl.c:8839
+#: fortran/decl.c:8858
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Initializer not allowed for COMMON variable '%s' at %C"
 msgid "Initializing already initialized variable at %C"
@@ -59844,502 +59916,508 @@
 msgstr "COMMON değişkeni `%s' için %C'de ilklendirme yapılamaz"
 
 #. With legacy PARAMETER statements, don't expect a terminating ')'.
-#: fortran/decl.c:8864
+#: fortran/decl.c:8883
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER without '()' at %C"
 msgstr ""
 
-#: fortran/decl.c:8880
+#: fortran/decl.c:8899
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr "%C'deki PARAMETER deyiminde umulmayan karakterler"
 
-#: fortran/decl.c:8899 fortran/decl.c:8955
+#: fortran/decl.c:8918 fortran/decl.c:8974
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:8934
+#: fortran/decl.c:8953
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected variable in READ statement at %C"
 msgid "Expected entity-list in AUTOMATIC statement at %C"
 msgstr "%C'deki READ deyiminde değişken umuluyordu"
 
-#: fortran/decl.c:8941
+#: fortran/decl.c:8960
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in AUTOMATIC statement at %C"
 msgstr "%C'deki SAVE deyiminde sözdizimi hatası"
 
-#: fortran/decl.c:8990
+#: fortran/decl.c:9009
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected variable in READ statement at %C"
 msgid "Expected entity-list in STATIC statement at %C"
 msgstr "%C'deki READ deyiminde değişken umuluyordu"
 
-#: fortran/decl.c:8997
+#: fortran/decl.c:9016
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in STATIC statement at %C"
 msgstr "%C'deki SAVE deyiminde sözdizimi hatası"
 
-#: fortran/decl.c:9016
+#: fortran/decl.c:9035
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr "%C'deki kapsamlı SAVE deyiminden önce bir SAVE deyimi var"
 
-#: fortran/decl.c:9027
+#: fortran/decl.c:9046
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr "%C'deki SAVE deyiminden önce bir kapsamlı SAVE deyimi var"
 
-#: fortran/decl.c:9073
+#: fortran/decl.c:9092
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr "%C'deki SAVE deyiminde sözdizimi hatası"
 
-#: fortran/decl.c:9087
+#: fortran/decl.c:9106
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:9091
+#: fortran/decl.c:9110
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Obsolete: PAUSE statement at %C"
 msgid "VALUE statement at %C"
 msgstr "Atıl: %C'deki PAUSE deyimi"
 
-#: fortran/decl.c:9129
+#: fortran/decl.c:9148
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in VALUE statement at %C"
 msgstr "%C'deki SAVE deyiminde sözdizimi hatası"
 
-#: fortran/decl.c:9141
+#: fortran/decl.c:9160
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate PRIVATE statement at %C"
 msgid "VOLATILE statement at %C"
 msgstr "%C'de PRIVATE deyimi yinelenmiş"
 
-#: fortran/decl.c:9168
+#: fortran/decl.c:9187
 #, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr ""
 
-#: fortran/decl.c:9193
+#: fortran/decl.c:9212
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr "%C'deki SAVE deyiminde sözdizimi hatası"
 
-#: fortran/decl.c:9205
+#: fortran/decl.c:9224
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Obsolete: PAUSE statement at %C"
 msgid "ASYNCHRONOUS statement at %C"
 msgstr "Atıl: %C'deki PAUSE deyimi"
 
-#: fortran/decl.c:9249
+#: fortran/decl.c:9268
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr "%C'deki SAVE deyiminde sözdizimi hatası"
 
-#: fortran/decl.c:9274
+#: fortran/decl.c:9293
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in data declaration at %C"
 msgid "MODULE PROCEDURE declaration at %C"
 msgstr "%C'deki veri bildiriminde sözdizimi hatası"
 
-#: fortran/decl.c:9367
+#: fortran/decl.c:9386
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr "%C'deki MODULE PROCEDURE bir soysal modül arayüzü olmalı"
 
-#: fortran/decl.c:9425
+#: fortran/decl.c:9444
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr ""
 
-#: fortran/decl.c:9474
+#: fortran/decl.c:9493
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected :: in TYPE definition at %C"
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr "%C'deki TYPE tanımında :: umuluyordu"
 
-#: fortran/decl.c:9483
+#: fortran/decl.c:9502
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C has already been host associated"
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr "'%s' simgesi (%C'deki) zaten konakla ilişkiliymiş"
 
-#: fortran/decl.c:9489
+#: fortran/decl.c:9508
 #, gcc-internal-format
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr ""
 
-#: fortran/decl.c:9496
+#: fortran/decl.c:9515
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:9503
+#: fortran/decl.c:9522
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be thread-local because it has non-POD type %qT"
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr "%qD evreye yerel olamaz çünkü POD olmayan %qT türünde"
 
-#: fortran/decl.c:9526
+#: fortran/decl.c:9545
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Derived type at %C can only be PRIVATE within a MODULE"
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr "%C'deki türetilmiş tür sadece bir MODULE içinde PRIVATE olabilir"
 
-#: fortran/decl.c:9538
+#: fortran/decl.c:9557
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Derived type at %C can only be PUBLIC within a MODULE"
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr "%C'deki türetilmiş tür sadece bir MODULE içinde PUBLIC olabilir"
 
-#: fortran/decl.c:9559
+#: fortran/decl.c:9578
 #, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
 msgstr ""
 
-#: fortran/decl.c:9605
+#: fortran/decl.c:9624
 #, gcc-internal-format, gfc-internal-format
 msgid "Failed to create structure type '%s' at %C"
 msgstr ""
 
-#: fortran/decl.c:9611
+#: fortran/decl.c:9630
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type definition of '%s' at %C has already been defined"
 msgid "Type definition of %qs at %C was already defined at %L"
 msgstr "'%s' için türetilmiş tür tanımı %C'de zaten tanımlı"
 
-#: fortran/decl.c:9658
+#: fortran/decl.c:9677
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate PRIVATE statement at %C"
 msgid "Junk after MAP statement at %C"
 msgstr "%C'de PRIVATE deyimi yinelenmiş"
 
-#: fortran/decl.c:9691
+#: fortran/decl.c:9710
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate PRIVATE statement at %C"
 msgid "Junk after UNION statement at %C"
 msgstr "%C'de PRIVATE deyimi yinelenmiş"
 
-#: fortran/decl.c:9726
+#: fortran/decl.c:9745
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is not a member of the '%s' structure"
 msgid "%s at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr "'%s' (%C'deki) '%s' yapısının bir üyesi değil"
 
-#: fortran/decl.c:9740
+#: fortran/decl.c:9759
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after function declaration at %C"
 msgid "Structure name expected in non-nested structure declaration at %C"
 msgstr "%C'deki işlev bildiriminden sonra umulmayan döküntü"
 
-#: fortran/decl.c:9758
+#: fortran/decl.c:9777
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate PRIVATE statement at %C"
 msgid "Junk after non-nested STRUCTURE statement at %C"
 msgstr "%C'de PRIVATE deyimi yinelenmiş"
 
-#: fortran/decl.c:9765
+#: fortran/decl.c:9784
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C cannot be the same as an intrinsic type"
 msgid "Structure name %qs at %C cannot be the same as an intrinsic type"
 msgstr "Tür ismi '%s' (%C'de) bir yerleşik türle aynı olamaz"
 
-#: fortran/decl.c:9926
+#: fortran/decl.c:9947
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr "%C'deki TYPE tanımında :: umuluyordu"
 
-#: fortran/decl.c:9954
+#: fortran/decl.c:9975
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C cannot be the same as an intrinsic type"
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr "Tür ismi '%s' (%C'de) bir yerleşik türle aynı olamaz"
 
-#: fortran/decl.c:9964
+#: fortran/decl.c:9986
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type name '%s' at %C already has a basic type of %s"
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr "Türetilmiş tür ismi '%s' %C'de zaten temel  %s türünde"
 
-#: fortran/decl.c:9981
+#: fortran/decl.c:9989
 #, fuzzy, gcc-internal-format
+#| msgid "Derived type name '%s' at %C already has a basic type of %s"
+msgid "Derived type name %qs at %C already has a basic type"
+msgstr "Türetilmiş tür ismi '%s' %C'de zaten temel  %s türünde"
+
+#: fortran/decl.c:10006
+#, fuzzy, gcc-internal-format
 #| msgid "Derived type definition of '%s' at %C has already been defined"
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr "'%s' için türetilmiş tür tanımı %C'de zaten tanımlı"
 
-#: fortran/decl.c:10042
+#: fortran/decl.c:10067
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CHARACTER declaration at %C"
 msgid "Garbage after PARAMETERIZED TYPE declaration at %C"
 msgstr "%C'deki CHARACTER bildiriminde sözdizimi hatası"
 
-#: fortran/decl.c:10126
+#: fortran/decl.c:10151
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr "%C'deki Cray göstericileri tahmini biçimli dizi olamaz"
 
-#: fortran/decl.c:10146
+#: fortran/decl.c:10171
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "New in Fortran 2003: ENUM AND ENUMERATOR at %C"
 msgid "ENUM and ENUMERATOR at %C"
 msgstr "Fortran 2003'te yeni: %C'de ENUM AND ENUMERATOR"
 
-#: fortran/decl.c:10178
+#: fortran/decl.c:10203
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr "Sayısal sabitler %C'de C tamsayı türünü aşıyor"
 
-#: fortran/decl.c:10257
+#: fortran/decl.c:10282
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr "bir tamsayı ifadesi ile ilklendirilmemiş ENUMERATOR %L"
 
-#: fortran/decl.c:10305
+#: fortran/decl.c:10330
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr "%C öncesinde ENUM tanım deyimi umuluyordu"
 
-#: fortran/decl.c:10341
+#: fortran/decl.c:10366
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr "%C'deki ENUMERATOR tanımında sözdizimi hatası"
 
-#: fortran/decl.c:10388 fortran/decl.c:10403
+#: fortran/decl.c:10413 fortran/decl.c:10428
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate %s specification at %C"
 msgid "Duplicate access-specifier at %C"
 msgstr "%s belirtimi %C'de yinelenmiş"
 
-#: fortran/decl.c:10423
+#: fortran/decl.c:10448
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10443
+#: fortran/decl.c:10468
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10470
+#: fortran/decl.c:10495
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate %s attribute at %L"
 msgid "Duplicate POINTER attribute at %C"
 msgstr "%s özniteliği %L'de yinelenmiş"
 
-#: fortran/decl.c:10488
+#: fortran/decl.c:10513
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected VARIABLE at %C"
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr "%C'de VARIABLE umuluyordu"
 
-#: fortran/decl.c:10504
+#: fortran/decl.c:10529
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate SEQUENCE statement at %C"
 msgid "Duplicate DEFERRED at %C"
 msgstr "%C'de SEQUENCE deyimi yinelenmiş"
 
-#: fortran/decl.c:10517
+#: fortran/decl.c:10542
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected a nameless interface at %C"
 msgid "Expected access-specifier at %C"
 msgstr "%C'de isimsiz bir arayüz umuluyordu"
 
-#: fortran/decl.c:10519
+#: fortran/decl.c:10544
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected terminating name at %C"
 msgid "Expected binding attribute at %C"
 msgstr "%C'de sonlandıran isim umuluyordu"
 
-#: fortran/decl.c:10527
+#: fortran/decl.c:10552
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED can't both appear at %C"
 msgstr ""
 
-#: fortran/decl.c:10539
+#: fortran/decl.c:10564
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:10581
+#: fortran/decl.c:10606
 #, fuzzy, gcc-internal-format
 #| msgid "identifier expected after %<@protocol%>"
 msgid "Interface-name expected after %<(%> at %C"
 msgstr "%<@protocol%> sonrasında betimleyici umuluyordu"
 
-#: fortran/decl.c:10587
+#: fortran/decl.c:10612
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "%<)%> expected at %C"
 msgstr "%C'de '(' umuluyordu"
 
-#: fortran/decl.c:10607
+#: fortran/decl.c:10632
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:10612
+#: fortran/decl.c:10637
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:10635
+#: fortran/decl.c:10660
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected terminating name at %C"
 msgid "Expected binding name at %C"
 msgstr "%C'de sonlandıran isim umuluyordu"
 
-#: fortran/decl.c:10639
+#: fortran/decl.c:10664
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
 msgstr ""
 
-#: fortran/decl.c:10651
+#: fortran/decl.c:10676
 #, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:10657
+#: fortran/decl.c:10682
 #, gcc-internal-format
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr ""
 
-#: fortran/decl.c:10667
+#: fortran/decl.c:10692
 #, fuzzy, gcc-internal-format
 #| msgid "Expected terminating name at %C"
 msgid "Expected binding target after %<=>%> at %C"
 msgstr "%C'de sonlandıran isim umuluyordu"
 
-#: fortran/decl.c:10684
+#: fortran/decl.c:10709
 #, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr ""
 
-#: fortran/decl.c:10695
+#: fortran/decl.c:10720
 #, gcc-internal-format
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:10746
+#: fortran/decl.c:10771
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr ""
 
-#: fortran/decl.c:10766
+#: fortran/decl.c:10791
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "Expected %<::%> at %C"
 msgstr "%C'de '(' umuluyordu"
 
-#: fortran/decl.c:10778
+#: fortran/decl.c:10803
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected array subscript at %C"
 msgid "Expected generic name or operator descriptor at %C"
 msgstr "%C'de dizi indisi umuluyordu"
 
-#: fortran/decl.c:10799
+#: fortran/decl.c:10824
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid form of PROGRAM statement at %C"
 msgid "Malformed GENERIC statement at %C"
 msgstr "%C'deki PROGRAM deyiminin biçimi geçersiz"
 
-#: fortran/decl.c:10810
+#: fortran/decl.c:10835
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "Expected %<=>%> at %C"
 msgstr "%C'de '(' umuluyordu"
 
-#: fortran/decl.c:10846
+#: fortran/decl.c:10871
 #, gcc-internal-format
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:10854
+#: fortran/decl.c:10879
 #, gcc-internal-format
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr ""
 
-#: fortran/decl.c:10902
+#: fortran/decl.c:10927
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected terminating name at %C"
 msgid "Expected specific binding name at %C"
 msgstr "%C'de sonlandıran isim umuluyordu"
 
-#: fortran/decl.c:10912
+#: fortran/decl.c:10937
 #, gcc-internal-format
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:10930
+#: fortran/decl.c:10955
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr ""
 
-#: fortran/decl.c:10965
+#: fortran/decl.c:10990
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr ""
 
-#: fortran/decl.c:10976
+#: fortran/decl.c:11001
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr ""
 
-#: fortran/decl.c:10998
+#: fortran/decl.c:11023
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected VARIABLE at %C"
 msgid "Empty FINAL at %C"
 msgstr "%C'de VARIABLE umuluyordu"
 
-#: fortran/decl.c:11005
+#: fortran/decl.c:11030
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected structure component name at %C"
 msgid "Expected module procedure name at %C"
 msgstr "%C'de yapı bileşeni ismi umuluyordu"
 
-#: fortran/decl.c:11015
+#: fortran/decl.c:11040
 #, fuzzy, gcc-internal-format
 #| msgid "Expected \",\" at %C"
 msgid "Expected %<,%> at %C"
 msgstr "%C'de \",\" umuluyordu"
 
-#: fortran/decl.c:11021
+#: fortran/decl.c:11046
 #, fuzzy, gcc-internal-format
 #| msgid "procedure name = %s"
 msgid "Unknown procedure name %qs at %C"
 msgstr "yordam ismi = %s"
 
-#: fortran/decl.c:11034
+#: fortran/decl.c:11059
 #, fuzzy, gcc-internal-format
 #| msgid "%s procedure at %L is already declared as %s procedure"
 msgid "%qs at %C is already defined as FINAL procedure"
 msgstr "%s yordamı %L'de zaten %s yordamı olarak bildirilmiş"
 
-#: fortran/decl.c:11104
+#: fortran/decl.c:11129
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "RESULT attribute required in ENTRY statement at %C"
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr "%C'deki ENTRY deyimi bir RESULT özniteliği gerektirir"
 
-#: fortran/decl.c:11150
+#: fortran/decl.c:11175
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr "%C'deki SAVE deyiminde sözdizimi hatası"
 
-#: fortran/decl.c:11170
+#: fortran/decl.c:11195
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive requires a non-negative integral constant less than or equal to %u at %C"
 msgstr ""
 
-#: fortran/decl.c:11184
+#: fortran/decl.c:11209
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in FORALL iterator at %C"
 msgid "Syntax error in !GCC$ UNROLL directive at %C"
@@ -60712,27 +60790,27 @@
 msgid "BOZ literal at %L used to initialize non-integer variable %qs"
 msgstr ""
 
-#: fortran/expr.c:3369 fortran/resolve.c:10197
+#: fortran/expr.c:3369 fortran/resolve.c:10210
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal at %L outside a DATA statement and outside INT/REAL/DBLE/CMPLX"
 msgstr ""
 
-#: fortran/expr.c:3380 fortran/resolve.c:10208
+#: fortran/expr.c:3380 fortran/resolve.c:10221
 #, gcc-internal-format
 msgid "BOZ literal at %L is bitwise transferred non-integer symbol %qs"
 msgstr ""
 
-#: fortran/expr.c:3388 fortran/resolve.c:10217
+#: fortran/expr.c:3388 fortran/resolve.c:10230
 #, gcc-internal-format
 msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3392 fortran/resolve.c:10221
+#: fortran/expr.c:3392 fortran/resolve.c:10234
 #, gcc-internal-format
 msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3396 fortran/resolve.c:10225
+#: fortran/expr.c:3396 fortran/resolve.c:10238
 #, gcc-internal-format
 msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
@@ -60742,164 +60820,164 @@
 msgid "The assignment to a KIND or LEN component of a parameterized type at %L is not allowed"
 msgstr ""
 
-#: fortran/expr.c:3426
+#: fortran/expr.c:3429
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Incompatible types in assignment at %L, %s to %s"
 msgid "Incompatible types in DATA statement at %L; attempted conversion of %s to %s"
 msgstr "%L'deki atamada uyumsuz türler, %s den %s'e"
 
-#: fortran/expr.c:3465
+#: fortran/expr.c:3468
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is not a POINTER at %L"
 msgstr "%L'deki gösterici atamasının hedefi bir POINTER değil"
 
-#: fortran/expr.c:3473
+#: fortran/expr.c:3476
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgid "%qs in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgstr "'%s' (%L'deki gösterici atamasındaki) bir yordam olduğundan bir sol taraf değeri olamaz"
 
-#: fortran/expr.c:3496
+#: fortran/expr.c:3499
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate %s specification at %C"
 msgid "Expected bounds specification for %qs at %L"
 msgstr "%s belirtimi %C'de yinelenmiş"
 
-#: fortran/expr.c:3501
+#: fortran/expr.c:3504
 #, fuzzy, gcc-internal-format
 #| msgid "Different types in pointer assignment at %L"
 msgid "Bounds specification for %qs in pointer assignment at %L"
 msgstr "%L'deki gösterici atamasında farklı türler"
 
-#: fortran/expr.c:3514
+#: fortran/expr.c:3517
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower bound has to be present at %L"
 msgstr ""
 
-#: fortran/expr.c:3520
+#: fortran/expr.c:3523
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "stack size must not be greater than 64k"
 msgid "Stride must not be present at %L"
 msgstr "yığıt boyutu 64k'dan büyük olmamalıdır"
 
-#: fortran/expr.c:3532
+#: fortran/expr.c:3535
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the upper bounds must be specified at %L"
 msgstr ""
 
-#: fortran/expr.c:3558
+#: fortran/expr.c:3561
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "External object '%s' at %L may not have an initializer"
 msgid "Pointer object at %L shall not have a coindex"
 msgstr "Harici nesne '%s'  %L'de bir ilklendiriciye sahip olamayabilir"
 
-#: fortran/expr.c:3579
+#: fortran/expr.c:3582
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Different types in pointer assignment at %L"
 msgid "Invalid procedure pointer assignment at %L"
 msgstr "%L'deki gösterici atamasında farklı türler"
 
-#: fortran/expr.c:3603
+#: fortran/expr.c:3606
 #, fuzzy, gcc-internal-format
 #| msgid "Different kind type parameters in pointer assignment at %L"
 msgid "Function result %qs is invalid as proc-target in procedure pointer assignment at %L"
 msgstr "%L'deki gösterici atamasında parametreler farklı çeşit türlerinde"
 
-#: fortran/expr.c:3612
+#: fortran/expr.c:3615
 #, fuzzy, gcc-internal-format
 #| msgid "Different kind type parameters in pointer assignment at %L"
 msgid "Abstract interface %qs is invalid in procedure pointer assignment at %L"
 msgstr "%L'deki gösterici atamasında parametreler farklı çeşit türlerinde"
 
-#: fortran/expr.c:3622
+#: fortran/expr.c:3625
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' requires argument list at %C"
 msgid "Statement function %qs is invalid in procedure pointer assignment at %L"
 msgstr "'%s' deyim işlevi %C'de argüman listesi gerektiriyor"
 
-#: fortran/expr.c:3628
+#: fortran/expr.c:3631
 #, fuzzy, gcc-internal-format
 #| msgid "Internal procedure '%s' is not allowed as an actual argument at %L"
 msgid "Internal procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "'%s' iç yordamına %L'de bir fiili argüman olarak izin verilmez."
 
-#: fortran/expr.c:3635
+#: fortran/expr.c:3638
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L is not included in the selected standard"
 msgid "Intrinsic %qs at %L is invalid in procedure pointer assignment"
 msgstr "%L'deki yerleşik '%s' seçilmiş standartta bulunmuyor"
 
-#: fortran/expr.c:3643
+#: fortran/expr.c:3646
 #, gcc-internal-format
 msgid "Nonintrinsic elemental procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3666
+#: fortran/expr.c:3669
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in the procedure pointer assignment at %L: mismatch in the calling convention"
 msgstr ""
 
-#: fortran/expr.c:3719
+#: fortran/expr.c:3722
 #, fuzzy, gcc-internal-format
 #| msgid "Different character lengths in pointer assignment at %L"
 msgid "Interface mismatch in procedure pointer assignment at %L: %qs is not a subroutine"
 msgstr "%L'deki gösterici atamasında farklı karakter uzunlukları"
 
-#: fortran/expr.c:3729 fortran/expr.c:3744
+#: fortran/expr.c:3732 fortran/expr.c:3747
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate interface declaration for class %qs"
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr "%qs sınıfı için birden fazla arabirim bildirimi"
 
-#: fortran/expr.c:3735 fortran/expr.c:3750 fortran/resolve.c:2566
+#: fortran/expr.c:3738 fortran/expr.c:3753 fortran/resolve.c:2566
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate interface declaration for class %qs"
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr "%qs sınıfı için birden fazla arabirim bildirimi"
 
-#: fortran/expr.c:3762
+#: fortran/expr.c:3765
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Different character lengths in pointer assignment at %L"
 msgid "Interface mismatch in procedure pointer assignment at %L: %s"
 msgstr "%L'deki gösterici atamasında farklı karakter uzunlukları"
 
-#: fortran/expr.c:3771
+#: fortran/expr.c:3774
 #, gcc-internal-format
 msgid "Procedure pointer target %qs at %L must be either an intrinsic, host or use associated, referenced or have the EXTERNAL attribute"
 msgstr ""
 
-#: fortran/expr.c:3788
+#: fortran/expr.c:3791
 #, gcc-internal-format, gfc-internal-format
 msgid "Data-pointer-object at %L must be unlimited polymorphic, or of a type with the BIND or SEQUENCE attribute, to be compatible with an unlimited polymorphic target"
 msgstr ""
 
-#: fortran/expr.c:3793
+#: fortran/expr.c:3796
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Different types in pointer assignment at %L"
 msgid "Different types in pointer assignment at %L; attempted assignment of %s to %s"
 msgstr "%L'deki gösterici atamasında farklı türler"
 
-#: fortran/expr.c:3802
+#: fortran/expr.c:3805
 #, gcc-internal-format, gfc-internal-format
 msgid "Different kind type parameters in pointer assignment at %L"
 msgstr "%L'deki gösterici atamasında parametreler farklı çeşit türlerinde"
 
-#: fortran/expr.c:3809
+#: fortran/expr.c:3812
 #, gcc-internal-format, gfc-internal-format
 msgid "Different ranks in pointer assignment at %L"
 msgstr "%L'deki gösterici atamasında farklı sıralamalar"
 
-#: fortran/expr.c:3828
+#: fortran/expr.c:3831
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is smaller than size of the pointer (%ld < %ld) at %L"
 msgstr ""
 
-#: fortran/expr.c:3841
+#: fortran/expr.c:3844
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target must be rank 1 or simply contiguous at %L"
 msgstr ""
 
-#: fortran/expr.c:3845
+#: fortran/expr.c:3848
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer assignment target is not a POINTER at %L"
 msgid "Rank remapping target is not rank 1 at %L"
@@ -60908,154 +60986,159 @@
 #. The test above might need to be extend when F08, Note 5.4 has to be
 #. interpreted in the way that target and pointer with the same coindex
 #. are allowed.
-#: fortran/expr.c:3877 fortran/expr.c:3925
+#: fortran/expr.c:3880 fortran/expr.c:3928
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components"
 msgid "Data target at %L shall not have a coindex"
 msgstr "%L'deki veri aktarım elemanının POINTER bileşenleri olamaz"
 
-#: fortran/expr.c:3880
+#: fortran/expr.c:3883
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr "%L'de hesaplanmış GOTO deyimindeki seçim ifadesi bir değişmez tamsayı ifadesi olmalıdır"
 
-#: fortran/expr.c:3888
+#: fortran/expr.c:3891
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr "%L'deki gösterici atamasının hedefi ne TARGET ne de POINTER"
 
-#: fortran/expr.c:3895
+#: fortran/expr.c:3898
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr "%L'deki PURE yordamdaki gösterici atamasında hedef berbat"
 
-#: fortran/expr.c:3904
+#: fortran/expr.c:3907
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr "%L'de sağ tarafta vektör indisli gösterici ataması"
 
-#: fortran/expr.c:3912
+#: fortran/expr.c:3915
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer assignment target is not a POINTER at %L"
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr "%L'deki gösterici atamasının hedefi bir POINTER değil"
 
-#: fortran/expr.c:3936
+#: fortran/expr.c:3939
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to contiguous pointer from non-contiguous target at %L"
 msgstr ""
 
-#: fortran/expr.c:3975
+#: fortran/expr.c:3978
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr ""
 
-#: fortran/expr.c:4051 fortran/resolve.c:1452
+#: fortran/expr.c:4054 fortran/resolve.c:1452
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer initialization at %C requires '=>', not '='"
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr "%C'deki gösterici ilklendirmesi bir '=>' gerektirir, '=' değil"
 
-#: fortran/expr.c:4057
+#: fortran/expr.c:4060
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Component at %C must have the POINTER attribute"
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr "%C'deki bileşen POINTER özniteliğinde olmalı"
 
-#: fortran/expr.c:4072 fortran/resolve.c:1458
+#: fortran/expr.c:4075 fortran/resolve.c:1458
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Object '%s' at %L must have the SAVE attribute %s"
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr "Nesne '%s' (%L'de), %s SAVE özniteliğine sahip olmalı"
 
-#: fortran/expr.c:4084
+#: fortran/expr.c:4087
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr ""
 
-#: fortran/expr.c:5512
+#: fortran/expr.c:4557
+#, gcc-internal-format
+msgid "generate_isocbinding_initializer(): bad iso_c_binding type, expected %<c_ptr%> or %<c_funptr%>"
+msgstr ""
+
+#: fortran/expr.c:5568
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5520
+#: fortran/expr.c:5576
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5528
+#: fortran/expr.c:5584
 #, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5537
+#: fortran/expr.c:5593
 #, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr ""
 
-#: fortran/expr.c:5548
+#: fortran/expr.c:5604
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5557
+#: fortran/expr.c:5613
 #, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5570
+#: fortran/expr.c:5626
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5583
+#: fortran/expr.c:5639
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5613
+#: fortran/expr.c:5669
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5621
+#: fortran/expr.c:5677
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5634
+#: fortran/expr.c:5690
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' cannot appear in the expression at %L"
 msgid "Variable %qs is PROTECTED and can not appear in a pointer association context (%s) at %L"
 msgstr "Değişken '%s' (%L'de) ifade içinde görünemez"
 
-#: fortran/expr.c:5642
+#: fortran/expr.c:5698
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5654
+#: fortran/expr.c:5710
 #, gcc-internal-format
 msgid "Variable %qs can not appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr ""
 
-#: fortran/expr.c:5713
+#: fortran/expr.c:5769
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:5717
+#: fortran/expr.c:5773
 #, gcc-internal-format
 msgid "%qs at %L associated to expression can not be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:5728
+#: fortran/expr.c:5784
 #, gcc-internal-format
 msgid "Associate-name %qs can not appear in a variable definition context (%s) at %L because its target at %L can not, either"
 msgstr ""
 
-#: fortran/expr.c:5770
+#: fortran/expr.c:5826
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr ""
@@ -61065,24 +61148,24 @@
 msgid "can't open input file: %s"
 msgstr "girdi dosyası açılamıyor: %s"
 
-#: fortran/frontend-passes.c:190
+#: fortran/frontend-passes.c:192
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "No location in statement"
 msgstr "deyim umuluyordu"
 
-#: fortran/frontend-passes.c:205
+#: fortran/frontend-passes.c:207
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected exponent in expression at %C"
 msgid "No location in expression near %L"
 msgstr "%C'deki ifadede bir üs umuluyordu"
 
-#: fortran/frontend-passes.c:409
+#: fortran/frontend-passes.c:414
 #, gcc-internal-format
 msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
-#: fortran/frontend-passes.c:817 fortran/trans-array.c:1182
+#: fortran/frontend-passes.c:822 fortran/trans-array.c:1182
 #: fortran/trans-array.c:6440 fortran/trans-array.c:7864
 #: fortran/trans-intrinsic.c:7307
 #, fuzzy, gcc-internal-format, gfc-internal-format
@@ -61090,76 +61173,76 @@
 msgid "Creating array temporary at %L"
 msgstr "%qT dizisi oluşturulması"
 
-#: fortran/frontend-passes.c:842 fortran/frontend-passes.c:846
+#: fortran/frontend-passes.c:847 fortran/frontend-passes.c:851
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "Removing call to function %qs at %L"
 msgstr "işlev olmayan %qD ye çağrı"
 
-#: fortran/frontend-passes.c:1273 fortran/frontend-passes.c:1312
+#: fortran/frontend-passes.c:1278 fortran/frontend-passes.c:1317
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "bad expression"
 msgstr "ifade umuluyordu"
 
-#: fortran/frontend-passes.c:1308
+#: fortran/frontend-passes.c:1313
 #, fuzzy, gcc-internal-format
 #| msgid "bad test"
 msgid "bad op"
 msgstr "hatalı test"
 
-#: fortran/frontend-passes.c:2161
+#: fortran/frontend-passes.c:2166
 #, gcc-internal-format
 msgid "illegal OP in optimize_comparison"
 msgstr ""
 
-#: fortran/frontend-passes.c:2407
+#: fortran/frontend-passes.c:2412
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgid "Variable %qs at %L set to undefined value inside loop  beginning at %L as INTENT(OUT) argument to subroutine %qs"
 msgstr "'%s' değişkeni (%C'deki), %L'de başlayan döngünün içinde yeniden tanımlanamaz"
 
-#: fortran/frontend-passes.c:2414
+#: fortran/frontend-passes.c:2419
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to subroutine %qs"
 msgstr "'%s' değişkeni (%C'deki), %L'de başlayan döngünün içinde yeniden tanımlanamaz"
 
-#: fortran/frontend-passes.c:2637 fortran/frontend-passes.c:2661
+#: fortran/frontend-passes.c:2642 fortran/frontend-passes.c:2666
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Array reference at %L out of bounds (%ld < %ld) in loop beginning at %L"
 msgstr "%L'deki dizi başvurusu sınırların dışında"
 
-#: fortran/frontend-passes.c:2646 fortran/frontend-passes.c:2670
+#: fortran/frontend-passes.c:2651 fortran/frontend-passes.c:2675
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Array reference at %L out of bounds (%ld > %ld) in loop beginning at %L"
 msgstr "%L'deki dizi başvurusu sınırların dışında"
 
-#: fortran/frontend-passes.c:2730
+#: fortran/frontend-passes.c:2735
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgid "Variable %qs at %L set to undefined value inside loop beginning at %L as INTENT(OUT) argument to function %qs"
 msgstr "'%s' değişkeni (%C'deki), %L'de başlayan döngünün içinde yeniden tanımlanamaz"
 
-#: fortran/frontend-passes.c:2736
+#: fortran/frontend-passes.c:2741
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr "'%s' değişkeni (%C'deki), %L'de başlayan döngünün içinde yeniden tanımlanamaz"
 
-#: fortran/frontend-passes.c:3128 fortran/trans-expr.c:1581
+#: fortran/frontend-passes.c:3133 fortran/trans-expr.c:1581
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr ""
 
-#: fortran/frontend-passes.c:3637
+#: fortran/frontend-passes.c:3642
 #, gcc-internal-format
 msgid "Scalarization using DIMEN_RANGE unimplemented"
 msgstr ""
 
-#: fortran/frontend-passes.c:4429
+#: fortran/frontend-passes.c:4434
 #, gcc-internal-format, gfc-internal-format
 msgid "Interchanging loops at %L"
 msgstr ""
@@ -61291,12 +61374,12 @@
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "%L'de tanımlanmış atamanın ikinci argümanı INTENT(IN) olmalıdır"
 
-#: fortran/interface.c:970 fortran/resolve.c:16351
+#: fortran/interface.c:970 fortran/resolve.c:16378
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "%L'deki işleç arayüzünün ilk argümanı INTENT(IN) olmalıdır"
 
-#: fortran/interface.c:977 fortran/resolve.c:16369
+#: fortran/interface.c:977 fortran/resolve.c:16396
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "%L'deki işleç arayüzünün ikinci argümanı INTENT(IN) olmalıdır"
@@ -62618,7 +62701,7 @@
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.c:3369 fortran/resolve.c:14263
+#: fortran/io.c:3369 fortran/resolve.c:14283
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -62797,7 +62880,7 @@
 msgid "Integer too large at %C"
 msgstr "%C'deki tamsayı çok büyük"
 
-#: fortran/match.c:580 fortran/parse.c:1132
+#: fortran/match.c:580 fortran/parse.c:1136
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many digits in statement label at %C"
 msgstr "%C'deki deyim etiketinde çok fazla rakam var"
@@ -63634,62 +63717,62 @@
 msgid "Expected block name %qs of SELECT construct at %C"
 msgstr "'%s' için %s deyiminde (%C'de) blok ismi umuluyordu"
 
-#: fortran/match.c:6186
+#: fortran/match.c:6201
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "parse error in SELECT TYPE statement at %C"
 msgstr "%C'deki SAVE deyiminde sözdizimi hatası"
 
-#: fortran/match.c:6211
+#: fortran/match.c:6226
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr ""
 
-#: fortran/match.c:6249
+#: fortran/match.c:6264
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr "%C'de umulmadık CASE deyimi"
 
-#: fortran/match.c:6301
+#: fortran/match.c:6316
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CASE-specification at %C"
 msgid "Syntax error in CASE specification at %C"
 msgstr "%C'deki CASE belirtiminde sözdizimi hatası"
 
-#: fortran/match.c:6319
+#: fortran/match.c:6334
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected END statement at %C"
 msgid "Unexpected TYPE IS statement at %C"
 msgstr "%C'de beklenmeyen END deyimi"
 
-#: fortran/match.c:6351
+#: fortran/match.c:6366
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr ""
 
-#: fortran/match.c:6362
+#: fortran/match.c:6377
 #, gcc-internal-format, gfc-internal-format
 msgid "All the LEN type parameters in the TYPE IS statement at %C must be ASSUMED"
 msgstr ""
 
-#: fortran/match.c:6373
+#: fortran/match.c:6388
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CASE-specification at %C"
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr "%C'deki CASE belirtiminde sözdizimi hatası"
 
-#: fortran/match.c:6449
+#: fortran/match.c:6464
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CASE-specification at %C"
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr "%C'deki CASE belirtiminde sözdizimi hatası"
 
-#: fortran/match.c:6572
+#: fortran/match.c:6587
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr "%C'deki ELSEWHERE deyimi WHERE bloku içinde değil"
 
-#: fortran/match.c:6610
+#: fortran/match.c:6625
 #, fuzzy, gcc-internal-format
 #| msgid "Label '%s' at %C doesn't match WHERE label '%s'"
 msgid "Label %qs at %C doesn't match WHERE label %qs"
@@ -63853,198 +63936,198 @@
 msgid "mio_array_ref(): Unknown array ref"
 msgstr ""
 
-#: fortran/module.c:3716
+#: fortran/module.c:3718
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Namelist %s cannot be renamed by USE association to %s."
 msgid "Namelist %s cannot be renamed by USE association to %s"
 msgstr "İsim listesinin ismi %s USE ilişkisiyle %s yapılamaz"
 
-#: fortran/module.c:4832
+#: fortran/module.c:4834
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4835
+#: fortran/module.c:4837
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:5029
+#: fortran/module.c:5031
 #, gcc-internal-format
 msgid "%qs of module %qs, imported at %C, is also the name of the current program unit"
 msgstr ""
 
-#: fortran/module.c:5381
+#: fortran/module.c:5383
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' referenced at %L not found in module '%s'"
 msgid "Symbol %qs referenced at %L not found in module %qs"
 msgstr "Başvurulan '%s' simgesi (%L'de), '%s' modülünde yok"
 
-#: fortran/module.c:5388
+#: fortran/module.c:5390
 #, fuzzy, gcc-internal-format
 #| msgid "User operator '%s' referenced at %L not found in module '%s'"
 msgid "User operator %qs referenced at %L not found in module %qs"
 msgstr "Başvurulan '%s' işleci (%L'de), '%s' modülünde yok"
 
-#: fortran/module.c:5393
+#: fortran/module.c:5395
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic operator '%s' referenced at %L not found in module '%s'"
 msgid "Intrinsic operator %qs referenced at %L not found in module %qs"
 msgstr "Başvurulan '%s' yerleşik işleci (%L'de), '%s' modülünde yok"
 
-#: fortran/module.c:5628
+#: fortran/module.c:5630
 #, gcc-internal-format
 msgid "write_symbol(): bad module symbol %qs"
 msgstr ""
 
-#: fortran/module.c:5961
+#: fortran/module.c:5963
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr ""
 
-#: fortran/module.c:6148
+#: fortran/module.c:6150
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open module file '%s' for writing at %C: %s"
 msgid "Can't open module file %qs for writing at %C: %s"
 msgstr "Modül dosyası`%s' yazmak için açılamıyor (%C'de): %s"
 
-#: fortran/module.c:6169
+#: fortran/module.c:6171
 #, fuzzy, gcc-internal-format
 #| msgid "Error writing module file '%s' for writing: %s"
 msgid "Error writing module file %qs for writing: %s"
 msgstr "Modül dosyası `%s' yazmak için açılırken hata: %s"
 
-#: fortran/module.c:6180
+#: fortran/module.c:6182
 #, fuzzy, gcc-internal-format
 #| msgid "%s: can't delete file '%s': %s\n"
 msgid "Can't delete module file %qs: %s"
 msgstr "%s: `%s' silinemiyor: %s\n"
 
-#: fortran/module.c:6183
+#: fortran/module.c:6185
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open module file '%s' for writing at %C: %s"
 msgid "Can't rename module file %qs to %qs: %s"
 msgstr "Modül dosyası`%s' yazmak için açılamıyor (%C'de): %s"
 
-#: fortran/module.c:6189
+#: fortran/module.c:6191
 #, fuzzy, gcc-internal-format
 #| msgid "%s: can't delete aux info file '%s': %s\n"
 msgid "Can't delete temporary module file %qs: %s"
 msgstr "%s: yardımcı bilgi dosyası `%s' silinemiyor: %s\n"
 
-#: fortran/module.c:6246
+#: fortran/module.c:6248
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C already declared at %L"
 msgid "Symbol %qs at %C already declared"
 msgstr "'%s' bileşeni (%C'deki) zaten %L'de bildirilmiş"
 
-#: fortran/module.c:6317
+#: fortran/module.c:6319
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr ""
 
-#: fortran/module.c:6425 fortran/module.c:6769
+#: fortran/module.c:6427 fortran/module.c:6771
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L is not included in the selected standard"
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr "%L'deki yerleşik '%s' seçilmiş standartta bulunmuyor"
 
-#: fortran/module.c:6553
+#: fortran/module.c:6555
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' referenced at %L not found in module '%s'"
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr "Başvurulan '%s' simgesi (%L'de), '%s' modülünde yok"
 
-#: fortran/module.c:6574 fortran/module.c:6607 fortran/module.c:6649
+#: fortran/module.c:6576 fortran/module.c:6609 fortran/module.c:6651
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C already declared at %L"
 msgid "Symbol %qs already declared"
 msgstr "'%s' bileşeni (%C'deki) zaten %L'de bildirilmiş"
 
-#: fortran/module.c:6754
+#: fortran/module.c:6756
 #, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:6776
+#: fortran/module.c:6778
 #, gcc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr ""
 
-#: fortran/module.c:6844
+#: fortran/module.c:6846
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr ""
 
-#: fortran/module.c:6898
+#: fortran/module.c:6900
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' referenced at %L not found in module '%s'"
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr "Başvurulan '%s' simgesi (%L'de), '%s' modülünde yok"
 
-#: fortran/module.c:6924
+#: fortran/module.c:6926
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement at %C is not within a loop"
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr "%s deyimi bir döngü içinde değil (%C'de)"
 
-#: fortran/module.c:6953
+#: fortran/module.c:6955
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr ""
 
-#: fortran/module.c:6965
+#: fortran/module.c:6967
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
 msgstr ""
 
-#: fortran/module.c:6978
+#: fortran/module.c:6980
 #, gcc-internal-format
 msgid "Can't find an intrinsic module named %qs at %C"
 msgstr ""
 
-#: fortran/module.c:6984
+#: fortran/module.c:6986
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr ""
 
-#: fortran/module.c:6990
+#: fortran/module.c:6992
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr ""
 
-#: fortran/module.c:6996
+#: fortran/module.c:6998
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr ""
 
-#: fortran/module.c:7006
+#: fortran/module.c:7008
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open module file '%s' for reading at %C: %s"
 msgid "Can't open module file %qs for reading at %C: %s"
 msgstr "Modül dosyası`%s' okumak için açılamıyor (%C'de): %s"
 
-#: fortran/module.c:7009
+#: fortran/module.c:7011
 #, gcc-internal-format
 msgid "Module file %qs has not been generated, either because the module does not contain a MODULE PROCEDURE or there is an error in the module."
 msgstr ""
 
-#: fortran/module.c:7020
+#: fortran/module.c:7022
 #, gcc-internal-format
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:7043
+#: fortran/module.c:7045
 #, gcc-internal-format
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr ""
 
-#: fortran/module.c:7051
+#: fortran/module.c:7053
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr ""
 
-#: fortran/module.c:7066
+#: fortran/module.c:7068
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Can't USE the same module we're building!"
 msgid "Can't USE the same %smodule we're building"
@@ -64051,7 +64134,7 @@
 msgstr "Bizim oluşturduğumuz modülün aynısı (USE olamaz)/kullanılamaz!?"
 
 #: fortran/openmp.c:296 fortran/openmp.c:397 fortran/openmp.c:692
-#: fortran/openmp.c:3167
+#: fortran/openmp.c:3166
 #, gcc-internal-format, gfc-internal-format
 msgid "COMMON block /%s/ not found at %C"
 msgstr ""
@@ -64139,920 +64222,920 @@
 #: fortran/openmp.c:2180
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid third argument of IBITS at %L"
-msgid "Invalid argument to !$ACC WAIT at %L"
+msgid "Invalid argument to !$ACC WAIT at %C"
 msgstr "%L'de IBITS'in üçüncü argümanı geçersiz"
 
-#: fortran/openmp.c:2188
+#: fortran/openmp.c:2187
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgid "WAIT clause at %L requires a scalar INTEGER expression"
 msgstr "%L'deki IF deyimi bir sabit LOGICAL ifadesi gerektirir"
 
-#: fortran/openmp.c:2221
+#: fortran/openmp.c:2220
 #, gcc-internal-format, gfc-internal-format
 msgid "ACC CACHE directive must be inside of loop %C"
 msgstr ""
 
-#: fortran/openmp.c:2252
+#: fortran/openmp.c:2251
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for typename"
 msgid "Multiple loop axes specified for routine"
 msgstr "veri türü ismi için saklama sınıfı belirtildi"
 
-#: fortran/openmp.c:2278
+#: fortran/openmp.c:2277
 #, gcc-internal-format, gfc-internal-format
 msgid "Only the !$ACC ROUTINE form without list is allowed in interface block at %C"
 msgstr ""
 
-#: fortran/openmp.c:2306
+#: fortran/openmp.c:2305
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in COMPLEX constant at %C"
 msgid "Syntax error in !$ACC ROUTINE ( NAME ) at %C, invalid function name %s"
 msgstr "%C'deki COMPLEX sabit içinde sözdizimi hatası"
 
-#: fortran/openmp.c:2315
+#: fortran/openmp.c:2314
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in COMPLEX constant at %C"
 msgid "Syntax error in !$ACC ROUTINE ( NAME ) at %C"
 msgstr "%C'deki COMPLEX sabit içinde sözdizimi hatası"
 
-#: fortran/openmp.c:2322
+#: fortran/openmp.c:2321
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$ACC ROUTINE ( NAME ) at %C, expecting ')' after NAME"
 msgstr ""
 
-#: fortran/openmp.c:2457 fortran/openmp.c:2481
+#: fortran/openmp.c:2456 fortran/openmp.c:2480
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after ELSE statement at %C"
 msgid "Unexpected junk after $OMP CRITICAL statement at %C"
 msgstr "%C'deki ELSE deyiminden sonra umulmadık döküntü"
 
-#: fortran/openmp.c:2548
+#: fortran/openmp.c:2547
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after ELSE statement at %C"
 msgid "Unexpected junk after $OMP FLUSH statement at %C"
 msgstr "%C'deki ELSE deyiminden sonra umulmadık döküntü"
 
-#: fortran/openmp.c:2942 fortran/openmp.c:6225
+#: fortran/openmp.c:2941 fortran/openmp.c:6230
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined %s !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2946 fortran/openmp.c:6229
+#: fortran/openmp.c:2945 fortran/openmp.c:6234
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2951
+#: fortran/openmp.c:2950
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2953
+#: fortran/openmp.c:2952
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2973
+#: fortran/openmp.c:2972
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after ELSE statement at %C"
 msgid "Unexpected junk after !$OMP DECLARE REDUCTION at %C"
 msgstr "%C'deki ELSE deyiminden sonra umulmadık döküntü"
 
-#: fortran/openmp.c:3010
+#: fortran/openmp.c:3009
 #, gcc-internal-format, gfc-internal-format
 msgid "Only the !$OMP DECLARE TARGET form without clauses is allowed in interface block at %C"
 msgstr ""
 
-#: fortran/openmp.c:3025
+#: fortran/openmp.c:3024
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after ELSE statement at %C"
 msgid "Unexpected junk after !$OMP DECLARE TARGET at %C"
 msgstr "%C'deki ELSE deyiminden sonra umulmadık döküntü"
 
-#: fortran/openmp.c:3048
+#: fortran/openmp.c:3047
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET variable at %L is an element of a COMMON block"
 msgstr ""
 
-#: fortran/openmp.c:3053
+#: fortran/openmp.c:3052
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET variable at %L previously mentioned in LINK clause and later in TO clause"
 msgstr ""
 
-#: fortran/openmp.c:3059
+#: fortran/openmp.c:3058
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET variable at %L previously mentioned in TO clause and later in LINK clause"
 msgstr ""
 
-#: fortran/openmp.c:3063
+#: fortran/openmp.c:3062
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable at %L mentioned multiple times in clauses of the same OMP DECLARE TARGET directive"
 msgstr ""
 
-#: fortran/openmp.c:3078
+#: fortran/openmp.c:3077
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET COMMON at %L previously mentioned in LINK clause and later in TO clause"
 msgstr ""
 
-#: fortran/openmp.c:3084
+#: fortran/openmp.c:3083
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET COMMON at %L previously mentioned in TO clause and later in LINK clause"
 msgstr ""
 
-#: fortran/openmp.c:3088
+#: fortran/openmp.c:3087
 #, gcc-internal-format, gfc-internal-format
 msgid "COMMON at %L mentioned multiple times in clauses of the same OMP DECLARE TARGET directive"
 msgstr ""
 
-#: fortran/openmp.c:3115
+#: fortran/openmp.c:3114
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in COMPLEX constant at %C"
 msgid "Syntax error in !$OMP DECLARE TARGET list at %C"
 msgstr "%C'deki COMPLEX sabit içinde sözdizimi hatası"
 
-#: fortran/openmp.c:3147
+#: fortran/openmp.c:3146
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate variable at %C is an element of a COMMON block"
 msgstr ""
 
-#: fortran/openmp.c:3184
+#: fortran/openmp.c:3183
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after ELSE statement at %C"
 msgid "Unexpected junk after OMP THREADPRIVATE at %C"
 msgstr "%C'deki ELSE deyiminden sonra umulmadık döküntü"
 
-#: fortran/openmp.c:3191
+#: fortran/openmp.c:3190
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CHARACTER declaration at %C"
 msgid "Syntax error in !$OMP THREADPRIVATE list at %C"
 msgstr "%C'deki CHARACTER bildiriminde sözdizimi hatası"
 
-#: fortran/openmp.c:3405
+#: fortran/openmp.c:3404
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after ELSE statement at %C"
 msgid "Unexpected junk after TASKWAIT clause at %C"
 msgstr "%C'deki ELSE deyiminden sonra umulmadık döküntü"
 
-#: fortran/openmp.c:3419
+#: fortran/openmp.c:3418
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after ELSE statement at %C"
 msgid "Unexpected junk after TASKYIELD clause at %C"
 msgstr "%C'deki ELSE deyiminden sonra umulmadık döküntü"
 
-#: fortran/openmp.c:3478
+#: fortran/openmp.c:3477
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after ELSE statement at %C"
 msgid "Unexpected junk after $OMP WORKSHARE statement at %C"
 msgstr "%C'deki ELSE deyiminden sonra umulmadık döküntü"
 
-#: fortran/openmp.c:3492
+#: fortran/openmp.c:3491
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after ELSE statement at %C"
 msgid "Unexpected junk after $OMP MASTER statement at %C"
 msgstr "%C'deki ELSE deyiminden sonra umulmadık döküntü"
 
-#: fortran/openmp.c:3551
+#: fortran/openmp.c:3550
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after ELSE IF statement at %C"
 msgid "Unexpected junk after $OMP ATOMIC statement at %C"
 msgstr "%C'deki ELSE IF deyiminden sonra umulmadık dotuntu"
 
-#: fortran/openmp.c:3578
+#: fortran/openmp.c:3577
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after ELSE statement at %C"
 msgid "Unexpected junk after $OMP BARRIER statement at %C"
 msgstr "%C'deki ELSE deyiminden sonra umulmadık döküntü"
 
-#: fortran/openmp.c:3592
+#: fortran/openmp.c:3591
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after ELSE statement at %C"
 msgid "Unexpected junk after $OMP TASKGROUP statement at %C"
 msgstr "%C'deki ELSE deyiminden sonra umulmadık döküntü"
 
-#: fortran/openmp.c:3642
+#: fortran/openmp.c:3641
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after ELSE IF statement at %C"
 msgid "Unexpected junk after $OMP CANCELLATION POINT statement at %C"
 msgstr "%C'deki ELSE IF deyiminden sonra umulmadık dotuntu"
 
-#: fortran/openmp.c:3662
+#: fortran/openmp.c:3661
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after ELSE statement at %C"
 msgid "Unexpected junk after NOWAIT clause at %C"
 msgstr "%C'deki ELSE deyiminden sonra umulmadık döküntü"
 
-#: fortran/openmp.c:3704
+#: fortran/openmp.c:3703
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgid "%s clause at %L requires a scalar INTEGER expression"
 msgstr "%L'deki IF deyimi bir sabit LOGICAL ifadesi gerektirir"
 
-#: fortran/openmp.c:3715
+#: fortran/openmp.c:3714
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in CASE statement at %L must be of type %s"
 msgid "INTEGER expression of %s clause at %L must be positive"
 msgstr "%L'de CASE deyimindeki ifade %s türünde olmalı"
 
-#: fortran/openmp.c:3726
+#: fortran/openmp.c:3725
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in CASE statement at %L must be of type %s"
 msgid "INTEGER expression of %s clause at %L must be non-negative"
 msgstr "%L'de CASE deyimindeki ifade %s türünde olmalı"
 
-#: fortran/openmp.c:3737
+#: fortran/openmp.c:3736
 #, gcc-internal-format
 msgid "POINTER object %qs of derived type in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3740
+#: fortran/openmp.c:3739
 #, fuzzy, gcc-internal-format
 #| msgid "Bad pointer object in PURE procedure at %L"
 msgid "Cray pointer object %qs of derived type in %s clause at %L"
 msgstr "%L'deki PURE yordamında hatalı gösterici nesnesi"
 
-#: fortran/openmp.c:3743
+#: fortran/openmp.c:3742
 #, fuzzy, gcc-internal-format
 #| msgid "Bad pointer object in PURE procedure at %L"
 msgid "Cray pointee object %qs of derived type in %s clause at %L"
 msgstr "%L'deki PURE yordamında hatalı gösterici nesnesi"
 
-#: fortran/openmp.c:3749 fortran/openmp.c:4687
+#: fortran/openmp.c:3748 fortran/openmp.c:4686
 #, gcc-internal-format
 msgid "POINTER object %qs of polymorphic type in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3754
+#: fortran/openmp.c:3753
 #, fuzzy, gcc-internal-format
 #| msgid "Bad pointer object in PURE procedure at %L"
 msgid "Cray pointer object %qs of polymorphic type in %s clause at %L"
 msgstr "%L'deki PURE yordamında hatalı gösterici nesnesi"
 
-#: fortran/openmp.c:3759
+#: fortran/openmp.c:3758
 #, fuzzy, gcc-internal-format
 #| msgid "Bad pointer object in PURE procedure at %L"
 msgid "Cray pointee object %qs of polymorphic type in %s clause at %L"
 msgstr "%L'deki PURE yordamında hatalı gösterici nesnesi"
 
-#: fortran/openmp.c:3769 fortran/openmp.c:4385 fortran/openmp.c:4490
+#: fortran/openmp.c:3768 fortran/openmp.c:4384 fortran/openmp.c:4489
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed size array '%s' in namelist '%s'at %C is not allowed."
 msgid "Assumed size array %qs in %s clause at %L"
 msgstr "'%s' tahmini boyutlu dizisine '%s' isim listesinde izin verilmiyor (%C'de)."
 
-#: fortran/openmp.c:3772
+#: fortran/openmp.c:3771
 #, fuzzy, gcc-internal-format
 msgid "Assumed rank array %qs in %s clause at %L"
 msgstr "%3$s:%4$d: %2$s içinde alttan taşmalı %1$s sanal dizisi"
 
-#: fortran/openmp.c:3776
+#: fortran/openmp.c:3775
 #, gcc-internal-format
 msgid "Noncontiguous deferred shape array %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3784
+#: fortran/openmp.c:3783
 #, gcc-internal-format
 msgid "ALLOCATABLE object %qs of derived type in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3789
+#: fortran/openmp.c:3788
 #, gcc-internal-format
 msgid "ALLOCATABLE object %qs of polymorphic type in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3801 fortran/openmp.c:4480
+#: fortran/openmp.c:3800 fortran/openmp.c:4479
 #, gcc-internal-format
 msgid "POINTER object %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3806 fortran/openmp.c:4691
+#: fortran/openmp.c:3805 fortran/openmp.c:4690
 #, fuzzy, gcc-internal-format
 #| msgid "Bad pointer object in PURE procedure at %L"
 msgid "Cray pointer object %qs in %s clause at %L"
 msgstr "%L'deki PURE yordamında hatalı gösterici nesnesi"
 
-#: fortran/openmp.c:3811 fortran/openmp.c:4694
+#: fortran/openmp.c:3810 fortran/openmp.c:4693
 #, fuzzy, gcc-internal-format
 #| msgid "Bad pointer object in PURE procedure at %L"
 msgid "Cray pointee object %qs in %s clause at %L"
 msgstr "%L'deki PURE yordamında hatalı gösterici nesnesi"
 
-#: fortran/openmp.c:3816 fortran/openmp.c:4682
+#: fortran/openmp.c:3815 fortran/openmp.c:4681
 #, gcc-internal-format
 msgid "ALLOCATABLE object %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3819
+#: fortran/openmp.c:3818
 #, gcc-internal-format
 msgid "VALUE object %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3862
+#: fortran/openmp.c:3861
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after ELSE statement at %C"
 msgid "Implicitly declared function %s used in !$OMP DECLARE REDUCTION at %L"
 msgstr "%C'deki ELSE deyiminden sonra umulmadık döküntü"
 
-#: fortran/openmp.c:3911
+#: fortran/openmp.c:3910
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after ELSE statement at %C"
 msgid "Implicitly declared subroutine %s used in !$OMP DECLARE REDUCTION at %L"
 msgstr "%C'deki ELSE deyiminden sonra umulmadık döküntü"
 
-#: fortran/openmp.c:3944
+#: fortran/openmp.c:3943
 #, gcc-internal-format, gfc-internal-format
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:3952 fortran/openmp.c:3963 fortran/resolve.c:10028
-#: fortran/resolve.c:11295
+#: fortran/openmp.c:3951 fortran/openmp.c:3962 fortran/resolve.c:10041
+#: fortran/resolve.c:11315
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "%L'deki IF deyimi bir sabit LOGICAL ifadesi gerektirir"
 
-#: fortran/openmp.c:3967
+#: fortran/openmp.c:3966
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause without modifier at %L used together with IF clauses with modifiers"
 msgstr ""
 
-#: fortran/openmp.c:4044
+#: fortran/openmp.c:4043
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause modifier %s at %L not appropriate for the current OpenMP construct"
 msgstr ""
 
-#: fortran/openmp.c:4054
+#: fortran/openmp.c:4053
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgid "FINAL clause at %L requires a scalar LOGICAL expression"
 msgstr "%L'deki IF deyimi bir sabit LOGICAL ifadesi gerektirir"
 
-#: fortran/openmp.c:4064
+#: fortran/openmp.c:4063
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ELSE IF clause at %L requires a scalar LOGICAL expression"
 msgid "SCHEDULE clause's chunk_size at %L requires a scalar INTEGER expression"
 msgstr "%L'deki ELSE IF deyimi bir değişmez LOGICAL ifadesi gerektirir"
 
-#: fortran/openmp.c:4069
+#: fortran/openmp.c:4068
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in CASE statement at %L must be of type %s"
 msgid "INTEGER expression of SCHEDULE clause's chunk_size at %L must be positive"
 msgstr "%L'de CASE deyimindeki ifade %s türünde olmalı"
 
-#: fortran/openmp.c:4084
+#: fortran/openmp.c:4083
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' has not been assigned a target label at %L"
 msgid "Variable %qs is not a dummy argument at %L"
 msgstr "'%s' değişkenine %L'de bir hedef etiketi atanmış olmamalıydı"
 
-#: fortran/openmp.c:4116
+#: fortran/openmp.c:4115 fortran/openmp.c:5998
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol at %L is not a DUMMY variable"
 msgid "Object %qs is not a variable at %L"
 msgstr "%L'deki simge bir DUMMY değişken değil"
 
-#: fortran/openmp.c:4132 fortran/openmp.c:4143 fortran/openmp.c:4151
-#: fortran/openmp.c:4162 fortran/openmp.c:4174 fortran/openmp.c:4189
-#: fortran/openmp.c:6023
+#: fortran/openmp.c:4131 fortran/openmp.c:4142 fortran/openmp.c:4150
+#: fortran/openmp.c:4161 fortran/openmp.c:4173 fortran/openmp.c:4188
+#: fortran/openmp.c:6028
 #, gcc-internal-format
 msgid "Symbol %qs present on multiple clauses at %L"
 msgstr ""
 
-#: fortran/openmp.c:4196
+#: fortran/openmp.c:4195
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' cannot appear in the expression at %L"
 msgid "Array %qs is not permitted in reduction at %L"
 msgstr "Değişken '%s' (%L'de) ifade içinde görünemez"
 
-#: fortran/openmp.c:4209
+#: fortran/openmp.c:4208
 #, gcc-internal-format
 msgid "Symbol %qs present on both FROM and TO clauses at %L"
 msgstr ""
 
-#: fortran/openmp.c:4231
+#: fortran/openmp.c:4230
 #, gcc-internal-format
 msgid "Non-THREADPRIVATE object %qs in COPYIN clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4239
+#: fortran/openmp.c:4238
 #, gcc-internal-format
 msgid "Assumed size array %qs in COPYPRIVATE clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4242
+#: fortran/openmp.c:4241
 #, gcc-internal-format
 msgid "INTENT(IN) POINTER %qs in COPYPRIVATE clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4250
+#: fortran/openmp.c:4249
 #, gcc-internal-format
 msgid "THREADPRIVATE object %qs in SHARED clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4253
+#: fortran/openmp.c:4252
 #, fuzzy, gcc-internal-format
 #| msgid "Bad pointer object in PURE procedure at %L"
 msgid "Cray pointee %qs in SHARED clause at %L"
 msgstr "%L'deki PURE yordamında hatalı gösterici nesnesi"
 
-#: fortran/openmp.c:4256
+#: fortran/openmp.c:4255
 #, gcc-internal-format
 msgid "ASSOCIATE name %qs in SHARED clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4271
+#: fortran/openmp.c:4270
 #, gcc-internal-format
 msgid "%qs in ALIGNED clause must be POINTER, ALLOCATABLE, Cray pointer or C_PTR at %L"
 msgstr ""
 
-#: fortran/openmp.c:4283
+#: fortran/openmp.c:4282
 #, fuzzy, gcc-internal-format
 #| msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgid "%qs in ALIGNED clause at %L requires a scalar positive constant integer alignment expression"
 msgstr "%L'deki IF deyimi bir sabit LOGICAL ifadesi gerektirir"
 
-#: fortran/openmp.c:4302
+#: fortran/openmp.c:4301
 #, gcc-internal-format, gfc-internal-format
 msgid "SINK dependence type only allowed on ORDERED directive at %L"
 msgstr ""
 
-#: fortran/openmp.c:4306
+#: fortran/openmp.c:4305
 #, gcc-internal-format, gfc-internal-format
 msgid "DEPEND SINK used together with DEPEND SOURCE on the same construct at %L"
 msgstr ""
 
-#: fortran/openmp.c:4316
+#: fortran/openmp.c:4315
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "accumulator is not a constant integer"
 msgid "SINK addend not a constant integer at %L"
 msgstr "birikeç bir tamsayı sabit değil"
 
-#: fortran/openmp.c:4322
+#: fortran/openmp.c:4321
 #, gcc-internal-format, gfc-internal-format
 msgid "Only SOURCE or SINK dependence types are allowed on ORDERED directive at %L"
 msgstr ""
 
-#: fortran/openmp.c:4333 fortran/openmp.c:4354
+#: fortran/openmp.c:4332 fortran/openmp.c:4353
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' in %s statement at %C is not a loop name"
 msgid "%qs in %s clause at %L is not a proper array section"
 msgstr "İsim '%s' %s deyimi içindeki bir döngü ismi değil (%C'de)"
 
-#: fortran/openmp.c:4337
+#: fortran/openmp.c:4336
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-m%s not supported in this configuration"
 msgid "Coarrays not supported in %s clause at %L"
 msgstr "-m%s bu yapılandırmada desteklenmiyor"
 
-#: fortran/openmp.c:4346
+#: fortran/openmp.c:4345
 #, gcc-internal-format, gfc-internal-format
 msgid "Stride should not be specified for array section in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4367
+#: fortran/openmp.c:4366
 #, gcc-internal-format
 msgid "%qs in DEPEND clause at %L is a zero size array section"
 msgstr ""
 
-#: fortran/openmp.c:4403
+#: fortran/openmp.c:4402
 #, gcc-internal-format, gfc-internal-format
 msgid "TARGET%s with map-type other than TO, FROM, TOFROM, or ALLOC on MAP clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4419
+#: fortran/openmp.c:4418
 #, gcc-internal-format, gfc-internal-format
 msgid "TARGET ENTER DATA with map-type other than TO, or ALLOC on MAP clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4434
+#: fortran/openmp.c:4433
 #, gcc-internal-format, gfc-internal-format
 msgid "TARGET EXIT DATA with map-type other than FROM, RELEASE, or DELETE on MAP clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4450 fortran/openmp.c:4466
+#: fortran/openmp.c:4449 fortran/openmp.c:4465
 #, gcc-internal-format
 msgid "THREADPRIVATE object %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4453 fortran/openmp.c:4469
+#: fortran/openmp.c:4452 fortran/openmp.c:4468
 #, fuzzy, gcc-internal-format
 #| msgid "Can't convert %s to %s at %L"
 msgid "Cray pointee %qs in %s clause at %L"
 msgstr "%s den %s e dönüşüm yapılamaz (%L'de)"
 
-#: fortran/openmp.c:4472
+#: fortran/openmp.c:4471
 #, gcc-internal-format
 msgid "ASSOCIATE name %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4477
+#: fortran/openmp.c:4476
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %C is already defined at %L"
 msgid "Procedure pointer %qs in %s clause at %L"
 msgstr "işlev `%s' (%C'deki) zaten %L'de tanımlı"
 
-#: fortran/openmp.c:4483
+#: fortran/openmp.c:4482
 #, fuzzy, gcc-internal-format
 #| msgid "Can't convert %s to %s at %L"
 msgid "Cray pointer %qs in %s clause at %L"
 msgstr "%s den %s e dönüşüm yapılamaz (%L'de)"
 
-#: fortran/openmp.c:4493
+#: fortran/openmp.c:4492
 #, gcc-internal-format
 msgid "Variable %qs in %s clause is used in NAMELIST statement at %L"
 msgstr ""
 
 #. case OMP_LIST_REDUCTION:
-#: fortran/openmp.c:4503
+#: fortran/openmp.c:4502
 #, gcc-internal-format
 msgid "INTENT(IN) POINTER %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4596
+#: fortran/openmp.c:4595
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP DECLARE REDUCTION %s not found for type %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:4622
+#: fortran/openmp.c:4621
 #, gcc-internal-format, gfc-internal-format
 msgid "LINEAR clause modifier used on DO or SIMD construct at %L"
 msgstr ""
 
-#: fortran/openmp.c:4627
+#: fortran/openmp.c:4626
 #, gcc-internal-format, gfc-internal-format
 msgid "LINEAR clause specified together with ORDERED clause with argument at %L"
 msgstr ""
 
-#: fortran/openmp.c:4632
+#: fortran/openmp.c:4631
 #, fuzzy, gcc-internal-format
 #| msgid "%s at %L must be INTEGER or REAL"
 msgid "LINEAR variable %qs must be INTEGER at %L"
 msgstr "%s' (%L'de) bir INTEGER veya REAL olmalıdır"
 
-#: fortran/openmp.c:4637
+#: fortran/openmp.c:4636
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "LINEAR dummy argument %qs with VALUE attribute with %s modifier at %L"
 msgstr "`%s' için fiili argüman bir gösterici olmalı (%L'de)"
 
-#: fortran/openmp.c:4648
+#: fortran/openmp.c:4647
 #, fuzzy, gcc-internal-format
 #| msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgid "%qs in LINEAR clause at %L requires a scalar integer linear-step expression"
 msgstr "%L'deki IF deyimi bir sabit LOGICAL ifadesi gerektirir"
 
-#: fortran/openmp.c:4665
+#: fortran/openmp.c:4664
 #, fuzzy, gcc-internal-format
 #| msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgid "%qs in LINEAR clause at %L requires a constant integer linear-step expression or dummy argument specified in UNIFORM clause"
 msgstr "%L'deki IF deyimi bir sabit LOGICAL ifadesi gerektirir"
 
-#: fortran/openmp.c:4699
+#: fortran/openmp.c:4698
 #, gcc-internal-format
 msgid "%s clause variable %qs at %L is neither a POINTER nor an array"
 msgstr ""
 
-#: fortran/openmp.c:4731
+#: fortran/openmp.c:4730
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ELSE IF clause at %L requires a scalar LOGICAL expression"
 msgid "DIST_SCHEDULE clause's chunk_size at %L requires a scalar INTEGER expression"
 msgstr "%L'deki ELSE IF deyimi bir değişmez LOGICAL ifadesi gerektirir"
 
-#: fortran/openmp.c:4763
+#: fortran/openmp.c:4762
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Incompatible ranks in %s at %L"
 msgid "Incompatible use of TILE and COLLAPSE at %L"
 msgstr "%s (%L'de) içindeki sıra uyumsuz"
 
-#: fortran/openmp.c:4765
+#: fortran/openmp.c:4764
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE dependence type only allowed on ORDERED directive at %L"
 msgstr ""
 
-#: fortran/openmp.c:4778
+#: fortran/openmp.c:4777
 #, gcc-internal-format, gfc-internal-format
 msgid "%s must contain at least one MAP clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4875
+#: fortran/openmp.c:4874
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after ELSE IF statement at %C"
 msgid "unexpected !$OMP ATOMIC expression at %L"
 msgstr "%C'deki ELSE IF deyiminden sonra umulmadık dotuntu"
 
-#: fortran/openmp.c:4904
+#: fortran/openmp.c:4903
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC statement must set a scalar variable of intrinsic type at %L"
 msgstr ""
 
-#: fortran/openmp.c:4929
+#: fortran/openmp.c:4928
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC READ statement must read from a scalar variable of intrinsic type at %L"
 msgstr ""
 
-#: fortran/openmp.c:4934
+#: fortran/openmp.c:4933
 #, gcc-internal-format, gfc-internal-format
 msgid "expr in !$OMP ATOMIC WRITE assignment var = expr must be scalar and cannot reference var at %L"
 msgstr ""
 
-#: fortran/openmp.c:4956 fortran/openmp.c:5247
+#: fortran/openmp.c:4955 fortran/openmp.c:5246
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE capture statement must read from a scalar variable of intrinsic type at %L"
 msgstr ""
 
-#: fortran/openmp.c:4971
+#: fortran/openmp.c:4970
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE update statement must set a scalar variable of intrinsic type at %L"
 msgstr ""
 
-#: fortran/openmp.c:4978 fortran/openmp.c:5254
+#: fortran/openmp.c:4977 fortran/openmp.c:5253
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE capture statement reads from different variable than update statement writes into at %L"
 msgstr ""
 
-#: fortran/openmp.c:4994
+#: fortran/openmp.c:4993
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC with ALLOCATABLE variable at %L"
 msgstr ""
 
-#: fortran/openmp.c:5036
+#: fortran/openmp.c:5035
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment operator must be binary +, *, -, /, .AND., .OR., .EQV. or .NEQV. at %L"
 msgstr ""
 
-#: fortran/openmp.c:5084
+#: fortran/openmp.c:5083
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment must be var = var op expr or var = expr op var at %L"
 msgstr ""
 
-#: fortran/openmp.c:5098
+#: fortran/openmp.c:5097
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC var = var op expr not mathematically equivalent to var = var op (expr) at %L"
 msgstr ""
 
-#: fortran/openmp.c:5130
+#: fortran/openmp.c:5129
 #, gcc-internal-format, gfc-internal-format
 msgid "expr in !$OMP ATOMIC assignment var = var op expr must be scalar and cannot reference var at %L"
 msgstr ""
 
-#: fortran/openmp.c:5154
+#: fortran/openmp.c:5153
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment intrinsic IAND, IOR or IEOR must have two arguments at %L"
 msgstr ""
 
-#: fortran/openmp.c:5161
+#: fortran/openmp.c:5160
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment intrinsic must be MIN, MAX, IAND, IOR or IEOR at %L"
 msgstr ""
 
-#: fortran/openmp.c:5178
+#: fortran/openmp.c:5177
 #, gcc-internal-format
 msgid "!$OMP ATOMIC intrinsic arguments except one must not reference %qs at %L"
 msgstr ""
 
-#: fortran/openmp.c:5185
+#: fortran/openmp.c:5184
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC intrinsic arguments must be scalar at %L"
 msgstr ""
 
-#: fortran/openmp.c:5193
+#: fortran/openmp.c:5192
 #, gcc-internal-format
 msgid "First or last !$OMP ATOMIC intrinsic argument must be %qs at %L"
 msgstr ""
 
-#: fortran/openmp.c:5211
+#: fortran/openmp.c:5210
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment must have an operator or intrinsic on right hand side at %L"
 msgstr ""
 
-#: fortran/openmp.c:5225
+#: fortran/openmp.c:5224
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE capture statement must set a scalar variable of intrinsic type at %L"
 msgstr ""
 
-#: fortran/openmp.c:5544
+#: fortran/openmp.c:5543
 #, gcc-internal-format, gfc-internal-format
 msgid "%s cannot be a DO WHILE or DO without loop control at %L"
 msgstr ""
 
-#: fortran/openmp.c:5550
+#: fortran/openmp.c:5549
 #, gcc-internal-format, gfc-internal-format
 msgid "%s cannot be a DO CONCURRENT loop at %L"
 msgstr ""
 
-#: fortran/openmp.c:5556
+#: fortran/openmp.c:5555
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s tag at %L must be of type %s or %s"
 msgid "%s iteration variable must be of type integer at %L"
 msgstr "%s etiketi (%L'de) ya %s ya da %s türünde olmalıdır"
 
-#: fortran/openmp.c:5560
+#: fortran/openmp.c:5559
 #, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable must not be THREADPRIVATE at %L"
 msgstr ""
 
-#: fortran/openmp.c:5573
+#: fortran/openmp.c:5572
 #, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable present on clause other than PRIVATE or LASTPRIVATE at %L"
 msgstr ""
 
-#: fortran/openmp.c:5577
+#: fortran/openmp.c:5576
 #, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable present on clause other than LASTPRIVATE at %L"
 msgstr ""
 
-#: fortran/openmp.c:5581
+#: fortran/openmp.c:5580
 #, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable present on clause other than LINEAR at %L"
 msgstr ""
 
-#: fortran/openmp.c:5599
+#: fortran/openmp.c:5598
 #, gcc-internal-format, gfc-internal-format
 msgid "%s collapsed loops don't form rectangular iteration space at %L"
 msgstr ""
 
-#: fortran/openmp.c:5611
+#: fortran/openmp.c:5610
 #, gcc-internal-format, gfc-internal-format
 msgid "collapsed %s loops not perfectly nested at %L"
 msgstr ""
 
-#: fortran/openmp.c:5620 fortran/openmp.c:5628
+#: fortran/openmp.c:5619 fortran/openmp.c:5627
 #, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for collapsed %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:5712 fortran/openmp.c:5725
+#: fortran/openmp.c:5711 fortran/openmp.c:5724
 #, gcc-internal-format, gfc-internal-format
 msgid "The %s directive cannot be specified within a %s region at %L"
 msgstr ""
 
-#: fortran/openmp.c:5744
+#: fortran/openmp.c:5743
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP cannot be a DO WHILE or DO without loop control at %L"
 msgstr ""
 
-#: fortran/openmp.c:5750
+#: fortran/openmp.c:5749
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP iteration variable must be of type integer at %L"
 msgstr ""
 
-#: fortran/openmp.c:5766
+#: fortran/openmp.c:5765
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s loops don't form rectangular iteration space at %L"
 msgstr ""
 
-#: fortran/openmp.c:5778
+#: fortran/openmp.c:5777
 #, gcc-internal-format, gfc-internal-format
 msgid "%s !$ACC LOOP loops not perfectly nested at %L"
 msgstr ""
 
-#: fortran/openmp.c:5788 fortran/openmp.c:5797
+#: fortran/openmp.c:5787 fortran/openmp.c:5796
 #, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for %s !$ACC LOOP at %L"
 msgstr ""
 
-#: fortran/openmp.c:5812 fortran/openmp.c:5819
+#: fortran/openmp.c:5811 fortran/openmp.c:5818
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s in PARALLEL region doesn't allow %s arguments at %L"
 msgstr ""
 
-#: fortran/openmp.c:5841
+#: fortran/openmp.c:5840
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside another loop parallelized across gangs at %L"
 msgstr ""
 
-#: fortran/openmp.c:5845 fortran/openmp.c:5849
+#: fortran/openmp.c:5844 fortran/openmp.c:5848
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside loop parallelized across workers at %L"
 msgstr ""
 
-#: fortran/openmp.c:5856
+#: fortran/openmp.c:5855
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across workers at %L"
 msgstr ""
 
-#: fortran/openmp.c:5860
+#: fortran/openmp.c:5859
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across vectors at %L"
 msgstr ""
 
-#: fortran/openmp.c:5866
+#: fortran/openmp.c:5865
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across vectors is not allowed inside another loop parallelized across vectors at %L"
 msgstr ""
 
-#: fortran/openmp.c:5878
+#: fortran/openmp.c:5877
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgid "Clause SEQ conflicts with INDEPENDENT at %L"
 msgstr "INTENT (%s) ile INTENT(%s) %L'de çelişiyor"
 
-#: fortran/openmp.c:5880
+#: fortran/openmp.c:5879
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "Clause SEQ conflicts with GANG at %L"
 msgstr "%s özniteliği ile %s özniteliği %L'de çelişiyor"
 
-#: fortran/openmp.c:5882
+#: fortran/openmp.c:5881
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with WORKER at %L"
 msgstr ""
 
-#: fortran/openmp.c:5884
+#: fortran/openmp.c:5883
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgid "Clause SEQ conflicts with VECTOR at %L"
 msgstr "INTENT (%s) ile INTENT(%s) %L'de çelişiyor"
 
-#: fortran/openmp.c:5886
+#: fortran/openmp.c:5885
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "Clause SEQ conflicts with AUTO at %L"
 msgstr "%s özniteliği ile %s özniteliği %L'de çelişiyor"
 
-#: fortran/openmp.c:5891
+#: fortran/openmp.c:5890
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "Clause AUTO conflicts with GANG at %L"
 msgstr "%s özniteliği ile %s özniteliği %L'de çelişiyor"
 
-#: fortran/openmp.c:5893
+#: fortran/openmp.c:5892
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with WORKER at %L"
 msgstr ""
 
-#: fortran/openmp.c:5895
+#: fortran/openmp.c:5894
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgid "Clause AUTO conflicts with VECTOR at %L"
 msgstr "INTENT (%s) ile INTENT(%s) %L'de çelişiyor"
 
-#: fortran/openmp.c:5899
+#: fortran/openmp.c:5898
 #, gcc-internal-format, gfc-internal-format
 msgid "Tiled loop cannot be parallelized across gangs, workers and vectors at the same time at %L"
 msgstr ""
 
-#: fortran/openmp.c:5934
+#: fortran/openmp.c:5933
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "LOGICAL operands are required in expression at %L"
 msgid "TILE requires constant expression at %L"
 msgstr "%L'deki ifadede LOGICAL terimler gerekiyor"
 
-#: fortran/openmp.c:5999
+#: fortran/openmp.c:6004
 #, gcc-internal-format
 msgid "PARAMETER object %qs is not allowed at %L"
 msgstr ""
 
-#: fortran/openmp.c:6006
+#: fortran/openmp.c:6011
 #, gcc-internal-format
 msgid "Array sections: %qs not allowed in !$ACC DECLARE at %L"
 msgstr ""
 
-#: fortran/openmp.c:6133
+#: fortran/openmp.c:6138
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP TARGET UPDATE at %L requires at least one TO or FROM clause"
 msgstr ""
 
-#: fortran/openmp.c:6155
+#: fortran/openmp.c:6160
 #, gcc-internal-format
 msgid "!$OMP DECLARE SIMD should refer to containing procedure %qs at %L"
 msgstr ""
 
-#: fortran/openmp.c:6179
+#: fortran/openmp.c:6184
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_PRIV or OMP_ORIG used in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6187
+#: fortran/openmp.c:6192
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_OUT or OMP_IN used in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6216
+#: fortran/openmp.c:6221
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid operator for !$OMP DECLARE REDUCTION %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:6238
+#: fortran/openmp.c:6243
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER length in !$OMP DECLARE REDUCTION %s not constant at %L"
 msgstr ""
 
-#: fortran/openmp.c:6254
+#: fortran/openmp.c:6259
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6269
+#: fortran/openmp.c:6274
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6279
+#: fortran/openmp.c:6284
 #, gcc-internal-format, gfc-internal-format
 msgid "One of actual subroutine arguments in INITIALIZER clause of !$OMP DECLARE REDUCTION must be OMP_PRIV at %L"
 msgstr ""
 
-#: fortran/openmp.c:6287
+#: fortran/openmp.c:6292
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing INITIALIZER clause for !$OMP DECLARE REDUCTION of derived type without default initializer at %L"
 msgstr ""
@@ -65174,531 +65257,531 @@
 msgid "Unclassifiable statement at %C"
 msgstr "%C'de tasnif edilemeyen deyim"
 
-#: fortran/parse.c:629
+#: fortran/parse.c:631
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Initialization at %C is not allowed in a PURE procedure"
 msgid "OpenACC directives at %C may not appear in PURE procedures"
 msgstr "%C'de ilklendirmeye bir PURE işlevinde izin verilmez"
 
-#: fortran/parse.c:705
+#: fortran/parse.c:707
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unclassifiable statement at %C"
 msgid "Unclassifiable OpenACC directive at %C"
 msgstr "%C'de tasnif edilemeyen deyim"
 
-#: fortran/parse.c:831 fortran/parse.c:1040
+#: fortran/parse.c:835 fortran/parse.c:1044
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Dummy procedure at %L not allowed in ELEMENTAL procedure"
 msgid "OpenMP directives other than SIMD or DECLARE TARGET at %C may not appear in PURE or ELEMENTAL procedures"
 msgstr "%L'deki sözde yordama ELEMENTAL yordamında izin verilmez"
 
-#: fortran/parse.c:1024
+#: fortran/parse.c:1028
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unclassifiable statement at %C"
 msgid "Unclassifiable OpenMP directive at %C"
 msgstr "%C'de tasnif edilemeyen deyim"
 
-#: fortran/parse.c:1076
+#: fortran/parse.c:1080
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unclassifiable statement at %C"
 msgid "Unclassifiable GCC directive at %C"
 msgstr "%C'de tasnif edilemeyen deyim"
 
-#: fortran/parse.c:1135 fortran/parse.c:1362
+#: fortran/parse.c:1139 fortran/parse.c:1366
 #, gcc-internal-format, gfc-internal-format
 msgid "Zero is not a valid statement label at %C"
 msgstr "Sıfır (Zero), %C'de geçerli bir deyim yaftası değil"
 
-#: fortran/parse.c:1142 fortran/parse.c:1354
+#: fortran/parse.c:1146 fortran/parse.c:1358
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-numeric character in statement label at %C"
 msgstr "%C'deki deyim yaftasında sayısal olmayan karakter"
 
-#: fortran/parse.c:1154 fortran/parse.c:1403
+#: fortran/parse.c:1158 fortran/parse.c:1407
 #, gcc-internal-format, gfc-internal-format
 msgid "Semicolon at %C needs to be preceded by statement"
 msgstr ""
 
-#: fortran/parse.c:1161 fortran/parse.c:1418
+#: fortran/parse.c:1165 fortran/parse.c:1422
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Ignoring statement label in empty statement at %C"
 msgid "Statement label without statement at %L"
 msgstr "%C'de boş deyimdeki deyim yaftası yok sayılıyor"
 
-#: fortran/parse.c:1224 fortran/parse.c:1405
+#: fortran/parse.c:1228 fortran/parse.c:1409
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Semicolon at %C without preceding statement"
 msgstr ""
 
-#: fortran/parse.c:1247 fortran/parse.c:1381
+#: fortran/parse.c:1251 fortran/parse.c:1385
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad continuation line at %C"
 msgstr "%C'deki devam satırı hatalı"
 
-#: fortran/parse.c:1679
+#: fortran/parse.c:1683
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT statement at %L does not have a statement label"
 msgstr "%L'deki FORMAT deyimi bir deyim yaftası içermiyor"
 
-#: fortran/parse.c:2435
+#: fortran/parse.c:2439
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_ascii_statement(): Bad statement code"
 msgstr "gfc_trans_code(): Hatalı deyim kodu"
 
-#: fortran/parse.c:2577
+#: fortran/parse.c:2581
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement at %C"
 msgstr "Umulmadık %s deyimi (%C'de)"
 
-#: fortran/parse.c:2732
+#: fortran/parse.c:2736
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot follow %s statement at %L"
 msgstr "%s deyimi (%C'deki), %s deyimini (%L'deki) izlemiyor"
 
-#: fortran/parse.c:2749
+#: fortran/parse.c:2753
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of file in '%s'"
 msgid "Unexpected end of file in %qs"
 msgstr "'%s' de umulmadık dosya sonu"
 
-#: fortran/parse.c:2784
+#: fortran/parse.c:2788
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected %s statement in CONTAINS section at %C"
 msgid "Derived-type %qs with SEQUENCE must not have a CONTAINS section at %C"
 msgstr "CONTAINS bölümünde umulmadık %s deyimi (%C'de)"
 
-#: fortran/parse.c:2787
+#: fortran/parse.c:2791
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected %s statement in CONTAINS section at %C"
 msgid "Derived-type %qs with BIND(C) must not have a CONTAINS section at %C"
 msgstr "CONTAINS bölümünde umulmadık %s deyimi (%C'de)"
 
-#: fortran/parse.c:2807
+#: fortran/parse.c:2811
 #, gcc-internal-format, gfc-internal-format
 msgid "Components in TYPE at %C must precede CONTAINS"
 msgstr ""
 
-#: fortran/parse.c:2811
+#: fortran/parse.c:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound procedure at %C"
 msgstr ""
 
-#: fortran/parse.c:2819
+#: fortran/parse.c:2823
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC binding at %C"
 msgstr ""
 
-#: fortran/parse.c:2827
+#: fortran/parse.c:2831
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "previous declaration of %qs"
 msgid "FINAL procedure declaration at %C"
 msgstr "%qs'in önceki bildirimi"
 
-#: fortran/parse.c:2839
+#: fortran/parse.c:2843
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Derived type definition at %C has no components"
 msgid "Derived type definition at %C with empty CONTAINS section"
 msgstr "%C'deki türetilmiş tür tanımının hiç bileşeni yok"
 
-#: fortran/parse.c:2849 fortran/parse.c:3304
+#: fortran/parse.c:2853 fortran/parse.c:3308
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement in TYPE at %C must be inside a MODULE"
 msgstr "%C'de TYPEdeki PRIVATE deyimi bir MODULE içinde olmalı"
 
-#: fortran/parse.c:2856
+#: fortran/parse.c:2860
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PRIVATE statement at %C must precede structure components"
 msgid "PRIVATE statement at %C must precede procedure bindings"
 msgstr "%C'deki PRIVATE deyimi yapı elemanlarını öncelemelidir"
 
-#: fortran/parse.c:2863 fortran/parse.c:3317
+#: fortran/parse.c:2867 fortran/parse.c:3321
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PRIVATE statement at %C"
 msgstr "%C'de PRIVATE deyimi yinelenmiş"
 
-#: fortran/parse.c:2873
+#: fortran/parse.c:2877
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "SEQUENCE statement at %C must precede structure components"
 msgid "SEQUENCE statement at %C must precede CONTAINS"
 msgstr "%C'de SEQUENCE deyimi yapı bileşenlerini öncelemelidir"
 
-#: fortran/parse.c:2877
+#: fortran/parse.c:2881
 #, gcc-internal-format, gfc-internal-format
 msgid "Already inside a CONTAINS block at %C"
 msgstr ""
 
-#: fortran/parse.c:2996
+#: fortran/parse.c:3000
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s at %L of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray, which is not possible as the component has the pointer attribute"
 msgstr ""
 
-#: fortran/parse.c:3002
+#: fortran/parse.c:3006
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer component %s at %L has a noncoarray subcomponent of type LOCK_TYPE, which must have a codimension or be a subcomponent of a coarray"
 msgstr ""
 
-#: fortran/parse.c:3007
+#: fortran/parse.c:3011
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L of type LOCK_TYPE must have a codimension"
 msgstr ""
 
-#: fortran/parse.c:3011
+#: fortran/parse.c:3015
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L must have a codimension as it has a noncoarray subcomponent of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/parse.c:3016
+#: fortran/parse.c:3020
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as already a coarray subcomponent exists)"
 msgstr ""
 
-#: fortran/parse.c:3023
+#: fortran/parse.c:3027
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as %s at %L has a codimension or a coarray subcomponent)"
 msgstr ""
 
-#: fortran/parse.c:3033
+#: fortran/parse.c:3037
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s at %L of type EVENT_TYPE must have a codimension or be a subcomponent of a coarray, which is not possible as the component has the pointer attribute"
 msgstr ""
 
-#: fortran/parse.c:3039
+#: fortran/parse.c:3043
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer component %s at %L has a noncoarray subcomponent of type EVENT_TYPE, which must have a codimension or be a subcomponent of a coarray"
 msgstr ""
 
-#: fortran/parse.c:3044
+#: fortran/parse.c:3048
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer array component of structure at %C must have a deferred shape"
 msgid "Allocatable component %s at %L of type EVENT_TYPE must have a codimension"
 msgstr "Yapının gösterici dizisi bileşeni %C'de ertelenmiş durumda olmalı"
 
-#: fortran/parse.c:3048
+#: fortran/parse.c:3052
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L must have a codimension as it has a noncoarray subcomponent of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/parse.c:3053
+#: fortran/parse.c:3057
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as already a coarray subcomponent exists)"
 msgstr ""
 
-#: fortran/parse.c:3060
+#: fortran/parse.c:3064
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as %s at %L has a codimension or a coarray subcomponent)"
 msgstr ""
 
-#: fortran/parse.c:3112
+#: fortran/parse.c:3116
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to create map component '%s'"
 msgstr ""
 
-#: fortran/parse.c:3145
+#: fortran/parse.c:3149
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "failed to find class '%s'"
 msgid "failed to create union component '%s'"
 msgstr "sınıf '%s' bulunamadı"
 
-#: fortran/parse.c:3200
+#: fortran/parse.c:3204
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in data declaration at %C"
 msgid "Syntax error in nested structure declaration at %C"
 msgstr "%C'deki veri bildiriminde sözdizimi hatası"
 
-#: fortran/parse.c:3287
+#: fortran/parse.c:3291
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENUM declaration at %C has no ENUMERATORS"
 msgid "FINAL declaration at %C must be inside CONTAINS"
 msgstr "%C'de ENUM bildirimi hiç ENUMERATORS içermiyor"
 
-#: fortran/parse.c:3295
+#: fortran/parse.c:3299
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Derived type definition at %C has no components"
 msgid "Derived type definition at %C without components"
 msgstr "%C'deki türetilmiş tür tanımının hiç bileşeni yok"
 
-#: fortran/parse.c:3311
+#: fortran/parse.c:3315
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede structure components"
 msgstr "%C'deki PRIVATE deyimi yapı elemanlarını öncelemelidir"
 
-#: fortran/parse.c:3328
+#: fortran/parse.c:3332
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede structure components"
 msgstr "%C'de SEQUENCE deyimi yapı bileşenlerini öncelemelidir"
 
-#: fortran/parse.c:3334
+#: fortran/parse.c:3338
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE attribute at %C already specified in TYPE statement"
 msgstr "%C'de SEQUENCE deyimi zaten TYPE deyiminde belirtilmiş"
 
-#: fortran/parse.c:3339
+#: fortran/parse.c:3343
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SEQUENCE statement at %C"
 msgstr "%C'de SEQUENCE deyimi yinelenmiş"
 
-#: fortran/parse.c:3349
+#: fortran/parse.c:3353
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS block in derived type definition at %C"
 msgstr ""
 
-#: fortran/parse.c:3407
+#: fortran/parse.c:3411
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM declaration at %C has no ENUMERATORS"
 msgstr "%C'de ENUM bildirimi hiç ENUMERATORS içermiyor"
 
-#: fortran/parse.c:3494
+#: fortran/parse.c:3498
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in INTERFACE block at %C"
 msgstr "INTERFACE blokunda umulmadık %s deyimi (%C'de)"
 
-#: fortran/parse.c:3518
+#: fortran/parse.c:3522
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C cannot be the same as an intrinsic type"
 msgid "Name %qs of ABSTRACT INTERFACE at %C cannot be the same as an intrinsic type"
 msgstr "Tür ismi '%s' (%C'de) bir yerleşik türle aynı olamaz"
 
-#: fortran/parse.c:3552
+#: fortran/parse.c:3556
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement at %C in INTERFACE body"
 msgstr "INTERFACE gövdesinde umulmadık %s deyimi (%C'de)"
 
-#: fortran/parse.c:3570
+#: fortran/parse.c:3574
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is the name of the procedure"
 msgid "INTERFACE procedure %qs at %L has the same name as the enclosing procedure"
 msgstr "İsim '%s' %C'de işlev ismidir"
 
-#: fortran/parse.c:3700
+#: fortran/parse.c:3704
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement not allowed in PURE procedure at %C"
 msgid "%s statement is not allowed inside of BLOCK at %C"
 msgstr "PURE yordamda %s deyimine izin verilmez (%C'de)"
 
-#: fortran/parse.c:3732
+#: fortran/parse.c:3736
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement not allowed in PURE procedure at %C"
 msgid "%s statement is not allowed inside of BLOCK DATA at %C"
 msgstr "PURE yordamda %s deyimine izin verilmez (%C'de)"
 
-#: fortran/parse.c:3822
+#: fortran/parse.c:3826
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement must appear in a MODULE"
 msgid "%s statement must appear in a MODULE"
 msgstr "%S deyimi bir MODULE'de görünmemeli"
 
-#: fortran/parse.c:3830
+#: fortran/parse.c:3834
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C follows another accessibility specification"
 msgstr "%s deyimi başka erişilebilirlik belirtimini izliyor (%C'de)"
 
-#: fortran/parse.c:3882
+#: fortran/parse.c:3886
 #, fuzzy, gcc-internal-format
 #| msgid "invalid storage class for function %qs"
 msgid "Bad kind expression for function %qs at %L"
 msgstr "%qs işlevi için geçersiz saklama sınıfı"
 
-#: fortran/parse.c:3886
+#: fortran/parse.c:3890
 #, fuzzy, gcc-internal-format
 #| msgid "Alternate return specifier in function '%s' at %L is not allowed"
 msgid "The type for function %qs at %L is not accessible"
 msgstr "'%s' işlevinde diğer return belirtecine %L'de izin verilmiyor"
 
-#: fortran/parse.c:3946
+#: fortran/parse.c:3950
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C follows previous unmasked ELSEWHERE"
 msgstr "ELSEWHERE deyimi önceki masksız ELSEWHERE'i izliyor (%C'de)"
 
-#: fortran/parse.c:3968
+#: fortran/parse.c:3972
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in WHERE block at %C"
 msgstr "WHERE blokunda umulmadık %s deyimi (%C'de)"
 
-#: fortran/parse.c:4027
+#: fortran/parse.c:4031
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in FORALL block at %C"
 msgstr "FORALL blokunda umulmadık %s deyimi (%C'de)"
 
-#: fortran/parse.c:4078
+#: fortran/parse.c:4082
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSE IF statement at %C cannot follow ELSE statement at %L"
 msgstr "%C'deki ELSE IF deyimi %L'deki ELSE deyimini izleyemez"
 
-#: fortran/parse.c:4096
+#: fortran/parse.c:4100
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ELSE statements at %L and %C"
 msgstr "%L ve %C'de yinelenmiş ELSE deyimi"
 
-#: fortran/parse.c:4157
+#: fortran/parse.c:4161
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected a CASE or END SELECT statement following SELECT CASE at %C"
 msgstr "%C'deki SELECT CASE'i umulmadık bir CASE veya END SELECT deyimi izliyor"
 
-#: fortran/parse.c:4241
+#: fortran/parse.c:4245
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected a CASE or END SELECT statement following SELECT CASE at %C"
 msgid "Expected TYPE IS, CLASS IS or END SELECT statement following SELECT TYPE at %C"
 msgstr "%C'deki SELECT CASE'i umulmadık bir CASE veya END SELECT deyimi izliyor"
 
-#: fortran/parse.c:4303
+#: fortran/parse.c:4307
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgid "Variable %qs at %C cannot be redefined inside loop beginning at %L"
 msgstr "'%s' değişkeni (%C'deki), %L'de başlayan döngünün içinde yeniden tanımlanamaz"
 
-#: fortran/parse.c:4336
+#: fortran/parse.c:4340
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is within another block"
 msgstr "%C'de bloksuz DO deyiminin sonu diğer bloğun içindedir"
 
-#: fortran/parse.c:4346
+#: fortran/parse.c:4350
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is interwoven with another DO loop"
 msgstr "%C'de bloksuz DO deyiminin sonu diğer DO döngüsü ile arabağlantılıdır"
 
-#: fortran/parse.c:4372
+#: fortran/parse.c:4376
 #, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL block inside of OpenACC region at %C"
 msgstr ""
 
-#: fortran/parse.c:4373
+#: fortran/parse.c:4377
 #, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL block inside of OpenMP region at %C"
 msgstr ""
 
-#: fortran/parse.c:4399
+#: fortran/parse.c:4403
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Statement label in ENDDO at %C doesn't match DO label"
 msgid "Statement label in END CRITICAL at %C does not match CRITICAL label"
 msgstr "%C'de ENDDO'daki deyim yaftası DO yaftası ile uyuşmuyor"
 
-#: fortran/parse.c:4468
+#: fortran/parse.c:4472
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Constructor can't be %s"
 msgid "BLOCK construct at %C"
 msgstr "Kurucu %s olmayabilir"
 
-#: fortran/parse.c:4502
+#: fortran/parse.c:4506
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSOCIATE construct at %C"
 msgstr ""
 
-#: fortran/parse.c:4690
+#: fortran/parse.c:4694
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label in ENDDO at %C doesn't match DO label"
 msgstr "%C'de ENDDO'daki deyim yaftası DO yaftası ile uyuşmuyor"
 
-#: fortran/parse.c:4706
+#: fortran/parse.c:4710
 #, gcc-internal-format, gfc-internal-format
 msgid "Named block DO at %L requires matching ENDDO name"
 msgstr ""
 
-#: fortran/parse.c:4897
+#: fortran/parse.c:4901
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing !$OMP END ATOMIC after !$OMP ATOMIC CAPTURE at %C"
 msgstr ""
 
-#: fortran/parse.c:4913 fortran/parse.c:4972
+#: fortran/parse.c:4917 fortran/parse.c:4976
 #, gcc-internal-format, gfc-internal-format
 msgid "OpenACC directive inside of CRITICAL block at %C"
 msgstr ""
 
-#: fortran/parse.c:4947
+#: fortran/parse.c:4951
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting %s statement at %C"
 msgid "Expecting %s at %C"
 msgstr "%s deyimi umuluyordu (%C'de)"
 
-#: fortran/parse.c:4991
+#: fortran/parse.c:4995
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "Expected DO loop at %C"
 msgstr "%C'de '(' umuluyordu"
 
-#: fortran/parse.c:5011
+#: fortran/parse.c:5015
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant !$ACC END LOOP at %C"
 msgstr ""
 
-#: fortran/parse.c:5225
+#: fortran/parse.c:5229
 #, gcc-internal-format, gfc-internal-format
 msgid "Name after !$omp critical and !$omp end critical does not match at %C"
 msgstr ""
 
-#: fortran/parse.c:5283
+#: fortran/parse.c:5287
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot terminate a non-block DO loop"
 msgstr "%s deyimi (%C'deki), bir bloksuz DO döngüsünü sonlandıramaz"
 
-#: fortran/parse.c:5297
+#: fortran/parse.c:5301
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORMAT statement at %L does not have a statement label"
 msgid "DATA statement at %C after the first executable statement"
 msgstr "%L'deki FORMAT deyimi bir deyim yaftası içermiyor"
 
-#: fortran/parse.c:5423
+#: fortran/parse.c:5427
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive does not commence a loop at %C"
 msgstr ""
 
-#: fortran/parse.c:5538
+#: fortran/parse.c:5542
 #, fuzzy, gcc-internal-format
 #| msgid "Contained procedure '%s' at %C is already ambiguous"
 msgid "Contained procedure %qs at %C is already ambiguous"
 msgstr "İçerilmiş yordam '%s' zaten belirsiz (%C'de)"
 
-#: fortran/parse.c:5595
+#: fortran/parse.c:5599
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in CONTAINS section at %C"
 msgstr "CONTAINS bölümünde umulmadık %s deyimi (%C'de)"
 
-#: fortran/parse.c:5620
+#: fortran/parse.c:5624
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement at %C cannot follow %s statement at %L"
 msgid "CONTAINS statement without FUNCTION or SUBROUTINE statement at %L"
 msgstr "%s deyimi (%C'deki), %s deyimini (%L'deki) izlemiyor"
 
-#: fortran/parse.c:5732
+#: fortran/parse.c:5736
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS statement at %C is already in a contained program unit"
 msgstr "%C'deki CONTAINS bölümü zaken içerilmiş bir program birimidir"
 
-#: fortran/parse.c:5784
+#: fortran/parse.c:5788
 #, fuzzy, gcc-internal-format
 #| msgid "Global name '%s' at %L is already being used as a %s at %L"
 msgid "Global binding name %qs at %L is already being used as a %s at %L"
 msgstr "Genel isim '%s' (%L'de), zaten %s (%L'de) olarak kullanılıyor"
 
-#: fortran/parse.c:5788
+#: fortran/parse.c:5792
 #, fuzzy, gcc-internal-format
 #| msgid "Global name '%s' at %L is already being used as a %s at %L"
 msgid "Global name %qs at %L is already being used as a %s at %L"
 msgstr "Genel isim '%s' (%L'de), zaten %s (%L'de) olarak kullanılıyor"
 
-#: fortran/parse.c:5794
+#: fortran/parse.c:5798
 #, fuzzy, gcc-internal-format
 #| msgid "Global name '%s' at %L is already being used as a %s at %L"
 msgid "Global binding name %qs at %L is already being used at %L"
 msgstr "Genel isim '%s' (%L'de), zaten %s (%L'de) olarak kullanılıyor"
 
-#: fortran/parse.c:5797
+#: fortran/parse.c:5801
 #, fuzzy, gcc-internal-format
 #| msgid "Global name '%s' at %L is already being used as a %s at %L"
 msgid "Global name %qs at %L is already being used at %L"
 msgstr "Genel isim '%s' (%L'de), zaten %s (%L'de) olarak kullanılıyor"
 
-#: fortran/parse.c:5819
+#: fortran/parse.c:5823
 #, gcc-internal-format, gfc-internal-format
 msgid "Blank BLOCK DATA at %C conflicts with prior BLOCK DATA at %L"
 msgstr "%C'deki boş BLOCK DATA %L'deki önceki BLOCK DATA ile çelişiyor"
 
-#: fortran/parse.c:5845
+#: fortran/parse.c:5849
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in BLOCK DATA at %C"
 msgstr "BLOCK DATA içinde umulmadık %s deyimi (%C'de)"
 
-#: fortran/parse.c:5949
+#: fortran/parse.c:5953
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in MODULE at %C"
 msgstr "MODULE içinde umulmadık %s deyimi (%C'de)"
@@ -65706,7 +65789,7 @@
 #. If we see a duplicate main program, shut down.  If the second
 #. instance is an implied main program, i.e. data decls or executable
 #. statements, we're in for lots of errors.
-#: fortran/parse.c:6333
+#: fortran/parse.c:6337
 #, gcc-internal-format, gfc-internal-format
 msgid "Two main PROGRAMs at %L and %C"
 msgstr "%L ve %C'de iki ana PROGRAM"
@@ -66534,7 +66617,7 @@
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.c:1893 fortran/resolve.c:9560 fortran/resolve.c:11225
+#: fortran/resolve.c:1893 fortran/resolve.c:9573 fortran/resolve.c:11245
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "Yafta %d (%L'de başvurulu) hiç tanımlanmamış"
@@ -66658,7 +66741,7 @@
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "'%s' işlevi (%L'de) hiç IMPLICIT tür içermiyor"
 
-#: fortran/resolve.c:2905 fortran/resolve.c:16283
+#: fortran/resolve.c:2905 fortran/resolve.c:16310
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Function %qs at %L has no IMPLICIT type"
@@ -66792,214 +66875,214 @@
 msgid "logical_to_bitwise(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:4059
+#: fortran/resolve.c:4065
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:4229 fortran/resolve.c:4252
+#: fortran/resolve.c:4235 fortran/resolve.c:4258
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:4347
+#: fortran/resolve.c:4353
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "%L'deki dizi başvurusu sınırların dışında"
 
-#: fortran/resolve.c:4352
+#: fortran/resolve.c:4358
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr "%L'deki dizi başvurusu sınırların dışında"
 
-#: fortran/resolve.c:4362
+#: fortran/resolve.c:4368
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "%L'deki dizi başvurusu sınırların dışında"
 
-#: fortran/resolve.c:4367
+#: fortran/resolve.c:4373
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr "%L'deki dizi başvurusu sınırların dışında"
 
-#: fortran/resolve.c:4387
+#: fortran/resolve.c:4393
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr "%L'de sıfır adım uzunluğu kuraldışı"
 
-#: fortran/resolve.c:4404
+#: fortran/resolve.c:4410
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "%L'deki dizi başvurusu sınırların dışında"
 
-#: fortran/resolve.c:4412
+#: fortran/resolve.c:4418
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "%L'deki dizi başvurusu sınırların dışında"
 
-#: fortran/resolve.c:4428
+#: fortran/resolve.c:4434
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "%L'deki dizi başvurusu sınırların dışında"
 
-#: fortran/resolve.c:4437
+#: fortran/resolve.c:4443
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds"
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "%L'deki dizi başvurusu sınırların dışında"
 
-#: fortran/resolve.c:4453
+#: fortran/resolve.c:4459
 #, fuzzy, gcc-internal-format
 #| msgid "subscript missing in array reference"
 msgid "check_dimension(): Bad array reference"
 msgstr "dizi başvurusunda altindis yok"
 
-#: fortran/resolve.c:4476
+#: fortran/resolve.c:4482
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr "Tahmini boyutlu dizi bölümünün en sağ üst sınırı %L'de belirtilmemiş"
 
-#: fortran/resolve.c:4486
+#: fortran/resolve.c:4492
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr "%L'de dizi başvurusunda sıra uyumsuz (%d/%d)"
 
-#: fortran/resolve.c:4494
+#: fortran/resolve.c:4500
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr "%L'de dizi başvurusunda sıra uyumsuz (%d/%d)"
 
-#: fortran/resolve.c:4510
+#: fortran/resolve.c:4516
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL stride expression at %L must be a scalar %s"
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr "%L'deki FORALL adım ifadesi bir değişmez %s olmalıdır"
 
-#: fortran/resolve.c:4538
+#: fortran/resolve.c:4544
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr "%L'de dizi indisi değişmez olmalıdır"
 
-#: fortran/resolve.c:4544
+#: fortran/resolve.c:4550
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array index at %L must be of INTEGER type"
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr "%L'de dizi indisi INTEGER türünde olmalıdır"
 
-#: fortran/resolve.c:4550
+#: fortran/resolve.c:4556
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: REAL array index at %L"
 msgid "REAL array index at %L"
 msgstr "Ek: %L'de REAL dizi indisi"
 
-#: fortran/resolve.c:4589
+#: fortran/resolve.c:4595
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr "%L'de boyut argümanı değişmez olmalı"
 
-#: fortran/resolve.c:4596
+#: fortran/resolve.c:4602
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr "%L'de boyut argümanı INTEGER türünde olmalı"
 
-#: fortran/resolve.c:4641
+#: fortran/resolve.c:4647
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr ""
 
-#: fortran/resolve.c:4652
+#: fortran/resolve.c:4658
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.c:4663
+#: fortran/resolve.c:4669
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.c:4706
+#: fortran/resolve.c:4712
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr "%L'deki dizi indisi %d. mertebeden bir dizidir"
 
-#: fortran/resolve.c:4804
+#: fortran/resolve.c:4810
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr "%L'deki altdizge başlangıç indisi INTEGER türünde olmalıdır"
 
-#: fortran/resolve.c:4811
+#: fortran/resolve.c:4817
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr "%L'deki altdizge başlangıç indisi bir değişmez olmalıdır"
 
-#: fortran/resolve.c:4820
+#: fortran/resolve.c:4826
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr "%L'deki altdizge başlangıç indisi birden küçük olmalıdır"
 
-#: fortran/resolve.c:4833
+#: fortran/resolve.c:4839
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr "%L'deki altdizge son indisi INTEGER türünde olmalıdır"
 
-#: fortran/resolve.c:4840
+#: fortran/resolve.c:4846
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr "%L'deki altdizge son indisi bir değişmez olmalıdır"
 
-#: fortran/resolve.c:4850
+#: fortran/resolve.c:4856
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Substring end index at %L must be scalar"
 msgid "Substring end index at %L exceeds the string length"
 msgstr "%L'deki altdizge son indisi bir değişmez olmalıdır"
 
-#: fortran/resolve.c:4860
+#: fortran/resolve.c:4866
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Substring end index at %L must be scalar"
 msgid "Substring end index at %L is too large"
 msgstr "%L'deki altdizge son indisi bir değişmez olmalıdır"
 
-#: fortran/resolve.c:5013
+#: fortran/resolve.c:5019
 #, fuzzy, gcc-internal-format
 #| msgid "Bad array reference at %L"
 msgid "resolve_ref(): Bad array reference"
 msgstr "%L'de hatalı dizi başvurusu"
 
-#: fortran/resolve.c:5027
+#: fortran/resolve.c:5033
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr "Sıfırdan farklı bir mertebeden bir parça başvurusunun sağ bileşeni %L'de POINTER özniteliğinde olmamalıdır"
 
-#: fortran/resolve.c:5037
+#: fortran/resolve.c:5043
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr "Sıfırdan farklı bir mertebeden bir parça başvurusunun sağ bileşeni %L'de POINTER özniteliğinde olmamalıdır"
 
-#: fortran/resolve.c:5056
+#: fortran/resolve.c:5062
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr "%L'de sıfırdan farklı bir mertebeden iki veya daha fazla parça başvurusu belirtilmemelidir"
 
-#: fortran/resolve.c:5154
+#: fortran/resolve.c:5160
 #, gcc-internal-format
 msgid "expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.c:5236
+#: fortran/resolve.c:5242
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr ""
 
-#: fortran/resolve.c:5246
+#: fortran/resolve.c:5252
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
@@ -67009,12 +67092,12 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5256
+#: fortran/resolve.c:5262
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5271
+#: fortran/resolve.c:5277
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
@@ -67024,63 +67107,63 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5281
+#: fortran/resolve.c:5287
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5292
+#: fortran/resolve.c:5298
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5301
+#: fortran/resolve.c:5307
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5316
+#: fortran/resolve.c:5322
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5478
+#: fortran/resolve.c:5484
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5483
+#: fortran/resolve.c:5489
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5553
+#: fortran/resolve.c:5559
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.c:5566
+#: fortran/resolve.c:5572
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.c:5919
+#: fortran/resolve.c:5925
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s tag at %L must be scalar"
 msgid "Passed-object at %L must be scalar"
 msgstr "%s' etiketi (%L'de) bir değişmez olmalı"
 
-#: fortran/resolve.c:5926
+#: fortran/resolve.c:5932
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5961
+#: fortran/resolve.c:5967
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5970
+#: fortran/resolve.c:5976
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument '%s' of elemental procedure at %L must be scalar"
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
@@ -67087,219 +67170,219 @@
 msgstr "Öğesel yordamın '%s' argümanı değişmez olmalı (%L'de)"
 
 #. Nothing matching found!
-#: fortran/resolve.c:6158
+#: fortran/resolve.c:6164
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:6185
+#: fortran/resolve.c:6191
 #, fuzzy, gcc-internal-format
 #| msgid "%s at %L must be INTEGER"
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "%s' (%L'de) bir INTEGER olmalıdır"
 
-#: fortran/resolve.c:6236
+#: fortran/resolve.c:6242
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:6786
+#: fortran/resolve.c:6792
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "İfade türü umuluyordu"
 
-#: fortran/resolve.c:6812
+#: fortran/resolve.c:6818
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s' (%L'de) bir değişmez olmalıdır"
 
-#: fortran/resolve.c:6822
+#: fortran/resolve.c:6828
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s at %L must be a scalar"
 msgid "%s at %L must be integer"
 msgstr "%s' (%L'de) bir değişmez olmalıdır"
 
-#: fortran/resolve.c:6826 fortran/resolve.c:6833
+#: fortran/resolve.c:6832 fortran/resolve.c:6839
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s' (%L'de) bir INTEGER olmalıdır"
 
-#: fortran/resolve.c:6875
+#: fortran/resolve.c:6881
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "%L'de Do döngüsündeki adım ifadesi sıfır olamaz"
 
-#: fortran/resolve.c:6911
+#: fortran/resolve.c:6917
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.c:6928
+#: fortran/resolve.c:6934
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.c:6934
+#: fortran/resolve.c:6940
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.c:6995
+#: fortran/resolve.c:7001
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "%L'de FORALL indis ismi bir değişmez INTEGER olmalıdır"
 
-#: fortran/resolve.c:7000
+#: fortran/resolve.c:7006
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "%L'de FORALL başlatma ifadesi bir değişmez INTEGER olmalıdır"
 
-#: fortran/resolve.c:7007
+#: fortran/resolve.c:7013
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "%L'de FORALL son ifadesi bir değişmez INTEGER olmalıdır"
 
-#: fortran/resolve.c:7015
+#: fortran/resolve.c:7021
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "%L'deki FORALL adım ifadesi bir değişmez %s olmalıdır"
 
-#: fortran/resolve.c:7020
+#: fortran/resolve.c:7026
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "%L'deki FORALL adım ifadesi sıfır olamaz"
 
-#: fortran/resolve.c:7033
+#: fortran/resolve.c:7039
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' cannot appear in the expression at %L"
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "Değişken '%s' (%L'de) ifade içinde görünemez"
 
-#: fortran/resolve.c:7136 fortran/resolve.c:7428
+#: fortran/resolve.c:7142 fortran/resolve.c:7434
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in ALLOCATE statement at %L must be ALLOCATABLE or a POINTER"
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "%L'de ALLOCATE deyimindeki ifade ya bir POINTER ya da ALLOCATABLE olmalı"
 
-#: fortran/resolve.c:7144 fortran/resolve.c:7393
+#: fortran/resolve.c:7150 fortran/resolve.c:7399
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7250
+#: fortran/resolve.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7281
+#: fortran/resolve.c:7287
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.c:7439
+#: fortran/resolve.c:7445
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.c:7451
+#: fortran/resolve.c:7457
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.c:7465
+#: fortran/resolve.c:7471
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7480
+#: fortran/resolve.c:7486
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7493
+#: fortran/resolve.c:7499
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.c:7511
+#: fortran/resolve.c:7517
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.c:7592 fortran/resolve.c:7607
+#: fortran/resolve.c:7598 fortran/resolve.c:7613
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "%L'deki ALLOCATE deyimde dizi belirtimi gerekli "
 
-#: fortran/resolve.c:7599
+#: fortran/resolve.c:7605
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array specification required in ALLOCATE statement at %L"
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "%L'deki ALLOCATE deyimde dizi belirtimi gerekli "
 
-#: fortran/resolve.c:7622
+#: fortran/resolve.c:7628
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array specification required in ALLOCATE statement at %L"
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "%L'deki ALLOCATE deyimde dizi belirtimi gerekli "
 
-#: fortran/resolve.c:7649
+#: fortran/resolve.c:7655
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "%L'deki ALLOCATE deyimde dizi belirtimi hatalı"
 
-#: fortran/resolve.c:7668
+#: fortran/resolve.c:7674
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.c:7683
+#: fortran/resolve.c:7689
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad array specification in ALLOCATE statement at %L"
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr "%L'deki ALLOCATE deyimde dizi belirtimi hatalı"
 
-#: fortran/resolve.c:7694
+#: fortran/resolve.c:7700
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad array specification in ALLOCATE statement at %L"
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "%L'deki ALLOCATE deyimde dizi belirtimi hatalı"
 
-#: fortran/resolve.c:7726
+#: fortran/resolve.c:7732
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "%L'deki ASSIGN deyimi bir sabit öntanımlı INTEGER değişken gerektirir"
 
-#: fortran/resolve.c:7749
+#: fortran/resolve.c:7755
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "%L'deki yafta %L'deki GOTO deyimiyle aynı blokta değil"
 
-#: fortran/resolve.c:7760
+#: fortran/resolve.c:7766
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.c:7771
+#: fortran/resolve.c:7782
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "UNIT specification at %L must be an INTEGER expression or a CHARACTER variable"
-msgid "Errmsg-variable at %L must be a scalar CHARACTER variable"
-msgstr "%L'deki UNIT belirtimi ya bir INTEGER ifadesi ya da bir CHARACTER değişkeni olmalıdır"
+#| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
+msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
+msgstr "%L'deki ASSIGN deyimi bir sabit öntanımlı INTEGER değişken gerektirir"
 
-#: fortran/resolve.c:7794
+#: fortran/resolve.c:7805
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:7824
+#: fortran/resolve.c:7835
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.c:7830 fortran/resolve.c:7836
+#: fortran/resolve.c:7841 fortran/resolve.c:7847
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -67308,258 +67391,258 @@
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8064
+#: fortran/resolve.c:8075
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "%L'deki CASE etiketi ile %L'deki CASE etiketi birbirinin üzerine taşıyor"
 
-#: fortran/resolve.c:8115
+#: fortran/resolve.c:8126
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "%L'de CASE deyimindeki ifade %s türünde olmalı"
 
-#: fortran/resolve.c:8126
+#: fortran/resolve.c:8137
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in CASE statement at %L must be kind %d"
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "%L'de CASE deyimindeki ifade %d. çeşit olmalı"
 
-#: fortran/resolve.c:8139
+#: fortran/resolve.c:8150
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "%L'de CASE deyimindeki ifade bir değişmez olmalı"
 
-#: fortran/resolve.c:8185
+#: fortran/resolve.c:8196
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "%L'de hesaplanmış GOTO deyimindeki seçim ifadesi bir değişmez tamsayı ifadesi olmalıdır"
 
-#: fortran/resolve.c:8204
+#: fortran/resolve.c:8215
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "%L'deki SELECT deyiminin argümanı %s olamaz"
 
-#: fortran/resolve.c:8214
+#: fortran/resolve.c:8225
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "%L'deki SELECT deyiminin argümanı bir sabit ifadesi olmalı"
 
-#: fortran/resolve.c:8232 fortran/resolve.c:8240
+#: fortran/resolve.c:8243 fortran/resolve.c:8251
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in CASE statement at %L must be of type %s"
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "%L'de CASE deyimindeki ifade %s türünde olmalı"
 
-#: fortran/resolve.c:8302 fortran/resolve.c:8873
+#: fortran/resolve.c:8313 fortran/resolve.c:8884
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "%L'deki DEFAULT CASE deyiminden sonra %L'de ikinci bir DEFAULT CASE olamaz"
 
-#: fortran/resolve.c:8328
+#: fortran/resolve.c:8339
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "%L'deki CASE deyiminde mantıksal aralığa izin verilmez"
 
-#: fortran/resolve.c:8340
+#: fortran/resolve.c:8351
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Logical range in CASE statement at %L is not allowed"
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "%L'deki CASE deyiminde mantıksal aralığa izin verilmez"
 
-#: fortran/resolve.c:8355
+#: fortran/resolve.c:8366
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "%L'deki aralık belirtimi asla eşleşmeyebilir"
 
-#: fortran/resolve.c:8458
+#: fortran/resolve.c:8469
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "%L'deki mantıksal SELECT CASE blokunun ikiden fazla case'i var"
 
-#: fortran/resolve.c:8518
+#: fortran/resolve.c:8529
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Iterator step at %L cannot be zero"
 msgid "Selector at %L cannot be NULL()"
 msgstr "%L'deki yineleyici adımı sıfır olamaz"
 
-#: fortran/resolve.c:8523
+#: fortran/resolve.c:8534
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Selector at %L has no type"
 msgstr "'%s' işlevi (%L'de) hiç IMPLICIT tür içermiyor"
 
-#: fortran/resolve.c:8545
+#: fortran/resolve.c:8556
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.c:8556
+#: fortran/resolve.c:8567
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:8763
+#: fortran/resolve.c:8774
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in EQUIVALENCE statement at %L"
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "%L'deki EQUIVALENCE deyiminde söz dizimi hatası"
 
-#: fortran/resolve.c:8783 fortran/resolve.c:8795
+#: fortran/resolve.c:8794 fortran/resolve.c:8806
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.c:8824
+#: fortran/resolve.c:8835
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CASE label at %L overlaps with CASE label at %L"
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "%L'deki CASE etiketi ile %L'deki CASE etiketi birbirinin üzerine taşıyor"
 
-#: fortran/resolve.c:8836
+#: fortran/resolve.c:8847
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %C is being used before it is defined"
 msgid "Derived type %qs at %L must be extensible"
 msgstr "Türetilmiş '%s' türü (%C'deki) tanımından önce kullanılıyor"
 
-#: fortran/resolve.c:8848
+#: fortran/resolve.c:8859
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type name '%s' at %C already has a basic type of %s"
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "Türetilmiş tür ismi '%s' %C'de zaten temel  %s türünde"
 
-#: fortran/resolve.c:8851
+#: fortran/resolve.c:8862
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected %s statement at %C"
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "Umulmadık %s deyimi (%C'de)"
 
-#: fortran/resolve.c:8861
+#: fortran/resolve.c:8872
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.c:9108
+#: fortran/resolve.c:9119
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9204
+#: fortran/resolve.c:9215
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "%s için %L'deki çeşit geçersiz"
 
-#: fortran/resolve.c:9257
+#: fortran/resolve.c:9268
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array index at %L must be scalar"
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "%L'de dizi indisi değişmez olmalıdır"
 
-#: fortran/resolve.c:9267
+#: fortran/resolve.c:9278
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9280
+#: fortran/resolve.c:9291
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components"
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "%L'deki veri aktarım elemanının POINTER bileşenleri olamaz"
 
-#: fortran/resolve.c:9289
+#: fortran/resolve.c:9300
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components"
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "%L'deki veri aktarım elemanının POINTER bileşenleri olamaz"
 
-#: fortran/resolve.c:9296
+#: fortran/resolve.c:9307
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have PRIVATE components"
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "%L'deki veri aktarım elemanının PRIVATE bileşenleri olamaz"
 
-#: fortran/resolve.c:9307
+#: fortran/resolve.c:9318
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "%L'deki veri aktarım elemanının PRIVATE bileşenleri olamaz"
 
-#: fortran/resolve.c:9313
+#: fortran/resolve.c:9324
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components"
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr "%L'deki veri aktarım elemanının POINTER bileşenleri olamaz"
 
-#: fortran/resolve.c:9328
+#: fortran/resolve.c:9339
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "%L'deki veri aktarım elemanı tahmini boyutlu bir diziye bir tam başvuru olamaz"
 
-#: fortran/resolve.c:9388
+#: fortran/resolve.c:9399
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "%L'de FORALL indis ismi bir değişmez INTEGER olmalıdır"
 
-#: fortran/resolve.c:9398
+#: fortran/resolve.c:9409
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr "%L'de FORALL indis ismi bir değişmez INTEGER olmalıdır"
 
-#: fortran/resolve.c:9402
+#: fortran/resolve.c:9413
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "`%s' için fiili argüman bir gösterici olmalı (%L'de)"
 
-#: fortran/resolve.c:9405
+#: fortran/resolve.c:9416
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "`%s' için fiili argüman bir gösterici olmalı (%L'de)"
 
-#: fortran/resolve.c:9412 fortran/resolve.c:9533
+#: fortran/resolve.c:9423 fortran/resolve.c:9545
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "%L'deki ASSIGN deyimi bir sabit öntanımlı INTEGER değişken gerektirir"
 
-#: fortran/resolve.c:9424 fortran/resolve.c:9540
+#: fortran/resolve.c:9435 fortran/resolve.c:9553
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "%L'deki ASSIGN deyimi bir sabit öntanımlı INTEGER değişken gerektirir"
 
-#: fortran/resolve.c:9436
+#: fortran/resolve.c:9447
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument dim at %L must be scalar"
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "%L'de boyut argümanı değişmez olmalı"
 
-#: fortran/resolve.c:9449
+#: fortran/resolve.c:9460
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "%L'deki SELECT deyiminin argümanı bir sabit ifadesi olmalı"
 
-#: fortran/resolve.c:9510
+#: fortran/resolve.c:9521
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "%L'deki SELECT deyiminin argümanı bir sabit ifadesi olmalı"
 
-#: fortran/resolve.c:9514 fortran/resolve.c:9524
+#: fortran/resolve.c:9525 fortran/resolve.c:9535
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of ACOS at %L must be between -1 and 1"
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "%L'deki ACOS argümanı -1 .. 1 arasında olmalı"
 
-#: fortran/resolve.c:9567
+#: fortran/resolve.c:9580
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "%L'deki deyim %L'deki dallanma deyimi için geçerli bir dallanma hedef deyimi değildir"
 
-#: fortran/resolve.c:9577
+#: fortran/resolve.c:9590
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Branch at %L causes an infinite loop"
 msgid "Branch at %L may result in an infinite loop"
@@ -67567,12 +67650,12 @@
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:9594 fortran/resolve.c:9617
+#: fortran/resolve.c:9607 fortran/resolve.c:9630
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.c:9598 fortran/resolve.c:9623
+#: fortran/resolve.c:9611 fortran/resolve.c:9636
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -67580,113 +67663,113 @@
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:9638
+#: fortran/resolve.c:9651
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "%L'deki yafta %L'deki GOTO deyimiyle aynı blokta değil"
 
-#: fortran/resolve.c:9710
+#: fortran/resolve.c:9723
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "%L'deki WHERE maskesi uyumsuz biçimde"
 
-#: fortran/resolve.c:9726
+#: fortran/resolve.c:9739
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "%L'deki WHERE atama hedefi uyumsuz biçimde"
 
-#: fortran/resolve.c:9734 fortran/resolve.c:9821
+#: fortran/resolve.c:9747 fortran/resolve.c:9834
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:9744 fortran/resolve.c:9831
+#: fortran/resolve.c:9757 fortran/resolve.c:9844
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "%L'deki WHERE içinde desteklenmeyen deyim"
 
-#: fortran/resolve.c:9775
+#: fortran/resolve.c:9788
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "%L'de bir FORALL indis değişkenine atama"
 
-#: fortran/resolve.c:9784
+#: fortran/resolve.c:9797
 #, fuzzy, gcc-internal-format
 #| msgid "The FORALL with index '%s' cause more than one assignment to this object at %L"
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "'%s' indisli FORALL %L'de bu nesneye birden fazla atamaya sebep oluyor"
 
-#: fortran/resolve.c:9949
+#: fortran/resolve.c:9962
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "%L'de FORALL indis ismi bir değişmez INTEGER olmalıdır"
 
-#: fortran/resolve.c:9959
+#: fortran/resolve.c:9972
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "Bir dış FORALL oluşumu zaten bu isimde bir indise sahip (%L'de)"
 
-#: fortran/resolve.c:10036
+#: fortran/resolve.c:10049
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "%L'deki WHERE/ELSEWHERE deyimi bir değişmez LOGICAL dizisi gerektirir"
 
-#: fortran/resolve.c:10138
+#: fortran/resolve.c:10151
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:10251
+#: fortran/resolve.c:10264
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr ""
 
-#: fortran/resolve.c:10283
+#: fortran/resolve.c:10296
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Right side of assignment at %L is a derived type containing a POINTER in a PURE procedure"
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "%L'deki atamanın sağ tarafı bir PURE yordamda bir POINTER içeren türetilmiş bir türdür"
 
-#: fortran/resolve.c:10288
+#: fortran/resolve.c:10301
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Right side of assignment at %L is a derived type containing a POINTER in a PURE procedure"
 msgid "The impure variable at %L is assigned to a derived type variable with a POINTER component in a PURE procedure (12.6)"
 msgstr "%L'deki atamanın sağ tarafı bir PURE yordamda bir POINTER içeren türetilmiş bir türdür"
 
-#: fortran/resolve.c:10298
+#: fortran/resolve.c:10311
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assignment to a FORALL index variable at %L"
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "%L'de bir FORALL indis değişkenine atama"
 
-#: fortran/resolve.c:10330
+#: fortran/resolve.c:10343
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:10334
+#: fortran/resolve.c:10347
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assignment to a FORALL index variable at %L"
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "%L'de bir FORALL indis değişkenine atama"
 
-#: fortran/resolve.c:10339
+#: fortran/resolve.c:10352
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.c:10346
+#: fortran/resolve.c:10359
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr ""
 
-#: fortran/resolve.c:10357
+#: fortran/resolve.c:10370
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:10663
+#: fortran/resolve.c:10683
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
@@ -67693,75 +67776,75 @@
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:10905
+#: fortran/resolve.c:10925
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Different types in pointer assignment at %L"
 msgid "Pointer procedure assignment at %L"
 msgstr "%L'deki gösterici atamasında farklı türler"
 
-#: fortran/resolve.c:10917
+#: fortran/resolve.c:10937
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr "%L'de hesaplanmış GOTO deyimindeki seçim ifadesi bir değişmez tamsayı ifadesi olmalıdır"
 
-#: fortran/resolve.c:11157
+#: fortran/resolve.c:11177
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgstr "%L'deki ASSIGNED GOTO deyimi bir INTEGER değişken gerektirir"
 
-#: fortran/resolve.c:11160
+#: fortran/resolve.c:11180
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' has not been assigned a target label at %L"
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "'%s' değişkenine %L'de bir hedef etiketi atanmış olmamalıydı"
 
-#: fortran/resolve.c:11171
+#: fortran/resolve.c:11191
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Alternate RETURN statement at %L requires an INTEGER return specifier"
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "Diğer RETURN deyimi %L'de bir INTEGER dönüş belirteci gerektirir"
 
-#: fortran/resolve.c:11233
+#: fortran/resolve.c:11253
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "%L'deki ASSIGN deyimi bir sabit öntanımlı INTEGER değişken gerektirir"
 
-#: fortran/resolve.c:11278
+#: fortran/resolve.c:11298
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Invalid NULL at %L"
 msgstr "%s için %L'deki çeşit geçersiz"
 
-#: fortran/resolve.c:11282
+#: fortran/resolve.c:11302
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Arithmetic IF statement at %L requires a numeric expression"
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr "%L'deki aritmetik IF deyimi bir sayısal ifade gerektirir"
 
-#: fortran/resolve.c:11339
+#: fortran/resolve.c:11359
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:11344
+#: fortran/resolve.c:11364
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "%L'deki DO WHILE döngüsünün çıkış koşulu bir sabit LOGICAL ifadesi olmalıdır"
 
-#: fortran/resolve.c:11428
+#: fortran/resolve.c:11448
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL mask clause at %L requires a LOGICAL expression"
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "%L'deki FORALL maske deyimi bir LOGICAL ifadesi gerektirir"
 
-#: fortran/resolve.c:11507
+#: fortran/resolve.c:11527
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_trans_code(): Hatalı deyim kodu"
 
-#: fortran/resolve.c:11617
+#: fortran/resolve.c:11637
 #, fuzzy, gcc-internal-format
 #| msgid "Named COMMON block '%s' at %L shall be of the same size"
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
@@ -67769,7 +67852,7 @@
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:11630
+#: fortran/resolve.c:11650
 #, fuzzy, gcc-internal-format
 #| msgid "Named COMMON block '%s' at %L shall be of the same size"
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
@@ -67778,63 +67861,63 @@
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:11647
+#: fortran/resolve.c:11667
 #, fuzzy, gcc-internal-format
 #| msgid "Named COMMON block '%s' at %L shall be of the same size"
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "İsimli COMMON blok '%s' %L'de aynı boyutta olmalı"
 
-#: fortran/resolve.c:11732
+#: fortran/resolve.c:11752
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "String length at %L is too large"
 msgstr "%qs dizisinin boyutu çok büyük"
 
-#: fortran/resolve.c:11961
+#: fortran/resolve.c:11981
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable array '%s' at %L must have a deferred shape"
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "Ayrılabilir '%s' dizisi %L'de ertelenmiş bir biçimde olmalı"
 
-#: fortran/resolve.c:11965
+#: fortran/resolve.c:11985
 #, fuzzy, gcc-internal-format
 #| msgid "Scalar object '%s' at %L may not be ALLOCATABLE"
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "'%s' sabit nesnesi %L'de ALLOCATABLE olmayabilir"
 
-#: fortran/resolve.c:11973
+#: fortran/resolve.c:11993
 #, fuzzy, gcc-internal-format
 #| msgid "Array pointer '%s' at %L must have a deferred shape"
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "'%s' dizi göstericisi %L'de ertelenmiş bir biçimde olmalı"
 
-#: fortran/resolve.c:11983
+#: fortran/resolve.c:12003
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "'%s' dizisi %L'de ertelenmiş bir biçimde olamaz"
 
-#: fortran/resolve.c:11998
+#: fortran/resolve.c:12018
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.c:12010
+#: fortran/resolve.c:12030
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.c:12041
+#: fortran/resolve.c:12061
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.c:12063
+#: fortran/resolve.c:12083
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
 
-#: fortran/resolve.c:12090
+#: fortran/resolve.c:12110
 #, fuzzy, gcc-internal-format
 #| msgid "Possible frontend bug: Deferred array size without pointer or allocatable attribute."
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
@@ -67842,971 +67925,977 @@
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12131
+#: fortran/resolve.c:12151
 #, fuzzy, gcc-internal-format
 #| msgid "The module or main program array '%s' at %L must have constant shape"
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "Modül veya ana program dizisi '%s' %L'de sabit biçimde olmalı"
 
-#: fortran/resolve.c:12150
+#: fortran/resolve.c:12170
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "%L'deki tahmini karakter uzunluklu öğe ya bir sözde argüman ya da bir PARAMETER olmalı"
 
-#: fortran/resolve.c:12171
+#: fortran/resolve.c:12191
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "%qs at %L must have constant character length in this context"
 msgstr "'%s' %L'de bu bağlam için sabit karakter uzunluklu olmalı"
 
-#: fortran/resolve.c:12178
+#: fortran/resolve.c:12198
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "'%s' %L'de bu bağlam için sabit karakter uzunluklu olmalı"
 
-#: fortran/resolve.c:12225
+#: fortran/resolve.c:12245
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable '%s' at %L cannot have an initializer"
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "Ayrılabilir '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.c:12228
+#: fortran/resolve.c:12248
 #, fuzzy, gcc-internal-format
 #| msgid "External '%s' at %L cannot have an initializer"
 msgid "External %qs at %L cannot have an initializer"
 msgstr "Harici '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.c:12232
+#: fortran/resolve.c:12252
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "Sözde '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.c:12235
+#: fortran/resolve.c:12255
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L cannot have an initializer"
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "Yerleşik '%s' %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.c:12238
+#: fortran/resolve.c:12258
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L cannot have an initializer"
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "işlev sonucu '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.c:12241
+#: fortran/resolve.c:12261
 #, fuzzy, gcc-internal-format
 #| msgid "Automatic array '%s' at %L cannot have an initializer"
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "Özdevinimli dizi '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.c:12283
+#: fortran/resolve.c:12303
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "in %s, at %s:%d"
 msgid "%s at %L"
 msgstr "%s işlevinde (%s dosyasının %d. satırı)"
 
-#: fortran/resolve.c:12310
+#: fortran/resolve.c:12330
 #, fuzzy, gcc-internal-format
 #| msgid "Character-valued statement function '%s' at %L must have constant length"
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "Karakter değerli deyim işlevi '%s'  %L'de sabit uzunlukta olmalı"
 
-#: fortran/resolve.c:12332
+#: fortran/resolve.c:12352
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' is of a PRIVATE type and cannot be a dummy argument of '%s', which is PUBLIC at %L"
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "'%s' bir PRIVATE türündedir ve '%s' (%L'de PUBLIC tanımlı) için bir sözde argüman olamaz"
 
-#: fortran/resolve.c:12354
+#: fortran/resolve.c:12374
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.c:12372
+#: fortran/resolve.c:12392
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L cannot have an initializer"
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "işlev sonucu '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.c:12381
+#: fortran/resolve.c:12401
 #, fuzzy, gcc-internal-format
 #| msgid "External object '%s' at %L may not have an initializer"
 msgid "External object %qs at %L may not have an initializer"
 msgstr "Harici nesne '%s'  %L'de bir ilklendiriciye sahip olamayabilir"
 
-#: fortran/resolve.c:12389
+#: fortran/resolve.c:12409
 #, fuzzy, gcc-internal-format
 #| msgid "%s at %L must be a scalar"
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "%s' (%L'de) bir değişmez olmalıdır"
 
-#: fortran/resolve.c:12399
+#: fortran/resolve.c:12419
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' at %L is not allowed as an actual argument"
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "'%s' beyan işlevine bir fiili argüman olarak izin verilmez (%L'de)"
 
-#: fortran/resolve.c:12418
+#: fortran/resolve.c:12438
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be array-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "CHARACTER(*) işlevi '%s'  %L'de dizi değerli olamaz"
 
-#: fortran/resolve.c:12422
+#: fortran/resolve.c:12442
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pointer-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "CHARACTER(*) işlevi '%s'  %L'de gösterici değerli olamaz"
 
-#: fortran/resolve.c:12426
+#: fortran/resolve.c:12446
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "CHARACTER(*) işlevi '%s'  %L'de katıksız olamaz"
 
-#: fortran/resolve.c:12430
+#: fortran/resolve.c:12450
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be recursive"
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "CHARACTER(*) işlevi '%s'  %L'de iç içe olamaz"
 
-#: fortran/resolve.c:12443
+#: fortran/resolve.c:12463
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "CHARACTER(*) işlevi '%s'  %L'de katıksız olamaz"
 
-#: fortran/resolve.c:12452
+#: fortran/resolve.c:12472
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:12458
+#: fortran/resolve.c:12478
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy procedure '%s' of PURE procedure at %L must also be PURE"
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "PURE yordamının '%s' sözde yordamı da ayrıca PURE olmalı"
 
-#: fortran/resolve.c:12470
+#: fortran/resolve.c:12490
 #, fuzzy, gcc-internal-format
 #| msgid "Loop variable at %C cannot have the POINTER attribute"
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr "%C'deki döngü değişkeni POINTER özniteliğinde olamaz"
 
-#: fortran/resolve.c:12527
+#: fortran/resolve.c:12547
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "PROCEDURE özniteliği '%s' içinde NAMELIST özniteliği ile çelişiyor (%L'de)"
 
-#: fortran/resolve.c:12533
+#: fortran/resolve.c:12553
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "PROCEDURE özniteliği '%s' içinde NAMELIST özniteliği ile çelişiyor (%L'de)"
 
-#: fortran/resolve.c:12539
+#: fortran/resolve.c:12559
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "PROCEDURE özniteliği '%s' içinde NAMELIST özniteliği ile çelişiyor (%L'de)"
 
-#: fortran/resolve.c:12547
+#: fortran/resolve.c:12567
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute in '%s' at %L"
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "%s özniteliği ile %s özniteliği '%s' içinde %L'de çelişiyor"
 
-#: fortran/resolve.c:12553
+#: fortran/resolve.c:12573
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.c:12596
+#: fortran/resolve.c:12616
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12604
+#: fortran/resolve.c:12624
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12612
+#: fortran/resolve.c:12632
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12621
+#: fortran/resolve.c:12641
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.c:12705
+#: fortran/resolve.c:12725
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:12714
+#: fortran/resolve.c:12734
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "Kullanıcı işleci yordamı '%s' (%L'de) için en azından bir argüman bulunmalı"
 
-#: fortran/resolve.c:12723
+#: fortran/resolve.c:12743
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ICHAR at %L must be of length one"
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "%L'de ICHAR'ın argümanı bir uzunlukta olmalı"
 
-#: fortran/resolve.c:12731
+#: fortran/resolve.c:12751
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a POINTER"
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) bir POINTER olmalı"
 
-#: fortran/resolve.c:12737
+#: fortran/resolve.c:12757
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be ALLOCATABLE"
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) ALLOCATABLE olmalı"
 
-#: fortran/resolve.c:12743
+#: fortran/resolve.c:12763
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must not be OPTIONAL"
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) OPTIONAL olmamalı"
 
-#: fortran/resolve.c:12751
+#: fortran/resolve.c:12771
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "%L'deki işleç arayüzünün ilk argümanı INTENT(IN) olmalıdır"
 
-#: fortran/resolve.c:12760
+#: fortran/resolve.c:12780
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "Kullanıcı işleci yordamı '%s' (%L'de) için en azından bir argüman bulunmalı"
 
-#: fortran/resolve.c:12782
+#: fortran/resolve.c:12802
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr ""
 
-#: fortran/resolve.c:12819
+#: fortran/resolve.c:12839
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr ""
 
-#: fortran/resolve.c:12859
+#: fortran/resolve.c:12879
 #, gcc-internal-format
 msgid "%qs and %qs can't be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12895
+#: fortran/resolve.c:12915
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.c:12954
+#: fortran/resolve.c:12974
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12966
+#: fortran/resolve.c:12986
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.c:12994
+#: fortran/resolve.c:13014
 #, gcc-internal-format
 msgid "GENERIC %qs at %L can't overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.c:13050
+#: fortran/resolve.c:13070
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L can't be NOPASS"
 msgstr ""
 
-#: fortran/resolve.c:13242
+#: fortran/resolve.c:13262
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' called with an implicit interface at %L"
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "Yordam '%s' bir örtük arayüz ile çağrılmış (%L'de)"
 
-#: fortran/resolve.c:13284
+#: fortran/resolve.c:13304
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:13298
+#: fortran/resolve.c:13318
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "Kullanıcı işleci yordamı '%s' (%L'de) için en azından bir argüman bulunmalı"
 
-#: fortran/resolve.c:13312 fortran/resolve.c:13778
+#: fortran/resolve.c:13332 fortran/resolve.c:13798
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13320
+#: fortran/resolve.c:13340
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a non-derived type"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) türetilmemiş bir türde olmalı"
 
-#: fortran/resolve.c:13329
+#: fortran/resolve.c:13349
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a scalar"
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "`%s' argümanı `%s' yerleşiği için  %L'de bir değişmez olmalı"
 
-#: fortran/resolve.c:13335
+#: fortran/resolve.c:13355
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be ALLOCATABLE"
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) ALLOCATABLE olmalı"
 
-#: fortran/resolve.c:13341
+#: fortran/resolve.c:13361
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a POINTER"
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) bir POINTER olmalı"
 
-#: fortran/resolve.c:13370
+#: fortran/resolve.c:13390
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:13380
+#: fortran/resolve.c:13400
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:13472
+#: fortran/resolve.c:13492
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.c:13574
+#: fortran/resolve.c:13594
 #, fuzzy, gcc-internal-format
 #| msgid "Array pointer '%s' at %L must have a deferred shape"
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "'%s' dizi göstericisi %L'de ertelenmiş bir biçimde olmalı"
 
-#: fortran/resolve.c:13583
+#: fortran/resolve.c:13603
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13593
+#: fortran/resolve.c:13613
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.c:13602
+#: fortran/resolve.c:13622
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.c:13613
+#: fortran/resolve.c:13633
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ICHAR at %L must be of length one"
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "%L'de ICHAR'ın argümanı bir uzunlukta olmalı"
 
-#: fortran/resolve.c:13711
+#: fortran/resolve.c:13731
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:13725
+#: fortran/resolve.c:13745
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "Kullanıcı işleci yordamı '%s' (%L'de) için en azından bir argüman bulunmalı"
 
-#: fortran/resolve.c:13741
+#: fortran/resolve.c:13761
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a non-derived type"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) türetilmemiş bir türde olmalı"
 
-#: fortran/resolve.c:13751
+#: fortran/resolve.c:13771
 #, fuzzy, gcc-internal-format
 #| msgid "Argument dim at %L must be scalar"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "%L'de boyut argümanı değişmez olmalı"
 
-#: fortran/resolve.c:13760
+#: fortran/resolve.c:13780
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of elemental procedure at %L cannot have the POINTER attribute"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "Öğesel yordamın '%s' argümanı POINTER özniteliğine sahip olamaz (%L'de)"
 
-#: fortran/resolve.c:13769
+#: fortran/resolve.c:13789
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be ALLOCATABLE"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "`%s' argümanı `%s' yerleşiği için  (%L'de) ALLOCATABLE olmalı"
 
-#: fortran/resolve.c:13811
+#: fortran/resolve.c:13831
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' of '%s' at %L must have constant array bounds."
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "'%s' ('%s'in bileşeni) %L'de sabit dizi sınırlarına sahip olmalı"
 
-#: fortran/resolve.c:13824
+#: fortran/resolve.c:13844
 #, fuzzy, gcc-internal-format
 #| msgid "Character length of component '%s' needs to be a constant specification expression at %L."
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "Bileşen karakter uzunluğu '%s'in %L'de bir sabit belirtim ifadesi olması gerekir"
 
-#: fortran/resolve.c:13835
+#: fortran/resolve.c:13855
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13868
+#: fortran/resolve.c:13888
 #, fuzzy, gcc-internal-format
 #| msgid "The component '%s' is a PRIVATE type and cannot be a component of '%s', which is PUBLIC at %L"
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "Bileşen '%s' bir PRIVATE türdür ve '%s' (%L'de PUBLIC tanımlı) bileşeni olamaz"
 
-#: fortran/resolve.c:13876
+#: fortran/resolve.c:13896
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.c:13885
+#: fortran/resolve.c:13905
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Component %s of SEQUENCE type declared at %C does not have the SEQUENCE attribute"
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "SEQUENCE türünün %s bileşeni SEQUENCE özniteliğine sahip değil (%C'de)"
 
-#: fortran/resolve.c:13903 fortran/resolve.c:13915
+#: fortran/resolve.c:13923 fortran/resolve.c:13935
 #, fuzzy, gcc-internal-format
 #| msgid "The derived type '%s' at %L is of type '%s', which has not been defined."
 msgid "The pointer component %qs of %qs at %L is a type that has not been declared"
 msgstr "Türetilmiş '%s' türü (%L'de) tanımlanmamış olan '%s' türündedir."
 
-#: fortran/resolve.c:13989
+#: fortran/resolve.c:14009
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected an initialization expression at %C"
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "%C'de bir ilklendirme ifadesi umuluyordu"
 
-#: fortran/resolve.c:14034
+#: fortran/resolve.c:14054
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.c:14047
+#: fortran/resolve.c:14067
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr ""
 
-#: fortran/resolve.c:14111
+#: fortran/resolve.c:14131
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14144
+#: fortran/resolve.c:14164
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' of '%s' at %L must have constant array bounds."
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr "'%s' ('%s'in bileşeni) %L'de sabit dizi sınırlarına sahip olmalı"
 
-#: fortran/resolve.c:14216
+#: fortran/resolve.c:14236
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed size array '%s' in namelist '%s'at %C is not allowed."
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "'%s' tahmini boyutlu dizisine '%s' isim listesinde izin verilmiyor (%C'de)."
 
-#: fortran/resolve.c:14222
+#: fortran/resolve.c:14242
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14228
+#: fortran/resolve.c:14248
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14236
+#: fortran/resolve.c:14256
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14253
+#: fortran/resolve.c:14273
 #, fuzzy, gcc-internal-format
 #| msgid "PRIVATE symbol '%s' cannot be member of PUBLIC namelist at %L"
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "'%s' PRIVATE simgesi %L'de PUBLIC isim listesi üyesi olamaz"
 
-#: fortran/resolve.c:14275
+#: fortran/resolve.c:14295
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14286
+#: fortran/resolve.c:14306
 #, fuzzy, gcc-internal-format
 #| msgid "PRIVATE symbol '%s' cannot be member of PUBLIC namelist at %L"
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "'%s' PRIVATE simgesi %L'de PUBLIC isim listesi üyesi olamaz"
 
-#: fortran/resolve.c:14313
+#: fortran/resolve.c:14333
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "PROCEDURE özniteliği '%s' içinde NAMELIST özniteliği ile çelişiyor (%L'de)"
 
-#: fortran/resolve.c:14337
+#: fortran/resolve.c:14357
 #, fuzzy, gcc-internal-format
 #| msgid "Parameter array '%s' at %L cannot be automatic or assumed shape"
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "Parametre dizisi '%s' %L'de özdevinimli veya tahmini biçimli olamaz"
 
-#: fortran/resolve.c:14353
+#: fortran/resolve.c:14373
 #, fuzzy, gcc-internal-format
 #| msgid "Implicitly typed PARAMETER '%s' at %L doesn't match a later IMPLICIT type"
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "Örtük olarak  PARAMETER türlü '%s' %L'de sonraki bir IMPLICIT türle eşleşmiyor"
 
-#: fortran/resolve.c:14364
+#: fortran/resolve.c:14384
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "%L'de PARAMETER içindeki türetilmiş tür uyumsuz"
 
-#: fortran/resolve.c:14372
+#: fortran/resolve.c:14392
 #, fuzzy, gcc-internal-format
 #| msgid "Loop variable at %C cannot have the POINTER attribute"
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "%C'deki döngü değişkeni POINTER özniteliğinde olamaz"
 
-#: fortran/resolve.c:14423
+#: fortran/resolve.c:14443
 #, fuzzy, gcc-internal-format
 #| msgid "Possible frontend bug: Deferred array size without pointer or allocatable attribute."
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr "Olası önyüz hatası: gösterici veya tahsis edilebilir öznitelik olmaksızın ertelenmiş dizi boyutu"
 
-#: fortran/resolve.c:14434
+#: fortran/resolve.c:14454
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.c:14441
+#: fortran/resolve.c:14461
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.c:14480
+#: fortran/resolve.c:14500
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:14544
+#: fortran/resolve.c:14564
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "PROCEDURE özniteliği '%s' içinde NAMELIST özniteliği ile çelişiyor (%L'de)"
 
-#: fortran/resolve.c:14547
+#: fortran/resolve.c:14567
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "PROCEDURE özniteliği '%s' içinde NAMELIST özniteliği ile çelişiyor (%L'de)"
 
-#: fortran/resolve.c:14643
+#: fortran/resolve.c:14663
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:14664
+#: fortran/resolve.c:14684
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad specification for assumed size array at %C"
 msgid "Bad specification for assumed size array at %L"
 msgstr "%C'deki tahmini boyutlu dizi için belirtim hatalı"
 
-#: fortran/resolve.c:14677
+#: fortran/resolve.c:14697
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "%L'deki tahmini boyutlu dizi bir sözde argüman olmalı"
 
-#: fortran/resolve.c:14680
+#: fortran/resolve.c:14700
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "Tahmini boyutlu dizi bir sözde argüman olmalı"
 
-#: fortran/resolve.c:14688
+#: fortran/resolve.c:14708
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "Tahmini boyutlu dizi bir sözde argüman olmalı"
 
-#: fortran/resolve.c:14695
+#: fortran/resolve.c:14715
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:14708
+#: fortran/resolve.c:14728
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "%L'deki simge bir DUMMY değişken değil"
 
-#: fortran/resolve.c:14714
+#: fortran/resolve.c:14734
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14724
+#: fortran/resolve.c:14744
 #, fuzzy, gcc-internal-format
 #| msgid "Character-valued statement function '%s' at %L must have constant length"
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "Karakter değerli deyim işlevi '%s'  %L'de sabit uzunlukta olmalı"
 
-#: fortran/resolve.c:14733
+#: fortran/resolve.c:14753
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.c:14746 fortran/resolve.c:14923
+#: fortran/resolve.c:14766 fortran/resolve.c:14943
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "Türetilmiş %qs türü %L'de tanımlanmamış olan %qs türündedir."
 
-#: fortran/resolve.c:14760
+#: fortran/resolve.c:14780
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14769
+#: fortran/resolve.c:14789
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:14778
+#: fortran/resolve.c:14798
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14786
+#: fortran/resolve.c:14806
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Loop variable at %C cannot have the POINTER attribute"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "%C'deki döngü değişkeni POINTER özniteliğinde olamaz"
 
-#: fortran/resolve.c:14793
+#: fortran/resolve.c:14813
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:14813
+#: fortran/resolve.c:14833
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.c:14820
+#: fortran/resolve.c:14840
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Loop variable at %C cannot have the POINTER attribute"
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "%C'deki döngü değişkeni POINTER özniteliğinde olamaz"
 
-#: fortran/resolve.c:14827
+#: fortran/resolve.c:14847
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Loop variable at %C cannot have the POINTER attribute"
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "%C'deki döngü değişkeni POINTER özniteliğinde olamaz"
 
-#: fortran/resolve.c:14834
+#: fortran/resolve.c:14854
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:14860
+#: fortran/resolve.c:14880
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:14870
+#: fortran/resolve.c:14890
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "'%s' %L'de bu bağlam için sabit karakter uzunluklu olmalı"
 
-#: fortran/resolve.c:14949
+#: fortran/resolve.c:14969
 #, fuzzy, gcc-internal-format
 #| msgid "PUBLIC function '%s' at %L cannot be of PRIVATE type '%s'"
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "PUBLIC işlev '%s' %L'de PRIVATE '%s' türünde olamaz"
 
-#: fortran/resolve.c:14964
+#: fortran/resolve.c:14984
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14977
+#: fortran/resolve.c:14997
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14995
+#: fortran/resolve.c:15015
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "INTENT(OUT) sözde argüman %qs %L'de ASSUMED SIZE olduğundan bir öntanımlı ilklerdiriciye sahip olamaz"
 
-#: fortran/resolve.c:15007
+#: fortran/resolve.c:15027
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "Sözde argüman '%s' (%L'de) INTENT(OUT) olamaz"
 
-#: fortran/resolve.c:15016
+#: fortran/resolve.c:15036
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "Sözde argüman '%s' (%L'de) INTENT(OUT) olamaz"
 
-#: fortran/resolve.c:15028
+#: fortran/resolve.c:15048
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L cannot have an initializer"
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "işlev sonucu '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.c:15037
+#: fortran/resolve.c:15057
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15049
+#: fortran/resolve.c:15069
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15065
+#: fortran/resolve.c:15085
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15073
+#: fortran/resolve.c:15093
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "'%s' dizisi %L'de ertelenmiş bir biçimde olamaz"
 
-#: fortran/resolve.c:15080
+#: fortran/resolve.c:15100
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable array '%s' at %L must have a deferred shape"
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "Ayrılabilir '%s' dizisi %L'de ertelenmiş bir biçimde olmalı"
 
-#: fortran/resolve.c:15092
+#: fortran/resolve.c:15112
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.c:15101
+#: fortran/resolve.c:15121
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy procedure at %L not allowed in ELEMENTAL procedure"
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "%L'deki sözde yordama ELEMENTAL yordamında izin verilmez"
 
-#: fortran/resolve.c:15117
+#: fortran/resolve.c:15137
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15123
+#: fortran/resolve.c:15143
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15148
+#: fortran/resolve.c:15168
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist %s cannot be renamed by USE association to %s."
 msgid "Namelist %qs can not be an argument to subroutine or function at %L"
 msgstr "İsim listesinin ismi %s USE ilişkisiyle %s yapılamaz"
 
-#: fortran/resolve.c:15218
+#: fortran/resolve.c:15238
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:15229
+#: fortran/resolve.c:15249
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:15333
+#: fortran/resolve.c:15353
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:15339
+#: fortran/resolve.c:15359
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "BLOCK DATA öğesi %qs %L'de COMMON içinde olmalıdır"
 
-#: fortran/resolve.c:15345
+#: fortran/resolve.c:15365
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.c:15354
+#: fortran/resolve.c:15374
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "Sözde '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.c:15368
+#: fortran/resolve.c:15388
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:15414
+#: fortran/resolve.c:15434
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "DATA deyiminde %L'de sabit olmayan dizi bölümü"
 
-#: fortran/resolve.c:15427
+#: fortran/resolve.c:15447
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "%L'deki DATA deyiminde değerden çok değişken var"
 
-#: fortran/resolve.c:15526
+#: fortran/resolve.c:15546
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15534
+#: fortran/resolve.c:15554
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15542
+#: fortran/resolve.c:15562
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15667
+#: fortran/resolve.c:15687
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "%L'deki DATA deyiminde değişkenden çok değer var"
 
-#: fortran/resolve.c:15832
+#: fortran/resolve.c:15852
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "%d yaftası %L'de tanımlanmış ama kullanılmamış"
 
-#: fortran/resolve.c:15838
+#: fortran/resolve.c:15858
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "%d yaftası %L'de tanımlanmış ama kullanılamıyor"
 
-#: fortran/resolve.c:15922
+#: fortran/resolve.c:15942
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "Türetilmiş tür değişkeni %qs %L'de bir EQUIVALENCE nesnesi olarak SEQUENCE özniteliğine sahip olmalı"
 
-#: fortran/resolve.c:15931
+#: fortran/resolve.c:15951
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "Türetilmiş tür değişkeni '%s' %L'de gösterici bileşen(ler)le bir EQUIVALENCE nesnesi olamaz"
 
-#: fortran/resolve.c:15939
+#: fortran/resolve.c:15959
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with default initializer cannot be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "Türetilmiş tür değişkeni '%s' %L'de öntanımlı ilklendiriciyle bir EQUIVALENCE nesnesi olamaz"
 
-#: fortran/resolve.c:15955
+#: fortran/resolve.c:15975
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "Türetilmiş tür değişkeni %qs %L'de gösterici bileşen(ler)le bir EQUIVALENCE nesnesi olamaz"
 
-#: fortran/resolve.c:16058
+#: fortran/resolve.c:16078
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "%L'deki EQUIVALENCE deyiminde söz dizimi hatası"
 
-#: fortran/resolve.c:16073
+#: fortran/resolve.c:16093
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:16098
+#: fortran/resolve.c:16118
 #, fuzzy, gcc-internal-format
 #| msgid "Common block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "Ortak blok üyesi %qs %L'de, %qs pure yordamındaki bir EQUIVALENCE nesnesi olamaz"
 
-#: fortran/resolve.c:16107
+#: fortran/resolve.c:16127
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "%qs isimli sabiti %L'de bir EQUIVALENCE nesnesi olamaz"
 
-#: fortran/resolve.c:16180
+#: fortran/resolve.c:16200
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "Sınırları sabit olmayan %qs dizisi %L'de bir EQUIVALENCE nesnesi olamaz"
 
-#: fortran/resolve.c:16191
+#: fortran/resolve.c:16211
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Yapı bileşeni %qs %L'de bir EQUIVALENCE nesnesi olamaz"
 
-#: fortran/resolve.c:16202
+#: fortran/resolve.c:16222
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "%L'deki altdizge sıfır uzunlukta"
 
-#: fortran/resolve.c:16293
+#: fortran/resolve.c:16253
+#, fuzzy, gcc-internal-format
+#| msgid "Syntax error in character length specification at %C"
+msgid "Self reference in character length expression for %qs at %L"
+msgstr "%C'deki karakter uzunluğu belirtiminde sözdizimi hatası"
+
+#: fortran/resolve.c:16320
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.c:16306
+#: fortran/resolve.c:16333
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "ENTRY %qs %L'de hiç IMPLICIT tür içermiyor"
 
-#: fortran/resolve.c:16326
+#: fortran/resolve.c:16353
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "Yerleşik işleç arayüzü %qs %L'de bir FUNCTION olmalı"
 
-#: fortran/resolve.c:16336
+#: fortran/resolve.c:16363
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "Kullanıcı işleci yordamı %qs %L'de tahmini karakter uzunluğunda olamaz"
 
-#: fortran/resolve.c:16344
+#: fortran/resolve.c:16371
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "Kullanıcı işleci yordamı %qs %L'de için en azından bir argüman bulunmalı"
 
-#: fortran/resolve.c:16358
+#: fortran/resolve.c:16385
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "%L'deki işleç arayüzünün ilk argümanı isteğe bağlı olamaz"
 
-#: fortran/resolve.c:16376
+#: fortran/resolve.c:16403
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "%L'deki işleç arayüzünün ikinci argümanı isteğe bağlı olamaz"
 
-#: fortran/resolve.c:16383
+#: fortran/resolve.c:16410
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "%L'deki işleç arayüzünün en fazla iki argümanı olmalı"
 
-#: fortran/resolve.c:16461
+#: fortran/resolve.c:16488
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -69155,19 +69244,13 @@
 msgid "simplify_min_max(): Bad type in arglist"
 msgstr ""
 
-#. Result is processor-dependent.
-#: fortran/simplify.c:5472
-#, gcc-internal-format, gfc-internal-format
-msgid "Second argument MOD at %L is zero"
-msgstr "%L'de ikinci MOD argümanı sıfırdır"
+#: fortran/simplify.c:5470 fortran/simplify.c:5478
+#, fuzzy, gcc-internal-format
+#| msgid "Second argument of NEAREST at %L may not be zero"
+msgid "Argument %qs of MOD at %L shall not be zero"
+msgstr "%L'de NEAREST'ın ikinci argümanı sıfır olmayabilir"
 
-#. Result is processor-dependent.
-#: fortran/simplify.c:5483
-#, gcc-internal-format, gfc-internal-format
-msgid "Second argument of MOD at %L is zero"
-msgstr "%L'de MOD'un ikinci argümanı sıfırdır"
-
-#: fortran/simplify.c:5494
+#: fortran/simplify.c:5484
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_simplify_mod(): Bad arguments"
@@ -69176,102 +69259,102 @@
 #. Result is processor-dependent. This processor just opts
 #. to not handle it at all.
 #. Result is processor-dependent.
-#: fortran/simplify.c:5520 fortran/simplify.c:5532
+#: fortran/simplify.c:5525 fortran/simplify.c:5537
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of MODULO at %L is zero"
 msgstr "%L'de MODULO'nun ikinci argümanı sıfırdır"
 
-#: fortran/simplify.c:5552
+#: fortran/simplify.c:5557
 #, gcc-internal-format
 msgid "gfc_simplify_modulo(): Bad arguments"
 msgstr ""
 
-#: fortran/simplify.c:5600
+#: fortran/simplify.c:5605
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Result of SCALE overflows its kind at %L"
 msgid "Result of NEAREST is NaN at %L"
 msgstr "%L'de SCALE sonucu kendi çeşidini üstten taşırıyor"
 
-#: fortran/simplify.c:6081
+#: fortran/simplify.c:6086
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative at %L"
 msgstr ""
 
-#: fortran/simplify.c:6137
+#: fortran/simplify.c:6142
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument NCOPIES of REPEAT intrinsic is too large at %L"
 msgstr ""
 
-#: fortran/simplify.c:6174
+#: fortran/simplify.c:6179
 #, gcc-internal-format, gfc-internal-format
 msgid "Evaluation of string longer than 2**28 at %L deferred to runtime, expect bugs"
 msgstr ""
 
-#: fortran/simplify.c:6302
+#: fortran/simplify.c:6307
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Integer too large at %C"
 msgid "Reshaped array too large at %C"
 msgstr "%C'deki tamsayı çok büyük"
 
-#: fortran/simplify.c:6416
+#: fortran/simplify.c:6421
 #, gcc-internal-format, gfc-internal-format
 msgid "Result of SCALE overflows its kind at %L"
 msgstr "%L'de SCALE sonucu kendi çeşidini üstten taşırıyor"
 
-#: fortran/simplify.c:6995
+#: fortran/simplify.c:7000
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "Bad type in gfc_simplify_sign"
 msgstr "Sabit ifadesinde tür hatalı"
 
-#: fortran/simplify.c:7024
+#: fortran/simplify.c:7029
 #, gcc-internal-format
 msgid "in gfc_simplify_sin(): Bad type"
 msgstr ""
 
-#: fortran/simplify.c:7151 fortran/simplify.c:7431
+#: fortran/simplify.c:7156 fortran/simplify.c:7436
 #, gcc-internal-format
 msgid "Failure getting length of a constant array."
 msgstr ""
 
-#: fortran/simplify.c:7161
+#: fortran/simplify.c:7166
 #, gcc-internal-format
 msgid "The number of elements (%d) in the array constructor at %L requires an increase of the allowed %d upper limit.  See %<-fmax-array-constructor%> option."
 msgstr ""
 
-#: fortran/simplify.c:7227
+#: fortran/simplify.c:7232
 #, gcc-internal-format, gfc-internal-format
 msgid "Simplification of SPREAD at %C not yet implemented"
 msgstr ""
 
-#: fortran/simplify.c:7251
+#: fortran/simplify.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SQRT at %L has a negative value"
 msgstr "%L'de SQRT'nin argümanı negatif değer içeriyor"
 
-#: fortran/simplify.c:7267
+#: fortran/simplify.c:7272
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid second argument of IBSET at %L"
 msgid "invalid argument of SQRT at %L"
 msgstr "%L'de IBSET'in ikinci argümanı geçersiz"
 
-#: fortran/simplify.c:7598
+#: fortran/simplify.c:7603
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY lower bound is %ld)"
 msgstr ""
 
-#: fortran/simplify.c:7621
+#: fortran/simplify.c:7626
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY upper bound is %ld)"
 msgstr ""
 
-#: fortran/simplify.c:7993
+#: fortran/simplify.c:7998
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_conv_constant_to_tree(): invalid type: %s"
 msgid "gfc_convert_constant(): Unexpected type"
 msgstr "gfc_conv_constant_to_tree(): geçersiz tür: %s"
 
-#: fortran/simplify.c:8078
+#: fortran/simplify.c:8083
 #, gcc-internal-format
 msgid "Character %qs in string at %L cannot be converted into character kind %d"
 msgstr ""
@@ -69385,7 +69468,7 @@
 msgid "BIND(C) applied to %s %s at %L"
 msgstr ""
 
-#: fortran/symbol.c:901 fortran/symbol.c:912 fortran/symbol.c:1762
+#: fortran/symbol.c:901 fortran/symbol.c:912 fortran/symbol.c:1776
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute conflicts with %s attribute at %L"
 msgstr "%s özniteliği ile %s özniteliği %L'de çelişiyor"
@@ -69466,19 +69549,25 @@
 msgid "Duplicate VOLATILE attribute specified at %L"
 msgstr "%L'de yinelenen SAVE özniteliği belirtilmiş"
 
-#: fortran/symbol.c:1367
+#: fortran/symbol.c:1360
 #, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "SAVE attribute at %L cannot be specified in a PURE procedure"
+msgid "VOLATILE attribute at %L cannot be specified in a PURE procedure"
+msgstr "%L'deki SAVE özniteliği bir PURE yordamında belirtilemez"
+
+#: fortran/symbol.c:1381
+#, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate SAVE attribute specified at %L"
 msgid "Duplicate ASYNCHRONOUS attribute specified at %L"
 msgstr "%L'de yinelenen SAVE özniteliği belirtilmiş"
 
-#: fortran/symbol.c:1758
+#: fortran/symbol.c:1772
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "%s attribute of %qs conflicts with %s attribute at %L"
 msgstr "%s özniteliği ile %s özniteliği %L'de çelişiyor"
 
-#: fortran/symbol.c:1794
+#: fortran/symbol.c:1808
 #, gcc-internal-format, gfc-internal-format
 msgid ""
 "%s procedure at %L is already declared as %s procedure. \n"
@@ -69485,224 +69574,224 @@
 "F2008: A pointer function assignment is ambiguous if it is the first executable statement after the specification block. Please add any other kind of executable statement before it. FIXME"
 msgstr ""
 
-#: fortran/symbol.c:1802
+#: fortran/symbol.c:1816
 #, gcc-internal-format, gfc-internal-format
 msgid "%s procedure at %L is already declared as %s procedure"
 msgstr "%s yordamı %L'de zaten %s yordamı olarak bildirilmiş"
 
-#: fortran/symbol.c:1837
+#: fortran/symbol.c:1851
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgstr "INTENT (%s) ile INTENT(%s) %L'de çelişiyor"
 
-#: fortran/symbol.c:1861
+#: fortran/symbol.c:1875
 #, gcc-internal-format, gfc-internal-format
 msgid "ACCESS specification at %L was already specified"
 msgstr "ACCESS belirtimi %L'de zaten belirtilmiş"
 
-#: fortran/symbol.c:1878
+#: fortran/symbol.c:1892
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate %s attribute specified at %L"
 msgid "Duplicate BIND attribute specified at %L"
 msgstr "%L'de yinelenen %s özniteliği belirtilmiş"
 
-#: fortran/symbol.c:1885
+#: fortran/symbol.c:1899
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) at %L"
 msgstr ""
 
-#: fortran/symbol.c:1901
+#: fortran/symbol.c:1915
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate SAVE attribute specified at %L"
 msgid "Duplicate EXTENDS attribute specified at %L"
 msgstr "%L'de yinelenen SAVE özniteliği belirtilmiş"
 
-#: fortran/symbol.c:1905
+#: fortran/symbol.c:1919
 #, gcc-internal-format, gfc-internal-format
 msgid "EXTENDS at %L"
 msgstr ""
 
-#: fortran/symbol.c:1931
+#: fortran/symbol.c:1945
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has an explicit interface"
 msgstr "%qs simgesi %L'de zaten bir aleni arayüze sahip"
 
-#: fortran/symbol.c:1938
+#: fortran/symbol.c:1952
 #, gcc-internal-format
 msgid "%qs at %L has attributes specified outside its INTERFACE body"
 msgstr ""
 
-#: fortran/symbol.c:1976
+#: fortran/symbol.c:1990
 #, gcc-internal-format
 msgid "Symbol %qs at %L conflicts with symbol from module %qs, use-associated at %L"
 msgstr ""
 
-#: fortran/symbol.c:1980
+#: fortran/symbol.c:1994
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L already has basic type of %s"
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr "'%s' simgesi %L'de zaten temel %s türünde"
 
-#: fortran/symbol.c:1987
+#: fortran/symbol.c:2001
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L already has basic type of %s"
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr "'%s' simgesi %L'de zaten temel %s türünde"
 
-#: fortran/symbol.c:1999
+#: fortran/symbol.c:2013
 #, gcc-internal-format
 msgid "Symbol %qs at %L cannot have a type"
 msgstr "%qs simgesi (%L'de) bir türe sahip olamaz"
 
-#: fortran/symbol.c:2242
+#: fortran/symbol.c:2256
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C already declared at %L"
 msgid "Component %qs at %C already in the parent type at %L"
 msgstr "'%s' bileşeni (%C'deki) zaten %L'de bildirilmiş"
 
-#: fortran/symbol.c:2327
+#: fortran/symbol.c:2341
 #, gcc-internal-format
 msgid "Symbol %qs at %C is ambiguous"
 msgstr "%qs simgesi %C'de belirsiz"
 
-#: fortran/symbol.c:2359
+#: fortran/symbol.c:2373
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %C is being used before it is defined"
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr "Türetilmiş '%s' türü (%C'deki) tanımından önce kullanılıyor"
 
-#: fortran/symbol.c:2508
+#: fortran/symbol.c:2522
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C is a PRIVATE component of '%s'"
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr "'%s' bileşeni (%C'deki) '%s'nin bir PRIVATE bileşenidir"
 
-#: fortran/symbol.c:2529
+#: fortran/symbol.c:2543
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is not a member of the '%s' structure"
 msgid "%qs at %C is not a member of the %qs structure; did you mean %qs?"
 msgstr "'%s' (%C'deki) '%s' yapısının bir üyesi değil"
 
-#: fortran/symbol.c:2533
+#: fortran/symbol.c:2547
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is not a member of the '%s' structure"
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr "'%s' (%C'deki) '%s' yapısının bir üyesi değil"
 
-#: fortran/symbol.c:2697
+#: fortran/symbol.c:2711
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr " %d yaftası %L ve %L'de yinelenmiş"
 
-#: fortran/symbol.c:2708
+#: fortran/symbol.c:2722
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr "%d yaftası (%C'deki) zaten dallanma hedefi olarak başvurulu"
 
-#: fortran/symbol.c:2718
+#: fortran/symbol.c:2732
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr "%d yaftası (%C'deki) zaten bir biçim yaftası olarak başvurulu"
 
-#: fortran/symbol.c:2724
+#: fortran/symbol.c:2738
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:2766
+#: fortran/symbol.c:2780
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr "%d yaftası (%C'deki) evvelce bir biçim yaftası olarak kullanılmış"
 
-#: fortran/symbol.c:2775
+#: fortran/symbol.c:2789
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr "%d yaftası (%C'deki) evvelce dallanma hedefi olarak kullanılmış"
 
-#: fortran/symbol.c:2781
+#: fortran/symbol.c:2795
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected terminating name at %C"
 msgid "Shared DO termination label %d at %C"
 msgstr "%C'de sonlandıran isim umuluyordu"
 
-#: fortran/symbol.c:3110
+#: fortran/symbol.c:3124
 #, gcc-internal-format
 msgid "new_symbol(): Symbol name too long"
 msgstr ""
 
-#: fortran/symbol.c:3135
+#: fortran/symbol.c:3149
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is an ambiguous reference to '%s' from module '%s'"
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr "'%s' ismi (%C'deki) '%s'e '%s' modülünden belirsiz bir başvurudur"
 
-#: fortran/symbol.c:3138
+#: fortran/symbol.c:3152
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
 msgstr "%qs ismi (%C'deki) şu an ki program biriminden %qs'e belirsiz bir başvurudur"
 
 #. Symbol is from another namespace.
-#: fortran/symbol.c:3381
+#: fortran/symbol.c:3395
 #, gcc-internal-format
 msgid "Symbol %qs at %C has already been host associated"
 msgstr "%qs simgesi (%C'deki) zaten konakla ilişkiliymiş"
 
-#: fortran/symbol.c:4397
+#: fortran/symbol.c:4411
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr ""
 
-#: fortran/symbol.c:4410
+#: fortran/symbol.c:4424
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr "Türetilmiş tür değişkeni '%s' %L'de bir EQUIVALENCE nesnesi olarak SEQUENCE özniteliğine sahip olmalı"
 
-#: fortran/symbol.c:4428
+#: fortran/symbol.c:4442
 #, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr ""
 
-#: fortran/symbol.c:4449
+#: fortran/symbol.c:4463
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgid "Component %qs at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr "Türetilmiş tür değişkeni '%s' %L'de bir EQUIVALENCE nesnesi olarak SEQUENCE özniteliğine sahip olmalı"
 
-#: fortran/symbol.c:4459
+#: fortran/symbol.c:4473
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' requires an argument list at %C"
 msgid "Procedure pointer component %qs at %L cannot be a member of the BIND(C) derived type %qs at %L"
 msgstr "'%s' işlevi %C'de bir argüman listesi gerektiriyor"
 
-#: fortran/symbol.c:4470
+#: fortran/symbol.c:4484
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgid "Component %qs at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr "Türetilmiş tür değişkeni '%s' %L'de bir EQUIVALENCE nesnesi olarak SEQUENCE özniteliğine sahip olmalı"
 
-#: fortran/symbol.c:4509
+#: fortran/symbol.c:4523
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.c:4519
+#: fortran/symbol.c:4533
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/symbol.c:4533
+#: fortran/symbol.c:4547
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot be declared with both PRIVATE and BIND(C) attributes"
 msgstr ""
 
-#: fortran/symbol.c:4541
+#: fortran/symbol.c:4555
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr "Türetilmiş tür değişkeni '%s' %L'de bir EQUIVALENCE nesnesi olarak SEQUENCE özniteliğine sahip olmalı"
 
-#: fortran/symbol.c:5018 fortran/symbol.c:5023
+#: fortran/symbol.c:5032 fortran/symbol.c:5037
 #, gcc-internal-format
 msgid "Symbol %qs is used before it is typed at %L"
 msgstr ""
@@ -69751,7 +69840,7 @@
 msgid "Creating array temporary at %L for argument %qs"
 msgstr ""
 
-#: fortran/trans-array.c:10693
+#: fortran/trans-array.c:10724
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr "yürüyüş sırasında ifade türü hatalı (%d)"
@@ -69981,12 +70070,12 @@
 msgid "%<dim%> argument of %s intrinsic at %L is not a valid dimension index"
 msgstr "`dim' argümanı `%s' yerleşiği için  (%L'de) geçerli bir boyut indisi değil"
 
-#: fortran/trans-intrinsic.c:10572 fortran/trans-stmt.c:1050
+#: fortran/trans-intrinsic.c:10574 fortran/trans-stmt.c:1050
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, the event component of derived type at %L is not yet supported"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:10579
+#: fortran/trans-intrinsic.c:10581
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Complex argument of LOG at %L cannot be zero"
 msgid "The event variable at %L shall not be coindexed"
@@ -70029,7 +70118,7 @@
 msgid "Sorry, only support for integer kind %d implemented for image-set at %L"
 msgstr ""
 
-#: fortran/trans-stmt.c:3346
+#: fortran/trans-stmt.c:3343
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_trans_select(): Bad type for case expr."
@@ -70175,7 +70264,7 @@
 msgid "two or more sections for %s"
 msgstr "%qs bildiriminde iki veya daha fazla veri türü"
 
-#: lto/lto-partition.c:516
+#: lto/lto-partition.c:570
 #, gcc-internal-format
 msgid "min partition size cannot be greater than max partition size"
 msgstr ""
@@ -70331,64 +70420,64 @@
 msgid "Cannot read %s"
 msgstr "%s açılamıyor"
 
-#: lto/lto.c:2369
+#: lto/lto.c:2337
 #, gcc-internal-format
 msgid "lto_obj_file_open() failed"
 msgstr ""
 
-#: lto/lto.c:2394
+#: lto/lto.c:2362
 #, fuzzy, gcc-internal-format
 #| msgid "pex_init failed"
 msgid "waitpid failed"
 msgstr "pex_init başarısız"
 
-#: lto/lto.c:2397
+#: lto/lto.c:2365
 #, fuzzy, gcc-internal-format
 #| msgid "renaming .rpo file"
 msgid "streaming subprocess failed"
 msgstr "rpo dosyasının ismi değiştiriliyor"
 
-#: lto/lto.c:2400
+#: lto/lto.c:2368
 #, gcc-internal-format
 msgid "streaming subprocess was killed by signal"
 msgstr ""
 
-#: lto/lto.c:2476
+#: lto/lto.c:2445
 #, gcc-internal-format
 msgid "no LTRANS output list filename provided"
 msgstr ""
 
-#: lto/lto.c:2564
+#: lto/lto.c:2525
 #, fuzzy, gcc-internal-format
 #| msgid "opening output file %s: %m"
 msgid "opening LTRANS output list %s: %m"
 msgstr "`%s' çıktı dosyasının açılması: %m"
 
-#: lto/lto.c:2570
+#: lto/lto.c:2532
 #, fuzzy, gcc-internal-format
 #| msgid "when writing output to %s: %m"
 msgid "writing to LTRANS output list %s: %m"
 msgstr "çıktı %s e yazılırken: %m"
 
-#: lto/lto.c:2581
+#: lto/lto.c:2542
 #, fuzzy, gcc-internal-format
 #| msgid "opening output file %s: %m"
 msgid "closing LTRANS output list %s: %m"
 msgstr "`%s' çıktı dosyasının açılması: %m"
 
-#: lto/lto.c:2833
+#: lto/lto.c:2794
 #, fuzzy, gcc-internal-format
 #| msgid "%s:could not open output file '%s'\n"
 msgid "could not open symbol resolution file: %m"
 msgstr "%s: çıktı dosyası '%s' açılamadı\n"
 
-#: lto/lto.c:2954
+#: lto/lto.c:2915
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing braces around initializer for %qT"
 msgid "missing resolution data for %s"
 msgstr "%qT için ilklendiriciyi çevreleyen parantezler yok"
 
-#: lto/lto.c:2986
+#: lto/lto.c:2947
 #, gcc-internal-format
 msgid "errors during merging of translation units"
 msgstr ""
@@ -71825,6 +71914,9 @@
 #~ msgid "Set the target VM version"
 #~ msgstr "Hedef işlemcinin türü belirtilir"
 
+#~ msgid "Warn if the loop cannot be optimized due to nontrivial assumptions."
+#~ msgstr "Önemsiz olmayan varsayımlardan dolayı döngü eniyilenemezse uyarır"
+
 #~ msgid "Perform DWARF2 duplicate elimination"
 #~ msgstr "DWARF2 yinelenmiş elemesi uygulanır"
 
@@ -72833,6 +72925,11 @@
 #~ msgstr "%C'deki gösterici ilklendirmesi bir '=>' gerektirir, '=' değil"
 
 #, fuzzy
+#~| msgid "UNIT specification at %L must be an INTEGER expression or a CHARACTER variable"
+#~ msgid "Errmsg-variable at %L must be a scalar CHARACTER variable"
+#~ msgstr "%L'deki UNIT belirtimi ya bir INTEGER ifadesi ya da bir CHARACTER değişkeni olmalıdır"
+
+#, fuzzy
 #~| msgid "%s attribute conflicts with %s attribute at %L"
 #~ msgid "%s attribute with %s attribute at %L"
 #~ msgstr "%s özniteliği ile %s özniteliği %L'de çelişiyor"
Index: gcc/po/be.po
===================================================================
--- gcc/po/be.po	(.../tags/gcc_8_2_0_release)
+++ gcc/po/be.po	(.../branches/gcc-8-branch)
@@ -6,7 +6,7 @@
 msgstr ""
 "Project-Id-Version: gcc 3.1\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2018-05-01 20:30+0000\n"
+"POT-Creation-Date: 2018-07-25 14:25+0000\n"
 "PO-Revision-Date: 2002-05-17 15:54+0200\n"
 "Last-Translator: Ales Nyakhaychyk <nyakhaychyk@i18n.linux.by>\n"
 "Language-Team: Belarusian <i18n@tut.by>\n"
@@ -37,13 +37,13 @@
 msgid "[cannot find %s]"
 msgstr "[нельга знайсці %s]"
 
-#: collect2.c:1557
+#: collect2.c:1585
 #, fuzzy, c-format
 #| msgid "gcc version %s\n"
 msgid "collect2 version %s\n"
 msgstr "версія gcc %s\n"
 
-#: collect2.c:1664
+#: collect2.c:1692
 #, fuzzy, c-format
 #| msgid "%d constructor(s) found\n"
 msgid "%d constructor found\n"
@@ -51,7 +51,7 @@
 msgstr[0] "%d канструктар(аў) знойдзен(а)\n"
 msgstr[1] "%d канструктар(аў) знойдзен(а)\n"
 
-#: collect2.c:1668
+#: collect2.c:1696
 #, fuzzy, c-format
 #| msgid "%d destructor(s)  found\n"
 msgid "%d destructor found\n"
@@ -59,7 +59,7 @@
 msgstr[0] "%d дэструктар(аў) знойдзен(а)\n"
 msgstr[1] "%d дэструктар(аў) знойдзен(а)\n"
 
-#: collect2.c:1672
+#: collect2.c:1700
 #, c-format
 msgid "%d frame table found\n"
 msgid_plural "%d frame tables found\n"
@@ -66,12 +66,12 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: collect2.c:1836
+#: collect2.c:1864
 #, c-format
 msgid "[Leaving %s]\n"
 msgstr ""
 
-#: collect2.c:2068
+#: collect2.c:2094
 #, c-format
 msgid ""
 "\n"
@@ -78,7 +78,7 @@
 "write_c_file - output name is %s, prefix is %s\n"
 msgstr ""
 
-#: collect2.c:2584
+#: collect2.c:2610
 #, c-format
 msgid ""
 "\n"
@@ -99,7 +99,7 @@
 msgid "%s: some warnings being treated as errors"
 msgstr ""
 
-#: diagnostic.c:324 input.c:222 input.c:1834 c-family/c-opts.c:1377
+#: diagnostic.c:324 input.c:222 input.c:1834 c-family/c-opts.c:1392
 #: fortran/cpp.c:576 fortran/error.c:1008 fortran/error.c:1028
 msgid "<built-in>"
 msgstr ""
@@ -193,13 +193,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:4164 config/arc/arc.c:5784 config/i386/i386.c:17302
+#: final.c:4164 config/arc/arc.c:5775 config/i386/i386.c:17305
 #: config/pdp11/pdp11.c:1715
 #, c-format
 msgid "floating constant misused"
 msgstr ""
 
-#: final.c:4222 config/arc/arc.c:5881 config/i386/i386.c:17393
+#: final.c:4222 config/arc/arc.c:5872 config/i386/i386.c:17396
 #: config/pdp11/pdp11.c:1756
 #, c-format
 msgid "invalid expression as operand"
@@ -1100,7 +1100,7 @@
 msgid "GCSE disabled"
 msgstr ""
 
-#: gimple-ssa-isolate-paths.c:542 c/c-typeck.c:10240
+#: gimple-ssa-isolate-paths.c:542 c/c-typeck.c:10245
 #, gcc-internal-format
 msgid "function returns address of local variable"
 msgstr ""
@@ -1413,7 +1413,7 @@
 msgid "options enabled: "
 msgstr "выбары ўключаны:"
 
-#: tree-diagnostic.c:299 c/c-decl.c:5419 c/c-typeck.c:7259 cp/error.c:1042
+#: tree-diagnostic.c:299 c/c-decl.c:5439 c/c-typeck.c:7264 cp/error.c:1042
 #: c-family/c-pretty-print.c:413
 #, gcc-internal-format
 msgid "<anonymous>"
@@ -2916,67 +2916,67 @@
 msgstr ""
 
 #. Handle deferred options from command-line.
-#: c-family/c-opts.c:1402 fortran/cpp.c:590
+#: c-family/c-opts.c:1417 fortran/cpp.c:590
 msgid "<command-line>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6613
+#: config/aarch64/aarch64.c:6629
 #, fuzzy, c-format
 msgid "unsupported operand for code '%c'"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: config/aarch64/aarch64.c:6624 config/aarch64/aarch64.c:6640
-#: config/aarch64/aarch64.c:6652 config/aarch64/aarch64.c:6663
-#: config/aarch64/aarch64.c:6673 config/aarch64/aarch64.c:6694
-#: config/aarch64/aarch64.c:6764 config/aarch64/aarch64.c:6775
-#: config/aarch64/aarch64.c:6789 config/aarch64/aarch64.c:7011
-#: config/aarch64/aarch64.c:7029
+#: config/aarch64/aarch64.c:6640 config/aarch64/aarch64.c:6656
+#: config/aarch64/aarch64.c:6668 config/aarch64/aarch64.c:6679
+#: config/aarch64/aarch64.c:6689 config/aarch64/aarch64.c:6710
+#: config/aarch64/aarch64.c:6780 config/aarch64/aarch64.c:6791
+#: config/aarch64/aarch64.c:6805 config/aarch64/aarch64.c:7027
+#: config/aarch64/aarch64.c:7045
 #, fuzzy, c-format
 msgid "invalid operand for '%%%c'"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: config/aarch64/aarch64.c:6709 config/aarch64/aarch64.c:6720
-#: config/aarch64/aarch64.c:6871 config/aarch64/aarch64.c:6882
+#: config/aarch64/aarch64.c:6725 config/aarch64/aarch64.c:6736
+#: config/aarch64/aarch64.c:6887 config/aarch64/aarch64.c:6898
 #, fuzzy, c-format
 #| msgid "invalid string constant `%E'"
 msgid "invalid vector constant"
 msgstr "`%E' - нерэчаісная нязьменная тыпу string"
 
-#: config/aarch64/aarch64.c:6732 config/aarch64/aarch64.c:6744
-#: config/aarch64/aarch64.c:6755
+#: config/aarch64/aarch64.c:6748 config/aarch64/aarch64.c:6760
+#: config/aarch64/aarch64.c:6771
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6823 config/arm/arm.c:22704
+#: config/aarch64/aarch64.c:6839 config/arm/arm.c:22704
 #, fuzzy, c-format
 msgid "missing operand"
 msgstr "прапушчан ініцыялізатар"
 
-#: config/aarch64/aarch64.c:6908
+#: config/aarch64/aarch64.c:6924
 #, fuzzy, c-format
 msgid "invalid constant"
 msgstr "Нерэчаісны выбар %s"
 
-#: config/aarch64/aarch64.c:6911
+#: config/aarch64/aarch64.c:6927
 #, fuzzy, c-format
 #| msgid "invalid %%d operand"
 msgid "invalid operand"
 msgstr "нерэчаісны %%d аперанд"
 
-#: config/aarch64/aarch64.c:7040 config/aarch64/aarch64.c:7045
+#: config/aarch64/aarch64.c:7056 config/aarch64/aarch64.c:7061
 #, fuzzy, c-format
 msgid "invalid operand prefix '%%%c'"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: config/aarch64/aarch64.c:7062
+#: config/aarch64/aarch64.c:7078
 #, fuzzy, c-format
 #| msgid "invalid address"
 msgid "invalid address mode"
 msgstr "нерэчаісны адрас"
 
-#: config/alpha/alpha.c:5125 config/i386/i386.c:18558
-#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21798
+#: config/alpha/alpha.c:5125 config/i386/i386.c:18561
+#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21875
 #: config/sparc/sparc.c:9290
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
@@ -2993,7 +2993,7 @@
 msgstr "нерэчаіснае значэньне %%r"
 
 #: config/alpha/alpha.c:5223 config/ia64/ia64.c:5534
-#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21506
+#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21583
 #: config/xtensa/xtensa.c:2429
 #, c-format
 msgid "invalid %%R value"
@@ -3000,13 +3000,13 @@
 msgstr "нерэчаіснае значэньне %%R"
 
 #: config/alpha/alpha.c:5229 config/powerpcspe/powerpcspe.c:23933
-#: config/rs6000/rs6000.c:21426 config/xtensa/xtensa.c:2396
+#: config/rs6000/rs6000.c:21503 config/xtensa/xtensa.c:2396
 #, c-format
 msgid "invalid %%N value"
 msgstr "нерэчаіснае значэньне %%N"
 
 #: config/alpha/alpha.c:5237 config/powerpcspe/powerpcspe.c:23961
-#: config/rs6000/rs6000.c:21454
+#: config/rs6000/rs6000.c:21531
 #, c-format
 msgid "invalid %%P value"
 msgstr "нерэчаіснае значэньне %%P"
@@ -3037,7 +3037,7 @@
 msgstr "нерэчаіснае значэньне %%U"
 
 #: config/alpha/alpha.c:5323 config/powerpcspe/powerpcspe.c:24021
-#: config/rs6000/rs6000.c:21514
+#: config/rs6000/rs6000.c:21591
 #, c-format
 msgid "invalid %%s value"
 msgstr "нерэчаіснае значэньне %%v"
@@ -3048,7 +3048,7 @@
 msgstr "нерэчаіснае значэньне %%C"
 
 #: config/alpha/alpha.c:5371 config/powerpcspe/powerpcspe.c:23797
-#: config/rs6000/rs6000.c:21290
+#: config/rs6000/rs6000.c:21367
 #, c-format
 msgid "invalid %%E value"
 msgstr "нерэчаіснае значэньне %%E"
@@ -3059,7 +3059,7 @@
 msgstr ""
 
 #: config/alpha/alpha.c:5405 config/cr16/cr16.c:1569
-#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21803
+#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21880
 #: config/spu/spu.c:1458
 #, c-format
 msgid "invalid %%xn code"
@@ -3071,57 +3071,57 @@
 msgid "invalid operand address"
 msgstr "нерэчаісны адрас"
 
-#: config/arc/arc.c:3810
+#: config/arc/arc.c:3808
 #, fuzzy, c-format
 msgid "invalid operand to %%Z code"
 msgstr "нерэчаісны %%-код"
 
-#: config/arc/arc.c:3818
+#: config/arc/arc.c:3816
 #, fuzzy, c-format
 msgid "invalid operand to %%z code"
 msgstr "нерэчаісны %%-код"
 
-#: config/arc/arc.c:3826
+#: config/arc/arc.c:3824
 #, fuzzy, c-format
 msgid "invalid operands to %%c code"
 msgstr "нерэчаісны %%-код"
 
-#: config/arc/arc.c:3834
+#: config/arc/arc.c:3832
 #, fuzzy, c-format
 msgid "invalid operand to %%M code"
 msgstr "нерэчаісны %%-код"
 
-#: config/arc/arc.c:3842 config/m32r/m32r.c:2100
+#: config/arc/arc.c:3840 config/m32r/m32r.c:2100
 #, fuzzy, c-format
 msgid "invalid operand to %%p code"
 msgstr "нерэчаісны %%-код"
 
-#: config/arc/arc.c:3853 config/m32r/m32r.c:2093
+#: config/arc/arc.c:3851 config/m32r/m32r.c:2093
 #, fuzzy, c-format
 msgid "invalid operand to %%s code"
 msgstr "нерэчаісны %%-код"
 
-#: config/arc/arc.c:4001 config/m32r/m32r.c:2126
+#: config/arc/arc.c:3999 config/m32r/m32r.c:2126
 #, fuzzy, c-format
 msgid "invalid operand to %%R code"
 msgstr "нерэчаісны %%-код"
 
-#: config/arc/arc.c:4077 config/m32r/m32r.c:2149
+#: config/arc/arc.c:4075 config/m32r/m32r.c:2149
 #, fuzzy, c-format
 msgid "invalid operand to %%H/%%L code"
 msgstr "нерэчаісны %%-код"
 
-#: config/arc/arc.c:4145 config/m32r/m32r.c:2220
+#: config/arc/arc.c:4143 config/m32r/m32r.c:2220
 #, fuzzy, c-format
 msgid "invalid operand to %%U code"
 msgstr "нерэчаісны %%-код"
 
-#: config/arc/arc.c:4157
+#: config/arc/arc.c:4155
 #, fuzzy, c-format
 msgid "invalid operand to %%V code"
 msgstr "нерэчаісны %%-код"
 
-#: config/arc/arc.c:4214
+#: config/arc/arc.c:4212
 #, fuzzy, c-format
 msgid "invalid operand to %%O code"
 msgstr "нерэчаісны %%-код"
@@ -3128,18 +3128,18 @@
 
 #. Unknown flag.
 #. Undocumented flag.
-#: config/arc/arc.c:4240 config/epiphany/epiphany.c:1305
-#: config/m32r/m32r.c:2247 config/nds32/nds32.c:3079 config/sparc/sparc.c:9569
+#: config/arc/arc.c:4238 config/epiphany/epiphany.c:1305
+#: config/m32r/m32r.c:2247 config/nds32/nds32.c:3080 config/sparc/sparc.c:9569
 #, c-format
 msgid "invalid operand output code"
 msgstr ""
 
-#: config/arc/arc.c:5869
+#: config/arc/arc.c:5860
 #, fuzzy, c-format
 msgid "invalid UNSPEC as operand: %d"
 msgstr "нерэчаісны %%-код"
 
-#: config/arc/arc.c:6158 config/cris/cris.c:2568
+#: config/arc/arc.c:6149 config/cris/cris.c:2568
 #, fuzzy
 msgid "unrecognized supposed constant"
 msgstr "нераспазнаны выбар \"-%s\""
@@ -3176,7 +3176,7 @@
 #: config/arm/arm.c:22685 config/arm/arm.c:22692 config/bfin/bfin.c:1441
 #: config/bfin/bfin.c:1448 config/bfin/bfin.c:1455 config/bfin/bfin.c:1462
 #: config/bfin/bfin.c:1471 config/bfin/bfin.c:1478 config/bfin/bfin.c:1485
-#: config/bfin/bfin.c:1492 config/nds32/nds32.c:3098
+#: config/bfin/bfin.c:1492 config/nds32/nds32.c:3099
 #, fuzzy, c-format
 msgid "invalid operand for code '%c'"
 msgstr "Нерэчаісны выбар \"%s\""
@@ -3526,100 +3526,100 @@
 msgid "bad output_condmove_single operand"
 msgstr ""
 
-#: config/i386/i386.c:17387
+#: config/i386/i386.c:17390
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr ""
 
-#: config/i386/i386.c:17925
+#: config/i386/i386.c:17928
 #, fuzzy, c-format
 #| msgid "invalid use of `restrict'"
 msgid "invalid use of register '%s'"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: config/i386/i386.c:17930
+#: config/i386/i386.c:17933
 #, fuzzy, c-format
 #| msgid "invalid use of `restrict'"
 msgid "invalid use of asm flag output"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: config/i386/i386.c:18160
+#: config/i386/i386.c:18163
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr "нерэчаісны %%-код"
 
-#: config/i386/i386.c:18195
+#: config/i386/i386.c:18198
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr "нерэчаісны %%-код"
 
-#: config/i386/i386.c:18264
+#: config/i386/i386.c:18267
 #, fuzzy, c-format
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "нерэчаісны %%-код"
 
-#: config/i386/i386.c:18269
+#: config/i386/i386.c:18272
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'Z'"
 msgstr "нерэчаісны %%-код"
 
-#: config/i386/i386.c:18346
+#: config/i386/i386.c:18349
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr ""
 
-#: config/i386/i386.c:18425
+#: config/i386/i386.c:18428
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr ""
 
-#: config/i386/i386.c:18443
+#: config/i386/i386.c:18446
 #, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr ""
 
-#: config/i386/i386.c:18456
+#: config/i386/i386.c:18459
 #, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr ""
 
-#: config/i386/i386.c:18471
+#: config/i386/i386.c:18474
 #, c-format
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr ""
 
-#: config/i386/i386.c:18499
+#: config/i386/i386.c:18502
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr ""
 
-#: config/i386/i386.c:18517
+#: config/i386/i386.c:18520
 #, c-format
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr ""
 
-#: config/i386/i386.c:18540
+#: config/i386/i386.c:18543
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr ""
 
-#: config/i386/i386.c:18626
+#: config/i386/i386.c:18629
 #, fuzzy, c-format
 msgid "invalid operand code '%c'"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: config/i386/i386.c:18688
+#: config/i386/i386.c:18691
 #, fuzzy, c-format
 #| msgid "invalid %%c operand"
 msgid "invalid constraints for operand"
 msgstr "нерэчаісны %%c аперанд"
 
-#: config/i386/i386.c:18738
+#: config/i386/i386.c:18741
 #, fuzzy, c-format
 msgid "invalid vector immediate"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: config/i386/i386.c:29572
+#: config/i386/i386.c:29575
 #, fuzzy
 msgid "unknown insn mode"
 msgstr "невядомы рэжым машыны \"%s\""
@@ -3663,7 +3663,7 @@
 msgstr "нерэчаісны %%-код"
 
 #: config/iq2000/iq2000.c:3185 config/powerpcspe/powerpcspe.c:23951
-#: config/rs6000/rs6000.c:21444
+#: config/rs6000/rs6000.c:21521
 #, c-format
 msgid "invalid %%p value"
 msgstr ""
@@ -3719,7 +3719,7 @@
 msgstr ""
 
 #: config/m32r/m32r.c:2350 config/m32r/m32r.c:2365
-#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33292
+#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33348
 msgid "bad address"
 msgstr "дрэнны адрас"
 
@@ -3844,129 +3844,129 @@
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4411 config/rs6000/rs6000.c:4258
+#: config/powerpcspe/powerpcspe.c:4411 config/rs6000/rs6000.c:4278
 msgid "-maltivec=le not allowed for big-endian targets"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4423 config/rs6000/rs6000.c:4273
+#: config/powerpcspe/powerpcspe.c:4423 config/rs6000/rs6000.c:4293
 #, fuzzy
 #| msgid "Use hardware floating point"
 msgid "-mvsx requires hardware floating point"
 msgstr "Выкарыстоўваць апаратную \"плаваючую кропку\""
 
-#: config/powerpcspe/powerpcspe.c:4431 config/rs6000/rs6000.c:4281
+#: config/powerpcspe/powerpcspe.c:4431 config/rs6000/rs6000.c:4301
 msgid "-mvsx and -mpaired are incompatible"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4433 config/rs6000/rs6000.c:4283
+#: config/powerpcspe/powerpcspe.c:4433 config/rs6000/rs6000.c:4303
 msgid "-mvsx needs indexed addressing"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4438 config/rs6000/rs6000.c:4288
+#: config/powerpcspe/powerpcspe.c:4438 config/rs6000/rs6000.c:4308
 msgid "-mvsx and -mno-altivec are incompatible"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4440 config/rs6000/rs6000.c:4290
+#: config/powerpcspe/powerpcspe.c:4440 config/rs6000/rs6000.c:4310
 msgid "-mno-altivec disables vsx"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4648 config/rs6000/rs6000.c:4416
+#: config/powerpcspe/powerpcspe.c:4648 config/rs6000/rs6000.c:4436
 msgid "-mquad-memory requires 64-bit mode"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4651 config/rs6000/rs6000.c:4419
+#: config/powerpcspe/powerpcspe.c:4651 config/rs6000/rs6000.c:4439
 msgid "-mquad-memory-atomic requires 64-bit mode"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4663 config/rs6000/rs6000.c:4431
+#: config/powerpcspe/powerpcspe.c:4663 config/rs6000/rs6000.c:4451
 msgid "-mquad-memory is not available in little endian mode"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4735 config/rs6000/rs6000.c:4512
+#: config/powerpcspe/powerpcspe.c:4735 config/rs6000/rs6000.c:4532
 msgid "-mtoc-fusion requires 64-bit"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4742 config/rs6000/rs6000.c:4519
+#: config/powerpcspe/powerpcspe.c:4742 config/rs6000/rs6000.c:4539
 msgid "-mtoc-fusion requires medium/large code model"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10915
+#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10947
 msgid "bad move"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21087
+#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21164
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21278
+#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21355
 #, fuzzy, c-format
 #| msgid "invalid %%Q value"
 msgid "invalid %%e value"
 msgstr "дрэннае %%Q значэнне"
 
-#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21299
+#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21376
 #, c-format
 msgid "invalid %%f value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21308
+#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21385
 #, c-format
 msgid "invalid %%F value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21317
+#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21394
 #, c-format
 msgid "invalid %%G value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21352
+#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21429
 #, c-format
 msgid "invalid %%j code"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21362
+#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21439
 #, c-format
 msgid "invalid %%J code"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21372
+#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21449
 #, c-format
 msgid "invalid %%k value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21387
+#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21464
 #: config/xtensa/xtensa.c:2415
 #, c-format
 msgid "invalid %%K value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21434
+#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21511
 #, c-format
 msgid "invalid %%O value"
 msgstr "нерэчаіснае значэньне %%O"
 
-#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21481
+#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21558
 #, c-format
 msgid "invalid %%q value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21534
+#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21611
 #, c-format
 msgid "invalid %%T value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21546
+#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21623
 #, c-format
 msgid "invalid %%u value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21560
+#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21637
 #: config/xtensa/xtensa.c:2384
 #, c-format
 msgid "invalid %%v value"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21627
+#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21704
 #: config/xtensa/xtensa.c:2436
 #, fuzzy, c-format
 #| msgid "invalid %%x/X value"
@@ -3973,63 +3973,63 @@
 msgid "invalid %%x value"
 msgstr "нерэчаіснае значэньне %%x/X"
 
-#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21747
+#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21824
 #, fuzzy, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22282
+#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22359
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22288
+#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22365
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22294
+#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22371
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36572
+#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36628
 #, fuzzy
 #| msgid "too few arguments to function"
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "не хапае аргументаў у функцыі"
 
-#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38739
+#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38795
 #, fuzzy
 msgid "Could not generate addis value for fusion"
 msgstr "Стварыць код для DLL"
 
-#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38809
+#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38865
 msgid "Unable to generate load/store offset for fusion"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38908
+#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38964
 msgid "Bad GPR fusion"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39126
+#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39182
 msgid "emit_fusion_p9_load, bad reg #1"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39172
+#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39228
 msgid "emit_fusion_p9_load, bad reg #2"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39175
+#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39231
 msgid "emit_fusion_p9_load not MEM"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39213
+#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39269
 msgid "emit_fusion_p9_store, bad reg #1"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39259
+#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39315
 msgid "emit_fusion_p9_store, bad reg #2"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39262
+#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39318
 msgid "emit_fusion_p9_store not MEM"
 msgstr ""
 
@@ -4414,14 +4414,14 @@
 #: c/gimple-parser.c:188 c/gimple-parser.c:197 c/gimple-parser.c:226
 #: c/gimple-parser.c:1375 c/gimple-parser.c:1404 c/gimple-parser.c:1484
 #: c/gimple-parser.c:1511 c/c-parser.c:3204 c/c-parser.c:9967
-#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27841
-#: cp/parser.c:28430
+#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27838
+#: cp/parser.c:28427
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr ""
 
 #: c/c-parser.c:2431 c/c-parser.c:7573 c/c-parser.c:8015 c/c-parser.c:8058
-#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27839 cp/parser.c:28448
+#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27836 cp/parser.c:28445
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr ""
@@ -4436,7 +4436,7 @@
 #: c/gimple-parser.c:821 c/gimple-parser.c:837 c/gimple-parser.c:853
 #: c/gimple-parser.c:880 c/gimple-parser.c:915 c/gimple-parser.c:1038
 #: c/gimple-parser.c:1209 c/gimple-parser.c:1220 c/gimple-parser.c:1342
-#: c/gimple-parser.c:1441 cp/parser.c:28478
+#: c/gimple-parser.c:1441 cp/parser.c:28475
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr ""
@@ -4444,7 +4444,7 @@
 #: c/c-parser.c:3824 c/c-parser.c:4733 c/c-parser.c:4769 c/c-parser.c:6441
 #: c/c-parser.c:8125 c/c-parser.c:8983 c/c-parser.c:9127 c/c-parser.c:11588
 #: c/c-parser.c:18220 c/c-parser.c:18222 c/gimple-parser.c:1015
-#: cp/parser.c:28442
+#: cp/parser.c:28439
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr ""
@@ -4458,7 +4458,7 @@
 #: c/c-parser.c:17792 c/gimple-parser.c:363 c/gimple-parser.c:811
 #: c/gimple-parser.c:873 c/gimple-parser.c:911 c/gimple-parser.c:1198
 #: c/gimple-parser.c:1339 c/gimple-parser.c:1438 c/c-parser.c:11911
-#: cp/parser.c:28433
+#: cp/parser.c:28430
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr ""
@@ -4465,7 +4465,7 @@
 
 #: c/c-parser.c:4903 c/c-parser.c:10310 c/c-parser.c:16212 c/c-parser.c:18449
 #: c/gimple-parser.c:141 c/gimple-parser.c:1444 c/c-parser.c:3018
-#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18155 cp/parser.c:28439
+#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18152 cp/parser.c:28436
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr ""
@@ -4475,13 +4475,13 @@
 #: c/c-parser.c:12351 c/c-parser.c:12493 c/c-parser.c:12864 c/c-parser.c:12957
 #: c/c-parser.c:13566 c/c-parser.c:17636 c/c-parser.c:17695
 #: c/gimple-parser.c:431 c/gimple-parser.c:1492 c/gimple-parser.c:1519
-#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28472 cp/parser.c:29597
-#: cp/parser.c:32279
+#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28469 cp/parser.c:29594
+#: cp/parser.c:32276
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr ""
 
-#: c/c-parser.c:5974 cp/parser.c:28365
+#: c/c-parser.c:5974 cp/parser.c:28362
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr ""
@@ -4490,18 +4490,18 @@
 msgid "expected %<.%>"
 msgstr ""
 
-#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30172
-#: cp/parser.c:30246
+#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30169
+#: cp/parser.c:30243
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr ""
 
-#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28457
+#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28454
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr ""
 
-#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28481
+#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28478
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr ""
@@ -4509,32 +4509,32 @@
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15190 c/c-parser.c:15234 c/c-parser.c:15466 c/c-parser.c:15701
 #: c/c-parser.c:17833 c/gimple-parser.c:286 c/c-parser.c:4792
-#: cp/parser.c:28460
+#: cp/parser.c:28457
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr ""
 
-#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28436
-#: cp/parser.c:30389
+#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28433
+#: cp/parser.c:30386
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr ""
 
-#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35674
+#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35671
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr ""
 
-#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28445 cp/parser.c:31535
+#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28442 cp/parser.c:31532
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr ""
 
-#: c/c-typeck.c:7847
+#: c/c-typeck.c:7852
 msgid "(anonymous)"
 msgstr ""
 
-#: c/gimple-parser.c:795 cp/parser.c:15791 cp/parser.c:28454
+#: c/gimple-parser.c:795 cp/parser.c:15788 cp/parser.c:28451
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr ""
@@ -4808,11 +4808,11 @@
 msgid "%r%s:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr ""
 
-#: cp/pt.c:1949 cp/semantics.c:5268
+#: cp/pt.c:1949 cp/semantics.c:5271
 msgid "candidates are:"
 msgstr ""
 
-#: cp/pt.c:1951 cp/pt.c:22975
+#: cp/pt.c:1951 cp/pt.c:23053
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] ""
@@ -4863,27 +4863,27 @@
 msgid "source type is not polymorphic"
 msgstr ""
 
-#: cp/typeck.c:6083 c/c-typeck.c:4261
+#: cp/typeck.c:6083 c/c-typeck.c:4266
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr ""
 
-#: cp/typeck.c:6084 c/c-typeck.c:4248
+#: cp/typeck.c:6084 c/c-typeck.c:4253
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr ""
 
-#: cp/typeck.c:6111 c/c-typeck.c:4302
+#: cp/typeck.c:6111 c/c-typeck.c:4307
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr ""
 
-#: cp/typeck.c:6128 c/c-typeck.c:4310
+#: cp/typeck.c:6128 c/c-typeck.c:4315
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr ""
 
-#: cp/typeck.c:6140 c/c-typeck.c:4322
+#: cp/typeck.c:6140 c/c-typeck.c:4327
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr ""
@@ -5127,75 +5127,75 @@
 msgid "Expected attribute bit name"
 msgstr ""
 
-#: fortran/module.c:3223
+#: fortran/module.c:3225
 msgid "Expected integer string"
 msgstr ""
 
-#: fortran/module.c:3227
+#: fortran/module.c:3229
 msgid "Error converting integer"
 msgstr ""
 
-#: fortran/module.c:3249
+#: fortran/module.c:3251
 msgid "Expected real string"
 msgstr ""
 
-#: fortran/module.c:3474
+#: fortran/module.c:3476
 msgid "Expected expression type"
 msgstr ""
 
-#: fortran/module.c:3554
+#: fortran/module.c:3556
 #, fuzzy
 #| msgid "invalid declarator"
 msgid "Bad operator"
 msgstr "нерэчаісны абвяшчальнік"
 
-#: fortran/module.c:3671
+#: fortran/module.c:3673
 msgid "Bad type in constant expression"
 msgstr ""
 
-#: fortran/module.c:7038
+#: fortran/module.c:7040
 msgid "Unexpected end of module"
 msgstr ""
 
-#: fortran/parse.c:1757
+#: fortran/parse.c:1761
 msgid "arithmetic IF"
 msgstr ""
 
-#: fortran/parse.c:1766
+#: fortran/parse.c:1770
 #, fuzzy
 #| msgid "Invalid declaration"
 msgid "attribute declaration"
 msgstr "Нерэчаіснае абвяшчэнне"
 
-#: fortran/parse.c:1802
+#: fortran/parse.c:1806
 #, fuzzy
 #| msgid "empty declaration"
 msgid "data declaration"
 msgstr "пустое абвяшчэньне"
 
-#: fortran/parse.c:1820
+#: fortran/parse.c:1824
 #, fuzzy
 #| msgid "empty declaration"
 msgid "derived type declaration"
 msgstr "пустое абвяшчэньне"
 
-#: fortran/parse.c:1947
+#: fortran/parse.c:1951
 msgid "block IF"
 msgstr ""
 
-#: fortran/parse.c:1956
+#: fortran/parse.c:1960
 msgid "implied END DO"
 msgstr ""
 
-#: fortran/parse.c:2050 fortran/resolve.c:11199
+#: fortran/parse.c:2054 fortran/resolve.c:11219
 msgid "assignment"
 msgstr ""
 
-#: fortran/parse.c:2053 fortran/resolve.c:11250 fortran/resolve.c:11253
+#: fortran/parse.c:2057 fortran/resolve.c:11270 fortran/resolve.c:11273
 msgid "pointer assignment"
 msgstr ""
 
-#: fortran/parse.c:2071
+#: fortran/parse.c:2075
 msgid "simple IF"
 msgstr ""
 
@@ -5307,106 +5307,111 @@
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:3878
+#: fortran/resolve.c:3879
 #, c-format
+msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
+msgstr ""
+
+#: fortran/resolve.c:3884
+#, c-format
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3893
+#: fortran/resolve.c:3899
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3926
+#: fortran/resolve.c:3932
 #, c-format
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3949
+#: fortran/resolve.c:3955
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:3963
+#: fortran/resolve.c:3969
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr ""
 
-#: fortran/resolve.c:4015
+#: fortran/resolve.c:4021
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr ""
 
-#: fortran/resolve.c:4021
+#: fortran/resolve.c:4027
 #, c-format
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4034
+#: fortran/resolve.c:4040
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L; did you mean '%s'?"
 msgstr ""
 
-#: fortran/resolve.c:4037
+#: fortran/resolve.c:4043
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr ""
 
-#: fortran/resolve.c:4040
+#: fortran/resolve.c:4046
 #, c-format
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:4044
+#: fortran/resolve.c:4050
 #, c-format
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4132
+#: fortran/resolve.c:4138
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr ""
 
-#: fortran/resolve.c:6849
+#: fortran/resolve.c:6855
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.c:6853
+#: fortran/resolve.c:6859
 msgid "iterator variable"
 msgstr ""
 
-#: fortran/resolve.c:6857
+#: fortran/resolve.c:6863
 msgid "Start expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:6861
+#: fortran/resolve.c:6867
 msgid "End expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:6865
+#: fortran/resolve.c:6871
 msgid "Step expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:7150 fortran/resolve.c:7153
+#: fortran/resolve.c:7156 fortran/resolve.c:7159
 msgid "DEALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.c:7525 fortran/resolve.c:7528
+#: fortran/resolve.c:7531 fortran/resolve.c:7534
 msgid "ALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.c:7720 fortran/resolve.c:9417
+#: fortran/resolve.c:7726 fortran/resolve.c:9428
 msgid "STAT variable"
 msgstr ""
 
-#: fortran/resolve.c:7764 fortran/resolve.c:9429
+#: fortran/resolve.c:7770 fortran/resolve.c:9440
 msgid "ERRMSG variable"
 msgstr ""
 
-#: fortran/resolve.c:9219
+#: fortran/resolve.c:9230
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.c:9441
+#: fortran/resolve.c:9452
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
@@ -5439,7 +5444,7 @@
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:10154
+#: fortran/trans-expr.c:10157
 msgid "Assignment of scalar to unallocated array"
 msgstr ""
 
@@ -5448,12 +5453,12 @@
 msgid "Unequal character lengths (%ld/%ld) in %s"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:8088
+#: fortran/trans-intrinsic.c:8090
 #, c-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative (its value is %ld)"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:8120
+#: fortran/trans-intrinsic.c:8122
 msgid "Argument NCOPIES of REPEAT intrinsic is too large"
 msgstr ""
 
@@ -5474,15 +5479,15 @@
 msgid "Invalid image number %d in SYNC IMAGES"
 msgstr ""
 
-#: fortran/trans-stmt.c:2180
+#: fortran/trans-stmt.c:2177
 msgid "Loop iterates infinitely"
 msgstr ""
 
-#: fortran/trans-stmt.c:2200 fortran/trans-stmt.c:2456
+#: fortran/trans-stmt.c:2197 fortran/trans-stmt.c:2453
 msgid "Loop variable has been modified"
 msgstr ""
 
-#: fortran/trans-stmt.c:2309
+#: fortran/trans-stmt.c:2306
 msgid "DO step value is zero"
 msgstr ""
 
@@ -6084,10 +6089,10 @@
 msgid "Allow dollar signs in entity names."
 msgstr ""
 
-#: fortran/lang.opt:485 config/alpha/alpha.opt:31 common.opt:783
-#: common.opt:985 common.opt:989 common.opt:993 common.opt:997 common.opt:1532
-#: common.opt:1588 common.opt:1712 common.opt:1716 common.opt:1946
-#: common.opt:2116 common.opt:2792
+#: fortran/lang.opt:485 config/alpha/alpha.opt:31 common.opt:649
+#: common.opt:783 common.opt:989 common.opt:993 common.opt:997 common.opt:1001
+#: common.opt:1536 common.opt:1592 common.opt:1716 common.opt:1720
+#: common.opt:1950 common.opt:2120 common.opt:2796
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr ""
 
@@ -6308,12 +6313,12 @@
 msgstr ""
 
 #: fortran/lang.opt:751 c-family/c.opt:1356 c-family/c.opt:1384
-#: c-family/c.opt:1634 config/pa/pa.opt:42 config/pa/pa.opt:70 common.opt:1154
-#: common.opt:1333 common.opt:1408 common.opt:1676 common.opt:1799
-#: common.opt:2169 common.opt:2205 common.opt:2298 common.opt:2302
-#: common.opt:2407 common.opt:2498 common.opt:2506 common.opt:2514
-#: common.opt:2522 common.opt:2623 common.opt:2675 common.opt:2755
-#: common.opt:2893 common.opt:2897 common.opt:2901 common.opt:2905
+#: c-family/c.opt:1634 config/pa/pa.opt:42 config/pa/pa.opt:70 common.opt:1158
+#: common.opt:1337 common.opt:1412 common.opt:1680 common.opt:1803
+#: common.opt:2173 common.opt:2209 common.opt:2302 common.opt:2306
+#: common.opt:2411 common.opt:2502 common.opt:2510 common.opt:2518
+#: common.opt:2526 common.opt:2627 common.opt:2679 common.opt:2759
+#: common.opt:2897 common.opt:2901 common.opt:2905 common.opt:2909
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr ""
 
@@ -6363,7 +6368,7 @@
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:220 c-family/c.opt:224
 #: c-family/c.opt:236 c-family/c.opt:1855 c-family/c.opt:1863 brig/lang.opt:39
-#: config/darwin.opt:56 common.opt:338 common.opt:341 common.opt:3046
+#: config/darwin.opt:56 common.opt:338 common.opt:341 common.opt:3050
 #, fuzzy, c-format
 #| msgid "missing white space after number '%.*s'"
 msgid "missing filename after %qs"
@@ -6957,7 +6962,7 @@
 #: c-family/c.opt:1525 c-family/c.opt:1528 c-family/c.opt:1569
 #: c-family/c.opt:1704 c-family/c.opt:1731 c-family/c.opt:1771
 #: c-family/c.opt:1802 c-family/c.opt:1806 c-family/c.opt:1822
-#: config/ia64/ia64.opt:167 config/ia64/ia64.opt:170 c-family/c-opts.c:434
+#: config/ia64/ia64.opt:167 config/ia64/ia64.opt:170 c-family/c-opts.c:432
 #, fuzzy, gcc-internal-format
 msgid "switch %qs is no longer supported"
 msgstr "-pipe не падтрымліваецца."
@@ -14471,10 +14476,6 @@
 msgid "Warn if dereferencing a NULL pointer may lead to erroneous or undefined behavior."
 msgstr ""
 
-#: common.opt:649
-msgid "Warn if the loop cannot be optimized due to nontrivial assumptions."
-msgstr ""
-
 #: common.opt:656
 msgid "Warn about some C++ One Definition Rule violations during link time optimization."
 msgstr ""
@@ -14643,1731 +14644,1731 @@
 msgid "-dumpdir <dir>\tSet the directory name to be used for dumps."
 msgstr ""
 
-#: common.opt:946
+#: common.opt:950
 msgid "The version of the C++ ABI in use."
 msgstr ""
 
-#: common.opt:950
+#: common.opt:954
 msgid "Aggressively optimize loops using language constraints."
 msgstr ""
 
-#: common.opt:954
+#: common.opt:958
 #, fuzzy
 msgid "Align the start of functions."
 msgstr "вельмі шмат аргументаў у функцыі"
 
-#: common.opt:964
+#: common.opt:968
 msgid "Align labels which are only reached by jumping."
 msgstr ""
 
-#: common.opt:971
+#: common.opt:975
 msgid "Align all labels."
 msgstr ""
 
-#: common.opt:978
+#: common.opt:982
 msgid "Align the start of loops."
 msgstr ""
 
-#: common.opt:1001
+#: common.opt:1005
 msgid "Select what to sanitize."
 msgstr ""
 
-#: common.opt:1005
+#: common.opt:1009
 msgid "Select type of coverage sanitization."
 msgstr ""
 
-#: common.opt:1009
+#: common.opt:1013
 msgid "-fasan-shadow-offset=<number>\tUse custom shadow memory offset."
 msgstr ""
 
-#: common.opt:1013
+#: common.opt:1017
 msgid "-fsanitize-sections=<sec1,sec2,...>\tSanitize global variables in user-defined sections."
 msgstr ""
 
-#: common.opt:1018
+#: common.opt:1022
 msgid "After diagnosing undefined behavior attempt to continue execution."
 msgstr ""
 
-#: common.opt:1022
+#: common.opt:1026
 msgid "This switch is deprecated; use -fsanitize-recover= instead."
 msgstr ""
 
-#: common.opt:1029
+#: common.opt:1033
 msgid "Use trap instead of a library function for undefined behavior sanitization."
 msgstr ""
 
-#: common.opt:1033
+#: common.opt:1037
 msgid "Generate unwind tables that are exact at each instruction boundary."
 msgstr ""
 
-#: common.opt:1037
+#: common.opt:1041
 #, fuzzy
 #| msgid "Do not generate char instructions"
 msgid "Generate auto-inc/dec instructions."
 msgstr "Не генерыраваць сімвальныя інструкцыі"
 
-#: common.opt:1041
+#: common.opt:1045
 msgid "Use sample profile information for call graph node weights. The default profile file is fbdata.afdo in 'pwd'."
 msgstr ""
 
-#: common.opt:1046
+#: common.opt:1050
 msgid "Use sample profile information for call graph node weights. The profile file is specified in the argument."
 msgstr ""
 
-#: common.opt:1055
+#: common.opt:1059
 msgid "Generate code to check bounds before indexing arrays."
 msgstr ""
 
-#: common.opt:1059
+#: common.opt:1063
 msgid "Replace add, compare, branch with branch on count register."
 msgstr ""
 
-#: common.opt:1063
+#: common.opt:1067
 msgid "Use profiling information for branch probabilities."
 msgstr ""
 
-#: common.opt:1067
+#: common.opt:1071
 msgid "Perform branch target load optimization before prologue / epilogue threading."
 msgstr ""
 
-#: common.opt:1071
+#: common.opt:1075
 msgid "Perform branch target load optimization after prologue / epilogue threading."
 msgstr ""
 
-#: common.opt:1075
+#: common.opt:1079
 msgid "Restrict target load migration not to re-use registers in any basic block."
 msgstr ""
 
-#: common.opt:1079
+#: common.opt:1083
 msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions."
 msgstr ""
 
-#: common.opt:1083
+#: common.opt:1087
 msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls."
 msgstr ""
 
-#: common.opt:1090
+#: common.opt:1094
 msgid "Save registers around function calls."
 msgstr ""
 
-#: common.opt:1094
+#: common.opt:1098
 msgid "This switch is deprecated; do not use."
 msgstr ""
 
-#: common.opt:1098
+#: common.opt:1102
 msgid "Check the return value of new in C++."
 msgstr ""
 
-#: common.opt:1102 common.opt:1106
+#: common.opt:1106 common.opt:1110
 msgid "Perform internal consistency checkings."
 msgstr ""
 
-#: common.opt:1110
+#: common.opt:1114
 #, fuzzy
 #| msgid "Enable exception handling"
 msgid "Enable code hoisting."
 msgstr "Уключыць апрацоўку выключэньняў"
 
-#: common.opt:1114
+#: common.opt:1118
 msgid "Looks for opportunities to reduce stack adjustments and stack references."
 msgstr ""
 
-#: common.opt:1118
+#: common.opt:1122
 msgid "Do not put uninitialized globals in the common section."
 msgstr ""
 
-#: common.opt:1126
+#: common.opt:1130
 msgid "-fcompare-debug[=<opts>]\tCompile with and without e.g. -gtoggle, and compare the final-insns dump."
 msgstr ""
 
-#: common.opt:1130
+#: common.opt:1134
 msgid "Run only the second compilation of -fcompare-debug."
 msgstr ""
 
-#: common.opt:1134
+#: common.opt:1138
 msgid "Perform comparison elimination after register allocation has finished."
 msgstr ""
 
-#: common.opt:1138
+#: common.opt:1142
 msgid "Do not perform optimizations increasing noticeably stack usage."
 msgstr ""
 
-#: common.opt:1142
+#: common.opt:1146
 msgid "Perform a register copy-propagation optimization pass."
 msgstr ""
 
-#: common.opt:1146
+#: common.opt:1150
 msgid "Perform cross-jumping optimization."
 msgstr ""
 
-#: common.opt:1150
+#: common.opt:1154
 msgid "When running CSE, follow jumps to their targets."
 msgstr ""
 
-#: common.opt:1158
+#: common.opt:1162
 msgid "Omit range reduction step when performing complex division."
 msgstr ""
 
-#: common.opt:1162
+#: common.opt:1166
 msgid "Complex multiplication and division follow Fortran rules."
 msgstr ""
 
-#: common.opt:1166
+#: common.opt:1170
 msgid "Place data items into their own section."
 msgstr ""
 
-#: common.opt:1170
+#: common.opt:1174
 msgid "List all available debugging counters with their limits and counts."
 msgstr ""
 
-#: common.opt:1174
+#: common.opt:1178
 msgid "-fdbg-cnt=<counter>:<limit>[,<counter>:<limit>,...]\tSet the debug counter limit."
 msgstr ""
 
-#: common.opt:1178
+#: common.opt:1182
 msgid "-fdebug-prefix-map=<old>=<new> Map one directory name to another in debug information."
 msgstr ""
 
-#: common.opt:1182
+#: common.opt:1186
 msgid "-ffile-prefix-map=<old>=<new> Map one directory name to another in compilation result."
 msgstr ""
 
-#: common.opt:1186
+#: common.opt:1190
 msgid "Output .debug_types section when using DWARF v4 debuginfo."
 msgstr ""
 
-#: common.opt:1192
+#: common.opt:1196
 msgid "Defer popping functions args from stack until later."
 msgstr ""
 
-#: common.opt:1196
+#: common.opt:1200
 msgid "Attempt to fill delay slots of branch instructions."
 msgstr ""
 
-#: common.opt:1200
+#: common.opt:1204
 msgid "Delete dead instructions that may throw exceptions."
 msgstr ""
 
-#: common.opt:1204
+#: common.opt:1208
 msgid "Delete useless null pointer checks."
 msgstr ""
 
-#: common.opt:1208
+#: common.opt:1212
 msgid "Stream extra data to support more aggressive devirtualization in LTO local transformation mode."
 msgstr ""
 
-#: common.opt:1212
+#: common.opt:1216
 msgid "Perform speculative devirtualization."
 msgstr ""
 
-#: common.opt:1216
+#: common.opt:1220
 msgid "Try to convert virtual calls to direct ones."
 msgstr ""
 
-#: common.opt:1220
+#: common.opt:1224
 msgid "-fdiagnostics-show-location=[once|every-line]\tHow often to emit source location at the beginning of line-wrapped diagnostics."
 msgstr ""
 
-#: common.opt:1237
+#: common.opt:1241
 msgid "Show the source line with a caret indicating the column."
 msgstr ""
 
-#: common.opt:1245
+#: common.opt:1249
 msgid "-fdiagnostics-color=[never|always|auto]\tColorize diagnostics."
 msgstr ""
 
-#: common.opt:1265
+#: common.opt:1269
 msgid "Print fix-it hints in machine-readable form."
 msgstr ""
 
-#: common.opt:1269
+#: common.opt:1273
 msgid "Print fix-it hints to stderr in unified diff format."
 msgstr ""
 
-#: common.opt:1273
+#: common.opt:1277
 msgid "Amend appropriate diagnostic messages with the command line option that controls them."
 msgstr ""
 
-#: common.opt:1277
+#: common.opt:1281
 msgid "-fdisable-[tree|rtl|ipa]-<pass>=range1+range2 disables an optimization pass."
 msgstr ""
 
-#: common.opt:1281
+#: common.opt:1285
 msgid "-fenable-[tree|rtl|ipa]-<pass>=range1+range2 enables an optimization pass."
 msgstr ""
 
-#: common.opt:1285
+#: common.opt:1289
 msgid "-fdump-<type>\tDump various compiler internals to a file."
 msgstr ""
 
-#: common.opt:1292
+#: common.opt:1296
 msgid "-fdump-final-insns=filename\tDump to filename the insns at the end of translation."
 msgstr ""
 
-#: common.opt:1296
+#: common.opt:1300
 msgid "-fdump-go-spec=filename\tWrite all declarations to file as Go code."
 msgstr ""
 
-#: common.opt:1300
+#: common.opt:1304
 msgid "Suppress output of addresses in debugging dumps."
 msgstr ""
 
-#: common.opt:1304
+#: common.opt:1308
 msgid "Collect and dump debug information into temporary file if ICE in C/C++ compiler occurred."
 msgstr ""
 
-#: common.opt:1309
+#: common.opt:1313
 msgid "Dump detailed information on GCC's internal representation of source code locations."
 msgstr ""
 
-#: common.opt:1313
+#: common.opt:1317
 msgid "Dump optimization passes."
 msgstr ""
 
-#: common.opt:1317
+#: common.opt:1321
 msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps."
 msgstr ""
 
-#: common.opt:1321
+#: common.opt:1325
 msgid "Suppress output of previous and next insn numbers in debugging dumps."
 msgstr ""
 
-#: common.opt:1325
+#: common.opt:1329
 msgid "Enable CFI tables via GAS assembler directives."
 msgstr ""
 
-#: common.opt:1329
+#: common.opt:1333
 msgid "Perform early inlining."
 msgstr ""
 
-#: common.opt:1337
+#: common.opt:1341
 msgid "Perform interprocedural reduction of aggregates."
 msgstr ""
 
-#: common.opt:1341
+#: common.opt:1345
 msgid "Perform unused symbol elimination in debug info."
 msgstr ""
 
-#: common.opt:1345
+#: common.opt:1349
 msgid "Perform unused type elimination in debug info."
 msgstr ""
 
-#: common.opt:1349
+#: common.opt:1353
 msgid "Do not suppress C++ class debug information."
 msgstr ""
 
-#: common.opt:1353
+#: common.opt:1357
 #, fuzzy
 #| msgid "Enable exception handling"
 msgid "Enable exception handling."
 msgstr "Уключыць апрацоўку выключэньняў"
 
-#: common.opt:1357
+#: common.opt:1361
 msgid "Perform a number of minor, expensive optimizations."
 msgstr ""
 
-#: common.opt:1361
+#: common.opt:1365
 msgid "-fexcess-precision=[fast|standard]\tSpecify handling of excess floating-point precision."
 msgstr ""
 
-#: common.opt:1364
+#: common.opt:1368
 #, fuzzy, c-format
 msgid "unknown excess precision style %qs"
 msgstr "невядомая назва рэгістра: %s\n"
 
-#: common.opt:1376
+#: common.opt:1380
 msgid "-fpermitted-flt-eval-methods=[c11|ts-18661]\tSpecify which values of FLT_EVAL_METHOD are permitted."
 msgstr ""
 
-#: common.opt:1379
+#: common.opt:1383
 #, c-format
 msgid "unknown specification for the set of FLT_EVAL_METHOD values to permit %qs"
 msgstr ""
 
-#: common.opt:1392
+#: common.opt:1396
 msgid "Output lto objects containing both the intermediate language and binary output."
 msgstr ""
 
-#: common.opt:1396
+#: common.opt:1400
 msgid "Assume no NaNs or infinities are generated."
 msgstr ""
 
-#: common.opt:1400
+#: common.opt:1404
 msgid "-ffixed-<register>\tMark <register> as being unavailable to the compiler."
 msgstr ""
 
-#: common.opt:1404
+#: common.opt:1408
 msgid "Don't allocate floats and doubles in extended-precision registers."
 msgstr ""
 
-#: common.opt:1412
+#: common.opt:1416
 msgid "Perform a forward propagation pass on RTL."
 msgstr ""
 
-#: common.opt:1416
+#: common.opt:1420
 msgid "-ffp-contract=[off|on|fast]\tPerform floating-point expression contraction."
 msgstr ""
 
-#: common.opt:1419
+#: common.opt:1423
 #, c-format
 msgid "unknown floating point contraction style %qs"
 msgstr ""
 
-#: common.opt:1433
+#: common.opt:1437
 msgid "Allow built-in functions ceil, floor, round, trunc to raise \"inexact\" exceptions."
 msgstr ""
 
-#: common.opt:1440
+#: common.opt:1444
 msgid "Allow function addresses to be held in registers."
 msgstr ""
 
-#: common.opt:1444
+#: common.opt:1448
 #, fuzzy
 #| msgid "for each function it appears in.)"
 msgid "Place each function into its own section."
 msgstr "адзін раз для кожнай функцыі, дзе ён з'яўляецца.)"
 
-#: common.opt:1448
+#: common.opt:1452
 msgid "Perform global common subexpression elimination."
 msgstr ""
 
-#: common.opt:1452
+#: common.opt:1456
 msgid "Perform enhanced load motion during global common subexpression elimination."
 msgstr ""
 
-#: common.opt:1456
+#: common.opt:1460
 msgid "Perform store motion after global common subexpression elimination."
 msgstr ""
 
-#: common.opt:1460
+#: common.opt:1464
 msgid "Perform redundant load after store elimination in global common subexpression elimination."
 msgstr ""
 
-#: common.opt:1465
+#: common.opt:1469
 msgid "Perform global common subexpression elimination after register allocation has finished."
 msgstr ""
 
-#: common.opt:1482
+#: common.opt:1486
 msgid "-fgnat-encodings=[all|gdb|minimal]\tSelect the balance between GNAT encodings and standard DWARF emitted in the debug information"
 msgstr ""
 
-#: common.opt:1487
+#: common.opt:1491
 msgid "Enable in and out of Graphite representation."
 msgstr ""
 
-#: common.opt:1491
+#: common.opt:1495
 msgid "Enable Graphite Identity transformation."
 msgstr ""
 
-#: common.opt:1495
+#: common.opt:1499
 msgid "Enable hoisting adjacent loads to encourage generating conditional move instructions."
 msgstr ""
 
-#: common.opt:1504
+#: common.opt:1508
 msgid "Mark all loops as parallel."
 msgstr ""
 
-#: common.opt:1508 common.opt:1516 common.opt:2587
+#: common.opt:1512 common.opt:1520 common.opt:2591
 msgid "Enable loop nest transforms.  Same as -floop-nest-optimize."
 msgstr ""
 
-#: common.opt:1512
+#: common.opt:1516
 msgid "Enable loop interchange on trees."
 msgstr ""
 
-#: common.opt:1520
+#: common.opt:1524
 msgid "Perform unroll-and-jam on loops."
 msgstr ""
 
-#: common.opt:1524
+#: common.opt:1528
 msgid "Enable support for GNU transactional memory."
 msgstr ""
 
-#: common.opt:1528
+#: common.opt:1532
 msgid "Use STB_GNU_UNIQUE if supported by the assembler."
 msgstr ""
 
-#: common.opt:1536
+#: common.opt:1540
 msgid "Enable the loop nest optimizer."
 msgstr ""
 
-#: common.opt:1540
+#: common.opt:1544
 msgid "Force bitfield accesses to match their type width."
 msgstr ""
 
-#: common.opt:1544
+#: common.opt:1548
 msgid "Merge adjacent stores."
 msgstr ""
 
-#: common.opt:1548
+#: common.opt:1552
 msgid "Enable guessing of branch probabilities."
 msgstr ""
 
-#: common.opt:1556
+#: common.opt:1560
 #, fuzzy
 msgid "Process #ident directives."
 msgstr "нерэчаісны ініцыялізатар"
 
-#: common.opt:1560
+#: common.opt:1564
 msgid "Perform conversion of conditional jumps to branchless equivalents."
 msgstr ""
 
-#: common.opt:1564
+#: common.opt:1568
 msgid "Perform conversion of conditional jumps to conditional execution."
 msgstr ""
 
-#: common.opt:1568
+#: common.opt:1572
 msgid "-fstack-reuse=[all|named_vars|none]\tSet stack reuse level for local variables."
 msgstr ""
 
-#: common.opt:1571
+#: common.opt:1575
 #, c-format
 msgid "unknown Stack Reuse Level %qs"
 msgstr ""
 
-#: common.opt:1584
+#: common.opt:1588
 msgid "Convert conditional jumps in innermost loops to branchless equivalents."
 msgstr ""
 
-#: common.opt:1596
+#: common.opt:1600
 #, fuzzy
 #| msgid "Do not generate char instructions"
 msgid "Do not generate .size directives."
 msgstr "Не генерыраваць сімвальныя інструкцыі"
 
-#: common.opt:1600
+#: common.opt:1604
 msgid "Perform indirect inlining."
 msgstr ""
 
-#: common.opt:1606
+#: common.opt:1610
 msgid "Enable inlining of function declared \"inline\", disabling disables all inlining."
 msgstr ""
 
-#: common.opt:1610
+#: common.opt:1614
 msgid "Integrate functions into their callers when code size is known not to grow."
 msgstr ""
 
-#: common.opt:1614
+#: common.opt:1618
 msgid "Integrate functions not declared \"inline\" into their callers when profitable."
 msgstr ""
 
-#: common.opt:1618
+#: common.opt:1622
 msgid "Integrate functions only required by their single caller."
 msgstr ""
 
-#: common.opt:1625
+#: common.opt:1629
 msgid "-finline-limit=<number>\tLimit the size of inlined functions to <number>."
 msgstr ""
 
-#: common.opt:1629
+#: common.opt:1633
 msgid "Inline __atomic operations when a lock free instruction sequence is available."
 msgstr ""
 
-#: common.opt:1636
+#: common.opt:1640
 msgid "-fcf-protection=[full|branch|return|none]\tInstrument functions with checks to verify jump/call/return control-flow transfer instructions have valid targets."
 msgstr ""
 
-#: common.opt:1640
+#: common.opt:1644
 #, c-format
 msgid "unknown Control-Flow Protection Level %qs"
 msgstr ""
 
-#: common.opt:1656
+#: common.opt:1660
 msgid "Instrument function entry and exit with profiling calls."
 msgstr ""
 
-#: common.opt:1660
+#: common.opt:1664
 msgid "-finstrument-functions-exclude-function-list=name,...  Do not instrument listed functions."
 msgstr ""
 
-#: common.opt:1664
+#: common.opt:1668
 msgid "-finstrument-functions-exclude-file-list=filename,...  Do not instrument functions listed in files."
 msgstr ""
 
-#: common.opt:1668
+#: common.opt:1672
 msgid "Perform interprocedural constant propagation."
 msgstr ""
 
-#: common.opt:1672
+#: common.opt:1676
 msgid "Perform cloning to make Interprocedural constant propagation stronger."
 msgstr ""
 
-#: common.opt:1680
+#: common.opt:1684
 msgid "Perform interprocedural bitwise constant propagation."
 msgstr ""
 
-#: common.opt:1684
+#: common.opt:1688
 msgid "Perform interprocedural profile propagation."
 msgstr ""
 
-#: common.opt:1688
+#: common.opt:1692
 msgid "Perform interprocedural points-to analysis."
 msgstr ""
 
-#: common.opt:1692
+#: common.opt:1696
 msgid "Discover pure and const functions."
 msgstr ""
 
-#: common.opt:1696
+#: common.opt:1700
 msgid "Perform Identical Code Folding for functions and read-only variables."
 msgstr ""
 
-#: common.opt:1700
+#: common.opt:1704
 msgid "Perform Identical Code Folding for functions."
 msgstr ""
 
-#: common.opt:1704
+#: common.opt:1708
 msgid "Perform Identical Code Folding for variables."
 msgstr ""
 
-#: common.opt:1708
+#: common.opt:1712
 msgid "Discover readonly and non addressable static variables."
 msgstr ""
 
-#: common.opt:1720
+#: common.opt:1724
 msgid "Perform IPA Value Range Propagation."
 msgstr ""
 
-#: common.opt:1724
+#: common.opt:1728
 msgid "-fira-algorithm=[CB|priority]\tSet the used IRA algorithm."
 msgstr ""
 
-#: common.opt:1727
+#: common.opt:1731
 #, fuzzy, c-format
 #| msgid "unknown register name: %s"
 msgid "unknown IRA algorithm %qs"
 msgstr "невядомая назва рэгістра: %s"
 
-#: common.opt:1737
+#: common.opt:1741
 msgid "-fira-region=[one|all|mixed]\tSet regions for IRA."
 msgstr ""
 
-#: common.opt:1740
+#: common.opt:1744
 #, fuzzy, c-format
 #| msgid "unknown register name: %s"
 msgid "unknown IRA region %qs"
 msgstr "невядомая назва рэгістра: %s"
 
-#: common.opt:1753
+#: common.opt:1757
 msgid "Use IRA based register pressure calculation in RTL hoist optimizations."
 msgstr ""
 
-#: common.opt:1758
+#: common.opt:1762
 msgid "Use IRA based register pressure calculation in RTL loop optimizations."
 msgstr ""
 
-#: common.opt:1763
+#: common.opt:1767
 msgid "Share slots for saving different hard registers."
 msgstr ""
 
-#: common.opt:1767
+#: common.opt:1771
 msgid "Share stack slots for spilled pseudo-registers."
 msgstr ""
 
-#: common.opt:1771
+#: common.opt:1775
 msgid "-fira-verbose=<number>\tControl IRA's level of diagnostic messages."
 msgstr ""
 
-#: common.opt:1775
+#: common.opt:1779
 msgid "Optimize induction variables on trees."
 msgstr ""
 
-#: common.opt:1779
+#: common.opt:1783
 msgid "Use jump tables for sufficiently large switch statements."
 msgstr ""
 
-#: common.opt:1783
+#: common.opt:1787
 msgid "Generate code for functions even if they are fully inlined."
 msgstr ""
 
-#: common.opt:1787
+#: common.opt:1791
 msgid "Generate code for static functions even if they are never called."
 msgstr ""
 
-#: common.opt:1791
+#: common.opt:1795
 msgid "Emit static const variables even if they are not used."
 msgstr ""
 
-#: common.opt:1795
+#: common.opt:1799
 msgid "Give external symbols a leading underscore."
 msgstr ""
 
-#: common.opt:1803
+#: common.opt:1807
 msgid "Do CFG-sensitive rematerialization in LRA."
 msgstr ""
 
-#: common.opt:1807
+#: common.opt:1811
 #, fuzzy
 #| msgid "Enable SSA optimizations"
 msgid "Enable link-time optimization."
 msgstr "Уключаць SSA аптымізацыю"
 
-#: common.opt:1811
+#: common.opt:1815
 msgid "Link-time optimization with number of parallel jobs or jobserver."
 msgstr ""
 
-#: common.opt:1814
+#: common.opt:1818
 #, fuzzy, c-format
 #| msgid "unknown machine mode `%s'"
 msgid "unknown LTO partitioning model %qs"
 msgstr "невядомы рэжым машыны \"%s\""
 
-#: common.opt:1833
+#: common.opt:1837
 msgid "Specify the algorithm to partition symbols and vars at linktime."
 msgstr ""
 
-#: common.opt:1838
+#: common.opt:1842
 msgid "-flto-compression-level=<number>\tUse zlib compression level <number> for IL."
 msgstr ""
 
-#: common.opt:1842
+#: common.opt:1846
 msgid "Merge C++ types using One Definition Rule."
 msgstr ""
 
-#: common.opt:1846
+#: common.opt:1850
 msgid "Report various link-time optimization statistics."
 msgstr ""
 
-#: common.opt:1850
+#: common.opt:1854
 msgid "Report various link-time optimization statistics for WPA only."
 msgstr ""
 
-#: common.opt:1854
+#: common.opt:1858
 #, fuzzy
 msgid "Set errno after built-in math functions."
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: common.opt:1858
+#: common.opt:1862
 msgid "-fmax-errors=<number>\tMaximum number of errors to report."
 msgstr ""
 
-#: common.opt:1862
+#: common.opt:1866
 msgid "Report on permanent memory allocation."
 msgstr ""
 
-#: common.opt:1866
+#: common.opt:1870
 msgid "Report on permanent memory allocation in WPA only."
 msgstr ""
 
-#: common.opt:1873
+#: common.opt:1877
 msgid "Attempt to merge identical constants and constant variables."
 msgstr ""
 
-#: common.opt:1877
+#: common.opt:1881
 msgid "Attempt to merge identical constants across compilation units."
 msgstr ""
 
-#: common.opt:1881
+#: common.opt:1885
 msgid "Attempt to merge identical debug strings across compilation units."
 msgstr ""
 
-#: common.opt:1885
+#: common.opt:1889
 msgid "-fmessage-length=<number>\tLimit diagnostics to <number> characters per line.  0 suppresses line-wrapping."
 msgstr ""
 
-#: common.opt:1889
+#: common.opt:1893
 msgid "Perform SMS based modulo scheduling before the first scheduling pass."
 msgstr ""
 
-#: common.opt:1893
+#: common.opt:1897
 msgid "Perform SMS based modulo scheduling with register moves allowed."
 msgstr ""
 
-#: common.opt:1897
+#: common.opt:1901
 msgid "Move loop invariant computations out of loops."
 msgstr ""
 
-#: common.opt:1901
+#: common.opt:1905
 msgid "Use the RTL dead code elimination pass."
 msgstr ""
 
-#: common.opt:1905
+#: common.opt:1909
 msgid "Use the RTL dead store elimination pass."
 msgstr ""
 
-#: common.opt:1909
+#: common.opt:1913
 msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling."
 msgstr ""
 
-#: common.opt:1913
+#: common.opt:1917
 msgid "Support synchronous non-call exceptions."
 msgstr ""
 
-#: common.opt:1916
+#: common.opt:1920
 #, fuzzy, c-format
 msgid "options or targets missing after %qs"
 msgstr "аргумент для \"%s\" прапушчан"
 
-#: common.opt:1917
+#: common.opt:1921
 msgid "-foffload=<targets>=<options>  Specify offloading targets and options for them."
 msgstr ""
 
-#: common.opt:1921
+#: common.opt:1925
 msgid "-foffload-abi=[lp64|ilp32]     Set the ABI to use in an offload compiler."
 msgstr ""
 
-#: common.opt:1924
+#: common.opt:1928
 #, c-format
 msgid "unknown offload ABI %qs"
 msgstr ""
 
-#: common.opt:1934
+#: common.opt:1938
 msgid "When possible do not generate stack frames."
 msgstr ""
 
-#: common.opt:1938
+#: common.opt:1942
 #, fuzzy
 #| msgid "Enable SSA optimizations"
 msgid "Enable all optimization info dumps on stderr."
 msgstr "Уключаць SSA аптымізацыю"
 
-#: common.opt:1942
+#: common.opt:1946
 msgid "-fopt-info[-<type>=filename]\tDump compiler optimization details."
 msgstr ""
 
-#: common.opt:1950
+#: common.opt:1954
 msgid "Optimize sibling and tail recursive calls."
 msgstr ""
 
-#: common.opt:1954
+#: common.opt:1958
 msgid "Perform partial inlining."
 msgstr ""
 
-#: common.opt:1958 common.opt:1962
+#: common.opt:1962 common.opt:1966
 msgid "Report on memory allocation before interprocedural optimization."
 msgstr ""
 
-#: common.opt:1966
+#: common.opt:1970
 msgid "Pack structure members together without holes."
 msgstr ""
 
-#: common.opt:1970
+#: common.opt:1974
 msgid "-fpack-struct=<number>\tSet initial maximum structure member alignment."
 msgstr ""
 
-#: common.opt:1974
+#: common.opt:1978
 msgid "Return small aggregates in memory, not registers."
 msgstr ""
 
-#: common.opt:1978
+#: common.opt:1982
 msgid "Perform loop peeling."
 msgstr ""
 
-#: common.opt:1982
+#: common.opt:1986
 msgid "Enable machine specific peephole optimizations."
 msgstr ""
 
-#: common.opt:1986
+#: common.opt:1990
 msgid "Enable an RTL peephole pass before sched2."
 msgstr ""
 
-#: common.opt:1990
+#: common.opt:1994
 msgid "Generate position-independent code if possible (large mode)."
 msgstr ""
 
-#: common.opt:1994
+#: common.opt:1998
 msgid "Generate position-independent code for executables if possible (large mode)."
 msgstr ""
 
-#: common.opt:1998
+#: common.opt:2002
 msgid "Generate position-independent code if possible (small mode)."
 msgstr ""
 
-#: common.opt:2002
+#: common.opt:2006
 msgid "Generate position-independent code for executables if possible (small mode)."
 msgstr ""
 
-#: common.opt:2006
+#: common.opt:2010
 msgid "Use PLT for PIC calls (-fno-plt: load the address from GOT at call site)."
 msgstr ""
 
-#: common.opt:2010
+#: common.opt:2014
 msgid "Specify a plugin to load."
 msgstr ""
 
-#: common.opt:2014
+#: common.opt:2018
 msgid "-fplugin-arg-<name>-<key>[=<value>]\tSpecify argument <key>=<value> for plugin <name>."
 msgstr ""
 
-#: common.opt:2018
+#: common.opt:2022
 msgid "Run predictive commoning optimization."
 msgstr ""
 
-#: common.opt:2022
+#: common.opt:2026
 msgid "Generate prefetch instructions, if available, for arrays in loops."
 msgstr ""
 
-#: common.opt:2026
+#: common.opt:2030
 msgid "Enable basic program profiling code."
 msgstr ""
 
-#: common.opt:2030
+#: common.opt:2034
 msgid "Generate absolute source path names for gcov."
 msgstr ""
 
-#: common.opt:2034
+#: common.opt:2038
 msgid "Insert arc-based program profiling code."
 msgstr ""
 
-#: common.opt:2038
+#: common.opt:2042
 msgid "Set the top-level directory for storing the profile data. The default is 'pwd'."
 msgstr ""
 
-#: common.opt:2043
+#: common.opt:2047
 msgid "Enable correction of flow inconsistent profile data input."
 msgstr ""
 
-#: common.opt:2047
+#: common.opt:2051
 msgid "-fprofile-update=[single|atomic|prefer-atomic]\tSet the profile update method."
 msgstr ""
 
-#: common.opt:2050
+#: common.opt:2054
 #, fuzzy, c-format
 #| msgid "unknown register name: %s"
 msgid "unknown profile update method %qs"
 msgstr "невядомая назва рэгістра: %s"
 
-#: common.opt:2063
+#: common.opt:2067
 msgid "Enable common options for generating profile info for profile feedback directed optimizations."
 msgstr ""
 
-#: common.opt:2067
+#: common.opt:2071
 msgid "Enable common options for generating profile info for profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr ""
 
-#: common.opt:2071
+#: common.opt:2075
 msgid "Enable common options for performing profile feedback directed optimizations."
 msgstr ""
 
-#: common.opt:2075
+#: common.opt:2079
 msgid "Enable common options for performing profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr ""
 
-#: common.opt:2079
+#: common.opt:2083
 msgid "Insert code to profile values of expressions."
 msgstr ""
 
-#: common.opt:2083
+#: common.opt:2087
 msgid "Report on consistency of profile."
 msgstr ""
 
-#: common.opt:2087
+#: common.opt:2091
 msgid "Enable function reordering that improves code placement."
 msgstr ""
 
-#: common.opt:2091
+#: common.opt:2095
 msgid "Insert NOP instructions at each function entry."
 msgstr ""
 
-#: common.opt:2098
+#: common.opt:2102
 msgid "-frandom-seed=<string>\tMake compile reproducible using <string>."
 msgstr ""
 
-#: common.opt:2108
+#: common.opt:2112
 msgid "Record gcc command line switches in the object file."
 msgstr ""
 
-#: common.opt:2112
+#: common.opt:2116
 #, fuzzy
 msgid "Return small aggregates in registers."
 msgstr "Не выкарыстоўваць рэгістра sb"
 
-#: common.opt:2120
+#: common.opt:2124
 msgid "Tell DSE that the storage for a C++ object is dead when the constructor starts and when the destructor finishes."
 msgstr ""
 
-#: common.opt:2128
+#: common.opt:2132
 msgid "Relief of register pressure through live range shrinkage."
 msgstr ""
 
-#: common.opt:2132
+#: common.opt:2136
 msgid "Perform a register renaming optimization pass."
 msgstr ""
 
-#: common.opt:2136
+#: common.opt:2140
 msgid "Perform a target dependent instruction fusion optimization pass."
 msgstr ""
 
-#: common.opt:2140
+#: common.opt:2144
 msgid "Reorder basic blocks to improve code placement."
 msgstr ""
 
-#: common.opt:2144
+#: common.opt:2148
 msgid "-freorder-blocks-algorithm=[simple|stc]\tSet the used basic block reordering algorithm."
 msgstr ""
 
-#: common.opt:2147
+#: common.opt:2151
 #, c-format
 msgid "unknown basic block reordering algorithm %qs"
 msgstr ""
 
-#: common.opt:2157
+#: common.opt:2161
 msgid "Reorder basic blocks and partition into hot and cold sections."
 msgstr ""
 
-#: common.opt:2161
+#: common.opt:2165
 msgid "Reorder functions to improve code placement."
 msgstr ""
 
-#: common.opt:2165
+#: common.opt:2169
 msgid "Add a common subexpression elimination pass after loop optimizations."
 msgstr ""
 
-#: common.opt:2173
+#: common.opt:2177
 msgid "Disable optimizations that assume default FP rounding behavior."
 msgstr ""
 
-#: common.opt:2177
+#: common.opt:2181
 msgid "Enable scheduling across basic blocks."
 msgstr ""
 
-#: common.opt:2181
+#: common.opt:2185
 msgid "Enable register pressure sensitive insn scheduling."
 msgstr ""
 
-#: common.opt:2185
+#: common.opt:2189
 msgid "Allow speculative motion of non-loads."
 msgstr ""
 
-#: common.opt:2189
+#: common.opt:2193
 msgid "Allow speculative motion of some loads."
 msgstr ""
 
-#: common.opt:2193
+#: common.opt:2197
 msgid "Allow speculative motion of more loads."
 msgstr ""
 
-#: common.opt:2197
+#: common.opt:2201
 msgid "-fsched-verbose=<number>\tSet the verbosity level of the scheduler."
 msgstr ""
 
-#: common.opt:2201
+#: common.opt:2205
 msgid "If scheduling post reload, do superblock scheduling."
 msgstr ""
 
-#: common.opt:2209
+#: common.opt:2213
 msgid "Reschedule instructions before register allocation."
 msgstr ""
 
-#: common.opt:2213
+#: common.opt:2217
 msgid "Reschedule instructions after register allocation."
 msgstr ""
 
-#: common.opt:2220
+#: common.opt:2224
 msgid "Schedule instructions using selective scheduling algorithm."
 msgstr ""
 
-#: common.opt:2224
+#: common.opt:2228
 msgid "Run selective scheduling after reload."
 msgstr ""
 
-#: common.opt:2228
+#: common.opt:2232
 msgid "Run self-tests, using the given path to locate test files."
 msgstr ""
 
-#: common.opt:2232
+#: common.opt:2236
 msgid "Perform software pipelining of inner loops during selective scheduling."
 msgstr ""
 
-#: common.opt:2236
+#: common.opt:2240
 msgid "Perform software pipelining of outer loops during selective scheduling."
 msgstr ""
 
-#: common.opt:2240
+#: common.opt:2244
 msgid "Reschedule pipelined regions without pipelining."
 msgstr ""
 
-#: common.opt:2244
+#: common.opt:2248
 msgid "Allow interposing function (or variables) by ones with different semantics (or initializer) respectively by dynamic linker."
 msgstr ""
 
-#: common.opt:2250
+#: common.opt:2254
 msgid "Allow premature scheduling of queued insns."
 msgstr ""
 
-#: common.opt:2254
+#: common.opt:2258
 msgid "-fsched-stalled-insns=<number>\tSet number of queued insns that can be prematurely scheduled."
 msgstr ""
 
-#: common.opt:2262
+#: common.opt:2266
 msgid "Set dependence distance checking in premature scheduling of queued insns."
 msgstr ""
 
-#: common.opt:2266
+#: common.opt:2270
 msgid "-fsched-stalled-insns-dep=<number>\tSet dependence distance checking in premature scheduling of queued insns."
 msgstr ""
 
-#: common.opt:2270
+#: common.opt:2274
 msgid "Enable the group heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2274
+#: common.opt:2278
 msgid "Enable the critical path heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2278
+#: common.opt:2282
 msgid "Enable the speculative instruction heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2282
+#: common.opt:2286
 msgid "Enable the rank heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2286
+#: common.opt:2290
 msgid "Enable the last instruction heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2290
+#: common.opt:2294
 msgid "Enable the dependent count heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2294
+#: common.opt:2298
 msgid "Access data in the same section from shared anchor points."
 msgstr ""
 
-#: common.opt:2306
+#: common.opt:2310
 msgid "Turn on Redundant Extensions Elimination pass."
 msgstr ""
 
-#: common.opt:2310
+#: common.opt:2314
 msgid "Show column numbers in diagnostics, when available.  Default on."
 msgstr ""
 
-#: common.opt:2314
+#: common.opt:2318
 msgid "Emit function prologues only before parts of the function that need it, rather than at the top of the function."
 msgstr ""
 
-#: common.opt:2319
+#: common.opt:2323
 msgid "Shrink-wrap parts of the prologue and epilogue separately."
 msgstr ""
 
-#: common.opt:2323
+#: common.opt:2327
 msgid "Disable optimizations observable by IEEE signaling NaNs."
 msgstr ""
 
-#: common.opt:2327
+#: common.opt:2331
 msgid "Disable floating point optimizations that ignore the IEEE signedness of zero."
 msgstr ""
 
-#: common.opt:2331
+#: common.opt:2335
 msgid "Convert floating point constants to single precision constants."
 msgstr ""
 
-#: common.opt:2335
+#: common.opt:2339
 msgid "Split lifetimes of induction variables when loops are unrolled."
 msgstr ""
 
-#: common.opt:2339
+#: common.opt:2343
 msgid "Generate discontiguous stack frames."
 msgstr ""
 
-#: common.opt:2343
+#: common.opt:2347
 msgid "Split wide types into independent registers."
 msgstr ""
 
-#: common.opt:2347
+#: common.opt:2351
 msgid "Enable backward propagation of use properties at the SSA level."
 msgstr ""
 
-#: common.opt:2351
+#: common.opt:2355
 msgid "Optimize conditional patterns using SSA PHI nodes."
 msgstr ""
 
-#: common.opt:2355
+#: common.opt:2359
 msgid "Optimize amount of stdarg registers saved to stack at start of function."
 msgstr ""
 
-#: common.opt:2359
+#: common.opt:2363
 msgid "Apply variable expansion when loops are unrolled."
 msgstr ""
 
-#: common.opt:2363
+#: common.opt:2367
 #, fuzzy
 #| msgid "Insert stack checking code into the program"
 msgid "-fstack-check=[no|generic|specific]\tInsert stack checking code into the program."
 msgstr "Уключаць код правэркі стэку ў праграму"
 
-#: common.opt:2367
+#: common.opt:2371
 #, fuzzy
 #| msgid "Insert stack checking code into the program"
 msgid "Insert stack checking code into the program.  Same as -fstack-check=specific."
 msgstr "Уключаць код правэркі стэку ў праграму"
 
-#: common.opt:2371
+#: common.opt:2375
 msgid "Insert code to probe each page of stack space as it is allocated to protect from stack-clash style attacks."
 msgstr ""
 
-#: common.opt:2379
+#: common.opt:2383
 msgid "-fstack-limit-register=<register>\tTrap if the stack goes past <register>."
 msgstr ""
 
-#: common.opt:2383
+#: common.opt:2387
 msgid "-fstack-limit-symbol=<name>\tTrap if the stack goes past symbol <name>."
 msgstr ""
 
-#: common.opt:2387
+#: common.opt:2391
 msgid "Use propolice as a stack protection method."
 msgstr ""
 
-#: common.opt:2391
+#: common.opt:2395
 msgid "Use a stack protection method for every function."
 msgstr ""
 
-#: common.opt:2395
+#: common.opt:2399
 msgid "Use a smart stack protection method for certain functions."
 msgstr ""
 
-#: common.opt:2399
+#: common.opt:2403
 msgid "Use stack protection method only for functions with the stack_protect attribute."
 msgstr ""
 
-#: common.opt:2403
+#: common.opt:2407
 msgid "Output stack usage information on a per-function basis."
 msgstr ""
 
-#: common.opt:2415
+#: common.opt:2419
 msgid "Assume strict aliasing rules apply."
 msgstr ""
 
-#: common.opt:2419
+#: common.opt:2423
 msgid "Treat signed overflow as undefined.  Negated as -fwrapv -fwrapv-pointer."
 msgstr ""
 
-#: common.opt:2423
+#: common.opt:2427
 msgid "Implement __atomic operations via libcalls to legacy __sync functions."
 msgstr ""
 
-#: common.opt:2427
+#: common.opt:2431
 msgid "Check for syntax errors, then stop."
 msgstr ""
 
-#: common.opt:2431
+#: common.opt:2435
 msgid "Create data files needed by \"gcov\"."
 msgstr ""
 
-#: common.opt:2435
+#: common.opt:2439
 msgid "Perform jump threading optimizations."
 msgstr ""
 
-#: common.opt:2439
+#: common.opt:2443
 msgid "Report the time taken by each compiler pass."
 msgstr ""
 
-#: common.opt:2443
+#: common.opt:2447
 msgid "Record times taken by sub-phases separately."
 msgstr ""
 
-#: common.opt:2447
+#: common.opt:2451
 msgid "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tSet the default thread-local storage code generation model."
 msgstr ""
 
-#: common.opt:2450
+#: common.opt:2454
 #, fuzzy, c-format
 #| msgid "unknown machine mode `%s'"
 msgid "unknown TLS model %qs"
 msgstr "невядомы рэжым машыны \"%s\""
 
-#: common.opt:2466
+#: common.opt:2470
 msgid "Reorder top level functions, variables, and asms."
 msgstr ""
 
-#: common.opt:2470
+#: common.opt:2474
 msgid "Perform superblock formation via tail duplication."
 msgstr ""
 
-#: common.opt:2474
+#: common.opt:2478
 msgid "For targets that normally need trampolines for nested functions, always generate them instead of using descriptors."
 msgstr ""
 
-#: common.opt:2482
+#: common.opt:2486
 msgid "Assume floating-point operations can trap."
 msgstr ""
 
-#: common.opt:2486
+#: common.opt:2490
 msgid "Trap for signed overflow in addition, subtraction and multiplication."
 msgstr ""
 
-#: common.opt:2490
+#: common.opt:2494
 #, fuzzy
 #| msgid "Enable SSA optimizations"
 msgid "Enable SSA-CCP optimization on trees."
 msgstr "Уключаць SSA аптымізацыю"
 
-#: common.opt:2494
+#: common.opt:2498
 #, fuzzy
 #| msgid "Enable SSA optimizations"
 msgid "Enable SSA-BIT-CCP optimization on trees."
 msgstr "Уключаць SSA аптымізацыю"
 
-#: common.opt:2502
+#: common.opt:2506
 msgid "Enable loop header copying on trees."
 msgstr ""
 
-#: common.opt:2510
+#: common.opt:2514
 msgid "Enable SSA coalescing of user variables."
 msgstr ""
 
-#: common.opt:2518
+#: common.opt:2522
 msgid "Enable copy propagation on trees."
 msgstr ""
 
-#: common.opt:2526
+#: common.opt:2530
 msgid "Transform condition stores into unconditional ones."
 msgstr ""
 
-#: common.opt:2530
+#: common.opt:2534
 msgid "Perform conversions of switch initializations."
 msgstr ""
 
-#: common.opt:2534
+#: common.opt:2538
 #, fuzzy
 #| msgid "Enable SSA optimizations"
 msgid "Enable SSA dead code elimination optimization on trees."
 msgstr "Уключаць SSA аптымізацыю"
 
-#: common.opt:2538
+#: common.opt:2542
 #, fuzzy
 #| msgid "Enable SSA optimizations"
 msgid "Enable dominator optimizations."
 msgstr "Уключаць SSA аптымізацыю"
 
-#: common.opt:2542
+#: common.opt:2546
 msgid "Enable tail merging on trees."
 msgstr ""
 
-#: common.opt:2546
+#: common.opt:2550
 #, fuzzy
 #| msgid "Enable SSA optimizations"
 msgid "Enable dead store elimination."
 msgstr "Уключаць SSA аптымізацыю"
 
-#: common.opt:2550
+#: common.opt:2554
 msgid "Enable forward propagation on trees."
 msgstr ""
 
-#: common.opt:2554
+#: common.opt:2558
 msgid "Enable Full Redundancy Elimination (FRE) on trees."
 msgstr ""
 
-#: common.opt:2558
+#: common.opt:2562
 #, fuzzy
 #| msgid "Enable SSA optimizations"
 msgid "Enable string length optimizations on trees."
 msgstr "Уключаць SSA аптымізацыю"
 
-#: common.opt:2562
+#: common.opt:2566
 msgid "Detect paths that trigger erroneous or undefined behavior due to dereferencing a null pointer.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
-#: common.opt:2568
+#: common.opt:2572
 msgid "Detect paths that trigger erroneous or undefined behavior due to a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
-#: common.opt:2575
+#: common.opt:2579
 msgid "Enable loop distribution on trees."
 msgstr ""
 
-#: common.opt:2579
+#: common.opt:2583
 msgid "Enable loop distribution for patterns transformed into a library call."
 msgstr ""
 
-#: common.opt:2583
+#: common.opt:2587
 msgid "Enable loop invariant motion on trees."
 msgstr ""
 
-#: common.opt:2591
+#: common.opt:2595
 msgid "Create canonical induction variables in loops."
 msgstr ""
 
-#: common.opt:2595
+#: common.opt:2599
 #, fuzzy
 #| msgid "Enable SSA optimizations"
 msgid "Enable loop optimizations on tree level."
 msgstr "Уключаць SSA аптымізацыю"
 
-#: common.opt:2599
+#: common.opt:2603
 msgid "-ftree-parallelize-loops=<number>\tEnable automatic parallelization of loops."
 msgstr ""
 
-#: common.opt:2603
+#: common.opt:2607
 msgid "Enable hoisting loads from conditional pointers."
 msgstr ""
 
-#: common.opt:2607
+#: common.opt:2611
 #, fuzzy
 #| msgid "Enable SSA optimizations"
 msgid "Enable SSA-PRE optimization on trees."
 msgstr "Уключаць SSA аптымізацыю"
 
-#: common.opt:2611
+#: common.opt:2615
 msgid "In SSA-PRE optimization on trees, enable partial-partial redundancy elimination."
 msgstr ""
 
-#: common.opt:2615
+#: common.opt:2619
 msgid "Perform function-local points-to analysis on trees."
 msgstr ""
 
-#: common.opt:2619
+#: common.opt:2623
 msgid "Enable reassociation on tree level."
 msgstr ""
 
-#: common.opt:2627
+#: common.opt:2631
 msgid "Enable SSA code sinking on trees."
 msgstr ""
 
-#: common.opt:2631
+#: common.opt:2635
 msgid "Perform straight-line strength reduction."
 msgstr ""
 
-#: common.opt:2635
+#: common.opt:2639
 msgid "Perform scalar replacement of aggregates."
 msgstr ""
 
-#: common.opt:2639
+#: common.opt:2643
 msgid "Replace temporary expressions in the SSA->normal pass."
 msgstr ""
 
-#: common.opt:2643
+#: common.opt:2647
 msgid "Perform live range splitting during the SSA->normal pass."
 msgstr ""
 
-#: common.opt:2647
+#: common.opt:2651
 msgid "Perform Value Range Propagation on trees."
 msgstr ""
 
-#: common.opt:2651
+#: common.opt:2655
 msgid "Split paths leading to loop backedges."
 msgstr ""
 
-#: common.opt:2655
+#: common.opt:2659
 msgid "Assume common declarations may be overridden with ones with a larger trailing array."
 msgstr ""
 
-#: common.opt:2660
+#: common.opt:2664
 msgid "Compile whole compilation unit at a time."
 msgstr ""
 
-#: common.opt:2664
+#: common.opt:2668
 msgid "Perform loop unrolling when iteration count is known."
 msgstr ""
 
-#: common.opt:2668
+#: common.opt:2672
 msgid "Perform loop unrolling for all loops."
 msgstr ""
 
-#: common.opt:2679
+#: common.opt:2683
 msgid "Allow optimization for floating-point arithmetic which may change the result of the operation due to rounding."
 msgstr ""
 
-#: common.opt:2684
+#: common.opt:2688
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr ""
 
-#: common.opt:2692
+#: common.opt:2696
 msgid "Allow math optimizations that may violate IEEE or ISO standards."
 msgstr ""
 
-#: common.opt:2696
+#: common.opt:2700
 msgid "Perform loop unswitching."
 msgstr ""
 
-#: common.opt:2700
+#: common.opt:2704
 msgid "Perform loop splitting."
 msgstr ""
 
-#: common.opt:2704
+#: common.opt:2708
 #, fuzzy
 #| msgid "Enable exception handling"
 msgid "Just generate unwind tables for exception handling."
 msgstr "Уключыць апрацоўку выключэньняў"
 
-#: common.opt:2708
+#: common.opt:2712
 msgid "Use the bfd linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2712
+#: common.opt:2716
 msgid "Use the gold linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2724
+#: common.opt:2728
 msgid "Perform variable tracking."
 msgstr ""
 
-#: common.opt:2732
+#: common.opt:2736
 msgid "Perform variable tracking by annotating assignments."
 msgstr ""
 
-#: common.opt:2738
+#: common.opt:2742
 msgid "Toggle -fvar-tracking-assignments."
 msgstr ""
 
-#: common.opt:2746
+#: common.opt:2750
 msgid "Perform variable tracking and also tag variables that are uninitialized."
 msgstr ""
 
-#: common.opt:2751
+#: common.opt:2755
 msgid "Enable vectorization on trees."
 msgstr ""
 
-#: common.opt:2759
+#: common.opt:2763
 #, fuzzy
 #| msgid "Enable SSA optimizations"
 msgid "Enable loop vectorization on trees."
 msgstr "Уключаць SSA аптымізацыю"
 
-#: common.opt:2763
+#: common.opt:2767
 msgid "Enable basic block vectorization (SLP) on trees."
 msgstr ""
 
-#: common.opt:2767
+#: common.opt:2771
 msgid "Specifies the cost model for vectorization. -fvect-cost-model=[unlimited|dynamic|cheap]\tSpecifies the cost model for vectorization."
 msgstr ""
 
-#: common.opt:2772
+#: common.opt:2776
 msgid "-fsimd-cost-model=[unlimited|dynamic|cheap]\tSpecifies the vectorization cost model for code marked with a simd directive."
 msgstr ""
 
-#: common.opt:2775
+#: common.opt:2779
 #, fuzzy, c-format
 #| msgid "unknown machine mode `%s'"
 msgid "unknown vectorizer cost model %qs"
 msgstr "невядомы рэжым машыны \"%s\""
 
-#: common.opt:2788
+#: common.opt:2792
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr ""
 
-#: common.opt:2796
+#: common.opt:2800
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr ""
 
-#: common.opt:2806
+#: common.opt:2810
 msgid "Add extra commentary to assembler output."
 msgstr ""
 
-#: common.opt:2810
+#: common.opt:2814
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility."
 msgstr ""
 
-#: common.opt:2813
+#: common.opt:2817
 #, fuzzy, c-format
 #| msgid "unrecognized section name \"%s\""
 msgid "unrecognized visibility value %qs"
 msgstr "нераспазнаная назва сэкцыі \"%s\""
 
-#: common.opt:2829
+#: common.opt:2833
 msgid "Validate vtable pointers before using them."
 msgstr ""
 
-#: common.opt:2832
+#: common.opt:2836
 #, c-format
 msgid "unknown vtable verify initialization priority %qs"
 msgstr ""
 
-#: common.opt:2845
+#: common.opt:2849
 msgid "Output vtable verification counters."
 msgstr ""
 
-#: common.opt:2849
+#: common.opt:2853
 msgid "Output vtable verification pointer sets information."
 msgstr ""
 
-#: common.opt:2853
+#: common.opt:2857
 msgid "Use expression value profiles in optimizations."
 msgstr ""
 
-#: common.opt:2857
+#: common.opt:2861
 msgid "Construct webs and split unrelated uses of single variable."
 msgstr ""
 
-#: common.opt:2861
+#: common.opt:2865
 msgid "Enable conditional dead code elimination for builtin calls."
 msgstr ""
 
-#: common.opt:2865
+#: common.opt:2869
 msgid "Perform whole program optimizations."
 msgstr ""
 
-#: common.opt:2869
+#: common.opt:2873
 msgid "Assume pointer overflow wraps around."
 msgstr ""
 
-#: common.opt:2873
+#: common.opt:2877
 msgid "Assume signed arithmetic overflow wraps around."
 msgstr ""
 
-#: common.opt:2877
+#: common.opt:2881
 msgid "Put zero initialized data in the bss section."
 msgstr ""
 
-#: common.opt:2881
+#: common.opt:2885
 msgid "Generate debug information in default format."
 msgstr ""
 
-#: common.opt:2885
+#: common.opt:2889
 msgid "Assume assembler support for (DWARF2+) .loc directives"
 msgstr ""
 
-#: common.opt:2889
+#: common.opt:2893
 msgid "Assume assembler support for view in (DWARF2+) .loc directives"
 msgstr ""
 
-#: common.opt:2892 common.opt:2896 common.opt:2900 common.opt:2904
+#: common.opt:2896 common.opt:2900 common.opt:2904 common.opt:2908
 #, fuzzy, c-format
 msgid "switch %qs no longer supported"
 msgstr "-pipe не падтрымліваецца."
 
-#: common.opt:2909
+#: common.opt:2913
 msgid "Record DW_AT_decl_column and DW_AT_call_column in DWARF."
 msgstr ""
 
-#: common.opt:2913
+#: common.opt:2917
 msgid "Generate debug information in default version of DWARF format."
 msgstr ""
 
-#: common.opt:2917
+#: common.opt:2921
 msgid "Generate debug information in DWARF v2 (or later) format."
 msgstr ""
 
-#: common.opt:2921
+#: common.opt:2925
 msgid "Generate debug information in default extended format."
 msgstr ""
 
-#: common.opt:2925
+#: common.opt:2929
 msgid "Generate extended entry point information for inlined functions"
 msgstr ""
 
-#: common.opt:2929
+#: common.opt:2933
 msgid "Compute locview reset points based on insn length estimates"
 msgstr ""
 
-#: common.opt:2937
+#: common.opt:2941
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:2941
+#: common.opt:2945
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:2945
+#: common.opt:2949
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr ""
 
-#: common.opt:2949
+#: common.opt:2953
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr ""
 
-#: common.opt:2953
+#: common.opt:2957
 msgid "Generate debug information in separate .dwo files."
 msgstr ""
 
-#: common.opt:2957
+#: common.opt:2961
 #, fuzzy
 msgid "Generate debug information in STABS format."
 msgstr "Стварыць код для DLL"
 
-#: common.opt:2961
+#: common.opt:2965
 msgid "Generate debug information in extended STABS format."
 msgstr ""
 
-#: common.opt:2965
+#: common.opt:2969
 msgid "Emit progressive recommended breakpoint locations."
 msgstr ""
 
-#: common.opt:2969
+#: common.opt:2973
 msgid "Don't emit DWARF additions beyond selected version."
 msgstr ""
 
-#: common.opt:2973
+#: common.opt:2977
 msgid "Toggle debug information generation."
 msgstr ""
 
-#: common.opt:2977
+#: common.opt:2981
 msgid "Augment variable location lists with progressive views."
 msgstr ""
 
-#: common.opt:2984
+#: common.opt:2988
 #, fuzzy
 msgid "Generate debug information in VMS format."
 msgstr "Стварыць код для DLL"
 
-#: common.opt:2988
+#: common.opt:2992
 msgid "Generate debug information in XCOFF format."
 msgstr ""
 
-#: common.opt:2992
+#: common.opt:2996
 msgid "Generate debug information in extended XCOFF format."
 msgstr ""
 
-#: common.opt:3010
+#: common.opt:3014
 msgid "Generate compressed debug sections."
 msgstr ""
 
-#: common.opt:3014
+#: common.opt:3018
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>."
 msgstr ""
 
-#: common.opt:3021
+#: common.opt:3025
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory."
 msgstr ""
 
-#: common.opt:3025
+#: common.opt:3029
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory."
 msgstr ""
 
-#: common.opt:3047
+#: common.opt:3051
 #, fuzzy
 #| msgid "  -o <file>                Place the output into <file>\n"
 msgid "-o <file>\tPlace output into <file>."
 msgstr "  -o <файл>                Памясціць вывад у <файл>\n"
 
-#: common.opt:3051
+#: common.opt:3055
 #, fuzzy
 #| msgid "Enable exception handling"
 msgid "Enable function profiling."
 msgstr "Уключыць апрацоўку выключэньняў"
 
-#: common.opt:3061
+#: common.opt:3065
 msgid "Like -pedantic but issue them as errors."
 msgstr ""
 
-#: common.opt:3101
+#: common.opt:3105
 msgid "Do not display functions compiled or elapsed time."
 msgstr ""
 
-#: common.opt:3133
+#: common.opt:3137
 msgid "Enable verbose output."
 msgstr ""
 
-#: common.opt:3137
+#: common.opt:3141
 msgid "Display the compiler's version."
 msgstr ""
 
-#: common.opt:3141
+#: common.opt:3145
 msgid "Suppress warnings."
 msgstr ""
 
-#: common.opt:3151
+#: common.opt:3155
 msgid "Create a shared library."
 msgstr ""
 
-#: common.opt:3196
+#: common.opt:3200
 msgid "Don't create a dynamically linked position independent executable."
 msgstr ""
 
-#: common.opt:3200
+#: common.opt:3204
 msgid "Create a dynamically linked position independent executable."
 msgstr ""
 
-#: common.opt:3204
+#: common.opt:3208
 msgid "Create a static position independent executable."
 msgstr ""
 
-#: common.opt:3211
+#: common.opt:3215
 msgid "Use caller save register across calls if possible."
 msgstr ""
 
-#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:598 cp/cvt.c:1308
+#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:599 cp/cvt.c:1308
 #: cp/cvt.c:1561
 #, gcc-internal-format
 msgid "value computed is not used"
@@ -16396,7 +16397,7 @@
 msgstr ""
 
 #: go/gofrontend/expressions.cc:4331 c/c-parser.c:13477 c/c-parser.c:13484
-#: cp/parser.c:33264 cp/parser.c:33271
+#: cp/parser.c:33261 cp/parser.c:33268
 #, gcc-internal-format
 msgid "expected integer"
 msgstr ""
@@ -16849,14 +16850,14 @@
 msgid "ignoring attribute %qE because it conflicts with attribute %qs"
 msgstr ""
 
-#: attribs.c:449 c-family/c-attribs.c:1894 cp/decl.c:13690 cp/friend.c:302
-#: cp/tree.c:4559
+#: attribs.c:449 c-family/c-attribs.c:1905 cp/decl.c:13714 cp/friend.c:302
+#: cp/tree.c:4607
 #, fuzzy, gcc-internal-format
 msgid "previous declaration here"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
 #. Warn about and ignore all others for now, but store them.
-#: attribs.c:564 c-family/c-attribs.c:2717 objc/objc-act.c:4963
+#: attribs.c:564 c-family/c-attribs.c:2728 objc/objc-act.c:4963
 #: objc/objc-act.c:6932 objc/objc-act.c:8119 objc/objc-act.c:8170
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored"
@@ -16877,18 +16878,18 @@
 #. This is a c++11 attribute that appertains to a
 #. type-specifier, outside of the definition of, a class
 #. type.  Ignore it.
-#: attribs.c:590 cp/decl.c:10999
+#: attribs.c:590 cp/decl.c:11023
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored"
 msgid "attribute ignored"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: attribs.c:592 cp/decl.c:11000
+#: attribs.c:592 cp/decl.c:11024
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
 
-#: attribs.c:610 c-family/c-attribs.c:3219
+#: attribs.c:610 c-family/c-attribs.c:3230
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute does not apply to types"
 msgstr "\"%s\" звычайна функцыя"
@@ -16904,40 +16905,40 @@
 msgstr ""
 
 #: attribs.c:691 attribs.c:1622 attribs.c:1632 attribs.c:1642
-#: c-family/c-attribs.c:540 c-family/c-attribs.c:559 c-family/c-attribs.c:577
-#: c-family/c-attribs.c:607 c-family/c-attribs.c:628 c-family/c-attribs.c:649
-#: c-family/c-attribs.c:690 c-family/c-attribs.c:717 c-family/c-attribs.c:733
-#: c-family/c-attribs.c:750 c-family/c-attribs.c:766 c-family/c-attribs.c:792
-#: c-family/c-attribs.c:807 c-family/c-attribs.c:835 c-family/c-attribs.c:852
-#: c-family/c-attribs.c:870 c-family/c-attribs.c:893 c-family/c-attribs.c:931
-#: c-family/c-attribs.c:954 c-family/c-attribs.c:971 c-family/c-attribs.c:1000
-#: c-family/c-attribs.c:1021 c-family/c-attribs.c:1042
-#: c-family/c-attribs.c:1069 c-family/c-attribs.c:1099
-#: c-family/c-attribs.c:1136 c-family/c-attribs.c:1189
-#: c-family/c-attribs.c:1255 c-family/c-attribs.c:1313
-#: c-family/c-attribs.c:1402 c-family/c-attribs.c:1432
-#: c-family/c-attribs.c:1483 c-family/c-attribs.c:1998
-#: c-family/c-attribs.c:2035 c-family/c-attribs.c:2096
-#: c-family/c-attribs.c:2152 c-family/c-attribs.c:2230
-#: c-family/c-attribs.c:2312 c-family/c-attribs.c:2371
-#: c-family/c-attribs.c:2390 c-family/c-attribs.c:2498
-#: c-family/c-attribs.c:2514 c-family/c-attribs.c:2530
-#: c-family/c-attribs.c:2551 c-family/c-attribs.c:2608
-#: c-family/c-attribs.c:2635 c-family/c-attribs.c:2690
-#: c-family/c-attribs.c:2870 c-family/c-attribs.c:2891
-#: c-family/c-attribs.c:3004 c-family/c-attribs.c:3031
-#: c-family/c-attribs.c:3221 c-family/c-attribs.c:3239
-#: c-family/c-attribs.c:3262 c-family/c-attribs.c:3301
-#: c-family/c-attribs.c:3383 c-family/c-attribs.c:3439
-#: c-family/c-attribs.c:3455 c-family/c-attribs.c:3549
-#: c-family/c-common.c:5600 config/darwin.c:2072 config/arm/arm.c:6868
+#: c-family/c-attribs.c:547 c-family/c-attribs.c:566 c-family/c-attribs.c:584
+#: c-family/c-attribs.c:614 c-family/c-attribs.c:635 c-family/c-attribs.c:656
+#: c-family/c-attribs.c:697 c-family/c-attribs.c:728 c-family/c-attribs.c:744
+#: c-family/c-attribs.c:761 c-family/c-attribs.c:777 c-family/c-attribs.c:803
+#: c-family/c-attribs.c:818 c-family/c-attribs.c:846 c-family/c-attribs.c:863
+#: c-family/c-attribs.c:881 c-family/c-attribs.c:904 c-family/c-attribs.c:942
+#: c-family/c-attribs.c:965 c-family/c-attribs.c:982 c-family/c-attribs.c:1011
+#: c-family/c-attribs.c:1032 c-family/c-attribs.c:1053
+#: c-family/c-attribs.c:1080 c-family/c-attribs.c:1110
+#: c-family/c-attribs.c:1147 c-family/c-attribs.c:1200
+#: c-family/c-attribs.c:1266 c-family/c-attribs.c:1324
+#: c-family/c-attribs.c:1413 c-family/c-attribs.c:1443
+#: c-family/c-attribs.c:1494 c-family/c-attribs.c:2009
+#: c-family/c-attribs.c:2046 c-family/c-attribs.c:2107
+#: c-family/c-attribs.c:2163 c-family/c-attribs.c:2241
+#: c-family/c-attribs.c:2323 c-family/c-attribs.c:2382
+#: c-family/c-attribs.c:2401 c-family/c-attribs.c:2509
+#: c-family/c-attribs.c:2525 c-family/c-attribs.c:2541
+#: c-family/c-attribs.c:2562 c-family/c-attribs.c:2619
+#: c-family/c-attribs.c:2646 c-family/c-attribs.c:2701
+#: c-family/c-attribs.c:2881 c-family/c-attribs.c:2902
+#: c-family/c-attribs.c:3015 c-family/c-attribs.c:3042
+#: c-family/c-attribs.c:3232 c-family/c-attribs.c:3250
+#: c-family/c-attribs.c:3273 c-family/c-attribs.c:3312
+#: c-family/c-attribs.c:3394 c-family/c-attribs.c:3450
+#: c-family/c-attribs.c:3466 c-family/c-attribs.c:3560
+#: c-family/c-common.c:5598 config/darwin.c:2072 config/arm/arm.c:6868
 #: config/arm/arm.c:6896 config/arm/arm.c:6913 config/avr/avr.c:9698
-#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6497
-#: config/i386/i386.c:41520 config/ia64/ia64.c:788
-#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33056
-#: config/spu/spu.c:3743 ada/gcc-interface/utils.c:6244
-#: ada/gcc-interface/utils.c:6261 ada/gcc-interface/utils.c:6277
-#: ada/gcc-interface/utils.c:6303 brig/brig-lang.c:476 lto/lto-lang.c:283
+#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6500
+#: config/i386/i386.c:41514 config/ia64/ia64.c:788
+#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33112
+#: config/spu/spu.c:3743 ada/gcc-interface/utils.c:6249
+#: ada/gcc-interface/utils.c:6266 ada/gcc-interface/utils.c:6282
+#: ada/gcc-interface/utils.c:6308 brig/brig-lang.c:476 lto/lto-lang.c:283
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored"
 msgid "%qE attribute ignored"
@@ -17321,88 +17322,103 @@
 msgid "%Kattempt to free a non-heap object"
 msgstr ""
 
-#: calls.c:1434
+#: calls.c:1291 file-prefix-map.c:50
+#, fuzzy, gcc-internal-format
+msgid "invalid argument %qs to %qs"
+msgstr "нявернае выкарыстанне \"restict\""
+
+#: calls.c:1452
 #, gcc-internal-format
 msgid "%Kargument %i value %qE is negative"
 msgstr ""
 
-#: calls.c:1452
+#: calls.c:1470
 #, gcc-internal-format
 msgid "%Kargument %i value is zero"
 msgstr ""
 
-#: calls.c:1469
+#: calls.c:1487
 #, gcc-internal-format
 msgid "%Kargument %i value %qE exceeds maximum object size %E"
 msgstr ""
 
-#: calls.c:1483
+#: calls.c:1501
 #, gcc-internal-format
 msgid "%Kargument %i range [%E, %E] is negative"
 msgstr ""
 
-#: calls.c:1490
+#: calls.c:1508
 #, gcc-internal-format
 msgid "%Kargument %i range [%E, %E] exceeds maximum object size %E"
 msgstr ""
 
-#: calls.c:1520
+#: calls.c:1538
 #, gcc-internal-format
 msgid "%Kproduct %<%E * %E%> of arguments %i and %i exceeds %<SIZE_MAX%>"
 msgstr ""
 
-#: calls.c:1526
+#: calls.c:1544
 #, gcc-internal-format
 msgid "%Kproduct %<%E * %E%> of arguments %i and %i exceeds maximum object size %E"
 msgstr ""
 
-#: calls.c:1537 calls.c:1540
+#: calls.c:1555 calls.c:1558
 #, fuzzy, gcc-internal-format
 msgid "argument %i in the range [%E, %E]"
 msgstr "аргумент для \"%s\" прапушчан"
 
-#: calls.c:1551
+#: calls.c:1569
 #, gcc-internal-format
 msgid "in a call to built-in allocation function %qD"
 msgstr ""
 
-#: calls.c:1554
+#: calls.c:1572
 #, gcc-internal-format
 msgid "in a call to allocation function %qD declared here"
 msgstr ""
 
-#: calls.c:1711
+#: calls.c:1835
 #, gcc-internal-format
-msgid "%qD argument %i declared attribute %<nonstring%> is smaller than the specified bound %E"
+msgid "%qD argument %i declared attribute %<nonstring%> is smaller than the specified bound %wu"
 msgstr ""
 
-#: calls.c:1716
+#: calls.c:1841
 #, gcc-internal-format
+msgid "%qD argument %i declared attribute %<nonstring%> is smaller than the specified bound [%E, %E]"
+msgstr ""
+
+#: calls.c:1847
+#, gcc-internal-format
+msgid "%qD argument %i declared attribute %<nonstring%> may be smaller than the specified bound [%E, %E]"
+msgstr ""
+
+#: calls.c:1857
+#, gcc-internal-format
 msgid "%qD argument %i declared attribute %<nonstring%>"
 msgstr ""
 
-#: calls.c:1721
+#: calls.c:1862
 #, fuzzy, gcc-internal-format
 msgid "argument %qD declared here"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: calls.c:1735
+#: calls.c:1876
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot find class `%s'"
 msgid "cannot tail-call: %s"
 msgstr "немагчыма знайсьці кляс `%s'"
 
-#: calls.c:3365
+#: calls.c:3506
 #, gcc-internal-format
 msgid "function call has aggregate value"
 msgstr ""
 
-#: calls.c:4059
+#: calls.c:4200
 #, gcc-internal-format
 msgid "passing too large argument on stack"
 msgstr ""
 
-#: cfgexpand.c:1665 function.c:1002 varasm.c:2231
+#: cfgexpand.c:1665 function.c:1002 varasm.c:2242
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%s' is too large"
 msgid "size of variable %q+D is too large"
@@ -17995,238 +18011,238 @@
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr ""
 
-#: cgraph.c:3051
+#: cgraph.c:3056
 #, gcc-internal-format
 msgid "caller edge count invalid"
 msgstr ""
 
-#: cgraph.c:3135
+#: cgraph.c:3140
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr ""
 
-#: cgraph.c:3142
+#: cgraph.c:3147
 #, gcc-internal-format
 msgid "cgraph count invalid"
 msgstr ""
 
-#: cgraph.c:3147
+#: cgraph.c:3152
 #, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr ""
 
-#: cgraph.c:3152
+#: cgraph.c:3157
 #, fuzzy, gcc-internal-format
 #| msgid "label `%s' used but not defined"
 msgid "local symbols must be defined"
 msgstr "адмеціна `%s' выкарыстоўвываецца, але ня вызначана"
 
-#: cgraph.c:3157
+#: cgraph.c:3162
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr ""
 
-#: cgraph.c:3162
+#: cgraph.c:3167
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr ""
 
-#: cgraph.c:3167
+#: cgraph.c:3172
 #, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr ""
 
-#: cgraph.c:3174
+#: cgraph.c:3179
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for indirect edge from %s"
 msgstr ""
 
-#: cgraph.c:3181
+#: cgraph.c:3186
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr ""
 
-#: cgraph.c:3196
+#: cgraph.c:3201
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr ""
 
-#: cgraph.c:3206
+#: cgraph.c:3211
 #, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr ""
 
-#: cgraph.c:3211
+#: cgraph.c:3216
 #, gcc-internal-format
 msgid "multiple inline callers"
 msgstr ""
 
-#: cgraph.c:3218
+#: cgraph.c:3223
 #, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr ""
 
-#: cgraph.c:3239
+#: cgraph.c:3244
 #, gcc-internal-format
 msgid "caller edge count does not match BB count"
 msgstr ""
 
-#: cgraph.c:3261
+#: cgraph.c:3266
 #, gcc-internal-format
 msgid "indirect call count does not match BB count"
 msgstr ""
 
-#: cgraph.c:3272
+#: cgraph.c:3277
 #, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr ""
 
-#: cgraph.c:3277
+#: cgraph.c:3282
 #, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr ""
 
-#: cgraph.c:3289
+#: cgraph.c:3294
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr ""
 
-#: cgraph.c:3301
+#: cgraph.c:3306
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr ""
 
-#: cgraph.c:3307
+#: cgraph.c:3312
 #, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr ""
 
-#: cgraph.c:3312
+#: cgraph.c:3317
 #, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr ""
 
-#: cgraph.c:3317
+#: cgraph.c:3322
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr ""
 
-#: cgraph.c:3329
+#: cgraph.c:3334
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr ""
 
-#: cgraph.c:3337
+#: cgraph.c:3342
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr ""
 
-#: cgraph.c:3342
+#: cgraph.c:3347
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr ""
 
-#: cgraph.c:3349
+#: cgraph.c:3354
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr ""
 
-#: cgraph.c:3358
+#: cgraph.c:3363
 #, gcc-internal-format
 msgid "Instrumentation clone does not reference original node"
 msgstr ""
 
-#: cgraph.c:3365
+#: cgraph.c:3370
 #, gcc-internal-format
 msgid "Not instrumented node has non-NULL original declaration"
 msgstr ""
 
-#: cgraph.c:3375
+#: cgraph.c:3380
 #, gcc-internal-format
 msgid "Instrumented node has wrong original declaration"
 msgstr ""
 
-#: cgraph.c:3393
+#: cgraph.c:3398
 #, gcc-internal-format
 msgid "Node has more than one chkp reference"
 msgstr ""
 
-#: cgraph.c:3398
+#: cgraph.c:3403
 #, gcc-internal-format
 msgid "Wrong node is referenced with chkp reference"
 msgstr ""
 
-#: cgraph.c:3406
+#: cgraph.c:3411
 #, gcc-internal-format
 msgid "Analyzed node has no reference to instrumented version"
 msgstr ""
 
-#: cgraph.c:3420
+#: cgraph.c:3425
 #, gcc-internal-format
 msgid "Alias chain for instrumented node is broken"
 msgstr ""
 
-#: cgraph.c:3429
+#: cgraph.c:3434
 #, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3434
+#: cgraph.c:3439
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3439
+#: cgraph.c:3444
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr ""
 
-#: cgraph.c:3445
+#: cgraph.c:3450
 #, gcc-internal-format
 msgid "Instrumentation thunk has wrong edge callee"
 msgstr ""
 
-#: cgraph.c:3481
+#: cgraph.c:3486
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr ""
 
-#: cgraph.c:3489
+#: cgraph.c:3494
 #, fuzzy, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr "\"%s\" - гэта не пачатак дэкларацыі"
 
-#: cgraph.c:3498
+#: cgraph.c:3503
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr ""
 
-#: cgraph.c:3508
+#: cgraph.c:3513
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr ""
 
-#: cgraph.c:3518
+#: cgraph.c:3523
 #, gcc-internal-format
 msgid "reference to dead statement"
 msgstr ""
 
-#: cgraph.c:3531
+#: cgraph.c:3536
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3543
+#: cgraph.c:3548
 #, gcc-internal-format, gfc-internal-format
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3554
+#: cgraph.c:3559
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr ""
 
-#: cgraph.c:3661 varpool.c:306
+#: cgraph.c:3666 varpool.c:306
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument to `-%s' is missing"
 msgid "%s: section %s is missing"
@@ -18258,13 +18274,13 @@
 msgstr ""
 
 #. include_self=
-#: cgraphunit.c:981 c/c-decl.c:11282
+#: cgraphunit.c:981 c/c-decl.c:11302
 #, fuzzy, gcc-internal-format
 #| msgid "label `%s' used but not defined"
 msgid "%q+F used but never defined"
 msgstr "адмеціна `%s' выкарыстоўвываецца, але ня вызначана"
 
-#: cgraphunit.c:983 c/c-decl.c:11291
+#: cgraphunit.c:983 c/c-decl.c:11311
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr ""
@@ -18384,12 +18400,12 @@
 msgid "cannot find '%s'"
 msgstr "нельга знайсці \"%s\""
 
-#: collect-utils.c:183 collect2.c:2361 collect2.c:2560 gcc.c:3080 gcc.c:6856
+#: collect-utils.c:183 collect2.c:2387 collect2.c:2586 gcc.c:3080 gcc.c:6856
 #, gcc-internal-format
 msgid "pex_init failed: %m"
 msgstr ""
 
-#: collect-utils.c:192 collect2.c:2370 collect2.c:2568 gcc.c:8498
+#: collect-utils.c:192 collect2.c:2396 collect2.c:2594 gcc.c:8498
 #, fuzzy, gcc-internal-format
 #| msgid "%s: %s: "
 msgid "%s: %m"
@@ -18400,99 +18416,99 @@
 msgid "COLLECT_LTO_WRAPPER must be set"
 msgstr ""
 
-#: collect2.c:966 gcc.c:7382 lto-wrapper.c:1666
+#: collect2.c:969 gcc.c:7382 lto-wrapper.c:1692
 #: config/i386/intelmic-mkoffload.c:556 config/nvptx/mkoffload.c:405
 #, gcc-internal-format
 msgid "atexit failed"
 msgstr ""
 
-#: collect2.c:1064
+#: collect2.c:1067
 #, gcc-internal-format
 msgid "no arguments"
 msgstr "няма аргументаў"
 
-#: collect2.c:1303 opts.c:904
+#: collect2.c:1311 opts.c:904
 #, gcc-internal-format
 msgid "LTO support has not been enabled in this configuration"
 msgstr ""
 
-#: collect2.c:1344
+#: collect2.c:1352
 #, fuzzy, gcc-internal-format
 #| msgid "can't open %s"
 msgid "can't open %s: %m"
 msgstr "немагчыма адчыніць %s"
 
-#: collect2.c:1450
+#: collect2.c:1472
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unknown machine mode `%s'"
 msgid "unknown demangling style '%s'"
 msgstr "невядомы рэжым машыны \"%s\""
 
-#: collect2.c:1546 collect2.c:1729 collect2.c:1769
+#: collect2.c:1574 collect2.c:1757 collect2.c:1797
 #, gcc-internal-format
 msgid "fopen %s: %m"
 msgstr ""
 
-#: collect2.c:1549 collect2.c:1734 collect2.c:1772
+#: collect2.c:1577 collect2.c:1762 collect2.c:1800
 #, gcc-internal-format
 msgid "fclose %s: %m"
 msgstr ""
 
-#: collect2.c:2335
+#: collect2.c:2361
 #, fuzzy, gcc-internal-format
 #| msgid "cannot find `nm'"
 msgid "cannot find 'nm'"
 msgstr "нельга знайсці \"nm\""
 
-#: collect2.c:2383
+#: collect2.c:2409
 #, fuzzy, gcc-internal-format
 #| msgid "can't open output file `%s'"
 msgid "can't open nm output: %m"
 msgstr "немагчыма адчыніць файл уводу `%s'"
 
-#: collect2.c:2467
+#: collect2.c:2493
 #, gcc-internal-format, gfc-internal-format
 msgid "init function found in object %s"
 msgstr ""
 
-#: collect2.c:2478
+#: collect2.c:2504
 #, gcc-internal-format, gfc-internal-format
 msgid "fini function found in object %s"
 msgstr ""
 
-#: collect2.c:2535
+#: collect2.c:2561
 #, fuzzy, gcc-internal-format
 #| msgid "cannot find `ldd'"
 msgid "cannot find 'ldd'"
 msgstr "не магу знайсці \"ldd\""
 
-#: collect2.c:2581
+#: collect2.c:2607
 #, fuzzy, gcc-internal-format
 #| msgid "can't open output file `%s'"
 msgid "can't open ldd output: %m"
 msgstr "немагчыма адчыніць файл уводу `%s'"
 
-#: collect2.c:2599
+#: collect2.c:2625
 #, gcc-internal-format, gfc-internal-format
 msgid "dynamic dependency %s not found"
 msgstr ""
 
-#: collect2.c:2611
+#: collect2.c:2637
 #, gcc-internal-format, gfc-internal-format
 msgid "unable to open dynamic dependency '%s'"
 msgstr ""
 
-#: collect2.c:2765
+#: collect2.c:2791
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: not a COFF file"
 msgstr ""
 
-#: collect2.c:2930
+#: collect2.c:2961
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: cannot open as COFF file"
 msgstr ""
 
-#: collect2.c:2989
+#: collect2.c:3020
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "library lib%s not found"
 msgstr "Бібліятэка lib%s не знойдзена"
@@ -18707,12 +18723,12 @@
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr ""
 
-#: dwarf2out.c:10901
+#: dwarf2out.c:10909
 #, gcc-internal-format
 msgid "-gdwarf-6 is output as version 5 with incompatibilities"
 msgstr ""
 
-#: dwarf2out.c:14415
+#: dwarf2out.c:14423
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
@@ -18833,11 +18849,6 @@
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr ""
 
-#: file-prefix-map.c:50
-#, fuzzy, gcc-internal-format
-msgid "invalid argument %qs to %qs"
-msgstr "нявернае выкарыстанне \"restict\""
-
 #: final.c:1868
 #, fuzzy, gcc-internal-format
 #| msgid "size of `%s' is larger than %d bytes"
@@ -18859,42 +18870,42 @@
 msgid "large fixed-point constant implicitly truncated to fixed-point type"
 msgstr ""
 
-#: fold-const.c:4151 fold-const.c:4161
+#: fold-const.c:4157 fold-const.c:4167
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d due to width of bit-field"
 msgstr ""
 
-#: fold-const.c:5478 tree-ssa-reassoc.c:2374 tree-ssa-reassoc.c:3214
+#: fold-const.c:5484 tree-ssa-reassoc.c:2379 tree-ssa-reassoc.c:3219
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
 
-#: fold-const.c:5928 fold-const.c:5942
+#: fold-const.c:5934 fold-const.c:5948
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr ""
 
-#: fold-const.c:6085
+#: fold-const.c:6091
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr ""
 
-#: fold-const.c:6090
+#: fold-const.c:6096
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr ""
 
-#: fold-const.c:8310
+#: fold-const.c:8316
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr ""
 
-#: fold-const.c:8710
+#: fold-const.c:8716
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr ""
 
-#: fold-const.c:12063
+#: fold-const.c:12069
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr ""
@@ -18905,7 +18916,7 @@
 msgid "total size of local objects too large"
 msgstr "памер масіва \"%s\" вельмі вялікі"
 
-#: function.c:1776 gimplify.c:6270
+#: function.c:1776 gimplify.c:6273
 #, fuzzy, gcc-internal-format
 #| msgid "impossible operator '%s'"
 msgid "impossible constraint in %<asm%>"
@@ -19218,7 +19229,7 @@
 msgid "%s: linker input file unused because linking not done"
 msgstr ""
 
-#: gcc.c:8420 c-family/c-opts.c:770
+#: gcc.c:8420 c-family/c-opts.c:768
 #, gcc-internal-format
 msgid "cannot use %<-%> as input filename for a precompiled header"
 msgstr ""
@@ -19466,7 +19477,7 @@
 msgid "%G%qD destination unchanged after copying no bytes"
 msgstr ""
 
-#: gimple-fold.c:2052 tree-ssa-strlen.c:2050
+#: gimple-fold.c:2052 tree-ssa-strlen.c:2074
 msgid "%G%qD specified bound %E equals destination size"
 msgstr ""
 
@@ -19488,12 +19499,12 @@
 msgid "null pointer dereference"
 msgstr ""
 
-#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12451
-#: tree.c:12488 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10147
-#: c/c-typeck.c:10164 c/gimple-parser.c:1616 c/gimple-parser.c:1624
+#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12455
+#: tree.c:12492 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10152
+#: c/c-typeck.c:10169 c/gimple-parser.c:1616 c/gimple-parser.c:1624
 #: cp/call.c:6493 cp/call.c:8098 cp/constexpr.c:820 cp/constexpr.c:2309
-#: cp/cvt.c:1015 cp/cvt.c:1042 cp/decl.c:7334 cp/decl2.c:5256 cp/pt.c:8334
-#: cp/semantics.c:1836 cp/semantics.c:4053 cp/typeck.c:1700 cp/typeck.c:1895
+#: cp/cvt.c:1015 cp/cvt.c:1042 cp/decl.c:7355 cp/decl2.c:5246 cp/pt.c:8348
+#: cp/semantics.c:1836 cp/semantics.c:4056 cp/typeck.c:1700 cp/typeck.c:1895
 #: cp/typeck.c:3837
 #, fuzzy, gcc-internal-format
 #| msgid "called from here"
@@ -19505,27 +19516,27 @@
 msgid "nonnull argument %qD compared to NULL"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2517 gimple-ssa-sprintf.c:2637
+#: gimple-ssa-sprintf.c:2555 gimple-ssa-sprintf.c:2675
 #, gcc-internal-format
 msgid "%qE output may be truncated before the last format character"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2519 gimple-ssa-sprintf.c:2639
+#: gimple-ssa-sprintf.c:2557 gimple-ssa-sprintf.c:2677
 #, gcc-internal-format
 msgid "%qE output truncated before the last format character"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2522 gimple-ssa-sprintf.c:2642
+#: gimple-ssa-sprintf.c:2560 gimple-ssa-sprintf.c:2680
 #, gcc-internal-format
 msgid "%qE may write a terminating nul past the end of the destination"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2524 gimple-ssa-sprintf.c:2644
+#: gimple-ssa-sprintf.c:2562 gimple-ssa-sprintf.c:2682
 #, gcc-internal-format
 msgid "%qE writing a terminating nul past the end of the destination"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2534
+#: gimple-ssa-sprintf.c:2572
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size %wu"
@@ -19532,7 +19543,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.c:2541
+#: gimple-ssa-sprintf.c:2579
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size %wu"
@@ -19539,7 +19550,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.c:2548
+#: gimple-ssa-sprintf.c:2586
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size %wu"
@@ -19546,67 +19557,67 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.c:2559
+#: gimple-ssa-sprintf.c:2597
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2562
+#: gimple-ssa-sprintf.c:2600
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2564
+#: gimple-ssa-sprintf.c:2602
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2576
+#: gimple-ssa-sprintf.c:2614
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2579
+#: gimple-ssa-sprintf.c:2617
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2582
+#: gimple-ssa-sprintf.c:2620
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2591
+#: gimple-ssa-sprintf.c:2629
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2594
+#: gimple-ssa-sprintf.c:2632
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2597
+#: gimple-ssa-sprintf.c:2635
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2606
+#: gimple-ssa-sprintf.c:2644
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2609
+#: gimple-ssa-sprintf.c:2647
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2611
+#: gimple-ssa-sprintf.c:2649
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2653
+#: gimple-ssa-sprintf.c:2691
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size between %wu and %wu"
@@ -19613,7 +19624,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.c:2660
+#: gimple-ssa-sprintf.c:2698
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size between %wu and %wu"
@@ -19620,7 +19631,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.c:2668
+#: gimple-ssa-sprintf.c:2706
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size between %wu and %wu"
@@ -19627,102 +19638,102 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.c:2680
+#: gimple-ssa-sprintf.c:2718
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2683
+#: gimple-ssa-sprintf.c:2721
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2686
+#: gimple-ssa-sprintf.c:2724
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2699
+#: gimple-ssa-sprintf.c:2737
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2702
+#: gimple-ssa-sprintf.c:2740
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2705
+#: gimple-ssa-sprintf.c:2743
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2715
+#: gimple-ssa-sprintf.c:2753
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2718
+#: gimple-ssa-sprintf.c:2756
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2721
+#: gimple-ssa-sprintf.c:2759
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2730
+#: gimple-ssa-sprintf.c:2768
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2733
+#: gimple-ssa-sprintf.c:2771
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2736
+#: gimple-ssa-sprintf.c:2774
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2825
+#: gimple-ssa-sprintf.c:2863
 #, gcc-internal-format
 msgid "%<%.*s%> directive argument is null"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2890
+#: gimple-ssa-sprintf.c:2928
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes exceeds minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2897
+#: gimple-ssa-sprintf.c:2935
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may exceed minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2900
+#: gimple-ssa-sprintf.c:2938
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes exceeds minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2929
+#: gimple-ssa-sprintf.c:2967
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2936
+#: gimple-ssa-sprintf.c:2974
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2939
+#: gimple-ssa-sprintf.c:2977
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may cause result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2949
+#: gimple-ssa-sprintf.c:2987
 #, gcc-internal-format
 msgid "assuming directive output of %wu byte"
 msgid_plural "assuming directive output of %wu bytes"
@@ -19729,77 +19740,77 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.c:2956
+#: gimple-ssa-sprintf.c:2994
 #, gcc-internal-format
 msgid "directive argument %qE"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2958
+#: gimple-ssa-sprintf.c:2996
 #, gcc-internal-format
 msgid "directive argument in the range [%E, %E]"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2962
+#: gimple-ssa-sprintf.c:3000
 #, gcc-internal-format
 msgid "using the range [%E, %E] for directive argument"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2982
+#: gimple-ssa-sprintf.c:3020
 #, gcc-internal-format
 msgid "%qE output %wu byte into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2983
+#: gimple-ssa-sprintf.c:3021
 #, gcc-internal-format
 msgid "%qE output %wu bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2987
+#: gimple-ssa-sprintf.c:3025
 #, gcc-internal-format
 msgid "%qE output between %wu and %wu bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2992
+#: gimple-ssa-sprintf.c:3030
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes (assuming %wu) into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2997
+#: gimple-ssa-sprintf.c:3035
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3368
+#: gimple-ssa-sprintf.c:3406
 #, gcc-internal-format
 msgid "%<%.*s%> directive width out of range"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3402
+#: gimple-ssa-sprintf.c:3440
 #, gcc-internal-format
 msgid "%<%.*s%> directive precision out of range"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3893
+#: gimple-ssa-sprintf.c:3931
 #, gcc-internal-format
 msgid "specified bound %wu exceeds maximum object size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3899
+#: gimple-ssa-sprintf.c:3937
 #, gcc-internal-format
 msgid "specified bound %wu exceeds %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3949
+#: gimple-ssa-sprintf.c:3987
 #, gcc-internal-format
 msgid "null destination pointer"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3966
+#: gimple-ssa-sprintf.c:4004
 #, gcc-internal-format
 msgid "specified bound %wu exceeds the size %wu of the destination object"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3978
+#: gimple-ssa-sprintf.c:4016
 #, gcc-internal-format
 msgid "null format string"
 msgstr ""
@@ -20013,10 +20024,10 @@
 msgstr ""
 
 #: gimple-ssa-warn-restrict.c:1678 c/c-decl.c:3603 c/c-decl.c:3874
-#: c/c-typeck.c:8345 cp/class.c:1346 cp/class.c:3098 cp/decl.c:3979
-#: cp/decl.c:10753 cp/decl.c:11151 cp/decl.c:11160 cp/friend.c:384
+#: c/c-typeck.c:8350 cp/class.c:1346 cp/class.c:3102 cp/decl.c:3979
+#: cp/decl.c:10777 cp/decl.c:11175 cp/decl.c:11184 cp/friend.c:384
 #: cp/friend.c:393 cp/parser.c:3275 cp/parser.c:3372 cp/parser.c:3422
-#: cp/parser.c:6327 cp/parser.c:21027
+#: cp/parser.c:6330 cp/parser.c:21024
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
@@ -20084,217 +20095,217 @@
 msgid "using result of function returning %<void%>"
 msgstr ""
 
-#: gimplify.c:6128
+#: gimplify.c:6131
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid lvalue in asm output %d"
 msgstr ""
 
-#: gimplify.c:6271
+#: gimplify.c:6274
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr ""
 
-#: gimplify.c:6311 gimplify.c:6320
+#: gimplify.c:6314 gimplify.c:6323
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr ""
 
-#: gimplify.c:6928
+#: gimplify.c:6931
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in target region"
 msgstr ""
 
-#: gimplify.c:6930
+#: gimplify.c:6933
 #, gcc-internal-format
 msgid "enclosing target region"
 msgstr ""
 
-#: gimplify.c:6942
+#: gimplify.c:6945
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in untied task"
 msgstr ""
 
-#: gimplify.c:6944
+#: gimplify.c:6947
 #, gcc-internal-format
 msgid "enclosing task"
 msgstr ""
 
-#: gimplify.c:7016
+#: gimplify.c:7019
 #, gcc-internal-format
 msgid "%qE not specified in enclosing %qs"
 msgstr ""
 
-#: gimplify.c:7018
+#: gimplify.c:7021
 #, gcc-internal-format
 msgid "enclosing %qs"
 msgstr ""
 
-#: gimplify.c:7143
+#: gimplify.c:7146
 #, gcc-internal-format
 msgid "%qE not specified in enclosing OpenACC %qs construct"
 msgstr ""
 
-#: gimplify.c:7145
+#: gimplify.c:7148
 #, gcc-internal-format
 msgid "enclosing OpenACC %qs construct"
 msgstr ""
 
-#: gimplify.c:7198
+#: gimplify.c:7201
 #, gcc-internal-format
 msgid "%qE with %<link%> clause used in %<routine%> function"
 msgstr ""
 
-#: gimplify.c:7206
+#: gimplify.c:7209
 #, gcc-internal-format
 msgid "%qE requires a %<declare%> directive for use in a %<routine%> function"
 msgstr ""
 
-#: gimplify.c:7272 gimplify.c:7872
+#: gimplify.c:7275 gimplify.c:7875
 #, gcc-internal-format
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr ""
 
-#: gimplify.c:7293
+#: gimplify.c:7296
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr ""
 
-#: gimplify.c:7411 gimplify.c:7443
+#: gimplify.c:7414 gimplify.c:7446
 #, gcc-internal-format
 msgid "iteration variable %qE is predetermined linear"
 msgstr ""
 
-#: gimplify.c:7414
+#: gimplify.c:7417
 #, gcc-internal-format
 msgid "iteration variable %qE should be private"
 msgstr ""
 
-#: gimplify.c:7428
+#: gimplify.c:7431
 #, gcc-internal-format
 msgid "iteration variable %qE should not be firstprivate"
 msgstr ""
 
-#: gimplify.c:7431
+#: gimplify.c:7434
 #, gcc-internal-format
 msgid "iteration variable %qE should not be reduction"
 msgstr ""
 
-#: gimplify.c:7434
+#: gimplify.c:7437
 #, gcc-internal-format
 msgid "iteration variable %qE should not be linear"
 msgstr ""
 
-#: gimplify.c:7437
+#: gimplify.c:7440
 #, gcc-internal-format
 msgid "iteration variable %qE should not be lastprivate"
 msgstr ""
 
-#: gimplify.c:7440
+#: gimplify.c:7443
 #, gcc-internal-format
 msgid "iteration variable %qE should not be private"
 msgstr ""
 
-#: gimplify.c:7742
+#: gimplify.c:7745
 #, gcc-internal-format
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr ""
 
-#: gimplify.c:7949
+#: gimplify.c:7952
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr ""
 
-#: gimplify.c:8160
+#: gimplify.c:8163
 #, gcc-internal-format
 msgid "%qE appears more than once in map clauses"
 msgstr ""
 
-#: gimplify.c:8464
+#: gimplify.c:8467
 #, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr ""
 
-#: gimplify.c:8484
+#: gimplify.c:8487
 #, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr ""
 
-#: gimplify.c:8510
+#: gimplify.c:8513
 #, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr ""
 
-#: gimplify.c:8775
+#: gimplify.c:8778
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr ""
 
-#: gimplify.c:8808
+#: gimplify.c:8811
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:9000
+#: gimplify.c:9003
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:9051
+#: gimplify.c:9054
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr ""
 
-#: gimplify.c:9133
+#: gimplify.c:9136
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to present_or_copy"
 msgstr ""
 
-#: gimplify.c:9278
+#: gimplify.c:9281
 #, fuzzy, gcc-internal-format
 msgid "invalid private reduction on %qE"
 msgstr "Нерэчаіснае абвяшчэнне"
 
-#: gimplify.c:11103 omp-low.c:2791
+#: gimplify.c:11106 omp-low.c:2791
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: gimplify.c:11121
+#: gimplify.c:11124
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr ""
 
-#: gimplify.c:11134
+#: gimplify.c:11137
 #, gcc-internal-format
 msgid "number of variables in %<depend(sink)%> clause does not match number of iteration variables"
 msgstr ""
 
-#: gimplify.c:11147
+#: gimplify.c:11150
 #, gcc-internal-format
 msgid "more than one %<depend(source)%> clause on an %<ordered%> construct"
 msgstr ""
 
-#: gimplify.c:11158
+#: gimplify.c:11161
 #, gcc-internal-format
 msgid "%<depend(source)%> clause specified together with %<depend(sink:)%> clauses on the same construct"
 msgstr ""
 
-#: gimplify.c:12393
+#: gimplify.c:12396
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr ""
 
-#: gimplify.c:12936
+#: gimplify.c:12939
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr ""
 
-#: gimplify.c:12941
+#: gimplify.c:12944
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr ""
 
-#: gimplify.c:12948
+#: gimplify.c:12951
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr ""
@@ -20771,49 +20782,49 @@
 msgid "Max. number of generated reload insns per insn is achieved (%d)\n"
 msgstr ""
 
-#: lto-cgraph.c:1294
+#: lto-cgraph.c:1296
 #, gcc-internal-format, gfc-internal-format
 msgid "bytecode stream: found multiple instances of cgraph node with uid %d"
 msgstr ""
 
-#: lto-cgraph.c:1472
+#: lto-cgraph.c:1474
 #, gcc-internal-format
 msgid "bytecode stream: no caller found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1478
+#: lto-cgraph.c:1480
 #, gcc-internal-format
 msgid "bytecode stream: no callee found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1552
+#: lto-cgraph.c:1554
 #, gcc-internal-format
 msgid "bytecode stream: found empty cgraph node"
 msgstr ""
 
-#: lto-cgraph.c:1730
+#: lto-cgraph.c:1732
 #, gcc-internal-format, gfc-internal-format
 msgid "At most %i profile runs is supported. Perhaps corrupted profile?"
 msgstr ""
 
-#: lto-cgraph.c:1817
+#: lto-cgraph.c:1819
 #, gcc-internal-format, gfc-internal-format
 msgid "Profile information in %s corrupted"
 msgstr ""
 
-#: lto-cgraph.c:1855
+#: lto-cgraph.c:1857
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot find class `%s'"
 msgid "cannot find LTO cgraph in %s"
 msgstr "немагчыма знайсьці кляс `%s'"
 
-#: lto-cgraph.c:1865
+#: lto-cgraph.c:1867
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot find source %s"
 msgid "cannot find LTO section refs in %s"
 msgstr "не магу знайсці крыніцу %s"
 
-#: lto-cgraph.c:1946
+#: lto-cgraph.c:1948
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid offload table in %s"
 msgstr "Нерэчаісны выбар %s"
@@ -20885,83 +20896,89 @@
 msgid "bytecode stream in file %qs generated with LTO version %d.%d instead of the expected %d.%d"
 msgstr ""
 
-#: lto-wrapper.c:117
+#: lto-wrapper.c:118
 #, gcc-internal-format
 msgid "deleting LTRANS file %s: %m"
 msgstr ""
 
-#: lto-wrapper.c:154
+#: lto-wrapper.c:155
 #, gcc-internal-format
 msgid "malformed COLLECT_GCC_OPTIONS"
 msgstr ""
 
-#: lto-wrapper.c:308
+#: lto-wrapper.c:309
 #, gcc-internal-format, gfc-internal-format
 msgid "Option %s with different values"
 msgstr ""
 
-#: lto-wrapper.c:392
+#: lto-wrapper.c:393
 #, gcc-internal-format, gfc-internal-format
 msgid "Option %s not used consistently in all LTO input files"
 msgstr ""
 
-#: lto-wrapper.c:832
+#: lto-wrapper.c:833
 #, gcc-internal-format, gfc-internal-format
 msgid "problem with building target image for %s\n"
 msgstr ""
 
-#: lto-wrapper.c:852
+#: lto-wrapper.c:853
 #, fuzzy, gcc-internal-format
 msgid "reading input file"
 msgstr "няма ўваходзячых файлаў"
 
-#: lto-wrapper.c:857
+#: lto-wrapper.c:858
 #, fuzzy, gcc-internal-format
 msgid "writing output file"
 msgstr "не магу запісаць ў %s"
 
-#: lto-wrapper.c:889
+#: lto-wrapper.c:890
 #, gcc-internal-format
 msgid "installation error, can't find crtoffloadtable.o"
 msgstr ""
 
-#: lto-wrapper.c:1000 lto-wrapper.c:1012
+#: lto-wrapper.c:1001 lto-wrapper.c:1013
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s: %s: "
 msgid "%s: %s\n"
 msgstr "%s: %s: "
 
-#: lto-wrapper.c:1056
+#: lto-wrapper.c:1064
 #, gcc-internal-format
 msgid "environment variable COLLECT_GCC must be set"
 msgstr ""
 
-#: lto-wrapper.c:1060 config/nvptx/mkoffload.c:363
+#: lto-wrapper.c:1068 config/nvptx/mkoffload.c:363
 #, gcc-internal-format
 msgid "environment variable COLLECT_GCC_OPTIONS must be set"
 msgstr ""
 
-#: lto-wrapper.c:1229 lto-wrapper.c:1285
+#: lto-wrapper.c:1237 lto-wrapper.c:1293
 #, fuzzy, gcc-internal-format
 #| msgid "can't open %s"
 msgid "cannot open %s: %m"
 msgstr "немагчыма адчыніць %s"
 
-#: lto-wrapper.c:1232 lto-wrapper.c:1291
+#: lto-wrapper.c:1240 lto-wrapper.c:1299
 #, fuzzy, gcc-internal-format
 msgid "cannot read %s: %m"
 msgstr "не магу прачытаць з %s"
 
-#: lto-wrapper.c:1259
+#: lto-wrapper.c:1267
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid format of %s"
 msgstr "Нерэчаісны выбар %s"
 
-#: lto-wrapper.c:1482
+#: lto-wrapper.c:1491
 #, gcc-internal-format
 msgid "fopen: %s: %m"
 msgstr ""
 
+#: lto-wrapper.c:1508
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "can't open output file `%s'"
+msgid "Corrupted ltrans output file %s"
+msgstr "немагчыма адчыніць файл уводу `%s'"
+
 #: multiple_target.c:76
 #, fuzzy, gcc-internal-format
 msgid "the call requires ifunc, which is not supported by this target"
@@ -21317,12 +21334,12 @@
 msgid "unrecognized argument in option %qs"
 msgstr "нераспазнаны выбар \"-%s\""
 
-#: opts-common.c:1198 config/i386/i386.c:3206
+#: opts-common.c:1198 config/i386/i386.c:3209
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: opts-common.c:1201 config/i386/i386.c:3209
+#: opts-common.c:1201 config/i386/i386.c:3212
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "нявернае выкарыстанне \"restict\""
@@ -21929,22 +21946,22 @@
 msgid "output operand %d must use %<&%> constraint"
 msgstr ""
 
-#: regcprop.c:1187
+#: regcprop.c:1193
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad next_regno for empty chain (%u)"
 msgstr ""
 
-#: regcprop.c:1199
+#: regcprop.c:1205
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: Loop in regno chain (%u)"
 msgstr ""
 
-#: regcprop.c:1202
+#: regcprop.c:1208
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad oldest_regno (%u)"
 msgstr ""
 
-#: regcprop.c:1214
+#: regcprop.c:1220
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Non-empty reg in chain (%s %u %i)"
 msgstr ""
@@ -21988,7 +22005,7 @@
 msgstr ""
 
 #: reginfo.c:789 config/powerpcspe/powerpcspe.c:32259
-#: config/rs6000/rs6000.c:29453
+#: config/rs6000/rs6000.c:29530
 #, gcc-internal-format
 msgid "conflicts with %qD"
 msgstr ""
@@ -22237,153 +22254,158 @@
 msgid "function symbol is not function"
 msgstr "функцыя не вяртае тып string"
 
-#: symtab.c:1006
+#: symtab.c:1005
+#, gcc-internal-format
+msgid "inconsistent `ifunc' attribute"
+msgstr ""
+
+#: symtab.c:1013
 #, fuzzy, gcc-internal-format
 msgid "variable symbol is not variable"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: symtab.c:1012
+#: symtab.c:1019
 #, gcc-internal-format
 msgid "node has unknown type"
 msgstr ""
 
-#: symtab.c:1021
+#: symtab.c:1028
 #, gcc-internal-format
 msgid "node not found node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.c:1029
+#: symtab.c:1036
 #, gcc-internal-format
 msgid "node differs from node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.c:1038
+#: symtab.c:1045
 #, gcc-internal-format
 msgid "assembler name hash list corrupted"
 msgstr ""
 
-#: symtab.c:1051
+#: symtab.c:1058
 #, gcc-internal-format
 msgid "node not found in symtab assembler name hash"
 msgstr ""
 
-#: symtab.c:1058
+#: symtab.c:1065
 #, gcc-internal-format
 msgid "double linked list of assembler names corrupted"
 msgstr ""
 
-#: symtab.c:1063
+#: symtab.c:1070
 #, gcc-internal-format
 msgid "node has body_removed but is definition"
 msgstr ""
 
-#: symtab.c:1068
+#: symtab.c:1075
 #, gcc-internal-format
 msgid "node is analyzed but it is not a definition"
 msgstr ""
 
-#: symtab.c:1073
+#: symtab.c:1080
 #, gcc-internal-format
 msgid "node is alias but not implicit alias"
 msgstr ""
 
-#: symtab.c:1078
+#: symtab.c:1085
 #, fuzzy, gcc-internal-format
 #| msgid "label `%s' used but not defined"
 msgid "node is alias but not definition"
 msgstr "адмеціна `%s' выкарыстоўвываецца, але ня вызначана"
 
-#: symtab.c:1083
+#: symtab.c:1090
 #, gcc-internal-format
 msgid "node is weakref but not an transparent_alias"
 msgstr ""
 
-#: symtab.c:1088
+#: symtab.c:1095
 #, gcc-internal-format
 msgid "node is transparent_alias but not an alias"
 msgstr ""
 
-#: symtab.c:1097
+#: symtab.c:1104
 #, gcc-internal-format
 msgid "node is in same_comdat_group list but has no comdat_group"
 msgstr ""
 
-#: symtab.c:1102
+#: symtab.c:1109
 #, gcc-internal-format
 msgid "same_comdat_group list across different groups"
 msgstr ""
 
-#: symtab.c:1107
+#: symtab.c:1114
 #, gcc-internal-format
 msgid "mixing different types of symbol in same comdat groups is not supported"
 msgstr ""
 
-#: symtab.c:1112
+#: symtab.c:1119
 #, gcc-internal-format
 msgid "node is alone in a comdat group"
 msgstr ""
 
-#: symtab.c:1119
+#: symtab.c:1126
 #, gcc-internal-format
 msgid "same_comdat_group is not a circular list"
 msgstr ""
 
-#: symtab.c:1134
+#: symtab.c:1141
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local symbol referred to by %s outside its comdat"
 msgstr ""
 
-#: symtab.c:1144
+#: symtab.c:1151
 #, gcc-internal-format
 msgid "implicit_section flag is set but section isn't"
 msgstr ""
 
-#: symtab.c:1151
+#: symtab.c:1158
 #, gcc-internal-format
 msgid "Both section and comdat group is set"
 msgstr ""
 
-#: symtab.c:1163
+#: symtab.c:1170
 #, gcc-internal-format
 msgid "Alias and target's section differs"
 msgstr ""
 
-#: symtab.c:1170
+#: symtab.c:1177
 #, gcc-internal-format
 msgid "Alias and target's comdat groups differs"
 msgstr ""
 
-#: symtab.c:1185
+#: symtab.c:1192
 #, gcc-internal-format
 msgid "Transparent alias and target's assembler names differs"
 msgstr ""
 
-#: symtab.c:1193
+#: symtab.c:1200
 #, gcc-internal-format
 msgid "Chained transparent aliases"
 msgstr ""
 
-#: symtab.c:1216 symtab.c:1253
+#: symtab.c:1223 symtab.c:1260
 #, gcc-internal-format
 msgid "symtab_node::verify failed"
 msgstr ""
 
-#: symtab.c:1249
+#: symtab.c:1256
 #, gcc-internal-format
 msgid "Two symbols with same comdat_group are not linked by the same_comdat_group list."
 msgstr ""
 
-#: symtab.c:1658
+#: symtab.c:1665
 #, gcc-internal-format
 msgid "function %q+D part of alias cycle"
 msgstr ""
 
-#: symtab.c:1660
+#: symtab.c:1667
 #, gcc-internal-format
 msgid "variable %q+D part of alias cycle"
 msgstr ""
 
-#: symtab.c:1688
+#: symtab.c:1695
 #, gcc-internal-format
 msgid "section of alias %q+D must match section of its target"
 msgstr ""
@@ -23199,7 +23221,7 @@
 msgid "the first argument of a VEC_COND_EXPR must be of a boolean vector type of the same number of elements as the result"
 msgstr ""
 
-#: tree-cfg.c:4395 c/c-typeck.c:5212
+#: tree-cfg.c:4395 c/c-typeck.c:5217
 #, gcc-internal-format
 msgid "type mismatch in conditional expression"
 msgstr ""
@@ -23555,22 +23577,22 @@
 msgid "missing edge %i->%i"
 msgstr "прапушчана поле '%s' у '%s'"
 
-#: tree-cfg.c:9379
+#: tree-cfg.c:9388
 #, gcc-internal-format
 msgid "%<noreturn%> function does return"
 msgstr ""
 
-#: tree-cfg.c:9400 tree-cfg.c:9432
+#: tree-cfg.c:9409 tree-cfg.c:9441
 #, gcc-internal-format
 msgid "control reaches end of non-void function"
 msgstr ""
 
-#: tree-cfg.c:9498 cp/cvt.c:1039
+#: tree-cfg.c:9507 cp/cvt.c:1039
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgstr ""
 
-#: tree-cfg.c:9503 cp/cvt.c:1046
+#: tree-cfg.c:9512 cp/cvt.c:1046
 #, gcc-internal-format
 msgid "ignoring return value of function declared with attribute warn_unused_result"
 msgstr ""
@@ -23835,46 +23857,46 @@
 msgid "stmt volatile flag not up-to-date"
 msgstr ""
 
-#: tree-ssa-strlen.c:1975
+#: tree-ssa-strlen.c:1999
 msgid "%G%qD output truncated before terminating nul copying %E byte from a string of the same length"
 msgid_plural "%G%qD output truncated before terminating nul copying %E bytes from a string of the same length"
 msgstr[0] ""
 msgstr[1] ""
 
-#: tree-ssa-strlen.c:1989
+#: tree-ssa-strlen.c:2013
 msgid "%G%qD output truncated copying %E byte from a string of length %wu"
 msgid_plural "%G%qD output truncated copying %E bytes from a string of length %wu"
 msgstr[0] ""
 msgstr[1] ""
 
-#: tree-ssa-strlen.c:1996
+#: tree-ssa-strlen.c:2020
 msgid "%G%qD output truncated copying between %wu and %wu bytes from a string of length %wu"
 msgstr ""
 
-#: tree-ssa-strlen.c:2008
+#: tree-ssa-strlen.c:2032
 msgid "%G%qD output may be truncated copying %E byte from a string of length %wu"
 msgid_plural "%G%qD output may be truncated copying %E bytes from a string of length %wu"
 msgstr[0] ""
 msgstr[1] ""
 
-#: tree-ssa-strlen.c:2015 tree-ssa-strlen.c:2029
+#: tree-ssa-strlen.c:2039 tree-ssa-strlen.c:2053
 msgid "%G%qD output may be truncated copying between %wu and %wu bytes from a string of length %wu"
 msgstr ""
 
-#: tree-ssa-strlen.c:2150
+#: tree-ssa-strlen.c:2174
 msgid "%G%qD output truncated before terminating nul copying as many bytes from a string as its length"
 msgstr ""
 
-#: tree-ssa-strlen.c:2156
+#: tree-ssa-strlen.c:2180
 msgid "%G%qD specified bound depends on the length of the source argument"
 msgstr ""
 
-#: tree-ssa-strlen.c:2163
+#: tree-ssa-strlen.c:2187
 #, gcc-internal-format
 msgid "length computed here"
 msgstr ""
 
-#: tree-ssa-uninit.c:191 varasm.c:331
+#: tree-ssa-uninit.c:191 varasm.c:342
 #, fuzzy, gcc-internal-format
 msgid "%qD was declared here"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
@@ -24053,27 +24075,27 @@
 msgid "target specific builtin not available"
 msgstr ""
 
-#: tree-vect-generic.c:287
+#: tree-vect-generic.c:283
 #, gcc-internal-format
 msgid "vector operation will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-generic.c:290
+#: tree-vect-generic.c:286
 #, gcc-internal-format
 msgid "vector operation will be expanded in parallel"
 msgstr ""
 
-#: tree-vect-generic.c:341
+#: tree-vect-generic.c:337
 #, gcc-internal-format
 msgid "vector operation will be expanded with a single scalar operation"
 msgstr ""
 
-#: tree-vect-generic.c:941
+#: tree-vect-generic.c:937
 #, gcc-internal-format
 msgid "vector condition will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-generic.c:1373
+#: tree-vect-generic.c:1369
 #, gcc-internal-format
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr ""
@@ -24083,27 +24105,27 @@
 msgid "vectorization did not happen for a simd loop"
 msgstr ""
 
-#: tree-vrp.c:4930 tree-vrp.c:4974
+#: tree-vrp.c:4931 tree-vrp.c:4975
 #, gcc-internal-format
 msgid "array subscript %E is above array bounds of %qT"
 msgstr ""
 
-#: tree-vrp.c:4956
+#: tree-vrp.c:4957
 #, gcc-internal-format
 msgid "array subscript [%E, %E] is outside array bounds of %qT"
 msgstr ""
 
-#: tree-vrp.c:4988
+#: tree-vrp.c:4989
 #, gcc-internal-format
 msgid "array subscript %E is below array bounds of %qT"
 msgstr ""
 
-#: tree-vrp.c:5046
+#: tree-vrp.c:5047
 #, gcc-internal-format
 msgid "array subscript %wi is below array bounds of %qT"
 msgstr ""
 
-#: tree-vrp.c:5060
+#: tree-vrp.c:5061
 #, gcc-internal-format
 msgid "array subscript %wu is above array bounds of %qT"
 msgstr ""
@@ -24118,92 +24140,92 @@
 msgid "side-effects element in no-side-effects CONSTRUCTOR"
 msgstr ""
 
-#: tree.c:7852
+#: tree.c:7856
 #, gcc-internal-format
 msgid "arrays of functions are not meaningful"
 msgstr ""
 
-#: tree.c:8019
+#: tree.c:8023
 #, gcc-internal-format
 msgid "function return type cannot be function"
 msgstr ""
 
-#: tree.c:9327 tree.c:9412 tree.c:9473
+#: tree.c:9331 tree.c:9416 tree.c:9477
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: %s, have %s in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9364
+#: tree.c:9368
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected none of %s, have %s in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9377
+#: tree.c:9381
 #, gcc-internal-format
 msgid "tree check: expected class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9426
+#: tree.c:9430
 #, gcc-internal-format
 msgid "tree check: did not expect class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9439
+#: tree.c:9443
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected omp_clause %s, have %s in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9499
+#: tree.c:9503
 #, gcc-internal-format
 msgid "tree check: expected tree that contains %qs structure, have %qs in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9513
+#: tree.c:9517
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_int_cst with %d elts in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9525
+#: tree.c:9529
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_vec with %d elts in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9538
+#: tree.c:9542
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of %s with %d operands in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9551
+#: tree.c:9555
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of omp_clause %s with %d operands in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:12446
+#: tree.c:12450
 #, gcc-internal-format
 msgid "%qD is deprecated: %s"
 msgstr ""
 
-#: tree.c:12449
+#: tree.c:12453
 #, gcc-internal-format
 msgid "%qD is deprecated"
 msgstr ""
 
-#: tree.c:12473 tree.c:12495
+#: tree.c:12477 tree.c:12499
 #, gcc-internal-format
 msgid "%qE is deprecated: %s"
 msgstr ""
 
-#: tree.c:12476 tree.c:12498
+#: tree.c:12480 tree.c:12502
 #, gcc-internal-format
 msgid "%qE is deprecated"
 msgstr ""
 
-#: tree.c:12482 tree.c:12503
+#: tree.c:12486 tree.c:12507
 #, gcc-internal-format, gfc-internal-format
 msgid "type is deprecated: %s"
 msgstr ""
 
-#: tree.c:12485 tree.c:12506
+#: tree.c:12489 tree.c:12510
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr ""
@@ -24228,243 +24250,243 @@
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.c:13043
+#: tree.c:13047
 #, gcc-internal-format, gfc-internal-format
 msgid "type variant differs by %s"
 msgstr ""
 
-#: tree.c:13084
+#: tree.c:13088
 #, gcc-internal-format
 msgid "type variant has different TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13086
+#: tree.c:13090
 #, gcc-internal-format
 msgid "type variant's TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13088
+#: tree.c:13092
 #, gcc-internal-format
 msgid "type's TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13108
+#: tree.c:13112
 #, gcc-internal-format
 msgid "type variant with TYPE_ALIAS_SET_KNOWN_P"
 msgstr ""
 
-#: tree.c:13121
+#: tree.c:13125
 #, gcc-internal-format
 msgid "type variant has different TYPE_VFIELD"
 msgstr ""
 
-#: tree.c:13157
+#: tree.c:13161
 #, gcc-internal-format
 msgid "type variant has different TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13159
+#: tree.c:13163
 #, gcc-internal-format
 msgid "type variant's TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13161
+#: tree.c:13165
 #, gcc-internal-format
 msgid "type's TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13199
+#: tree.c:13203
 #, gcc-internal-format
 msgid "type variant has different TYPE_FIELDS"
 msgstr ""
 
-#: tree.c:13201
+#: tree.c:13205
 #, gcc-internal-format
 msgid "first mismatch is field"
 msgstr ""
 
-#: tree.c:13203
+#: tree.c:13207
 #, gcc-internal-format
 msgid "and field"
 msgstr ""
 
-#: tree.c:13220
+#: tree.c:13224
 #, gcc-internal-format
 msgid "type variant has different TREE_TYPE"
 msgstr ""
 
-#: tree.c:13222 tree.c:13233
+#: tree.c:13226 tree.c:13237
 #, gcc-internal-format
 msgid "type variant's TREE_TYPE"
 msgstr ""
 
-#: tree.c:13224 tree.c:13235
+#: tree.c:13228 tree.c:13239
 #, gcc-internal-format
 msgid "type's TREE_TYPE"
 msgstr ""
 
-#: tree.c:13231
+#: tree.c:13235
 #, gcc-internal-format
 msgid "type is not compatible with its variant"
 msgstr ""
 
-#: tree.c:13534
+#: tree.c:13538
 #, gcc-internal-format
 msgid "Main variant is not defined"
 msgstr ""
 
-#: tree.c:13539
+#: tree.c:13543
 #, gcc-internal-format
 msgid "TYPE_MAIN_VARIANT has different TYPE_MAIN_VARIANT"
 msgstr ""
 
-#: tree.c:13551
+#: tree.c:13555
 #, gcc-internal-format
 msgid "TYPE_CANONICAL has different TYPE_CANONICAL"
 msgstr ""
 
-#: tree.c:13569
+#: tree.c:13573
 #, gcc-internal-format
 msgid "TYPE_CANONICAL is not compatible"
 msgstr ""
 
-#: tree.c:13577
+#: tree.c:13581
 #, gcc-internal-format
 msgid "TYPE_MODE of TYPE_CANONICAL is not compatible"
 msgstr ""
 
-#: tree.c:13583
+#: tree.c:13587
 #, gcc-internal-format
 msgid "TYPE_CANONICAL of main variant is not main variant"
 msgstr ""
 
-#: tree.c:13599
+#: tree.c:13603
 #, gcc-internal-format
 msgid "TYPE_VFIELD is not FIELD_DECL nor TREE_LIST"
 msgstr ""
 
-#: tree.c:13609
+#: tree.c:13613
 #, gcc-internal-format
 msgid "TYPE_NEXT_PTR_TO is not POINTER_TYPE"
 msgstr ""
 
-#: tree.c:13619
+#: tree.c:13623
 #, gcc-internal-format
 msgid "TYPE_NEXT_REF_TO is not REFERENCE_TYPE"
 msgstr ""
 
-#: tree.c:13640
+#: tree.c:13644
 #, gcc-internal-format
 msgid "TYPE_BINFO is not TREE_BINFO"
 msgstr ""
 
-#: tree.c:13646
+#: tree.c:13650
 #, gcc-internal-format
 msgid "TYPE_BINFO type is not TYPE_MAIN_VARIANT"
 msgstr ""
 
-#: tree.c:13657
+#: tree.c:13661
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not record nor union"
 msgstr ""
 
-#: tree.c:13668
+#: tree.c:13672
 #, gcc-internal-format
 msgid "TYPE_OFFSET_BASETYPE is not record nor union"
 msgstr ""
 
-#: tree.c:13686
+#: tree.c:13690
 #, gcc-internal-format
 msgid "TYPE_ARRAY_MAX_SIZE not INTEGER_CST"
 msgstr ""
 
-#: tree.c:13693
+#: tree.c:13697
 #, gcc-internal-format
 msgid "TYPE_MAX_VALUE_RAW non-NULL"
 msgstr ""
 
-#: tree.c:13700
+#: tree.c:13704
 #, gcc-internal-format
 msgid "TYPE_LANG_SLOT_1 (binfo) field is non-NULL"
 msgstr ""
 
-#: tree.c:13716
+#: tree.c:13720
 #, gcc-internal-format
 msgid "Enum value is not CONST_DECL or INTEGER_CST"
 msgstr ""
 
-#: tree.c:13724
+#: tree.c:13728
 #, gcc-internal-format
 msgid "Enum value type is not INTEGER_TYPE nor convertible to the enum"
 msgstr ""
 
-#: tree.c:13731
+#: tree.c:13735
 #, gcc-internal-format
 msgid "Enum value name is not IDENTIFIER_NODE"
 msgstr ""
 
-#: tree.c:13741
+#: tree.c:13745
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%D' has non-integer type"
 msgid "Array TYPE_DOMAIN is not integer type"
 msgstr "памер масіва `%D' не цэлалікавы тып"
 
-#: tree.c:13750
+#: tree.c:13754
 #, fuzzy, gcc-internal-format
 msgid "TYPE_FIELDS defined in incomplete type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: tree.c:13772
+#: tree.c:13776
 #, gcc-internal-format
 msgid "Wrong tree in TYPE_FIELDS list"
 msgstr ""
 
-#: tree.c:13787
+#: tree.c:13791
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is %i while TYPE_CACHED_VALUES is %p"
 msgstr ""
 
-#: tree.c:13793
+#: tree.c:13797
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES is not TREE_VEC"
 msgstr ""
 
-#: tree.c:13806
+#: tree.c:13810
 #, gcc-internal-format
 msgid "wrong TYPE_CACHED_VALUES entry"
 msgstr ""
 
-#: tree.c:13819
+#: tree.c:13823
 #, gcc-internal-format
 msgid "TREE_PURPOSE is non-NULL in TYPE_ARG_TYPES list"
 msgstr ""
 
-#: tree.c:13825
+#: tree.c:13829
 #, gcc-internal-format
 msgid "Wrong entry in TYPE_ARG_TYPES list"
 msgstr ""
 
-#: tree.c:13832
+#: tree.c:13836
 #, gcc-internal-format
 msgid "TYPE_VALUES_RAW field is non-NULL"
 msgstr ""
 
-#: tree.c:13844
+#: tree.c:13848
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is set while it should not"
 msgstr ""
 
-#: tree.c:13850
+#: tree.c:13854
 #, gcc-internal-format
 msgid "TYPE_STRING_FLAG is set on wrong type code"
 msgstr ""
 
-#: tree.c:13860
+#: tree.c:13864
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not main variant"
 msgstr ""
 
-#: tree.c:13867
+#: tree.c:13871
 #, gcc-internal-format
 msgid "verify_type failed"
 msgstr ""
@@ -24489,184 +24511,184 @@
 msgid "corrupted value profile: %s profile counter (%d out of %d) inconsistent with basic-block count (%d)"
 msgstr ""
 
-#: var-tracking.c:7166
+#: var-tracking.c:7184
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded with -fvar-tracking-assignments, retrying without"
 msgstr ""
 
-#: var-tracking.c:7170
+#: var-tracking.c:7188
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded"
 msgstr ""
 
-#: varasm.c:326
+#: varasm.c:337
 #, gcc-internal-format
 msgid "%+qD causes a section type conflict with %qD"
 msgstr ""
 
-#: varasm.c:329
+#: varasm.c:340
 #, gcc-internal-format
 msgid "section type conflict with %qD"
 msgstr ""
 
-#: varasm.c:334
+#: varasm.c:345
 #, gcc-internal-format
 msgid "%+qD causes a section type conflict"
 msgstr ""
 
-#: varasm.c:336
+#: varasm.c:347
 #, gcc-internal-format
 msgid "section type conflict"
 msgstr ""
 
-#: varasm.c:1019
+#: varasm.c:1030
 #, gcc-internal-format
 msgid "alignment of %q+D is greater than maximum object file alignment %d"
 msgstr ""
 
-#: varasm.c:1172
+#: varasm.c:1183
 #, fuzzy, gcc-internal-format
 #| msgid "can't initialize friend function `%s'"
 msgid "only zero initializers are allowed in section %qs"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: varasm.c:1378 varasm.c:1387
+#: varasm.c:1389 varasm.c:1398
 #, gcc-internal-format
 msgid "register name not specified for %q+D"
 msgstr ""
 
-#: varasm.c:1389
+#: varasm.c:1400
 #, fuzzy, gcc-internal-format
 #| msgid "invalid register name for `%s'"
 msgid "invalid register name for %q+D"
 msgstr "нерэчаісная назва рэгістра `%s'"
 
-#: varasm.c:1391
+#: varasm.c:1402
 #, gcc-internal-format
 msgid "data type of %q+D isn%'t suitable for a register"
 msgstr ""
 
-#: varasm.c:1394
+#: varasm.c:1405
 #, gcc-internal-format
 msgid "the register specified for %q+D cannot be accessed by the current target"
 msgstr ""
 
-#: varasm.c:1397
+#: varasm.c:1408
 #, gcc-internal-format
 msgid "the register specified for %q+D is not general enough to be used as a register variable"
 msgstr ""
 
-#: varasm.c:1400
+#: varasm.c:1411
 #, gcc-internal-format
 msgid "register specified for %q+D isn%'t suitable for data type"
 msgstr ""
 
-#: varasm.c:1410
+#: varasm.c:1421
 #, gcc-internal-format
 msgid "global register variable has initial value"
 msgstr ""
 
-#: varasm.c:1414
+#: varasm.c:1425
 #, gcc-internal-format
 msgid "optimization may eliminate reads and/or writes to register variables"
 msgstr ""
 
-#: varasm.c:1460
+#: varasm.c:1471
 #, gcc-internal-format
 msgid "register name given for non-register variable %q+D"
 msgstr ""
 
-#: varasm.c:1870
+#: varasm.c:1881
 #, gcc-internal-format
 msgid "Patchable function entry > size"
 msgstr ""
 
-#: varasm.c:2069
+#: varasm.c:2080
 #, gcc-internal-format
 msgid "thread-local COMMON data not implemented"
 msgstr ""
 
-#: varasm.c:2102
+#: varasm.c:2113
 #, gcc-internal-format
 msgid "requested alignment for %q+D is greater than implemented alignment of %wu"
 msgstr ""
 
-#: varasm.c:2205 c/c-decl.c:5027 c/c-parser.c:1534
+#: varasm.c:2216 c/c-decl.c:5027 c/c-parser.c:1534
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t known"
 msgstr ""
 
-#: varasm.c:4910
+#: varasm.c:4921
 #, gcc-internal-format
 msgid "initializer for integer/fixed-point value is too complicated"
 msgstr ""
 
-#: varasm.c:4915
+#: varasm.c:4926
 #, gcc-internal-format
 msgid "initializer for floating value is not a floating constant"
 msgstr ""
 
-#: varasm.c:5227
+#: varasm.c:5238
 #, fuzzy, gcc-internal-format
 msgid "invalid initial value for member %qE"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: varasm.c:5487
+#: varasm.c:5498
 #, gcc-internal-format
 msgid "%+qD declared weak after being used"
 msgstr ""
 
-#: varasm.c:5539
+#: varasm.c:5550
 #, gcc-internal-format
 msgid "weak declaration of %q+D being applied to a already existing, static definition"
 msgstr ""
 
-#: varasm.c:5575
+#: varasm.c:5586
 #, gcc-internal-format
 msgid "weak declaration of %q+D must be public"
 msgstr ""
 
-#: varasm.c:5579
+#: varasm.c:5590
 #, gcc-internal-format
 msgid "weak declaration of %q+D not supported"
 msgstr ""
 
-#: varasm.c:5608 varasm.c:5912
+#: varasm.c:5619 varasm.c:5926
 #, gcc-internal-format
 msgid "only weak aliases are supported in this configuration"
 msgstr ""
 
-#: varasm.c:5802
+#: varasm.c:5813
 #, fuzzy, gcc-internal-format
 msgid "weakref is not supported in this configuration"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: varasm.c:5834
+#: varasm.c:5846
 #, fuzzy, gcc-internal-format
 msgid "ifunc is not supported on this target"
 msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
 
-#: varasm.c:5892
+#: varasm.c:5904
 #, gcc-internal-format
 msgid "weakref %q+D ultimately targets itself"
 msgstr ""
 
-#: varasm.c:5894
+#: varasm.c:5906
 #, gcc-internal-format
 msgid "weakref %q+D must have static linkage"
 msgstr ""
 
-#: varasm.c:5901
+#: varasm.c:5913
 #, fuzzy, gcc-internal-format
 msgid "alias definitions not supported in this configuration"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: varasm.c:5909
+#: varasm.c:5923
 #, fuzzy, gcc-internal-format
 msgid "ifunc is not supported in this configuration"
 msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
 
-#: varasm.c:6127 config/sol2.c:159 config/i386/winnt.c:265
+#: varasm.c:6141 config/sol2.c:159 config/i386/winnt.c:265
 #, fuzzy, gcc-internal-format
 msgid "visibility attribute not supported in this configuration; ignored"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
@@ -24742,164 +24764,169 @@
 msgid "bytecode stream: tag %s is not in the expected range [%s, %s]"
 msgstr ""
 
-#: c-family/c-attribs.c:529
+#: c-family/c-attribs.c:524
 #, fuzzy, gcc-internal-format
+msgid "%qE attribute ignored for type %qT"
+msgstr "\"%s\" атрыбут ігнарыруецца"
+
+#: c-family/c-attribs.c:536
+#, fuzzy, gcc-internal-format
 msgid "%qE attribute ignored for field of type %qT"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: c-family/c-attribs.c:696
+#: c-family/c-attribs.c:706
 #, gcc-internal-format
 msgid "no_sanitize argument not a string"
 msgstr ""
 
-#: c-family/c-attribs.c:826 ada/gcc-interface/utils.c:6235
+#: c-family/c-attribs.c:837 ada/gcc-interface/utils.c:6240
 #, gcc-internal-format
 msgid "%qE attribute ignored due to conflict with attribute %qs"
 msgstr ""
 
-#: c-family/c-attribs.c:875
+#: c-family/c-attribs.c:886
 #, gcc-internal-format
 msgid "%qE attribute ignored. Use -fcf-protection option to enable it"
 msgstr ""
 
-#: c-family/c-attribs.c:914 c-family/c-attribs.c:920 c-family/c-attribs.c:3388
-#: c-family/c-attribs.c:3423 c-family/c-attribs.c:3429
+#: c-family/c-attribs.c:925 c-family/c-attribs.c:931 c-family/c-attribs.c:3399
+#: c-family/c-attribs.c:3434 c-family/c-attribs.c:3440
 #, gcc-internal-format
 msgid "%qE attribute ignored due to conflict with %qs attribute"
 msgstr ""
 
-#: c-family/c-attribs.c:976 brig/brig-lang.c:482 lto/lto-lang.c:288
+#: c-family/c-attribs.c:987 brig/brig-lang.c:482 lto/lto-lang.c:288
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute has no effect on unit local functions"
 msgstr "\"%s\" звычайна функцыя"
 
-#: c-family/c-attribs.c:1130
+#: c-family/c-attribs.c:1141
 #, gcc-internal-format
 msgid "%qE attribute have effect only on public objects"
 msgstr ""
 
-#: c-family/c-attribs.c:1159
+#: c-family/c-attribs.c:1170
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only affects top level objects"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: c-family/c-attribs.c:1198 c-family/c-attribs.c:2682
+#: c-family/c-attribs.c:1209 c-family/c-attribs.c:2693
 #, gcc-internal-format
 msgid "%qE attribute on function returning %<void%>"
 msgstr ""
 
-#: c-family/c-attribs.c:1221 c-family/c-pragma.c:419
+#: c-family/c-attribs.c:1232 c-family/c-pragma.c:419
 #, gcc-internal-format
 msgid "scalar_storage_order is not supported because endianness is not uniform"
 msgstr ""
 
-#: c-family/c-attribs.c:1238
+#: c-family/c-attribs.c:1249
 #, gcc-internal-format
 msgid "scalar_storage_order argument must be one of \"big-endian\" or \"little-endian\""
 msgstr ""
 
-#: c-family/c-attribs.c:1334
+#: c-family/c-attribs.c:1345
 #, fuzzy, gcc-internal-format
 #| msgid "section attributes are not supported for this target"
 msgid "destructor priorities are not supported"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: c-family/c-attribs.c:1336
+#: c-family/c-attribs.c:1347
 #, fuzzy, gcc-internal-format
 #| msgid "section attributes are not supported for this target"
 msgid "constructor priorities are not supported"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: c-family/c-attribs.c:1358
+#: c-family/c-attribs.c:1369
 #, gcc-internal-format, gfc-internal-format
 msgid "destructor priorities from 0 to %d are reserved for the implementation"
 msgstr ""
 
-#: c-family/c-attribs.c:1363
+#: c-family/c-attribs.c:1374
 #, gcc-internal-format, gfc-internal-format
 msgid "constructor priorities from 0 to %d are reserved for the implementation"
 msgstr ""
 
-#: c-family/c-attribs.c:1371
+#: c-family/c-attribs.c:1382
 #, gcc-internal-format, gfc-internal-format
 msgid "destructor priorities must be integers from 0 to %d inclusive"
 msgstr ""
 
-#: c-family/c-attribs.c:1374
+#: c-family/c-attribs.c:1385
 #, gcc-internal-format, gfc-internal-format
 msgid "constructor priorities must be integers from 0 to %d inclusive"
 msgstr ""
 
-#: c-family/c-attribs.c:1527
+#: c-family/c-attribs.c:1538
 #, fuzzy, gcc-internal-format
 #| msgid "unknown machine mode `%s'"
 msgid "unknown machine mode %qE"
 msgstr "невядомы рэжым машыны \"%s\""
 
-#: c-family/c-attribs.c:1557
+#: c-family/c-attribs.c:1568
 #, gcc-internal-format
 msgid "specifying vector types with __attribute__ ((mode)) is deprecated"
 msgstr ""
 
-#: c-family/c-attribs.c:1560
+#: c-family/c-attribs.c:1571
 #, gcc-internal-format
 msgid "use __attribute__ ((vector_size)) instead"
 msgstr ""
 
-#: c-family/c-attribs.c:1569
+#: c-family/c-attribs.c:1580
 #, fuzzy, gcc-internal-format
 #| msgid "unable to open file '%s'"
 msgid "unable to emulate %qs"
 msgstr "немагу адчыніць файл \"%s\""
 
-#: c-family/c-attribs.c:1582
+#: c-family/c-attribs.c:1593
 #, fuzzy, gcc-internal-format
 msgid "invalid pointer mode %qs"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: c-family/c-attribs.c:1599
+#: c-family/c-attribs.c:1610
 #, gcc-internal-format
 msgid "signedness of type and machine mode %qs don%'t match"
 msgstr ""
 
-#: c-family/c-attribs.c:1610
+#: c-family/c-attribs.c:1621
 #, fuzzy, gcc-internal-format
 #| msgid "no data type for mode `%s'"
 msgid "no data type for mode %qs"
 msgstr "няма тыпа дадзеных для рэжыма \"%s\""
 
-#: c-family/c-attribs.c:1620
+#: c-family/c-attribs.c:1631
 #, gcc-internal-format
 msgid "cannot use mode %qs for enumeral types"
 msgstr ""
 
-#: c-family/c-attribs.c:1647
+#: c-family/c-attribs.c:1658
 #, fuzzy, gcc-internal-format
 msgid "mode %qs applied to inappropriate type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: c-family/c-attribs.c:1669
+#: c-family/c-attribs.c:1680
 #, gcc-internal-format
 msgid "section attributes are not supported for this target"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: c-family/c-attribs.c:1675
+#: c-family/c-attribs.c:1686
 #, fuzzy, gcc-internal-format
 #| msgid "section attributes are not supported for this target"
 msgid "section attribute not allowed for %q+D"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: c-family/c-attribs.c:1681
+#: c-family/c-attribs.c:1692
 #, fuzzy, gcc-internal-format
 msgid "section attribute argument not a string constant"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: c-family/c-attribs.c:1690
+#: c-family/c-attribs.c:1701
 #, gcc-internal-format
 msgid "section attribute cannot be specified for local variables"
 msgstr ""
 
-#: c-family/c-attribs.c:1700 config/bfin/bfin.c:4806 config/bfin/bfin.c:4857
+#: c-family/c-attribs.c:1711 config/bfin/bfin.c:4806 config/bfin/bfin.c:4857
 #: config/bfin/bfin.c:4883 config/bfin/bfin.c:4896
 #, fuzzy, gcc-internal-format
 #| msgid "section of `%s' conflicts with previous declaration"
@@ -24906,313 +24933,313 @@
 msgid "section of %q+D conflicts with previous declaration"
 msgstr "секцыя \"%s\" канфліктуе з папярэдняй дэкларацыяй"
 
-#: c-family/c-attribs.c:1708
+#: c-family/c-attribs.c:1719
 #, fuzzy, gcc-internal-format
 msgid "section of %q+D cannot be overridden"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: c-family/c-attribs.c:1773
+#: c-family/c-attribs.c:1784
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "requested alignment %d is larger than %d"
 msgstr "памер \"%s\" больш чам %d байт"
 
-#: c-family/c-attribs.c:1866
+#: c-family/c-attribs.c:1877
 #, gcc-internal-format
 msgid "alignment may not be specified for %q+D"
 msgstr ""
 
-#: c-family/c-attribs.c:1886
+#: c-family/c-attribs.c:1897
 #, gcc-internal-format
 msgid "ignoring attribute %<%E (%u)%> because it conflicts with attribute %<%E (%u)%>"
 msgstr ""
 
 #. Do not error out for attribute warn_if_not_aligned.
-#: c-family/c-attribs.c:1891 c-family/c-attribs.c:1920
+#: c-family/c-attribs.c:1902 c-family/c-attribs.c:1931
 #, fuzzy, gcc-internal-format
 msgid "alignment for %q+D must be at least %d"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: c-family/c-attribs.c:1916
+#: c-family/c-attribs.c:1927
 #, gcc-internal-format
 msgid "alignment for %q+D was previously specified as %d and may not be decreased"
 msgstr ""
 
-#: c-family/c-attribs.c:1943
+#: c-family/c-attribs.c:1954
 #, gcc-internal-format
 msgid "%<warn_if_not_aligned%> may not be specified for %q+D"
 msgstr ""
 
-#: c-family/c-attribs.c:1986
+#: c-family/c-attribs.c:1997
 #, fuzzy, gcc-internal-format
 msgid "inline function %q+D declared weak"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: c-family/c-attribs.c:1991
+#: c-family/c-attribs.c:2002
 #, fuzzy, gcc-internal-format
 msgid "indirect function %q+D cannot be declared weak"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: c-family/c-attribs.c:2015
+#: c-family/c-attribs.c:2026
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is only applicable on functions"
 msgstr "\"%s\" звычайна функцыя"
 
-#: c-family/c-attribs.c:2046
+#: c-family/c-attribs.c:2057
 #, gcc-internal-format
 msgid "%q+D defined both normally and as %qE attribute"
 msgstr ""
 
-#: c-family/c-attribs.c:2054
+#: c-family/c-attribs.c:2065
 #, gcc-internal-format
 msgid "weak %q+D cannot be defined %qE"
 msgstr ""
 
-#: c-family/c-attribs.c:2071 c-family/c-attribs.c:2582
+#: c-family/c-attribs.c:2082 c-family/c-attribs.c:2593
 #, gcc-internal-format
 msgid "attribute %qE argument not a string"
 msgstr ""
 
-#: c-family/c-attribs.c:2106
+#: c-family/c-attribs.c:2117
 #, gcc-internal-format
 msgid "%+qD declared alias after being used"
 msgstr ""
 
-#: c-family/c-attribs.c:2108
+#: c-family/c-attribs.c:2119
 #, gcc-internal-format
 msgid "%+qD declared ifunc after being used"
 msgstr ""
 
-#: c-family/c-attribs.c:2159
+#: c-family/c-attribs.c:2170
 #, fuzzy, gcc-internal-format
 msgid "indirect function %q+D cannot be declared weakref"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: c-family/c-attribs.c:2181
+#: c-family/c-attribs.c:2192
 #, gcc-internal-format
 msgid "weakref attribute must appear before alias attribute"
 msgstr ""
 
-#: c-family/c-attribs.c:2193
+#: c-family/c-attribs.c:2204
 #, gcc-internal-format
 msgid "%+qD declared weakref after being used"
 msgstr ""
 
-#: c-family/c-attribs.c:2217
+#: c-family/c-attribs.c:2228
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute ignored on non-class types"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: c-family/c-attribs.c:2223
+#: c-family/c-attribs.c:2234
 #, gcc-internal-format
 msgid "%qE attribute ignored because %qT is already defined"
 msgstr ""
 
-#: c-family/c-attribs.c:2236
+#: c-family/c-attribs.c:2247
 #, fuzzy, gcc-internal-format
 msgid "visibility argument not a string"
 msgstr "аргумент для \"%s\" прапушчан"
 
-#: c-family/c-attribs.c:2248
+#: c-family/c-attribs.c:2259
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute ignored on types"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: c-family/c-attribs.c:2264
+#: c-family/c-attribs.c:2275
 #, gcc-internal-format
 msgid "visibility argument must be one of \"default\", \"hidden\", \"protected\" or \"internal\""
 msgstr ""
 
-#: c-family/c-attribs.c:2275
+#: c-family/c-attribs.c:2286
 #, gcc-internal-format
 msgid "%qD redeclared with different visibility"
 msgstr ""
 
-#: c-family/c-attribs.c:2278 c-family/c-attribs.c:2282
+#: c-family/c-attribs.c:2289 c-family/c-attribs.c:2293
 #, gcc-internal-format
 msgid "%qD was declared %qs which implies default visibility"
 msgstr ""
 
-#: c-family/c-attribs.c:2320
+#: c-family/c-attribs.c:2331
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function"
 msgid "tls_model argument not a string"
 msgstr "не хапае аргументаў у функцыі"
 
-#: c-family/c-attribs.c:2333
+#: c-family/c-attribs.c:2344
 #, gcc-internal-format
 msgid "tls_model argument must be one of \"local-exec\", \"initial-exec\", \"local-dynamic\" or \"global-dynamic\""
 msgstr ""
 
-#: c-family/c-attribs.c:2353 c-family/c-attribs.c:2656
-#: c-family/c-attribs.c:3497 config/m32c/m32c.c:2944
+#: c-family/c-attribs.c:2364 c-family/c-attribs.c:2667
+#: c-family/c-attribs.c:3508 config/m32c/m32c.c:2944
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applies only to functions"
 msgstr "\"%s\" звычайна функцыя"
 
-#: c-family/c-attribs.c:2417
+#: c-family/c-attribs.c:2428
 #, gcc-internal-format
 msgid "alloc_size parameter outside range"
 msgstr ""
 
-#: c-family/c-attribs.c:2443
+#: c-family/c-attribs.c:2454
 #, gcc-internal-format
 msgid "alloc_align parameter outside range"
 msgstr ""
 
-#: c-family/c-attribs.c:2467
+#: c-family/c-attribs.c:2478
 #, gcc-internal-format
 msgid "assume_aligned parameter not integer constant"
 msgstr ""
 
-#: c-family/c-attribs.c:2595
+#: c-family/c-attribs.c:2606
 #, gcc-internal-format
 msgid "only %<inbranch%> and %<notinbranch%> flags are allowed for %<__simd__%> attribute"
 msgstr ""
 
-#: c-family/c-attribs.c:2662 c-family/c-attribs.c:3503
+#: c-family/c-attribs.c:2673 c-family/c-attribs.c:3514
 #, gcc-internal-format
 msgid "can%'t set %qE attribute after definition"
 msgstr ""
 
-#: c-family/c-attribs.c:2727
+#: c-family/c-attribs.c:2738
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored"
 msgid "%qE attribute duplicated"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: c-family/c-attribs.c:2729
+#: c-family/c-attribs.c:2740
 #, gcc-internal-format
 msgid "%qE attribute follows %qE"
 msgstr ""
 
-#: c-family/c-attribs.c:2828
+#: c-family/c-attribs.c:2839
 #, fuzzy, gcc-internal-format
 msgid "type was previously declared %qE"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: c-family/c-attribs.c:2841 cp/class.c:4397
+#: c-family/c-attribs.c:2852 cp/class.c:4401
 #, gcc-internal-format
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
 msgstr ""
 
-#: c-family/c-attribs.c:2899
+#: c-family/c-attribs.c:2910
 #, gcc-internal-format
 msgid "%qE argument not an identifier"
 msgstr ""
 
-#: c-family/c-attribs.c:2910
+#: c-family/c-attribs.c:2921
 #, gcc-internal-format
 msgid "%qD is not compatible with %qD"
 msgstr ""
 
-#: c-family/c-attribs.c:2913
+#: c-family/c-attribs.c:2924
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function,"
 msgid "%qE argument is not a function"
 msgstr "`%D' - гэта ня функцыя,"
 
-#: c-family/c-attribs.c:2961
+#: c-family/c-attribs.c:2972
 #, gcc-internal-format
 msgid "deprecated message is not a string"
 msgstr ""
 
-#: c-family/c-attribs.c:3002
+#: c-family/c-attribs.c:3013
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute ignored for %qE"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: c-family/c-attribs.c:3065
+#: c-family/c-attribs.c:3076
 #, fuzzy, gcc-internal-format
 msgid "invalid vector type for attribute %qE"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: c-family/c-attribs.c:3071 ada/gcc-interface/utils.c:3896
+#: c-family/c-attribs.c:3082 ada/gcc-interface/utils.c:3899
 #, gcc-internal-format
 msgid "vector size not an integral multiple of component size"
 msgstr ""
 
-#: c-family/c-attribs.c:3077 ada/gcc-interface/utils.c:3903
+#: c-family/c-attribs.c:3088 ada/gcc-interface/utils.c:3906
 #, gcc-internal-format
 msgid "zero vector size"
 msgstr ""
 
-#: c-family/c-attribs.c:3085
+#: c-family/c-attribs.c:3096
 #, gcc-internal-format
 msgid "number of components of the vector not a power of two"
 msgstr ""
 
-#: c-family/c-attribs.c:3118 ada/gcc-interface/utils.c:6092
+#: c-family/c-attribs.c:3129 ada/gcc-interface/utils.c:6098
 #, gcc-internal-format
 msgid "nonnull attribute without arguments on a non-prototype"
 msgstr ""
 
-#: c-family/c-attribs.c:3137 ada/gcc-interface/utils.c:6106
+#: c-family/c-attribs.c:3148 ada/gcc-interface/utils.c:6112
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument has invalid operand number (argument %lu)"
 msgstr ""
 
-#: c-family/c-attribs.c:3159 ada/gcc-interface/utils.c:6128
+#: c-family/c-attribs.c:3170 ada/gcc-interface/utils.c:6134
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument with out-of-range operand number (argument %lu, operand %lu)"
 msgstr ""
 
-#: c-family/c-attribs.c:3168 ada/gcc-interface/utils.c:6137
+#: c-family/c-attribs.c:3179 ada/gcc-interface/utils.c:6143
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument references non-pointer operand (argument %lu, operand %lu)"
 msgstr ""
 
-#: c-family/c-attribs.c:3208
+#: c-family/c-attribs.c:3219
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute ignored on objects of type %qT"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: c-family/c-attribs.c:3216
+#: c-family/c-attribs.c:3227
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute does not apply to functions"
 msgstr "\"%s\" звычайна функцыя"
 
-#: c-family/c-attribs.c:3273
+#: c-family/c-attribs.c:3284
 #, gcc-internal-format
 msgid "cleanup argument not an identifier"
 msgstr ""
 
-#: c-family/c-attribs.c:3280
+#: c-family/c-attribs.c:3291
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function"
 msgid "cleanup argument not a function"
 msgstr "вельмі шмат аргументаў у функцыі"
 
-#: c-family/c-attribs.c:3317
+#: c-family/c-attribs.c:3328
 #, gcc-internal-format
 msgid "%qE attribute requires prototypes with named arguments"
 msgstr ""
 
-#: c-family/c-attribs.c:3325
+#: c-family/c-attribs.c:3336
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only applies to variadic functions"
 msgstr "\"%s\" звычайна функцыя"
 
-#: c-family/c-attribs.c:3341 ada/gcc-interface/utils.c:6179
+#: c-family/c-attribs.c:3352 ada/gcc-interface/utils.c:6185
 #, fuzzy, gcc-internal-format
 msgid "requested position is not an integer constant"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: c-family/c-attribs.c:3349 ada/gcc-interface/utils.c:6186
+#: c-family/c-attribs.c:3360 ada/gcc-interface/utils.c:6192
 #, gcc-internal-format
 msgid "requested position is less than zero"
 msgstr ""
 
-#: c-family/c-attribs.c:3404
+#: c-family/c-attribs.c:3415
 #, gcc-internal-format
 msgid "empty string in attribute %<target%>"
 msgstr ""
 
-#: c-family/c-attribs.c:3520
+#: c-family/c-attribs.c:3531
 #, gcc-internal-format
 msgid "returns_nonnull attribute on a function not returning a pointer"
 msgstr ""
 
-#: c-family/c-attribs.c:3535
+#: c-family/c-attribs.c:3546
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is only valid on %<struct%> type"
 msgstr "\"%s\" звычайна функцыя"
@@ -25257,12 +25284,12 @@
 msgid "__builtin_shuffle argument vector(s) inner type must have the same size as inner type of the mask"
 msgstr ""
 
-#: c-family/c-common.c:1262 c-family/c-warn.c:1194
+#: c-family/c-common.c:1262 c-family/c-warn.c:1202
 #, gcc-internal-format
 msgid "unsigned conversion from %qT to %qT changes value from %qE to %qE"
 msgstr ""
 
-#: c-family/c-common.c:1267 c-family/c-warn.c:1202
+#: c-family/c-common.c:1267 c-family/c-warn.c:1210
 #, gcc-internal-format
 msgid "unsigned conversion from %qT to %qT changes the value of %qE"
 msgstr ""
@@ -25392,7 +25419,7 @@
 msgid "suggest parentheses around assignment used as truth value"
 msgstr ""
 
-#: c-family/c-common.c:3518 c/c-decl.c:4325 c/c-decl.c:6430 c/c-typeck.c:14177
+#: c-family/c-common.c:3518 c/c-decl.c:4325 c/c-decl.c:6450 c/c-typeck.c:14182
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `restrict'"
 msgid "invalid use of %<restrict%>"
@@ -25473,7 +25500,7 @@
 msgid "duplicate case value"
 msgstr ""
 
-#: c-family/c-common.c:4867 c-family/c-warn.c:2216
+#: c-family/c-common.c:4867 c-family/c-warn.c:2225
 #, gcc-internal-format
 msgid "previously used here"
 msgstr ""
@@ -25519,32 +25546,32 @@
 msgid "missing sentinel in function call"
 msgstr ""
 
-#: c-family/c-common.c:5411
+#: c-family/c-common.c:5409
 #, gcc-internal-format, gfc-internal-format
 msgid "null argument where non-null required (argument %lu)"
 msgstr ""
 
-#: c-family/c-common.c:5506 c-family/c-common.c:5553
+#: c-family/c-common.c:5504 c-family/c-common.c:5551
 #, gcc-internal-format
 msgid "bad option %qs to attribute %<optimize%>"
 msgstr ""
 
-#: c-family/c-common.c:5509 c-family/c-common.c:5557
+#: c-family/c-common.c:5507 c-family/c-common.c:5555
 #, gcc-internal-format
 msgid "bad option %qs to pragma %<optimize%>"
 msgstr ""
 
-#: c-family/c-common.c:5589
+#: c-family/c-common.c:5587
 #, gcc-internal-format
 msgid "%<fallthrough%> attribute specified multiple times"
 msgstr ""
 
-#: c-family/c-common.c:5593
+#: c-family/c-common.c:5591
 #, gcc-internal-format
 msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr ""
 
-#: c-family/c-common.c:5733 c-family/c-common.c:6485 c-family/c-common.c:6558
+#: c-family/c-common.c:5731 c-family/c-common.c:6477 c-family/c-common.c:6550
 #: c/c-typeck.c:3555
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function"
@@ -25551,169 +25578,169 @@
 msgid "too few arguments to function %qE"
 msgstr "не хапае аргументаў у функцыі"
 
-#: c-family/c-common.c:5738 c-family/c-common.c:6584 c/c-typeck.c:3284
+#: c-family/c-common.c:5736 c-family/c-common.c:6576 c/c-typeck.c:3284
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function"
 msgid "too many arguments to function %qE"
 msgstr "вельмі шмат аргументаў у функцыі"
 
-#: c-family/c-common.c:5769
+#: c-family/c-common.c:5767
 #, fuzzy, gcc-internal-format
 msgid "third argument to function %qE must be a constant integer"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: c-family/c-common.c:5794
+#: c-family/c-common.c:5792
 #, gcc-internal-format
 msgid "second argument to function %qE must be a constant integer power of 2 between %qi and %qu bits"
 msgstr ""
 
-#: c-family/c-common.c:5815 c-family/c-common.c:5859
+#: c-family/c-common.c:5813 c-family/c-common.c:5857
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function `%s'"
 msgid "non-floating-point argument in call to function %qE"
 msgstr "вельмі шмат аргумэнтаў у функцыі `%s'"
 
-#: c-family/c-common.c:5838
+#: c-family/c-common.c:5836
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function `%s'"
 msgid "non-floating-point arguments in call to function %qE"
 msgstr "вельмі шмат аргумэнтаў у функцыі `%s'"
 
-#: c-family/c-common.c:5852
+#: c-family/c-common.c:5850
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function `%s'"
 msgid "non-const integer argument %u in call to function %qE"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: c-family/c-common.c:5872
+#: c-family/c-common.c:5870
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function `%s'"
 msgid "non-integer argument 3 in call to function %qE"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: c-family/c-common.c:5889 c-family/c-common.c:5925
+#: c-family/c-common.c:5887 c-family/c-common.c:5923
 #, gcc-internal-format
 msgid "argument %u in call to function %qE does not have integral type"
 msgstr ""
 
-#: c-family/c-common.c:5896
+#: c-family/c-common.c:5894
 #, gcc-internal-format
 msgid "argument 3 in call to function %qE does not have pointer to integral type"
 msgstr ""
 
-#: c-family/c-common.c:5902
+#: c-family/c-common.c:5900
 #, gcc-internal-format
 msgid "argument 3 in call to function %qE has pointer to enumerated type"
 msgstr ""
 
-#: c-family/c-common.c:5908
+#: c-family/c-common.c:5906
 #, gcc-internal-format
 msgid "argument 3 in call to function %qE has pointer to boolean type"
 msgstr ""
 
-#: c-family/c-common.c:5931
+#: c-family/c-common.c:5929
 #, gcc-internal-format
 msgid "argument 3 in call to function %qE has enumerated type"
 msgstr ""
 
-#: c-family/c-common.c:5937
+#: c-family/c-common.c:5935
 #, gcc-internal-format
 msgid "argument 3 in call to function %qE has boolean type"
 msgstr ""
 
-#: c-family/c-common.c:6184
+#: c-family/c-common.c:6183
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to static data member %qD"
 msgstr ""
 
-#: c-family/c-common.c:6189
+#: c-family/c-common.c:6188
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> when %<operator[]%> is overloaded"
 msgstr ""
 
-#: c-family/c-common.c:6196
+#: c-family/c-common.c:6195
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to a non constant address"
 msgstr ""
 
-#: c-family/c-common.c:6209
+#: c-family/c-common.c:6208
 #, fuzzy, gcc-internal-format
 msgid "attempt to take address of bit-field structure member %qD"
 msgstr "не магу атрымаць адрас бітавага поля \"%s\""
 
-#: c-family/c-common.c:6261
+#: c-family/c-common.c:6260
 #, gcc-internal-format
 msgid "index %E denotes an offset greater than size of %qT"
 msgstr ""
 
-#: c-family/c-common.c:6427 cp/init.c:3004 cp/init.c:3023
+#: c-family/c-common.c:6419 cp/init.c:3020 cp/init.c:3039
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%s' is too large"
 msgid "size of array is too large"
 msgstr "памер масіва \"%s\" вельмі вялікі"
 
-#: c-family/c-common.c:6517
+#: c-family/c-common.c:6509
 #, gcc-internal-format
 msgid "operand type %qT is incompatible with argument %d of %qE"
 msgstr ""
 
-#: c-family/c-common.c:6651
+#: c-family/c-common.c:6643
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function `%s'"
 msgid "incorrect number of arguments to function %qE"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: c-family/c-common.c:6665
+#: c-family/c-common.c:6657
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qE must be a non-void pointer type"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: c-family/c-common.c:6674
+#: c-family/c-common.c:6666
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a constant size type"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: c-family/c-common.c:6685
+#: c-family/c-common.c:6677
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a nonzero size object"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: c-family/c-common.c:6706
+#: c-family/c-common.c:6698
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must be a pointer type"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: c-family/c-common.c:6714
+#: c-family/c-common.c:6706
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must be a pointer to a constant size type"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: c-family/c-common.c:6720
+#: c-family/c-common.c:6712
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a function"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: c-family/c-common.c:6728
+#: c-family/c-common.c:6720
 #, gcc-internal-format
 msgid "size mismatch in argument %d of %qE"
 msgstr ""
 
-#: c-family/c-common.c:6740
+#: c-family/c-common.c:6732
 #, gcc-internal-format
 msgid "non-integer memory model argument %d of %qE"
 msgstr ""
 
-#: c-family/c-common.c:6753
+#: c-family/c-common.c:6745
 #, gcc-internal-format
 msgid "invalid memory model argument %d of %qE"
 msgstr ""
 
-#: c-family/c-common.c:7672
+#: c-family/c-common.c:7664
 #, gcc-internal-format
 msgid "index value is out of bound"
 msgstr ""
 
-#: c-family/c-common.c:7714 c-family/c-common.c:7763 c-family/c-common.c:7779
+#: c-family/c-common.c:7706 c-family/c-common.c:7755 c-family/c-common.c:7771
 #, gcc-internal-format
 msgid "conversion of scalar %qT to vector %qT involves truncation"
 msgstr ""
@@ -25720,24 +25747,24 @@
 
 #. Reject arguments that are built-in functions with
 #. no library fallback.
-#: c-family/c-common.c:7867
+#: c-family/c-common.c:7859
 #, gcc-internal-format
 msgid "built-in function %qE must be directly called"
 msgstr ""
 
-#: c-family/c-common.c:7889 c/c-decl.c:6177
+#: c-family/c-common.c:7881 c/c-decl.c:6197
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%s' is too large"
 msgid "size of array %qE is too large"
 msgstr "памер масіва \"%s\" вельмі вялікі"
 
-#: c-family/c-common.c:7891 c/c-decl.c:6180
+#: c-family/c-common.c:7883 c/c-decl.c:6200
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%s' is too large"
 msgid "size of unnamed array is too large"
 msgstr "памер масіва \"%s\" вельмі вялікі"
 
-#: c-family/c-common.c:7921
+#: c-family/c-common.c:7913
 #, gcc-internal-format
 msgid "environment variable SOURCE_DATE_EPOCH must expand to a non-negative integer less than or equal to %wd"
 msgstr ""
@@ -26268,7 +26295,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr ""
 
-#: c-family/c-omp.c:557 cp/semantics.c:8186
+#: c-family/c-omp.c:557 cp/semantics.c:8189
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr ""
@@ -26284,22 +26311,22 @@
 msgid "%qE is not initialized"
 msgstr "прапушчан ініцыялізатар"
 
-#: c-family/c-omp.c:599 cp/semantics.c:8076
+#: c-family/c-omp.c:599 cp/semantics.c:8079
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.c:704 cp/semantics.c:7732
+#: c-family/c-omp.c:704 cp/semantics.c:7735
 #, fuzzy, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: c-family/c-omp.c:711 cp/semantics.c:8082
+#: c-family/c-omp.c:711 cp/semantics.c:8085
 #, fuzzy, gcc-internal-format
 msgid "missing increment expression"
 msgstr "аргумент для \"%s\" прапушчан"
 
-#: c-family/c-omp.c:775 cp/semantics.c:7847
+#: c-family/c-omp.c:775 cp/semantics.c:7850
 #, fuzzy, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "нерэчаісны ініцыялізатар"
@@ -26355,114 +26382,129 @@
 msgid "%<-Wabi=1%> is not supported, using =2"
 msgstr "-pipe не падтрымліваецца"
 
-#: c-family/c-opts.c:612 fortran/cpp.c:350
+#: c-family/c-opts.c:610 fortran/cpp.c:350
 #, fuzzy, gcc-internal-format
 msgid "output filename specified twice"
 msgstr "не зададзены ўваходзячыя файлы"
 
-#: c-family/c-opts.c:799
+#: c-family/c-opts.c:797
 #, gcc-internal-format
 msgid "-fexcess-precision=standard for C++"
 msgstr ""
 
-#: c-family/c-opts.c:834
+#: c-family/c-opts.c:832
 #, gcc-internal-format
 msgid "-fno-gnu89-inline is only supported in GNU99 or C99 mode"
 msgstr ""
 
-#: c-family/c-opts.c:880
+#: c-family/c-opts.c:878
 #, gcc-internal-format
 msgid "-Wformat-y2k ignored without -Wformat"
 msgstr ""
 
-#: c-family/c-opts.c:882
+#: c-family/c-opts.c:880
 #, gcc-internal-format
 msgid "-Wformat-extra-args ignored without -Wformat"
 msgstr ""
 
-#: c-family/c-opts.c:884
+#: c-family/c-opts.c:882
 #, gcc-internal-format
 msgid "-Wformat-zero-length ignored without -Wformat"
 msgstr ""
 
-#: c-family/c-opts.c:886
+#: c-family/c-opts.c:884
 #, gcc-internal-format
 msgid "-Wformat-nonliteral ignored without -Wformat"
 msgstr ""
 
-#: c-family/c-opts.c:888
+#: c-family/c-opts.c:886
 #, gcc-internal-format
 msgid "-Wformat-contains-nul ignored without -Wformat"
 msgstr ""
 
-#: c-family/c-opts.c:890
+#: c-family/c-opts.c:888
 #, gcc-internal-format
 msgid "-Wformat-security ignored without -Wformat"
 msgstr ""
 
-#: c-family/c-opts.c:928
+#: c-family/c-opts.c:918
 #, gcc-internal-format
 msgid "%<-fabi-compat-version=1%> is not supported, using =2"
 msgstr ""
 
-#: c-family/c-opts.c:988
+#: c-family/c-opts.c:944
+#, gcc-internal-format
+msgid "-Wabi won't warn about anything"
+msgstr ""
+
+#: c-family/c-opts.c:946
+#, gcc-internal-format
+msgid "-Wabi warns about differences from the most up-to-date ABI, which is also used by default"
+msgstr ""
+
+#: c-family/c-opts.c:949
+#, gcc-internal-format
+msgid "use e.g. -Wabi=11 to warn about changes from GCC 7"
+msgstr ""
+
+#: c-family/c-opts.c:1003
 #, fuzzy, gcc-internal-format
 msgid "external TLS initialization functions not supported on this target"
 msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
 
-#: c-family/c-opts.c:1001
+#: c-family/c-opts.c:1016
 #, gcc-internal-format, gfc-internal-format
 msgid "too many filenames given.  Type %s --help for usage"
 msgstr ""
 
-#: c-family/c-opts.c:1016
+#: c-family/c-opts.c:1031
 #, fuzzy, gcc-internal-format
 #| msgid "can't open output file `%s'"
 msgid "opening output file %s: %m"
 msgstr "немагчыма адчыніць файл уводу `%s'"
 
-#: c-family/c-opts.c:1036
+#: c-family/c-opts.c:1051
 #, gcc-internal-format, gfc-internal-format
 msgid "the \"%s\" debug format cannot be used with pre-compiled headers"
 msgstr ""
 
-#: c-family/c-opts.c:1190
+#: c-family/c-opts.c:1205
 #, gcc-internal-format
 msgid "opening dependency file %s: %m"
 msgstr ""
 
-#: c-family/c-opts.c:1201
+#: c-family/c-opts.c:1216
 #, gcc-internal-format
 msgid "closing dependency file %s: %m"
 msgstr ""
 
-#: c-family/c-opts.c:1204
+#: c-family/c-opts.c:1219
 #, fuzzy, gcc-internal-format
 #| msgid "error writing to %s"
 msgid "when writing output to %s: %m"
 msgstr "памылка запісу ў %s"
 
-#: c-family/c-opts.c:1284
+#: c-family/c-opts.c:1299
 #, gcc-internal-format
 msgid "to generate dependencies you must specify either -M or -MM"
 msgstr ""
 
-#: c-family/c-opts.c:1307
+#: c-family/c-opts.c:1322
 #, gcc-internal-format
 msgid "-MG may only be used with -M or -MM"
 msgstr ""
 
-#: c-family/c-opts.c:1340
+#: c-family/c-opts.c:1355
 #, gcc-internal-format
 msgid "-fdirectives-only is incompatible with -Wunused_macros"
 msgstr ""
 
-#: c-family/c-opts.c:1342
+#: c-family/c-opts.c:1357
 #, gcc-internal-format
 msgid "-fdirectives-only is incompatible with -traditional"
 msgstr ""
 
-#: c-family/c-opts.c:1534
+#: c-family/c-opts.c:1549
 #, gcc-internal-format
 msgid "too late for # directive to set debug directory"
 msgstr ""
@@ -26854,738 +26896,738 @@
 msgid "wrong type argument to %s"
 msgstr "не хапае аргументаў у функцыі"
 
-#: c-family/c-warn.c:53 c-family/c-warn.c:66 cp/constexpr.c:1847
+#: c-family/c-warn.c:54 c-family/c-warn.c:67 cp/constexpr.c:1847
 #: cp/constexpr.c:4099
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr ""
 
-#: c-family/c-warn.c:93
+#: c-family/c-warn.c:94
 #, gcc-internal-format
 msgid "integer overflow in expression %qE of type %qT results in %qE"
 msgstr ""
 
-#: c-family/c-warn.c:95
+#: c-family/c-warn.c:96
 #, gcc-internal-format
 msgid "integer overflow in expression of type %qT results in %qE"
 msgstr ""
 
-#: c-family/c-warn.c:101
+#: c-family/c-warn.c:102
 #, gcc-internal-format
 msgid "floating point overflow in expression %qE of type %qT results in %qE"
 msgstr ""
 
-#: c-family/c-warn.c:103
+#: c-family/c-warn.c:104
 #, gcc-internal-format
 msgid "floating point overflow in expression of type %qT results in %qE"
 msgstr ""
 
-#: c-family/c-warn.c:109
+#: c-family/c-warn.c:110
 #, gcc-internal-format
 msgid "fixed-point overflow in expression %qE of type %qT results in %qE"
 msgstr ""
 
-#: c-family/c-warn.c:111
+#: c-family/c-warn.c:112
 #, gcc-internal-format
 msgid "fixed-point overflow in expression of type %qT results in %qE"
 msgstr ""
 
-#: c-family/c-warn.c:117
+#: c-family/c-warn.c:118
 #, gcc-internal-format
 msgid "vector overflow in expression %qE of type %qT results in %qE"
 msgstr ""
 
-#: c-family/c-warn.c:119
+#: c-family/c-warn.c:120
 #, gcc-internal-format
 msgid "vector overflow in expression of type %qT results in %qE"
 msgstr ""
 
-#: c-family/c-warn.c:126
+#: c-family/c-warn.c:127
 #, gcc-internal-format
 msgid "complex integer overflow in expression %qE of type %qT results in %qE"
 msgstr ""
 
-#: c-family/c-warn.c:128
+#: c-family/c-warn.c:129
 #, gcc-internal-format
 msgid "complex integer overflow in expression of type %qT results in %qE"
 msgstr ""
 
-#: c-family/c-warn.c:132
+#: c-family/c-warn.c:133
 #, gcc-internal-format
 msgid "complex floating point overflow in expression %qE of type %qT results in %qE"
 msgstr ""
 
-#: c-family/c-warn.c:134
+#: c-family/c-warn.c:135
 #, gcc-internal-format
 msgid "complex floating point overflow in expression of type %qT results in %qE"
 msgstr ""
 
-#: c-family/c-warn.c:216
+#: c-family/c-warn.c:217
 #, gcc-internal-format
 msgid "logical %<or%> applied to non-boolean constant"
 msgstr ""
 
-#: c-family/c-warn.c:219
+#: c-family/c-warn.c:220
 #, gcc-internal-format
 msgid "logical %<and%> applied to non-boolean constant"
 msgstr ""
 
-#: c-family/c-warn.c:289
+#: c-family/c-warn.c:290
 #, gcc-internal-format
 msgid "logical %<or%> of collectively exhaustive tests is always true"
 msgstr ""
 
-#: c-family/c-warn.c:293
+#: c-family/c-warn.c:294
 #, gcc-internal-format
 msgid "logical %<and%> of mutually exclusive tests is always false"
 msgstr ""
 
-#: c-family/c-warn.c:303
+#: c-family/c-warn.c:304
 #, gcc-internal-format
 msgid "logical %<or%> of equal expressions"
 msgstr ""
 
-#: c-family/c-warn.c:306
+#: c-family/c-warn.c:307
 #, gcc-internal-format
 msgid "logical %<and%> of equal expressions"
 msgstr ""
 
-#: c-family/c-warn.c:384
+#: c-family/c-warn.c:385
 #, gcc-internal-format
 msgid "bitwise comparison always evaluates to false"
 msgstr ""
 
-#: c-family/c-warn.c:387
+#: c-family/c-warn.c:388
 #, gcc-internal-format
 msgid "bitwise comparison always evaluates to true"
 msgstr ""
 
-#: c-family/c-warn.c:441
+#: c-family/c-warn.c:442
 #, gcc-internal-format
 msgid "self-comparison always evaluates to true"
 msgstr ""
 
-#: c-family/c-warn.c:444
+#: c-family/c-warn.c:445
 #, gcc-internal-format
 msgid "self-comparison always evaluates to false"
 msgstr ""
 
-#: c-family/c-warn.c:494
+#: c-family/c-warn.c:495
 #, gcc-internal-format
 msgid "logical not is only applied to the left hand side of comparison"
 msgstr ""
 
-#: c-family/c-warn.c:502
+#: c-family/c-warn.c:503
 #, gcc-internal-format
 msgid "add parentheses around left hand side expression to silence this warning"
 msgstr ""
 
-#: c-family/c-warn.c:636
+#: c-family/c-warn.c:637
 #, gcc-internal-format
 msgid "type-punning to incomplete type might break strict-aliasing rules"
 msgstr ""
 
-#: c-family/c-warn.c:654
+#: c-family/c-warn.c:655
 #, gcc-internal-format
 msgid "dereferencing type-punned pointer will break strict-aliasing rules"
 msgstr ""
 
-#: c-family/c-warn.c:662 c-family/c-warn.c:680
+#: c-family/c-warn.c:663 c-family/c-warn.c:681
 #, gcc-internal-format
 msgid "dereferencing type-punned pointer might break strict-aliasing rules"
 msgstr ""
 
-#: c-family/c-warn.c:803
+#: c-family/c-warn.c:811
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to use the size of the destination?"
 msgstr ""
 
-#: c-family/c-warn.c:834
+#: c-family/c-warn.c:842
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the destination; did you mean to remove the addressof?"
 msgstr ""
 
-#: c-family/c-warn.c:841
+#: c-family/c-warn.c:849
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the destination; did you mean to provide an explicit length?"
 msgstr ""
 
-#: c-family/c-warn.c:846
+#: c-family/c-warn.c:854
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the destination; did you mean to dereference it?"
 msgstr ""
 
-#: c-family/c-warn.c:858
+#: c-family/c-warn.c:866
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the destination; expected %qT or an explicit length"
 msgstr ""
 
-#: c-family/c-warn.c:874
+#: c-family/c-warn.c:882
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to remove the addressof?"
 msgstr ""
 
-#: c-family/c-warn.c:881
+#: c-family/c-warn.c:889
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to provide an explicit length?"
 msgstr ""
 
-#: c-family/c-warn.c:886
+#: c-family/c-warn.c:894
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to dereference it?"
 msgstr ""
 
-#: c-family/c-warn.c:898
+#: c-family/c-warn.c:906
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the source; expected %qT or an explicit length"
 msgstr ""
 
-#: c-family/c-warn.c:914
+#: c-family/c-warn.c:922
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the first source; did you mean to remove the addressof?"
 msgstr ""
 
-#: c-family/c-warn.c:921
+#: c-family/c-warn.c:929
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the first source; did you mean to provide an explicit length?"
 msgstr ""
 
-#: c-family/c-warn.c:926
+#: c-family/c-warn.c:934
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the first source; did you mean to dereference it?"
 msgstr ""
 
-#: c-family/c-warn.c:938
+#: c-family/c-warn.c:946
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the first source; expected %qT or an explicit length"
 msgstr ""
 
-#: c-family/c-warn.c:954
+#: c-family/c-warn.c:962
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the second source; did you mean to remove the addressof?"
 msgstr ""
 
-#: c-family/c-warn.c:961
+#: c-family/c-warn.c:969
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the second source; did you mean to provide an explicit length?"
 msgstr ""
 
-#: c-family/c-warn.c:966
+#: c-family/c-warn.c:974
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the second source; did you mean to dereference it?"
 msgstr ""
 
-#: c-family/c-warn.c:978
+#: c-family/c-warn.c:986
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the second source; expected %qT or an explicit length"
 msgstr ""
 
-#: c-family/c-warn.c:1007 c-family/c-warn.c:1014
+#: c-family/c-warn.c:1015 c-family/c-warn.c:1022
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter type `%T'"
 msgid "%<_Atomic%>-qualified parameter type %qT of %q+D"
 msgstr "нерэчаісны тып парамэтра `%T'"
 
-#: c-family/c-warn.c:1024
+#: c-family/c-warn.c:1032
 #, fuzzy, gcc-internal-format
 #| msgid "first argument of `%s' should be `int'"
 msgid "first argument of %q+D should be %<int%>"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: c-family/c-warn.c:1033
+#: c-family/c-warn.c:1041
 #, fuzzy, gcc-internal-format
 #| msgid "second argument of `%s' should be `char **'"
 msgid "second argument of %q+D should be %<char **%>"
 msgstr "другім аргументам \"%s\" павінен быць \"char **\""
 
-#: c-family/c-warn.c:1042
+#: c-family/c-warn.c:1050
 #, fuzzy, gcc-internal-format
 #| msgid "second argument of `%s' should be `char **'"
 msgid "third argument of %q+D should probably be %<char **%>"
 msgstr "другім аргументам \"%s\" павінен быць \"char **\""
 
-#: c-family/c-warn.c:1053
+#: c-family/c-warn.c:1061
 #, gcc-internal-format
 msgid "%q+D takes only zero or two arguments"
 msgstr ""
 
-#: c-family/c-warn.c:1057
+#: c-family/c-warn.c:1065
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared as variadic function"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: c-family/c-warn.c:1099
+#: c-family/c-warn.c:1107
 #, gcc-internal-format
 msgid "conversion to %qT from boolean expression"
 msgstr ""
 
-#: c-family/c-warn.c:1117 c-family/c-warn.c:1192
+#: c-family/c-warn.c:1125 c-family/c-warn.c:1200
 #, gcc-internal-format
 msgid "conversion from %qT to %qT changes value from %qE to %qE"
 msgstr ""
 
-#: c-family/c-warn.c:1121 c-family/c-warn.c:1200
+#: c-family/c-warn.c:1129 c-family/c-warn.c:1208
 #, gcc-internal-format
 msgid "conversion from %qT to %qT changes the value of %qE"
 msgstr ""
 
-#: c-family/c-warn.c:1141
+#: c-family/c-warn.c:1149
 #, gcc-internal-format
 msgid "conversion from %qT to %qT discards imaginary component"
 msgstr ""
 
-#: c-family/c-warn.c:1153
+#: c-family/c-warn.c:1161
 #, fuzzy, gcc-internal-format
 #| msgid "converting from `%T' to `%T'"
 msgid "conversion from %qT to %qT may change value"
 msgstr "пераўтварэньне з `%T' у `%T'"
 
-#: c-family/c-warn.c:1213 c-family/c-warn.c:1230 c-family/c-warn.c:1247
+#: c-family/c-warn.c:1221 c-family/c-warn.c:1238 c-family/c-warn.c:1255
 #, gcc-internal-format
 msgid "overflow in conversion from %qT to %qT changes value from %qE to %qE"
 msgstr ""
 
-#: c-family/c-warn.c:1218 c-family/c-warn.c:1235 c-family/c-warn.c:1252
+#: c-family/c-warn.c:1226 c-family/c-warn.c:1243 c-family/c-warn.c:1260
 #, gcc-internal-format
 msgid "overflow in conversion from %qT to %qT changes the value of %qE"
 msgstr ""
 
-#: c-family/c-warn.c:1282
+#: c-family/c-warn.c:1290
 #, gcc-internal-format
 msgid "case value %qs not in enumerated type"
 msgstr ""
 
-#: c-family/c-warn.c:1287
+#: c-family/c-warn.c:1295
 #, gcc-internal-format
 msgid "case value %qs not in enumerated type %qT"
 msgstr ""
 
-#: c-family/c-warn.c:1348
+#: c-family/c-warn.c:1356
 #, gcc-internal-format
 msgid "switch missing default case"
 msgstr ""
 
-#: c-family/c-warn.c:1393
+#: c-family/c-warn.c:1401
 #, gcc-internal-format
 msgid "switch condition has boolean value"
 msgstr ""
 
-#: c-family/c-warn.c:1466
+#: c-family/c-warn.c:1474
 #, gcc-internal-format
 msgid "enumeration value %qE not handled in switch"
 msgstr ""
 
-#: c-family/c-warn.c:1494
+#: c-family/c-warn.c:1502
 #, gcc-internal-format
 msgid "the omitted middle operand in ?: will always be %<true%>, suggest explicit middle operand"
 msgstr ""
 
-#: c-family/c-warn.c:1515
+#: c-family/c-warn.c:1523
 #, gcc-internal-format
 msgid "assignment of member %qD in read-only object"
 msgstr ""
 
-#: c-family/c-warn.c:1517
+#: c-family/c-warn.c:1525
 #, gcc-internal-format
 msgid "increment of member %qD in read-only object"
 msgstr ""
 
-#: c-family/c-warn.c:1519
+#: c-family/c-warn.c:1527
 #, gcc-internal-format
 msgid "decrement of member %qD in read-only object"
 msgstr ""
 
-#: c-family/c-warn.c:1521
+#: c-family/c-warn.c:1529
 #, gcc-internal-format
 msgid "member %qD in read-only object used as %<asm%> output"
 msgstr ""
 
-#: c-family/c-warn.c:1525
+#: c-family/c-warn.c:1533
 #, gcc-internal-format
 msgid "assignment of read-only member %qD"
 msgstr ""
 
-#: c-family/c-warn.c:1526
+#: c-family/c-warn.c:1534
 #, gcc-internal-format
 msgid "increment of read-only member %qD"
 msgstr ""
 
-#: c-family/c-warn.c:1527
+#: c-family/c-warn.c:1535
 #, gcc-internal-format
 msgid "decrement of read-only member %qD"
 msgstr ""
 
-#: c-family/c-warn.c:1528
+#: c-family/c-warn.c:1536
 #, gcc-internal-format
 msgid "read-only member %qD used as %<asm%> output"
 msgstr ""
 
-#: c-family/c-warn.c:1532
+#: c-family/c-warn.c:1540
 #, gcc-internal-format
 msgid "assignment of read-only variable %qD"
 msgstr ""
 
-#: c-family/c-warn.c:1533
+#: c-family/c-warn.c:1541
 #, gcc-internal-format
 msgid "increment of read-only variable %qD"
 msgstr ""
 
-#: c-family/c-warn.c:1534
+#: c-family/c-warn.c:1542
 #, gcc-internal-format
 msgid "decrement of read-only variable %qD"
 msgstr ""
 
-#: c-family/c-warn.c:1535
+#: c-family/c-warn.c:1543
 #, gcc-internal-format
 msgid "read-only variable %qD used as %<asm%> output"
 msgstr ""
 
-#: c-family/c-warn.c:1538
+#: c-family/c-warn.c:1546
 #, gcc-internal-format
 msgid "assignment of read-only parameter %qD"
 msgstr ""
 
-#: c-family/c-warn.c:1539
+#: c-family/c-warn.c:1547
 #, gcc-internal-format
 msgid "increment of read-only parameter %qD"
 msgstr ""
 
-#: c-family/c-warn.c:1540
+#: c-family/c-warn.c:1548
 #, gcc-internal-format
 msgid "decrement of read-only parameter %qD"
 msgstr ""
 
-#: c-family/c-warn.c:1541
+#: c-family/c-warn.c:1549
 #, gcc-internal-format
 msgid "read-only parameter %qD use as %<asm%> output"
 msgstr ""
 
-#: c-family/c-warn.c:1546
+#: c-family/c-warn.c:1554
 #, gcc-internal-format
 msgid "assignment of read-only named return value %qD"
 msgstr ""
 
-#: c-family/c-warn.c:1548
+#: c-family/c-warn.c:1556
 #, gcc-internal-format
 msgid "increment of read-only named return value %qD"
 msgstr ""
 
-#: c-family/c-warn.c:1550
+#: c-family/c-warn.c:1558
 #, gcc-internal-format
 msgid "decrement of read-only named return value %qD"
 msgstr ""
 
-#: c-family/c-warn.c:1552
+#: c-family/c-warn.c:1560
 #, gcc-internal-format
 msgid "read-only named return value %qD used as %<asm%>output"
 msgstr ""
 
-#: c-family/c-warn.c:1557
+#: c-family/c-warn.c:1565
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function `%s'"
 msgid "assignment of function %qD"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: c-family/c-warn.c:1558
+#: c-family/c-warn.c:1566
 #, fuzzy, gcc-internal-format
 msgid "increment of function %qD"
 msgstr "вельмі шмат аргументаў у функцыі"
 
-#: c-family/c-warn.c:1559
+#: c-family/c-warn.c:1567
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function `%s'"
 msgid "decrement of function %qD"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: c-family/c-warn.c:1560
+#: c-family/c-warn.c:1568
 #, gcc-internal-format
 msgid "function %qD used as %<asm%> output"
 msgstr ""
 
-#: c-family/c-warn.c:1563 c/c-typeck.c:4762
+#: c-family/c-warn.c:1571 c/c-typeck.c:4767
 #, gcc-internal-format
 msgid "assignment of read-only location %qE"
 msgstr ""
 
-#: c-family/c-warn.c:1564 c/c-typeck.c:4765
+#: c-family/c-warn.c:1572 c/c-typeck.c:4770
 #, gcc-internal-format
 msgid "increment of read-only location %qE"
 msgstr ""
 
-#: c-family/c-warn.c:1565 c/c-typeck.c:4768
+#: c-family/c-warn.c:1573 c/c-typeck.c:4773
 #, gcc-internal-format
 msgid "decrement of read-only location %qE"
 msgstr ""
 
-#: c-family/c-warn.c:1566
+#: c-family/c-warn.c:1574
 #, gcc-internal-format
 msgid "read-only location %qE used as %<asm%> output"
 msgstr ""
 
-#: c-family/c-warn.c:1580
+#: c-family/c-warn.c:1588
 #, gcc-internal-format
 msgid "lvalue required as left operand of assignment"
 msgstr ""
 
-#: c-family/c-warn.c:1583
+#: c-family/c-warn.c:1591
 #, gcc-internal-format
 msgid "lvalue required as increment operand"
 msgstr ""
 
-#: c-family/c-warn.c:1586
+#: c-family/c-warn.c:1594
 #, gcc-internal-format
 msgid "lvalue required as decrement operand"
 msgstr ""
 
-#: c-family/c-warn.c:1589
+#: c-family/c-warn.c:1597
 #, gcc-internal-format
 msgid "lvalue required as unary %<&%> operand"
 msgstr ""
 
-#: c-family/c-warn.c:1592
+#: c-family/c-warn.c:1600
 #, gcc-internal-format
 msgid "lvalue required in asm statement"
 msgstr ""
 
-#: c-family/c-warn.c:1609
+#: c-family/c-warn.c:1617
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter type `%T'"
 msgid "invalid type argument (have %qT)"
 msgstr "нерэчаісны тып парамэтра `%T'"
 
-#: c-family/c-warn.c:1613
+#: c-family/c-warn.c:1621
 #, gcc-internal-format
 msgid "invalid type argument of array indexing (have %qT)"
 msgstr ""
 
-#: c-family/c-warn.c:1618
+#: c-family/c-warn.c:1626
 #, gcc-internal-format
 msgid "invalid type argument of unary %<*%> (have %qT)"
 msgstr ""
 
-#: c-family/c-warn.c:1623
+#: c-family/c-warn.c:1631
 #, fuzzy, gcc-internal-format
 msgid "invalid type argument of %<->%> (have %qT)"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: c-family/c-warn.c:1628
+#: c-family/c-warn.c:1636
 #, fuzzy, gcc-internal-format
 msgid "invalid type argument of %<->*%> (have %qT)"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: c-family/c-warn.c:1633
+#: c-family/c-warn.c:1641
 #, gcc-internal-format
 msgid "invalid type argument of implicit conversion (have %qT)"
 msgstr ""
 
-#: c-family/c-warn.c:1654
+#: c-family/c-warn.c:1662
 #, gcc-internal-format
 msgid "array subscript has type %<char%>"
 msgstr ""
 
-#: c-family/c-warn.c:1689 c-family/c-warn.c:1692
+#: c-family/c-warn.c:1697 c-family/c-warn.c:1700
 #, gcc-internal-format
 msgid "suggest parentheses around %<+%> inside %<<<%>"
 msgstr ""
 
-#: c-family/c-warn.c:1695 c-family/c-warn.c:1698
+#: c-family/c-warn.c:1703 c-family/c-warn.c:1706
 #, gcc-internal-format
 msgid "suggest parentheses around %<-%> inside %<<<%>"
 msgstr ""
 
-#: c-family/c-warn.c:1704 c-family/c-warn.c:1707
+#: c-family/c-warn.c:1712 c-family/c-warn.c:1715
 #, gcc-internal-format
 msgid "suggest parentheses around %<+%> inside %<>>%>"
 msgstr ""
 
-#: c-family/c-warn.c:1710 c-family/c-warn.c:1713
+#: c-family/c-warn.c:1718 c-family/c-warn.c:1721
 #, gcc-internal-format
 msgid "suggest parentheses around %<-%> inside %<>>%>"
 msgstr ""
 
-#: c-family/c-warn.c:1719 c-family/c-warn.c:1722
+#: c-family/c-warn.c:1727 c-family/c-warn.c:1730
 #, gcc-internal-format
 msgid "suggest parentheses around %<&&%> within %<||%>"
 msgstr ""
 
-#: c-family/c-warn.c:1729 c-family/c-warn.c:1733
+#: c-family/c-warn.c:1737 c-family/c-warn.c:1741
 #, gcc-internal-format
 msgid "suggest parentheses around arithmetic in operand of %<|%>"
 msgstr ""
 
-#: c-family/c-warn.c:1737 c-family/c-warn.c:1740
+#: c-family/c-warn.c:1745 c-family/c-warn.c:1748
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<|%>"
 msgstr ""
 
-#: c-family/c-warn.c:1745
+#: c-family/c-warn.c:1753
 #, gcc-internal-format
 msgid "suggest parentheses around operand of %<!%> or change %<|%> to %<||%> or %<!%> to %<~%>"
 msgstr ""
 
-#: c-family/c-warn.c:1753 c-family/c-warn.c:1757
+#: c-family/c-warn.c:1761 c-family/c-warn.c:1765
 #, gcc-internal-format
 msgid "suggest parentheses around arithmetic in operand of %<^%>"
 msgstr ""
 
-#: c-family/c-warn.c:1761 c-family/c-warn.c:1764
+#: c-family/c-warn.c:1769 c-family/c-warn.c:1772
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<^%>"
 msgstr ""
 
-#: c-family/c-warn.c:1770 c-family/c-warn.c:1773
+#: c-family/c-warn.c:1778 c-family/c-warn.c:1781
 #, gcc-internal-format
 msgid "suggest parentheses around %<+%> in operand of %<&%>"
 msgstr ""
 
-#: c-family/c-warn.c:1776 c-family/c-warn.c:1779
+#: c-family/c-warn.c:1784 c-family/c-warn.c:1787
 #, gcc-internal-format
 msgid "suggest parentheses around %<-%> in operand of %<&%>"
 msgstr ""
 
-#: c-family/c-warn.c:1783 c-family/c-warn.c:1786
+#: c-family/c-warn.c:1791 c-family/c-warn.c:1794
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<&%>"
 msgstr ""
 
-#: c-family/c-warn.c:1791
+#: c-family/c-warn.c:1799
 #, gcc-internal-format
 msgid "suggest parentheses around operand of %<!%> or change %<&%> to %<&&%> or %<!%> to %<~%>"
 msgstr ""
 
-#: c-family/c-warn.c:1798 c-family/c-warn.c:1801
+#: c-family/c-warn.c:1806 c-family/c-warn.c:1809
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<==%>"
 msgstr ""
 
-#: c-family/c-warn.c:1806 c-family/c-warn.c:1809
+#: c-family/c-warn.c:1814 c-family/c-warn.c:1817
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<!=%>"
 msgstr ""
 
-#: c-family/c-warn.c:1819 c-family/c-warn.c:1825
+#: c-family/c-warn.c:1827 c-family/c-warn.c:1833
 #, gcc-internal-format
 msgid "comparisons like %<X<=Y<=Z%> do not have their mathematical meaning"
 msgstr ""
 
-#: c-family/c-warn.c:1841
+#: c-family/c-warn.c:1849
 #, fuzzy, gcc-internal-format
 #| msgid "label `%D' defined but not used"
 msgid "label %q+D defined but not used"
 msgstr "адмеціна `%D' вызначана, але не выкарыстоўваецца"
 
-#: c-family/c-warn.c:1843
+#: c-family/c-warn.c:1851
 #, fuzzy, gcc-internal-format
 #| msgid "label `%D' used but not defined"
 msgid "label %q+D declared but not defined"
 msgstr "адмеціна `%D' выкарыстоўвываецца, але ня вызначана"
 
-#: c-family/c-warn.c:1866
+#: c-family/c-warn.c:1874
 #, gcc-internal-format
 msgid "division by zero"
 msgstr ""
 
-#: c-family/c-warn.c:1886
+#: c-family/c-warn.c:1894
 #, gcc-internal-format
 msgid "%<memset%> used with constant zero length parameter; this could be due to transposed parameters"
 msgstr ""
 
-#: c-family/c-warn.c:1909
+#: c-family/c-warn.c:1918
 #, gcc-internal-format
 msgid "%<memset%> used with length equal to number of elements without multiplication by element size"
 msgstr ""
 
-#: c-family/c-warn.c:1948 c/c-typeck.c:11499 c/c-typeck.c:11667
+#: c-family/c-warn.c:1957 c/c-typeck.c:11504 c/c-typeck.c:11672
 #: cp/typeck.c:5048
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr ""
 
-#: c-family/c-warn.c:1998
+#: c-family/c-warn.c:2007
 #, gcc-internal-format
 msgid "comparison of integer expressions of different signedness: %qT and %qT"
 msgstr ""
 
-#: c-family/c-warn.c:2051
+#: c-family/c-warn.c:2060
 #, gcc-internal-format
 msgid "promoted ~unsigned is always non-zero"
 msgstr ""
 
-#: c-family/c-warn.c:2054
+#: c-family/c-warn.c:2063
 #, gcc-internal-format
 msgid "comparison of promoted ~unsigned with constant"
 msgstr ""
 
-#: c-family/c-warn.c:2064
+#: c-family/c-warn.c:2073
 #, gcc-internal-format
 msgid "comparison of promoted ~unsigned with unsigned"
 msgstr ""
 
-#: c-family/c-warn.c:2118
+#: c-family/c-warn.c:2127
 #, fuzzy, gcc-internal-format
 #| msgid "unused parameter `%s'"
 msgid "unused parameter %qD"
 msgstr "невыкарыстаемы параметр \"%s\""
 
-#: c-family/c-warn.c:2180
+#: c-family/c-warn.c:2189
 #, fuzzy, gcc-internal-format
 #| msgid "label `%D' defined but not used"
 msgid "typedef %qD locally defined but not used"
 msgstr "адмеціна `%D' вызначана, але не выкарыстоўваецца"
 
-#: c-family/c-warn.c:2215
+#: c-family/c-warn.c:2224
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `const'"
 msgid "duplicated %<if%> condition"
 msgstr "паўтарэнне \"const\""
 
-#: c-family/c-warn.c:2244
+#: c-family/c-warn.c:2253
 #, gcc-internal-format
 msgid "optimization attribute on %qD follows definition but the attribute doesn%'t match"
 msgstr ""
 
-#: c-family/c-warn.c:2254
+#: c-family/c-warn.c:2261
 #, fuzzy, gcc-internal-format
 msgid "inline declaration of %qD follows declaration with attribute %qs"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: c-family/c-warn.c:2259
+#: c-family/c-warn.c:2266
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q+D with attribute %qs follows inline declaration"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: c-family/c-warn.c:2306
+#: c-family/c-warn.c:2313
 #, gcc-internal-format
 msgid "result of %qE requires %u bits to represent, but %qT only has %u bits"
 msgstr ""
 
-#: c-family/c-warn.c:2344 c-family/c-warn.c:2368
+#: c-family/c-warn.c:2351 c-family/c-warn.c:2375
 #, gcc-internal-format
 msgid "comparison of constant %qE with boolean expression is always false"
 msgstr ""
 
-#: c-family/c-warn.c:2347 c-family/c-warn.c:2365
+#: c-family/c-warn.c:2354 c-family/c-warn.c:2372
 #, gcc-internal-format
 msgid "comparison of constant %qE with boolean expression is always true"
 msgstr ""
 
-#: c-family/c-warn.c:2415
+#: c-family/c-warn.c:2422
 msgid "passing argument %i to restrict-qualified parameter aliases with argument %Z"
 msgid_plural "passing argument %i to restrict-qualified parameter aliases with arguments %Z"
 msgstr[0] ""
 msgstr[1] ""
 
-#: c-family/c-warn.c:2480 c/c-typeck.c:5288 cp/call.c:5365
+#: c-family/c-warn.c:2487 c/c-typeck.c:5293 cp/call.c:5365
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr ""
 
-#: c-family/c-warn.c:2586
+#: c-family/c-warn.c:2593
 #, gcc-internal-format
 msgid "macro expands to multiple statements"
 msgstr ""
 
-#: c-family/c-warn.c:2587
+#: c-family/c-warn.c:2594
 #, gcc-internal-format
 msgid "some parts of macro expansion are not guarded by this %qs clause"
 msgstr ""
@@ -27600,7 +27642,7 @@
 msgid "too many input files"
 msgstr "вельмі шмат уваходзячых файлаў"
 
-#: common/config/aarch64/aarch64-common.c:319 config/aarch64/aarch64.c:10686
+#: common/config/aarch64/aarch64-common.c:319 config/aarch64/aarch64.c:10702
 #, gcc-internal-format
 msgid "unknown value %qs for -mcpu"
 msgstr ""
@@ -27632,13 +27674,13 @@
 msgstr ""
 
 #: common/config/arm/arm-common.c:322 common/config/arm/arm-common.c:376
-#: common/config/arm/arm-common.c:423 config/aarch64/aarch64.c:10639
+#: common/config/arm/arm-common.c:423 config/aarch64/aarch64.c:10655
 #, gcc-internal-format
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr ""
 
 #: common/config/arm/arm-common.c:325 common/config/arm/arm-common.c:379
-#: common/config/arm/arm-common.c:426 config/aarch64/aarch64.c:10642
+#: common/config/arm/arm-common.c:426 config/aarch64/aarch64.c:10658
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s"
 msgstr "нявернае выкарыстанне \"restict\""
@@ -28119,12 +28161,12 @@
 msgid "profiler support for VxWorks"
 msgstr ""
 
-#: config/aarch64/aarch64-builtins.c:1109 config/arm/arm-builtins.c:2262
+#: config/aarch64/aarch64-builtins.c:1109 config/arm/arm-builtins.c:2272
 #, fuzzy, gcc-internal-format
 msgid "%Kargument %d must be a constant immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/aarch64/aarch64-builtins.c:1180 config/arm/arm-builtins.c:2492
+#: config/aarch64/aarch64-builtins.c:1180 config/arm/arm-builtins.c:2502
 #, gcc-internal-format
 msgid "%Klane index must be a constant immediate"
 msgstr ""
@@ -28134,176 +28176,176 @@
 msgid "%Ktotal size and element size must be a non-zero constant immediate"
 msgstr ""
 
-#: config/aarch64/aarch64.c:1053
+#: config/aarch64/aarch64.c:1069
 #, gcc-internal-format
 msgid "%qs is incompatible with %s %s"
 msgstr ""
 
-#: config/aarch64/aarch64.c:1055
+#: config/aarch64/aarch64.c:1071
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with %s %s"
 msgstr ""
 
-#: config/aarch64/aarch64.c:3772
+#: config/aarch64/aarch64.c:3788
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10287
+#: config/aarch64/aarch64.c:10303
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown flag passed in -moverride=%s (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10331
+#: config/aarch64/aarch64.c:10347
 #, gcc-internal-format, gfc-internal-format
 msgid "%s string ill-formed\n"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10388
+#: config/aarch64/aarch64.c:10404
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr "Нераспазнаны выбар \"%s\""
 
-#: config/aarch64/aarch64.c:10406
+#: config/aarch64/aarch64.c:10422
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown tuning option (%s)"
 msgstr "невядомая назва рэгістра: %s\n"
 
-#: config/aarch64/aarch64.c:10683
+#: config/aarch64/aarch64.c:10699
 #, gcc-internal-format
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10690
+#: config/aarch64/aarch64.c:10706
 #, gcc-internal-format
 msgid "invalid feature modifier in %<-mcpu=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10717
+#: config/aarch64/aarch64.c:10733
 #, gcc-internal-format
 msgid "missing arch name in %<-march=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10720
+#: config/aarch64/aarch64.c:10736
 #, gcc-internal-format
 msgid "unknown value %qs for -march"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10724
+#: config/aarch64/aarch64.c:10740
 #, gcc-internal-format
 msgid "invalid feature modifier in %<-march=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10750
+#: config/aarch64/aarch64.c:10766
 #, gcc-internal-format
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10753
+#: config/aarch64/aarch64.c:10769
 #, gcc-internal-format
 msgid "unknown value %qs for -mtune"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10871 config/arm/arm.c:3173
+#: config/aarch64/aarch64.c:10887 config/arm/arm.c:3173
 #, gcc-internal-format, gfc-internal-format
 msgid "switch -mcpu=%s conflicts with -march=%s switch"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10906
+#: config/aarch64/aarch64.c:10922
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "assembler does not support -mabi=ilp32"
 msgstr "%s не падтрымлівае %s"
 
-#: config/aarch64/aarch64.c:10913
+#: config/aarch64/aarch64.c:10929
 #, gcc-internal-format
 msgid "return address signing is only supported for -mabi=lp64"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10975
+#: config/aarch64/aarch64.c:10991
 #, gcc-internal-format
 msgid "code model %qs with -f%s"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11138
+#: config/aarch64/aarch64.c:11154
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11141
+#: config/aarch64/aarch64.c:11157
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11145 config/aarch64/aarch64.c:11184
-#: config/aarch64/aarch64.c:11257
+#: config/aarch64/aarch64.c:11161 config/aarch64/aarch64.c:11200
+#: config/aarch64/aarch64.c:11273
 #, gcc-internal-format
 msgid "invalid value (\"%s\") in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11177
+#: config/aarch64/aarch64.c:11193
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11180
+#: config/aarch64/aarch64.c:11196
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11213
+#: config/aarch64/aarch64.c:11229
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"tune=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11253
+#: config/aarch64/aarch64.c:11269
 #, gcc-internal-format
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11306 config/aarch64/aarch64.c:11483
+#: config/aarch64/aarch64.c:11322 config/aarch64/aarch64.c:11499
 #, gcc-internal-format
 msgid "malformed %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11354
+#: config/aarch64/aarch64.c:11370
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11362
+#: config/aarch64/aarch64.c:11378
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11416
+#: config/aarch64/aarch64.c:11432
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11473 config/arm/arm.c:30742
-#: config/i386/i386.c:5440 config/powerpcspe/powerpcspe.c:39760
-#: config/rs6000/rs6000.c:36904 config/s390/s390.c:15746
+#: config/aarch64/aarch64.c:11489 config/arm/arm.c:30742
+#: config/i386/i386.c:5443 config/powerpcspe/powerpcspe.c:39760
+#: config/rs6000/rs6000.c:36960 config/s390/s390.c:15746
 #, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11500
+#: config/aarch64/aarch64.c:11516
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11509
+#: config/aarch64/aarch64.c:11525
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13571
+#: config/aarch64/aarch64.c:13587
 #, gcc-internal-format
 msgid "%Klane %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13573
+#: config/aarch64/aarch64.c:13589
 #, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr ""
@@ -28363,8 +28405,8 @@
 msgid "bad value %qs for -mmemory-latency"
 msgstr ""
 
-#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6526
-#: config/arc/arc.c:6800 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
+#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6517
+#: config/arc/arc.c:6791 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
 #: config/tilepro/tilepro.c:3108
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -28473,11 +28515,11 @@
 #: config/arm/arm.c:7029 config/avr/avr.c:9718 config/avr/avr.c:9734
 #: config/bfin/bfin.c:4705 config/bfin/bfin.c:4766 config/bfin/bfin.c:4795
 #: config/epiphany/epiphany.c:491 config/h8300/h8300.c:5459
-#: config/i386/i386.c:6452 config/i386/i386.c:12479 config/i386/i386.c:41424
-#: config/i386/i386.c:41474 config/i386/i386.c:41544 config/m68k/m68k.c:780
+#: config/i386/i386.c:6455 config/i386/i386.c:12482 config/i386/i386.c:41418
+#: config/i386/i386.c:41468 config/i386/i386.c:41538 config/m68k/m68k.c:780
 #: config/mcore/mcore.c:3070 config/nvptx/nvptx.c:4611
 #: config/powerpcspe/powerpcspe.c:35785 config/riscv/riscv.c:2698
-#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:32982
+#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:33038
 #: config/rx/rx.c:2719 config/rx/rx.c:2745 config/s390/s390.c:1056
 #: config/s390/s390.c:1143 config/sh/sh.c:8428 config/sh/sh.c:8446
 #: config/sh/sh.c:8470 config/sh/sh.c:8541 config/sh/sh.c:8564
@@ -28487,135 +28529,135 @@
 msgid "%qE attribute only applies to functions"
 msgstr "\"%s\" звычайна функцыя"
 
-#: config/arc/arc.c:6425
+#: config/arc/arc.c:6416
 #, fuzzy, gcc-internal-format
 #| msgid "`__builtin_next_arg' called without an argument"
 msgid "__builtin_arc_aligned with non-constant alignment"
 msgstr "\"__buitin_next_arg\" выклікаецца без аргумента"
 
-#: config/arc/arc.c:6433
+#: config/arc/arc.c:6424
 #, gcc-internal-format
 msgid "invalid alignment value for __builtin_arc_aligned"
 msgstr ""
 
-#: config/arc/arc.c:6596
+#: config/arc/arc.c:6587
 #, gcc-internal-format
 msgid "operand 1 should be an unsigned 3-bit immediate"
 msgstr ""
 
-#: config/arc/arc.c:6637 config/arc/arc.c:6734
+#: config/arc/arc.c:6628 config/arc/arc.c:6725
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6670 config/arc/arc.c:6702
+#: config/arc/arc.c:6661 config/arc/arc.c:6693
 #, gcc-internal-format
 msgid "operand 1 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6674 config/arc/arc.c:6706
+#: config/arc/arc.c:6665 config/arc/arc.c:6697
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 8-bit value"
 msgstr ""
 
-#: config/arc/arc.c:6738
+#: config/arc/arc.c:6729
 #, gcc-internal-format
 msgid "operand 3 should be an unsigned 8-bit value"
 msgstr ""
 
-#: config/arc/arc.c:6771
+#: config/arc/arc.c:6762
 #, gcc-internal-format
 msgid "operand 4 should be an unsigned 8-bit value (0-255)"
 msgstr ""
 
-#: config/arc/arc.c:6775
+#: config/arc/arc.c:6766
 #, gcc-internal-format
 msgid "operand 3 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6782
+#: config/arc/arc.c:6773
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (subreg 0-7)"
 msgstr ""
 
-#: config/arc/arc.c:6785
+#: config/arc/arc.c:6776
 #, gcc-internal-format
 msgid "operand 2 should be an even 3-bit value (subreg 0,2,4,6)"
 msgstr ""
 
-#: config/arc/arc.c:6832
+#: config/arc/arc.c:6823
 #, gcc-internal-format, gfc-internal-format
 msgid "builtin requires an immediate for operand %d"
 msgstr ""
 
-#: config/arc/arc.c:6837
+#: config/arc/arc.c:6828
 #, gcc-internal-format, gfc-internal-format
 msgid "operand %d should be a 6 bit unsigned immediate"
 msgstr ""
 
-#: config/arc/arc.c:6841
+#: config/arc/arc.c:6832
 #, gcc-internal-format, gfc-internal-format
 msgid "operand %d should be a 8 bit unsigned immediate"
 msgstr ""
 
-#: config/arc/arc.c:6845
+#: config/arc/arc.c:6836
 #, gcc-internal-format, gfc-internal-format
 msgid "operand %d should be a 3 bit unsigned immediate"
 msgstr ""
 
-#: config/arc/arc.c:6848
+#: config/arc/arc.c:6839
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown builtin immediate operand type for operand %d"
 msgstr ""
 
-#: config/arc/arc.c:6899
+#: config/arc/arc.c:6890
 #, gcc-internal-format
 msgid "register number must be a compile-time constant. Try giving higher optimization levels"
 msgstr ""
 
-#: config/arc/arc.c:7685
+#: config/arc/arc.c:7747
 #, gcc-internal-format
 msgid "Insn addresses not set after shorten_branches"
 msgstr ""
 
-#: config/arc/arc.c:7894
+#: config/arc/arc.c:7956
 #, gcc-internal-format
 msgid "insn addresses not freed"
 msgstr ""
 
-#: config/arc/arc.c:10682
+#: config/arc/arc.c:10670
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only valid for ARCv2 architecture"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: config/arc/arc.c:10690 config/arc/arc.c:10729
+#: config/arc/arc.c:10678 config/arc/arc.c:10717
 #, fuzzy, gcc-internal-format
 #| msgid "argument to `-%s' is missing"
 msgid "argument of %qE attribute is missing"
 msgstr "аргумент для \"-%s\" прапушчан"
 
-#: config/arc/arc.c:10701 config/arc/arc.c:10740 config/arc/arc.c:10842
+#: config/arc/arc.c:10689 config/arc/arc.c:10728 config/arc/arc.c:10830
 #: config/avr/avr.c:9790
 #, gcc-internal-format
 msgid "%qE attribute allows only an integer constant argument"
 msgstr ""
 
-#: config/arc/arc.c:10721
+#: config/arc/arc.c:10709
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only valid for ARC EM architecture"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: config/arc/arc.c:10776
+#: config/arc/arc.c:10764
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only applies to types"
 msgstr "\"%s\" звычайна функцыя"
 
-#: config/arc/arc.c:10782
+#: config/arc/arc.c:10770
 #, fuzzy, gcc-internal-format
 msgid "argument of %qE attribute ignored"
 msgstr "памер \"%s\" больш чам %d байт"
 
-#: config/arc/arc.c:10832 config/avr/avr.c:9777 config/bfin/bfin.c:4827
+#: config/arc/arc.c:10820 config/avr/avr.c:9777 config/bfin/bfin.c:4827
 #: config/i386/winnt.c:63 config/msp430/msp430.c:2018
 #: config/nvptx/nvptx.c:4634
 #, fuzzy, gcc-internal-format
@@ -28622,178 +28664,178 @@
 msgid "%qE attribute only applies to variables"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: config/arm/arm-builtins.c:2370
+#: config/arm/arm-builtins.c:2380
 #, fuzzy, gcc-internal-format
 msgid "this builtin is not supported for this target"
 msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
 
-#: config/arm/arm-builtins.c:2475
+#: config/arm/arm-builtins.c:2485
 #, gcc-internal-format
 msgid "You must enable NEON instructions (e.g. -mfloat-abi=softfp -mfpu=neon) to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2513
+#: config/arm/arm-builtins.c:2523
 #, gcc-internal-format
 msgid "You must enable VFP instructions to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2573
+#: config/arm/arm-builtins.c:2583
 #, gcc-internal-format
 msgid "You must enable crypto instructions (e.g. include -mfloat-abi=softfp -mfpu=crypto-neon...) to use these intrinsics."
 msgstr ""
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:2633 config/arm/arm-builtins.c:2737
+#: config/arm/arm-builtins.c:2643 config/arm/arm-builtins.c:2747
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2641 config/arm/arm-builtins.c:2686
-#: config/arm/arm-builtins.c:2744 config/arm/arm-builtins.c:2753
+#: config/arm/arm-builtins.c:2651 config/arm/arm-builtins.c:2696
+#: config/arm/arm-builtins.c:2754 config/arm/arm-builtins.c:2763
 #, fuzzy, gcc-internal-format
 #| msgid "first argument of `%s' should be `int'"
 msgid "the range of selector should be in 0 to 7"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/arm/arm-builtins.c:2646 config/arm/arm-builtins.c:2755
+#: config/arm/arm-builtins.c:2656 config/arm/arm-builtins.c:2765
 #, fuzzy, gcc-internal-format
 #| msgid "first argument of `%s' should be `int'"
 msgid "the range of selector should be in 0 to 3"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/arm/arm-builtins.c:2651 config/arm/arm-builtins.c:2757
+#: config/arm/arm-builtins.c:2661 config/arm/arm-builtins.c:2767
 #, fuzzy, gcc-internal-format
 #| msgid "first argument of `%s' should be `int'"
 msgid "the range of selector should be in 0 to 1"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/arm/arm-builtins.c:2823
+#: config/arm/arm-builtins.c:2833
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2828
+#: config/arm/arm-builtins.c:2838
 #, fuzzy, gcc-internal-format
 #| msgid "first argument of `%s' should be `int'"
 msgid "the range of mask should be in 0 to 255"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/arm/arm-builtins.c:3016
+#: config/arm/arm-builtins.c:3026
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3018
+#: config/arm/arm-builtins.c:3028
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3020
+#: config/arm/arm-builtins.c:3030
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3022
+#: config/arm/arm-builtins.c:3032
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3028
+#: config/arm/arm-builtins.c:3038
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3030
+#: config/arm/arm-builtins.c:3040
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3035
+#: config/arm/arm-builtins.c:3045
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3037
+#: config/arm/arm-builtins.c:3047
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3039
+#: config/arm/arm-builtins.c:3049
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3041
+#: config/arm/arm-builtins.c:3051
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3043
+#: config/arm/arm-builtins.c:3053
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3045
+#: config/arm/arm-builtins.c:3055
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3047
+#: config/arm/arm-builtins.c:3057
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3049
+#: config/arm/arm-builtins.c:3059
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3051
+#: config/arm/arm-builtins.c:3061
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3053
+#: config/arm/arm-builtins.c:3063
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3055
+#: config/arm/arm-builtins.c:3065
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3057
+#: config/arm/arm-builtins.c:3067
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3059
+#: config/arm/arm-builtins.c:3069
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3061
+#: config/arm/arm-builtins.c:3071
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3063
+#: config/arm/arm-builtins.c:3073
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3065
+#: config/arm/arm-builtins.c:3075
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3067
+#: config/arm/arm-builtins.c:3077
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3069
+#: config/arm/arm-builtins.c:3079
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr ""
@@ -29711,556 +29753,556 @@
 msgid "can%'t set position in PCH file: %m"
 msgstr "немагчыма зачыніць уваходзячы файл %s"
 
-#: config/i386/i386.c:3177
+#: config/i386/i386.c:3180
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function `%s'"
 msgid "wrong argument %qs to option %qs"
 msgstr "вельмі шмат аргумэнтаў у функцыі `%s'"
 
-#: config/i386/i386.c:3183
+#: config/i386/i386.c:3186
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr ""
 
-#: config/i386/i386.c:3193
+#: config/i386/i386.c:3196
 #, gcc-internal-format
 msgid "wrong strategy name %qs specified for option %qs"
 msgstr ""
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3219
+#: config/i386/i386.c:3222
 #, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386.c:3232
+#: config/i386/i386.c:3235
 #, gcc-internal-format
 msgid "unknown alignment %qs specified for option %qs"
 msgstr ""
 
-#: config/i386/i386.c:3242
+#: config/i386/i386.c:3245
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr ""
 
-#: config/i386/i386.c:3249
+#: config/i386/i386.c:3252
 #, gcc-internal-format
 msgid "too many size ranges specified in option %qs"
 msgstr ""
 
-#: config/i386/i386.c:3302
+#: config/i386/i386.c:3305
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unknown register name: %s"
 msgid "unknown parameter to option -mtune-ctrl: %s"
 msgstr "невядомая назва рэгістра: %s"
 
-#: config/i386/i386.c:3726
+#: config/i386/i386.c:3729
 #, gcc-internal-format
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr ""
 
-#: config/i386/i386.c:3775
+#: config/i386/i386.c:3778
 #, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr ""
 
-#: config/i386/i386.c:3777
+#: config/i386/i386.c:3780
 #, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr ""
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3804
+#: config/i386/i386.c:3807
 #, gcc-internal-format
 msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386.c:3821
+#: config/i386/i386.c:3824
 #, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr ""
 
-#: config/i386/i386.c:3833
+#: config/i386/i386.c:3836
 #, gcc-internal-format
 msgid "-mabi=ms not supported with X32 ABI"
 msgstr ""
 
-#: config/i386/i386.c:3851 config/i386/i386.c:3860 config/i386/i386.c:3872
-#: config/i386/i386.c:3883 config/i386/i386.c:3894
+#: config/i386/i386.c:3854 config/i386/i386.c:3863 config/i386/i386.c:3875
+#: config/i386/i386.c:3886 config/i386/i386.c:3897
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
 
-#: config/i386/i386.c:3863 config/i386/i386.c:3875
+#: config/i386/i386.c:3866 config/i386/i386.c:3878
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "-pipe не падтрымліваецца"
 
-#: config/i386/i386.c:3881 config/i386/i386.c:3890 config/i386/i386.c:5213
+#: config/i386/i386.c:3884 config/i386/i386.c:3893 config/i386/i386.c:5216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s does not support %s"
 msgid "code model %s does not support PIC mode"
 msgstr "%s не падтрымлівае %s"
 
-#: config/i386/i386.c:3918
+#: config/i386/i386.c:3921
 #, fuzzy, gcc-internal-format
 msgid "-masm=intel not supported in this configuration"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: config/i386/i386.c:3923
+#: config/i386/i386.c:3926
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr ""
 
-#: config/i386/i386.c:3932
+#: config/i386/i386.c:3935
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386.c:3934
+#: config/i386/i386.c:3937
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386.c:3941
+#: config/i386/i386.c:3944
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386.c:3943
+#: config/i386/i386.c:3946
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386.c:3951 config/i386/i386.c:4265
+#: config/i386/i386.c:3954 config/i386/i386.c:4268
 #, fuzzy, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "ISO C не падтрымлівае комлексныя цэлалікавыя тыпы"
 
-#: config/i386/i386.c:4197 config/i386/i386.c:4200
+#: config/i386/i386.c:4200 config/i386/i386.c:4203
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "Intel MPX does not support x32"
 msgstr "%s не падтрымлівае %s"
 
-#: config/i386/i386.c:4205
+#: config/i386/i386.c:4208
 #, gcc-internal-format
 msgid "bad value (%qs) for %<-march=%> switch"
 msgstr ""
 
-#: config/i386/i386.c:4206
+#: config/i386/i386.c:4209
 #, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"arch=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386.c:4228
+#: config/i386/i386.c:4231
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4230
+#: config/i386/i386.c:4233
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4235
+#: config/i386/i386.c:4238
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr ""
 
-#: config/i386/i386.c:4236
+#: config/i386/i386.c:4239
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: config/i386/i386.c:4284
+#: config/i386/i386.c:4287
 #, gcc-internal-format
 msgid "bad value (%qs) for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386.c:4285
+#: config/i386/i386.c:4288
 #, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386.c:4305
+#: config/i386/i386.c:4308
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4307
+#: config/i386/i386.c:4310
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4312
+#: config/i386/i386.c:4315
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr ""
 
-#: config/i386/i386.c:4313
+#: config/i386/i386.c:4316
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: config/i386/i386.c:4379
+#: config/i386/i386.c:4382
 #, gcc-internal-format
 msgid "-mregparm is ignored in 64-bit mode"
 msgstr ""
 
-#: config/i386/i386.c:4381
+#: config/i386/i386.c:4384
 #, gcc-internal-format
 msgid "-mregparm is ignored for Intel MCU psABI"
 msgstr ""
 
-#: config/i386/i386.c:4384
+#: config/i386/i386.c:4387
 #, gcc-internal-format, gfc-internal-format
 msgid "-mregparm=%d is not between 0 and %d"
 msgstr ""
 
-#: config/i386/i386.c:4417
+#: config/i386/i386.c:4420
 #, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr ""
 
-#: config/i386/i386.c:4418
+#: config/i386/i386.c:4421
 #, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr ""
 
-#: config/i386/i386.c:4497
+#: config/i386/i386.c:4500
 #, fuzzy, gcc-internal-format
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: config/i386/i386.c:4500
+#: config/i386/i386.c:4503
 #, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr ""
 
-#: config/i386/i386.c:4523
+#: config/i386/i386.c:4526
 #, gcc-internal-format, gfc-internal-format
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr ""
 
-#: config/i386/i386.c:4536
+#: config/i386/i386.c:4539
 #, fuzzy, gcc-internal-format
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: config/i386/i386.c:4539
+#: config/i386/i386.c:4542
 #, gcc-internal-format
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr ""
 
-#: config/i386/i386.c:4545
+#: config/i386/i386.c:4548
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386.c:4546
+#: config/i386/i386.c:4549
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386.c:4556
+#: config/i386/i386.c:4559
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr ""
 
-#: config/i386/i386.c:4563
+#: config/i386/i386.c:4566
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr ""
 
-#: config/i386/i386.c:4613
+#: config/i386/i386.c:4616
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr ""
 
-#: config/i386/i386.c:4615
+#: config/i386/i386.c:4618
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr ""
 
-#: config/i386/i386.c:4629
+#: config/i386/i386.c:4632
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr ""
 
-#: config/i386/i386.c:4631
+#: config/i386/i386.c:4634
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr ""
 
-#: config/i386/i386.c:4741
+#: config/i386/i386.c:4744
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr ""
 
-#: config/i386/i386.c:4744
+#: config/i386/i386.c:4747
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr ""
 
-#: config/i386/i386.c:4748
+#: config/i386/i386.c:4751
 #, gcc-internal-format
 msgid "-mcall-ms2sysv-xlogues isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386.c:4813 config/powerpcspe/powerpcspe.c:5663
+#: config/i386/i386.c:4816 config/powerpcspe/powerpcspe.c:5663
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown option for -mrecip=%s"
 msgstr "невядомая назва рэгістра: %s\n"
 
-#: config/i386/i386.c:4870 config/powerpcspe/powerpcspe.c:5339
+#: config/i386/i386.c:4873 config/powerpcspe/powerpcspe.c:5339
 #, gcc-internal-format
 msgid "%qs is not a valid number in -mstack-protector-guard-offset="
 msgstr ""
 
-#: config/i386/i386.c:4875 config/powerpcspe/powerpcspe.c:5344
+#: config/i386/i386.c:4878 config/powerpcspe/powerpcspe.c:5344
 #, gcc-internal-format
 msgid "%qs is not a valid offset in -mstack-protector-guard-offset="
 msgstr ""
 
-#: config/i386/i386.c:4907 config/powerpcspe/powerpcspe.c:5356
+#: config/i386/i386.c:4910 config/powerpcspe/powerpcspe.c:5356
 #, gcc-internal-format
 msgid "%qs is not a valid base register in -mstack-protector-guard-reg="
 msgstr ""
 
-#: config/i386/i386.c:5506 config/i386/i386.c:5553 config/s390/s390.c:15812
+#: config/i386/i386.c:5509 config/i386/i386.c:5556 config/s390/s390.c:15812
 #: config/s390/s390.c:15862 config/s390/s390.c:15879
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr ""
 
-#: config/i386/i386.c:5534
+#: config/i386/i386.c:5537
 #, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr ""
 
-#: config/i386/i386.c:5837
+#: config/i386/i386.c:5840
 #, gcc-internal-format
 msgid "interrupt and naked attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5852
+#: config/i386/i386.c:5855
 #, gcc-internal-format
 msgid "Only DWARF debug format is supported for interrupt service routine."
 msgstr ""
 
-#: config/i386/i386.c:5901
+#: config/i386/i386.c:5904
 #, gcc-internal-format
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5913
+#: config/i386/i386.c:5916
 #, gcc-internal-format
 msgid "%<-mindirect-branch=thunk-extern%>, %<-fcf-protection=branch%> and %<-fcheck-pointer-bounds%> are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5949
+#: config/i386/i386.c:5952
 #, gcc-internal-format
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6047
+#: config/i386/i386.c:6050
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in %s service routine"
 msgstr ""
 
-#: config/i386/i386.c:6051
+#: config/i386/i386.c:6054
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in function with no_caller_saved_registers attribute"
 msgstr ""
 
-#: config/i386/i386.c:6465 config/i386/i386.c:6516
+#: config/i386/i386.c:6468 config/i386/i386.c:6519
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6470
+#: config/i386/i386.c:6473
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6477 config/i386/i386.c:41444
+#: config/i386/i386.c:6480 config/i386/i386.c:41438
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr ""
 
-#: config/i386/i386.c:6483
+#: config/i386/i386.c:6486
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "памер \"%s\" больш чам %d байт"
 
-#: config/i386/i386.c:6508 config/i386/i386.c:6551
+#: config/i386/i386.c:6511 config/i386/i386.c:6554
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6512
+#: config/i386/i386.c:6515
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6520 config/i386/i386.c:6569
+#: config/i386/i386.c:6523 config/i386/i386.c:6572
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6530 config/i386/i386.c:6547
+#: config/i386/i386.c:6533 config/i386/i386.c:6550
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6534
+#: config/i386/i386.c:6537
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6538 config/i386/i386.c:6565
+#: config/i386/i386.c:6541 config/i386/i386.c:6568
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6555 config/i386/i386.c:6573
+#: config/i386/i386.c:6558 config/i386/i386.c:6576
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6561
+#: config/i386/i386.c:6564
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr ""
 
-#: config/i386/i386.c:6805
+#: config/i386/i386.c:6808
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:6808
+#: config/i386/i386.c:6811
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:7126
+#: config/i386/i386.c:7129
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "X32 does not support ms_abi attribute"
 msgstr "%s не падтрымлівае %s"
 
-#: config/i386/i386.c:7160
+#: config/i386/i386.c:7163
 #, gcc-internal-format
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr ""
 
-#: config/i386/i386.c:7502
+#: config/i386/i386.c:7505
 #, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7508
+#: config/i386/i386.c:7511
 #, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7522
+#: config/i386/i386.c:7525
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7528
+#: config/i386/i386.c:7531
 #, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7544
+#: config/i386/i386.c:7547
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7550
+#: config/i386/i386.c:7553
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7566
+#: config/i386/i386.c:7569
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7572
+#: config/i386/i386.c:7575
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7754
+#: config/i386/i386.c:7757
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:7871
+#: config/i386/i386.c:7874
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:7989
+#: config/i386/i386.c:7992
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:8152
+#: config/i386/i386.c:8155
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.c:8158
+#: config/i386/i386.c:8161
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.c:8174
+#: config/i386/i386.c:8177
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr ""
 
-#: config/i386/i386.c:8471 config/i386/i386.c:8750 config/i386/i386.c:9276
+#: config/i386/i386.c:8474 config/i386/i386.c:8753 config/i386/i386.c:9279
 #, gcc-internal-format
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:8473 config/i386/i386.c:8752 config/i386/i386.c:9278
+#: config/i386/i386.c:8476 config/i386/i386.c:8755 config/i386/i386.c:9281
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr ""
 
-#: config/i386/i386.c:9178
+#: config/i386/i386.c:9181
 #, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr ""
 
-#: config/i386/i386.c:11601
+#: config/i386/i386.c:11604
 #, gcc-internal-format, gfc-internal-format
 msgid "-mcall-ms2sysv-xlogues is not compatible with %s"
 msgstr ""
 
-#: config/i386/i386.c:13593
+#: config/i386/i386.c:13596
 #, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr ""
 
-#: config/i386/i386.c:13683
+#: config/i386/i386.c:13686
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr ""
 
-#: config/i386/i386.c:14970
+#: config/i386/i386.c:14973
 #, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr ""
 
-#: config/i386/i386.c:14990
+#: config/i386/i386.c:14993
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
 msgstr ""
@@ -30267,313 +30309,313 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:15001
+#: config/i386/i386.c:15004
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr ""
 
-#: config/i386/i386.c:17939
+#: config/i386/i386.c:17942
 #, gcc-internal-format
 msgid "'V' modifier on non-integer register"
 msgstr ""
 
-#: config/i386/i386.c:17950 config/i386/i386.c:17964
+#: config/i386/i386.c:17953 config/i386/i386.c:17967
 #, gcc-internal-format
 msgid "unsupported size for integer register"
 msgstr ""
 
-#: config/i386/i386.c:17996
+#: config/i386/i386.c:17999
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr ""
 
-#: config/i386/i386.c:18011
+#: config/i386/i386.c:18014
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr ""
 
-#: config/i386/i386.c:18202
+#: config/i386/i386.c:18205
 #, gcc-internal-format
 msgid "non-integer operand used with operand code 'z'"
 msgstr ""
 
-#: config/i386/i386.c:28467
+#: config/i386/i386.c:28470
 #, gcc-internal-format
 msgid "interrupt service routine can't be called directly"
 msgstr ""
 
-#: config/i386/i386.c:29995
+#: config/i386/i386.c:29998
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in -fabi-version=12 (GCC 8)"
 msgstr ""
 
-#: config/i386/i386.c:32435
+#: config/i386/i386.c:32438
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr ""
 
-#: config/i386/i386.c:32485
+#: config/i386/i386.c:32488
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for %s"
 msgstr ""
 
-#: config/i386/i386.c:32495
+#: config/i386/i386.c:32498
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr ""
 
-#: config/i386/i386.c:32657
+#: config/i386/i386.c:32660
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386.c:32662 config/i386/i386.c:32938
-#: config/rs6000/rs6000.c:37850
+#: config/i386/i386.c:32665 config/i386/i386.c:32941
+#: config/rs6000/rs6000.c:37906
 #, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr ""
 
-#: config/i386/i386.c:32795 config/rs6000/rs6000.c:37607
+#: config/i386/i386.c:32798 config/rs6000/rs6000.c:37663
 #, fuzzy, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
 
-#: config/i386/i386.c:33207
+#: config/i386/i386.c:33210
 #, fuzzy, gcc-internal-format
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: config/i386/i386.c:33232 config/i386/i386.c:33282
+#: config/i386/i386.c:33235 config/i386/i386.c:33285
 #, gcc-internal-format, gfc-internal-format
 msgid "Parameter to builtin not valid: %s"
 msgstr ""
 
-#: config/i386/i386.c:33975 config/i386/i386.c:35415
+#: config/i386/i386.c:33978 config/i386/i386.c:35418
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386.c:34370
+#: config/i386/i386.c:34373
 #, fuzzy, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386.c:34465
+#: config/i386/i386.c:34468
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386.c:35346
+#: config/i386/i386.c:35349
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386.c:35361
+#: config/i386/i386.c:35364
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386.c:35394
+#: config/i386/i386.c:35397
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386.c:35434
+#: config/i386/i386.c:35437
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386.c:35447
+#: config/i386/i386.c:35450
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386.c:35457
+#: config/i386/i386.c:35460
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:35462 config/i386/i386.c:36249
+#: config/i386/i386.c:35465 config/i386/i386.c:36252
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386.c:35596
+#: config/i386/i386.c:35599
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: config/i386/i386.c:35601
+#: config/i386/i386.c:35604
 #, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr ""
 
-#: config/i386/i386.c:35607 config/i386/i386.c:35814
+#: config/i386/i386.c:35610 config/i386/i386.c:35817
 #, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr ""
 
-#: config/i386/i386.c:35796
+#: config/i386/i386.c:35799
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386.c:35802
+#: config/i386/i386.c:35805
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386.c:35805
+#: config/i386/i386.c:35808
 #, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:36247
+#: config/i386/i386.c:36250
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386.c:36329 config/powerpcspe/powerpcspe.c:16219
-#: config/rs6000/rs6000.c:15304
+#: config/i386/i386.c:36332 config/powerpcspe/powerpcspe.c:16219
+#: config/rs6000/rs6000.c:15348
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr ""
 
-#: config/i386/i386.c:36539
+#: config/i386/i386.c:36542
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr ""
 
-#: config/i386/i386.c:36543
+#: config/i386/i386.c:36546
 #, fuzzy, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "Нерэчаісны выбар %s"
 
-#: config/i386/i386.c:37381
+#: config/i386/i386.c:37375
 #, fuzzy, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386.c:38108 config/i386/i386.c:38290
+#: config/i386/i386.c:38102 config/i386/i386.c:38284
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386.c:38343
+#: config/i386/i386.c:38337
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386.c:38349
+#: config/i386/i386.c:38343
 #, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr ""
 
-#: config/i386/i386.c:38368
+#: config/i386/i386.c:38362
 #, fuzzy, gcc-internal-format
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386.c:41431
+#: config/i386/i386.c:41425
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: config/i386/i386.c:41452
+#: config/i386/i386.c:41446
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: config/i386/i386.c:41485 config/i386/i386.c:41494
+#: config/i386/i386.c:41479 config/i386/i386.c:41488
 #, gcc-internal-format
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:41530 config/powerpcspe/powerpcspe.c:35868
-#: config/rs6000/rs6000.c:33065
+#: config/i386/i386.c:41524 config/powerpcspe/powerpcspe.c:35868
+#: config/rs6000/rs6000.c:33121
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored"
 msgid "%qE incompatible attribute ignored"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: config/i386/i386.c:41555 config/i386/i386.c:41577 config/ia64/ia64.c:815
+#: config/i386/i386.c:41549 config/i386/i386.c:41571 config/ia64/ia64.c:815
 #: config/s390/s390.c:1153
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: config/i386/i386.c:41565 config/i386/i386.c:41587 config/s390/s390.c:1182
+#: config/i386/i386.c:41559 config/i386/i386.c:41581 config/s390/s390.c:1182
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: config/i386/i386.c:41619
+#: config/i386/i386.c:41613
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386.c:41626
+#: config/i386/i386.c:41620
 #, gcc-internal-format, gfc-internal-format
 msgid "interrupt service routine should have unsigned %sint as the second argument"
 msgstr ""
 
-#: config/i386/i386.c:41636
+#: config/i386/i386.c:41630
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386.c:41639
+#: config/i386/i386.c:41633
 #, gcc-internal-format
 msgid "interrupt service routine can't have non-void return value"
 msgstr ""
 
-#: config/i386/i386.c:44676
+#: config/i386/i386.c:44670
 #, gcc-internal-format
 msgid "alternatives not allowed in asm flag output"
 msgstr ""
 
-#: config/i386/i386.c:44740
+#: config/i386/i386.c:44734
 #, gcc-internal-format
 msgid "unknown asm flag output %qs"
 msgstr ""
 
-#: config/i386/i386.c:44769
+#: config/i386/i386.c:44763
 #, gcc-internal-format
 msgid "invalid type for asm flag output"
 msgstr ""
 
-#: config/i386/i386.c:50634
+#: config/i386/i386.c:50628
 #, gcc-internal-format
 msgid "unknown architecture specific memory model"
 msgstr ""
 
-#: config/i386/i386.c:50641
+#: config/i386/i386.c:50635
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50647
+#: config/i386/i386.c:50641
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50671 config/i386/i386.c:50787
+#: config/i386/i386.c:50665 config/i386/i386.c:50781
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unsupported version"
 msgid "unsupported simdlen %d"
 msgstr "непадтрымліваемая версія"
 
-#: config/i386/i386.c:50690
+#: config/i386/i386.c:50684
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd"
 msgstr ""
 
-#: config/i386/i386.c:50712
+#: config/i386/i386.c:50706
 #, gcc-internal-format
 msgid "unsupported argument type %qT for simd"
 msgstr ""
 
-#: config/i386/i386.c:51033
+#: config/i386/i386.c:51027
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr ""
@@ -30802,7 +30844,7 @@
 msgstr ""
 
 #: config/m68k/m68k.c:1128 config/powerpcspe/powerpcspe.c:28512
-#: config/rs6000/rs6000.c:25791
+#: config/rs6000/rs6000.c:25868
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr ""
@@ -31386,58 +31428,58 @@
 
 #. Trampoline is not supported on reduced-set registers yet.
 #: config/nds32/nds32.c:2327 config/nds32/nds32.c:2381
-#: config/nds32/nds32.c:3127 config/nds32/nds32.c:3201
-#: config/nds32/nds32.c:3216 config/nds32/nds32.c:3222
-#: config/nds32/nds32.c:3284 config/nds32/nds32.c:3290
-#: config/nds32/nds32.c:3322
+#: config/nds32/nds32.c:3128 config/nds32/nds32.c:3202
+#: config/nds32/nds32.c:3217 config/nds32/nds32.c:3223
+#: config/nds32/nds32.c:3285 config/nds32/nds32.c:3291
+#: config/nds32/nds32.c:3323
 #, fuzzy, gcc-internal-format
 msgid "a nested function is not supported for reduced registers"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
 #. The enum index value for array size is out of range.
-#: config/nds32/nds32.c:3025
+#: config/nds32/nds32.c:3026
 #, fuzzy, gcc-internal-format
 msgid "intrinsic register index is out of range"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: config/nds32/nds32.c:3041 config/nds32/nds32.c:3048
-#: config/nds32/nds32.c:3055 config/nds32/nds32.c:3062
-#: config/nds32/nds32.c:3069
+#: config/nds32/nds32.c:3042 config/nds32/nds32.c:3049
+#: config/nds32/nds32.c:3056 config/nds32/nds32.c:3063
+#: config/nds32/nds32.c:3070
 #, gcc-internal-format
 msgid "CCTL intrinsic function subtype out of range!"
 msgstr ""
 
-#: config/nds32/nds32.c:3508
+#: config/nds32/nds32.c:3509
 #, gcc-internal-format
 msgid "invalid id value for interrupt/exception attribute"
 msgstr ""
 
-#: config/nds32/nds32.c:3536
+#: config/nds32/nds32.c:3537
 #, fuzzy, gcc-internal-format
 msgid "invalid id value for reset attribute"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: config/nds32/nds32.c:3552
+#: config/nds32/nds32.c:3553
 #, fuzzy, gcc-internal-format
 msgid "invalid nmi function for reset attribute"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: config/nds32/nds32.c:3565
+#: config/nds32/nds32.c:3566
 #, fuzzy, gcc-internal-format
 msgid "invalid warm function for reset attribute"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: config/nds32/nds32.c:3638
+#: config/nds32/nds32.c:3639
 #, gcc-internal-format
 msgid "Disable FPU ISA, the ABI option must be enable '-mfloat-abi=soft'"
 msgstr ""
 
-#: config/nds32/nds32.c:3641
+#: config/nds32/nds32.c:3642
 #, gcc-internal-format
 msgid "'-mabi=2fp+' option only support when FPU available, must be enable '-mext-fpu-sp' or '-mext-fpu-dp'"
 msgstr ""
 
-#: config/nds32/nds32.c:3647
+#: config/nds32/nds32.c:3648
 #, fuzzy, gcc-internal-format
 #| msgid "-pipe is not supported"
 msgid "position-independent code not supported"
@@ -31777,12 +31819,12 @@
 msgid "junk at end of #pragma longcall"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6154
+#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6152
 #, gcc-internal-format
 msgid "vec_lvsl is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6158
+#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6156
 #, gcc-internal-format
 msgid "vec_lvsr is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
@@ -31832,7 +31874,7 @@
 msgid "vec_insert only accepts 3 arguments"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6868
+#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6866
 #, gcc-internal-format
 msgid "passing arg %d of %qE discards qualifiers from pointer target type"
 msgstr ""
@@ -31918,7 +31960,7 @@
 msgid "target attribute or pragma changes SPE ABI"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4351 config/rs6000/rs6000.c:4223
+#: config/powerpcspe/powerpcspe.c:4351 config/rs6000/rs6000.c:4243
 #, fuzzy, gcc-internal-format
 msgid "AltiVec not supported in this target"
 msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
@@ -32064,7 +32106,7 @@
 msgid "-mvsx-small-integer requires -mpower8-vector, -mupper-regs-di, and -mdirect-move"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4959 config/rs6000/rs6000.c:4601
+#: config/powerpcspe/powerpcspe.c:4959 config/rs6000/rs6000.c:4628
 #, gcc-internal-format
 msgid "target attribute or pragma changes long double size"
 msgstr ""
@@ -32105,22 +32147,22 @@
 msgstr ""
 
 #: config/powerpcspe/powerpcspe.c:5140 config/powerpcspe/powerpcspe.c:5155
-#: config/rs6000/rs6000.c:4766 config/rs6000/rs6000.c:4781
+#: config/rs6000/rs6000.c:4791 config/rs6000/rs6000.c:4806
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:5168 config/rs6000/rs6000.c:4794
+#: config/powerpcspe/powerpcspe.c:5168 config/rs6000/rs6000.c:4819
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:5234 config/rs6000/rs6000.c:4828
+#: config/powerpcspe/powerpcspe.c:5234 config/rs6000/rs6000.c:4853
 #, gcc-internal-format
 msgid "target attribute or pragma changes single precision floating point"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:5237 config/rs6000/rs6000.c:4831
+#: config/powerpcspe/powerpcspe.c:5237 config/rs6000/rs6000.c:4856
 #, gcc-internal-format
 msgid "target attribute or pragma changes double precision floating point"
 msgstr ""
@@ -32130,12 +32172,12 @@
 msgid "-mstack-protector-guard=tls needs a valid base register"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:8415 config/rs6000/rs6000.c:7925
+#: config/powerpcspe/powerpcspe.c:8415 config/rs6000/rs6000.c:7950
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11237
+#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11269
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
@@ -32145,7 +32187,7 @@
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11595
+#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11633
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr ""
@@ -32155,12 +32197,12 @@
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12604
+#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12648
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12779
+#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12823
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
@@ -32170,28 +32212,28 @@
 msgid "internal error: builtin function %s already processed"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:13971
+#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:14015
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be an 8-bit field value"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14015
+#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14059
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
 #: config/powerpcspe/powerpcspe.c:14934 config/powerpcspe/powerpcspe.c:16803
-#: config/rs6000/rs6000.c:14101
+#: config/rs6000/rs6000.c:14145
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14119
+#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14163
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14135
+#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14179
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 7-bit unsigned literal"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
@@ -32211,12 +32253,12 @@
 msgid "builtin %s is only valid in 64-bit mode"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14791
+#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14835
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %d must be an unsigned literal"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14793
+#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14837
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "аргумент `__builtin_args_info' выйшаў за межы"
@@ -32238,53 +32280,53 @@
 msgid "hwcap %s is an invalid argument to builtin %s"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15065
+#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15109
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15090
+#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15134
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15110
+#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15154
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15122
+#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15166
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be 0 or 2"
 msgstr "аргумент для \"%s\" прапушчан"
 
-#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15134
+#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15178
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15148
+#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15192
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15160
+#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15204
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be 0 or 1"
 msgstr "аргумент для \"%s\" прапушчан"
 
-#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15168
+#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15212
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be in the range 0..15"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15237
-#: config/rs6000/rs6000.c:15569
+#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15281
+#: config/rs6000/rs6000.c:15613
 #, fuzzy, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15394
+#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15438
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr ""
@@ -32409,7 +32451,7 @@
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25758
+#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25835
 #, fuzzy, gcc-internal-format
 #| msgid "%s is too large"
 msgid "stack frame too large"
@@ -32420,12 +32462,12 @@
 msgid "-fsplit-stack uses register r29"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29459
+#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29536
 #, gcc-internal-format
 msgid "Stack frame larger than 2G is not supported for -fsplit-stack"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30447
+#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30524
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr ""
@@ -32435,22 +32477,22 @@
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32830
+#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32907
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32832
+#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32909
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32834
+#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32911
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32836
+#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32913
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr ""
@@ -32460,7 +32502,7 @@
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32845
+#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32922
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr ""
@@ -33004,71 +33046,71 @@
 "Please use an explicit cpu name.  Valid cpu names are: %s"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6168 config/rs6000/rs6000-c.c:6219
-#: config/rs6000/rs6000-c.c:6489 config/rs6000/rs6000-c.c:6555
-#: config/rs6000/rs6000-c.c:6916 config/rs6000/rs6000-c.c:6963
+#: config/rs6000/rs6000-c.c:6166 config/rs6000/rs6000-c.c:6217
+#: config/rs6000/rs6000-c.c:6487 config/rs6000/rs6000-c.c:6553
+#: config/rs6000/rs6000-c.c:6914 config/rs6000/rs6000-c.c:6961
 #, gcc-internal-format
 msgid "builtin %qs only accepts 2 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6292 config/rs6000/rs6000-c.c:6375
-#: config/rs6000/rs6000-c.c:6736
+#: config/rs6000/rs6000-c.c:6290 config/rs6000/rs6000-c.c:6373
+#: config/rs6000/rs6000-c.c:6734
 #, gcc-internal-format
 msgid "builtin %qs only accepts 3 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6484
+#: config/rs6000/rs6000-c.c:6482
 #, gcc-internal-format
 msgid "builtin %qs only accepts 1 argument"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:7054
+#: config/rs6000/rs6000-c.c:7052
 #, gcc-internal-format
 msgid "builtin %qs requires builtin %qs"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:7058
+#: config/rs6000/rs6000-c.c:7056
 #, gcc-internal-format
 msgid "builtin function %qs not supported in this compiler configuration"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:7068
+#: config/rs6000/rs6000-c.c:7066
 #, gcc-internal-format
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3754 config/rs6000/rs6000.c:3757
-#: config/rs6000/rs6000.c:3760
+#: config/rs6000/rs6000.c:3772 config/rs6000/rs6000.c:3775
+#: config/rs6000/rs6000.c:3778
 #, gcc-internal-format
 msgid "%qs requires %qs or %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3861
+#: config/rs6000/rs6000.c:3879
 #, gcc-internal-format
 msgid "%qs requires PowerPC64 architecture, enabling"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4037
+#: config/rs6000/rs6000.c:4057
 #, fuzzy, gcc-internal-format
 msgid "%qs command-line option is deprecated"
 msgstr "Нераспазнаны выбар \"%s\""
 
-#: config/rs6000/rs6000.c:4048
+#: config/rs6000/rs6000.c:4068
 #, gcc-internal-format
 msgid "%qs is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4147
+#: config/rs6000/rs6000.c:4167
 #, gcc-internal-format
 msgid "will not generate %qs instructions because assembler lacks %qs support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4240
+#: config/rs6000/rs6000.c:4260
 #, fuzzy, gcc-internal-format
 msgid "%qs is not supported on little endian systems"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: config/rs6000/rs6000.c:4333
+#: config/rs6000/rs6000.c:4353
 #, gcc-internal-format
 msgid "power9 target option is incompatible with %<%s=<xxx>%> for <xxx> less than power9"
 msgstr ""
@@ -33075,7 +33117,7 @@
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:4341
+#: config/rs6000/rs6000.c:4361
 #, gcc-internal-format
 msgid "%qs incompatible with explicitly disabled options"
 msgstr ""
@@ -33084,248 +33126,249 @@
 #. error messages.  However, if users have managed to select
 #. power9-fusion without selecting power8-fusion, they
 #. already know about undocumented flags.
-#: config/rs6000/rs6000.c:4366 config/rs6000/rs6000.c:4373
-#: config/rs6000/rs6000.c:4380 config/rs6000/rs6000.c:4388
-#: config/rs6000/rs6000.c:4407 config/rs6000/rs6000.c:4464
-#: config/rs6000/rs6000.c:4468 config/rs6000/rs6000.c:4485
-#: config/rs6000/rs6000.c:4538 config/rs6000/rs6000.c:4565
-#: config/rs6000/rs6000.c:4580 config/rs6000/rs6000.c:4588
-#: config/rs6000/rs6000.c:4684
+#: config/rs6000/rs6000.c:4386 config/rs6000/rs6000.c:4393
+#: config/rs6000/rs6000.c:4400 config/rs6000/rs6000.c:4408
+#: config/rs6000/rs6000.c:4427 config/rs6000/rs6000.c:4484
+#: config/rs6000/rs6000.c:4488 config/rs6000/rs6000.c:4505
+#: config/rs6000/rs6000.c:4558 config/rs6000/rs6000.c:4585
+#: config/rs6000/rs6000.c:4600 config/rs6000/rs6000.c:4608
+#: config/rs6000/rs6000.c:4709
 #, gcc-internal-format
 msgid "%qs requires %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4625
+#: config/rs6000/rs6000.c:4650
 #, gcc-internal-format
 msgid "Using IEEE extended precision long double"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4627
+#: config/rs6000/rs6000.c:4652
 #, gcc-internal-format
 msgid "Using IBM extended precision long double"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4644
+#: config/rs6000/rs6000.c:4669
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "%qs requires VSX support"
 msgstr "%s не падтрымлівае %s"
 
-#: config/rs6000/rs6000.c:4653
+#: config/rs6000/rs6000.c:4678
 #, gcc-internal-format
 msgid "The -mfloat128 option may not be fully supported"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4676
+#: config/rs6000/rs6000.c:4701
 #, gcc-internal-format
 msgid "%qs requires full ISA 3.0 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4743
+#: config/rs6000/rs6000.c:4768
 #, gcc-internal-format
 msgid "unknown vectorization library ABI type (%qs) for %qs switch"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4930
+#: config/rs6000/rs6000.c:4955
 #, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4935
+#: config/rs6000/rs6000.c:4960
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr "Нерэчаісны выбар %s"
 
-#: config/rs6000/rs6000.c:4947
+#: config/rs6000/rs6000.c:4972
 #, fuzzy, gcc-internal-format
 #| msgid "invalid register name for `%s'"
 msgid "%qs is not a valid base register in %qs"
 msgstr "нерэчаісная назва рэгістра `%s'"
 
-#: config/rs6000/rs6000.c:4955
+#: config/rs6000/rs6000.c:4980
 #, gcc-internal-format
 msgid "%qs needs a valid base register"
 msgstr ""
 
-#: config/rs6000/rs6000.c:5253
+#: config/rs6000/rs6000.c:5278
 #, fuzzy, gcc-internal-format
 msgid "unknown option for %<%s=%s%>"
 msgstr "невядомая назва рэгістра: %s\n"
 
-#: config/rs6000/rs6000.c:5290
+#: config/rs6000/rs6000.c:5315
 #, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11401
+#: config/rs6000/rs6000.c:11439
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11862
+#: config/rs6000/rs6000.c:11906
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13572
+#: config/rs6000/rs6000.c:13616
 #, gcc-internal-format
 msgid "internal error: builtin function %qs already processed"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14150
+#: config/rs6000/rs6000.c:14194
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 1-bit unsigned literal"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/rs6000/rs6000.c:14189
+#: config/rs6000/rs6000.c:14233
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qs must be a constant"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/rs6000/rs6000.c:14247 config/rs6000/rs6000.c:15898
+#: config/rs6000/rs6000.c:14291 config/rs6000/rs6000.c:15942
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `__builtin_args_info' out of range"
 msgid "argument 1 of %qs is out of range"
 msgstr "аргумент `__builtin_args_info' выйшаў за межы"
 
-#: config/rs6000/rs6000.c:14742
+#: config/rs6000/rs6000.c:14786
 #, gcc-internal-format
 msgid "builtin %qs is only valid in 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14939
+#: config/rs6000/rs6000.c:14983
 #, gcc-internal-format
 msgid "builtin %qs only accepts a string argument"
 msgstr ""
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000.c:14958
+#: config/rs6000/rs6000.c:15002
 #, gcc-internal-format
 msgid "cpu %qs is an invalid argument to builtin %qs"
 msgstr ""
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000.c:14986
+#: config/rs6000/rs6000.c:15030
 #, gcc-internal-format
 msgid "%s %qs is an invalid argument to builtin %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15012
+#: config/rs6000/rs6000.c:15056
 #, gcc-internal-format
 msgid "builtin %qs needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15616
+#: config/rs6000/rs6000.c:15660
 #, fuzzy, gcc-internal-format
 #| msgid "second argument of `%s' should be `char **'"
 msgid "second argument to %qs must be 0..12"
 msgstr "другім аргументам \"%s\" павінен быць \"char **\""
 
-#: config/rs6000/rs6000.c:15631
+#: config/rs6000/rs6000.c:15675
 #, fuzzy, gcc-internal-format
 #| msgid "first argument of `%s' should be `int'"
 msgid "third argument to %qs must be 0..12"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/rs6000/rs6000.c:15850
+#: config/rs6000/rs6000.c:15894
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument 1 of %s must be a constant"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/rs6000/rs6000.c:15932
+#: config/rs6000/rs6000.c:15976
 #, gcc-internal-format
 msgid "builtin function %qs is only valid for the cell processor"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15934 config/rs6000/rs6000.c:15936
-#: config/rs6000/rs6000.c:15938 config/rs6000/rs6000.c:15940
-#: config/rs6000/rs6000.c:15946 config/rs6000/rs6000.c:15948
-#: config/rs6000/rs6000.c:15955 config/rs6000/rs6000.c:15962
-#: config/rs6000/rs6000.c:15969 config/rs6000/rs6000.c:15975
+#: config/rs6000/rs6000.c:15978 config/rs6000/rs6000.c:15980
+#: config/rs6000/rs6000.c:15982 config/rs6000/rs6000.c:15984
+#: config/rs6000/rs6000.c:15990 config/rs6000/rs6000.c:15992
+#: config/rs6000/rs6000.c:15999 config/rs6000/rs6000.c:16006
+#: config/rs6000/rs6000.c:16011 config/rs6000/rs6000.c:16014
+#: config/rs6000/rs6000.c:16018 config/rs6000/rs6000.c:16024
 #, gcc-internal-format
 msgid "builtin function %qs requires the %qs option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15943 config/rs6000/rs6000.c:15952
-#: config/rs6000/rs6000.c:15959 config/rs6000/rs6000.c:15966
+#: config/rs6000/rs6000.c:15987 config/rs6000/rs6000.c:15996
+#: config/rs6000/rs6000.c:16003
 #, gcc-internal-format
 msgid "builtin function %qs requires the %qs and %qs options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15972
+#: config/rs6000/rs6000.c:16021
 #, gcc-internal-format
 msgid "builtin function %qs requires ISA 3.0 IEEE 128-bit floating point"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15978
+#: config/rs6000/rs6000.c:16027
 #, gcc-internal-format
 msgid "builtin function %qs requires the %qs (or newer), and %qs or %qs options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15982
+#: config/rs6000/rs6000.c:16031
 #, gcc-internal-format
 msgid "builtin function %qs is not supported with the current options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18218
+#: config/rs6000/rs6000.c:18290
 #, gcc-internal-format
 msgid "internal error: builtin function %qs had an unexpected return type %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18235
+#: config/rs6000/rs6000.c:18307
 #, gcc-internal-format
 msgid "internal error: builtin function %qs, argument %d had unexpected argument type %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:29451
+#: config/rs6000/rs6000.c:29528
 #, fuzzy, gcc-internal-format
 #| msgid "Do not use register sb"
 msgid "%qs uses register r29"
 msgstr "Не выкарыстоўваць рэгістра sb"
 
-#: config/rs6000/rs6000.c:32748
+#: config/rs6000/rs6000.c:32825
 #, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32842
+#: config/rs6000/rs6000.c:32919
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32850
+#: config/rs6000/rs6000.c:32927
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32853
+#: config/rs6000/rs6000.c:32930
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:36876
+#: config/rs6000/rs6000.c:36932
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `%D'"
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "нерэчаіснае выкарыстаньне `%D'"
 
-#: config/rs6000/rs6000.c:36879
+#: config/rs6000/rs6000.c:36935
 #, fuzzy, gcc-internal-format
 #| msgid "%s=%s is too large"
 msgid "%s%qs%s is not allowed"
 msgstr "%s=%s вельмі вялікі"
 
-#: config/rs6000/rs6000.c:36881
+#: config/rs6000/rs6000.c:36937
 #, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:37416
+#: config/rs6000/rs6000.c:37472
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:37575
+#: config/rs6000/rs6000.c:37631
 #, gcc-internal-format
 msgid "target_clones attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
@@ -34072,50 +34115,50 @@
 msgid "subprogram %q+F not marked Inline"
 msgstr ""
 
-#: ada/gcc-interface/trans.c:6404
+#: ada/gcc-interface/trans.c:6401
 #, gcc-internal-format
 msgid "out-of-bounds access may be optimized away"
 msgstr ""
 
-#: ada/gcc-interface/trans.c:6406
+#: ada/gcc-interface/trans.c:6403
 #, gcc-internal-format
 msgid "containing loop"
 msgstr ""
 
-#: ada/gcc-interface/utils.c:3887
+#: ada/gcc-interface/utils.c:3890
 #, fuzzy, gcc-internal-format
 msgid "invalid element type for attribute %qs"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: ada/gcc-interface/utils.c:3911
+#: ada/gcc-interface/utils.c:3914
 #, gcc-internal-format
 msgid "number of components of vector not a power of two"
 msgstr ""
 
-#: ada/gcc-interface/utils.c:6037 ada/gcc-interface/utils.c:6215
-#: ada/gcc-interface/utils.c:6322
+#: ada/gcc-interface/utils.c:6043 ada/gcc-interface/utils.c:6220
+#: ada/gcc-interface/utils.c:6327
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored"
 msgid "%qs attribute ignored"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: ada/gcc-interface/utils.c:6158
+#: ada/gcc-interface/utils.c:6164
 #, gcc-internal-format
 msgid "%qs attribute requires prototypes with named arguments"
 msgstr ""
 
-#: ada/gcc-interface/utils.c:6167
+#: ada/gcc-interface/utils.c:6173
 #, fuzzy, gcc-internal-format
 msgid "%qs attribute only applies to variadic functions"
 msgstr "\"%s\" звычайна функцыя"
 
-#: ada/gcc-interface/utils.c:6282
+#: ada/gcc-interface/utils.c:6287
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored"
 msgid "%qE attribute has no effect"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: ada/gcc-interface/utils.c:6406
+#: ada/gcc-interface/utils.c:6411
 #, fuzzy, gcc-internal-format
 msgid "attribute %qs applies to array types only"
 msgstr "\"%s\" атрыбут ігнарыруецца"
@@ -34130,7 +34173,7 @@
 #. an unprototyped function, it is compile-time undefined;
 #. making it a constraint in that case was rejected in
 #. DR#252.
-#: c/c-convert.c:101 c/c-typeck.c:2175 c/c-typeck.c:6507 c/c-typeck.c:12138
+#: c/c-convert.c:101 c/c-typeck.c:2175 c/c-typeck.c:6512 c/c-typeck.c:12143
 #: cp/typeck.c:2027 cp/typeck.c:7977 cp/typeck.c:8742
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
@@ -34194,7 +34237,7 @@
 msgid "type of array %q+D completed incompatibly with implicit initialization"
 msgstr ""
 
-#: c/c-decl.c:1567 c/c-decl.c:6701 c/c-decl.c:7574 c/c-decl.c:8381
+#: c/c-decl.c:1567 c/c-decl.c:6721 c/c-decl.c:7594 c/c-decl.c:8401
 #, gcc-internal-format
 msgid "originally defined here"
 msgstr ""
@@ -34610,16 +34653,11 @@
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.c:4548 c/c-decl.c:7147
+#: c/c-decl.c:4548 c/c-decl.c:7167
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr ""
 
-#: c/c-decl.c:4635 cp/decl2.c:1520
-#, gcc-internal-format
-msgid "%q+D in declare target directive does not have mappable type"
-msgstr ""
-
 #: c/c-decl.c:4693
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is usually a function"
@@ -34647,7 +34685,7 @@
 #. of VLAs themselves count as VLAs, it does not make
 #. sense to permit them to be initialized given that
 #. ordinary VLAs may not be initialized.
-#: c/c-decl.c:4732 c/c-decl.c:4747 c/c-typeck.c:7630
+#: c/c-decl.c:4732 c/c-decl.c:4747 c/c-typeck.c:7635
 #, gcc-internal-format
 msgid "variable-sized object may not be initialized"
 msgstr ""
@@ -34709,207 +34747,212 @@
 msgid "uninitialized const %qD is invalid in C++"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: c/c-decl.c:5268
+#: c/c-decl.c:5224 cp/decl.c:7318
 #, gcc-internal-format
+msgid "%q+D in declare target directive does not have mappable type"
+msgstr ""
+
+#: c/c-decl.c:5288
+#, gcc-internal-format
 msgid "ISO C forbids forward parameter declarations"
 msgstr ""
 
-#: c/c-decl.c:5371
+#: c/c-decl.c:5391
 #, gcc-internal-format
 msgid "defining a type in a compound literal is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:5425 c/c-decl.c:5440
+#: c/c-decl.c:5445 c/c-decl.c:5460
 #, fuzzy, gcc-internal-format
 msgid "bit-field %qs width not an integer constant"
 msgstr "бітавае поле \"%s\" мае нерэчаісны тып"
 
-#: c/c-decl.c:5435
+#: c/c-decl.c:5455
 #, fuzzy, gcc-internal-format
 msgid "bit-field %qs width not an integer constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: c/c-decl.c:5446
+#: c/c-decl.c:5466
 #, gcc-internal-format
 msgid "negative width in bit-field %qs"
 msgstr ""
 
-#: c/c-decl.c:5451
+#: c/c-decl.c:5471
 #, gcc-internal-format
 msgid "zero width for bit-field %qs"
 msgstr ""
 
-#: c/c-decl.c:5461
+#: c/c-decl.c:5481
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field `%s' has invalid type"
 msgid "bit-field %qs has invalid type"
 msgstr "бітавае поле \"%s\" мае нерэчаісны тып"
 
-#: c/c-decl.c:5467
+#: c/c-decl.c:5487
 #, gcc-internal-format
 msgid "cannot declare bit-field %qs with %<warn_if_not_aligned%> type"
 msgstr ""
 
-#: c/c-decl.c:5478
+#: c/c-decl.c:5498
 #, gcc-internal-format
 msgid "type of bit-field %qs is a GCC extension"
 msgstr ""
 
-#: c/c-decl.c:5484
+#: c/c-decl.c:5504
 #, gcc-internal-format
 msgid "width of %qs exceeds its type"
 msgstr ""
 
-#: c/c-decl.c:5497
+#: c/c-decl.c:5517
 #, gcc-internal-format
 msgid "%qs is narrower than values of its type"
 msgstr ""
 
-#: c/c-decl.c:5512
+#: c/c-decl.c:5532
 #, gcc-internal-format
 msgid "ISO C90 forbids array %qE whose size can%'t be evaluated"
 msgstr ""
 
-#: c/c-decl.c:5515
+#: c/c-decl.c:5535
 #, gcc-internal-format
 msgid "ISO C90 forbids array whose size can%'t be evaluated"
 msgstr ""
 
-#: c/c-decl.c:5522
+#: c/c-decl.c:5542
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 forbids variable length array %qE"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: c/c-decl.c:5524
+#: c/c-decl.c:5544
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 forbids variable length array"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: c/c-decl.c:5733 c/c-decl.c:6107 c/c-decl.c:6117
+#: c/c-decl.c:5753 c/c-decl.c:6127 c/c-decl.c:6137
 #, gcc-internal-format
 msgid "variably modified %qE at file scope"
 msgstr ""
 
-#: c/c-decl.c:5735
+#: c/c-decl.c:5755
 #, gcc-internal-format
 msgid "variably modified field at file scope"
 msgstr ""
 
-#: c/c-decl.c:5755
+#: c/c-decl.c:5775
 #, gcc-internal-format
 msgid "type defaults to %<int%> in declaration of %qE"
 msgstr ""
 
-#: c/c-decl.c:5759
+#: c/c-decl.c:5779
 #, gcc-internal-format
 msgid "type defaults to %<int%> in type name"
 msgstr ""
 
-#: c/c-decl.c:5791
+#: c/c-decl.c:5811
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `const'"
 msgid "duplicate %<const%>"
 msgstr "паўтарэнне \"const\""
 
-#: c/c-decl.c:5793
+#: c/c-decl.c:5813
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `restrict'"
 msgid "duplicate %<restrict%>"
 msgstr "паўтарэнне \"restrict\""
 
-#: c/c-decl.c:5795
+#: c/c-decl.c:5815
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `volatile'"
 msgid "duplicate %<volatile%>"
 msgstr "паўтарэнне \"volatile\""
 
-#: c/c-decl.c:5797
+#: c/c-decl.c:5817
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `restrict'"
 msgid "duplicate %<_Atomic%>"
 msgstr "паўтарэнне \"restrict\""
 
-#: c/c-decl.c:5800
+#: c/c-decl.c:5820
 #, gcc-internal-format, gfc-internal-format
 msgid "conflicting named address spaces (%s vs %s)"
 msgstr ""
 
-#: c/c-decl.c:5823 c/c-parser.c:2821
+#: c/c-decl.c:5843 c/c-parser.c:2821
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified array type"
 msgstr ""
 
-#: c/c-decl.c:5837
+#: c/c-decl.c:5857
 #, gcc-internal-format
 msgid "function definition declared %<auto%>"
 msgstr ""
 
-#: c/c-decl.c:5839
+#: c/c-decl.c:5859
 #, fuzzy, gcc-internal-format
 msgid "function definition declared %<register%>"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: c/c-decl.c:5841
+#: c/c-decl.c:5861
 #, gcc-internal-format
 msgid "function definition declared %<typedef%>"
 msgstr ""
 
-#: c/c-decl.c:5843
+#: c/c-decl.c:5863
 #, fuzzy, gcc-internal-format
 msgid "function definition declared %qs"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: c/c-decl.c:5861
+#: c/c-decl.c:5881
 #, gcc-internal-format
 msgid "storage class specified for structure field %qE"
 msgstr ""
 
-#: c/c-decl.c:5864
+#: c/c-decl.c:5884
 #, gcc-internal-format
 msgid "storage class specified for structure field"
 msgstr ""
 
-#: c/c-decl.c:5868
+#: c/c-decl.c:5888
 #, gcc-internal-format
 msgid "storage class specified for parameter %qE"
 msgstr ""
 
-#: c/c-decl.c:5871
+#: c/c-decl.c:5891
 #, gcc-internal-format
 msgid "storage class specified for unnamed parameter"
 msgstr ""
 
-#: c/c-decl.c:5874 cp/decl.c:10935
+#: c/c-decl.c:5894 cp/decl.c:10959
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr ""
 
-#: c/c-decl.c:5891
+#: c/c-decl.c:5911
 #, gcc-internal-format
 msgid "%qE initialized and declared %<extern%>"
 msgstr ""
 
-#: c/c-decl.c:5895
+#: c/c-decl.c:5915
 #, gcc-internal-format
 msgid "%qE has both %<extern%> and initializer"
 msgstr ""
 
-#: c/c-decl.c:5900
+#: c/c-decl.c:5920
 #, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<auto%>"
 msgstr ""
 
-#: c/c-decl.c:5904
+#: c/c-decl.c:5924
 #, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<register%>"
 msgstr ""
 
-#: c/c-decl.c:5909
+#: c/c-decl.c:5929
 #, gcc-internal-format
 msgid "nested function %qE declared %<extern%>"
 msgstr ""
 
-#: c/c-decl.c:5912
+#: c/c-decl.c:5932
 #, gcc-internal-format
 msgid "function-scope %qE implicitly auto and declared %qs"
 msgstr ""
@@ -34917,79 +34960,79 @@
 #. Only the innermost declarator (making a parameter be of
 #. array type which is converted to pointer type)
 #. may have static or type qualifiers.
-#: c/c-decl.c:5959 c/c-decl.c:6328
+#: c/c-decl.c:5979 c/c-decl.c:6348
 #, gcc-internal-format
 msgid "static or type qualifiers in non-parameter array declarator"
 msgstr ""
 
-#: c/c-decl.c:6007
+#: c/c-decl.c:6027
 #, gcc-internal-format
 msgid "declaration of %qE as array of voids"
 msgstr ""
 
-#: c/c-decl.c:6009
+#: c/c-decl.c:6029
 #, gcc-internal-format
 msgid "declaration of type name as array of voids"
 msgstr ""
 
-#: c/c-decl.c:6016
+#: c/c-decl.c:6036
 #, gcc-internal-format
 msgid "declaration of %qE as array of functions"
 msgstr ""
 
-#: c/c-decl.c:6019
+#: c/c-decl.c:6039
 #, gcc-internal-format
 msgid "declaration of type name as array of functions"
 msgstr ""
 
-#: c/c-decl.c:6027 c/c-decl.c:8085
+#: c/c-decl.c:6047 c/c-decl.c:8105
 #, fuzzy, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: c/c-decl.c:6053
+#: c/c-decl.c:6073
 #, fuzzy, gcc-internal-format
 msgid "size of array %qE has non-integer type"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: c/c-decl.c:6057
+#: c/c-decl.c:6077
 #, fuzzy, gcc-internal-format
 msgid "size of unnamed array has non-integer type"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: c/c-decl.c:6064
+#: c/c-decl.c:6084
 #, fuzzy, gcc-internal-format
 msgid "size of array %qE has incomplete type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: c/c-decl.c:6067
+#: c/c-decl.c:6087
 #, fuzzy, gcc-internal-format
 msgid "size of unnamed array has incomplete type"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: c/c-decl.c:6078
+#: c/c-decl.c:6098
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids zero-size array %qE"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: c/c-decl.c:6081
+#: c/c-decl.c:6101
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids zero-size array"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: c/c-decl.c:6090
+#: c/c-decl.c:6110
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is negative"
 msgid "size of array %qE is negative"
 msgstr "адмоўны памер масіва "
 
-#: c/c-decl.c:6092
+#: c/c-decl.c:6112
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is negative"
 msgid "size of unnamed array is negative"
 msgstr "адмоўны памер масіва "
 
-#: c/c-decl.c:6216 c/c-decl.c:6871
+#: c/c-decl.c:6236 c/c-decl.c:6891
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C89 does not support complex types"
 msgid "ISO C90 does not support flexible array members"
@@ -34996,645 +35039,645 @@
 msgstr "ISO C89 не падтрымлівае комлексныя тыпы"
 
 #. C99 6.7.5.2p4
-#: c/c-decl.c:6238
+#: c/c-decl.c:6258
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not at beginning of declaration"
 msgid "%<[*]%> not in a declaration"
 msgstr "\"%s\" - гэта не пачатак дэкларацыі"
 
-#: c/c-decl.c:6251
+#: c/c-decl.c:6271
 #, fuzzy, gcc-internal-format
 msgid "array type has incomplete element type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: c/c-decl.c:6257
+#: c/c-decl.c:6277
 #, gcc-internal-format
 msgid "declaration of %qE as multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: c/c-decl.c:6261
+#: c/c-decl.c:6281
 #, gcc-internal-format
 msgid "declaration of multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: c/c-decl.c:6364
+#: c/c-decl.c:6384
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' undeclared (first use in this function)"
 msgid "%qE declared as function returning a function"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: c/c-decl.c:6367
+#: c/c-decl.c:6387
 #, gcc-internal-format
 msgid "type name declared as function returning a function"
 msgstr ""
 
-#: c/c-decl.c:6374
+#: c/c-decl.c:6394
 #, gcc-internal-format
 msgid "%qE declared as function returning an array"
 msgstr ""
 
-#: c/c-decl.c:6377
+#: c/c-decl.c:6397
 #, gcc-internal-format
 msgid "type name declared as function returning an array"
 msgstr ""
 
-#: c/c-decl.c:6418
+#: c/c-decl.c:6438
 #, fuzzy, gcc-internal-format
 #| msgid "function does not return string type"
 msgid "function definition has qualified void return type"
 msgstr "функцыя не вяртае тып string"
 
-#: c/c-decl.c:6421 cp/decl.c:11201
+#: c/c-decl.c:6441 cp/decl.c:11225
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr ""
 
-#: c/c-decl.c:6459 c/c-decl.c:6668 c/c-decl.c:6721 c/c-decl.c:6805
-#: c/c-decl.c:6926 c/c-parser.c:2823
+#: c/c-decl.c:6479 c/c-decl.c:6688 c/c-decl.c:6741 c/c-decl.c:6825
+#: c/c-decl.c:6946 c/c-parser.c:2823
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified function type"
 msgstr ""
 
-#: c/c-decl.c:6465 c/c-decl.c:6674 c/c-decl.c:6810 c/c-decl.c:6931
+#: c/c-decl.c:6485 c/c-decl.c:6694 c/c-decl.c:6830 c/c-decl.c:6951
 #, gcc-internal-format
 msgid "ISO C forbids qualified function types"
 msgstr ""
 
-#: c/c-decl.c:6559
+#: c/c-decl.c:6579
 #, gcc-internal-format
 msgid "%qs combined with %<auto%> qualifier for %qE"
 msgstr ""
 
-#: c/c-decl.c:6563
+#: c/c-decl.c:6583
 #, gcc-internal-format
 msgid "%qs combined with %<register%> qualifier for %qE"
 msgstr ""
 
-#: c/c-decl.c:6569
+#: c/c-decl.c:6589
 #, gcc-internal-format
 msgid "%qs specified for auto variable %qE"
 msgstr ""
 
-#: c/c-decl.c:6585
+#: c/c-decl.c:6605
 #, gcc-internal-format
 msgid "%qs specified for parameter %qE"
 msgstr ""
 
-#: c/c-decl.c:6588
+#: c/c-decl.c:6608
 #, gcc-internal-format
 msgid "%qs specified for unnamed parameter"
 msgstr ""
 
-#: c/c-decl.c:6594
+#: c/c-decl.c:6614
 #, gcc-internal-format
 msgid "%qs specified for structure field %qE"
 msgstr ""
 
-#: c/c-decl.c:6597
+#: c/c-decl.c:6617
 #, gcc-internal-format
 msgid "%qs specified for structure field"
 msgstr ""
 
-#: c/c-decl.c:6612
+#: c/c-decl.c:6632
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field `%s' has invalid type"
 msgid "bit-field %qE has atomic type"
 msgstr "бітавае поле \"%s\" мае нерэчаісны тып"
 
-#: c/c-decl.c:6614
+#: c/c-decl.c:6634
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field `%s' has invalid type"
 msgid "bit-field has atomic type"
 msgstr "бітавае поле \"%s\" мае нерэчаісны тып"
 
-#: c/c-decl.c:6623
+#: c/c-decl.c:6643
 #, gcc-internal-format
 msgid "alignment specified for typedef %qE"
 msgstr ""
 
-#: c/c-decl.c:6625
+#: c/c-decl.c:6645
 #, gcc-internal-format
 msgid "alignment specified for %<register%> object %qE"
 msgstr ""
 
-#: c/c-decl.c:6630
+#: c/c-decl.c:6650
 #, gcc-internal-format
 msgid "alignment specified for parameter %qE"
 msgstr ""
 
-#: c/c-decl.c:6632
+#: c/c-decl.c:6652
 #, gcc-internal-format
 msgid "alignment specified for unnamed parameter"
 msgstr ""
 
-#: c/c-decl.c:6637
+#: c/c-decl.c:6657
 #, gcc-internal-format
 msgid "alignment specified for bit-field %qE"
 msgstr ""
 
-#: c/c-decl.c:6639
+#: c/c-decl.c:6659
 #, gcc-internal-format
 msgid "alignment specified for unnamed bit-field"
 msgstr ""
 
-#: c/c-decl.c:6642
+#: c/c-decl.c:6662
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for function %qE"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: c/c-decl.c:6649
+#: c/c-decl.c:6669
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of %qE"
 msgstr ""
 
-#: c/c-decl.c:6652
+#: c/c-decl.c:6672
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of unnamed field"
 msgstr ""
 
-#: c/c-decl.c:6683
+#: c/c-decl.c:6703
 #, gcc-internal-format
 msgid "typedef %q+D declared %<inline%>"
 msgstr ""
 
-#: c/c-decl.c:6685
+#: c/c-decl.c:6705
 #, gcc-internal-format
 msgid "typedef %q+D declared %<_Noreturn%>"
 msgstr ""
 
-#: c/c-decl.c:6727
+#: c/c-decl.c:6747
 #, gcc-internal-format
 msgid "ISO C forbids const or volatile function types"
 msgstr ""
 
 #. C99 6.7.2.1p8
-#: c/c-decl.c:6738
+#: c/c-decl.c:6758
 #, gcc-internal-format
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr ""
 
-#: c/c-decl.c:6755 cp/decl.c:9989
+#: c/c-decl.c:6775 cp/decl.c:10010
 #, fuzzy, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: c/c-decl.c:6795
+#: c/c-decl.c:6815
 #, gcc-internal-format
 msgid "attributes in parameter array declarator ignored"
 msgstr ""
 
-#: c/c-decl.c:6837
+#: c/c-decl.c:6857
 #, fuzzy, gcc-internal-format
 msgid "parameter %q+D declared %<inline%>"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: c/c-decl.c:6839
+#: c/c-decl.c:6859
 #, fuzzy, gcc-internal-format
 msgid "parameter %q+D declared %<_Noreturn%>"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: c/c-decl.c:6852
+#: c/c-decl.c:6872
 #, fuzzy, gcc-internal-format
 msgid "field %qE declared as a function"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: c/c-decl.c:6859
+#: c/c-decl.c:6879
 #, fuzzy, gcc-internal-format
 msgid "field %qE has incomplete type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: c/c-decl.c:6861
+#: c/c-decl.c:6881
 #, fuzzy, gcc-internal-format
 msgid "unnamed field has incomplete type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: c/c-decl.c:6897 c/c-decl.c:6908 c/c-decl.c:6911
+#: c/c-decl.c:6917 c/c-decl.c:6928 c/c-decl.c:6931
 #, fuzzy, gcc-internal-format
 msgid "invalid storage class for function %qE"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: c/c-decl.c:6968
+#: c/c-decl.c:6988
 #, fuzzy, gcc-internal-format
 msgid "cannot inline function %<main%>"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: c/c-decl.c:6970
+#: c/c-decl.c:6990
 #, gcc-internal-format
 msgid "%<main%> declared %<_Noreturn%>"
 msgstr ""
 
-#: c/c-decl.c:6981
+#: c/c-decl.c:7001
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C89 does not support complex types"
 msgid "ISO C99 does not support %<_Noreturn%>"
 msgstr "ISO C89 не падтрымлівае комлексныя тыпы"
 
-#: c/c-decl.c:6984
+#: c/c-decl.c:7004
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C89 does not support complex types"
 msgid "ISO C90 does not support %<_Noreturn%>"
 msgstr "ISO C89 не падтрымлівае комлексныя тыпы"
 
-#: c/c-decl.c:7013
+#: c/c-decl.c:7033
 #, gcc-internal-format
 msgid "variable previously declared %<static%> redeclared %<extern%>"
 msgstr ""
 
-#: c/c-decl.c:7023
+#: c/c-decl.c:7043
 #, gcc-internal-format
 msgid "variable %q+D declared %<inline%>"
 msgstr ""
 
-#: c/c-decl.c:7025
+#: c/c-decl.c:7045
 #, gcc-internal-format
 msgid "variable %q+D declared %<_Noreturn%>"
 msgstr ""
 
-#: c/c-decl.c:7060
+#: c/c-decl.c:7080
 #, gcc-internal-format
 msgid "non-nested function with variably modified type"
 msgstr ""
 
-#: c/c-decl.c:7062
+#: c/c-decl.c:7082
 #, gcc-internal-format
 msgid "object with variably modified type must have no linkage"
 msgstr ""
 
-#: c/c-decl.c:7153 c/c-decl.c:8821
+#: c/c-decl.c:7173 c/c-decl.c:8841
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr ""
 
-#: c/c-decl.c:7163
+#: c/c-decl.c:7183
 #, gcc-internal-format
 msgid "parameter names (without types) in function declaration"
 msgstr ""
 
-#: c/c-decl.c:7201
+#: c/c-decl.c:7221
 #, fuzzy, gcc-internal-format
 msgid "parameter %u (%q+D) has incomplete type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: c/c-decl.c:7205
+#: c/c-decl.c:7225
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has incomplete type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: c/c-decl.c:7216
+#: c/c-decl.c:7236
 #, fuzzy, gcc-internal-format
 msgid "parameter %u (%q+D) has void type"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: c/c-decl.c:7220
+#: c/c-decl.c:7240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has void type"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: c/c-decl.c:7294
+#: c/c-decl.c:7314
 #, gcc-internal-format
 msgid "%<void%> as only parameter may not be qualified"
 msgstr ""
 
-#: c/c-decl.c:7298 c/c-decl.c:7334
+#: c/c-decl.c:7318 c/c-decl.c:7354
 #, fuzzy, gcc-internal-format
 msgid "%<void%> must be the only parameter"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: c/c-decl.c:7328
+#: c/c-decl.c:7348
 #, gcc-internal-format
 msgid "parameter %q+D has just a forward declaration"
 msgstr ""
 
-#: c/c-decl.c:7374
+#: c/c-decl.c:7394
 #, gcc-internal-format
 msgid "%<%s %E%> declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr ""
 
-#: c/c-decl.c:7380
+#: c/c-decl.c:7400
 #, gcc-internal-format, gfc-internal-format
 msgid "anonymous %s declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr ""
 
-#: c/c-decl.c:7482
+#: c/c-decl.c:7502
 #, gcc-internal-format
 msgid "enum type defined here"
 msgstr ""
 
-#: c/c-decl.c:7488
+#: c/c-decl.c:7508
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition here"
 msgid "struct defined here"
 msgstr "папярэдняе вызначэньне"
 
-#: c/c-decl.c:7494
+#: c/c-decl.c:7514
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition here"
 msgid "union defined here"
 msgstr "папярэдняе вызначэньне"
 
-#: c/c-decl.c:7570
+#: c/c-decl.c:7590
 #, fuzzy, gcc-internal-format
 msgid "redefinition of %<union %E%>"
 msgstr "перанакіраванне stdout: %s"
 
-#: c/c-decl.c:7572
+#: c/c-decl.c:7592
 #, fuzzy, gcc-internal-format
 msgid "redefinition of %<struct %E%>"
 msgstr "перанакіраванне stdout: %s"
 
-#: c/c-decl.c:7581
+#: c/c-decl.c:7601
 #, fuzzy, gcc-internal-format
 msgid "nested redefinition of %<union %E%>"
 msgstr "перанакіраванне stdout: %s"
 
-#: c/c-decl.c:7583
+#: c/c-decl.c:7603
 #, fuzzy, gcc-internal-format
 msgid "nested redefinition of %<struct %E%>"
 msgstr "перанакіраванне stdout: %s"
 
-#: c/c-decl.c:7613 c/c-decl.c:8400
+#: c/c-decl.c:7633 c/c-decl.c:8420
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:7680 cp/decl.c:4802
+#: c/c-decl.c:7700 cp/decl.c:4802
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr ""
 
-#: c/c-decl.c:7685
+#: c/c-decl.c:7705
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C89 does not support complex types"
 msgid "ISO C99 doesn%'t support unnamed structs/unions"
 msgstr "ISO C89 не падтрымлівае комлексныя тыпы"
 
-#: c/c-decl.c:7688
+#: c/c-decl.c:7708
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C89 does not support complex types"
 msgid "ISO C90 doesn%'t support unnamed structs/unions"
 msgstr "ISO C89 не падтрымлівае комлексныя тыпы"
 
-#: c/c-decl.c:7781 c/c-decl.c:7799 c/c-decl.c:7860
+#: c/c-decl.c:7801 c/c-decl.c:7819 c/c-decl.c:7880
 #, fuzzy, gcc-internal-format
 msgid "duplicate member %q+D"
 msgstr "паўтарэнне \"%s\""
 
-#: c/c-decl.c:7886
+#: c/c-decl.c:7906
 #, gcc-internal-format
 msgid "empty struct has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.c:7889
+#: c/c-decl.c:7909
 #, gcc-internal-format
 msgid "empty union has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.c:7994
+#: c/c-decl.c:8014
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr ""
 
-#: c/c-decl.c:7996
+#: c/c-decl.c:8016
 #, gcc-internal-format
 msgid "union has no members"
 msgstr ""
 
-#: c/c-decl.c:8001
+#: c/c-decl.c:8021
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr ""
 
-#: c/c-decl.c:8003
+#: c/c-decl.c:8023
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr ""
 
-#: c/c-decl.c:8064 cp/decl.c:12069
+#: c/c-decl.c:8084 cp/decl.c:12093
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr ""
 
-#: c/c-decl.c:8070
+#: c/c-decl.c:8090
 #, gcc-internal-format
 msgid "flexible array member not at end of struct"
 msgstr ""
 
-#: c/c-decl.c:8076
+#: c/c-decl.c:8096
 #, gcc-internal-format
 msgid "flexible array member in a struct with no named members"
 msgstr ""
 
-#: c/c-decl.c:8107
+#: c/c-decl.c:8127
 #, fuzzy, gcc-internal-format
 #| msgid "%s is too large"
 msgid "type %qT is too large"
 msgstr "%s - вельмі вялікі"
 
-#: c/c-decl.c:8230
+#: c/c-decl.c:8250
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr ""
 
-#: c/c-decl.c:8372
+#: c/c-decl.c:8392
 #, fuzzy, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr "перанакіраванне stdout: %s"
 
 #. This enum is a named one that has been declared already.
-#: c/c-decl.c:8379
+#: c/c-decl.c:8399
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D'"
 msgid "redeclaration of %<enum %E%>"
 msgstr "абвяшчэньне `%#D'"
 
-#: c/c-decl.c:8458 cp/decl.c:14423
+#: c/c-decl.c:8478 cp/decl.c:14447
 #, gcc-internal-format
 msgid "specified mode too small for enumeral values"
 msgstr ""
 
-#: c/c-decl.c:8473
+#: c/c-decl.c:8493
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr ""
 
-#: c/c-decl.c:8587 c/c-decl.c:8603
+#: c/c-decl.c:8607 c/c-decl.c:8623
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: c/c-decl.c:8598
+#: c/c-decl.c:8618
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: c/c-decl.c:8622
+#: c/c-decl.c:8642
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr ""
 
-#: c/c-decl.c:8630
+#: c/c-decl.c:8650
 #, gcc-internal-format
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr ""
 
-#: c/c-decl.c:8715 cp/decl.c:5104 cp/decl.c:14955
+#: c/c-decl.c:8735 cp/decl.c:5104 cp/decl.c:14979
 #, fuzzy, gcc-internal-format
 msgid "inline function %qD given attribute noinline"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: c/c-decl.c:8733
+#: c/c-decl.c:8753
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr ""
 
-#: c/c-decl.c:8744
+#: c/c-decl.c:8764
 #, fuzzy, gcc-internal-format
 #| msgid "return type of `%s' is not `int'"
 msgid "return type defaults to %<int%>"
 msgstr "вяртаемы тып \"%s\" не \"int\""
 
-#: c/c-decl.c:8771
+#: c/c-decl.c:8791
 #, gcc-internal-format
 msgid "%q+D defined as variadic function without prototype"
 msgstr ""
 
-#: c/c-decl.c:8830
+#: c/c-decl.c:8850
 #, fuzzy, gcc-internal-format
 #| msgid "no previous prototype for `%s'"
 msgid "no previous prototype for %qD"
 msgstr "няма папярэдняга прататыпа для \"%s\""
 
-#: c/c-decl.c:8839
+#: c/c-decl.c:8859
 #, fuzzy, gcc-internal-format
 msgid "%qD was used with no prototype before its definition"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: c/c-decl.c:8847 cp/decl.c:15090
+#: c/c-decl.c:8867 cp/decl.c:15114
 #, fuzzy, gcc-internal-format
 #| msgid "no previous declaration for `%s'"
 msgid "no previous declaration for %qD"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: c/c-decl.c:8857
+#: c/c-decl.c:8877
 #, fuzzy, gcc-internal-format
 msgid "%qD was used with no declaration before its definition"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: c/c-decl.c:8876
+#: c/c-decl.c:8896
 #, fuzzy, gcc-internal-format
 #| msgid "return type of `%s' is not `int'"
 msgid "return type of %qD is not %<int%>"
 msgstr "вяртаемы тып \"%s\" не \"int\""
 
-#: c/c-decl.c:8878
+#: c/c-decl.c:8898
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr ""
 
-#: c/c-decl.c:8885
+#: c/c-decl.c:8905
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is usually a function"
 msgid "%qD is normally a non-static function"
 msgstr "`%s' - звычайна функцыя"
 
-#: c/c-decl.c:8922
+#: c/c-decl.c:8942
 #, gcc-internal-format
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr ""
 
-#: c/c-decl.c:8937
+#: c/c-decl.c:8957
 #, gcc-internal-format
 msgid "traditional C rejects ISO C style function definitions"
 msgstr ""
 
-#: c/c-decl.c:8953
+#: c/c-decl.c:8973
 #, gcc-internal-format
 msgid "parameter name omitted"
 msgstr ""
 
-#: c/c-decl.c:8990
+#: c/c-decl.c:9010
 #, gcc-internal-format
 msgid "old-style function definition"
 msgstr ""
 
-#: c/c-decl.c:8999
+#: c/c-decl.c:9019
 #, gcc-internal-format
 msgid "parameter name missing from parameter list"
 msgstr ""
 
-#: c/c-decl.c:9015
+#: c/c-decl.c:9035
 #, gcc-internal-format
 msgid "%qD declared as a non-parameter"
 msgstr ""
 
-#: c/c-decl.c:9023
+#: c/c-decl.c:9043
 #, fuzzy, gcc-internal-format
 msgid "multiple parameters named %qD"
 msgstr "невыкарыстаемы параметр \"%s\""
 
-#: c/c-decl.c:9032
+#: c/c-decl.c:9052
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD declared with void type"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: c/c-decl.c:9061 c/c-decl.c:9066
+#: c/c-decl.c:9081 c/c-decl.c:9086
 #, gcc-internal-format
 msgid "type of %qD defaults to %<int%>"
 msgstr ""
 
-#: c/c-decl.c:9086
+#: c/c-decl.c:9106
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD has incomplete type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: c/c-decl.c:9093
+#: c/c-decl.c:9113
 #, gcc-internal-format
 msgid "declaration for parameter %qD but no such parameter"
 msgstr ""
 
-#: c/c-decl.c:9146
+#: c/c-decl.c:9166
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr ""
 
-#: c/c-decl.c:9157
+#: c/c-decl.c:9177
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for `%s' attribute"
 msgid "number of arguments doesn%'t match prototype"
 msgstr "памылковая колькасьць аргументаў, зададзеных для атрыбута `%s'"
 
-#: c/c-decl.c:9160 c/c-decl.c:9207 c/c-decl.c:9221
+#: c/c-decl.c:9180 c/c-decl.c:9227 c/c-decl.c:9241
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "prototype declaration"
 msgstr "пустое абвяшчэньне"
 
-#: c/c-decl.c:9199
+#: c/c-decl.c:9219
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr ""
 
-#: c/c-decl.c:9204
+#: c/c-decl.c:9224
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr ""
 
-#: c/c-decl.c:9214
+#: c/c-decl.c:9234
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr ""
 
-#: c/c-decl.c:9219
+#: c/c-decl.c:9239
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr ""
 
-#: c/c-decl.c:9470 cp/decl.c:15873
+#: c/c-decl.c:9490 cp/decl.c:15897
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr ""
 
-#: c/c-decl.c:9490 cp/decl.c:15905
+#: c/c-decl.c:9510 cp/decl.c:15929
 #, fuzzy, gcc-internal-format
 #| msgid "label `%D' defined but not used"
 msgid "parameter %qD set but not used"
@@ -35643,262 +35686,262 @@
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:9586
+#: c/c-decl.c:9606
 #, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr ""
 
-#: c/c-decl.c:9591
+#: c/c-decl.c:9611
 #, gcc-internal-format
 msgid "use option -std=c99, -std=gnu99, -std=c11 or -std=gnu11 to compile your code"
 msgstr ""
 
-#: c/c-decl.c:9626
+#: c/c-decl.c:9646
 #, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:9630
+#: c/c-decl.c:9650
 #, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:9637
+#: c/c-decl.c:9657
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:9642
+#: c/c-decl.c:9662
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:9646
+#: c/c-decl.c:9666
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:9650
+#: c/c-decl.c:9670
 #, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:9900
+#: c/c-decl.c:9920
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr ""
 
-#: c/c-decl.c:9958 c/c-decl.c:9965
+#: c/c-decl.c:9978 c/c-decl.c:9985
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate label declaration `%s'"
 msgid "duplicate %qE declaration specifier"
 msgstr "паўторнае абвяшчэньне адмеціны `%s'"
 
-#: c/c-decl.c:9992 c/c-decl.c:10376 c/c-decl.c:10766
+#: c/c-decl.c:10012 c/c-decl.c:10396 c/c-decl.c:10786
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr ""
 
-#: c/c-decl.c:10004 cp/parser.c:28261
+#: c/c-decl.c:10024 cp/parser.c:28258
 #, fuzzy, gcc-internal-format
 #| msgid "`long long long' is too long for GCC"
 msgid "%<long long long%> is too long for GCC"
 msgstr "`long long long' - вельмі доўга для GCC"
 
-#: c/c-decl.c:10017
+#: c/c-decl.c:10037
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C89 does not support `long long'"
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C89 не падтрымлівае `long long'"
 
-#: c/c-decl.c:10246 c/c-parser.c:8848
+#: c/c-decl.c:10266 c/c-parser.c:8848
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C89 does not support complex types"
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C89 не падтрымлівае комлексныя тыпы"
 
-#: c/c-decl.c:10292
+#: c/c-decl.c:10312
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support saturating types"
 msgstr "ISO C не падтрымлівае комлексныя цэлалікавыя тыпы"
 
-#: c/c-decl.c:10363 c/c-decl.c:10923
+#: c/c-decl.c:10383 c/c-decl.c:10943
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `%s'"
 msgid "duplicate %qE"
 msgstr "паўтарэньне `%s'"
 
-#: c/c-decl.c:10419
+#: c/c-decl.c:10439
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C не падтрымлівае комлексныя цэлалікавыя тыпы"
 
-#: c/c-decl.c:10441
+#: c/c-decl.c:10461
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
 
-#: c/c-decl.c:10484
+#: c/c-decl.c:10504
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C89 does not support complex types"
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C89 не падтрымлівае комлексныя тыпы"
 
-#: c/c-decl.c:10603
+#: c/c-decl.c:10623
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C89 does not support complex types"
 msgid "ISO C does not support the %<_Float%d%s%> type"
 msgstr "ISO C89 не падтрымлівае комлексныя тыпы"
 
-#: c/c-decl.c:10653
+#: c/c-decl.c:10673
 #, fuzzy, gcc-internal-format
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
 
-#: c/c-decl.c:10724
+#: c/c-decl.c:10744
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C89 does not support `long long'"
 msgid "ISO C does not support decimal floating point"
 msgstr "ISO C89 не падтрымлівае `long long'"
 
-#: c/c-decl.c:10747 c/c-decl.c:11013 c/c-parser.c:7842
+#: c/c-decl.c:10767 c/c-decl.c:11033 c/c-parser.c:7842
 #, fuzzy, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: c/c-decl.c:10749
+#: c/c-decl.c:10769
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support complex integer types"
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C не падтрымлівае комлексныя цэлалікавыя тыпы"
 
-#: c/c-decl.c:10784
+#: c/c-decl.c:10804
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr ""
 
-#: c/c-decl.c:10797
+#: c/c-decl.c:10817
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr ""
 
-#: c/c-decl.c:10845
+#: c/c-decl.c:10865
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not at beginning of declaration"
 msgid "%qE is not at beginning of declaration"
 msgstr "\"%s\" - гэта не пачатак дэкларацыі"
 
-#: c/c-decl.c:10866
+#: c/c-decl.c:10886
 #, gcc-internal-format
 msgid "%qE used with %<auto%>"
 msgstr ""
 
-#: c/c-decl.c:10868
+#: c/c-decl.c:10888
 #, gcc-internal-format
 msgid "%qE used with %<register%>"
 msgstr ""
 
-#: c/c-decl.c:10870
+#: c/c-decl.c:10890
 #, gcc-internal-format
 msgid "%qE used with %<typedef%>"
 msgstr ""
 
-#: c/c-decl.c:10884 c/c-parser.c:7360
+#: c/c-decl.c:10904 c/c-parser.c:7360
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "ISO C99 does not support %qE"
 msgstr "%s не падтрымлівае %s"
 
-#: c/c-decl.c:10887 c/c-parser.c:7363
+#: c/c-decl.c:10907 c/c-parser.c:7363
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "ISO C90 does not support %qE"
 msgstr "%s не падтрымлівае %s"
 
-#: c/c-decl.c:10899
+#: c/c-decl.c:10919
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr ""
 
-#: c/c-decl.c:10908
+#: c/c-decl.c:10928
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr ""
 
-#: c/c-decl.c:10921
+#: c/c-decl.c:10941
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr ""
 
-#: c/c-decl.c:10929
+#: c/c-decl.c:10949
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr ""
 
-#: c/c-decl.c:10937
+#: c/c-decl.c:10957
 #, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr ""
 
-#: c/c-decl.c:11010
+#: c/c-decl.c:11030
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr ""
 
-#: c/c-decl.c:11025
+#: c/c-decl.c:11045
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain `complex' meaning `double complex'"
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C не падтрымлівае просты \"complex\" у значэнні \"double complex\""
 
-#: c/c-decl.c:11076 c/c-decl.c:11092 c/c-decl.c:11118
+#: c/c-decl.c:11096 c/c-decl.c:11112 c/c-decl.c:11138
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C не падтрымлівае комлексныя цэлалікавыя тыпы"
 
-#: c/c-decl.c:11514 cp/semantics.c:5348
+#: c/c-decl.c:11534 cp/semantics.c:5351
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:11518 cp/semantics.c:5352
+#: c/c-decl.c:11538 cp/semantics.c:5355
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.c:385 c/c-typeck.c:11426 cp/typeck.c:4680
+#: c/c-fold.c:385 c/c-typeck.c:11431 cp/typeck.c:4680
 #, gcc-internal-format
 msgid "left shift of negative value"
 msgstr ""
 
-#: c/c-fold.c:395 c/c-typeck.c:11435 cp/typeck.c:4688
+#: c/c-fold.c:395 c/c-typeck.c:11440 cp/typeck.c:4688
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr ""
 
-#: c/c-fold.c:396 c/c-typeck.c:11365 cp/typeck.c:4633
+#: c/c-fold.c:396 c/c-typeck.c:11370 cp/typeck.c:4633
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr ""
 
-#: c/c-fold.c:404 c/c-typeck.c:11454 cp/typeck.c:4696
+#: c/c-fold.c:404 c/c-typeck.c:11459 cp/typeck.c:4696
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr ""
 
-#: c/c-fold.c:405 c/c-typeck.c:11389 cp/typeck.c:4641
+#: c/c-fold.c:405 c/c-typeck.c:11394 cp/typeck.c:4641
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr ""
 
-#: c/c-fold.c:412 c/c-typeck.c:11446
+#: c/c-fold.c:412 c/c-typeck.c:11451
 #, gcc-internal-format
 msgid "left shift count >= width of vector element"
 msgstr ""
 
-#: c/c-fold.c:413 c/c-typeck.c:11376
+#: c/c-fold.c:413 c/c-typeck.c:11381
 #, gcc-internal-format
 msgid "right shift count >= width of vector element"
 msgstr ""
@@ -35918,7 +35961,7 @@
 msgid "to match this %qs"
 msgstr ""
 
-#: c/c-parser.c:1216 cp/parser.c:28484
+#: c/c-parser.c:1216 cp/parser.c:28481
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr ""
@@ -35961,7 +36004,7 @@
 msgstr "невядомая назва рэгістра: %s"
 
 #: c/c-parser.c:1848 c/c-parser.c:11129 c/c-parser.c:16147 c/c-parser.c:16585
-#: c/c-parser.c:17061 cp/parser.c:36007 cp/parser.c:38993
+#: c/c-parser.c:17061 cp/parser.c:36004 cp/parser.c:38990
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "expected declaration specifiers"
@@ -35978,7 +36021,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr ""
 
-#: c/c-parser.c:1906 cp/parser.c:30161 cp/parser.c:30235
+#: c/c-parser.c:1906 cp/parser.c:30158 cp/parser.c:30232
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "\"%s\" атрыбут ігнарыруецца"
@@ -36033,7 +36076,7 @@
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr ""
 
-#: c/c-parser.c:2220 cp/parser.c:13002 cp/parser.c:13159
+#: c/c-parser.c:2220 cp/parser.c:12999 cp/parser.c:13156
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr ""
@@ -36063,7 +36106,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C89 не падтрымлівае комлексныя тыпы"
 
-#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38634
+#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38631
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr ""
@@ -36129,13 +36172,13 @@
 #: c/c-parser.c:10745 c/c-parser.c:10798 c/c-parser.c:10814 c/c-parser.c:10860
 #: c/c-parser.c:11496 c/c-parser.c:11537 c/c-parser.c:13445 c/c-parser.c:13681
 #: c/c-parser.c:15544 c/c-parser.c:18218 c/gimple-parser.c:1058
-#: c/gimple-parser.c:1096 cp/parser.c:28487 cp/parser.c:31013
-#: cp/parser.c:31043 cp/parser.c:31113 cp/parser.c:33230 cp/parser.c:38350
+#: c/gimple-parser.c:1096 cp/parser.c:28484 cp/parser.c:31010
+#: cp/parser.c:31040 cp/parser.c:31110 cp/parser.c:33227 cp/parser.c:38347
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr ""
 
-#: c/c-parser.c:2995 cp/parser.c:18384
+#: c/c-parser.c:2995 cp/parser.c:18381
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr ""
@@ -36307,13 +36350,13 @@
 msgid "expected statement"
 msgstr ""
 
-#: c/c-parser.c:5639 cp/parser.c:12516
+#: c/c-parser.c:5639 cp/parser.c:12513
 #, fuzzy, gcc-internal-format
 #| msgid "empty body in an else-statement"
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "пустое цела ў else-выражэнні"
 
-#: c/c-parser.c:5681 cp/parser.c:12519
+#: c/c-parser.c:5681 cp/parser.c:12516
 #, fuzzy, gcc-internal-format
 #| msgid "empty body in an else-statement"
 msgid "suggest braces around empty body in an %<else%> statement"
@@ -36657,7 +36700,7 @@
 msgid "%<__builtin_complex%> operands of different types"
 msgstr ""
 
-#: c/c-parser.c:8891 cp/parser.c:6918
+#: c/c-parser.c:8891 cp/parser.c:6921
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for `%s' attribute"
 msgid "wrong number of arguments to %<__builtin_shuffle%>"
@@ -36719,77 +36762,77 @@
 msgid "no type or storage class may be specified here,"
 msgstr ""
 
-#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31073
+#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31070
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr ""
 
-#: c/c-parser.c:10682 cp/parser.c:31033
+#: c/c-parser.c:10682 cp/parser.c:31030
 #, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr ""
 
-#: c/c-parser.c:10685 cp/parser.c:31036
+#: c/c-parser.c:10685 cp/parser.c:31033
 #, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr ""
 
-#: c/c-parser.c:10699 cp/parser.c:31051
+#: c/c-parser.c:10699 cp/parser.c:31048
 #, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr ""
 
-#: c/c-parser.c:10704 cp/parser.c:31057
+#: c/c-parser.c:10704 cp/parser.c:31054
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.c:10711 cp/parser.c:31065
+#: c/c-parser.c:10711 cp/parser.c:31062
 #, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr ""
 
-#: c/c-parser.c:10905 cp/parser.c:38674
+#: c/c-parser.c:10905 cp/parser.c:38671
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
 #: c/c-parser.c:10949 c/c-parser.c:16582 c/c-parser.c:16840 c/c-parser.c:16899
-#: c/c-parser.c:16983 cp/parser.c:36004 cp/parser.c:36298 cp/parser.c:36386
-#: cp/parser.c:36457 cp/parser.c:38721 cp/parser.c:38736 cp/parser.c:38752
-#: cp/parser.c:38768 cp/parser.c:38784 cp/parser.c:38811 cp/parser.c:38824
-#: cp/parser.c:38847 cp/parser.c:38860
+#: c/c-parser.c:16983 cp/parser.c:36001 cp/parser.c:36295 cp/parser.c:36383
+#: cp/parser.c:36454 cp/parser.c:38718 cp/parser.c:38733 cp/parser.c:38749
+#: cp/parser.c:38765 cp/parser.c:38781 cp/parser.c:38808 cp/parser.c:38821
+#: cp/parser.c:38844 cp/parser.c:38857
 #, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:10972 cp/parser.c:38837
+#: c/c-parser.c:10972 cp/parser.c:38834
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr ""
 
-#: c/c-parser.c:11050 cp/parser.c:38918
+#: c/c-parser.c:11050 cp/parser.c:38915
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr ""
 
-#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38947 cp/parser.c:38980
+#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38944 cp/parser.c:38977
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr ""
 
-#: c/c-parser.c:11111 cp/parser.c:38711
+#: c/c-parser.c:11111 cp/parser.c:38708
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr ""
 
-#: c/c-parser.c:11421 cp/parser.c:31457
+#: c/c-parser.c:11421 cp/parser.c:31454
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %qs clauses"
 msgstr "вельмі шмат уваходзячых файлаў"
 
-#: c/c-parser.c:11443 cp/parser.c:31994
+#: c/c-parser.c:11443 cp/parser.c:31991
 #, gcc-internal-format
 msgid "expected integer expression before ')'"
 msgstr ""
@@ -36804,54 +36847,54 @@
 msgid "%qD is not a variable"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: c/c-parser.c:11746 cp/semantics.c:6808
+#: c/c-parser.c:11746 cp/semantics.c:6811
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "\"%s\" звычайна функцыя"
 
-#: c/c-parser.c:11788 cp/parser.c:32073
+#: c/c-parser.c:11788 cp/parser.c:32070
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:11865 cp/parser.c:32137
+#: c/c-parser.c:11865 cp/parser.c:32134
 #, gcc-internal-format
 msgid "expected %<none%> or %<present%>"
 msgstr ""
 
-#: c/c-parser.c:11867 cp/parser.c:32139
+#: c/c-parser.c:11867 cp/parser.c:32136
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr ""
 
-#: c/c-parser.c:11968 cp/parser.c:32242
+#: c/c-parser.c:11968 cp/parser.c:32239
 #, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr ""
 
-#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32260
-#: cp/parser.c:36290 cp/parser.c:36378
+#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32257
+#: cp/parser.c:36287 cp/parser.c:36375
 #, gcc-internal-format
 msgid "expected %<data%>"
 msgstr ""
 
-#: c/c-parser.c:12035 cp/parser.c:32313
+#: c/c-parser.c:12035 cp/parser.c:32310
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:12042 cp/parser.c:32320
+#: c/c-parser.c:12042 cp/parser.c:32317
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %<if%> clauses"
 msgstr "вельмі шмат уваходзячых файлаў"
 
-#: c/c-parser.c:12044 cp/parser.c:32322
+#: c/c-parser.c:12044 cp/parser.c:32319
 #, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr ""
 
-#: c/c-parser.c:12050 cp/parser.c:32328
+#: c/c-parser.c:12050 cp/parser.c:32325
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -36873,84 +36916,84 @@
 msgid "%<num_tasks%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:12229 cp/semantics.c:6992
+#: c/c-parser.c:12229 cp/semantics.c:6995
 #, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:12276 cp/semantics.c:7021
+#: c/c-parser.c:12276 cp/semantics.c:7024
 #, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr ""
 
-#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32545 cp/parser.c:32552
+#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32542 cp/parser.c:32549
 #, gcc-internal-format
 msgid "expected %<tofrom%>"
 msgstr ""
 
-#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32561 cp/parser.c:32568
+#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32558 cp/parser.c:32565
 #, gcc-internal-format
 msgid "expected %<scalar%>"
 msgstr ""
 
-#: c/c-parser.c:12425 cp/semantics.c:6299
+#: c/c-parser.c:12425 cp/semantics.c:6302
 #, gcc-internal-format
 msgid "%qs expression must be integral"
 msgstr ""
 
-#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6331
+#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6334
 #, gcc-internal-format
 msgid "%qs value must be positive"
 msgstr ""
 
-#: c/c-parser.c:12499 cp/parser.c:31853
+#: c/c-parser.c:12499 cp/parser.c:31850
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function"
 msgid "too many %<static%> arguments"
 msgstr "вельмі шмат аргументаў у функцыі"
 
-#: c/c-parser.c:12533 cp/parser.c:31886
+#: c/c-parser.c:12533 cp/parser.c:31883
 #, fuzzy, gcc-internal-format
 #| msgid "no arguments"
 msgid "unexpected argument"
 msgstr "няма аргументаў"
 
-#: c/c-parser.c:12699 cp/semantics.c:7120
+#: c/c-parser.c:12699 cp/semantics.c:7123
 #, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr ""
 
-#: c/c-parser.c:12765 cp/parser.c:32626
+#: c/c-parser.c:12765 cp/parser.c:32623
 #, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37643
+#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37640
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr ""
 
-#: c/c-parser.c:12967 cp/parser.c:32840
+#: c/c-parser.c:12967 cp/parser.c:32837
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr ""
 
-#: c/c-parser.c:13021 cp/parser.c:32856
+#: c/c-parser.c:13021 cp/parser.c:32853
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:13025 cp/parser.c:32859
+#: c/c-parser.c:13025 cp/parser.c:32856
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:13037 cp/semantics.c:6389
+#: c/c-parser.c:13037 cp/semantics.c:6392
 #, gcc-internal-format
 msgid "chunk size value must be positive"
 msgstr ""
 
-#: c/c-parser.c:13060 cp/parser.c:32879
+#: c/c-parser.c:13060 cp/parser.c:32876
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%-code"
 msgid "invalid schedule kind"
@@ -36961,12 +37004,12 @@
 msgid "%<num_teams%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:13226 cp/semantics.c:6479
+#: c/c-parser.c:13226 cp/semantics.c:6482
 #, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:13271 cp/semantics.c:6589
+#: c/c-parser.c:13271 cp/semantics.c:6592
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr ""
@@ -36986,19 +37029,19 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:13584 cp/parser.c:33374 cp/parser.c:33599
+#: c/c-parser.c:13584 cp/parser.c:33371 cp/parser.c:33596
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%d operand"
 msgid "invalid depend kind"
 msgstr "нерэчаісны %%d аперанд"
 
-#: c/c-parser.c:13669 cp/parser.c:33447
+#: c/c-parser.c:13669 cp/parser.c:33444
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mask"
 msgid "invalid map kind"
 msgstr "нерэчаісная маска"
 
-#: c/c-parser.c:13767 cp/parser.c:33546
+#: c/c-parser.c:13767 cp/parser.c:33543
 #, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr ""
@@ -37008,68 +37051,68 @@
 msgid "invalid proc_bind kind"
 msgstr "Нерэчаісны выбар %s"
 
-#: c/c-parser.c:14059 cp/parser.c:33825
+#: c/c-parser.c:14059 cp/parser.c:33822
 #, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr ""
 
-#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33836 cp/parser.c:34143
+#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33833 cp/parser.c:34140
 #, fuzzy, gcc-internal-format
 #| msgid "complex invalid for `%s'"
 msgid "%qs is not valid for %qs"
 msgstr "complex нерэчаісны для \"%s\""
 
-#: c/c-parser.c:14214 cp/parser.c:34010
+#: c/c-parser.c:14214 cp/parser.c:34007
 #, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr ""
 
-#: c/c-parser.c:14334 cp/parser.c:34132
+#: c/c-parser.c:14334 cp/parser.c:34129
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr ""
 
-#: c/c-parser.c:14472 cp/parser.c:36803
+#: c/c-parser.c:14472 cp/parser.c:36800
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14482 cp/parser.c:36813
+#: c/c-parser.c:14482 cp/parser.c:36810
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14502 cp/parser.c:36833
+#: c/c-parser.c:14502 cp/parser.c:36830
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr ""
 
-#: c/c-parser.c:14513 cp/parser.c:36844
+#: c/c-parser.c:14513 cp/parser.c:36841
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr ""
 
-#: c/c-parser.c:14520 cp/parser.c:36851
+#: c/c-parser.c:14520 cp/parser.c:36848
 #, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14528 cp/parser.c:36859
+#: c/c-parser.c:14528 cp/parser.c:36856
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14540 cp/parser.c:36871
+#: c/c-parser.c:14540 cp/parser.c:36868
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14632 cp/parser.c:36957
+#: c/c-parser.c:14632 cp/parser.c:36954
 #, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr ""
 
-#: c/c-parser.c:14648 cp/parser.c:36974
+#: c/c-parser.c:14648 cp/parser.c:36971
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr ""
@@ -37084,7 +37127,7 @@
 msgid "expected function name"
 msgstr ""
 
-#: c/c-parser.c:14893 cp/parser.c:38064
+#: c/c-parser.c:14893 cp/parser.c:38061
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function,"
 msgid "%qD does not refer to a function"
@@ -37095,42 +37138,42 @@
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14953 cp/parser.c:38118 cp/parser.c:38160
+#: c/c-parser.c:14953 cp/parser.c:38115 cp/parser.c:38157
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14970 cp/parser.c:38174
+#: c/c-parser.c:14970 cp/parser.c:38171
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> already applied to %qD"
 msgstr ""
 
-#: c/c-parser.c:14979 cp/parser.c:38183
+#: c/c-parser.c:14979 cp/parser.c:38180
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr ""
 
-#: c/c-parser.c:14980 cp/parser.c:38184
+#: c/c-parser.c:14980 cp/parser.c:38181
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr ""
 
-#: c/c-parser.c:15023 cp/parser.c:37152
+#: c/c-parser.c:15023 cp/parser.c:37149
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
 
-#: c/c-parser.c:15435 cp/parser.c:34511 cp/parser.c:34537
+#: c/c-parser.c:15435 cp/parser.c:34508 cp/parser.c:34534
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr ""
 
-#: c/c-parser.c:15439 cp/parser.c:34568 cp/parser.c:34584
+#: c/c-parser.c:15439 cp/parser.c:34565 cp/parser.c:34581
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr ""
 
-#: c/c-parser.c:15488 cp/semantics.c:8401 cp/semantics.c:8411
+#: c/c-parser.c:15488 cp/semantics.c:8404 cp/semantics.c:8414
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
@@ -37140,22 +37183,22 @@
 msgid "expected %<(%> or end of line"
 msgstr ""
 
-#: c/c-parser.c:15619 cp/parser.c:35103
+#: c/c-parser.c:15619 cp/parser.c:35100
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:15630 cp/parser.c:35114
+#: c/c-parser.c:15630 cp/parser.c:35111
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:15648 cp/parser.c:35141
+#: c/c-parser.c:15648 cp/parser.c:35138
 #, fuzzy, gcc-internal-format
 msgid "for statement expected"
 msgstr "вельмі шмат аргументаў у функцыі"
 
-#: c/c-parser.c:15718 cp/semantics.c:8066 cp/semantics.c:8153
+#: c/c-parser.c:15718 cp/semantics.c:8069 cp/semantics.c:8156
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr ""
@@ -37165,72 +37208,72 @@
 msgid "not enough perfectly nested loops"
 msgstr ""
 
-#: c/c-parser.c:15862 cp/parser.c:35364
+#: c/c-parser.c:15862 cp/parser.c:35361
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.c:15909 cp/parser.c:35184 cp/parser.c:35226 cp/pt.c:16385
+#: c/c-parser.c:15909 cp/parser.c:35181 cp/parser.c:35223 cp/pt.c:16407
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr ""
 
-#: c/c-parser.c:16000 cp/parser.c:35437
+#: c/c-parser.c:16000 cp/parser.c:35434
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr ""
 
-#: c/c-parser.c:16166 cp/parser.c:35600
+#: c/c-parser.c:16166 cp/parser.c:35597
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:16374 cp/parser.c:35799
+#: c/c-parser.c:16374 cp/parser.c:35796
 #, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr ""
 
-#: c/c-parser.c:16573 cp/parser.c:35995
+#: c/c-parser.c:16573 cp/parser.c:35992
 #, gcc-internal-format
 msgid "expected %<point%>"
 msgstr ""
 
-#: c/c-parser.c:16793 cp/parser.c:36232
+#: c/c-parser.c:16793 cp/parser.c:36229
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16806 cp/parser.c:36245
+#: c/c-parser.c:16806 cp/parser.c:36242
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16853 cp/parser.c:36470
+#: c/c-parser.c:16853 cp/parser.c:36467
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:16925 cp/parser.c:36325
+#: c/c-parser.c:16925 cp/parser.c:36322
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16937 cp/parser.c:36337
+#: c/c-parser.c:16937 cp/parser.c:36334
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17011 cp/parser.c:36414
+#: c/c-parser.c:17011 cp/parser.c:36411
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17024 cp/parser.c:36427
+#: c/c-parser.c:17024 cp/parser.c:36424
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17238 cp/parser.c:36680
+#: c/c-parser.c:17238 cp/parser.c:36677
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -37250,32 +37293,32 @@
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17395 cp/parser.c:37273
+#: c/c-parser.c:17395 cp/parser.c:37270
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17474 cp/parser.c:37343
+#: c/c-parser.c:17474 cp/parser.c:37340
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> with clauses in between %<#pragma omp declare target%> without clauses and %<#pragma omp end declare target%>"
 msgstr ""
 
-#: c/c-parser.c:17493 cp/parser.c:37362
+#: c/c-parser.c:17493 cp/parser.c:37359
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17534 cp/parser.c:37409
+#: c/c-parser.c:17534 cp/parser.c:37406
 #, gcc-internal-format
 msgid "expected %<target%>"
 msgstr ""
 
-#: c/c-parser.c:17541 cp/parser.c:37416
+#: c/c-parser.c:17541 cp/parser.c:37413
 #, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr ""
 
-#: c/c-parser.c:17547 cp/parser.c:37423
+#: c/c-parser.c:17547 cp/parser.c:37420
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr ""
@@ -37330,47 +37373,47 @@
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:17947 cp/parser.c:37868
+#: c/c-parser.c:17947 cp/parser.c:37865
 #, gcc-internal-format
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr ""
 
-#: c/c-parser.c:18162 cp/semantics.c:7531
+#: c/c-parser.c:18162 cp/semantics.c:7534
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr ""
 
-#: c/c-parser.c:18164 cp/semantics.c:7533
+#: c/c-parser.c:18164 cp/semantics.c:7536
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr ""
 
-#: c/c-parser.c:18168 cp/semantics.c:7535
+#: c/c-parser.c:18168 cp/semantics.c:7538
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: c/c-parser.c:18368 cp/parser.c:38565
+#: c/c-parser.c:18368 cp/parser.c:38562
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:18374 cp/parser.c:38571
+#: c/c-parser.c:18374 cp/parser.c:38568
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
 
-#: c/c-parser.c:18383 cp/parser.c:38580
+#: c/c-parser.c:18383 cp/parser.c:38577
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.c:18385 cp/parser.c:38583
+#: c/c-parser.c:18385 cp/parser.c:38580
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.c:18391 cp/parser.c:38589
+#: c/c-parser.c:18391 cp/parser.c:38586
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
@@ -37386,7 +37429,7 @@
 msgid "%qD has an incomplete type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: c/c-typeck.c:237 c/c-typeck.c:9994 c/c-typeck.c:10036 cp/call.c:4147
+#: c/c-typeck.c:237 c/c-typeck.c:9999 c/c-typeck.c:10041 cp/call.c:4147
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr ""
@@ -37462,12 +37505,12 @@
 msgid "converting an array compound literal to a pointer is ill-formed in C++"
 msgstr ""
 
-#: c/c-typeck.c:2417 c/c-typeck.c:8641
+#: c/c-typeck.c:2417 c/c-typeck.c:8646
 #, gcc-internal-format
 msgid "%qT has no member named %qE; did you mean %qE?"
 msgstr ""
 
-#: c/c-typeck.c:2421 c/c-typeck.c:8645
+#: c/c-typeck.c:2421 c/c-typeck.c:8650
 #, gcc-internal-format
 msgid "%qT has no member named %qE"
 msgstr ""
@@ -37666,460 +37709,460 @@
 msgid "pointer to a function used in subtraction"
 msgstr ""
 
-#: c/c-typeck.c:3847
+#: c/c-typeck.c:3852
 #, gcc-internal-format
 msgid "arithmetic on pointer to an incomplete type"
 msgstr ""
 
-#: c/c-typeck.c:3852 cp/typeck.c:5562
+#: c/c-typeck.c:3857 cp/typeck.c:5562
 #, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr ""
 
-#: c/c-typeck.c:4283
+#: c/c-typeck.c:4288
 #, gcc-internal-format
 msgid "%<~%> on a boolean expression"
 msgstr ""
 
-#: c/c-typeck.c:4287
+#: c/c-typeck.c:4292
 #, gcc-internal-format
 msgid "did you mean to use logical not?"
 msgstr ""
 
-#: c/c-typeck.c:4296
+#: c/c-typeck.c:4301
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C89 does not support complex types"
 msgid "ISO C does not support %<~%> for complex conjugation"
 msgstr "ISO C89 не падтрымлівае комлексныя тыпы"
 
-#: c/c-typeck.c:4335
+#: c/c-typeck.c:4340
 #, gcc-internal-format
 msgid "wrong type argument to unary exclamation mark"
 msgstr ""
 
-#: c/c-typeck.c:4393
+#: c/c-typeck.c:4398
 #, gcc-internal-format
 msgid "increment of enumeration value is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:4396
+#: c/c-typeck.c:4401
 #, gcc-internal-format
 msgid "decrement of enumeration value is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:4403
+#: c/c-typeck.c:4408
 #, gcc-internal-format
 msgid "increment of a boolean expression"
 msgstr ""
 
-#: c/c-typeck.c:4406
+#: c/c-typeck.c:4411
 #, gcc-internal-format
 msgid "decrement of a boolean expression"
 msgstr ""
 
-#: c/c-typeck.c:4422
+#: c/c-typeck.c:4427
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support `++' and `--' on complex types"
 msgid "ISO C does not support %<++%> and %<--%> on complex types"
 msgstr "ISO C не падтрымлівае \"++\" і \"--\" для тыпу complex"
 
-#: c/c-typeck.c:4447 c/c-typeck.c:4481
+#: c/c-typeck.c:4452 c/c-typeck.c:4486
 #, fuzzy, gcc-internal-format
 msgid "wrong type argument to increment"
 msgstr "не хапае аргументаў у функцыі"
 
-#: c/c-typeck.c:4449 c/c-typeck.c:4484
+#: c/c-typeck.c:4454 c/c-typeck.c:4489
 #, gcc-internal-format
 msgid "wrong type argument to decrement"
 msgstr ""
 
-#: c/c-typeck.c:4469
+#: c/c-typeck.c:4474
 #, fuzzy, gcc-internal-format
 msgid "increment of pointer to an incomplete type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: c/c-typeck.c:4473
+#: c/c-typeck.c:4478
 #, fuzzy, gcc-internal-format
 msgid "decrement of pointer to an incomplete type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: c/c-typeck.c:4577
+#: c/c-typeck.c:4582
 #, gcc-internal-format
 msgid "taking address of expression of type %<void%>"
 msgstr ""
 
-#: c/c-typeck.c:4636
+#: c/c-typeck.c:4641
 #, fuzzy, gcc-internal-format
 msgid "cannot take address of bit-field %qD"
 msgstr "не магу атрымаць адрас бітавага поля \"%s\""
 
-#: c/c-typeck.c:4649
+#: c/c-typeck.c:4654
 #, fuzzy, gcc-internal-format
 msgid "cannot take address of scalar with reverse storage order"
 msgstr "не магу атрымаць адрас бітавага поля \"%s\""
 
-#: c/c-typeck.c:4657
+#: c/c-typeck.c:4662
 #, gcc-internal-format
 msgid "address of array with reverse scalar storage order requested"
 msgstr ""
 
-#: c/c-typeck.c:4838
+#: c/c-typeck.c:4843
 #, gcc-internal-format
 msgid "global register variable %qD used in nested function"
 msgstr ""
 
-#: c/c-typeck.c:4841
+#: c/c-typeck.c:4846
 #, gcc-internal-format
 msgid "register variable %qD used in nested function"
 msgstr ""
 
-#: c/c-typeck.c:4846
+#: c/c-typeck.c:4851
 #, gcc-internal-format
 msgid "address of global register variable %qD requested"
 msgstr ""
 
-#: c/c-typeck.c:4848
+#: c/c-typeck.c:4853
 #, gcc-internal-format
 msgid "address of register variable %qD requested"
 msgstr ""
 
-#: c/c-typeck.c:4951
+#: c/c-typeck.c:4956
 #, gcc-internal-format
 msgid "non-lvalue array in conditional expression"
 msgstr ""
 
-#: c/c-typeck.c:5033
+#: c/c-typeck.c:5038
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other result of conditional"
 msgstr ""
 
-#: c/c-typeck.c:5092 c/c-typeck.c:5098
+#: c/c-typeck.c:5097 c/c-typeck.c:5103
 #, gcc-internal-format
 msgid "operand of ?: changes signedness from %qT to %qT due to unsignedness of other operand"
 msgstr ""
 
-#: c/c-typeck.c:5115
+#: c/c-typeck.c:5120
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr with only one void side"
 msgstr ""
 
-#: c/c-typeck.c:5132
+#: c/c-typeck.c:5137
 #, gcc-internal-format
 msgid "pointers to disjoint address spaces used in conditional expression"
 msgstr ""
 
-#: c/c-typeck.c:5143 c/c-typeck.c:5160
+#: c/c-typeck.c:5148 c/c-typeck.c:5165
 #, gcc-internal-format
 msgid "pointer to array loses qualifier in conditional expression"
 msgstr ""
 
-#: c/c-typeck.c:5148 c/c-typeck.c:5165
+#: c/c-typeck.c:5153 c/c-typeck.c:5170
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr between %<void *%> and function pointer"
 msgstr ""
 
-#: c/c-typeck.c:5178
+#: c/c-typeck.c:5183
 #, gcc-internal-format
 msgid "pointer type mismatch in conditional expression"
 msgstr ""
 
-#: c/c-typeck.c:5187 c/c-typeck.c:5198
+#: c/c-typeck.c:5192 c/c-typeck.c:5203
 #, gcc-internal-format
 msgid "pointer/integer type mismatch in conditional expression"
 msgstr ""
 
-#: c/c-typeck.c:5336
+#: c/c-typeck.c:5341
 #, gcc-internal-format
 msgid "left-hand operand of comma expression has no effect"
 msgstr ""
 
-#: c/c-typeck.c:5354 c/c-typeck.c:10636
+#: c/c-typeck.c:5359 c/c-typeck.c:10641
 #, gcc-internal-format
 msgid "right-hand operand of comma expression has no effect"
 msgstr ""
 
-#: c/c-typeck.c:5423
+#: c/c-typeck.c:5428
 msgid "cast adds %q#v qualifier to function type"
 msgstr ""
 
-#: c/c-typeck.c:5429
+#: c/c-typeck.c:5434
 msgid "cast discards %qv qualifier from pointer target type"
 msgstr ""
 
-#: c/c-typeck.c:5464
+#: c/c-typeck.c:5469
 #, gcc-internal-format
 msgid "to be safe all intermediate pointers in cast from %qT to %qT must be %<const%> qualified"
 msgstr ""
 
-#: c/c-typeck.c:5554
+#: c/c-typeck.c:5559
 #, gcc-internal-format
 msgid "cast specifies array type"
 msgstr ""
 
-#: c/c-typeck.c:5560
+#: c/c-typeck.c:5565
 #, gcc-internal-format
 msgid "cast specifies function type"
 msgstr ""
 
-#: c/c-typeck.c:5575
+#: c/c-typeck.c:5580
 #, gcc-internal-format
 msgid "ISO C forbids casting nonscalar to the same type"
 msgstr ""
 
-#: c/c-typeck.c:5595
+#: c/c-typeck.c:5600
 #, gcc-internal-format
 msgid "ISO C forbids casts to union type"
 msgstr ""
 
-#: c/c-typeck.c:5605
+#: c/c-typeck.c:5610
 #, gcc-internal-format
 msgid "cast to union type from type not present in union"
 msgstr ""
 
-#: c/c-typeck.c:5640
+#: c/c-typeck.c:5645
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint generic address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5645
+#: c/c-typeck.c:5650
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to generic address space pointer from disjoint %s address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5650
+#: c/c-typeck.c:5655
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint %s address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5670
+#: c/c-typeck.c:5675
 #, gcc-internal-format
 msgid "cast increases required alignment of target type"
 msgstr ""
 
-#: c/c-typeck.c:5681
+#: c/c-typeck.c:5686
 #, gcc-internal-format
 msgid "cast from pointer to integer of different size"
 msgstr ""
 
-#: c/c-typeck.c:5686
+#: c/c-typeck.c:5691
 #, gcc-internal-format
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr ""
 
-#: c/c-typeck.c:5695 cp/typeck.c:7811
+#: c/c-typeck.c:5700 cp/typeck.c:7811
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr ""
 
-#: c/c-typeck.c:5709
+#: c/c-typeck.c:5714
 #, gcc-internal-format
 msgid "ISO C forbids conversion of function pointer to object pointer type"
 msgstr ""
 
-#: c/c-typeck.c:5718
+#: c/c-typeck.c:5723
 #, gcc-internal-format
 msgid "ISO C forbids conversion of object pointer to function pointer type"
 msgstr ""
 
-#: c/c-typeck.c:5728
+#: c/c-typeck.c:5733
 #, gcc-internal-format
 msgid "cast between incompatible function types from %qT to %qT"
 msgstr ""
 
-#: c/c-typeck.c:5815
+#: c/c-typeck.c:5820
 #, gcc-internal-format
 msgid "defining a type in a cast is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:5856
+#: c/c-typeck.c:5861
 #, gcc-internal-format
 msgid "assignment to expression with array type"
 msgstr ""
 
-#: c/c-typeck.c:5982
+#: c/c-typeck.c:5987
 #, gcc-internal-format
 msgid "enum conversion in assignment is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:6180 c/c-typeck.c:6202 c/c-typeck.c:6226
+#: c/c-typeck.c:6185 c/c-typeck.c:6207 c/c-typeck.c:6231
 #, fuzzy, gcc-internal-format
 #| msgid "initialization"
 msgid "(near initialization for %qs)"
 msgstr "ініцыялізацыя"
 
-#: c/c-typeck.c:6241
+#: c/c-typeck.c:6246
 #, gcc-internal-format
 msgid "array initialized from parenthesized string constant"
 msgstr ""
 
-#: c/c-typeck.c:6284 c/c-typeck.c:6476 c/c-typeck.c:6908
+#: c/c-typeck.c:6289 c/c-typeck.c:6481 c/c-typeck.c:6913
 #, gcc-internal-format
 msgid "expected %qT but argument is of type %qT"
 msgstr ""
 
-#: c/c-typeck.c:6471
+#: c/c-typeck.c:6476
 #, gcc-internal-format
 msgid "enum conversion when passing argument %d of %qE is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:6480
+#: c/c-typeck.c:6485
 #, gcc-internal-format
 msgid "enum conversion from %qT to %qT in assignment is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:6484
+#: c/c-typeck.c:6489
 #, gcc-internal-format
 msgid "enum conversion from %qT to %qT in initialization is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:6489
+#: c/c-typeck.c:6494
 #, gcc-internal-format
 msgid "enum conversion from %qT to %qT in return is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:6523
+#: c/c-typeck.c:6528
 #, gcc-internal-format
 msgid "cannot pass rvalue to reference parameter"
 msgstr ""
 
-#: c/c-typeck.c:6656 c/c-typeck.c:6942
+#: c/c-typeck.c:6661 c/c-typeck.c:6947
 msgid "passing argument %d of %qE makes %q#v qualified function pointer from unqualified"
 msgstr ""
 
-#: c/c-typeck.c:6659 c/c-typeck.c:6945
+#: c/c-typeck.c:6664 c/c-typeck.c:6950
 msgid "assignment makes %q#v qualified function pointer from unqualified"
 msgstr ""
 
-#: c/c-typeck.c:6662 c/c-typeck.c:6947
+#: c/c-typeck.c:6667 c/c-typeck.c:6952
 msgid "initialization makes %q#v qualified function pointer from unqualified"
 msgstr ""
 
-#: c/c-typeck.c:6665 c/c-typeck.c:6949
+#: c/c-typeck.c:6670 c/c-typeck.c:6954
 msgid "return makes %q#v qualified function pointer from unqualified"
 msgstr ""
 
-#: c/c-typeck.c:6673 c/c-typeck.c:6840 c/c-typeck.c:6883
+#: c/c-typeck.c:6678 c/c-typeck.c:6845 c/c-typeck.c:6888
 msgid "passing argument %d of %qE discards %qv qualifier from pointer target type"
 msgstr ""
 
-#: c/c-typeck.c:6675 c/c-typeck.c:6842 c/c-typeck.c:6885
+#: c/c-typeck.c:6680 c/c-typeck.c:6847 c/c-typeck.c:6890
 msgid "assignment discards %qv qualifier from pointer target type"
 msgstr ""
 
-#: c/c-typeck.c:6677 c/c-typeck.c:6844 c/c-typeck.c:6887
+#: c/c-typeck.c:6682 c/c-typeck.c:6849 c/c-typeck.c:6892
 msgid "initialization discards %qv qualifier from pointer target type"
 msgstr ""
 
-#: c/c-typeck.c:6679 c/c-typeck.c:6846 c/c-typeck.c:6889
+#: c/c-typeck.c:6684 c/c-typeck.c:6851 c/c-typeck.c:6894
 msgid "return discards %qv qualifier from pointer target type"
 msgstr ""
 
-#: c/c-typeck.c:6688
+#: c/c-typeck.c:6693
 #, gcc-internal-format
 msgid "ISO C prohibits argument conversion to union type"
 msgstr ""
 
-#: c/c-typeck.c:6750
+#: c/c-typeck.c:6755
 #, gcc-internal-format
 msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgstr ""
 
-#: c/c-typeck.c:6762
+#: c/c-typeck.c:6767
 #, gcc-internal-format
 msgid "passing argument %d of %qE from pointer to non-enclosed address space"
 msgstr ""
 
-#: c/c-typeck.c:6766
+#: c/c-typeck.c:6771
 #, gcc-internal-format
 msgid "assignment from pointer to non-enclosed address space"
 msgstr ""
 
-#: c/c-typeck.c:6770
+#: c/c-typeck.c:6775
 #, gcc-internal-format
 msgid "initialization from pointer to non-enclosed address space"
 msgstr ""
 
-#: c/c-typeck.c:6774
+#: c/c-typeck.c:6779
 #, gcc-internal-format
 msgid "return from pointer to non-enclosed address space"
 msgstr ""
 
-#: c/c-typeck.c:6792
+#: c/c-typeck.c:6797
 #, gcc-internal-format
 msgid "argument %d of %qE might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:6798
+#: c/c-typeck.c:6803
 #, gcc-internal-format
 msgid "assignment left-hand side might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:6803
+#: c/c-typeck.c:6808
 #, gcc-internal-format
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:6808 cp/typeck.c:8891
+#: c/c-typeck.c:6813 cp/typeck.c:8891
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:6857
+#: c/c-typeck.c:6862
 #, gcc-internal-format
 msgid "ISO C forbids passing argument %d of %qE between function pointer and %<void *%>"
 msgstr ""
 
-#: c/c-typeck.c:6860
+#: c/c-typeck.c:6865
 #, gcc-internal-format
 msgid "ISO C forbids assignment between function pointer and %<void *%>"
 msgstr ""
 
-#: c/c-typeck.c:6862
+#: c/c-typeck.c:6867
 #, gcc-internal-format
 msgid "ISO C forbids initialization between function pointer and %<void *%>"
 msgstr ""
 
-#: c/c-typeck.c:6864
+#: c/c-typeck.c:6869
 #, gcc-internal-format
 msgid "ISO C forbids return between function pointer and %<void *%>"
 msgstr ""
 
-#: c/c-typeck.c:6904
+#: c/c-typeck.c:6909
 #, gcc-internal-format
 msgid "pointer targets in passing argument %d of %qE differ in signedness"
 msgstr ""
 
-#: c/c-typeck.c:6913
+#: c/c-typeck.c:6918
 #, gcc-internal-format
 msgid "pointer targets in assignment from %qT to %qT differ in signedness"
 msgstr ""
 
-#: c/c-typeck.c:6918
+#: c/c-typeck.c:6923
 #, gcc-internal-format
 msgid "pointer targets in initialization of %qT from %qT differ in signedness"
 msgstr ""
 
-#: c/c-typeck.c:6923
+#: c/c-typeck.c:6928
 #, gcc-internal-format
 msgid "pointer targets in returning %qT from a function with return type %qT differ in signedness"
 msgstr ""
 
-#: c/c-typeck.c:6961
+#: c/c-typeck.c:6966
 #, gcc-internal-format
 msgid "passing argument %d of %qE from incompatible pointer type"
 msgstr ""
 
-#: c/c-typeck.c:6967
+#: c/c-typeck.c:6972
 #, gcc-internal-format
 msgid "assignment to %qT from incompatible pointer type %qT"
 msgstr ""
 
-#: c/c-typeck.c:6972
+#: c/c-typeck.c:6977
 #, gcc-internal-format
 msgid "initialization of %qT from incompatible pointer type %qT"
 msgstr ""
 
-#: c/c-typeck.c:6977
+#: c/c-typeck.c:6982
 #, gcc-internal-format
 msgid "returning %qT from a function with incompatible return type %qT"
 msgstr ""
@@ -38126,784 +38169,784 @@
 
 #. ??? This should not be an error when inlining calls to
 #. unprototyped functions.
-#: c/c-typeck.c:6991 c/c-typeck.c:7514 cp/typeck.c:2063
+#: c/c-typeck.c:6996 c/c-typeck.c:7519 cp/typeck.c:2063
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr ""
 
-#: c/c-typeck.c:7004
+#: c/c-typeck.c:7009
 #, gcc-internal-format
 msgid "passing argument %d of %qE makes pointer from integer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7010
+#: c/c-typeck.c:7015
 #, gcc-internal-format
 msgid "assignment to %qT from %qT makes pointer from integer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7015
+#: c/c-typeck.c:7020
 #, gcc-internal-format
 msgid "initialization of %qT from %qT makes pointer from integer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7019
+#: c/c-typeck.c:7024
 #, gcc-internal-format
 msgid "returning %qT from a function with return type %qT makes pointer from integer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7035
+#: c/c-typeck.c:7040
 #, gcc-internal-format
 msgid "passing argument %d of %qE makes integer from pointer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7041
+#: c/c-typeck.c:7046
 #, gcc-internal-format
 msgid "assignment to %qT from %qT makes integer from pointer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7046
+#: c/c-typeck.c:7051
 #, gcc-internal-format
 msgid "initialization of %qT from %qT makes integer from pointer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7050
+#: c/c-typeck.c:7055
 #, gcc-internal-format
 msgid "returning %qT from a function with return type %qT makes integer from pointer without a cast"
 msgstr ""
 
-#: c/c-typeck.c:7073
+#: c/c-typeck.c:7078
 #, gcc-internal-format
 msgid "incompatible type for argument %d of %qE"
 msgstr ""
 
-#: c/c-typeck.c:7078
+#: c/c-typeck.c:7083
 #, gcc-internal-format
 msgid "incompatible types when assigning to type %qT from type %qT"
 msgstr ""
 
-#: c/c-typeck.c:7083
+#: c/c-typeck.c:7088
 #, gcc-internal-format
 msgid "incompatible types when initializing type %qT using type %qT"
 msgstr ""
 
-#: c/c-typeck.c:7088
+#: c/c-typeck.c:7093
 #, gcc-internal-format
 msgid "incompatible types when returning type %qT but %qT was expected"
 msgstr ""
 
-#: c/c-typeck.c:7152
+#: c/c-typeck.c:7157
 #, gcc-internal-format
 msgid "traditional C rejects automatic aggregate initialization"
 msgstr ""
 
-#: c/c-typeck.c:7388 c/c-typeck.c:8284 cp/typeck2.c:1045
+#: c/c-typeck.c:7393 c/c-typeck.c:8289 cp/typeck2.c:1045
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr ""
 
-#: c/c-typeck.c:7398 cp/typeck2.c:1059
+#: c/c-typeck.c:7403 cp/typeck2.c:1059
 #, gcc-internal-format
 msgid "char-array initialized from wide string"
 msgstr ""
 
-#: c/c-typeck.c:7407
+#: c/c-typeck.c:7412
 #, gcc-internal-format
 msgid "wide character array initialized from non-wide string"
 msgstr ""
 
-#: c/c-typeck.c:7413
+#: c/c-typeck.c:7418
 #, gcc-internal-format
 msgid "wide character array initialized from incompatible wide string"
 msgstr ""
 
-#: c/c-typeck.c:7446
+#: c/c-typeck.c:7451
 #, gcc-internal-format
 msgid "array of inappropriate type initialized from string constant"
 msgstr ""
 
-#: c/c-typeck.c:7533 c/c-typeck.c:7557 c/c-typeck.c:7560 c/c-typeck.c:7568
-#: c/c-typeck.c:7608 c/c-typeck.c:9131 c/c-typeck.c:9181
+#: c/c-typeck.c:7538 c/c-typeck.c:7562 c/c-typeck.c:7565 c/c-typeck.c:7573
+#: c/c-typeck.c:7613 c/c-typeck.c:9136 c/c-typeck.c:9186
 #, gcc-internal-format
 msgid "initializer element is not constant"
 msgstr ""
 
-#: c/c-typeck.c:7542
+#: c/c-typeck.c:7547
 #, gcc-internal-format
 msgid "array initialized from non-constant array expression"
 msgstr ""
 
-#: c/c-typeck.c:7573 c/c-typeck.c:7621 c/c-typeck.c:9191
+#: c/c-typeck.c:7578 c/c-typeck.c:7626 c/c-typeck.c:9196
 #, fuzzy, gcc-internal-format
 msgid "initializer element is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: c/c-typeck.c:7615 c/c-typeck.c:9186
+#: c/c-typeck.c:7620 c/c-typeck.c:9191
 #, gcc-internal-format
 msgid "initializer element is not computable at load time"
 msgstr ""
 
-#: c/c-typeck.c:7634
+#: c/c-typeck.c:7639
 #, gcc-internal-format
 msgid "invalid initializer"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: c/c-typeck.c:7912 cp/decl.c:6396
+#: c/c-typeck.c:7917 cp/decl.c:6396
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr ""
 
-#: c/c-typeck.c:8132
+#: c/c-typeck.c:8137
 #, gcc-internal-format
 msgid "extra brace group at end of initializer"
 msgstr ""
 
-#: c/c-typeck.c:8215
+#: c/c-typeck.c:8220
 #, gcc-internal-format
 msgid "braces around scalar initializer"
 msgstr ""
 
-#: c/c-typeck.c:8281 c/c-typeck.c:9615 cp/typeck2.c:1084 cp/typeck2.c:1297
+#: c/c-typeck.c:8286 c/c-typeck.c:9620 cp/typeck2.c:1084 cp/typeck2.c:1297
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr ""
 
-#: c/c-typeck.c:8318
+#: c/c-typeck.c:8323
 #, gcc-internal-format
 msgid "missing braces around initializer"
 msgstr ""
 
-#: c/c-typeck.c:8341
+#: c/c-typeck.c:8346
 #, fuzzy, gcc-internal-format
 msgid "missing initializer for field %qD of %qT"
 msgstr "прапушчан ініцыялізатар"
 
-#: c/c-typeck.c:8365
+#: c/c-typeck.c:8370
 #, gcc-internal-format
 msgid "empty scalar initializer"
 msgstr ""
 
-#: c/c-typeck.c:8370
+#: c/c-typeck.c:8375
 #, gcc-internal-format
 msgid "extra elements in scalar initializer"
 msgstr ""
 
-#: c/c-typeck.c:8483 c/c-typeck.c:8565
+#: c/c-typeck.c:8488 c/c-typeck.c:8570
 #, gcc-internal-format
 msgid "array index in non-array initializer"
 msgstr ""
 
-#: c/c-typeck.c:8488 c/c-typeck.c:8627
+#: c/c-typeck.c:8493 c/c-typeck.c:8632
 #, gcc-internal-format
 msgid "field name not in record or union initializer"
 msgstr ""
 
-#: c/c-typeck.c:8538
+#: c/c-typeck.c:8543
 #, fuzzy, gcc-internal-format
 msgid "array index in initializer not of integer type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: c/c-typeck.c:8547 c/c-typeck.c:8556
+#: c/c-typeck.c:8552 c/c-typeck.c:8561
 #, fuzzy, gcc-internal-format
 msgid "array index in initializer is not an integer constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: c/c-typeck.c:8561 c/c-typeck.c:8563
+#: c/c-typeck.c:8566 c/c-typeck.c:8568
 #, gcc-internal-format
 msgid "nonconstant array index in initializer"
 msgstr ""
 
-#: c/c-typeck.c:8567 c/c-typeck.c:8570
+#: c/c-typeck.c:8572 c/c-typeck.c:8575
 #, gcc-internal-format
 msgid "array index in initializer exceeds array bounds"
 msgstr ""
 
-#: c/c-typeck.c:8589
+#: c/c-typeck.c:8594
 #, gcc-internal-format
 msgid "empty index range in initializer"
 msgstr ""
 
-#: c/c-typeck.c:8598
+#: c/c-typeck.c:8603
 #, gcc-internal-format
 msgid "array index range in initializer exceeds array bounds"
 msgstr ""
 
-#: c/c-typeck.c:8700 c/c-typeck.c:8730 c/c-typeck.c:9274
+#: c/c-typeck.c:8705 c/c-typeck.c:8735 c/c-typeck.c:9279
 #, gcc-internal-format
 msgid "initialized field with side-effects overwritten"
 msgstr ""
 
-#: c/c-typeck.c:8704 c/c-typeck.c:8734 c/c-typeck.c:9277
+#: c/c-typeck.c:8709 c/c-typeck.c:8739 c/c-typeck.c:9282
 #, gcc-internal-format
 msgid "initialized field overwritten"
 msgstr ""
 
-#: c/c-typeck.c:9208
+#: c/c-typeck.c:9213
 #, gcc-internal-format
 msgid "enum conversion in initialization is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:9496
+#: c/c-typeck.c:9501
 #, gcc-internal-format
 msgid "excess elements in char array initializer"
 msgstr ""
 
-#: c/c-typeck.c:9503 c/c-typeck.c:9574
+#: c/c-typeck.c:9508 c/c-typeck.c:9579
 #, gcc-internal-format
 msgid "excess elements in struct initializer"
 msgstr ""
 
-#: c/c-typeck.c:9518
+#: c/c-typeck.c:9523
 #, gcc-internal-format
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr ""
 
-#: c/c-typeck.c:9589
+#: c/c-typeck.c:9594
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr ""
 
-#: c/c-typeck.c:9687
+#: c/c-typeck.c:9692
 #, gcc-internal-format
 msgid "excess elements in union initializer"
 msgstr ""
 
-#: c/c-typeck.c:9709
+#: c/c-typeck.c:9714
 #, gcc-internal-format
 msgid "traditional C rejects initialization of unions"
 msgstr ""
 
-#: c/c-typeck.c:9777
+#: c/c-typeck.c:9782
 #, gcc-internal-format
 msgid "excess elements in array initializer"
 msgstr ""
 
-#: c/c-typeck.c:9811
+#: c/c-typeck.c:9816
 #, gcc-internal-format
 msgid "excess elements in vector initializer"
 msgstr ""
 
-#: c/c-typeck.c:9843
+#: c/c-typeck.c:9848
 #, gcc-internal-format
 msgid "excess elements in scalar initializer"
 msgstr ""
 
-#: c/c-typeck.c:10086
+#: c/c-typeck.c:10091
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids `goto *expr;'"
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C не падтрымлівае \"goto *expr;\""
 
-#: c/c-typeck.c:10113 c/gimple-parser.c:1604 cp/typeck.c:9113
+#: c/c-typeck.c:10118 c/gimple-parser.c:1604 cp/typeck.c:9113
 #, fuzzy, gcc-internal-format
 #| msgid "function does not return string type"
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "функцыя не вяртае тып string"
 
-#: c/c-typeck.c:10139 c/c-typeck.c:10143
+#: c/c-typeck.c:10144 c/c-typeck.c:10148
 #, gcc-internal-format
 msgid "%<return%> with no value, in function returning non-void"
 msgstr ""
 
-#: c/c-typeck.c:10157 c/gimple-parser.c:1614
+#: c/c-typeck.c:10162 c/gimple-parser.c:1614
 #, gcc-internal-format
 msgid "%<return%> with a value, in function returning void"
 msgstr ""
 
-#: c/c-typeck.c:10160
+#: c/c-typeck.c:10165
 #, gcc-internal-format
 msgid "ISO C forbids %<return%> with expression, in function returning void"
 msgstr ""
 
-#: c/c-typeck.c:10236
+#: c/c-typeck.c:10241
 #, fuzzy, gcc-internal-format
 msgid "function returns address of label"
 msgstr "ISO C не дазваляе пусты ізыходны файл"
 
-#: c/c-typeck.c:10327 cp/semantics.c:1171
+#: c/c-typeck.c:10332 cp/semantics.c:1171
 #, gcc-internal-format
 msgid "switch quantity not an integer"
 msgstr ""
 
-#: c/c-typeck.c:10352
+#: c/c-typeck.c:10357
 #, gcc-internal-format
 msgid "%<long%> switch expression not converted to %<int%> in ISO C"
 msgstr ""
 
-#: c/c-typeck.c:10390 c/c-typeck.c:10398
+#: c/c-typeck.c:10395 c/c-typeck.c:10403
 #, fuzzy, gcc-internal-format
 msgid "case label is not an integer constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: c/c-typeck.c:10404 cp/parser.c:11067
+#: c/c-typeck.c:10409 cp/parser.c:11067
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr ""
 
-#: c/c-typeck.c:10406
+#: c/c-typeck.c:10411
 #, gcc-internal-format
 msgid "%<default%> label not within a switch statement"
 msgstr ""
 
-#: c/c-typeck.c:10578 cp/parser.c:12356
+#: c/c-typeck.c:10583 cp/parser.c:12353
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr ""
 
-#: c/c-typeck.c:10580 cp/parser.c:12379
+#: c/c-typeck.c:10585 cp/parser.c:12376
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr ""
 
-#: c/c-typeck.c:10585 cp/parser.c:12369
+#: c/c-typeck.c:10590 cp/parser.c:12366
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr ""
 
-#: c/c-typeck.c:10590
+#: c/c-typeck.c:10595
 #, gcc-internal-format
 msgid "break statement within %<#pragma simd%> loop body"
 msgstr ""
 
-#: c/c-typeck.c:10592
+#: c/c-typeck.c:10597
 #, gcc-internal-format
 msgid "continue statement within %<#pragma simd%> loop body"
 msgstr ""
 
-#: c/c-typeck.c:10618 cp/cp-gimplify.c:432
+#: c/c-typeck.c:10623 cp/cp-gimplify.c:432
 #, gcc-internal-format
 msgid "statement with no effect"
 msgstr ""
 
-#: c/c-typeck.c:10662
+#: c/c-typeck.c:10667
 #, gcc-internal-format
 msgid "expression statement has incomplete type"
 msgstr ""
 
-#: c/c-typeck.c:11476 c/c-typeck.c:11644 cp/typeck.c:5017
+#: c/c-typeck.c:11481 c/c-typeck.c:11649 cp/typeck.c:5017
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr ""
 
-#: c/c-typeck.c:11484 c/c-typeck.c:11652 cp/typeck.c:5030
+#: c/c-typeck.c:11489 c/c-typeck.c:11657 cp/typeck.c:5030
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr ""
 
-#: c/c-typeck.c:11509 c/c-typeck.c:11677 cp/typeck.c:5058
+#: c/c-typeck.c:11514 c/c-typeck.c:11682 cp/typeck.c:5058
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr ""
 
-#: c/c-typeck.c:11523 cp/typeck.c:4743
+#: c/c-typeck.c:11528 cp/typeck.c:4743
 #, gcc-internal-format
 msgid "comparing floating point with == or != is unsafe"
 msgstr ""
 
-#: c/c-typeck.c:11541 c/c-typeck.c:11562
+#: c/c-typeck.c:11546 c/c-typeck.c:11567
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<false%> for the address of %qD will never be NULL"
 msgstr ""
 
-#: c/c-typeck.c:11547 c/c-typeck.c:11568
+#: c/c-typeck.c:11552 c/c-typeck.c:11573
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<true%> for the address of %qD will never be NULL"
 msgstr ""
 
-#: c/c-typeck.c:11589 c/c-typeck.c:11718
+#: c/c-typeck.c:11594 c/c-typeck.c:11723
 #, gcc-internal-format
 msgid "comparison of pointers to disjoint address spaces"
 msgstr ""
 
-#: c/c-typeck.c:11596 c/c-typeck.c:11602
+#: c/c-typeck.c:11601 c/c-typeck.c:11607
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids comparison of %<void *%> with function pointer"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: c/c-typeck.c:11609 c/c-typeck.c:11728
+#: c/c-typeck.c:11614 c/c-typeck.c:11733
 #, gcc-internal-format
 msgid "comparison of distinct pointer types lacks a cast"
 msgstr ""
 
-#: c/c-typeck.c:11621 c/c-typeck.c:11626 c/c-typeck.c:11754 c/c-typeck.c:11759
+#: c/c-typeck.c:11626 c/c-typeck.c:11631 c/c-typeck.c:11759 c/c-typeck.c:11764
 #, gcc-internal-format
 msgid "comparison between pointer and integer"
 msgstr ""
 
-#: c/c-typeck.c:11706
+#: c/c-typeck.c:11711
 #, gcc-internal-format
 msgid "comparison of complete and incomplete pointers"
 msgstr ""
 
-#: c/c-typeck.c:11708
+#: c/c-typeck.c:11713
 #, gcc-internal-format
 msgid "ISO C forbids ordered comparisons of pointers to functions"
 msgstr ""
 
-#: c/c-typeck.c:11713
+#: c/c-typeck.c:11718
 #, gcc-internal-format
 msgid "ordered comparison of pointer with null pointer"
 msgstr ""
 
-#: c/c-typeck.c:11736 c/c-typeck.c:11739 c/c-typeck.c:11746 c/c-typeck.c:11749
+#: c/c-typeck.c:11741 c/c-typeck.c:11744 c/c-typeck.c:11751 c/c-typeck.c:11754
 #: cp/typeck.c:5081 cp/typeck.c:5088
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr ""
 
-#: c/c-typeck.c:11811
+#: c/c-typeck.c:11816
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
 msgstr ""
 
-#: c/c-typeck.c:12126
+#: c/c-typeck.c:12131
 #, gcc-internal-format
 msgid "used array that cannot be converted to pointer where scalar is required"
 msgstr ""
 
-#: c/c-typeck.c:12130
+#: c/c-typeck.c:12135
 #, gcc-internal-format
 msgid "used struct type value where scalar is required"
 msgstr ""
 
-#: c/c-typeck.c:12134
+#: c/c-typeck.c:12139
 #, gcc-internal-format
 msgid "used union type value where scalar is required"
 msgstr ""
 
-#: c/c-typeck.c:12150
+#: c/c-typeck.c:12155
 #, gcc-internal-format
 msgid "used vector type where scalar is required"
 msgstr ""
 
-#: c/c-typeck.c:12340 cp/semantics.c:8508
+#: c/c-typeck.c:12345 cp/semantics.c:8511
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12379 cp/semantics.c:8545
+#: c/c-typeck.c:12384 cp/semantics.c:8548
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12423 c/c-typeck.c:13581 c/c-typeck.c:13642 c/c-typeck.c:13704
+#: c/c-typeck.c:12428 c/c-typeck.c:13586 c/c-typeck.c:13647 c/c-typeck.c:13709
 #, gcc-internal-format
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12436 c/c-typeck.c:13628 cp/semantics.c:4546
-#: cp/semantics.c:6717
+#: c/c-typeck.c:12441 c/c-typeck.c:13633 cp/semantics.c:4549
+#: cp/semantics.c:6720
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12445 c/c-typeck.c:13652 cp/semantics.c:4556
-#: cp/semantics.c:6735
+#: c/c-typeck.c:12450 c/c-typeck.c:13657 cp/semantics.c:4559
+#: cp/semantics.c:6738
 #, gcc-internal-format
 msgid "%qE is a member of a union"
 msgstr ""
 
-#: c/c-typeck.c:12455 cp/semantics.c:4570 cp/semantics.c:6760
+#: c/c-typeck.c:12460 cp/semantics.c:4573 cp/semantics.c:6763
 #, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12459 c/c-typeck.c:13669 cp/semantics.c:4574
-#: cp/semantics.c:6763
+#: c/c-typeck.c:12464 c/c-typeck.c:13674 cp/semantics.c:4577
+#: cp/semantics.c:6766
 #, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12466
+#: c/c-typeck.c:12471
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12475 c/c-typeck.c:13676 c/c-typeck.c:13778
-#: cp/semantics.c:4591 cp/semantics.c:6769 cp/semantics.c:6931
+#: c/c-typeck.c:12480 c/c-typeck.c:13681 c/c-typeck.c:13783
+#: cp/semantics.c:4594 cp/semantics.c:6772 cp/semantics.c:6934
 #, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12511 cp/semantics.c:4623
+#: c/c-typeck.c:12516 cp/semantics.c:4626
 #, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr ""
 
-#: c/c-typeck.c:12518 cp/semantics.c:4630
+#: c/c-typeck.c:12523 cp/semantics.c:4633
 #, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr ""
 
-#: c/c-typeck.c:12545 c/c-typeck.c:12609 c/c-typeck.c:12867
-#: cp/semantics.c:4666 cp/semantics.c:4730
+#: c/c-typeck.c:12550 c/c-typeck.c:12614 c/c-typeck.c:12872
+#: cp/semantics.c:4669 cp/semantics.c:4733
 #, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12564 cp/semantics.c:4685
+#: c/c-typeck.c:12569 cp/semantics.c:4688
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12572 cp/semantics.c:4693
+#: c/c-typeck.c:12577 cp/semantics.c:4696
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12581 c/c-typeck.c:12691 cp/semantics.c:4702
-#: cp/semantics.c:4812
+#: c/c-typeck.c:12586 c/c-typeck.c:12696 cp/semantics.c:4705
+#: cp/semantics.c:4815
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12598 cp/semantics.c:4719
+#: c/c-typeck.c:12603 cp/semantics.c:4722
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12635 cp/semantics.c:4756
+#: c/c-typeck.c:12640 cp/semantics.c:4759
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12650 cp/semantics.c:4771
+#: c/c-typeck.c:12655 cp/semantics.c:4774
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12683 cp/semantics.c:4804
+#: c/c-typeck.c:12688 cp/semantics.c:4807
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12701 c/c-typeck.c:12810 cp/semantics.c:4822
-#: cp/semantics.c:4934
+#: c/c-typeck.c:12706 c/c-typeck.c:12815 cp/semantics.c:4825
+#: cp/semantics.c:4937
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12709 cp/semantics.c:4830
+#: c/c-typeck.c:12714 cp/semantics.c:4833
 #, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr ""
 
-#: c/c-typeck.c:13103 c/c-typeck.c:13113
+#: c/c-typeck.c:13108 c/c-typeck.c:13118
 #, gcc-internal-format
 msgid "%qD in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: c/c-typeck.c:13130
+#: c/c-typeck.c:13135
 #, gcc-internal-format
 msgid "%<_Atomic%> %qE in %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13178
+#: c/c-typeck.c:13183
 #, gcc-internal-format
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr ""
 
-#: c/c-typeck.c:13187 cp/semantics.c:5755
+#: c/c-typeck.c:13192 cp/semantics.c:5758
 #, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr ""
 
-#: c/c-typeck.c:13275
+#: c/c-typeck.c:13280
 #, gcc-internal-format
 msgid "variable length element type in array %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13293 c/c-typeck.c:13836 cp/semantics.c:7249
+#: c/c-typeck.c:13298 c/c-typeck.c:13841 cp/semantics.c:7252
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13305 cp/semantics.c:7289
+#: c/c-typeck.c:13310 cp/semantics.c:7292
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr ""
 
-#: c/c-typeck.c:13319 cp/semantics.c:5929
+#: c/c-typeck.c:13324 cp/semantics.c:5932
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr ""
 
-#: c/c-typeck.c:13327
+#: c/c-typeck.c:13332
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with type %qT"
 msgstr ""
 
-#: c/c-typeck.c:13335
+#: c/c-typeck.c:13340
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13354 cp/semantics.c:5999
+#: c/c-typeck.c:13359 cp/semantics.c:6002
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
-#: c/c-typeck.c:13384 c/c-typeck.c:13771 cp/semantics.c:6083
-#: cp/semantics.c:6924
+#: c/c-typeck.c:13389 c/c-typeck.c:13776 cp/semantics.c:6086
+#: cp/semantics.c:6927
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr ""
 
-#: c/c-typeck.c:13393 cp/semantics.c:6092
+#: c/c-typeck.c:13398 cp/semantics.c:6095
 #, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr ""
 
-#: c/c-typeck.c:13404 c/c-typeck.c:13434 c/c-typeck.c:13463
+#: c/c-typeck.c:13409 c/c-typeck.c:13439 c/c-typeck.c:13468
 #, gcc-internal-format
 msgid "%qE appears more than once in data clauses"
 msgstr ""
 
-#: c/c-typeck.c:13411 c/c-typeck.c:13440 c/c-typeck.c:13600 c/c-typeck.c:13714
-#: c/c-typeck.c:13720 c/c-typeck.c:13733 c/c-typeck.c:13742
-#: cp/semantics.c:6102 cp/semantics.c:6109 cp/semantics.c:6160
-#: cp/semantics.c:6166 cp/semantics.c:6203 cp/semantics.c:6680
-#: cp/semantics.c:6817 cp/semantics.c:6823 cp/semantics.c:6836
-#: cp/semantics.c:6845
+#: c/c-typeck.c:13416 c/c-typeck.c:13445 c/c-typeck.c:13605 c/c-typeck.c:13719
+#: c/c-typeck.c:13725 c/c-typeck.c:13738 c/c-typeck.c:13747
+#: cp/semantics.c:6105 cp/semantics.c:6112 cp/semantics.c:6163
+#: cp/semantics.c:6169 cp/semantics.c:6206 cp/semantics.c:6683
+#: cp/semantics.c:6820 cp/semantics.c:6826 cp/semantics.c:6839
+#: cp/semantics.c:6848
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
-#: c/c-typeck.c:13413 c/c-typeck.c:13442 c/c-typeck.c:13722 c/c-typeck.c:13744
-#: cp/semantics.c:6111 cp/semantics.c:6168 cp/semantics.c:6825
-#: cp/semantics.c:6847
+#: c/c-typeck.c:13418 c/c-typeck.c:13447 c/c-typeck.c:13727 c/c-typeck.c:13749
+#: cp/semantics.c:6114 cp/semantics.c:6171 cp/semantics.c:6828
+#: cp/semantics.c:6850
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr ""
 
-#: c/c-typeck.c:13427 cp/semantics.c:6154
+#: c/c-typeck.c:13432 cp/semantics.c:6157
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13456 cp/semantics.c:6197
+#: c/c-typeck.c:13461 cp/semantics.c:6200
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13475 cp/semantics.c:6545
+#: c/c-typeck.c:13480 cp/semantics.c:6548
 #, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13482
+#: c/c-typeck.c:13487
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array"
 msgstr ""
 
-#: c/c-typeck.c:13489
+#: c/c-typeck.c:13494
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<aligned%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13496
+#: c/c-typeck.c:13501
 #, gcc-internal-format
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:13551 cp/semantics.c:6627
+#: c/c-typeck.c:13556 cp/semantics.c:6630
 #, gcc-internal-format
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13573 cp/semantics.c:6658
+#: c/c-typeck.c:13578 cp/semantics.c:6661
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13597 c/c-typeck.c:13731 cp/semantics.c:6677
-#: cp/semantics.c:6834
+#: c/c-typeck.c:13602 c/c-typeck.c:13736 cp/semantics.c:6680
+#: cp/semantics.c:6837
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr ""
 
-#: c/c-typeck.c:13603 c/c-typeck.c:13735 cp/semantics.c:6683
-#: cp/semantics.c:6838
+#: c/c-typeck.c:13608 c/c-typeck.c:13740 cp/semantics.c:6686
+#: cp/semantics.c:6841
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr ""
 
-#: c/c-typeck.c:13635 cp/semantics.c:6724
+#: c/c-typeck.c:13640 cp/semantics.c:6727
 #, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13695 c/c-typeck.c:13785 cp/semantics.c:6799
-#: cp/semantics.c:6938
+#: c/c-typeck.c:13700 c/c-typeck.c:13790 cp/semantics.c:6802
+#: cp/semantics.c:6941
 #, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13766 cp/semantics.c:6918
+#: c/c-typeck.c:13771 cp/semantics.c:6921
 #, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr ""
 
-#: c/c-typeck.c:13794 cp/semantics.c:6947
+#: c/c-typeck.c:13799 cp/semantics.c:6950
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr ""
 
-#: c/c-typeck.c:13808 cp/semantics.c:6962
+#: c/c-typeck.c:13813 cp/semantics.c:6965
 #, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13811 cp/semantics.c:6964
+#: c/c-typeck.c:13816 cp/semantics.c:6967
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13826
+#: c/c-typeck.c:13831
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer nor an array"
 msgstr ""
 
-#: c/c-typeck.c:13900 cp/semantics.c:6359
+#: c/c-typeck.c:13905 cp/semantics.c:6362
 #, gcc-internal-format
 msgid "%<nonmonotonic%> modifier specified for %qs schedule kind"
 msgstr ""
 
-#: c/c-typeck.c:13931 cp/semantics.c:7141
+#: c/c-typeck.c:13936 cp/semantics.c:7144
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:13981 cp/semantics.c:7332
+#: c/c-typeck.c:13986 cp/semantics.c:7335
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr ""
 
-#: c/c-typeck.c:14001 cp/semantics.c:7223
+#: c/c-typeck.c:14006 cp/semantics.c:7226
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:14013 cp/semantics.c:7236
+#: c/c-typeck.c:14018 cp/semantics.c:7239
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14031 cp/semantics.c:7203
+#: c/c-typeck.c:14036 cp/semantics.c:7206
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14204
+#: c/c-typeck.c:14209
 #, gcc-internal-format
 msgid "cannot use %<va_arg%> with reverse storage order"
 msgstr ""
 
-#: c/c-typeck.c:14209
+#: c/c-typeck.c:14214
 #, fuzzy, gcc-internal-format
 msgid "second argument to %<va_arg%> is of incomplete type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: c/c-typeck.c:14215
+#: c/c-typeck.c:14220
 #, gcc-internal-format
 msgid "C++ requires promoted type, not enum type, in %<va_arg%>"
 msgstr ""
@@ -39022,7 +39065,7 @@
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr ""
 
-#: cp/call.c:3441 cp/pt.c:6495
+#: cp/call.c:3441 cp/pt.c:6509
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -39314,7 +39357,7 @@
 msgid "%q#D is private within this context"
 msgstr ""
 
-#: cp/call.c:6478 cp/decl.c:7343
+#: cp/call.c:6478 cp/decl.c:7364
 #, fuzzy, gcc-internal-format
 msgid "declared private here"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
@@ -39324,7 +39367,7 @@
 msgid "%q#D is protected within this context"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/call.c:6486 cp/decl.c:7344
+#: cp/call.c:6486 cp/decl.c:7365
 #, fuzzy, gcc-internal-format
 #| msgid "called from here"
 msgid "declared protected here"
@@ -39626,7 +39669,7 @@
 msgid "call to non-function %qD"
 msgstr ""
 
-#: cp/call.c:9119 cp/pt.c:15053 cp/typeck.c:2901
+#: cp/call.c:9119 cp/pt.c:15075 cp/typeck.c:2901
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
@@ -39837,262 +39880,262 @@
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr ""
 
-#: cp/class.c:2098
+#: cp/class.c:2103
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr ""
 
-#: cp/class.c:2110
+#: cp/class.c:2115
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr ""
 
-#: cp/class.c:2152
+#: cp/class.c:2156
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr ""
 
-#: cp/class.c:2156
+#: cp/class.c:2160
 #, gcc-internal-format
 msgid "%q#D is public, but requires an existing %q#T object"
 msgstr ""
 
-#: cp/class.c:2430
+#: cp/class.c:2434
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr ""
 
-#: cp/class.c:2785
+#: cp/class.c:2789
 #, gcc-internal-format
 msgid "%qD can be marked override"
 msgstr ""
 
-#: cp/class.c:2797
+#: cp/class.c:2801
 #, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr ""
 
-#: cp/class.c:2799
+#: cp/class.c:2803
 #, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr ""
 
-#: cp/class.c:2861
+#: cp/class.c:2865
 #, gcc-internal-format
 msgid "%qD was hidden"
 msgstr ""
 
-#: cp/class.c:2863
+#: cp/class.c:2867
 #, gcc-internal-format
 msgid "  by %qD"
 msgstr ""
 
-#: cp/class.c:2896
+#: cp/class.c:2900
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr ""
 
-#: cp/class.c:2906 cp/name-lookup.c:3293 cp/parser.c:19720
+#: cp/class.c:2910 cp/name-lookup.c:3293 cp/parser.c:19717
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
 
-#: cp/class.c:3097
+#: cp/class.c:3101
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr ""
 
-#: cp/class.c:3213
+#: cp/class.c:3217
 #, fuzzy, gcc-internal-format
 msgid "bit-field %q+#D with non-integral type"
 msgstr "бітавае поле \"%s\" мае нерэчаісны тып"
 
-#: cp/class.c:3229
+#: cp/class.c:3233
 #, fuzzy, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr "бітавае поле \"%s\" мае нерэчаісны тып"
 
-#: cp/class.c:3234
+#: cp/class.c:3238
 #, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr ""
 
-#: cp/class.c:3239
+#: cp/class.c:3243
 #, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr ""
 
-#: cp/class.c:3249
+#: cp/class.c:3253
 #, gcc-internal-format
 msgid "width of %qD exceeds its type"
 msgstr ""
 
-#: cp/class.c:3255
+#: cp/class.c:3259
 #, gcc-internal-format
 msgid "%qD is too small to hold all values of %q#T"
 msgstr ""
 
-#: cp/class.c:3316
+#: cp/class.c:3320
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr ""
 
-#: cp/class.c:3319
+#: cp/class.c:3323
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr ""
 
-#: cp/class.c:3321
+#: cp/class.c:3325
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr ""
 
-#: cp/class.c:3325
+#: cp/class.c:3329
 #, gcc-internal-format
 msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/class.c:3453
+#: cp/class.c:3457
 #, gcc-internal-format
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr ""
 
-#: cp/class.c:3460
+#: cp/class.c:3464
 #, gcc-internal-format
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr ""
 
-#: cp/class.c:3470
+#: cp/class.c:3474
 #, fuzzy, gcc-internal-format
 msgid "field %q+D invalidly declared function type"
 msgstr "бітавае поле \"%s\" мае нерэчаісны тып"
 
-#: cp/class.c:3476
+#: cp/class.c:3480
 #, fuzzy, gcc-internal-format
 msgid "field %q+D invalidly declared method type"
 msgstr "бітавае поле \"%s\" мае нерэчаісны тып"
 
-#: cp/class.c:3536
+#: cp/class.c:3540
 #, gcc-internal-format
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr ""
 
-#: cp/class.c:3585
+#: cp/class.c:3589
 #, gcc-internal-format
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr ""
 
-#: cp/class.c:3591
+#: cp/class.c:3595
 #, gcc-internal-format
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr ""
 
-#: cp/class.c:3617
+#: cp/class.c:3621
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr ""
 
-#: cp/class.c:3658
+#: cp/class.c:3662
 #, gcc-internal-format
 msgid "field %q#D with same name as class"
 msgstr ""
 
-#: cp/class.c:3681
+#: cp/class.c:3685
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr ""
 
-#: cp/class.c:3686
+#: cp/class.c:3690
 #, gcc-internal-format
 msgid "  but does not override %<%T(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:3688
+#: cp/class.c:3692
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:3692
+#: cp/class.c:3696
 #, gcc-internal-format
 msgid "  but does not override %<operator=(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:4097
+#: cp/class.c:4101
 #, gcc-internal-format
 msgid "alignment of %qD increased in -fabi-version=9 (GCC 5.2)"
 msgstr ""
 
-#: cp/class.c:4100
+#: cp/class.c:4104
 #, gcc-internal-format
 msgid "alignment of %qD will increase in -fabi-version=9"
 msgstr ""
 
-#: cp/class.c:4378
+#: cp/class.c:4382
 #, fuzzy, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/class.c:4813
+#: cp/class.c:4817
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr ""
 
-#: cp/class.c:4834
+#: cp/class.c:4838
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr ""
 
-#: cp/class.c:5350 cp/constexpr.c:237
+#: cp/class.c:5367 cp/constexpr.c:237
 #, gcc-internal-format
 msgid "enclosing class of %<constexpr%> non-static member function %q+#D is not a literal type"
 msgstr ""
 
-#: cp/class.c:5374
+#: cp/class.c:5391
 #, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr ""
 
-#: cp/class.c:5377
+#: cp/class.c:5394
 #, gcc-internal-format
 msgid "  %qT is a closure type, which is only literal in C++17 and later"
 msgstr ""
 
-#: cp/class.c:5380
+#: cp/class.c:5397
 #, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr ""
 
-#: cp/class.c:5387
+#: cp/class.c:5404
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no %<constexpr%> constructor that is not a copy or move constructor"
 msgstr ""
 
-#: cp/class.c:5420
+#: cp/class.c:5437
 #, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr ""
 
-#: cp/class.c:5435
+#: cp/class.c:5452
 #, gcc-internal-format
 msgid "  non-static data member %qD has non-literal type"
 msgstr ""
 
-#: cp/class.c:5442
+#: cp/class.c:5459
 #, gcc-internal-format
 msgid "  non-static data member %qD has volatile type"
 msgstr ""
 
-#: cp/class.c:5561
+#: cp/class.c:5578
 #, gcc-internal-format
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr ""
 
-#: cp/class.c:5590
+#: cp/class.c:5607
 #, gcc-internal-format
 msgid "non-static reference %q#D in class without a constructor"
 msgstr ""
 
-#: cp/class.c:5596
+#: cp/class.c:5613
 #, gcc-internal-format
 msgid "non-static const member %q#D in class without a constructor"
 msgstr ""
@@ -40099,156 +40142,156 @@
 
 #. If the function is defaulted outside the class, we just
 #. give the synthesis error.
-#: cp/class.c:5624
+#: cp/class.c:5641
 #, gcc-internal-format
 msgid "%q+D declared to take const reference, but implicit declaration would take non-const"
 msgstr ""
 
-#: cp/class.c:5898
+#: cp/class.c:5915
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:5910
+#: cp/class.c:5927
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:6133
+#: cp/class.c:6150
 #, gcc-internal-format
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr ""
 
-#: cp/class.c:6291
+#: cp/class.c:6308
 #, fuzzy, gcc-internal-format
 #| msgid "size of `%s' is larger than %d bytes"
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr "памер \"%s\" больш чам %d байт"
 
-#: cp/class.c:6576
+#: cp/class.c:6593
 #, gcc-internal-format
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr ""
 
-#: cp/class.c:6578
+#: cp/class.c:6595
 #, gcc-internal-format
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr ""
 
-#: cp/class.c:6583
+#: cp/class.c:6600
 #, fuzzy, gcc-internal-format
 msgid "array member %q#D declared here"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: cp/class.c:6610
+#: cp/class.c:6627
 #, gcc-internal-format
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr ""
 
-#: cp/class.c:6612
+#: cp/class.c:6629
 #, gcc-internal-format
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr ""
 
-#: cp/class.c:6620 cp/class.c:6650
+#: cp/class.c:6637 cp/class.c:6667
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of `%#T'"
 msgid "in the definition of %q#T"
 msgstr "папярэдняе вызначэньне `%#T'"
 
-#: cp/class.c:6628
+#: cp/class.c:6645
 #, gcc-internal-format
 msgid "flexible array member %qD not at end of %q#T"
 msgstr ""
 
-#: cp/class.c:6630
+#: cp/class.c:6647
 #, gcc-internal-format
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr ""
 
-#: cp/class.c:6648
+#: cp/class.c:6665
 #, gcc-internal-format
 msgid "next member %q#D declared here"
 msgstr ""
 
-#: cp/class.c:6760 cp/parser.c:23239
+#: cp/class.c:6777 cp/parser.c:23236
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of `%#T'"
 msgid "redefinition of %q#T"
 msgstr "папярэдняе вызначэньне `%#T'"
 
-#: cp/class.c:6897
+#: cp/class.c:6914
 #, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr ""
 
-#: cp/class.c:6925
+#: cp/class.c:6942
 #, gcc-internal-format
 msgid "type transparent %q#T does not have any fields"
 msgstr ""
 
-#: cp/class.c:6931
+#: cp/class.c:6948
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr ""
 
-#: cp/class.c:6935
+#: cp/class.c:6952
 #, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr ""
 
-#: cp/class.c:6941
+#: cp/class.c:6958
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:7071
+#: cp/class.c:7088
 #, gcc-internal-format
 msgid "definition of %qD does not match %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/class.c:7082
+#: cp/class.c:7099
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr ""
 
-#: cp/class.c:7582
+#: cp/class.c:7599
 #, fuzzy, gcc-internal-format
 #| msgid "language %s not recognized"
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "мова %s не распазнана"
 
-#: cp/class.c:7672
+#: cp/class.c:7689
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr ""
 
-#: cp/class.c:7817
+#: cp/class.c:7834
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr ""
 
-#: cp/class.c:7844
+#: cp/class.c:7861
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr ""
 
-#: cp/class.c:7870
+#: cp/class.c:7887
 #, fuzzy, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "прапушчан ініцыялізатар"
 
-#: cp/class.c:7873
+#: cp/class.c:7890
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr ""
 
-#: cp/class.c:7948 cp/class.c:7990
+#: cp/class.c:7965 cp/class.c:8007
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr ""
 
-#: cp/class.c:7968
+#: cp/class.c:7985
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr ""
@@ -40258,13 +40301,13 @@
 #. A name N used in a class S shall refer to the same declaration
 #. in its context and when re-evaluated in the completed scope of
 #. S.
-#: cp/class.c:8235
+#: cp/class.c:8252
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D'"
 msgid "declaration of %q#D"
 msgstr "абвяшчэньне `%#D'"
 
-#: cp/class.c:8237
+#: cp/class.c:8254
 #, gcc-internal-format
 msgid "changes meaning of %qD from %q#D"
 msgstr ""
@@ -40658,17 +40701,17 @@
 msgid "unexpected AST of kind %s"
 msgstr ""
 
-#: cp/cp-gimplify.c:1415
+#: cp/cp-gimplify.c:1416
 #, gcc-internal-format
 msgid "throw will always call terminate()"
 msgstr ""
 
-#: cp/cp-gimplify.c:1418
+#: cp/cp-gimplify.c:1419
 #, gcc-internal-format
 msgid "in C++11 destructors default to noexcept"
 msgstr ""
 
-#: cp/cp-gimplify.c:1429
+#: cp/cp-gimplify.c:1430
 #, gcc-internal-format
 msgid "in C++11 this throw will terminate because destructors default to noexcept"
 msgstr ""
@@ -41078,7 +41121,7 @@
 msgid "redeclaration %qD differs in %<constexpr%> from previous declaration"
 msgstr "секцыя \"%s\" канфліктуе з папярэдняй дэкларацыяй"
 
-#: cp/decl.c:1304 cp/decl.c:13843
+#: cp/decl.c:1304 cp/decl.c:13867
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration `%D'"
 msgid "previous declaration %qD"
@@ -41411,7 +41454,7 @@
 msgid "  enters OpenMP structured block"
 msgstr ""
 
-#: cp/decl.c:3434 cp/parser.c:12366 cp/parser.c:12387
+#: cp/decl.c:3434 cp/parser.c:12363 cp/parser.c:12384
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr ""
@@ -41421,7 +41464,7 @@
 msgid "%qD is not a type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.c:3838 cp/parser.c:6366
+#: cp/decl.c:3838 cp/parser.c:6369
 #, fuzzy, gcc-internal-format
 msgid "%qD used without template parameters"
 msgstr "нявернае выкарыстанне \"restict\""
@@ -41800,8 +41843,8 @@
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.c:6011 cp/decl.c:6234 cp/typeck2.c:1310 cp/typeck2.c:1590
-#: cp/typeck2.c:1638 cp/typeck2.c:1685
+#: cp/decl.c:6011 cp/decl.c:6234 cp/typeck2.c:1310 cp/typeck2.c:1593
+#: cp/typeck2.c:1641 cp/typeck2.c:1688
 #, fuzzy, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
@@ -41876,12 +41919,12 @@
 msgid "assignment (not initialization) in declaration"
 msgstr ""
 
-#: cp/decl.c:6873 cp/decl.c:12605
+#: cp/decl.c:6873 cp/decl.c:12629
 #, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr ""
 
-#: cp/decl.c:6877 cp/decl.c:12609
+#: cp/decl.c:6877 cp/decl.c:12633
 #, gcc-internal-format
 msgid "%<register%> storage class specifier used"
 msgstr ""
@@ -41906,42 +41949,42 @@
 msgid "function %q#D is initialized like a variable"
 msgstr ""
 
-#: cp/decl.c:7329
+#: cp/decl.c:7350
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr ""
 
-#: cp/decl.c:7332
+#: cp/decl.c:7353
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.c:7339
+#: cp/decl.c:7360
 #, gcc-internal-format
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr ""
 
-#: cp/decl.c:7365
+#: cp/decl.c:7386
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:7374
+#: cp/decl.c:7395
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:7592
+#: cp/decl.c:7613
 #, fuzzy, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.c:7608
+#: cp/decl.c:7629
 #, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr ""
 
-#: cp/decl.c:7617 cp/decl.c:7702
+#: cp/decl.c:7638 cp/decl.c:7723
 #, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
@@ -41948,7 +41991,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:7621
+#: cp/decl.c:7642
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
@@ -41955,7 +41998,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:7624
+#: cp/decl.c:7645
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
@@ -41962,902 +42005,902 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:7669
+#: cp/decl.c:7690
 #, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr ""
 
-#: cp/decl.c:7695
+#: cp/decl.c:7716
 #, fuzzy, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/decl.c:7704
+#: cp/decl.c:7725
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.c:7725
+#: cp/decl.c:7746
 #, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr ""
 
-#: cp/decl.c:7751
+#: cp/decl.c:7772
 #, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr ""
 
-#: cp/decl.c:7756
+#: cp/decl.c:7777
 #, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr ""
 
-#: cp/decl.c:7761
+#: cp/decl.c:7782
 #, gcc-internal-format
 msgid "cannot decompose lambda closure type %qT"
 msgstr ""
 
-#: cp/decl.c:7765
+#: cp/decl.c:7786
 #, gcc-internal-format
 msgid "structured binding refers to incomplete class type %qT"
 msgstr ""
 
-#: cp/decl.c:7774
+#: cp/decl.c:7795
 #, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr ""
 
-#: cp/decl.c:8213
+#: cp/decl.c:8234
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:8216
+#: cp/decl.c:8237
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:8222
+#: cp/decl.c:8243
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:8450
+#: cp/decl.c:8471
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr ""
 
-#: cp/decl.c:8454
+#: cp/decl.c:8475
 #, fuzzy, gcc-internal-format
 #| msgid "array size missing in `%D'"
 msgid "array size missing in %qT"
 msgstr "прапушчан памер масіва ў `%D'"
 
-#: cp/decl.c:8457
+#: cp/decl.c:8478
 #, fuzzy, gcc-internal-format
 #| msgid "zero-size array `%D'"
 msgid "zero-size array %qT"
 msgstr "нулявы памер масіва `%D'"
 
-#: cp/decl.c:8473
+#: cp/decl.c:8494
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.c:8475
+#: cp/decl.c:8496
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.c:8499
+#: cp/decl.c:8520
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr ""
 
-#: cp/decl.c:8501
+#: cp/decl.c:8522
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr ""
 
-#: cp/decl.c:8506
+#: cp/decl.c:8527
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr ""
 
-#: cp/decl.c:8508
+#: cp/decl.c:8529
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr ""
 
-#: cp/decl.c:8510
+#: cp/decl.c:8531
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:8515
+#: cp/decl.c:8536
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr ""
 
-#: cp/decl.c:8517
+#: cp/decl.c:8538
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr ""
 
-#: cp/decl.c:8519
+#: cp/decl.c:8540
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr ""
 
-#: cp/decl.c:8524
+#: cp/decl.c:8545
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr ""
 
-#: cp/decl.c:8526
+#: cp/decl.c:8547
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr ""
 
-#: cp/decl.c:8528
+#: cp/decl.c:8549
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr ""
 
-#: cp/decl.c:8535
+#: cp/decl.c:8556
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr ""
 
-#: cp/decl.c:8542
+#: cp/decl.c:8563
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/decl.c:8574
+#: cp/decl.c:8595
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr ""
 
-#: cp/decl.c:8614
+#: cp/decl.c:8635
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr ""
 
-#: cp/decl.c:8624
+#: cp/decl.c:8645
 #, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr ""
 
-#: cp/decl.c:8630
+#: cp/decl.c:8651
 #, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr ""
 
-#: cp/decl.c:8632
+#: cp/decl.c:8653
 #, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr ""
 
-#: cp/decl.c:8703
+#: cp/decl.c:8724
 #, gcc-internal-format
 msgid "concept %qD has no definition"
 msgstr ""
 
-#: cp/decl.c:8772
+#: cp/decl.c:8793
 #, fuzzy, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "ініцыялізацыя"
 
 #. Something like `template <class T> friend void f<T>()'.
-#: cp/decl.c:8782
+#: cp/decl.c:8803
 #, fuzzy, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/decl.c:8800
+#: cp/decl.c:8821
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:8808
+#: cp/decl.c:8829
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:8857
+#: cp/decl.c:8878
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr ""
 
-#: cp/decl.c:8859
+#: cp/decl.c:8880
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr ""
 
-#: cp/decl.c:8861
+#: cp/decl.c:8882
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be %<constexpr%>"
 msgstr ""
 
-#: cp/decl.c:8863
+#: cp/decl.c:8884
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr ""
 
-#: cp/decl.c:8920
+#: cp/decl.c:8941
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.c:8921
+#: cp/decl.c:8942
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.c:8929
+#: cp/decl.c:8950
 #, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr ""
 
-#: cp/decl.c:8930
+#: cp/decl.c:8951
 #, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr ""
 
-#: cp/decl.c:8940
+#: cp/decl.c:8961
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared at namespace scope"
 msgstr ""
 
-#: cp/decl.c:8946
+#: cp/decl.c:8967
 #, gcc-internal-format
 msgid "deduction guide %qD must not have a function body"
 msgstr ""
 
-#: cp/decl.c:8959
+#: cp/decl.c:8980
 #, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr ""
 
-#: cp/decl.c:8969
+#: cp/decl.c:8990
 #, fuzzy, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/decl.c:8977
+#: cp/decl.c:8998
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:8983
+#: cp/decl.c:9004
 #, gcc-internal-format
 msgid "floating point suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:8991
+#: cp/decl.c:9012
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/decl.c:8996
+#: cp/decl.c:9017
 #, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr ""
 
-#: cp/decl.c:9076
+#: cp/decl.c:9097
 #, fuzzy, gcc-internal-format
 #| msgid "`main' must return `int'"
 msgid "%<::main%> must return %<int%>"
 msgstr "`main' павінна вяртаць `int'"
 
-#: cp/decl.c:9116
+#: cp/decl.c:9137
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr ""
 
-#: cp/decl.c:9121
+#: cp/decl.c:9142
 #, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr ""
 
-#: cp/decl.c:9123
+#: cp/decl.c:9144
 #, fuzzy, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr "ініцыялізацыя"
 
-#: cp/decl.c:9140
+#: cp/decl.c:9161
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr ""
 
-#: cp/decl.c:9329
+#: cp/decl.c:9350
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr ""
 
-#: cp/decl.c:9337
+#: cp/decl.c:9358
 #, fuzzy, gcc-internal-format
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.c:9344
+#: cp/decl.c:9365
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.c:9464
+#: cp/decl.c:9485
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr ""
 
-#: cp/decl.c:9468
+#: cp/decl.c:9489
 #, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr ""
 
-#: cp/decl.c:9472
+#: cp/decl.c:9493
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr ""
 
-#: cp/decl.c:9486
+#: cp/decl.c:9507
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:9493
+#: cp/decl.c:9514
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr ""
 
-#: cp/decl.c:9498
+#: cp/decl.c:9519
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:9598
+#: cp/decl.c:9619
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%D' has non-integer type"
 msgid "size of array %qD has non-integral type %qT"
 msgstr "памер масіва `%D' не цэлалікавы тып"
 
-#: cp/decl.c:9600
+#: cp/decl.c:9621
 #, fuzzy, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/decl.c:9630 cp/decl.c:9680
+#: cp/decl.c:9651 cp/decl.c:9701
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr ""
 
-#: cp/decl.c:9646
+#: cp/decl.c:9667
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%D' is negative"
 msgid "size of array %qD is negative"
 msgstr "памер масіва `%D' - адмоўны"
 
-#: cp/decl.c:9648 cp/init.c:3651
+#: cp/decl.c:9669 cp/init.c:3667
 #, gcc-internal-format
 msgid "size of array is negative"
 msgstr "адмоўны памер масіва "
 
-#: cp/decl.c:9662
+#: cp/decl.c:9683
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/decl.c:9664
+#: cp/decl.c:9685
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/decl.c:9677
+#: cp/decl.c:9698
 #, fuzzy, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/decl.c:9686
+#: cp/decl.c:9707
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/decl.c:9688
+#: cp/decl.c:9709
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/decl.c:9694
+#: cp/decl.c:9715
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr ""
 
-#: cp/decl.c:9697
+#: cp/decl.c:9718
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr ""
 
-#: cp/decl.c:9746
+#: cp/decl.c:9767
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr ""
 
-#: cp/decl.c:9799
+#: cp/decl.c:9820
 #, gcc-internal-format
 msgid "%qD declared as array of %qT"
 msgstr ""
 
-#: cp/decl.c:9809
+#: cp/decl.c:9830
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D'"
 msgid "declaration of %qD as array of void"
 msgstr "абвяшчэньне `%#D'"
 
-#: cp/decl.c:9811
+#: cp/decl.c:9832
 #, gcc-internal-format
 msgid "creating array of void"
 msgstr ""
 
-#: cp/decl.c:9816
+#: cp/decl.c:9837
 #, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr ""
 
-#: cp/decl.c:9818
+#: cp/decl.c:9839
 #, gcc-internal-format
 msgid "creating array of functions"
 msgstr ""
 
-#: cp/decl.c:9823
+#: cp/decl.c:9844
 #, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr ""
 
-#: cp/decl.c:9825
+#: cp/decl.c:9846
 #, gcc-internal-format
 msgid "creating array of references"
 msgstr ""
 
-#: cp/decl.c:9830
+#: cp/decl.c:9851
 #, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr ""
 
-#: cp/decl.c:9832
+#: cp/decl.c:9853
 #, gcc-internal-format
 msgid "creating array of function members"
 msgstr ""
 
-#: cp/decl.c:9846
+#: cp/decl.c:9867
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.c:9850
+#: cp/decl.c:9871
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.c:9909
+#: cp/decl.c:9930
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr ""
 
-#: cp/decl.c:9912
+#: cp/decl.c:9933
 #, fuzzy, gcc-internal-format
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "\"%s\" - гэта не пачатак дэкларацыі"
 
-#: cp/decl.c:9922
+#: cp/decl.c:9943
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr ""
 
-#: cp/decl.c:9925
+#: cp/decl.c:9946
 #, fuzzy, gcc-internal-format
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "\"%s\" - гэта не пачатак дэкларацыі"
 
-#: cp/decl.c:9937
+#: cp/decl.c:9958
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr ""
 
-#: cp/decl.c:9940
+#: cp/decl.c:9961
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr ""
 
-#: cp/decl.c:9948
+#: cp/decl.c:9969
 #, gcc-internal-format
 msgid "return type specified for deduction guide"
 msgstr ""
 
-#: cp/decl.c:9951
+#: cp/decl.c:9972
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.c:9955
+#: cp/decl.c:9976
 #, gcc-internal-format
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.c:9964
+#: cp/decl.c:9985
 #, fuzzy, gcc-internal-format
 msgid "decl-specifier in declaration of deduction guide"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.c:9985
+#: cp/decl.c:10006
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr ""
 
-#: cp/decl.c:9992
+#: cp/decl.c:10013
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr ""
 
-#: cp/decl.c:10007
+#: cp/decl.c:10028
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr ""
 
-#: cp/decl.c:10013
+#: cp/decl.c:10034
 #, gcc-internal-format
 msgid "inline variables are only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/decl.c:10268
+#: cp/decl.c:10292
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/decl.c:10271 cp/decl.c:10291
+#: cp/decl.c:10295 cp/decl.c:10315
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/decl.c:10274
+#: cp/decl.c:10298
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/decl.c:10283
+#: cp/decl.c:10307
 #, gcc-internal-format
 msgid "%q#T is not a class or a namespace"
 msgstr ""
 
-#: cp/decl.c:10305 cp/decl.c:10398 cp/decl.c:10407 cp/decl.c:11970
+#: cp/decl.c:10329 cp/decl.c:10422 cp/decl.c:10431 cp/decl.c:11994
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.c:10311
+#: cp/decl.c:10335
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D'"
 msgid "declaration of %qD as non-member"
 msgstr "абвяшчэньне `%#D'"
 
-#: cp/decl.c:10339
+#: cp/decl.c:10363
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr ""
 
-#: cp/decl.c:10390
+#: cp/decl.c:10414
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr ""
 
-#: cp/decl.c:10415
+#: cp/decl.c:10439
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D'"
 msgid "declaration of %qD as %<typedef%>"
 msgstr "абвяшчэньне `%#D'"
 
-#: cp/decl.c:10420
+#: cp/decl.c:10444
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D'"
 msgid "declaration of %qD as parameter"
 msgstr "абвяшчэньне `%#D'"
 
-#: cp/decl.c:10454
+#: cp/decl.c:10478
 #, gcc-internal-format
 msgid "%<concept%> cannot appear in a typedef declaration"
 msgstr ""
 
-#: cp/decl.c:10460
+#: cp/decl.c:10484
 #, gcc-internal-format
 msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgstr ""
 
-#: cp/decl.c:10468
+#: cp/decl.c:10492
 #, fuzzy, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "пустое абвяшчэнне"
 
-#: cp/decl.c:10474
+#: cp/decl.c:10498
 #, fuzzy, gcc-internal-format
 #| msgid "conflicts with previous declaration `%#D'"
 msgid "conflicting specifiers in declaration of %qs"
 msgstr "канфлікт з папярэднім абвяшчэньнем `%#D'"
 
-#: cp/decl.c:10515
+#: cp/decl.c:10539
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain `complex' meaning `double complex'"
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C не падтрымлівае просты \"complex\" у значэнні \"double complex\""
 
-#: cp/decl.c:10564 cp/decl.c:10567 cp/decl.c:10570
+#: cp/decl.c:10588 cp/decl.c:10591 cp/decl.c:10594
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/decl.c:10586
+#: cp/decl.c:10610
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_saveregs not supported by this target"
 msgid "%<__int%d%> is not supported by this target"
 msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
 
-#: cp/decl.c:10592
+#: cp/decl.c:10616
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not support `long long'"
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ не падтрымлівае \"long long\""
 
-#: cp/decl.c:10614 cp/decl.c:10634
+#: cp/decl.c:10638 cp/decl.c:10658
 #, fuzzy, gcc-internal-format
 #| msgid "long, short, signed or unsigned invalid for `%s'"
 msgid "%<signed%> or %<unsigned%> invalid for %qs"
 msgstr "long, short, signed ці unsigned нерэчаісны для \"%s\""
 
-#: cp/decl.c:10616
+#: cp/decl.c:10640
 #, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgstr ""
 
-#: cp/decl.c:10618
+#: cp/decl.c:10642
 #, fuzzy, gcc-internal-format
 #| msgid "complex invalid for `%s'"
 msgid "%<long long%> invalid for %qs"
 msgstr "complex нерэчаісны для \"%s\""
 
-#: cp/decl.c:10620
+#: cp/decl.c:10644
 #, fuzzy, gcc-internal-format
 #| msgid "complex invalid for `%s'"
 msgid "%<long%> invalid for %qs"
 msgstr "complex нерэчаісны для \"%s\""
 
-#: cp/decl.c:10622
+#: cp/decl.c:10646
 #, fuzzy, gcc-internal-format
 #| msgid "complex invalid for `%s'"
 msgid "%<short%> invalid for %qs"
 msgstr "complex нерэчаісны для \"%s\""
 
-#: cp/decl.c:10624
+#: cp/decl.c:10648
 #, fuzzy, gcc-internal-format
 #| msgid "long, short, signed or unsigned invalid for `%s'"
 msgid "%<long%> or %<short%> invalid for %qs"
 msgstr "long, short, signed ці unsigned нерэчаісны для \"%s\""
 
-#: cp/decl.c:10626
+#: cp/decl.c:10650
 #, gcc-internal-format
 msgid "%<long%>, %<int%>, %<short%>, or %<char%> invalid for %qs"
 msgstr ""
 
-#: cp/decl.c:10628
+#: cp/decl.c:10652
 #, gcc-internal-format
 msgid "%<long%> or %<short%> specified with char for %qs"
 msgstr ""
 
-#: cp/decl.c:10630
+#: cp/decl.c:10654
 #, gcc-internal-format
 msgid "%<long%> and %<short%> specified together for %qs"
 msgstr ""
 
-#: cp/decl.c:10636
+#: cp/decl.c:10660
 #, fuzzy, gcc-internal-format
 #| msgid "long, short, signed or unsigned invalid for `%s'"
 msgid "%<short%> or %<long%> invalid for %qs"
 msgstr "long, short, signed ці unsigned нерэчаісны для \"%s\""
 
-#: cp/decl.c:10644
+#: cp/decl.c:10668
 #, fuzzy, gcc-internal-format
 #| msgid "long, short, signed or unsigned invalid for `%s'"
 msgid "long, short, signed or unsigned used invalidly for %qs"
 msgstr "long, short, signed ці unsigned нерэчаісны для \"%s\""
 
-#: cp/decl.c:10712
+#: cp/decl.c:10736
 #, fuzzy, gcc-internal-format
 #| msgid "complex invalid for `%s'"
 msgid "complex invalid for %qs"
 msgstr "complex нерэчаісны для \"%s\""
 
-#: cp/decl.c:10751
+#: cp/decl.c:10775
 #, gcc-internal-format
 msgid "template placeholder type %qT must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.c:10769
+#: cp/decl.c:10793
 #, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr ""
 
-#: cp/decl.c:10775
+#: cp/decl.c:10799
 #, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<constexpr%>"
 msgstr ""
 
-#: cp/decl.c:10785
+#: cp/decl.c:10809
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:10790
+#: cp/decl.c:10814
 #, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr ""
 
-#: cp/decl.c:10796
+#: cp/decl.c:10820
 #, gcc-internal-format
 msgid "storage class specifiers invalid in parameter declarations"
 msgstr ""
 
-#: cp/decl.c:10800
+#: cp/decl.c:10824
 #, fuzzy, gcc-internal-format
 msgid "a parameter cannot be declared %<concept%>"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.c:10805
+#: cp/decl.c:10829
 #, fuzzy, gcc-internal-format
 msgid "a parameter cannot be declared %<constexpr%>"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.c:10815
+#: cp/decl.c:10839
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid declaration"
 msgid "%<virtual%> outside class declaration"
 msgstr "Нерэчаіснае абвяшчэнне"
 
-#: cp/decl.c:10825
+#: cp/decl.c:10849
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<inline%>"
 msgstr ""
 
-#: cp/decl.c:10828
+#: cp/decl.c:10852
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<typedef%>"
 msgstr ""
 
-#: cp/decl.c:10830
+#: cp/decl.c:10854
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<constexpr%>"
 msgstr ""
 
-#: cp/decl.c:10834
+#: cp/decl.c:10858
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr ""
 
-#: cp/decl.c:10839
+#: cp/decl.c:10863
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<concept%>"
 msgstr ""
 
-#: cp/decl.c:10845
+#: cp/decl.c:10869
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<register%>"
 msgstr ""
 
-#: cp/decl.c:10849
+#: cp/decl.c:10873
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<static%>"
 msgstr ""
 
-#: cp/decl.c:10853
+#: cp/decl.c:10877
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<extern%>"
 msgstr ""
 
-#: cp/decl.c:10857
+#: cp/decl.c:10881
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:10861
+#: cp/decl.c:10885
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10872
+#: cp/decl.c:10896
 #, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr ""
 
-#: cp/decl.c:10875
+#: cp/decl.c:10899
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10906
+#: cp/decl.c:10930
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate label declaration `%s'"
 msgid "multiple storage classes in declaration of %qs"
 msgstr "паўторнае абвяшчэньне адмеціны `%s'"
 
-#: cp/decl.c:10929
+#: cp/decl.c:10953
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr ""
 
-#: cp/decl.c:10933
+#: cp/decl.c:10957
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr ""
 
-#: cp/decl.c:10946
+#: cp/decl.c:10970
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr ""
 
-#: cp/decl.c:10950
+#: cp/decl.c:10974
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10957
+#: cp/decl.c:10981
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr ""
 
-#: cp/decl.c:10969
+#: cp/decl.c:10993
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr ""
 
-#: cp/decl.c:11050
+#: cp/decl.c:11074
 #, fuzzy, gcc-internal-format
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.c:11098
+#: cp/decl.c:11122
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.c:11118
+#: cp/decl.c:11142
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.c:11121
+#: cp/decl.c:11145
 #, gcc-internal-format
 msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/decl.c:11127
+#: cp/decl.c:11151
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual function cannot have deduced return type"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.c:11134
+#: cp/decl.c:11158
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:11147
+#: cp/decl.c:11171
 #, gcc-internal-format
 msgid "deduced class type %qD in function return type"
 msgstr ""
 
-#: cp/decl.c:11156
+#: cp/decl.c:11180
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr ""
 
-#: cp/decl.c:11169
+#: cp/decl.c:11193
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
@@ -42864,463 +42907,463 @@
 
 #. Not using maybe_warn_cpp0x because this should
 #. always be an error.
-#: cp/decl.c:11180
+#: cp/decl.c:11204
 #, gcc-internal-format
 msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/decl.c:11183
+#: cp/decl.c:11207
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.c:11212
+#: cp/decl.c:11236
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' undeclared (first use in this function)"
 msgid "%qs declared as function returning a function"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/decl.c:11218
+#: cp/decl.c:11242
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr ""
 
-#: cp/decl.c:11247
+#: cp/decl.c:11271
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.c:11248
+#: cp/decl.c:11272
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.c:11252
+#: cp/decl.c:11276
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.c:11253
+#: cp/decl.c:11277
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.c:11261
+#: cp/decl.c:11285
 #, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr ""
 
-#: cp/decl.c:11262
+#: cp/decl.c:11286
 #, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr ""
 
-#: cp/decl.c:11280
+#: cp/decl.c:11304
 #, fuzzy, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
 #. Cannot be both friend and virtual.
-#: cp/decl.c:11295
+#: cp/decl.c:11319
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.c:11299
+#: cp/decl.c:11323
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr ""
 
-#: cp/decl.c:11301
+#: cp/decl.c:11325
 #, fuzzy, gcc-internal-format
 msgid "can%'t define friend function %qs in a local class definition"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/decl.c:11313
+#: cp/decl.c:11337
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr ""
 
-#: cp/decl.c:11339
+#: cp/decl.c:11363
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr ""
 
-#: cp/decl.c:11379
+#: cp/decl.c:11403
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.c:11392 cp/decl.c:11399
+#: cp/decl.c:11416 cp/decl.c:11423
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "Не магу знайсці файл для класа %s."
 
-#: cp/decl.c:11401
+#: cp/decl.c:11425
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr ""
 
-#: cp/decl.c:11430
+#: cp/decl.c:11454
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr ""
 
-#: cp/decl.c:11431
+#: cp/decl.c:11455
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.c:11504
+#: cp/decl.c:11528
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.c:11574
+#: cp/decl.c:11598
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr ""
 
-#: cp/decl.c:11599
+#: cp/decl.c:11623
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr ""
 
-#: cp/decl.c:11605
+#: cp/decl.c:11629
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr ""
 
-#: cp/decl.c:11635
+#: cp/decl.c:11659
 #, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.c:11637
+#: cp/decl.c:11661
 #, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.c:11645
+#: cp/decl.c:11669
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.c:11685
+#: cp/decl.c:11709
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr ""
 
-#: cp/decl.c:11693
+#: cp/decl.c:11717
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.c:11695
+#: cp/decl.c:11719
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.c:11706
+#: cp/decl.c:11730
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate label declaration `%s'"
 msgid "%<explicit%> outside class declaration"
 msgstr "паўторнае абвяшчэньне адмеціны `%s'"
 
-#: cp/decl.c:11709
+#: cp/decl.c:11733
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.c:11712
+#: cp/decl.c:11736
 #, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr ""
 
-#: cp/decl.c:11721
+#: cp/decl.c:11745
 #, fuzzy, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.c:11726
+#: cp/decl.c:11750
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:11732
+#: cp/decl.c:11756
 #, fuzzy, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.c:11737
+#: cp/decl.c:11761
 #, fuzzy, gcc-internal-format
 msgid "static %qs cannot be declared %<mutable%>"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.c:11742
+#: cp/decl.c:11766
 #, fuzzy, gcc-internal-format
 msgid "const %qs cannot be declared %<mutable%>"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.c:11747
+#: cp/decl.c:11771
 #, fuzzy, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.c:11778
+#: cp/decl.c:11802
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr ""
 
-#: cp/decl.c:11783
+#: cp/decl.c:11807
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.c:11787
+#: cp/decl.c:11811
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr ""
 
-#: cp/decl.c:11813
+#: cp/decl.c:11837
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr ""
 
-#: cp/decl.c:11900
+#: cp/decl.c:11924
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/decl.c:11908
+#: cp/decl.c:11932
 #, fuzzy, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.c:11910
+#: cp/decl.c:11934
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr ""
 
-#: cp/decl.c:11914
+#: cp/decl.c:11938
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr ""
 
-#: cp/decl.c:11927
+#: cp/decl.c:11951
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr ""
 
-#: cp/decl.c:11947
+#: cp/decl.c:11971
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr ""
 
-#: cp/decl.c:11951
+#: cp/decl.c:11975
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.c:11961
+#: cp/decl.c:11985
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr ""
 
-#: cp/decl.c:11976
+#: cp/decl.c:12000
 #, fuzzy, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.c:11995
+#: cp/decl.c:12019
 #, fuzzy, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "Не магу знайсці дэкларацыю пратакола для \"%s\""
 
-#: cp/decl.c:12001
+#: cp/decl.c:12025
 #, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr ""
 
-#: cp/decl.c:12003
+#: cp/decl.c:12027
 #, fuzzy, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: cp/decl.c:12052 cp/parser.c:3270
+#: cp/decl.c:12076 cp/parser.c:3270
 #, fuzzy, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/decl.c:12056
+#: cp/decl.c:12080
 #, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr ""
 
-#: cp/decl.c:12080
+#: cp/decl.c:12104
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/decl.c:12083
+#: cp/decl.c:12107
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids flexible array members"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:12099
+#: cp/decl.c:12123
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `::'"
 msgid "invalid use of %<::%>"
 msgstr "нерэчаіснае выкарыстаньне `::'"
 
-#: cp/decl.c:12121
+#: cp/decl.c:12145
 #, fuzzy, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.c:12130
+#: cp/decl.c:12154
 #, fuzzy, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/decl.c:12139
+#: cp/decl.c:12163
 #, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr ""
 
-#: cp/decl.c:12153
+#: cp/decl.c:12177
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr ""
 
-#: cp/decl.c:12160
+#: cp/decl.c:12184
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template `%#D'"
 msgid "declaration of %qD as member of %qT"
 msgstr "абвяшчэньне шаблёну `%#D'"
 
-#: cp/decl.c:12166
+#: cp/decl.c:12190
 #, gcc-internal-format
 msgid "a destructor cannot be %<concept%>"
 msgstr ""
 
-#: cp/decl.c:12171
+#: cp/decl.c:12195
 #, gcc-internal-format
 msgid "a destructor cannot be %<constexpr%>"
 msgstr ""
 
-#: cp/decl.c:12177
+#: cp/decl.c:12201
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr ""
 
-#: cp/decl.c:12185
+#: cp/decl.c:12209
 #, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr ""
 
-#: cp/decl.c:12190
+#: cp/decl.c:12214
 #, fuzzy, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/decl.c:12199
+#: cp/decl.c:12223
 #, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr ""
 
-#: cp/decl.c:12202
+#: cp/decl.c:12226
 #, fuzzy, gcc-internal-format
 msgid "variable template declared here"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/decl.c:12257
+#: cp/decl.c:12281
 #, fuzzy, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.c:12262
+#: cp/decl.c:12286
 #, fuzzy, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.c:12272
+#: cp/decl.c:12296
 #, fuzzy, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/decl.c:12318
+#: cp/decl.c:12342
 #, gcc-internal-format
 msgid "static data member %qE declared %<concept%>"
 msgstr ""
 
-#: cp/decl.c:12322
+#: cp/decl.c:12346
 #, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr ""
 
-#: cp/decl.c:12350
+#: cp/decl.c:12374
 #, gcc-internal-format
 msgid "non-static data member %qE declared %<concept%>"
 msgstr ""
 
-#: cp/decl.c:12354
+#: cp/decl.c:12378
 #, gcc-internal-format
 msgid "non-static data member %qE declared %<constexpr%>"
 msgstr ""
 
-#: cp/decl.c:12409
+#: cp/decl.c:12433
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:12411
+#: cp/decl.c:12435
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:12415
+#: cp/decl.c:12439
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:12418
+#: cp/decl.c:12442
 #, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr ""
 
-#: cp/decl.c:12423
+#: cp/decl.c:12447
 #, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr ""
 
-#: cp/decl.c:12434
+#: cp/decl.c:12458
 #, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.c:12438
+#: cp/decl.c:12462
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.c:12446
+#: cp/decl.c:12470
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr ""
 
-#: cp/decl.c:12453
+#: cp/decl.c:12477
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr ""
 
-#: cp/decl.c:12454
+#: cp/decl.c:12478
 #, fuzzy, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/decl.c:12489
+#: cp/decl.c:12513
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr ""
@@ -43327,77 +43370,77 @@
 
 #. 7.1.1: There can be no static function declarations within a
 #. block.
-#: cp/decl.c:12497
+#: cp/decl.c:12521
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr ""
 
-#: cp/decl.c:12533
+#: cp/decl.c:12557
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr ""
 
-#: cp/decl.c:12540
+#: cp/decl.c:12564
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr ""
 
-#: cp/decl.c:12546
+#: cp/decl.c:12570
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr ""
 
-#: cp/decl.c:12553
+#: cp/decl.c:12577
 #, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr ""
 
-#: cp/decl.c:12574
+#: cp/decl.c:12598
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl.c:12585
+#: cp/decl.c:12609
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr ""
 
-#: cp/decl.c:12589
+#: cp/decl.c:12613
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr ""
 
-#: cp/decl.c:12754
+#: cp/decl.c:12778
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: cp/decl.c:12757
+#: cp/decl.c:12781
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: cp/decl.c:12841
+#: cp/decl.c:12865
 #, fuzzy, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/decl.c:12845
+#: cp/decl.c:12869
 #, fuzzy, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/decl.c:12868
+#: cp/decl.c:12892
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: cp/decl.c:12895
+#: cp/decl.c:12919
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.c:12897
+#: cp/decl.c:12921
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr ""
@@ -43417,172 +43460,172 @@
 #. or implicitly defined), there's no need to worry about their
 #. existence.  Theoretically, they should never even be
 #. instantiated, but that's hard to forestall.
-#: cp/decl.c:13150
+#: cp/decl.c:13174
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr ""
 
-#: cp/decl.c:13228
+#: cp/decl.c:13252
 #, fuzzy, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/decl.c:13234
+#: cp/decl.c:13258
 #, fuzzy, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/decl.c:13261
+#: cp/decl.c:13285
 #, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr ""
 
-#: cp/decl.c:13267
+#: cp/decl.c:13291
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr ""
 
-#: cp/decl.c:13277
+#: cp/decl.c:13301
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr ""
 
 #. 13.4.0.3
-#: cp/decl.c:13303
+#: cp/decl.c:13327
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading operator ?:"
 msgstr ""
 
 #. Variadic.
-#: cp/decl.c:13314
+#: cp/decl.c:13338
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr ""
 
-#: cp/decl.c:13338
+#: cp/decl.c:13362
 #, gcc-internal-format
 msgid "%qD must have either zero or one argument"
 msgstr ""
 
-#: cp/decl.c:13339
+#: cp/decl.c:13363
 #, gcc-internal-format
 msgid "%qD must have either one or two arguments"
 msgstr ""
 
-#: cp/decl.c:13350
+#: cp/decl.c:13374
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr ""
 
-#: cp/decl.c:13351
+#: cp/decl.c:13375
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr ""
 
-#: cp/decl.c:13361
+#: cp/decl.c:13385
 #, fuzzy, gcc-internal-format
 #| msgid "no arguments"
 msgid "%qD must have no arguments"
 msgstr "няма аргументаў"
 
-#: cp/decl.c:13362 cp/decl.c:13371
+#: cp/decl.c:13386 cp/decl.c:13395
 #, gcc-internal-format
 msgid "%qD must have exactly one argument"
 msgstr ""
 
-#: cp/decl.c:13372
+#: cp/decl.c:13396
 #, gcc-internal-format
 msgid "%qD must have exactly two arguments"
 msgstr ""
 
-#: cp/decl.c:13389 cp/decl.c:13392
+#: cp/decl.c:13413 cp/decl.c:13416
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: cp/decl.c:13419
+#: cp/decl.c:13443
 #, gcc-internal-format
 msgid "conversion to a reference to void will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13421
+#: cp/decl.c:13445
 #, gcc-internal-format
 msgid "conversion to void will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13428
+#: cp/decl.c:13452
 #, gcc-internal-format
 msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13430
+#: cp/decl.c:13454
 #, gcc-internal-format
 msgid "conversion to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13438
+#: cp/decl.c:13462
 #, gcc-internal-format
 msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13440
+#: cp/decl.c:13464
 #, gcc-internal-format
 msgid "conversion to a base class will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13455
+#: cp/decl.c:13479
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr ""
 
-#: cp/decl.c:13474
+#: cp/decl.c:13498
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.c:13480
+#: cp/decl.c:13504
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.c:13492
+#: cp/decl.c:13516
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr ""
 
-#: cp/decl.c:13547
+#: cp/decl.c:13571
 #, fuzzy, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/decl.c:13570
+#: cp/decl.c:13594
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr ""
 
-#: cp/decl.c:13573
+#: cp/decl.c:13597
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr ""
 
-#: cp/decl.c:13575
+#: cp/decl.c:13599
 #, fuzzy, gcc-internal-format
 #| msgid "this is a previous declaration"
 msgid "%qD has a previous declaration here"
 msgstr "гэта папярэдняе абвяшчэньне"
 
-#: cp/decl.c:13583
+#: cp/decl.c:13607
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr ""
 
-#: cp/decl.c:13584 cp/decl.c:13591
+#: cp/decl.c:13608 cp/decl.c:13615
 #, fuzzy, gcc-internal-format
 #| msgid "this is a previous declaration"
 msgid "%qT has a previous declaration here"
 msgstr "гэта папярэдняе абвяшчэньне"
 
-#: cp/decl.c:13590
+#: cp/decl.c:13614
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr ""
@@ -43594,95 +43637,95 @@
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:13605
+#: cp/decl.c:13629
 #, fuzzy, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/decl.c:13659 cp/name-lookup.c:4652
+#: cp/decl.c:13683 cp/name-lookup.c:4652
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr ""
 
-#: cp/decl.c:13689 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6425
-#: cp/pt.c:9209
+#: cp/decl.c:13713 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6428
+#: cp/pt.c:9223
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.c:13694
+#: cp/decl.c:13718
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:13703 cp/name-lookup.c:4079 cp/name-lookup.c:4086
-#: cp/name-lookup.c:4939 cp/parser.c:6376 cp/parser.c:26300
+#: cp/decl.c:13727 cp/name-lookup.c:4079 cp/name-lookup.c:4086
+#: cp/name-lookup.c:4939 cp/parser.c:6379 cp/parser.c:26297
 #, fuzzy, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "памер \"%s\" - %d байт"
 
-#: cp/decl.c:13806
+#: cp/decl.c:13830
 #, fuzzy, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "секцыя \"%s\" канфліктуе з папярэдняй дэкларацыяй"
 
-#: cp/decl.c:13842
+#: cp/decl.c:13866
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template `%#D'"
 msgid "redeclaration of %qT as a non-template"
 msgstr "абвяшчэньне шаблёну `%#D'"
 
-#: cp/decl.c:13982
+#: cp/decl.c:14006
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr ""
 
-#: cp/decl.c:13989
+#: cp/decl.c:14013
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr ""
 
-#: cp/decl.c:14000
+#: cp/decl.c:14024
 #, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr ""
 
-#: cp/decl.c:14025
+#: cp/decl.c:14049
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr ""
 
-#: cp/decl.c:14055
+#: cp/decl.c:14079
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr ""
 
-#: cp/decl.c:14057
+#: cp/decl.c:14081
 #, fuzzy, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "паўтарэнне \"restrict\""
 
-#: cp/decl.c:14202
+#: cp/decl.c:14226
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14205 cp/decl.c:14213 cp/decl.c:14225 cp/parser.c:18284
+#: cp/decl.c:14229 cp/decl.c:14237 cp/decl.c:14249 cp/parser.c:18281
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "папярэдняе вызначэньне"
 
-#: cp/decl.c:14210
+#: cp/decl.c:14234
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14222
+#: cp/decl.c:14246
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14300
+#: cp/decl.c:14324
 #, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr ""
@@ -43691,78 +43734,78 @@
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:14447
+#: cp/decl.c:14471
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr ""
 
-#: cp/decl.c:14619
+#: cp/decl.c:14643
 #, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr ""
 
-#: cp/decl.c:14629
+#: cp/decl.c:14653
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/decl.c:14678
+#: cp/decl.c:14702
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr ""
 
-#: cp/decl.c:14679
+#: cp/decl.c:14703
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr ""
 
-#: cp/decl.c:14690
+#: cp/decl.c:14714
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr ""
 
-#: cp/decl.c:14710
+#: cp/decl.c:14734
 #, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr ""
 
-#: cp/decl.c:14821
+#: cp/decl.c:14845
 #, fuzzy, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "вяртаемы тып \"%s\" не \"int\""
 
-#: cp/decl.c:14999 cp/typeck.c:9286
+#: cp/decl.c:15023 cp/typeck.c:9286
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr ""
 
-#: cp/decl.c:15344
+#: cp/decl.c:15368
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid declaration"
 msgid "invalid function declaration"
 msgstr "Нерэчаіснае абвяшчэнне"
 
-#: cp/decl.c:15786
+#: cp/decl.c:15810
 #, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr ""
 
-#: cp/decl.c:15788 cp/typeck.c:9166
+#: cp/decl.c:15812 cp/typeck.c:9166
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr ""
 
-#: cp/decl.c:15996
+#: cp/decl.c:16020
 #, fuzzy, gcc-internal-format
 msgid "invalid member function declaration"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/decl.c:16010
+#: cp/decl.c:16034
 #, fuzzy, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "не знойдзен клас \"%s\""
 
-#: cp/decl.c:16386
+#: cp/decl.c:16410
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -43802,7 +43845,7 @@
 msgid "deleting %qT is undefined"
 msgstr "метка \"%s\" ужываецца, але не вызначана"
 
-#: cp/decl2.c:585 cp/pt.c:5552
+#: cp/decl2.c:585 cp/pt.c:5566
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "пустое абвяшчэнне"
@@ -43815,7 +43858,7 @@
 #. [temp.mem]
 #.
 #. A destructor shall not be a member template.
-#: cp/decl2.c:640 cp/pt.c:5511
+#: cp/decl2.c:640 cp/pt.c:5525
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr ""
@@ -43990,47 +44033,47 @@
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr ""
 
-#: cp/decl2.c:2660
+#: cp/decl2.c:2650
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2664
+#: cp/decl2.c:2654
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2669
+#: cp/decl2.c:2659
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2677
+#: cp/decl2.c:2667
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr ""
 
-#: cp/decl2.c:2695
+#: cp/decl2.c:2685
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2699
+#: cp/decl2.c:2689
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2704
+#: cp/decl2.c:2694
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2711
+#: cp/decl2.c:2701
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr ""
 
-#: cp/decl2.c:4309
+#: cp/decl2.c:4299
 #, gcc-internal-format
 msgid "%q#D, declared using unnamed type, is used but never defined"
 msgstr ""
@@ -44039,65 +44082,65 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4318
+#: cp/decl2.c:4308
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4322
+#: cp/decl2.c:4312
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4326
+#: cp/decl2.c:4316
 #, gcc-internal-format
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr ""
 
-#: cp/decl2.c:4334
+#: cp/decl2.c:4324
 #, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr ""
 
-#: cp/decl2.c:4338
+#: cp/decl2.c:4328
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4341
+#: cp/decl2.c:4331
 #, fuzzy, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl2.c:4529
+#: cp/decl2.c:4519
 #, fuzzy, gcc-internal-format
 #| msgid "section of `%s' conflicts with previous declaration"
 msgid "mangling of %q#D as %qE conflicts with a previous mangle"
 msgstr "секцыя \"%s\" канфліктуе з папярэдняй дэкларацыяй"
 
-#: cp/decl2.c:4532
+#: cp/decl2.c:4522
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration `%D'"
 msgid "previous mangling %q#D"
 msgstr "папярэдняе абвяшчэньне `%D'"
 
-#: cp/decl2.c:4534
+#: cp/decl2.c:4524
 #, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr ""
 
-#: cp/decl2.c:4606 cp/decl2.c:4609
+#: cp/decl2.c:4596 cp/decl2.c:4599
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.c:4956
+#: cp/decl2.c:4946
 #, fuzzy, gcc-internal-format
 #| msgid "label `%D' used but not defined"
 msgid "inline function %qD used but never defined"
 msgstr "адмеціна `%D' выкарыстоўвываецца, але ня вызначана"
 
-#: cp/decl2.c:5143
+#: cp/decl2.c:5133
 #, fuzzy, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr "аргумент для \"%s\" прапушчан"
@@ -44104,17 +44147,17 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5251
+#: cp/decl2.c:5241
 #, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.c:5254
+#: cp/decl2.c:5244
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr ""
 
-#: cp/decl2.c:5307
+#: cp/decl2.c:5297
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr ""
@@ -44401,335 +44444,335 @@
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr ""
 
-#: cp/init.c:613
+#: cp/init.c:629
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr ""
 
-#: cp/init.c:615
+#: cp/init.c:631
 #, gcc-internal-format
 msgid "defined here"
 msgstr ""
 
-#: cp/init.c:673
+#: cp/init.c:689
 #, fuzzy, gcc-internal-format
 msgid "initializer for flexible array member %q#D"
 msgstr "прапушчан ініцыялізатар"
 
-#: cp/init.c:699
+#: cp/init.c:715
 #, fuzzy, gcc-internal-format
 msgid "%qD should be initialized in the member initialization list"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/init.c:720
+#: cp/init.c:736
 #, fuzzy, gcc-internal-format
 msgid "%qD is initialized with itself"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/init.c:831
+#: cp/init.c:847
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for array member %q#D"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/init.c:845 cp/init.c:869 cp/init.c:2410 cp/method.c:1368
+#: cp/init.c:861 cp/init.c:885 cp/init.c:2427 cp/method.c:1368
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/init.c:847 cp/init.c:864 cp/init.c:871 cp/init.c:2395 cp/init.c:2423
+#: cp/init.c:863 cp/init.c:880 cp/init.c:887 cp/init.c:2412 cp/init.c:2440
 #: cp/method.c:1371 cp/method.c:1382
 #, fuzzy, gcc-internal-format
 msgid "%q#D should be initialized"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/init.c:862 cp/init.c:2382 cp/method.c:1379
+#: cp/init.c:878 cp/init.c:2399 cp/method.c:1379
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr "прапушчан ініцыялізатар"
 
-#: cp/init.c:1041
+#: cp/init.c:1057
 #, gcc-internal-format
 msgid "%qD will be initialized after"
 msgstr ""
 
-#: cp/init.c:1044
+#: cp/init.c:1060
 #, fuzzy, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr "Клас \"%s\" ужо існуе"
 
-#: cp/init.c:1048
+#: cp/init.c:1064
 #, gcc-internal-format
 msgid "  %q#D"
 msgstr ""
 
-#: cp/init.c:1050
+#: cp/init.c:1066
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr ""
 
-#: cp/init.c:1052
+#: cp/init.c:1068
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "  when initialized here"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/init.c:1069
+#: cp/init.c:1085
 #, fuzzy, gcc-internal-format
 msgid "multiple initializations given for %qD"
 msgstr "ініцыялізацыя"
 
-#: cp/init.c:1073
+#: cp/init.c:1089
 #, gcc-internal-format
 msgid "multiple initializations given for base %qT"
 msgstr ""
 
-#: cp/init.c:1158
+#: cp/init.c:1174
 #, gcc-internal-format
 msgid "initializations for multiple members of %qT"
 msgstr ""
 
-#: cp/init.c:1255
+#: cp/init.c:1271
 #, gcc-internal-format
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr ""
 
-#: cp/init.c:1482 cp/init.c:1501
+#: cp/init.c:1498 cp/init.c:1517
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr ""
 
-#: cp/init.c:1488
+#: cp/init.c:1504
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr ""
 
-#: cp/init.c:1495
+#: cp/init.c:1511
 #, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr ""
 
-#: cp/init.c:1534
+#: cp/init.c:1550
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr ""
 
-#: cp/init.c:1542
+#: cp/init.c:1558
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr ""
 
-#: cp/init.c:1589
+#: cp/init.c:1605
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr ""
 
-#: cp/init.c:1597
+#: cp/init.c:1613
 #, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr ""
 
-#: cp/init.c:1600
+#: cp/init.c:1616
 #, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr ""
 
-#: cp/init.c:1710 cp/init.c:4386 cp/typeck2.c:1175
+#: cp/init.c:1727 cp/init.c:4402 cp/typeck2.c:1175
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
 
-#: cp/init.c:2019 cp/semantics.c:3268
+#: cp/init.c:2036 cp/semantics.c:3271
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/init.c:2075
+#: cp/init.c:2092
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr ""
 
-#: cp/init.c:2089
+#: cp/init.c:2106
 #, fuzzy, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/init.c:2175 cp/typeck.c:1893
+#: cp/init.c:2192 cp/typeck.c:1893
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/init.c:2182 cp/semantics.c:1835
+#: cp/init.c:2199 cp/semantics.c:1835
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/init.c:2379
+#: cp/init.c:2396
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2387
+#: cp/init.c:2404
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2391
+#: cp/init.c:2408
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr ""
 
-#: cp/init.c:2407
+#: cp/init.c:2424
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2415
+#: cp/init.c:2432
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2419
+#: cp/init.c:2436
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr ""
 
-#: cp/init.c:2710
+#: cp/init.c:2727
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2721
+#: cp/init.c:2738
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2732
+#: cp/init.c:2749
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2880
+#: cp/init.c:2896
 #, gcc-internal-format
 msgid "integer overflow in array size"
 msgstr ""
 
-#: cp/init.c:2890
+#: cp/init.c:2906
 #, gcc-internal-format
 msgid "array size in new-expression must be constant"
 msgstr ""
 
-#: cp/init.c:2904
+#: cp/init.c:2920
 #, gcc-internal-format
 msgid "variably modified type not allowed in new-expression"
 msgstr ""
 
-#: cp/init.c:2920
+#: cp/init.c:2936
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by typedef"
 msgstr ""
 
-#: cp/init.c:2922
+#: cp/init.c:2938
 #, gcc-internal-format
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr ""
 
-#: cp/init.c:2932
+#: cp/init.c:2948
 #, gcc-internal-format
 msgid "invalid type %<void%> for new"
 msgstr ""
 
-#: cp/init.c:2975
+#: cp/init.c:2991
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/init.c:3101
+#: cp/init.c:3117
 #, fuzzy, gcc-internal-format
 #| msgid "field '%s' not found in class"
 msgid "no suitable %qD found in class %qT"
 msgstr "поле \"%s\" не знойдзена ў класе"
 
-#: cp/init.c:3108 cp/search.c:1023
+#: cp/init.c:3124 cp/search.c:1026
 #, fuzzy, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "памер \"%s\" - %d байт"
 
-#: cp/init.c:3181
+#: cp/init.c:3197
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr ""
 
-#: cp/init.c:3184
+#: cp/init.c:3200
 #, gcc-internal-format
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr ""
 
-#: cp/init.c:3187
+#: cp/init.c:3203
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr ""
 
-#: cp/init.c:3370
+#: cp/init.c:3386
 #, gcc-internal-format
 msgid "parenthesized initializer in array new"
 msgstr ""
 
-#: cp/init.c:3633
+#: cp/init.c:3649
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr ""
 
-#: cp/init.c:3665
+#: cp/init.c:3681
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr ""
 
-#: cp/init.c:3674
+#: cp/init.c:3690
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr ""
 
-#: cp/init.c:3743
+#: cp/init.c:3759
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete [] operator:"
 msgstr ""
 
-#: cp/init.c:3747
+#: cp/init.c:3763
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete [] will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4295
+#: cp/init.c:4311
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr ""
 
-#: cp/init.c:4599
+#: cp/init.c:4615
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr ""
 
-#: cp/init.c:4623
+#: cp/init.c:4639
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete operator:"
 msgstr ""
 
-#: cp/init.c:4628
+#: cp/init.c:4644
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4642
+#: cp/init.c:4658
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4647
+#: cp/init.c:4663
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4954
+#: cp/init.c:4970
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr ""
@@ -45204,7 +45247,7 @@
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr ""
 
-#: cp/name-lookup.c:5111 cp/name-lookup.c:7065
+#: cp/name-lookup.c:5111 cp/name-lookup.c:7073
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored"
 msgid "%qD attribute directive ignored"
@@ -45252,53 +45295,53 @@
 msgid "it was later defined here"
 msgstr ""
 
-#: cp/name-lookup.c:6687
+#: cp/name-lookup.c:6695
 #, gcc-internal-format
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn't a template"
 msgstr ""
 
-#: cp/name-lookup.c:7059
+#: cp/name-lookup.c:7067
 #, fuzzy, gcc-internal-format
 msgid "strong using directive no longer supported"
 msgstr "-pipe не падтрымліваецца."
 
-#: cp/name-lookup.c:7062
+#: cp/name-lookup.c:7070
 #, gcc-internal-format
 msgid "you may use an inline namespace instead"
 msgstr ""
 
-#: cp/name-lookup.c:7079
+#: cp/name-lookup.c:7087
 #, gcc-internal-format
 msgid "attributes ignored on local using directive"
 msgstr ""
 
-#: cp/name-lookup.c:7163
+#: cp/name-lookup.c:7171
 #, fuzzy, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "\"%s\" - гэта не пачатак дэкларацыі"
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:7183
+#: cp/name-lookup.c:7191
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot nest more than %d namespaces"
 msgstr ""
 
-#: cp/name-lookup.c:7218
+#: cp/name-lookup.c:7226
 #, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr ""
 
-#: cp/name-lookup.c:7219
+#: cp/name-lookup.c:7227
 #, fuzzy, gcc-internal-format
 msgid "%qD defined here"
 msgstr "YYDEBUG не вызначан."
 
-#: cp/name-lookup.c:7292
+#: cp/name-lookup.c:7300
 #, gcc-internal-format
 msgid "XXX entering pop_everything ()\n"
 msgstr ""
 
-#: cp/name-lookup.c:7301
+#: cp/name-lookup.c:7309
 #, gcc-internal-format
 msgid "XXX leaving pop_everything ()\n"
 msgstr ""
@@ -45318,7 +45361,7 @@
 msgid "LEXER_DEBUGGING_ENABLED_P is not set to true"
 msgstr ""
 
-#: cp/parser.c:1352 cp/parser.c:37254
+#: cp/parser.c:1352 cp/parser.c:37251
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -45343,7 +45386,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr ""
 
-#: cp/parser.c:2949 cp/parser.c:18221
+#: cp/parser.c:2949 cp/parser.c:18218
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr ""
@@ -45423,7 +45466,7 @@
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3143 cp/pt.c:17853
+#: cp/parser.c:3143 cp/pt.c:17890
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr ""
@@ -45646,7 +45689,7 @@
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr ""
 
-#: cp/parser.c:4587 cp/parser.c:12940
+#: cp/parser.c:4587 cp/parser.c:12937
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "expected declaration"
@@ -45698,7 +45741,7 @@
 msgid "fold-expressions only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:5275 cp/parser.c:5452 cp/parser.c:5630 cp/semantics.c:3612
+#: cp/parser.c:5275 cp/parser.c:5452 cp/parser.c:5633 cp/semantics.c:3615
 #, gcc-internal-format
 msgid "expected primary-expression"
 msgstr ""
@@ -45718,94 +45761,94 @@
 msgid "local variable %qD may not appear in this context"
 msgstr ""
 
-#: cp/parser.c:5787
+#: cp/parser.c:5790
 #, gcc-internal-format
 msgid "expected id-expression"
 msgstr ""
 
-#: cp/parser.c:5919
+#: cp/parser.c:5922
 #, gcc-internal-format
 msgid "scope %qT before %<~%> is not a class-name"
 msgstr ""
 
-#: cp/parser.c:5948 cp/parser.c:7860
+#: cp/parser.c:5951 cp/parser.c:7860
 #, gcc-internal-format
 msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:6059
+#: cp/parser.c:6062
 #, gcc-internal-format
 msgid "declaration of %<~%T%> as member of %qT"
 msgstr ""
 
-#: cp/parser.c:6074
+#: cp/parser.c:6077
 #, gcc-internal-format
 msgid "typedef-name %qD used as destructor declarator"
 msgstr ""
 
-#: cp/parser.c:6111 cp/parser.c:20249
+#: cp/parser.c:6114 cp/parser.c:20246
 #, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr ""
 
-#: cp/parser.c:6220
+#: cp/parser.c:6223
 #, gcc-internal-format
 msgid "found %<:%> in nested-name-specifier, expected %<::%>"
 msgstr ""
 
-#: cp/parser.c:6288
+#: cp/parser.c:6291
 #, gcc-internal-format
 msgid "decltype evaluates to %qT, which is not a class or enumeration type"
 msgstr ""
 
-#: cp/parser.c:6314
+#: cp/parser.c:6317
 #, gcc-internal-format
 msgid "function template-id %qD in nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:6322
+#: cp/parser.c:6325
 #, gcc-internal-format
 msgid "variable template-id %qD in nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:6426 cp/typeck.c:2684 cp/typeck.c:2687 cp/typeck.c:2704
+#: cp/parser.c:6429 cp/typeck.c:2684 cp/typeck.c:2687 cp/typeck.c:2704
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/parser.c:6504
+#: cp/parser.c:6507
 #, gcc-internal-format
 msgid "expected nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:6711 cp/parser.c:8950
+#: cp/parser.c:6714 cp/parser.c:8950
 #, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr ""
 
-#: cp/parser.c:6797
+#: cp/parser.c:6800
 #, gcc-internal-format
 msgid "types may not be defined in a %<typeid%> expression"
 msgstr ""
 
-#: cp/parser.c:6889
+#: cp/parser.c:6892
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for `%s' attribute"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "памылковая колькасьць аргументаў, зададзеных для атрыбута `%s'"
 
-#: cp/parser.c:6901 cp/pt.c:18416
+#: cp/parser.c:6904 cp/pt.c:18453
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for `%s' attribute"
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "памылковая колькасьць аргументаў, зададзеных для атрыбута `%s'"
 
-#: cp/parser.c:6995
+#: cp/parser.c:6998
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids compound-literals"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/parser.c:7054
+#: cp/parser.c:7057
 #, gcc-internal-format
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
@@ -45936,7 +45979,7 @@
 msgid "capture of non-variable %qE"
 msgstr ""
 
-#: cp/parser.c:10391 cp/parser.c:10401 cp/semantics.c:3453 cp/semantics.c:3465
+#: cp/parser.c:10391 cp/parser.c:10401 cp/semantics.c:3456 cp/semantics.c:3468
 #, fuzzy, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
@@ -46023,7 +46066,7 @@
 msgid "init-statement in selection statements only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:11546 cp/parser.c:28490
+#: cp/parser.c:11546 cp/parser.c:28487
 #, fuzzy, gcc-internal-format
 #| msgid "empty body in an else-statement"
 msgid "expected selection-statement"
@@ -46044,201 +46087,201 @@
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:12250 cp/parser.c:28493
+#: cp/parser.c:12250 cp/parser.c:28490
 #, fuzzy, gcc-internal-format
 #| msgid "empty body in an else-statement"
 msgid "expected iteration-statement"
 msgstr "пустое цела ў else-выражэнні"
 
-#: cp/parser.c:12298
+#: cp/parser.c:12297
 #, gcc-internal-format
 msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/parser.c:12426
+#: cp/parser.c:12423
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr ""
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:12434
+#: cp/parser.c:12431
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr ""
 
-#: cp/parser.c:12447 cp/parser.c:28496
+#: cp/parser.c:12444 cp/parser.c:28493
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr ""
 
-#: cp/parser.c:12620 cp/parser.c:23584
+#: cp/parser.c:12617 cp/parser.c:23581
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr ""
 
-#: cp/parser.c:12863
+#: cp/parser.c:12860
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr ""
 
-#: cp/parser.c:13083
+#: cp/parser.c:13080
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:13103
+#: cp/parser.c:13100
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr ""
 
-#: cp/parser.c:13124
+#: cp/parser.c:13121
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr ""
 
-#: cp/parser.c:13148
+#: cp/parser.c:13145
 #, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr ""
 
-#: cp/parser.c:13203
+#: cp/parser.c:13200
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13206
+#: cp/parser.c:13203
 #, fuzzy, gcc-internal-format
 #| msgid "multiple declarations `%T' and `%T'"
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr "неаднолькавае абвяшчэньне `%T' і `%T'"
 
-#: cp/parser.c:13257
+#: cp/parser.c:13254
 #, gcc-internal-format
 msgid "structured bindings only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:13306
+#: cp/parser.c:13303
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "empty structured binding declaration"
 msgstr "пустое абвяшчэньне"
 
-#: cp/parser.c:13324
+#: cp/parser.c:13321
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for structured binding declaration"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/parser.c:13491
+#: cp/parser.c:13488
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr ""
 
-#: cp/parser.c:13558
+#: cp/parser.c:13555
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr ""
 
-#: cp/parser.c:13594
+#: cp/parser.c:13591
 #, gcc-internal-format
 msgid "decl-specifier invalid in condition"
 msgstr ""
 
-#: cp/parser.c:13600
+#: cp/parser.c:13597
 #, fuzzy, gcc-internal-format
 msgid "%qD invalid in lambda"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: cp/parser.c:13693
+#: cp/parser.c:13690
 #, fuzzy, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/parser.c:13763 cp/parser.c:24064
+#: cp/parser.c:13760 cp/parser.c:24061
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:13805
+#: cp/parser.c:13802
 #, fuzzy, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr "Нерэчаісная спецыфікацыя! Памылка ў cc."
 
-#: cp/parser.c:13909
+#: cp/parser.c:13906
 #, gcc-internal-format
 msgid "static_assert without a message only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:14111
+#: cp/parser.c:14108
 #, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr ""
 
-#: cp/parser.c:14264
+#: cp/parser.c:14261
 #, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr ""
 
-#: cp/parser.c:14291
+#: cp/parser.c:14288
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr ""
 
-#: cp/parser.c:14295
+#: cp/parser.c:14292
 #, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr ""
 
-#: cp/parser.c:14379
+#: cp/parser.c:14376
 #, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr ""
 
-#: cp/parser.c:14406
+#: cp/parser.c:14403
 #, fuzzy, gcc-internal-format
 msgid "cannot expand initializer for member %qD"
 msgstr "прапушчан ініцыялізатар"
 
-#: cp/parser.c:14418 cp/pt.c:24255
+#: cp/parser.c:14415 cp/pt.c:24333
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr ""
 
-#: cp/parser.c:14430 cp/pt.c:24267
+#: cp/parser.c:14427 cp/pt.c:24345
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
 
-#: cp/parser.c:14482
+#: cp/parser.c:14479
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr ""
 
-#: cp/parser.c:14552
+#: cp/parser.c:14549
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:14927
+#: cp/parser.c:14924
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr ""
 
-#: cp/parser.c:14933
+#: cp/parser.c:14930
 #, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr ""
 
-#: cp/parser.c:14942
+#: cp/parser.c:14939
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr ""
 
-#: cp/parser.c:14948
+#: cp/parser.c:14945
 #, gcc-internal-format
 msgid "invalid encoding prefix in literal operator"
 msgstr ""
 
-#: cp/parser.c:14975
+#: cp/parser.c:14972
 #, fuzzy, gcc-internal-format
 #| msgid "unregistered operator %s"
 msgid "expected operator"
@@ -46245,364 +46288,364 @@
 msgstr "нераспазнаны аператар %s"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:15020
+#: cp/parser.c:15017
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr ""
 
-#: cp/parser.c:15190
+#: cp/parser.c:15187
 #, fuzzy, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/parser.c:15198
+#: cp/parser.c:15195
 #, fuzzy, gcc-internal-format
 msgid "cv-qualified type parameter"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/parser.c:15283
+#: cp/parser.c:15280
 #, gcc-internal-format
 msgid "variadic constraint introduced without %<...%>"
 msgstr ""
 
-#: cp/parser.c:15347
+#: cp/parser.c:15344
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/parser.c:15582 cp/parser.c:15668 cp/parser.c:21694
+#: cp/parser.c:15579 cp/parser.c:15665 cp/parser.c:21691
 #, fuzzy, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/parser.c:15586 cp/parser.c:15672
+#: cp/parser.c:15583 cp/parser.c:15669
 #, fuzzy, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/parser.c:15738
+#: cp/parser.c:15735
 #, gcc-internal-format
 msgid "expected template-id"
 msgstr ""
 
-#: cp/parser.c:15798
+#: cp/parser.c:15795
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr ""
 
-#: cp/parser.c:15802
+#: cp/parser.c:15799
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr ""
 
-#: cp/parser.c:15806
+#: cp/parser.c:15803
 #, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr ""
 
-#: cp/parser.c:15924
+#: cp/parser.c:15921
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr ""
 
 #. The name does not name a template.
-#: cp/parser.c:15992 cp/parser.c:16122 cp/parser.c:16337
+#: cp/parser.c:15989 cp/parser.c:16119 cp/parser.c:16334
 #, gcc-internal-format
 msgid "expected template-name"
 msgstr ""
 
 #. Explain what went wrong.
-#: cp/parser.c:16038
+#: cp/parser.c:16035
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr ""
 
-#: cp/parser.c:16040
+#: cp/parser.c:16037
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr ""
 
-#: cp/parser.c:16189
+#: cp/parser.c:16186
 #, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr ""
 
-#: cp/parser.c:16298 cp/parser.c:16316 cp/parser.c:16483
+#: cp/parser.c:16295 cp/parser.c:16313 cp/parser.c:16480
 #, gcc-internal-format
 msgid "expected template-argument"
 msgstr ""
 
-#: cp/parser.c:16458
+#: cp/parser.c:16455
 #, fuzzy, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/parser.c:16585
+#: cp/parser.c:16582
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr ""
 
-#: cp/parser.c:16589
+#: cp/parser.c:16586
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr ""
 
-#: cp/parser.c:16648
+#: cp/parser.c:16645
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr ""
 
-#: cp/parser.c:16869
+#: cp/parser.c:16866
 #, gcc-internal-format
 msgid "expected type specifier"
 msgstr ""
 
-#: cp/parser.c:17053
+#: cp/parser.c:17050
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:17059
+#: cp/parser.c:17056
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:17064
+#: cp/parser.c:17061
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -fconcepts"
 msgstr ""
 
-#: cp/parser.c:17209
+#: cp/parser.c:17206
 #, gcc-internal-format
 msgid "expected template-id for type"
 msgstr ""
 
-#: cp/parser.c:17278
+#: cp/parser.c:17275
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr ""
 
-#: cp/parser.c:17631
+#: cp/parser.c:17628
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr ""
 
-#: cp/parser.c:17854
+#: cp/parser.c:17851
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr ""
 
-#: cp/parser.c:17942
+#: cp/parser.c:17939
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr ""
 
-#: cp/parser.c:17946
+#: cp/parser.c:17943
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr ""
 
-#: cp/parser.c:17951
+#: cp/parser.c:17948
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr ""
 
-#: cp/parser.c:18085
+#: cp/parser.c:18082
 #, fuzzy, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/parser.c:18096
+#: cp/parser.c:18093
 #, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr ""
 
-#: cp/parser.c:18111
+#: cp/parser.c:18108
 #, gcc-internal-format
 msgid "unnamed scoped enum is not allowed"
 msgstr ""
 
-#: cp/parser.c:18166
+#: cp/parser.c:18163
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr ""
 
-#: cp/parser.c:18215
+#: cp/parser.c:18212
 #, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr ""
 
-#: cp/parser.c:18229
+#: cp/parser.c:18226
 #, gcc-internal-format
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr ""
 
-#: cp/parser.c:18241 cp/parser.c:23070
+#: cp/parser.c:18238 cp/parser.c:23067
 #, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr ""
 
-#: cp/parser.c:18246 cp/parser.c:23075
+#: cp/parser.c:18243 cp/parser.c:23072
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr ""
 
-#: cp/parser.c:18258 cp/parser.c:23089
+#: cp/parser.c:18255 cp/parser.c:23086
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr ""
 
-#: cp/parser.c:18282
+#: cp/parser.c:18279
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of `%#T'"
 msgid "multiple definition of %q#T"
 msgstr "папярэдняе вызначэньне `%#T'"
 
-#: cp/parser.c:18295
+#: cp/parser.c:18292
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids an empty source file"
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO C не дазваляе пусты ізыходны файл"
 
-#: cp/parser.c:18315
+#: cp/parser.c:18312
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:18318
+#: cp/parser.c:18315
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:18497
+#: cp/parser.c:18494
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function,"
 msgid "%qD is not a namespace-name"
 msgstr "`%D' - гэта ня функцыя,"
 
-#: cp/parser.c:18503
+#: cp/parser.c:18500
 #, gcc-internal-format
 msgid "expected namespace-name"
 msgstr ""
 
-#: cp/parser.c:18570
+#: cp/parser.c:18567
 #, gcc-internal-format
 msgid "nested namespace definitions only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:18578
+#: cp/parser.c:18575
 #, gcc-internal-format
 msgid "nested namespace name required"
 msgstr ""
 
-#: cp/parser.c:18583
+#: cp/parser.c:18580
 #, gcc-internal-format
 msgid "namespace name required"
 msgstr ""
 
-#: cp/parser.c:18587
+#: cp/parser.c:18584
 #, gcc-internal-format
 msgid "a nested namespace definition cannot have attributes"
 msgstr ""
 
-#: cp/parser.c:18590
+#: cp/parser.c:18587
 #, gcc-internal-format
 msgid "a nested namespace definition cannot be inline"
 msgstr ""
 
-#: cp/parser.c:18597
+#: cp/parser.c:18594
 #, gcc-internal-format
 msgid "namespace %qD entered"
 msgstr ""
 
-#: cp/parser.c:18652
+#: cp/parser.c:18649
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr ""
 
-#: cp/parser.c:18803
+#: cp/parser.c:18800
 #, gcc-internal-format
 msgid "pack expansion in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:18818
+#: cp/parser.c:18815
 #, fuzzy, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "\"%s\" - гэта не пачатак дэкларацыі"
 
-#: cp/parser.c:18865
+#: cp/parser.c:18862
 #, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:18875
+#: cp/parser.c:18872
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:18940
+#: cp/parser.c:18937
 #, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr ""
 
-#: cp/parser.c:19106
+#: cp/parser.c:19103
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:19493
+#: cp/parser.c:19490
 #, fuzzy, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: cp/parser.c:19504
+#: cp/parser.c:19501
 #, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr ""
 
-#: cp/parser.c:19508
+#: cp/parser.c:19505
 #, fuzzy, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "\"%s\" - гэта не пачатак дэкларацыі"
 
-#: cp/parser.c:19559
+#: cp/parser.c:19556
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
 #. Anything else is an error.
-#: cp/parser.c:19598 cp/parser.c:21906
+#: cp/parser.c:19595 cp/parser.c:21903
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "expected initializer"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/parser.c:19679
+#: cp/parser.c:19676
 #, fuzzy, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/parser.c:19713
+#: cp/parser.c:19710
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr ""
 
-#: cp/parser.c:19727
+#: cp/parser.c:19724
 #, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr ""
 
-#: cp/parser.c:20169
+#: cp/parser.c:20166
 #, fuzzy, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/parser.c:20295
+#: cp/parser.c:20292
 #, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr ""
 
-#: cp/parser.c:20299
+#: cp/parser.c:20296
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "\"%s\" мае незавершаны тып"
@@ -46611,17 +46654,17 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:20328
+#: cp/parser.c:20325
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr "нерэчаісны абвяшчальнік"
 
-#: cp/parser.c:20336
+#: cp/parser.c:20333
 #, fuzzy, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/parser.c:20338
+#: cp/parser.c:20335
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr ""
@@ -46628,389 +46671,389 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:20410
+#: cp/parser.c:20407
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid declaration"
 msgid "qualified-id in declaration"
 msgstr "Нерэчаіснае абвяшчэнне"
 
-#: cp/parser.c:20435
+#: cp/parser.c:20432
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "expected declarator"
 msgstr "пустое абвяшчэньне"
 
-#: cp/parser.c:20554
+#: cp/parser.c:20551
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr ""
 
-#: cp/parser.c:20556
+#: cp/parser.c:20553
 #, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr ""
 
-#: cp/parser.c:20577
+#: cp/parser.c:20574
 #, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr ""
 
-#: cp/parser.c:20638
+#: cp/parser.c:20635
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `volatile'"
 msgid "duplicate cv-qualifier"
 msgstr "паўтарэнне \"volatile\""
 
-#: cp/parser.c:20692
+#: cp/parser.c:20689
 #, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr ""
 
-#: cp/parser.c:20729
+#: cp/parser.c:20726
 #, gcc-internal-format
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr ""
 
-#: cp/parser.c:20787
+#: cp/parser.c:20784
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `volatile'"
 msgid "duplicate virt-specifier"
 msgstr "паўтарэнне \"volatile\""
 
-#: cp/parser.c:21025
+#: cp/parser.c:21022
 #, fuzzy, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr "невыкарыстаемы параметр \"%s\""
 
-#: cp/parser.c:21031 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2090
+#: cp/parser.c:21028 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2093
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `%T'"
 msgid "invalid use of %qT"
 msgstr "нерэчаіснае выкарыстаньне `%T'"
 
-#: cp/parser.c:21052
+#: cp/parser.c:21049
 #, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr ""
 
-#: cp/parser.c:21057
+#: cp/parser.c:21054
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/parser.c:21145
+#: cp/parser.c:21142
 #, gcc-internal-format
 msgid "expected type-specifier"
 msgstr ""
 
-#: cp/parser.c:21429
+#: cp/parser.c:21426
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr ""
 
-#: cp/parser.c:21504
+#: cp/parser.c:21501
 #, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr ""
 
-#: cp/parser.c:21678
+#: cp/parser.c:21675
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr ""
 
-#: cp/parser.c:21696
+#: cp/parser.c:21693
 #, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:21702
+#: cp/parser.c:21699
 #, fuzzy, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/parser.c:21704
+#: cp/parser.c:21701
 #, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:22131
+#: cp/parser.c:22128
 #, gcc-internal-format
 msgid "C++ designated initializers only available with -std=c++2a or -std=gnu++2a"
 msgstr ""
 
-#: cp/parser.c:22151
+#: cp/parser.c:22148
 #, gcc-internal-format
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr ""
 
-#: cp/parser.c:22189
+#: cp/parser.c:22186
 #, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr ""
 
-#: cp/parser.c:22203
+#: cp/parser.c:22200
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr ""
 
-#: cp/parser.c:22228
+#: cp/parser.c:22225
 #, gcc-internal-format
 msgid "%<...%> not allowed in designated initializer list"
 msgstr ""
 
-#: cp/parser.c:22266
+#: cp/parser.c:22263
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr ""
 
-#: cp/parser.c:22322 cp/parser.c:22448
+#: cp/parser.c:22319 cp/parser.c:22445
 #, gcc-internal-format
 msgid "expected class-name"
 msgstr ""
 
-#: cp/parser.c:22650
+#: cp/parser.c:22647
 #, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr ""
 
-#: cp/parser.c:22653
+#: cp/parser.c:22650
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr ""
 
-#: cp/parser.c:22656
+#: cp/parser.c:22653
 #, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr ""
 
-#: cp/parser.c:23012
+#: cp/parser.c:23009
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr ""
 
-#: cp/parser.c:23023
+#: cp/parser.c:23020
 #, fuzzy, gcc-internal-format
 #| msgid "cannot find file for class %s"
 msgid "cannot specify %<override%> for a class"
 msgstr "немагчыма знайсьці файл для кляса %s"
 
-#: cp/parser.c:23031
+#: cp/parser.c:23028
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:23038
+#: cp/parser.c:23035
 #, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr ""
 
-#: cp/parser.c:23050
+#: cp/parser.c:23047
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr ""
 
-#: cp/parser.c:23056
+#: cp/parser.c:23053
 #, fuzzy, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "Нерэчаіснае абвяшчэнне"
 
-#: cp/parser.c:23114
+#: cp/parser.c:23111
 #, fuzzy, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "ініцыялізацыя"
 
-#: cp/parser.c:23146
+#: cp/parser.c:23143
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr ""
 
-#: cp/parser.c:23182
+#: cp/parser.c:23179
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr ""
 
-#: cp/parser.c:23241
+#: cp/parser.c:23238
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of `%#T'"
 msgid "previous definition of %q#T"
 msgstr "папярэдняе вызначэньне `%#T'"
 
-#: cp/parser.c:23331 cp/parser.c:28499
+#: cp/parser.c:23328 cp/parser.c:28496
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr ""
 
-#: cp/parser.c:23355
+#: cp/parser.c:23352
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:23359
+#: cp/parser.c:23356
 #, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr ""
 
-#: cp/parser.c:23605
+#: cp/parser.c:23602
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr ""
 
-#: cp/parser.c:23623
+#: cp/parser.c:23620
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr ""
 
-#: cp/parser.c:23641
+#: cp/parser.c:23638
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:23738
+#: cp/parser.c:23735
 #, gcc-internal-format
 msgid "default member initializers for bit-fields only available with -std=c++2a or -std=gnu++2a"
 msgstr ""
 
-#: cp/parser.c:23745
+#: cp/parser.c:23742
 #, gcc-internal-format
 msgid "default member initializer for unnamed bit-field"
 msgstr ""
 
-#: cp/parser.c:23758
+#: cp/parser.c:23755
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr ""
 
-#: cp/parser.c:23903
+#: cp/parser.c:23900
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr ""
 
-#: cp/parser.c:23923
+#: cp/parser.c:23920
 #, gcc-internal-format
 msgid "extra %<;%> after in-class function definition"
 msgstr ""
 
-#: cp/parser.c:23970
+#: cp/parser.c:23967
 #, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr ""
 
-#: cp/parser.c:23984
+#: cp/parser.c:23981
 #, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr ""
 
-#: cp/parser.c:24058
+#: cp/parser.c:24055
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr ""
 
-#: cp/parser.c:24093
+#: cp/parser.c:24090
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr ""
 
-#: cp/parser.c:24223
+#: cp/parser.c:24220
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr ""
 
-#: cp/parser.c:24243
+#: cp/parser.c:24240
 #, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr ""
 
-#: cp/parser.c:24267
+#: cp/parser.c:24264
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr ""
 
-#: cp/parser.c:24270
+#: cp/parser.c:24267
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:24364 cp/parser.c:24442
+#: cp/parser.c:24361 cp/parser.c:24439
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/parser.c:24450
+#: cp/parser.c:24447
 #, fuzzy, gcc-internal-format
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/parser.c:24456
+#: cp/parser.c:24453
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr ""
 
-#: cp/parser.c:24500
+#: cp/parser.c:24497
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/parser.c:24539
+#: cp/parser.c:24536
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:24650
+#: cp/parser.c:24647
 #, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr ""
 
-#: cp/parser.c:25203
+#: cp/parser.c:25200
 #, gcc-internal-format
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr ""
 
-#: cp/parser.c:25217
+#: cp/parser.c:25214
 #, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr ""
 
-#: cp/parser.c:25301
+#: cp/parser.c:25298
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:25305
+#: cp/parser.c:25302
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:25342
+#: cp/parser.c:25339
 #, gcc-internal-format
 msgid "expected attribute before %<...%>"
 msgstr ""
 
-#: cp/parser.c:25403
+#: cp/parser.c:25400
 #, gcc-internal-format
 msgid "attribute using prefix only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:25721
+#: cp/parser.c:25718
 #, gcc-internal-format
 msgid "%<requires%> only available with -fconcepts"
 msgstr ""
 
-#: cp/parser.c:25753
+#: cp/parser.c:25750
 #, gcc-internal-format
 msgid "a requires expression cannot appear outside a template"
 msgstr ""
 
-#: cp/parser.c:26467
+#: cp/parser.c:26464
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:26472
+#: cp/parser.c:26469
 #, fuzzy, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "Нерэчаіснае абвяшчэнне"
 
-#: cp/parser.c:26476
+#: cp/parser.c:26473
 #, fuzzy, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "невыкарыстаемы параметр \"%s\""
@@ -47019,462 +47062,462 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:26483
+#: cp/parser.c:26480
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr ""
 
-#: cp/parser.c:26832
+#: cp/parser.c:26829
 #, fuzzy, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "-pipe не падтрымліваецца."
 
-#: cp/parser.c:26991
+#: cp/parser.c:26988
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr ""
 
-#: cp/parser.c:26996
+#: cp/parser.c:26993
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr ""
 
-#: cp/parser.c:27066
+#: cp/parser.c:27063
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "empty introduction-list"
 msgstr "пустое абвяшчэньне"
 
-#: cp/parser.c:27090
+#: cp/parser.c:27087
 #, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr ""
 
-#: cp/parser.c:27112
+#: cp/parser.c:27109
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr ""
 
-#: cp/parser.c:27121
+#: cp/parser.c:27118
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr ""
 
-#: cp/parser.c:27141
+#: cp/parser.c:27138
 #, fuzzy, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "ініцыялізацыя"
 
-#: cp/parser.c:27245
+#: cp/parser.c:27242
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "пустое абвяшчэнне"
 
-#: cp/parser.c:27296
+#: cp/parser.c:27293
 #, gcc-internal-format
 msgid "a class template declaration must not declare anything else"
 msgstr ""
 
-#: cp/parser.c:27342
+#: cp/parser.c:27339
 #, fuzzy, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "ініцыялізацыя"
 
-#: cp/parser.c:27650
+#: cp/parser.c:27647
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr ""
 
-#: cp/parser.c:27663
+#: cp/parser.c:27660
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr ""
 
-#: cp/parser.c:27958
+#: cp/parser.c:27955
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:28118
+#: cp/parser.c:28115
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr ""
 
-#: cp/parser.c:28133
+#: cp/parser.c:28130
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr ""
 
-#: cp/parser.c:28267
+#: cp/parser.c:28264
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not support `long long'"
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ не падтрымлівае \"long long\""
 
-#: cp/parser.c:28275
+#: cp/parser.c:28272
 #, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr ""
 
-#: cp/parser.c:28280
+#: cp/parser.c:28277
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `%s'"
 msgid "duplicate %qD"
 msgstr "паўтарэньне `%s'"
 
-#: cp/parser.c:28304
+#: cp/parser.c:28301
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `%s'"
 msgid "duplicate %qs"
 msgstr "паўтарэньне `%s'"
 
-#: cp/parser.c:28356
+#: cp/parser.c:28353
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr ""
 
-#: cp/parser.c:28359
+#: cp/parser.c:28356
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr ""
 
-#: cp/parser.c:28362
+#: cp/parser.c:28359
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr ""
 
-#: cp/parser.c:28368
+#: cp/parser.c:28365
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr ""
 
-#: cp/parser.c:28371
+#: cp/parser.c:28368
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr ""
 
-#: cp/parser.c:28374
+#: cp/parser.c:28371
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr ""
 
-#: cp/parser.c:28377
+#: cp/parser.c:28374
 #, fuzzy, gcc-internal-format
 #| msgid "unregistered operator %s"
 msgid "expected %<operator%>"
 msgstr "нераспазнаны аператар %s"
 
-#: cp/parser.c:28380
+#: cp/parser.c:28377
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr ""
 
-#: cp/parser.c:28383
+#: cp/parser.c:28380
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr ""
 
-#: cp/parser.c:28386
+#: cp/parser.c:28383
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr ""
 
-#: cp/parser.c:28389
+#: cp/parser.c:28386
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr ""
 
-#: cp/parser.c:28392
+#: cp/parser.c:28389
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr ""
 
-#: cp/parser.c:28395
+#: cp/parser.c:28392
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr ""
 
-#: cp/parser.c:28398
+#: cp/parser.c:28395
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr ""
 
-#: cp/parser.c:28401
+#: cp/parser.c:28398
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr ""
 
-#: cp/parser.c:28404
+#: cp/parser.c:28401
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr ""
 
-#: cp/parser.c:28407
+#: cp/parser.c:28404
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr ""
 
-#: cp/parser.c:28410
+#: cp/parser.c:28407
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr ""
 
-#: cp/parser.c:28413
+#: cp/parser.c:28410
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr ""
 
-#: cp/parser.c:28416
+#: cp/parser.c:28413
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.c:28419
+#: cp/parser.c:28416
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr ""
 
-#: cp/parser.c:28451
+#: cp/parser.c:28448
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr ""
 
-#: cp/parser.c:28463
+#: cp/parser.c:28460
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr ""
 
-#: cp/parser.c:28466
+#: cp/parser.c:28463
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr ""
 
-#: cp/parser.c:28469
+#: cp/parser.c:28466
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr ""
 
-#: cp/parser.c:28475
+#: cp/parser.c:28472
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr ""
 
-#: cp/parser.c:28502
+#: cp/parser.c:28499
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr ""
 
-#: cp/parser.c:28772
+#: cp/parser.c:28769
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr ""
 
-#: cp/parser.c:28777
+#: cp/parser.c:28774
 #, fuzzy, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/parser.c:28798
+#: cp/parser.c:28795
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr ""
 
-#: cp/parser.c:28819
+#: cp/parser.c:28816
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr ""
 
-#: cp/parser.c:29062
+#: cp/parser.c:29059
 #, fuzzy, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: cp/parser.c:29303 cp/parser.c:30620 cp/parser.c:30808
+#: cp/parser.c:29300 cp/parser.c:30617 cp/parser.c:30805
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr ""
 
-#: cp/parser.c:29372
+#: cp/parser.c:29369
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr ""
 
-#: cp/parser.c:29442
+#: cp/parser.c:29439
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:29473
+#: cp/parser.c:29470
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr ""
 
-#: cp/parser.c:29883
+#: cp/parser.c:29880
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr ""
 
-#: cp/parser.c:29958 cp/parser.c:29976
+#: cp/parser.c:29955 cp/parser.c:29973
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr ""
 
-#: cp/parser.c:29970 cp/parser.c:30035
+#: cp/parser.c:29967 cp/parser.c:30032
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr ""
 
-#: cp/parser.c:30078
+#: cp/parser.c:30075
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:30284 cp/parser.c:30291 cp/parser.c:30298
+#: cp/parser.c:30281 cp/parser.c:30288 cp/parser.c:30295
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mode for gen_tst_reg"
 msgid "invalid type for instance variable"
 msgstr "нерэчаісны рэжым для gen_tst_reg"
 
-#: cp/parser.c:30413
+#: cp/parser.c:30410
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr ""
 
-#: cp/parser.c:30585
+#: cp/parser.c:30582
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:30592
+#: cp/parser.c:30589
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: cp/parser.c:30867 cp/parser.c:30874 cp/parser.c:30881
+#: cp/parser.c:30864 cp/parser.c:30871 cp/parser.c:30878
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `restrict'"
 msgid "invalid type for property"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/parser.c:32011
+#: cp/parser.c:32008
 #, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr ""
 
-#: cp/parser.c:32724
+#: cp/parser.c:32721
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid reduction-identifier"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/parser.c:34911
+#: cp/parser.c:34908
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:35231 cp/pt.c:16392
+#: cp/parser.c:35228 cp/pt.c:16414
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr ""
 
-#: cp/parser.c:35316
+#: cp/parser.c:35313
 #, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr ""
 
-#: cp/parser.c:37521
+#: cp/parser.c:37518
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer clause"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/parser.c:37549
+#: cp/parser.c:37546
 #, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr ""
 
-#: cp/parser.c:37561
+#: cp/parser.c:37558
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:37662
+#: cp/parser.c:37659
 #, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr ""
 
-#: cp/parser.c:37682 cp/semantics.c:5405
+#: cp/parser.c:37679 cp/semantics.c:5408
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37687 cp/semantics.c:5414
+#: cp/parser.c:37684 cp/semantics.c:5417
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37690 cp/pt.c:12944 cp/semantics.c:5420
+#: cp/parser.c:37687 cp/pt.c:12966 cp/semantics.c:5423
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37693 cp/semantics.c:5426
+#: cp/parser.c:37690 cp/semantics.c:5429
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:38047
+#: cp/parser.c:38044
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:38057
+#: cp/parser.c:38054
 #, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr ""
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:38392
+#: cp/parser.c:38389
 #, gcc-internal-format
 msgid "atomic_cancel"
 msgstr ""
 
-#: cp/parser.c:38435 cp/semantics.c:8575
+#: cp/parser.c:38432 cp/semantics.c:8578
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:38437 cp/semantics.c:8577
+#: cp/parser.c:38434 cp/semantics.c:8580
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:38631
+#: cp/parser.c:38628
 #, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr ""
 
-#: cp/parser.c:38927
+#: cp/parser.c:38924
 #, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr ""
 
-#: cp/parser.c:38959
+#: cp/parser.c:38956
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr ""
 
-#: cp/parser.c:39039
+#: cp/parser.c:39036
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr ""
 
-#: cp/parser.c:39295
+#: cp/parser.c:39292
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:39351
+#: cp/parser.c:39348
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
@@ -47563,7 +47606,7 @@
 msgid "specialization of %qD after instantiation"
 msgstr ""
 
-#: cp/pt.c:1954 cp/semantics.c:5274
+#: cp/pt.c:1954 cp/semantics.c:5277
 #, gcc-internal-format
 msgid "%s %#qD"
 msgstr ""
@@ -47731,108 +47774,108 @@
 msgid "argument to __integer_pack must be between 0 and %d"
 msgstr ""
 
-#: cp/pt.c:3942
+#: cp/pt.c:3955
 #, gcc-internal-format
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr ""
 
-#: cp/pt.c:4010
+#: cp/pt.c:4023
 #, gcc-internal-format
 msgid "expansion pattern %qT contains no argument packs"
 msgstr ""
 
-#: cp/pt.c:4012
+#: cp/pt.c:4025
 #, gcc-internal-format
 msgid "expansion pattern %qE contains no argument packs"
 msgstr ""
 
-#: cp/pt.c:4063
+#: cp/pt.c:4077
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr ""
 
-#: cp/pt.c:4080 cp/pt.c:4835
+#: cp/pt.c:4094 cp/pt.c:4849
 #, gcc-internal-format
 msgid "        %qD"
 msgstr ""
 
-#: cp/pt.c:4082
+#: cp/pt.c:4096
 #, gcc-internal-format
 msgid "        <anonymous>"
 msgstr ""
 
-#: cp/pt.c:4208
+#: cp/pt.c:4222
 #, gcc-internal-format
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr ""
 
-#: cp/pt.c:4211
+#: cp/pt.c:4225
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template `%#D'"
 msgid "declaration of %q+#D shadows template parameter"
 msgstr "абвяшчэньне шаблёну `%#D'"
 
-#: cp/pt.c:4213
+#: cp/pt.c:4227
 #, fuzzy, gcc-internal-format
 msgid "template parameter %qD declared here"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: cp/pt.c:4771
+#: cp/pt.c:4785
 #, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr ""
 
-#: cp/pt.c:4830
+#: cp/pt.c:4844
 #, fuzzy, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/pt.c:4854
+#: cp/pt.c:4868
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:4858
+#: cp/pt.c:4872
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:4862 cp/pt.c:4873
+#: cp/pt.c:4876 cp/pt.c:4887
 #, gcc-internal-format
 msgid "primary template here"
 msgstr ""
 
-#: cp/pt.c:4870
+#: cp/pt.c:4884
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:4885
+#: cp/pt.c:4899
 #, gcc-internal-format
 msgid "partial specialization %qD is not more specialized than"
 msgstr ""
 
-#: cp/pt.c:4887
+#: cp/pt.c:4901
 #, gcc-internal-format
 msgid "primary template %qD"
 msgstr ""
 
-#: cp/pt.c:4934
+#: cp/pt.c:4948
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:4937
+#: cp/pt.c:4951
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:4958
+#: cp/pt.c:4972
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr ""
 
-#: cp/pt.c:5004
+#: cp/pt.c:5018
 #, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
@@ -47839,17 +47882,17 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/pt.c:5066
+#: cp/pt.c:5080
 #, gcc-internal-format
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr ""
 
-#: cp/pt.c:5070
+#: cp/pt.c:5084
 #, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr ""
 
-#: cp/pt.c:5247
+#: cp/pt.c:5261
 #, fuzzy, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "нехапае аргументаў у функцыі \"%s\""
@@ -47857,47 +47900,47 @@
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5269
+#: cp/pt.c:5283
 #, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr ""
 
-#: cp/pt.c:5305
+#: cp/pt.c:5319
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr ""
 
-#: cp/pt.c:5308
+#: cp/pt.c:5322
 #, gcc-internal-format
 msgid "default template arguments may not be used in template friend declarations"
 msgstr ""
 
-#: cp/pt.c:5311
+#: cp/pt.c:5325
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/pt.c:5314
+#: cp/pt.c:5328
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr ""
 
-#: cp/pt.c:5317 cp/pt.c:5375
+#: cp/pt.c:5331 cp/pt.c:5389
 #, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr ""
 
-#: cp/pt.c:5489
+#: cp/pt.c:5503
 #, fuzzy, gcc-internal-format
 msgid "template %qD declared"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: cp/pt.c:5496
+#: cp/pt.c:5510
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr ""
 
-#: cp/pt.c:5504
+#: cp/pt.c:5518
 #, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr ""
@@ -47907,58 +47950,58 @@
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5526
+#: cp/pt.c:5540
 #, fuzzy, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.c:5669
+#: cp/pt.c:5683
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template `%#D'"
 msgid "template definition of non-template %q#D"
 msgstr "абвяшчэньне шаблёну `%#D'"
 
-#: cp/pt.c:5712
+#: cp/pt.c:5726
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr ""
 
-#: cp/pt.c:5726
+#: cp/pt.c:5740
 #, fuzzy, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "невыкарыстаемы параметр \"%s\""
 
-#: cp/pt.c:5729
+#: cp/pt.c:5743
 #, fuzzy, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "невыкарыстаемы параметр \"%s\""
 
-#: cp/pt.c:5731
+#: cp/pt.c:5745
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr ""
 
-#: cp/pt.c:5752
+#: cp/pt.c:5766
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr ""
 
-#: cp/pt.c:5755
+#: cp/pt.c:5769
 #, gcc-internal-format
 msgid "use %<template<>%> for an explicit specialization"
 msgstr ""
 
-#: cp/pt.c:5882
+#: cp/pt.c:5896
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/pt.c:5895
+#: cp/pt.c:5909
 #, fuzzy, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "пустое абвяшчэнне"
 
-#: cp/pt.c:5906
+#: cp/pt.c:5920
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
@@ -47965,7 +48008,7 @@
 msgstr[0] "нявернае выкарыстанне \"restict\""
 msgstr[1] "нявернае выкарыстанне \"restict\""
 
-#: cp/pt.c:5910
+#: cp/pt.c:5924
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
@@ -47972,12 +48015,12 @@
 msgstr[0] "няма папярэдняга аб'яўлення для \"%s\""
 msgstr[1] "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/pt.c:5947
+#: cp/pt.c:5961
 #, fuzzy, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "невыкарыстаемы параметр \"%s\""
 
-#: cp/pt.c:5948
+#: cp/pt.c:5962
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr ""
@@ -47986,118 +48029,118 @@
 #.
 #. A template-parameter may not be given default arguments
 #. by two different declarations in the same scope.
-#: cp/pt.c:5958
+#: cp/pt.c:5972
 #, fuzzy, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: cp/pt.c:5960
+#: cp/pt.c:5974
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition here"
 msgid "original definition appeared here"
 msgstr "папярэдняе вызначэньне"
 
-#: cp/pt.c:5988
+#: cp/pt.c:6002
 #, gcc-internal-format
 msgid "redeclaration %q#D with different constraints"
 msgstr ""
 
-#: cp/pt.c:5991
+#: cp/pt.c:6005
 #, fuzzy, gcc-internal-format
 msgid "original declaration appeared here"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/pt.c:6250 cp/pt.c:6318
+#: cp/pt.c:6264 cp/pt.c:6332
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/pt.c:6253
+#: cp/pt.c:6267
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6256
+#: cp/pt.c:6270
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6268
+#: cp/pt.c:6282
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr ""
 
-#: cp/pt.c:6272
+#: cp/pt.c:6286
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr ""
 
-#: cp/pt.c:6321
+#: cp/pt.c:6335
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr ""
 
-#: cp/pt.c:6323
+#: cp/pt.c:6337
 #, gcc-internal-format
 msgid "because it is a member of %qT"
 msgstr ""
 
-#: cp/pt.c:6383
+#: cp/pt.c:6397
 #, fuzzy, gcc-internal-format
 msgid "  couldn't deduce template parameter %qD"
 msgstr "невыкарыстаемы параметр \"%s\""
 
-#: cp/pt.c:6392
+#: cp/pt.c:6406
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.c:6401
+#: cp/pt.c:6415
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:6410
+#: cp/pt.c:6424
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr ""
 
-#: cp/pt.c:6421
+#: cp/pt.c:6435
 #, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr ""
 
-#: cp/pt.c:6431
+#: cp/pt.c:6445
 #, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr ""
 
-#: cp/pt.c:6440
+#: cp/pt.c:6454
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:6452
+#: cp/pt.c:6466
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.c:6456
+#: cp/pt.c:6470
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.c:6467
+#: cp/pt.c:6481
 #, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6478
+#: cp/pt.c:6492
 #, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6490
+#: cp/pt.c:6504
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
@@ -48104,294 +48147,294 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/pt.c:6521
+#: cp/pt.c:6535
 #, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr ""
 
-#: cp/pt.c:6534
+#: cp/pt.c:6548
 #, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr ""
 
-#: cp/pt.c:6538
+#: cp/pt.c:6552
 #, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr ""
 
-#: cp/pt.c:6549
+#: cp/pt.c:6563
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.c:6559
+#: cp/pt.c:6573
 #, gcc-internal-format
 msgid "  can't deduce a template for %qT from non-template type %qT"
 msgstr ""
 
-#: cp/pt.c:6569
+#: cp/pt.c:6583
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/pt.c:6609
+#: cp/pt.c:6623
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr ""
 
-#: cp/pt.c:6758
+#: cp/pt.c:6772
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for `%#D' has type `%T'"
 msgid "in template argument for type %qT"
 msgstr "звычайны аргумэнт для `%#D' мае тып `%T'"
 
-#: cp/pt.c:6772
+#: cp/pt.c:6786
 #, gcc-internal-format
 msgid "template argument %qE for type %qT not a constant integer"
 msgstr ""
 
-#: cp/pt.c:6833
+#: cp/pt.c:6847
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr ""
 
-#: cp/pt.c:6841
+#: cp/pt.c:6855
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr ""
 
-#: cp/pt.c:6857
+#: cp/pt.c:6871
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr ""
 
-#: cp/pt.c:6864
+#: cp/pt.c:6878
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr ""
 
-#: cp/pt.c:6873
+#: cp/pt.c:6887
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr ""
 
-#: cp/pt.c:6888
+#: cp/pt.c:6902
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6897
+#: cp/pt.c:6911
 #, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6904
+#: cp/pt.c:6918
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr ""
 
-#: cp/pt.c:6933
+#: cp/pt.c:6947
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr ""
 
-#: cp/pt.c:6941
+#: cp/pt.c:6955
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr ""
 
-#: cp/pt.c:6959
+#: cp/pt.c:6973
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr ""
 
-#: cp/pt.c:6975
+#: cp/pt.c:6989
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an object with linkage"
 msgstr ""
 
-#: cp/pt.c:6986
+#: cp/pt.c:7000
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because object %qD does not have linkage"
 msgstr ""
 
-#: cp/pt.c:7036
+#: cp/pt.c:7050
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr ""
 
-#: cp/pt.c:7038
+#: cp/pt.c:7052
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr ""
 
-#: cp/pt.c:7092
+#: cp/pt.c:7106
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr ""
 
-#: cp/pt.c:7654
+#: cp/pt.c:7668
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr ""
 
-#: cp/pt.c:7670
+#: cp/pt.c:7684
 #, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr ""
 
-#: cp/pt.c:7805
+#: cp/pt.c:7819
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr ""
 
-#: cp/pt.c:7834
+#: cp/pt.c:7848
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `restrict'"
 msgid "invalid use of destructor %qE as a type"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/pt.c:7839
+#: cp/pt.c:7853
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr ""
 
-#: cp/pt.c:7855 cp/pt.c:7877 cp/pt.c:7931
+#: cp/pt.c:7869 cp/pt.c:7891 cp/pt.c:7945
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.c:7860
+#: cp/pt.c:7874
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr ""
 
-#: cp/pt.c:7865
+#: cp/pt.c:7879
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr ""
 
-#: cp/pt.c:7868
+#: cp/pt.c:7882
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr ""
 
-#: cp/pt.c:7882
+#: cp/pt.c:7896
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr ""
 
-#: cp/pt.c:7885
+#: cp/pt.c:7899
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr ""
 
-#: cp/pt.c:7935
+#: cp/pt.c:7949
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr ""
 
-#: cp/pt.c:7949
+#: cp/pt.c:7963
 #, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.c:7952
+#: cp/pt.c:7966
 #, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr ""
 
-#: cp/pt.c:8012
+#: cp/pt.c:8026
 #, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr ""
 
-#: cp/pt.c:8149 cp/pt.c:8465
+#: cp/pt.c:8163 cp/pt.c:8479
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/pt.c:8164 cp/pt.c:8298
+#: cp/pt.c:8178 cp/pt.c:8312
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr ""
 
-#: cp/pt.c:8294
+#: cp/pt.c:8308
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr ""
 
-#: cp/pt.c:8303
+#: cp/pt.c:8317
 #, fuzzy, gcc-internal-format
 msgid "provided for %qD"
 msgstr "дэструктару неабходны \"%#D\""
 
-#: cp/pt.c:8328
+#: cp/pt.c:8342
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:8332
+#: cp/pt.c:8346
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr ""
 
-#: cp/pt.c:8431
+#: cp/pt.c:8445
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:9054
+#: cp/pt.c:9068
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/pt.c:9221
+#: cp/pt.c:9235
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr ""
 
-#: cp/pt.c:9223
+#: cp/pt.c:9237
 #, fuzzy, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "пустое абвяшчэнне"
 
-#: cp/pt.c:9346
+#: cp/pt.c:9360
 #, gcc-internal-format
 msgid "template constraint failure"
 msgstr ""
 
-#: cp/pt.c:9697
+#: cp/pt.c:9718
 #, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr ""
 
-#: cp/pt.c:10125
+#: cp/pt.c:10148
 #, gcc-internal-format, gfc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:11202
+#: cp/pt.c:11225
 #, gcc-internal-format
 msgid "flexible array member %qD in union"
 msgstr ""
 
-#: cp/pt.c:11691
+#: cp/pt.c:11713
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:12160
+#: cp/pt.c:12182
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr ""
 
-#: cp/pt.c:12163
+#: cp/pt.c:12185
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr ""
 
-#: cp/pt.c:12747
+#: cp/pt.c:12769
 #, fuzzy, gcc-internal-format
 msgid "  when instantiating default argument for call to %qD"
 msgstr "нехапае аргументаў у функцыі \"%s\""
@@ -48409,280 +48452,280 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:13708
+#: cp/pt.c:13730
 #, fuzzy, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: cp/pt.c:13881
+#: cp/pt.c:13903
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter type `%T'"
 msgid "invalid parameter type %qT"
 msgstr "нерэчаісны тып парамэтра `%T'"
 
-#: cp/pt.c:13883
+#: cp/pt.c:13905
 #, fuzzy, gcc-internal-format
 #| msgid "in declaration `%D'"
 msgid "in declaration %q+D"
 msgstr "у абвяшчэньні  `%D'"
 
-#: cp/pt.c:14001
+#: cp/pt.c:14023
 #, fuzzy, gcc-internal-format
 #| msgid "function does not return string type"
 msgid "function returning an array"
 msgstr "функцыя не вяртае тып string"
 
-#: cp/pt.c:14003
+#: cp/pt.c:14025
 #, fuzzy, gcc-internal-format
 msgid "function returning a function"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/pt.c:14043
+#: cp/pt.c:14065
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr ""
 
-#: cp/pt.c:14637
+#: cp/pt.c:14659
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr ""
 
-#: cp/pt.c:14639
+#: cp/pt.c:14661
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/pt.c:14641
+#: cp/pt.c:14663
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr ""
 
-#: cp/pt.c:14654
+#: cp/pt.c:14676
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: cp/pt.c:14657
+#: cp/pt.c:14679
 #, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr ""
 
-#: cp/pt.c:14705
+#: cp/pt.c:14727
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr ""
 
-#: cp/pt.c:14711
+#: cp/pt.c:14733
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr ""
 
-#: cp/pt.c:14717
+#: cp/pt.c:14739
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr ""
 
-#: cp/pt.c:14783
+#: cp/pt.c:14805
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr ""
 
-#: cp/pt.c:14816
+#: cp/pt.c:14838
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr ""
 
-#: cp/pt.c:14853
+#: cp/pt.c:14875
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr ""
 
-#: cp/pt.c:14861
+#: cp/pt.c:14883
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr ""
 
-#: cp/pt.c:14925
+#: cp/pt.c:14947
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.c:15000
+#: cp/pt.c:15022
 #, fuzzy, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/pt.c:15178
+#: cp/pt.c:15200
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/pt.c:15193
+#: cp/pt.c:15215
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr ""
 
-#: cp/pt.c:15195
+#: cp/pt.c:15217
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr ""
 
-#: cp/pt.c:15394
+#: cp/pt.c:15416
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr ""
 
-#: cp/pt.c:15883 cp/pt.c:17386
+#: cp/pt.c:15905 cp/pt.c:17408
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr ""
 
-#: cp/pt.c:15887 cp/pt.c:17390
+#: cp/pt.c:15909 cp/pt.c:17412
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr ""
 
-#: cp/pt.c:18334
+#: cp/pt.c:18371
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:18362
+#: cp/pt.c:18399
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:18367
+#: cp/pt.c:18404
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.c:18370
+#: cp/pt.c:18407
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr ""
 
-#: cp/pt.c:18375
+#: cp/pt.c:18412
 #, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr ""
 
-#: cp/pt.c:18712
+#: cp/pt.c:18752
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/pt.c:18715
+#: cp/pt.c:18755
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/pt.c:19026
+#: cp/pt.c:19066
 #, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr ""
 
-#: cp/pt.c:19028
+#: cp/pt.c:19068
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for `%#D' has type `%T'"
 msgid "template argument for %qD uses local type %qT"
 msgstr "звычайны аргумэнт для `%#D' мае тып `%T'"
 
-#: cp/pt.c:19038
+#: cp/pt.c:19078
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr ""
 
-#: cp/pt.c:19053
+#: cp/pt.c:19093
 #, fuzzy, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: cp/pt.c:19071
+#: cp/pt.c:19111
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr ""
 
-#: cp/pt.c:22972
+#: cp/pt.c:23050
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.c:22974
+#: cp/pt.c:23052
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.c:22980
+#: cp/pt.c:23058
 msgid "%s %#qS"
 msgstr ""
 
-#: cp/pt.c:23004 cp/pt.c:23091
+#: cp/pt.c:23082 cp/pt.c:23169
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.c:23023
+#: cp/pt.c:23101
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr ""
 
-#: cp/pt.c:23029 cp/pt.c:23086
+#: cp/pt.c:23107 cp/pt.c:23164
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr ""
 
-#: cp/pt.c:23034
+#: cp/pt.c:23112
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr ""
 
-#: cp/pt.c:23042
+#: cp/pt.c:23120
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.c:23078
+#: cp/pt.c:23156
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.c:23101 cp/pt.c:23187
+#: cp/pt.c:23179 cp/pt.c:23265
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr ""
 
-#: cp/pt.c:23106 cp/pt.c:23204
+#: cp/pt.c:23184 cp/pt.c:23282
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr ""
 
-#: cp/pt.c:23163
+#: cp/pt.c:23241
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.c:23165
+#: cp/pt.c:23243
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.c:23174
+#: cp/pt.c:23252
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr ""
 
-#: cp/pt.c:23192
+#: cp/pt.c:23270
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr ""
 
-#: cp/pt.c:23238
+#: cp/pt.c:23316
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.c:23536
+#: cp/pt.c:23614
 #, gcc-internal-format
 msgid "exception specification of %qD depends on itself"
 msgstr ""
@@ -48694,107 +48737,107 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:23842
+#: cp/pt.c:23920
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr ""
 
-#: cp/pt.c:24043
+#: cp/pt.c:24121
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:24418
+#: cp/pt.c:24496
 #, fuzzy, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/pt.c:24420
+#: cp/pt.c:24498
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/pt.c:25723
+#: cp/pt.c:25802
 #, fuzzy, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "\"%s\" - гэта не пачатак дэкларацыі"
 
-#: cp/pt.c:25961
+#: cp/pt.c:26040
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/pt.c:26440
+#: cp/pt.c:26519
 #, gcc-internal-format
 msgid "non-class template %qT used without template arguments"
 msgstr ""
 
-#: cp/pt.c:26586
+#: cp/pt.c:26665
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:26593
+#: cp/pt.c:26672
 #, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr ""
 
-#: cp/pt.c:26607
+#: cp/pt.c:26686
 #, fuzzy, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/pt.c:26614
+#: cp/pt.c:26693
 #, gcc-internal-format
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr ""
 
-#: cp/pt.c:26676
+#: cp/pt.c:26755
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:26679
+#: cp/pt.c:26758
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:26711
+#: cp/pt.c:26790
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/pt.c:26746
+#: cp/pt.c:26825
 #, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr ""
 
-#: cp/pt.c:26748
+#: cp/pt.c:26827
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr ""
 
-#: cp/pt.c:26781
+#: cp/pt.c:26860
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:26785
+#: cp/pt.c:26864
 #, gcc-internal-format
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.c:26789
+#: cp/pt.c:26868
 #, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.c:26793
+#: cp/pt.c:26872
 #, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.c:26912
+#: cp/pt.c:26991
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr "нявернае выкарыстанне \"restict\""
@@ -48850,79 +48893,79 @@
 msgid "cannot dynamic_cast %qE (of type %q#T) to type %q#T (%s)"
 msgstr ""
 
-#: cp/search.c:240
+#: cp/search.c:243
 #, gcc-internal-format
 msgid "%qT is an ambiguous base of %qT"
 msgstr ""
 
-#: cp/search.c:256
+#: cp/search.c:259
 #, gcc-internal-format
 msgid "%qT is an inaccessible base of %qT"
 msgstr ""
 
-#: cp/search.c:1905
+#: cp/search.c:1908
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter type `%T'"
 msgid "invalid covariant return type for %q#D"
 msgstr "нерэчаісны тып парамэтра `%T'"
 
-#: cp/search.c:1907 cp/search.c:1922 cp/search.c:1928 cp/search.c:1957
+#: cp/search.c:1910 cp/search.c:1925 cp/search.c:1931 cp/search.c:1960
 #, gcc-internal-format
 msgid "overridden function is %q#D"
 msgstr ""
 
-#: cp/search.c:1920
+#: cp/search.c:1923
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter type `%T'"
 msgid "invalid covariant return type for %q+#D"
 msgstr "нерэчаісны тып парамэтра `%T'"
 
-#: cp/search.c:1926
+#: cp/search.c:1929
 #, gcc-internal-format
 msgid "conflicting return type specified for %q+#D"
 msgstr ""
 
-#: cp/search.c:1942
+#: cp/search.c:1945
 #, gcc-internal-format
 msgid "looser throw specifier for %q+#F"
 msgstr ""
 
-#: cp/search.c:1944
+#: cp/search.c:1947
 #, gcc-internal-format
 msgid "overridden function is %q#F"
 msgstr ""
 
-#: cp/search.c:1955
+#: cp/search.c:1958
 #, gcc-internal-format
 msgid "conflicting type attributes specified for %q+#D"
 msgstr ""
 
-#: cp/search.c:1972
+#: cp/search.c:1975
 #, gcc-internal-format
 msgid "%qD declared %<transaction_safe_dynamic%>"
 msgstr ""
 
-#: cp/search.c:1974
+#: cp/search.c:1977
 #, gcc-internal-format
 msgid "overriding %qD declared %<transaction_safe%>"
 msgstr ""
 
-#: cp/search.c:1981
+#: cp/search.c:1984
 #, gcc-internal-format
 msgid "deleted function %q+D overriding non-deleted function"
 msgstr ""
 
-#: cp/search.c:1984 cp/search.c:1992 cp/search.c:2000
+#: cp/search.c:1987 cp/search.c:1995 cp/search.c:2003
 #, gcc-internal-format
 msgid "overridden function is %qD"
 msgstr ""
 
-#: cp/search.c:1989
+#: cp/search.c:1992
 #, gcc-internal-format
 msgid "non-deleted function %q+D overriding deleted function"
 msgstr ""
 
-#: cp/search.c:1998
+#: cp/search.c:2001
 #, gcc-internal-format
 msgid "virtual function %q+D overriding final function"
 msgstr ""
@@ -48929,12 +48972,12 @@
 
 #. A static member function cannot match an inherited
 #. virtual member function.
-#: cp/search.c:2082
+#: cp/search.c:2085
 #, fuzzy, gcc-internal-format
 msgid "%q+#D cannot be declared"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/search.c:2083
+#: cp/search.c:2086
 #, gcc-internal-format
 msgid "  since %q+#D declared in base class"
 msgstr ""
@@ -48974,576 +49017,592 @@
 msgid "invalid use of member %qD in static member function"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/semantics.c:2153
+#: cp/semantics.c:2156
 #, gcc-internal-format
 msgid "a statement expression is an insufficient context for overload resolution"
 msgstr ""
 
-#: cp/semantics.c:2540
+#: cp/semantics.c:2543
 #, fuzzy, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr "памер \"%s\" больш чам %d байт"
 
-#: cp/semantics.c:2622
+#: cp/semantics.c:2625
 #, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr ""
 
-#: cp/semantics.c:2624
+#: cp/semantics.c:2627
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/semantics.c:2626
+#: cp/semantics.c:2629
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/semantics.c:2648
+#: cp/semantics.c:2651
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr ""
 
-#: cp/semantics.c:2656 cp/typeck.c:2604
+#: cp/semantics.c:2659 cp/typeck.c:2604
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/semantics.c:2678
+#: cp/semantics.c:2681
 #, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr ""
 
-#: cp/semantics.c:2751
+#: cp/semantics.c:2754
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr ""
 
-#: cp/semantics.c:2892
+#: cp/semantics.c:2895
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr ""
 
-#: cp/semantics.c:2942
+#: cp/semantics.c:2945
 #, fuzzy, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/semantics.c:2945
+#: cp/semantics.c:2948
 #, fuzzy, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/semantics.c:2962
+#: cp/semantics.c:2965
 #, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr ""
 
-#: cp/semantics.c:2993
+#: cp/semantics.c:2996
 #, fuzzy, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/semantics.c:3263
+#: cp/semantics.c:3266
 #, fuzzy, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "Нерэчаісная спецыфікацыя! Памылка ў cc."
 
-#: cp/semantics.c:3423
+#: cp/semantics.c:3426
 #, gcc-internal-format
 msgid "cannot capture member %qD of anonymous union"
 msgstr ""
 
-#: cp/semantics.c:3443 cp/semantics.c:9269
+#: cp/semantics.c:3446 cp/semantics.c:9272
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr ""
 
-#: cp/semantics.c:3448
+#: cp/semantics.c:3451
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.c:3450
+#: cp/semantics.c:3453
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.c:3462
+#: cp/semantics.c:3465
 #, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr ""
 
-#: cp/semantics.c:3464
+#: cp/semantics.c:3467
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr ""
 
-#: cp/semantics.c:3596
+#: cp/semantics.c:3599
 #, gcc-internal-format
 msgid "use of parameter outside function body"
 msgstr ""
 
-#: cp/semantics.c:3606
+#: cp/semantics.c:3609
 #, fuzzy, gcc-internal-format
 msgid "missing template arguments"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/semantics.c:3633
+#: cp/semantics.c:3636
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr ""
 
-#: cp/semantics.c:3664
+#: cp/semantics.c:3667
 #, gcc-internal-format
 msgid "use of namespace %qD as expression"
 msgstr ""
 
-#: cp/semantics.c:3669
+#: cp/semantics.c:3672
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr ""
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:3675
+#: cp/semantics.c:3678
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr ""
 
-#: cp/semantics.c:3702
+#: cp/semantics.c:3705
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/semantics.c:3841
+#: cp/semantics.c:3844
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr ""
 
-#: cp/semantics.c:3870
+#: cp/semantics.c:3873
 #, fuzzy, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr "\"%s\" мае незавершаны тып"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4009
+#: cp/semantics.c:4012
 #, gcc-internal-format
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr ""
 
-#: cp/semantics.c:4038
+#: cp/semantics.c:4041
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr ""
 
-#: cp/semantics.c:4052
+#: cp/semantics.c:4055
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr ""
 
-#: cp/semantics.c:4056
+#: cp/semantics.c:4059
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function"
 msgstr ""
 
-#: cp/semantics.c:4061
+#: cp/semantics.c:4064
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr ""
 
-#: cp/semantics.c:4072
+#: cp/semantics.c:4075
 #, gcc-internal-format
 msgid "offsetof within non-standard-layout type %qT is conditionally-supported"
 msgstr ""
 
-#: cp/semantics.c:4583 cp/semantics.c:6069 cp/semantics.c:6140
-#: cp/semantics.c:6183 cp/semantics.c:6533 cp/semantics.c:6632
-#: cp/semantics.c:6775
+#: cp/semantics.c:4586 cp/semantics.c:6072 cp/semantics.c:6143
+#: cp/semantics.c:6186 cp/semantics.c:6536 cp/semantics.c:6635
+#: cp/semantics.c:6778
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5271
+#: cp/semantics.c:5274
 #, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr ""
 
-#: cp/semantics.c:5544
+#: cp/semantics.c:5547
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: cp/semantics.c:5592
+#: cp/semantics.c:5595
 #, gcc-internal-format
 msgid "%qE has const type for %<reduction%>"
 msgstr ""
 
-#: cp/semantics.c:5707
+#: cp/semantics.c:5710
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:5941
+#: cp/semantics.c:5944
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5955
+#: cp/semantics.c:5958
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5977
+#: cp/semantics.c:5980
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6080
+#: cp/semantics.c:6083
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6152
+#: cp/semantics.c:6155
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr ""
 
-#: cp/semantics.c:6195
+#: cp/semantics.c:6198
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr ""
 
-#: cp/semantics.c:6240
+#: cp/semantics.c:6243
 #, gcc-internal-format
 msgid "%<gang%> static expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6254
+#: cp/semantics.c:6257
 #, gcc-internal-format
 msgid "%<gang%> static value must be positive"
 msgstr ""
 
-#: cp/semantics.c:6288
+#: cp/semantics.c:6291
 #, gcc-internal-format
 msgid "%<gang%> num expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6291
+#: cp/semantics.c:6294
 #, gcc-internal-format
 msgid "%<vector%> length expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6295
+#: cp/semantics.c:6298
 #, gcc-internal-format
 msgid "%<worker%> num expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6317
+#: cp/semantics.c:6320
 #, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr ""
 
-#: cp/semantics.c:6321
+#: cp/semantics.c:6324
 #, gcc-internal-format
 msgid "%<vector%> length value must be positive"
 msgstr ""
 
-#: cp/semantics.c:6326
+#: cp/semantics.c:6329
 #, gcc-internal-format
 msgid "%<worker%> num value must be positive"
 msgstr ""
 
-#: cp/semantics.c:6376
+#: cp/semantics.c:6379
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6406
+#: cp/semantics.c:6409
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6419
+#: cp/semantics.c:6422
 #, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr ""
 
-#: cp/semantics.c:6438
+#: cp/semantics.c:6441
 #, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6466
+#: cp/semantics.c:6469
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6495
+#: cp/semantics.c:6498
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr ""
 
-#: cp/semantics.c:6516
+#: cp/semantics.c:6519
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6543
+#: cp/semantics.c:6546
 #, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr ""
 
-#: cp/semantics.c:6557
+#: cp/semantics.c:6560
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:6563
+#: cp/semantics.c:6566
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: cp/semantics.c:6576
+#: cp/semantics.c:6579
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6625
+#: cp/semantics.c:6628
 #, gcc-internal-format
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr ""
 
-#: cp/semantics.c:6910
+#: cp/semantics.c:6913
 #, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6914
+#: cp/semantics.c:6917
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6979
+#: cp/semantics.c:6982
 #, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7008
+#: cp/semantics.c:7011
 #, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7037
+#: cp/semantics.c:7040
 #, gcc-internal-format
 msgid "%<num_tasks%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7066
+#: cp/semantics.c:7069
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:7105
+#: cp/semantics.c:7108
 #, gcc-internal-format
 msgid "%<tile%> argument needs integral type"
 msgstr ""
 
-#: cp/semantics.c:7524
+#: cp/semantics.c:7527
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.c:7538
+#: cp/semantics.c:7541
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr ""
 
-#: cp/semantics.c:7743
+#: cp/semantics.c:7746
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.c:8171
+#: cp/semantics.c:8174
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.c:8398 cp/semantics.c:8408
+#: cp/semantics.c:8401 cp/semantics.c:8411
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.c:8702
+#: cp/semantics.c:8705
 #, gcc-internal-format
 msgid "static assertion failed"
 msgstr ""
 
-#: cp/semantics.c:8704
+#: cp/semantics.c:8707
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr ""
 
-#: cp/semantics.c:8709
+#: cp/semantics.c:8712
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr ""
 
-#: cp/semantics.c:8739
+#: cp/semantics.c:8742
 #, gcc-internal-format
 msgid "argument to decltype must be an expression"
 msgstr ""
 
-#: cp/semantics.c:8767
+#: cp/semantics.c:8770
 #, gcc-internal-format
 msgid "decltype cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/semantics.c:9308
+#: cp/semantics.c:9311
 #, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.c:9361
+#: cp/semantics.c:9364
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.c:9363
+#: cp/semantics.c:9366
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:9381
+#: cp/semantics.c:9384
 #, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr ""
 
-#: cp/tree.c:1276
+#: cp/tree.c:1295
 #, gcc-internal-format
 msgid "%qV qualifiers cannot be applied to %qT"
 msgstr ""
 
-#: cp/tree.c:1788
+#: cp/tree.c:1807
 #, gcc-internal-format
 msgid "lambda-expression in a constant expression"
 msgstr ""
 
-#: cp/tree.c:1792
+#: cp/tree.c:1811
 #, gcc-internal-format
 msgid "statement-expression in a constant expression"
 msgstr ""
 
-#: cp/tree.c:4050
+#: cp/tree.c:4083
 #, gcc-internal-format
-msgid "the calling convention for %qT changes in -fabi-version=12 (GCC 8)"
+msgid "-fabi-version=13 (GCC 8.2) fixes the calling convention for %qT, which was accidentally changed in 8.1"
 msgstr ""
 
-#: cp/tree.c:4055
+#: cp/tree.c:4087
 #, gcc-internal-format
+msgid "-fabi-version=12 (GCC 8.1) accidentally changes the calling convention for %qT"
+msgstr ""
+
+#: cp/tree.c:4090
+#, fuzzy, gcc-internal-format
+#| msgid "called from here"
+msgid " declared here"
+msgstr "выклікана адсюль"
+
+#: cp/tree.c:4094
+#, gcc-internal-format
+msgid "the calling convention for %qT changes in -fabi-version=13 (GCC 8.2)"
+msgstr ""
+
+#: cp/tree.c:4096
+#, gcc-internal-format
 msgid " because all of its copy and move constructors are deleted"
 msgstr ""
 
-#: cp/tree.c:4416
+#: cp/tree.c:4464
 #, gcc-internal-format
 msgid "%qE attribute applied to %qD with void return type"
 msgstr ""
 
-#: cp/tree.c:4423
+#: cp/tree.c:4471
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/tree.c:4475
+#: cp/tree.c:4523
 #, gcc-internal-format
 msgid "requested init_priority is not an integer constant"
 msgstr ""
 
-#: cp/tree.c:4497
+#: cp/tree.c:4545
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr ""
 
-#: cp/tree.c:4505
+#: cp/tree.c:4553
 #, gcc-internal-format
 msgid "requested init_priority is out of range"
 msgstr ""
 
-#: cp/tree.c:4515
+#: cp/tree.c:4563
 #, gcc-internal-format
 msgid "requested init_priority is reserved for internal use"
 msgstr ""
 
-#: cp/tree.c:4526
+#: cp/tree.c:4574
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: cp/tree.c:4553
+#: cp/tree.c:4601
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %qE"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/tree.c:4573
+#: cp/tree.c:4621
 #, gcc-internal-format
 msgid "the %qE attribute requires arguments"
 msgstr ""
 
-#: cp/tree.c:4584
+#: cp/tree.c:4632
 #, fuzzy, gcc-internal-format
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: cp/tree.c:4597 cp/tree.c:4610
+#: cp/tree.c:4645 cp/tree.c:4658
 #, fuzzy, gcc-internal-format
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: cp/tree.c:4599
+#: cp/tree.c:4647
 #, gcc-internal-format
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr ""
 
-#: cp/tree.c:4612
+#: cp/tree.c:4660
 #, fuzzy, gcc-internal-format
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "сімвальная канстанта вельмі доўгая"
 
-#: cp/tree.c:4636
+#: cp/tree.c:4684
 #, gcc-internal-format
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr ""
 
-#: cp/tree.c:4642
+#: cp/tree.c:4690
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/tree.c:4649
+#: cp/tree.c:4697
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr ""
 
-#: cp/tree.c:4656
+#: cp/tree.c:4704
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr ""
 
-#: cp/tree.c:4678
+#: cp/tree.c:4726
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/tree.c:4684
+#: cp/tree.c:4732
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/tree.c:5440
+#: cp/tree.c:5488
 #, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr ""
 
-#: cp/tree.c:5453
+#: cp/tree.c:5501
 #, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr ""
@@ -50643,108 +50702,108 @@
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr ""
 
-#: cp/typeck2.c:1496 cp/typeck2.c:1523
+#: cp/typeck2.c:1499 cp/typeck2.c:1526
 #, fuzzy, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "прапушчан ініцыялізатар"
 
-#: cp/typeck2.c:1504
+#: cp/typeck2.c:1507
 #, fuzzy, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/typeck2.c:1511
+#: cp/typeck2.c:1514
 #, fuzzy, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/typeck2.c:1587
+#: cp/typeck2.c:1590
 #, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr ""
 
-#: cp/typeck2.c:1660
+#: cp/typeck2.c:1663
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr ""
 
-#: cp/typeck2.c:1671
+#: cp/typeck2.c:1674
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr ""
 
-#: cp/typeck2.c:1858
+#: cp/typeck2.c:1861
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr ""
 
-#: cp/typeck2.c:1872
+#: cp/typeck2.c:1875
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%D' has non-integer type"
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "памер масіва `%D' не цэлалікавы тып"
 
-#: cp/typeck2.c:1898
+#: cp/typeck2.c:1901
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr ""
 
-#: cp/typeck2.c:1900
+#: cp/typeck2.c:1903
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr ""
 
-#: cp/typeck2.c:1927
+#: cp/typeck2.c:1930
 #, fuzzy, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/typeck2.c:1936
+#: cp/typeck2.c:1939
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr ""
 
-#: cp/typeck2.c:1958
+#: cp/typeck2.c:1961
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2018
+#: cp/typeck2.c:2021
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr ""
 
-#: cp/typeck2.c:2029
+#: cp/typeck2.c:2032
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr ""
 
-#: cp/typeck2.c:2037
+#: cp/typeck2.c:2040
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++2a"
 msgstr ""
 
-#: cp/typeck2.c:2080
+#: cp/typeck2.c:2083
 #, fuzzy, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: cp/typeck2.c:2096
+#: cp/typeck2.c:2099
 #, fuzzy, gcc-internal-format
 msgid "cannot deduce template arguments for %qT from ()"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: cp/typeck2.c:2114
+#: cp/typeck2.c:2117
 #, fuzzy, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/typeck2.c:2341
+#: cp/typeck2.c:2344
 #, fuzzy, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/typeck2.c:2344
+#: cp/typeck2.c:2347
 #, fuzzy, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "\"%s\" мае незавершаны тып"
@@ -50960,11 +51019,11 @@
 msgstr ""
 
 #: fortran/array.c:221 fortran/array.c:661 fortran/check.c:2849
-#: fortran/check.c:5222 fortran/check.c:5260 fortran/check.c:5302
-#: fortran/check.c:5329 fortran/check.c:5529 fortran/match.c:1821
+#: fortran/check.c:5225 fortran/check.c:5263 fortran/check.c:5305
+#: fortran/check.c:5332 fortran/check.c:5532 fortran/match.c:1821
 #: fortran/match.c:3174 fortran/match.c:3516 fortran/match.c:3712
-#: fortran/simplify.c:2909 fortran/simplify.c:2939 fortran/simplify.c:5764
-#: fortran/simplify.c:7658
+#: fortran/simplify.c:2909 fortran/simplify.c:2939 fortran/simplify.c:5769
+#: fortran/simplify.c:7663
 #, gcc-internal-format
 msgid "Coarrays disabled at %C, use %<-fcoarray=%> to enable"
 msgstr ""
@@ -51099,118 +51158,123 @@
 msgid "DO-iterator %qs at %L is inside iterator of the same name"
 msgstr ""
 
-#: fortran/array.c:1073 fortran/array.c:1255
+#: fortran/array.c:1073 fortran/array.c:1264
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in array constructor at %C"
 msgstr ""
 
-#: fortran/array.c:1129
+#: fortran/array.c:1105
 #, gcc-internal-format, gfc-internal-format
+msgid "NULL() at %C cannot appear in an array constructor"
+msgstr ""
+
+#: fortran/array.c:1138
+#, gcc-internal-format, gfc-internal-format
 msgid "[...] style array constructors at %C"
 msgstr ""
 
-#: fortran/array.c:1149
+#: fortran/array.c:1158
 #, gcc-internal-format, gfc-internal-format
 msgid "Array constructor including type specification at %C"
 msgstr ""
 
-#: fortran/array.c:1155 fortran/match.c:4148
+#: fortran/array.c:1164 fortran/match.c:4148
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-spec at %L cannot contain a deferred type parameter"
 msgstr ""
 
-#: fortran/array.c:1163
+#: fortran/array.c:1172
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-spec at %L cannot contain an asterisk for a type parameter"
 msgstr ""
 
-#: fortran/array.c:1181
+#: fortran/array.c:1190
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty array constructor at %C is not allowed"
 msgstr ""
 
-#: fortran/array.c:1218 fortran/array.c:1228
+#: fortran/array.c:1227 fortran/array.c:1237
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible typespec for array element at %L"
 msgstr ""
 
-#: fortran/array.c:1302
+#: fortran/array.c:1311
 #, gcc-internal-format, gfc-internal-format
 msgid "Element in %s array constructor at %L is %s"
 msgstr ""
 
-#: fortran/array.c:1633
+#: fortran/array.c:1642
 #, gcc-internal-format, gfc-internal-format
 msgid "Iterator step at %L cannot be zero"
 msgstr ""
 
-#: fortran/array.c:1770
+#: fortran/array.c:1779
 #, gcc-internal-format
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit.   See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/array.c:1940
+#: fortran/array.c:1949
 #, gcc-internal-format, gfc-internal-format
 msgid "AC-IMPLIED-DO initial expression references control variable at %L"
 msgstr ""
 
-#: fortran/array.c:1947
+#: fortran/array.c:1956
 #, gcc-internal-format, gfc-internal-format
 msgid "AC-IMPLIED-DO final expression references control variable at %L"
 msgstr ""
 
-#: fortran/array.c:1954
+#: fortran/array.c:1963
 #, gcc-internal-format, gfc-internal-format
 msgid "AC-IMPLIED-DO step expression references control variable at %L"
 msgstr ""
 
-#: fortran/array.c:1966
+#: fortran/array.c:1975
 #, gcc-internal-format, gfc-internal-format
 msgid "Array constructor value at %L shall not be unlimited polymorphic [F2008: C4106]"
 msgstr ""
 
-#: fortran/array.c:2055
+#: fortran/array.c:2067
 #, gcc-internal-format, gfc-internal-format
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor at %L"
 msgstr ""
 
-#: fortran/array.c:2174
+#: fortran/array.c:2186
 #, gcc-internal-format
 msgid "spec_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2233
+#: fortran/array.c:2245
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2237
+#: fortran/array.c:2249
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array dimension at %L"
 msgstr ""
 
-#: fortran/array.c:2264 fortran/data.c:552 fortran/data.c:571
-#: fortran/data.c:585 fortran/data.c:714
+#: fortran/array.c:2276 fortran/data.c:563 fortran/data.c:582
+#: fortran/data.c:596 fortran/data.c:725
 #, gcc-internal-format
 msgid "Simplification error"
 msgstr ""
 
-#: fortran/array.c:2376
+#: fortran/array.c:2388
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimen_type"
 msgstr ""
 
-#: fortran/array.c:2427
+#: fortran/array.c:2439
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2472
+#: fortran/array.c:2484
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad EXPR_ARRAY expr"
 msgstr ""
 
-#: fortran/array.c:2620
+#: fortran/array.c:2632
 #, gcc-internal-format
 msgid "gfc_find_array_ref(): No ref found"
 msgstr ""
@@ -51261,7 +51325,7 @@
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or PROCEDURE"
 msgstr ""
 
-#: fortran/check.c:205 fortran/check.c:6658
+#: fortran/check.c:205 fortran/check.c:6661
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a constant"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
@@ -51377,7 +51441,7 @@
 msgid "Unequal character lengths (%ld/%ld) in %s at %L"
 msgstr ""
 
-#: fortran/check.c:946 fortran/check.c:6602
+#: fortran/check.c:946 fortran/check.c:6605
 #, gcc-internal-format
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have the same type"
 msgstr ""
@@ -51612,9 +51676,9 @@
 msgstr ""
 
 #: fortran/check.c:1939 fortran/check.c:2525 fortran/check.c:2628
-#: fortran/check.c:2835 fortran/check.c:2880 fortran/check.c:4256
-#: fortran/check.c:4390 fortran/check.c:4445 fortran/check.c:5515
-#: fortran/check.c:5644
+#: fortran/check.c:2835 fortran/check.c:2880 fortran/check.c:4259
+#: fortran/check.c:4393 fortran/check.c:4448 fortran/check.c:5518
+#: fortran/check.c:5647
 #, gcc-internal-format
 msgid "%qs intrinsic with KIND argument at %L"
 msgstr ""
@@ -51810,7 +51874,7 @@
 msgid "NULL intrinsic with allocatable MOLD at %L"
 msgstr ""
 
-#: fortran/check.c:3768 fortran/check.c:5591
+#: fortran/check.c:3768 fortran/check.c:5594
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must provide at least as many elements as there are .TRUE. values in %qs (%ld/%d)"
 msgstr ""
@@ -51830,372 +51894,372 @@
 msgid "%qs argument of %qs intrinsic at %L must not be a subobject of %qs"
 msgstr ""
 
-#: fortran/check.c:3901
+#: fortran/check.c:3904
 #, gcc-internal-format, gfc-internal-format
 msgid "The argument of the RANK intrinsic at %L must be a data object"
 msgstr ""
 
-#: fortran/check.c:4005
+#: fortran/check.c:4008
 #, gcc-internal-format
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L must be an array of constant size"
 msgstr ""
 
-#: fortran/check.c:4015
+#: fortran/check.c:4018
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L is empty"
 msgstr ""
 
-#: fortran/check.c:4022
+#: fortran/check.c:4025
 #, gcc-internal-format
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L has more than %d elements"
 msgstr ""
 
-#: fortran/check.c:4039
+#: fortran/check.c:4042
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has negative element (%d)"
 msgstr ""
 
-#: fortran/check.c:4071
+#: fortran/check.c:4074
 #, gcc-internal-format, gfc-internal-format
 msgid "Element %d of actual argument of RESHAPE at %L cannot be negative"
 msgstr ""
 
-#: fortran/check.c:4109
+#: fortran/check.c:4112
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has wrong number of elements (%d/%d)"
 msgstr ""
 
-#: fortran/check.c:4127
+#: fortran/check.c:4130
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has out-of-range dimension (%d)"
 msgstr ""
 
-#: fortran/check.c:4136
+#: fortran/check.c:4139
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has invalid permutation of dimensions (dimension %qd duplicated)"
 msgstr ""
 
-#: fortran/check.c:4172
+#: fortran/check.c:4175
 #, gcc-internal-format, gfc-internal-format
 msgid "Without padding, there are not enough elements in the intrinsic RESHAPE source at %L to match the shape"
 msgstr ""
 
-#: fortran/check.c:4189 fortran/check.c:4208
+#: fortran/check.c:4192 fortran/check.c:4211
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L cannot be of type %s"
 msgstr ""
 
-#: fortran/check.c:4199 fortran/check.c:4218
+#: fortran/check.c:4202 fortran/check.c:4221
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of an extensible type"
 msgstr ""
 
-#: fortran/check.c:4317
+#: fortran/check.c:4320
 #, gcc-internal-format
 msgid "SELECTED_REAL_KIND with neither %<P%> nor %<R%> argument at %L"
 msgstr ""
 
-#: fortran/check.c:4348
+#: fortran/check.c:4351
 #, gcc-internal-format
 msgid "%qs intrinsic with RADIX argument at %L"
 msgstr ""
 
-#: fortran/check.c:4383
+#: fortran/check.c:4386
 #, gcc-internal-format
 msgid "%<source%> argument of %<shape%> intrinsic at %L must not be an assumed size array"
 msgstr ""
 
-#: fortran/check.c:4460 fortran/check.c:6641
+#: fortran/check.c:4463 fortran/check.c:6644
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be a procedure"
 msgstr ""
 
-#: fortran/check.c:4473 fortran/check.c:4612 fortran/check.c:6633
+#: fortran/check.c:4476 fortran/check.c:4615 fortran/check.c:6636
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be TYPE(*)"
 msgstr ""
 
-#: fortran/check.c:4484 fortran/check.c:4624
+#: fortran/check.c:4487 fortran/check.c:4627
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be an assumed-size array"
 msgstr ""
 
-#: fortran/check.c:4554
+#: fortran/check.c:4557
 #, gcc-internal-format
 msgid "is_c_interoperable(): gfc_simplify_expr failed"
 msgstr ""
 
-#: fortran/check.c:4603
+#: fortran/check.c:4606
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be an interoperable data entity: %s"
 msgstr ""
 
-#: fortran/check.c:4642
+#: fortran/check.c:4645
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_1 at %L to C_ASSOCIATED shall have the type TYPE(C_PTR) or TYPE(C_FUNPTR)"
 msgstr ""
 
-#: fortran/check.c:4656
+#: fortran/check.c:4659
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_2 at %L to C_ASSOCIATED shall have the same type as C_PTR_1: %s instead of %s"
 msgstr ""
 
-#: fortran/check.c:4680
+#: fortran/check.c:4683
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_POINTER shall have the type TYPE(C_PTR)"
 msgstr ""
 
-#: fortran/check.c:4692
+#: fortran/check.c:4695
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER must be a pointer"
 msgstr ""
 
-#: fortran/check.c:4699
+#: fortran/check.c:4702
 #, gcc-internal-format, gfc-internal-format
 msgid "FPTR argument at %L to C_F_POINTER shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:4706
+#: fortran/check.c:4709
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:4713
+#: fortran/check.c:4716
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected SHAPE argument at %L to C_F_POINTER with scalar FPTR"
 msgstr ""
 
-#: fortran/check.c:4719
+#: fortran/check.c:4722
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected SHAPE argument to C_F_POINTER with array FPTR at %L"
 msgstr ""
 
-#: fortran/check.c:4738
+#: fortran/check.c:4741
 #, gcc-internal-format, gfc-internal-format
 msgid "SHAPE argument at %L to C_F_POINTER must have the same size as the RANK of FPTR"
 msgstr ""
 
-#: fortran/check.c:4748
+#: fortran/check.c:4751
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic FPTR at %L to C_F_POINTER"
 msgstr ""
 
-#: fortran/check.c:4753
+#: fortran/check.c:4756
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array FPTR at %L to C_F_POINTER: %s"
 msgstr ""
 
-#: fortran/check.c:4769
+#: fortran/check.c:4772
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_PROCPOINTER shall have the type TYPE(C_FUNPTR)"
 msgstr ""
 
-#: fortran/check.c:4781
+#: fortran/check.c:4784
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall be a procedure pointer"
 msgstr ""
 
-#: fortran/check.c:4788
+#: fortran/check.c:4791
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:4794
+#: fortran/check.c:4797
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure pointer at %L to C_F_PROCPOINTER"
 msgstr ""
 
-#: fortran/check.c:4808
+#: fortran/check.c:4811
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:4823
+#: fortran/check.c:4826
 #, gcc-internal-format
 msgid "Function result %qs at %L is invalid as X argument to C_FUNLOC"
 msgstr ""
 
-#: fortran/check.c:4831
+#: fortran/check.c:4834
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall be a procedure or a procedure pointer"
 msgstr ""
 
-#: fortran/check.c:4837
+#: fortran/check.c:4840
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure at %L to C_FUNLOC"
 msgstr ""
 
-#: fortran/check.c:4851
+#: fortran/check.c:4854
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:4857
+#: fortran/check.c:4860
 #, gcc-internal-format, gfc-internal-format
 msgid "X argument at %L to C_LOC shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:4868
+#: fortran/check.c:4871
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall have either the POINTER or the TARGET attribute"
 msgstr ""
 
-#: fortran/check.c:4876
+#: fortran/check.c:4879
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall be not be a zero-sized string"
 msgstr ""
 
-#: fortran/check.c:4885
+#: fortran/check.c:4888
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument at %L to C_LOC shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:4892
+#: fortran/check.c:4895
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array at %L as argument to C_LOC: %s"
 msgstr ""
 
-#: fortran/check.c:4903
+#: fortran/check.c:4906
 #, gcc-internal-format, gfc-internal-format
 msgid "Array of interoperable type at %L to C_LOC which is nonallocatable and neither assumed size nor explicit size"
 msgstr ""
 
-#: fortran/check.c:4908
+#: fortran/check.c:4911
 #, gcc-internal-format, gfc-internal-format
 msgid "Array section at %L to C_LOC"
 msgstr ""
 
-#: fortran/check.c:4936
+#: fortran/check.c:4939
 #, gcc-internal-format, gfc-internal-format
 msgid "non double precision REAL argument to %s intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:4949
+#: fortran/check.c:4952
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be less than rank %d"
 msgstr "памер \"%s\" больш чам %d байт"
 
-#: fortran/check.c:4968
+#: fortran/check.c:4971
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L is not a valid dimension index"
 msgstr ""
 
-#: fortran/check.c:5231
+#: fortran/check.c:5234
 #, gcc-internal-format, gfc-internal-format
 msgid "%s argument to IMAGE_INDEX must be a rank one array at %L"
 msgstr ""
 
-#: fortran/check.c:5242
+#: fortran/check.c:5245
 #, gcc-internal-format, gfc-internal-format
 msgid "The number of array elements of the SUB argument to IMAGE_INDEX at %L shall be %d (corank) not %d"
 msgstr ""
 
-#: fortran/check.c:5275
+#: fortran/check.c:5278
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to NUM_IMAGES at %L"
 msgstr ""
 
-#: fortran/check.c:5288
+#: fortran/check.c:5291
 #, gcc-internal-format, gfc-internal-format
 msgid "FAILED= argument to NUM_IMAGES at %L"
 msgstr ""
 
-#: fortran/check.c:5312
+#: fortran/check.c:5315
 #, gcc-internal-format, gfc-internal-format
 msgid "TEAM argument at %L to the intrinsic TEAM_NUMBER shall be of type TEAM_TYPE"
 msgstr ""
 
-#: fortran/check.c:5338
+#: fortran/check.c:5341
 #, gcc-internal-format, gfc-internal-format
 msgid "DIM argument without COARRAY argument not allowed for THIS_IMAGE intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:5345
+#: fortran/check.c:5348
 #, gcc-internal-format, gfc-internal-format
 msgid "The DISTANCE argument may not be specified together with the COARRAY or DIM argument in intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:5356
+#: fortran/check.c:5359
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected DIM argument with noncoarray argument at %L"
 msgstr ""
 
-#: fortran/check.c:5374
+#: fortran/check.c:5377
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to THIS_IMAGE at %L"
 msgstr ""
 
-#: fortran/check.c:5454
+#: fortran/check.c:5457
 #, gcc-internal-format
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L must not be %s"
 msgstr ""
 
-#: fortran/check.c:5483
+#: fortran/check.c:5486
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic TRANSFER at %L has partly undefined result: source size %ld < result size %ld"
 msgstr ""
 
-#: fortran/check.c:5605
+#: fortran/check.c:5608
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must have the same rank as %qs or be a scalar"
 msgstr ""
 
-#: fortran/check.c:5618
+#: fortran/check.c:5621
 #, gcc-internal-format
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have identical shape."
 msgstr ""
 
-#: fortran/check.c:5861 fortran/check.c:5893
+#: fortran/check.c:5864 fortran/check.c:5896
 #, gcc-internal-format
 msgid "Size of %qs argument of %qs intrinsic at %L too small (%i/%i)"
 msgstr ""
 
-#: fortran/check.c:5901
+#: fortran/check.c:5904
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Too many arguments to %s at %L"
 msgstr "вельмі шмат аргументаў у функцыі \"%s\""
 
-#: fortran/check.c:5919
+#: fortran/check.c:5922
 #, gcc-internal-format
 msgid "fe_runtime_error string must be null terminated"
 msgstr ""
 
-#: fortran/check.c:5931
+#: fortran/check.c:5934
 #, gcc-internal-format, gfc-internal-format
 msgid "fe_runtime_error: Wrong number of arguments (%d instead of %d)"
 msgstr ""
 
-#: fortran/check.c:5971
+#: fortran/check.c:5974
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:5990
+#: fortran/check.c:5993
 #, gcc-internal-format, gfc-internal-format
 msgid "Real COUNT_RATE argument to SYSTEM_CLOCK at %L"
 msgstr ""
 
-#: fortran/check.c:6000
+#: fortran/check.c:6003
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT_RATE argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:6017
+#: fortran/check.c:6020
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT_MAX argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:6234
+#: fortran/check.c:6237
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of a kind not wider than the default kind (%d)"
 msgstr ""
 
-#: fortran/check.c:6586 fortran/check.c:6594
+#: fortran/check.c:6589 fortran/check.c:6597
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or LOGICAL"
 msgstr ""
 
-#: fortran/check.c:6625
+#: fortran/check.c:6628
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic function NULL at %L cannot be an actual argument to STORAGE_SIZE, because it returns a disassociated pointer"
 msgstr ""
@@ -52207,7 +52271,7 @@
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:727 fortran/decl.c:3636 fortran/decl.c:10066
+#: fortran/class.c:727 fortran/decl.c:3655 fortran/decl.c:10091
 #, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr ""
@@ -52233,44 +52297,49 @@
 msgid "non-constant array in DATA statement %L"
 msgstr ""
 
-#: fortran/data.c:137
+#: fortran/data.c:140
 #, gcc-internal-format, gfc-internal-format
 msgid "failure to simplify substring reference in DATA statement at %L"
 msgstr ""
 
-#: fortran/data.c:170
+#: fortran/data.c:173
 #, gcc-internal-format, gfc-internal-format
 msgid "Unused initialization string at %L because variable has zero length"
 msgstr ""
 
-#: fortran/data.c:176
+#: fortran/data.c:179
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization string at %L was truncated to fit the variable (%ld/%ld)"
 msgstr ""
 
-#: fortran/data.c:265
+#: fortran/data.c:268
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L already is initialized at %L"
 msgstr "Клас \"%s\" ужо існуе"
 
-#: fortran/data.c:289
+#: fortran/data.c:292
 #, gcc-internal-format, gfc-internal-format
 msgid "Data element below array lower bound at %L"
 msgstr ""
 
-#: fortran/data.c:306 fortran/data.c:395
+#: fortran/data.c:309 fortran/data.c:398
 #, gcc-internal-format, gfc-internal-format
 msgid "Data element above array upper bound at %L"
 msgstr ""
 
-#: fortran/data.c:336 fortran/data.c:505
+#: fortran/data.c:339 fortran/data.c:496
 #, fuzzy, gcc-internal-format
 #| msgid "initialization"
 msgid "re-initialization of %qs at %L"
 msgstr "ініцыялізацыя"
 
-#: fortran/data.c:727
+#: fortran/data.c:515
 #, gcc-internal-format
+msgid "Nonpointer object %qs with default initialization shall not appear in a DATA statement at %L"
+msgstr ""
+
+#: fortran/data.c:738
+#, gcc-internal-format
 msgid "TODO: Vector sections in data statements"
 msgstr ""
 
@@ -52294,786 +52363,786 @@
 msgid "Invalid initializer %s in Data statement at %C"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: fortran/decl.c:536
+#: fortran/decl.c:537
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:573
+#: fortran/decl.c:574
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %C cannot appear within an INTERFACE"
 msgstr ""
 
-#: fortran/decl.c:597
+#: fortran/decl.c:598
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid substring in data-implied-do at %L in DATA statement"
 msgstr ""
 
-#: fortran/decl.c:619
+#: fortran/decl.c:620
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:664
+#: fortran/decl.c:662
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty old style initializer list at %C"
 msgstr ""
 
-#: fortran/decl.c:684
+#: fortran/decl.c:671
 #, gcc-internal-format, gfc-internal-format
+msgid "Array in initializer list at %L must have an explicit shape"
+msgstr ""
+
+#: fortran/decl.c:694
+#, gcc-internal-format, gfc-internal-format
 msgid "Repeat spec invalid in scalar initializer at %C"
 msgstr ""
 
-#: fortran/decl.c:689
+#: fortran/decl.c:699
 #, gcc-internal-format, gfc-internal-format
 msgid "Repeat spec must be an integer at %C"
 msgstr ""
 
-#: fortran/decl.c:698
+#: fortran/decl.c:710
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected data constant after repeat spec at %C"
 msgstr ""
 
-#: fortran/decl.c:729
+#: fortran/decl.c:742
 #, gcc-internal-format, gfc-internal-format
 msgid "End of scalar initializer expected at %C"
 msgstr ""
 
-#: fortran/decl.c:758
+#: fortran/decl.c:773
 #, gcc-internal-format, gfc-internal-format
-msgid "Expected constant array-spec in initializer list at %L"
-msgstr ""
-
-#: fortran/decl.c:767
-#, gcc-internal-format, gfc-internal-format
 msgid "Not enough elements in array initializer at %C"
 msgstr ""
 
-#: fortran/decl.c:769
+#: fortran/decl.c:775
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many elements in array initializer at %C"
 msgstr ""
 
-#: fortran/decl.c:790
+#: fortran/decl.c:795
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in old style initializer list at %C"
 msgstr ""
 
-#: fortran/decl.c:812
+#: fortran/decl.c:821
 #, gcc-internal-format, gfc-internal-format
 msgid "The assumed-rank array at %C shall not have a codimension"
 msgstr ""
 
-#: fortran/decl.c:876
+#: fortran/decl.c:885
 #, gcc-internal-format, gfc-internal-format
 msgid "Sum of array rank %d and corank %d at %C exceeds maximum allowed dimensions of %d"
 msgstr ""
 
-#: fortran/decl.c:900
+#: fortran/decl.c:909
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad INTENT specification at %C"
 msgstr ""
 
-#: fortran/decl.c:921
+#: fortran/decl.c:930
 #, gcc-internal-format, gfc-internal-format
 msgid "deferred type parameter at %C"
 msgstr ""
 
-#: fortran/decl.c:1004 fortran/resolve.c:11705
+#: fortran/decl.c:1013 fortran/resolve.c:11725
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
 
-#: fortran/decl.c:1030
+#: fortran/decl.c:1039
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Old-style character length at %C"
 msgstr "пустая сімвальная канстанта"
 
-#: fortran/decl.c:1061
+#: fortran/decl.c:1070
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in character length specification at %C"
 msgstr ""
 
-#: fortran/decl.c:1212 fortran/decl.c:1217 fortran/decl.c:1266
+#: fortran/decl.c:1221 fortran/decl.c:1226 fortran/decl.c:1275
 #, gcc-internal-format
 msgid "Procedure %qs at %C is already defined at %L"
 msgstr ""
 
-#: fortran/decl.c:1222
+#: fortran/decl.c:1231
 #, gcc-internal-format
 msgid "Contained procedure %qs at %C clashes with procedure defined at %L"
 msgstr ""
 
-#: fortran/decl.c:1231
+#: fortran/decl.c:1240
 #, gcc-internal-format
 msgid "Name %qs at %C is already defined as a generic interface at %L"
 msgstr ""
 
-#: fortran/decl.c:1244
+#: fortran/decl.c:1253
 #, gcc-internal-format
 msgid "Procedure %qs at %C has an explicit interface from a previous declaration"
 msgstr ""
 
-#: fortran/decl.c:1257
+#: fortran/decl.c:1266
 #, gcc-internal-format
 msgid "Procedure %qs defined in interface body at %L clashes with internal procedure defined at %C"
 msgstr ""
 
-#: fortran/decl.c:1335
+#: fortran/decl.c:1344
 #, gcc-internal-format
 msgid "Procedure %qs at %L must have the BIND(C) attribute to be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:1362
+#: fortran/decl.c:1371
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because derived type %qs is not C interoperable"
 msgstr ""
 
-#: fortran/decl.c:1369
+#: fortran/decl.c:1378
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because it is polymorphic"
 msgstr ""
 
-#: fortran/decl.c:1376
+#: fortran/decl.c:1385
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument of the BIND(C) procedure %qs but may not be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:1391
+#: fortran/decl.c:1400
 #, gcc-internal-format
 msgid "Character argument %qs at %L must be length 1 because procedure %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1404
+#: fortran/decl.c:1413
 #, gcc-internal-format
 msgid "Variable %qs at %L with ALLOCATABLE attribute in procedure %qs with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1412
+#: fortran/decl.c:1421
 #, gcc-internal-format
 msgid "Variable %qs at %L with POINTER attribute in procedure %qs with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1421
+#: fortran/decl.c:1430
 #, gcc-internal-format
 msgid "Scalar variable %qs at %L with POINTER or ALLOCATABLE in procedure %qs with BIND(C) is not yet supported"
 msgstr ""
 
-#: fortran/decl.c:1430
+#: fortran/decl.c:1439
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the OPTIONAL and the VALUE attribute because procedure %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1437
+#: fortran/decl.c:1446
 #, gcc-internal-format
 msgid "Variable %qs at %L with OPTIONAL attribute in procedure %qs which is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1448
+#: fortran/decl.c:1457
 #, gcc-internal-format
 msgid "Assumed-shape array %qs at %L as dummy argument to the BIND(C) procedure %qs at %L"
 msgstr ""
 
-#: fortran/decl.c:1516
+#: fortran/decl.c:1525
 #, gcc-internal-format
 msgid "Symbol %qs at %C also declared as a type at %L"
 msgstr ""
 
-#: fortran/decl.c:1575
+#: fortran/decl.c:1584
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %C must be declared with a C interoperable kind since common block %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1615
+#: fortran/decl.c:1624
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER length must be a constant at %L"
 msgstr ""
 
-#: fortran/decl.c:1630
+#: fortran/decl.c:1639
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression at %L is being truncated (%ld/%ld)"
 msgstr ""
 
-#: fortran/decl.c:1638
+#: fortran/decl.c:1647
 #, gcc-internal-format, gfc-internal-format
 msgid "The CHARACTER elements of the array constructor at %L must have the same length (%ld/%ld)"
 msgstr ""
 
-#: fortran/decl.c:1729
+#: fortran/decl.c:1738
 #, gcc-internal-format
 msgid "Initializer not allowed for PARAMETER %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:1739
+#: fortran/decl.c:1748
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing initializer"
 msgid "PARAMETER at %L is missing an initializer"
 msgstr "прапушчан ініцыялізатар"
 
-#: fortran/decl.c:1749
+#: fortran/decl.c:1758
 #, gcc-internal-format
 msgid "Variable %qs at %C with an initializer already appears in a DATA statement"
 msgstr ""
 
-#: fortran/decl.c:1792
+#: fortran/decl.c:1801
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot initialize parameter array at %L with variable length elements"
 msgstr ""
 
-#: fortran/decl.c:1861
+#: fortran/decl.c:1870
 #, gcc-internal-format, gfc-internal-format
 msgid "Can't initialize implied-shape array at %L with scalar"
 msgstr ""
 
-#: fortran/decl.c:1896
+#: fortran/decl.c:1905
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-constant lower bound in implied-shape declaration at %L"
 msgstr ""
 
-#: fortran/decl.c:1982 fortran/decl.c:1989
+#: fortran/decl.c:1991 fortran/decl.c:1998
 #, gcc-internal-format, gfc-internal-format
 msgid "Component at %C must have the POINTER attribute"
 msgstr ""
 
-#: fortran/decl.c:1998
+#: fortran/decl.c:2007
 #, gcc-internal-format
 msgid "Component %qs with CLASS at %C must be allocatable or pointer"
 msgstr ""
 
-#: fortran/decl.c:2007
+#: fortran/decl.c:2016
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr ""
 
-#: fortran/decl.c:2031 fortran/symbol.c:2230
+#: fortran/decl.c:2040 fortran/symbol.c:2244
 #, gcc-internal-format
 msgid "Component %qs at %C already declared at %L"
 msgstr ""
 
-#: fortran/decl.c:2079
+#: fortran/decl.c:2088
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer array component of structure at %C must have a deferred shape"
 msgstr ""
 
-#: fortran/decl.c:2088
+#: fortran/decl.c:2097
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component of structure at %C must have a deferred shape"
 msgstr ""
 
-#: fortran/decl.c:2097
+#: fortran/decl.c:2106
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have an explicit shape"
 msgstr ""
 
-#: fortran/decl.c:2114
+#: fortran/decl.c:2123
 #, gcc-internal-format
 msgid "Type parameter %qs at %C has no corresponding entry in the type parameter name list at %L"
 msgstr ""
 
-#: fortran/decl.c:2171
+#: fortran/decl.c:2180
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C is ambiguous"
 msgstr ""
 
-#: fortran/decl.c:2188
+#: fortran/decl.c:2197
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C may not have MOLD"
 msgstr ""
 
-#: fortran/decl.c:2205
+#: fortran/decl.c:2214
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of pointer at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:2226
+#: fortran/decl.c:2235
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Error in pointer initialization at %C"
 msgstr "ініцыялізацыя"
 
-#: fortran/decl.c:2233
+#: fortran/decl.c:2242
 #, gcc-internal-format, gfc-internal-format
 msgid "non-NULL pointer initialization at %C"
 msgstr ""
 
-#: fortran/decl.c:2256
+#: fortran/decl.c:2265
 #, gcc-internal-format
 msgid "RESULT variable %qs at %L prohibits FUNCTION name %qs at %C from appearing in a specification statement"
 msgstr ""
 
-#: fortran/decl.c:2318
+#: fortran/decl.c:2327
 #, gcc-internal-format
 msgid "%qs not allowed outside STRUCTURE at %C"
 msgstr ""
 
-#: fortran/decl.c:2320
+#: fortran/decl.c:2329
 #, gcc-internal-format
 msgid "%qs at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr ""
 
-#: fortran/decl.c:2327
+#: fortran/decl.c:2336
 #, gcc-internal-format
 msgid "%qs entity cannot have attributes at %C"
 msgstr ""
 
-#: fortran/decl.c:2367
+#: fortran/decl.c:2376
 #, gcc-internal-format
 msgid "Non-PARAMETER symbol %qs at %L can't be implied-shape"
 msgstr ""
 
-#: fortran/decl.c:2377
+#: fortran/decl.c:2386
 #, gcc-internal-format, gfc-internal-format
 msgid "Implied-shape array at %L"
 msgstr ""
 
-#: fortran/decl.c:2422
+#: fortran/decl.c:2431
 #, gcc-internal-format, gfc-internal-format
 msgid "Explicit shaped array with nonconstant bounds at %C"
 msgstr ""
 
-#: fortran/decl.c:2501
+#: fortran/decl.c:2510
 #, gcc-internal-format
 msgid "%qs at %C is a redefinition of the declaration in the corresponding interface for MODULE PROCEDURE %qs"
 msgstr ""
 
-#: fortran/decl.c:2512
+#: fortran/decl.c:2521
 #, gcc-internal-format
 msgid "%qs entity cannot have an initializer at %C"
 msgstr ""
 
-#: fortran/decl.c:2538 fortran/decl.c:8369
+#: fortran/decl.c:2547 fortran/decl.c:8388
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr ""
 
-#: fortran/decl.c:2546
+#: fortran/decl.c:2555
 #, gcc-internal-format
 msgid "Couldn't set pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:2609
+#: fortran/decl.c:2618
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "initialization"
 msgid "Old-style initialization at %C"
 msgstr "ініцыялізацыя"
 
-#: fortran/decl.c:2617
+#: fortran/decl.c:2626
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr ""
 
-#: fortran/decl.c:2630
+#: fortran/decl.c:2639
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in old style initialization of %s at %C"
 msgstr ""
 
-#: fortran/decl.c:2650 fortran/decl.c:6661
+#: fortran/decl.c:2659 fortran/decl.c:6680
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr ""
 
-#: fortran/decl.c:2663
+#: fortran/decl.c:2672
 #, gcc-internal-format
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr ""
 
-#: fortran/decl.c:2672 fortran/decl.c:10240
+#: fortran/decl.c:2681 fortran/decl.c:10265
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr ""
 
-#: fortran/decl.c:2679
+#: fortran/decl.c:2688
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:2696
+#: fortran/decl.c:2705
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr ""
 
-#: fortran/decl.c:2710
+#: fortran/decl.c:2719
 #, gcc-internal-format, gfc-internal-format
 msgid "The component with KIND or LEN attribute at %C does not not appear in the type parameter list at %L"
 msgstr ""
 
-#: fortran/decl.c:2718
+#: fortran/decl.c:2727
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C that appears in the type parameter list at %L has neither the KIND nor LEN attribute"
 msgstr ""
 
-#: fortran/decl.c:2726
+#: fortran/decl.c:2735
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C which is a type parameter must be a scalar"
 msgstr ""
 
-#: fortran/decl.c:2789 fortran/decl.c:2825
+#: fortran/decl.c:2798 fortran/decl.c:2834
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr ""
 
-#: fortran/decl.c:2831
+#: fortran/decl.c:2840
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr ""
 
-#: fortran/decl.c:2890 fortran/decl.c:2967
+#: fortran/decl.c:2899 fortran/decl.c:2976
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis at %C"
 msgstr ""
 
-#: fortran/decl.c:2903 fortran/decl.c:3038
+#: fortran/decl.c:2912 fortran/decl.c:3047
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr ""
 
-#: fortran/decl.c:2911 fortran/decl.c:3044
+#: fortran/decl.c:2920 fortran/decl.c:3053
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr ""
 
-#: fortran/decl.c:2941 fortran/decl.c:3657
+#: fortran/decl.c:2950 fortran/decl.c:3676
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: fortran/decl.c:2954
+#: fortran/decl.c:2963
 #, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr ""
 
-#: fortran/decl.c:2965
+#: fortran/decl.c:2974
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr ""
 
-#: fortran/decl.c:3070
+#: fortran/decl.c:3079
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr ""
 
-#: fortran/decl.c:3202
+#: fortran/decl.c:3211
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:3291
+#: fortran/decl.c:3310
 #, gcc-internal-format, gfc-internal-format
 msgid "RECORD at %C is an extension, enable it with -fdec-structure"
 msgstr ""
 
-#: fortran/decl.c:3304
+#: fortran/decl.c:3323
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected after RECORD at %C"
 msgstr ""
 
-#: fortran/decl.c:3417
+#: fortran/decl.c:3436
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C cannot contain both ASSUMED and DEFERRED parameters"
 msgstr ""
 
-#: fortran/decl.c:3441
+#: fortran/decl.c:3460
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C does not contain enough parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3465
+#: fortran/decl.c:3484
 #, gcc-internal-format
 msgid "The derived parameter %qs at %C does not have a default value"
 msgstr ""
 
-#: fortran/decl.c:3497
+#: fortran/decl.c:3516
 #, gcc-internal-format, gfc-internal-format
 msgid "The parameter expression at %C must be of INTEGER type and not %s type"
 msgstr ""
 
-#: fortran/decl.c:3525
+#: fortran/decl.c:3544
 #, gcc-internal-format
 msgid "The KIND parameter %qs at %C cannot either be ASSUMED or DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:3532
+#: fortran/decl.c:3551
 #, gcc-internal-format
 msgid "The value for the KIND parameter %qs at %C does not reduce to a constant expression"
 msgstr ""
 
-#: fortran/decl.c:3547
+#: fortran/decl.c:3566
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C contains too many parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3556
+#: fortran/decl.c:3575
 #, gcc-internal-format, gfc-internal-format
 msgid "Parameterized derived type at %C is ambiguous"
 msgstr ""
 
-#: fortran/decl.c:3819
+#: fortran/decl.c:3838
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type at %C"
 msgstr ""
 
-#: fortran/decl.c:3824
+#: fortran/decl.c:3843
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr ""
 
-#: fortran/decl.c:3846
+#: fortran/decl.c:3865
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C is not allowed for components"
 msgstr ""
 
-#: fortran/decl.c:3849
+#: fortran/decl.c:3868
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr ""
 
-#: fortran/decl.c:3872 fortran/decl.c:3903 fortran/decl.c:3932
-#: fortran/decl.c:4216
+#: fortran/decl.c:3891 fortran/decl.c:3922 fortran/decl.c:3951
+#: fortran/decl.c:4235
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr ""
 
-#: fortran/decl.c:3928
+#: fortran/decl.c:3947
 #, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr ""
 
-#: fortran/decl.c:3971 fortran/decl.c:4107 fortran/decl.c:4119
-#: fortran/decl.c:4133 fortran/decl.c:4611 fortran/decl.c:4619
+#: fortran/decl.c:3990 fortran/decl.c:4126 fortran/decl.c:4138
+#: fortran/decl.c:4152 fortran/decl.c:4630 fortran/decl.c:4638
 #, fuzzy, gcc-internal-format
 msgid "Type name %qs at %C is ambiguous"
 msgstr "памер \"%s\" - %d байт"
 
-#: fortran/decl.c:4066
+#: fortran/decl.c:4085
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4148
+#: fortran/decl.c:4167
 #, gcc-internal-format
 msgid "Type name %qs at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr ""
 
-#: fortran/decl.c:4287
+#: fortran/decl.c:4306
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4296
+#: fortran/decl.c:4315
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr ""
 
-#: fortran/decl.c:4355
+#: fortran/decl.c:4374
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr ""
 
-#: fortran/decl.c:4401
+#: fortran/decl.c:4420
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4454
+#: fortran/decl.c:4473
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr ""
 
-#: fortran/decl.c:4464
+#: fortran/decl.c:4483
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4570
+#: fortran/decl.c:4589
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr ""
 
-#: fortran/decl.c:4577
+#: fortran/decl.c:4596
 #, gcc-internal-format, gfc-internal-format
 msgid "F2008: C1210 IMPORT statement at %C is not permitted in a module procedure interface body"
 msgstr ""
 
-#: fortran/decl.c:4582
+#: fortran/decl.c:4601
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C"
 msgstr "вельмі шмат аргументаў у функцыі"
 
-#: fortran/decl.c:4596
+#: fortran/decl.c:4615
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr ""
 
-#: fortran/decl.c:4625
+#: fortran/decl.c:4644
 #, gcc-internal-format
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr ""
 
-#: fortran/decl.c:4632
+#: fortran/decl.c:4651
 #, gcc-internal-format
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr ""
 
-#: fortran/decl.c:4673
+#: fortran/decl.c:4692
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IMPORT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5010
+#: fortran/decl.c:5029
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing codimension specification at %C"
 msgstr ""
 
-#: fortran/decl.c:5012
+#: fortran/decl.c:5031
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr ""
 
-#: fortran/decl.c:5107
+#: fortran/decl.c:5126
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr ""
 
-#: fortran/decl.c:5124
+#: fortran/decl.c:5143
 #, gcc-internal-format
 msgid "%s at %L is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:5141
+#: fortran/decl.c:5160
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5150
+#: fortran/decl.c:5169
 #, gcc-internal-format, gfc-internal-format
 msgid "KIND attribute at %C in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5158
+#: fortran/decl.c:5177
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be INTEGER"
 msgstr ""
 
-#: fortran/decl.c:5165
+#: fortran/decl.c:5184
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5174
+#: fortran/decl.c:5193
 #, gcc-internal-format, gfc-internal-format
 msgid "LEN attribute at %C in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5182
+#: fortran/decl.c:5201
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be INTEGER"
 msgstr ""
 
-#: fortran/decl.c:5189
+#: fortran/decl.c:5208
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5198
+#: fortran/decl.c:5217
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5216
+#: fortran/decl.c:5235
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5226
+#: fortran/decl.c:5245
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:5236
+#: fortran/decl.c:5255
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed outside a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5249
+#: fortran/decl.c:5268
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5260
+#: fortran/decl.c:5279
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5315 fortran/decl.c:8673
+#: fortran/decl.c:5334 fortran/decl.c:8692
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:5321
+#: fortran/decl.c:5340
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5355
+#: fortran/decl.c:5374
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5362
+#: fortran/decl.c:5381
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5369
+#: fortran/decl.c:5388
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr ""
 
-#: fortran/decl.c:5410
+#: fortran/decl.c:5429
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:5508
+#: fortran/decl.c:5527
 #, gcc-internal-format
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:5530
+#: fortran/decl.c:5549
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5539
+#: fortran/decl.c:5558
 #, gcc-internal-format
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5543
+#: fortran/decl.c:5562
 #, gcc-internal-format
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5555
+#: fortran/decl.c:5574
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr ""
 
-#: fortran/decl.c:5569
+#: fortran/decl.c:5588
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr ""
 
-#: fortran/decl.c:5577
+#: fortran/decl.c:5596
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr ""
 
-#: fortran/decl.c:5589
+#: fortran/decl.c:5608
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr ""
 
-#: fortran/decl.c:5597
+#: fortran/decl.c:5616
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be a character string"
 msgstr ""
@@ -53080,953 +53149,958 @@
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:5608
+#: fortran/decl.c:5627
 #, gcc-internal-format
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr ""
 
-#: fortran/decl.c:5682
+#: fortran/decl.c:5701
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5727
+#: fortran/decl.c:5746
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5734
+#: fortran/decl.c:5753
 #, fuzzy, gcc-internal-format
 #| msgid "Missing name"
 msgid "Missing symbol"
 msgstr "Прапушчана назва"
 
-#: fortran/decl.c:5763
+#: fortran/decl.c:5782
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5850
+#: fortran/decl.c:5869
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr ""
 
-#: fortran/decl.c:5892
+#: fortran/decl.c:5911
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in anonymous structure declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:5901
+#: fortran/decl.c:5920
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:5951
+#: fortran/decl.c:5970
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C"
 msgstr ""
 
-#: fortran/decl.c:5996
+#: fortran/decl.c:6015
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPURE procedure at %C"
 msgstr ""
 
-#: fortran/decl.c:6008
+#: fortran/decl.c:6027
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr ""
 
-#: fortran/decl.c:6054
+#: fortran/decl.c:6073
 #, gcc-internal-format, gfc-internal-format
 msgid "ELEMENTAL prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6061
+#: fortran/decl.c:6080
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6068
+#: fortran/decl.c:6087
 #, gcc-internal-format, gfc-internal-format
 msgid "RECURSIVE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6134 fortran/primary.c:1820
+#: fortran/decl.c:6153 fortran/primary.c:1820
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate-return argument at %C"
 msgstr ""
 
-#: fortran/decl.c:6140 fortran/decl.c:6148
+#: fortran/decl.c:6159 fortran/decl.c:6167
 #, gcc-internal-format, gfc-internal-format
 msgid "A parameter name is required at %C"
 msgstr ""
 
-#: fortran/decl.c:6188
+#: fortran/decl.c:6207
 #, gcc-internal-format
 msgid "Name %qs at %C is the name of the procedure"
 msgstr ""
 
-#: fortran/decl.c:6201
+#: fortran/decl.c:6220
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected parameter list in type declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:6204
+#: fortran/decl.c:6223
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr ""
 
-#: fortran/decl.c:6222
+#: fortran/decl.c:6241
 #, gcc-internal-format
 msgid "Duplicate name %qs in parameter list at %C"
 msgstr ""
 
-#: fortran/decl.c:6225
+#: fortran/decl.c:6244
 #, gcc-internal-format
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr ""
 
-#: fortran/decl.c:6264
+#: fortran/decl.c:6283
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in MODULE PROCEDURE formal argument names (%s/%s) at %C"
 msgstr ""
 
-#: fortran/decl.c:6270
+#: fortran/decl.c:6289
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in number of MODULE PROCEDURE formal arguments at %C"
 msgstr ""
 
-#: fortran/decl.c:6309
+#: fortran/decl.c:6328
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr ""
 
-#: fortran/decl.c:6386
+#: fortran/decl.c:6405
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr "секцыя \"%s\" канфліктуе з папярэдняй дэкларацыяй"
 
-#: fortran/decl.c:6396 fortran/decl.c:7494
+#: fortran/decl.c:6415 fortran/decl.c:7513
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr ""
 
-#: fortran/decl.c:6600
+#: fortran/decl.c:6619
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:6607
+#: fortran/decl.c:6626
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:6613
+#: fortran/decl.c:6632
 #, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr ""
 
-#: fortran/decl.c:6636
+#: fortran/decl.c:6655
 #, gcc-internal-format
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr ""
 
-#: fortran/decl.c:6682 fortran/decl.c:6870 fortran/decl.c:10723
+#: fortran/decl.c:6701 fortran/decl.c:6889 fortran/decl.c:10748
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6731 fortran/decl.c:10623
+#: fortran/decl.c:6750 fortran/decl.c:10648
 #, gcc-internal-format
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr ""
 
-#: fortran/decl.c:6738
+#: fortran/decl.c:6757
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr ""
 
-#: fortran/decl.c:6742
+#: fortran/decl.c:6761
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:6814
+#: fortran/decl.c:6833
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:6832
+#: fortran/decl.c:6851
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr ""
 
-#: fortran/decl.c:6841 fortran/decl.c:9392
+#: fortran/decl.c:6860 fortran/decl.c:9411
 #, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr ""
 
-#: fortran/decl.c:6911
+#: fortran/decl.c:6930
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6983
+#: fortran/decl.c:7002
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr ""
 
-#: fortran/decl.c:7007 fortran/decl.c:7011 fortran/decl.c:7266
-#: fortran/decl.c:7270 fortran/decl.c:7462 fortran/decl.c:7466
-#: fortran/symbol.c:1875
+#: fortran/decl.c:7026 fortran/decl.c:7030 fortran/decl.c:7285
+#: fortran/decl.c:7289 fortran/decl.c:7481 fortran/decl.c:7485
+#: fortran/symbol.c:1889
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr ""
 
-#: fortran/decl.c:7164
+#: fortran/decl.c:7183
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7173
+#: fortran/decl.c:7192
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr ""
 
-#: fortran/decl.c:7176
+#: fortran/decl.c:7195
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr ""
 
-#: fortran/decl.c:7179
+#: fortran/decl.c:7198
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SUBMODULE"
 msgstr ""
 
-#: fortran/decl.c:7182
+#: fortran/decl.c:7201
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr ""
 
-#: fortran/decl.c:7186 fortran/decl.c:7231
+#: fortran/decl.c:7205 fortran/decl.c:7250
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr ""
 
-#: fortran/decl.c:7190
+#: fortran/decl.c:7209
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a STRUCTURE block"
 msgstr ""
 
-#: fortran/decl.c:7194
+#: fortran/decl.c:7213
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr ""
 
-#: fortran/decl.c:7198
+#: fortran/decl.c:7217
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr ""
 
-#: fortran/decl.c:7203
+#: fortran/decl.c:7222
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr ""
 
-#: fortran/decl.c:7207
+#: fortran/decl.c:7226
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr ""
 
-#: fortran/decl.c:7211
+#: fortran/decl.c:7230
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr ""
 
-#: fortran/decl.c:7215
+#: fortran/decl.c:7234
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr ""
 
-#: fortran/decl.c:7219
+#: fortran/decl.c:7238
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr ""
 
-#: fortran/decl.c:7223
+#: fortran/decl.c:7242
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected ENTRY statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7244
+#: fortran/decl.c:7263
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr ""
 
-#: fortran/decl.c:7295 fortran/decl.c:7501
+#: fortran/decl.c:7314 fortran/decl.c:7520
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7563 fortran/decl.c:7570
+#: fortran/decl.c:7582 fortran/decl.c:7589
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:7610
+#: fortran/decl.c:7629
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr ""
 
-#: fortran/decl.c:7626
+#: fortran/decl.c:7645
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr ""
 
-#: fortran/decl.c:7634
+#: fortran/decl.c:7653
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr ""
 
-#: fortran/decl.c:7653
+#: fortran/decl.c:7672
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing closing paren for binding label at %C"
 msgstr ""
 
-#: fortran/decl.c:7659
+#: fortran/decl.c:7678
 #, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7665
+#: fortran/decl.c:7684
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7694
+#: fortran/decl.c:7713
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr ""
 
-#: fortran/decl.c:7939
+#: fortran/decl.c:7958
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7948
+#: fortran/decl.c:7967
 #, gcc-internal-format, gfc-internal-format
 msgid "END statement instead of %s statement at %L"
 msgstr ""
 
 #. We would have required END [something].
-#: fortran/decl.c:7957
+#: fortran/decl.c:7976
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr ""
 
-#: fortran/decl.c:7968
+#: fortran/decl.c:7987
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s statement at %L"
 msgstr ""
 
-#: fortran/decl.c:7988
+#: fortran/decl.c:8007
 #, gcc-internal-format
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr ""
 
-#: fortran/decl.c:8005
+#: fortran/decl.c:8024
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr ""
 
-#: fortran/decl.c:8019 fortran/decl.c:8027
+#: fortran/decl.c:8038 fortran/decl.c:8046
 #, gcc-internal-format
 msgid "Expected label %qs for %s statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8126
+#: fortran/decl.c:8145
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr ""
 
-#: fortran/decl.c:8134
+#: fortran/decl.c:8153
 #, gcc-internal-format, gfc-internal-format
 msgid "Dimensions specified for %s at %L after its initialization"
 msgstr ""
 
-#: fortran/decl.c:8142
+#: fortran/decl.c:8161
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr ""
 
-#: fortran/decl.c:8151
+#: fortran/decl.c:8170
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr ""
 
-#: fortran/decl.c:8249
+#: fortran/decl.c:8268
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr ""
 
-#: fortran/decl.c:8286
+#: fortran/decl.c:8305
 #, gcc-internal-format
 msgid "Expected %<(%> at %C"
 msgstr ""
 
-#: fortran/decl.c:8300 fortran/decl.c:8340
+#: fortran/decl.c:8319 fortran/decl.c:8359
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr ""
 
-#: fortran/decl.c:8316
+#: fortran/decl.c:8335
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C must be an integer"
 msgstr ""
 
-#: fortran/decl.c:8320
+#: fortran/decl.c:8339
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr ""
 
-#: fortran/decl.c:8326
+#: fortran/decl.c:8345
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr ""
 
-#: fortran/decl.c:8365
+#: fortran/decl.c:8384
 #, gcc-internal-format
 msgid "Couldn't set Cray pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:8389
+#: fortran/decl.c:8408
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr ""
 
-#: fortran/decl.c:8401
+#: fortran/decl.c:8420
 #, gcc-internal-format
 msgid "Expected %<,%> or end of statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8427
+#: fortran/decl.c:8446
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:8459
+#: fortran/decl.c:8478
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:8478
+#: fortran/decl.c:8497
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer declaration at %C requires -fcray-pointer flag"
 msgstr ""
 
-#: fortran/decl.c:8517
+#: fortran/decl.c:8536
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8623
+#: fortran/decl.c:8642
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:8640
+#: fortran/decl.c:8659
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:8679
+#: fortran/decl.c:8698
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8717
+#: fortran/decl.c:8736
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8741
+#: fortran/decl.c:8760
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:8778
+#: fortran/decl.c:8797
 #, gcc-internal-format, gfc-internal-format
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:8806
+#: fortran/decl.c:8825
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr ""
 
-#: fortran/decl.c:8813
+#: fortran/decl.c:8832
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8819
+#: fortran/decl.c:8838
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr ""
 
-#: fortran/decl.c:8839
+#: fortran/decl.c:8858
 #, gcc-internal-format, gfc-internal-format
 msgid "Initializing already initialized variable at %C"
 msgstr ""
 
 #. With legacy PARAMETER statements, don't expect a terminating ')'.
-#: fortran/decl.c:8864
+#: fortran/decl.c:8883
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER without '()' at %C"
 msgstr ""
 
-#: fortran/decl.c:8880
+#: fortran/decl.c:8899
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8899 fortran/decl.c:8955
+#: fortran/decl.c:8918 fortran/decl.c:8974
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:8934
+#: fortran/decl.c:8953
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in AUTOMATIC statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8941
+#: fortran/decl.c:8960
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in AUTOMATIC statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8990
+#: fortran/decl.c:9009
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in STATIC statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8997
+#: fortran/decl.c:9016
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in STATIC statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9016
+#: fortran/decl.c:9035
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:9027
+#: fortran/decl.c:9046
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:9073
+#: fortran/decl.c:9092
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9087
+#: fortran/decl.c:9106
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:9091
+#: fortran/decl.c:9110
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9129
+#: fortran/decl.c:9148
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VALUE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9141
+#: fortran/decl.c:9160
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9168
+#: fortran/decl.c:9187
 #, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr ""
 
-#: fortran/decl.c:9193
+#: fortran/decl.c:9212
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9205
+#: fortran/decl.c:9224
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9249
+#: fortran/decl.c:9268
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9274
+#: fortran/decl.c:9293
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:9367
+#: fortran/decl.c:9386
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr ""
 
-#: fortran/decl.c:9425
+#: fortran/decl.c:9444
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr ""
 
-#: fortran/decl.c:9474
+#: fortran/decl.c:9493
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr ""
 
-#: fortran/decl.c:9483
+#: fortran/decl.c:9502
 #, gcc-internal-format
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr ""
 
-#: fortran/decl.c:9489
+#: fortran/decl.c:9508
 #, gcc-internal-format
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr ""
 
-#: fortran/decl.c:9496
+#: fortran/decl.c:9515
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:9503
+#: fortran/decl.c:9522
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr ""
 
-#: fortran/decl.c:9526
+#: fortran/decl.c:9545
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:9538
+#: fortran/decl.c:9557
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:9559
+#: fortran/decl.c:9578
 #, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
 msgstr ""
 
-#: fortran/decl.c:9605
+#: fortran/decl.c:9624
 #, gcc-internal-format, gfc-internal-format
 msgid "Failed to create structure type '%s' at %C"
 msgstr ""
 
-#: fortran/decl.c:9611
+#: fortran/decl.c:9630
 #, gcc-internal-format
 msgid "Type definition of %qs at %C was already defined at %L"
 msgstr ""
 
-#: fortran/decl.c:9658
+#: fortran/decl.c:9677
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after MAP statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9691
+#: fortran/decl.c:9710
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after UNION statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9726
+#: fortran/decl.c:9745
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr ""
 
-#: fortran/decl.c:9740
+#: fortran/decl.c:9759
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected in non-nested structure declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:9758
+#: fortran/decl.c:9777
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after non-nested STRUCTURE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9765
+#: fortran/decl.c:9784
 #, gcc-internal-format
 msgid "Structure name %qs at %C cannot be the same as an intrinsic type"
 msgstr ""
 
-#: fortran/decl.c:9926
+#: fortran/decl.c:9947
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr ""
 
-#: fortran/decl.c:9954
+#: fortran/decl.c:9975
 #, gcc-internal-format
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr ""
 
-#: fortran/decl.c:9964
+#: fortran/decl.c:9986
 #, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr ""
 
-#: fortran/decl.c:9981
+#: fortran/decl.c:9989
 #, gcc-internal-format
+msgid "Derived type name %qs at %C already has a basic type"
+msgstr ""
+
+#: fortran/decl.c:10006
+#, gcc-internal-format
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr ""
 
-#: fortran/decl.c:10042
+#: fortran/decl.c:10067
 #, gcc-internal-format, gfc-internal-format
 msgid "Garbage after PARAMETERIZED TYPE declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:10126
+#: fortran/decl.c:10151
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr ""
 
-#: fortran/decl.c:10146
+#: fortran/decl.c:10171
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM and ENUMERATOR at %C"
 msgstr ""
 
-#: fortran/decl.c:10178
+#: fortran/decl.c:10203
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr ""
 
-#: fortran/decl.c:10257
+#: fortran/decl.c:10282
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr ""
 
-#: fortran/decl.c:10305
+#: fortran/decl.c:10330
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr ""
 
-#: fortran/decl.c:10341
+#: fortran/decl.c:10366
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr ""
 
-#: fortran/decl.c:10388 fortran/decl.c:10403
+#: fortran/decl.c:10413 fortran/decl.c:10428
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate access-specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:10423
+#: fortran/decl.c:10448
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10443
+#: fortran/decl.c:10468
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10470
+#: fortran/decl.c:10495
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:10488
+#: fortran/decl.c:10513
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr ""
 
-#: fortran/decl.c:10504
+#: fortran/decl.c:10529
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DEFERRED at %C"
 msgstr ""
 
-#: fortran/decl.c:10517
+#: fortran/decl.c:10542
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected access-specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:10519
+#: fortran/decl.c:10544
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:10527
+#: fortran/decl.c:10552
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED can't both appear at %C"
 msgstr ""
 
-#: fortran/decl.c:10539
+#: fortran/decl.c:10564
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:10581
+#: fortran/decl.c:10606
 #, gcc-internal-format
 msgid "Interface-name expected after %<(%> at %C"
 msgstr ""
 
-#: fortran/decl.c:10587
+#: fortran/decl.c:10612
 #, gcc-internal-format
 msgid "%<)%> expected at %C"
 msgstr ""
 
-#: fortran/decl.c:10607
+#: fortran/decl.c:10632
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:10612
+#: fortran/decl.c:10637
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:10635
+#: fortran/decl.c:10660
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr ""
 
-#: fortran/decl.c:10639
+#: fortran/decl.c:10664
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
 msgstr ""
 
-#: fortran/decl.c:10651
+#: fortran/decl.c:10676
 #, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:10657
+#: fortran/decl.c:10682
 #, gcc-internal-format
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr ""
 
-#: fortran/decl.c:10667
+#: fortran/decl.c:10692
 #, gcc-internal-format
 msgid "Expected binding target after %<=>%> at %C"
 msgstr ""
 
-#: fortran/decl.c:10684
+#: fortran/decl.c:10709
 #, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr ""
 
-#: fortran/decl.c:10695
+#: fortran/decl.c:10720
 #, gcc-internal-format
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:10746
+#: fortran/decl.c:10771
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr ""
 
-#: fortran/decl.c:10766
+#: fortran/decl.c:10791
 #, gcc-internal-format
 msgid "Expected %<::%> at %C"
 msgstr ""
 
-#: fortran/decl.c:10778
+#: fortran/decl.c:10803
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected generic name or operator descriptor at %C"
 msgstr ""
 
-#: fortran/decl.c:10799
+#: fortran/decl.c:10824
 #, gcc-internal-format, gfc-internal-format
 msgid "Malformed GENERIC statement at %C"
 msgstr ""
 
-#: fortran/decl.c:10810
+#: fortran/decl.c:10835
 #, gcc-internal-format
 msgid "Expected %<=>%> at %C"
 msgstr ""
 
-#: fortran/decl.c:10846
+#: fortran/decl.c:10871
 #, gcc-internal-format
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:10854
+#: fortran/decl.c:10879
 #, gcc-internal-format
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr ""
 
-#: fortran/decl.c:10902
+#: fortran/decl.c:10927
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr ""
 
-#: fortran/decl.c:10912
+#: fortran/decl.c:10937
 #, gcc-internal-format
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:10930
+#: fortran/decl.c:10955
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr ""
 
-#: fortran/decl.c:10965
+#: fortran/decl.c:10990
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr ""
 
-#: fortran/decl.c:10976
+#: fortran/decl.c:11001
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr ""
 
-#: fortran/decl.c:10998
+#: fortran/decl.c:11023
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr ""
 
-#: fortran/decl.c:11005
+#: fortran/decl.c:11030
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr ""
 
-#: fortran/decl.c:11015
+#: fortran/decl.c:11040
 #, gcc-internal-format
 msgid "Expected %<,%> at %C"
 msgstr ""
 
-#: fortran/decl.c:11021
+#: fortran/decl.c:11046
 #, fuzzy, gcc-internal-format
 #| msgid "unknown register name: %s"
 msgid "Unknown procedure name %qs at %C"
 msgstr "невядомая назва рэгістра: %s"
 
-#: fortran/decl.c:11034
+#: fortran/decl.c:11059
 #, gcc-internal-format
 msgid "%qs at %C is already defined as FINAL procedure"
 msgstr ""
 
-#: fortran/decl.c:11104
+#: fortran/decl.c:11129
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr ""
 
-#: fortran/decl.c:11150
+#: fortran/decl.c:11175
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr ""
 
-#: fortran/decl.c:11170
+#: fortran/decl.c:11195
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive requires a non-negative integral constant less than or equal to %u at %C"
 msgstr ""
 
-#: fortran/decl.c:11184
+#: fortran/decl.c:11209
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ UNROLL directive at %C"
 msgstr ""
@@ -54363,27 +54437,27 @@
 msgid "BOZ literal at %L used to initialize non-integer variable %qs"
 msgstr ""
 
-#: fortran/expr.c:3369 fortran/resolve.c:10197
+#: fortran/expr.c:3369 fortran/resolve.c:10210
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal at %L outside a DATA statement and outside INT/REAL/DBLE/CMPLX"
 msgstr ""
 
-#: fortran/expr.c:3380 fortran/resolve.c:10208
+#: fortran/expr.c:3380 fortran/resolve.c:10221
 #, gcc-internal-format
 msgid "BOZ literal at %L is bitwise transferred non-integer symbol %qs"
 msgstr ""
 
-#: fortran/expr.c:3388 fortran/resolve.c:10217
+#: fortran/expr.c:3388 fortran/resolve.c:10230
 #, gcc-internal-format
 msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3392 fortran/resolve.c:10221
+#: fortran/expr.c:3392 fortran/resolve.c:10234
 #, gcc-internal-format
 msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3396 fortran/resolve.c:10225
+#: fortran/expr.c:3396 fortran/resolve.c:10238
 #, gcc-internal-format
 msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
@@ -54393,147 +54467,147 @@
 msgid "The assignment to a KIND or LEN component of a parameterized type at %L is not allowed"
 msgstr ""
 
-#: fortran/expr.c:3426
+#: fortran/expr.c:3429
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible types in DATA statement at %L; attempted conversion of %s to %s"
 msgstr ""
 
-#: fortran/expr.c:3465
+#: fortran/expr.c:3468
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is not a POINTER at %L"
 msgstr ""
 
-#: fortran/expr.c:3473
+#: fortran/expr.c:3476
 #, gcc-internal-format
 msgid "%qs in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgstr ""
 
-#: fortran/expr.c:3496
+#: fortran/expr.c:3499
 #, gcc-internal-format
 msgid "Expected bounds specification for %qs at %L"
 msgstr ""
 
-#: fortran/expr.c:3501
+#: fortran/expr.c:3504
 #, gcc-internal-format
 msgid "Bounds specification for %qs in pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3514
+#: fortran/expr.c:3517
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower bound has to be present at %L"
 msgstr ""
 
-#: fortran/expr.c:3520
+#: fortran/expr.c:3523
 #, gcc-internal-format, gfc-internal-format
 msgid "Stride must not be present at %L"
 msgstr ""
 
-#: fortran/expr.c:3532
+#: fortran/expr.c:3535
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the upper bounds must be specified at %L"
 msgstr ""
 
-#: fortran/expr.c:3558
+#: fortran/expr.c:3561
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %L shall not have a coindex"
 msgstr ""
 
-#: fortran/expr.c:3579
+#: fortran/expr.c:3582
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3603
+#: fortran/expr.c:3606
 #, gcc-internal-format
 msgid "Function result %qs is invalid as proc-target in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3612
+#: fortran/expr.c:3615
 #, gcc-internal-format
 msgid "Abstract interface %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3622
+#: fortran/expr.c:3625
 #, gcc-internal-format
 msgid "Statement function %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3628
+#: fortran/expr.c:3631
 #, gcc-internal-format
 msgid "Internal procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3635
+#: fortran/expr.c:3638
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L is invalid in procedure pointer assignment"
 msgstr ""
 
-#: fortran/expr.c:3643
+#: fortran/expr.c:3646
 #, gcc-internal-format
 msgid "Nonintrinsic elemental procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3666
+#: fortran/expr.c:3669
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in the procedure pointer assignment at %L: mismatch in the calling convention"
 msgstr ""
 
-#: fortran/expr.c:3719
+#: fortran/expr.c:3722
 #, gcc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %qs is not a subroutine"
 msgstr ""
 
-#: fortran/expr.c:3729 fortran/expr.c:3744
+#: fortran/expr.c:3732 fortran/expr.c:3747
 #, gcc-internal-format
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr ""
 
-#: fortran/expr.c:3735 fortran/expr.c:3750 fortran/resolve.c:2566
+#: fortran/expr.c:3738 fortran/expr.c:3753 fortran/resolve.c:2566
 #, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr ""
 
-#: fortran/expr.c:3762
+#: fortran/expr.c:3765
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %s"
 msgstr ""
 
-#: fortran/expr.c:3771
+#: fortran/expr.c:3774
 #, gcc-internal-format
 msgid "Procedure pointer target %qs at %L must be either an intrinsic, host or use associated, referenced or have the EXTERNAL attribute"
 msgstr ""
 
-#: fortran/expr.c:3788
+#: fortran/expr.c:3791
 #, gcc-internal-format, gfc-internal-format
 msgid "Data-pointer-object at %L must be unlimited polymorphic, or of a type with the BIND or SEQUENCE attribute, to be compatible with an unlimited polymorphic target"
 msgstr ""
 
-#: fortran/expr.c:3793
+#: fortran/expr.c:3796
 #, gcc-internal-format, gfc-internal-format
 msgid "Different types in pointer assignment at %L; attempted assignment of %s to %s"
 msgstr ""
 
-#: fortran/expr.c:3802
+#: fortran/expr.c:3805
 #, gcc-internal-format, gfc-internal-format
 msgid "Different kind type parameters in pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3809
+#: fortran/expr.c:3812
 #, gcc-internal-format, gfc-internal-format
 msgid "Different ranks in pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3828
+#: fortran/expr.c:3831
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is smaller than size of the pointer (%ld < %ld) at %L"
 msgstr ""
 
-#: fortran/expr.c:3841
+#: fortran/expr.c:3844
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target must be rank 1 or simply contiguous at %L"
 msgstr ""
 
-#: fortran/expr.c:3845
+#: fortran/expr.c:3848
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is not rank 1 at %L"
 msgstr ""
@@ -54541,147 +54615,152 @@
 #. The test above might need to be extend when F08, Note 5.4 has to be
 #. interpreted in the way that target and pointer with the same coindex
 #. are allowed.
-#: fortran/expr.c:3877 fortran/expr.c:3925
+#: fortran/expr.c:3880 fortran/expr.c:3928
 #, gcc-internal-format, gfc-internal-format
 msgid "Data target at %L shall not have a coindex"
 msgstr ""
 
-#: fortran/expr.c:3880
+#: fortran/expr.c:3883
 #, gcc-internal-format, gfc-internal-format
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr ""
 
-#: fortran/expr.c:3888
+#: fortran/expr.c:3891
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr ""
 
-#: fortran/expr.c:3895
+#: fortran/expr.c:3898
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr ""
 
-#: fortran/expr.c:3904
+#: fortran/expr.c:3907
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr ""
 
-#: fortran/expr.c:3912
+#: fortran/expr.c:3915
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/expr.c:3936
+#: fortran/expr.c:3939
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to contiguous pointer from non-contiguous target at %L"
 msgstr ""
 
-#: fortran/expr.c:3975
+#: fortran/expr.c:3978
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr ""
 
-#: fortran/expr.c:4051 fortran/resolve.c:1452
+#: fortran/expr.c:4054 fortran/resolve.c:1452
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/expr.c:4057
+#: fortran/expr.c:4060
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr ""
 
-#: fortran/expr.c:4072 fortran/resolve.c:1458
+#: fortran/expr.c:4075 fortran/resolve.c:1458
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr ""
 
-#: fortran/expr.c:4084
+#: fortran/expr.c:4087
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr ""
 
-#: fortran/expr.c:5512
+#: fortran/expr.c:4557
+#, gcc-internal-format
+msgid "generate_isocbinding_initializer(): bad iso_c_binding type, expected %<c_ptr%> or %<c_funptr%>"
+msgstr ""
+
+#: fortran/expr.c:5568
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5520
+#: fortran/expr.c:5576
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5528
+#: fortran/expr.c:5584
 #, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5537
+#: fortran/expr.c:5593
 #, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr ""
 
-#: fortran/expr.c:5548
+#: fortran/expr.c:5604
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5557
+#: fortran/expr.c:5613
 #, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5570
+#: fortran/expr.c:5626
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5583
+#: fortran/expr.c:5639
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5613
+#: fortran/expr.c:5669
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5621
+#: fortran/expr.c:5677
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5634
+#: fortran/expr.c:5690
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5642
+#: fortran/expr.c:5698
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5654
+#: fortran/expr.c:5710
 #, gcc-internal-format
 msgid "Variable %qs can not appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr ""
 
-#: fortran/expr.c:5713
+#: fortran/expr.c:5769
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:5717
+#: fortran/expr.c:5773
 #, gcc-internal-format
 msgid "%qs at %L associated to expression can not be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:5728
+#: fortran/expr.c:5784
 #, gcc-internal-format
 msgid "Associate-name %qs can not appear in a variable definition context (%s) at %L because its target at %L can not, either"
 msgstr ""
 
-#: fortran/expr.c:5770
+#: fortran/expr.c:5826
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr ""
@@ -54692,22 +54771,22 @@
 msgid "can't open input file: %s"
 msgstr "немагчыма зачыніць уваходзячы файл %s"
 
-#: fortran/frontend-passes.c:190
+#: fortran/frontend-passes.c:192
 #, gcc-internal-format
 msgid "No location in statement"
 msgstr ""
 
-#: fortran/frontend-passes.c:205
+#: fortran/frontend-passes.c:207
 #, gcc-internal-format, gfc-internal-format
 msgid "No location in expression near %L"
 msgstr ""
 
-#: fortran/frontend-passes.c:409
+#: fortran/frontend-passes.c:414
 #, gcc-internal-format
 msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
-#: fortran/frontend-passes.c:817 fortran/trans-array.c:1182
+#: fortran/frontend-passes.c:822 fortran/trans-array.c:1182
 #: fortran/trans-array.c:6440 fortran/trans-array.c:7864
 #: fortran/trans-intrinsic.c:7307
 #, gcc-internal-format, gfc-internal-format
@@ -54714,68 +54793,68 @@
 msgid "Creating array temporary at %L"
 msgstr ""
 
-#: fortran/frontend-passes.c:842 fortran/frontend-passes.c:846
+#: fortran/frontend-passes.c:847 fortran/frontend-passes.c:851
 #, fuzzy, gcc-internal-format
 msgid "Removing call to function %qs at %L"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: fortran/frontend-passes.c:1273 fortran/frontend-passes.c:1312
+#: fortran/frontend-passes.c:1278 fortran/frontend-passes.c:1317
 #, fuzzy, gcc-internal-format
 #| msgid "bad header version"
 msgid "bad expression"
 msgstr "дрэнная версія загалоўка"
 
-#: fortran/frontend-passes.c:1308
+#: fortran/frontend-passes.c:1313
 #, gcc-internal-format
 msgid "bad op"
 msgstr ""
 
-#: fortran/frontend-passes.c:2161
+#: fortran/frontend-passes.c:2166
 #, gcc-internal-format
 msgid "illegal OP in optimize_comparison"
 msgstr ""
 
-#: fortran/frontend-passes.c:2407
+#: fortran/frontend-passes.c:2412
 #, gcc-internal-format
 msgid "Variable %qs at %L set to undefined value inside loop  beginning at %L as INTENT(OUT) argument to subroutine %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:2414
+#: fortran/frontend-passes.c:2419
 #, gcc-internal-format
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to subroutine %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:2637 fortran/frontend-passes.c:2661
+#: fortran/frontend-passes.c:2642 fortran/frontend-passes.c:2666
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L out of bounds (%ld < %ld) in loop beginning at %L"
 msgstr ""
 
-#: fortran/frontend-passes.c:2646 fortran/frontend-passes.c:2670
+#: fortran/frontend-passes.c:2651 fortran/frontend-passes.c:2675
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L out of bounds (%ld > %ld) in loop beginning at %L"
 msgstr ""
 
-#: fortran/frontend-passes.c:2730
+#: fortran/frontend-passes.c:2735
 #, gcc-internal-format
 msgid "Variable %qs at %L set to undefined value inside loop beginning at %L as INTENT(OUT) argument to function %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:2736
+#: fortran/frontend-passes.c:2741
 #, gcc-internal-format
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:3128 fortran/trans-expr.c:1581
+#: fortran/frontend-passes.c:3133 fortran/trans-expr.c:1581
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr ""
 
-#: fortran/frontend-passes.c:3637
+#: fortran/frontend-passes.c:3642
 #, gcc-internal-format
 msgid "Scalarization using DIMEN_RANGE unimplemented"
 msgstr ""
 
-#: fortran/frontend-passes.c:4429
+#: fortran/frontend-passes.c:4434
 #, gcc-internal-format, gfc-internal-format
 msgid "Interchanging loops at %L"
 msgstr ""
@@ -54895,12 +54974,12 @@
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:970 fortran/resolve.c:16351
+#: fortran/interface.c:970 fortran/resolve.c:16378
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:977 fortran/resolve.c:16369
+#: fortran/interface.c:977 fortran/resolve.c:16396
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
@@ -56094,7 +56173,7 @@
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.c:3369 fortran/resolve.c:14263
+#: fortran/io.c:3369 fortran/resolve.c:14283
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -56264,7 +56343,7 @@
 msgid "Integer too large at %C"
 msgstr ""
 
-#: fortran/match.c:580 fortran/parse.c:1132
+#: fortran/match.c:580 fortran/parse.c:1136
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many digits in statement label at %C"
 msgstr ""
@@ -57025,57 +57104,57 @@
 msgid "Expected block name %qs of SELECT construct at %C"
 msgstr ""
 
-#: fortran/match.c:6186
+#: fortran/match.c:6201
 #, gcc-internal-format, gfc-internal-format
 msgid "parse error in SELECT TYPE statement at %C"
 msgstr ""
 
-#: fortran/match.c:6211
+#: fortran/match.c:6226
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr ""
 
-#: fortran/match.c:6249
+#: fortran/match.c:6264
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr ""
 
-#: fortran/match.c:6301
+#: fortran/match.c:6316
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CASE specification at %C"
 msgstr ""
 
-#: fortran/match.c:6319
+#: fortran/match.c:6334
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected TYPE IS statement at %C"
 msgstr ""
 
-#: fortran/match.c:6351
+#: fortran/match.c:6366
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr ""
 
-#: fortran/match.c:6362
+#: fortran/match.c:6377
 #, gcc-internal-format, gfc-internal-format
 msgid "All the LEN type parameters in the TYPE IS statement at %C must be ASSUMED"
 msgstr ""
 
-#: fortran/match.c:6373
+#: fortran/match.c:6388
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr ""
 
-#: fortran/match.c:6449
+#: fortran/match.c:6464
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr ""
 
-#: fortran/match.c:6572
+#: fortran/match.c:6587
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr ""
 
-#: fortran/match.c:6610
+#: fortran/match.c:6625
 #, gcc-internal-format
 msgid "Label %qs at %C doesn't match WHERE label %qs"
 msgstr ""
@@ -57228,194 +57307,194 @@
 msgid "mio_array_ref(): Unknown array ref"
 msgstr ""
 
-#: fortran/module.c:3716
+#: fortran/module.c:3718
 #, gcc-internal-format, gfc-internal-format
 msgid "Namelist %s cannot be renamed by USE association to %s"
 msgstr ""
 
-#: fortran/module.c:4832
+#: fortran/module.c:4834
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4835
+#: fortran/module.c:4837
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:5029
+#: fortran/module.c:5031
 #, gcc-internal-format
 msgid "%qs of module %qs, imported at %C, is also the name of the current program unit"
 msgstr ""
 
-#: fortran/module.c:5381
+#: fortran/module.c:5383
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5388
+#: fortran/module.c:5390
 #, gcc-internal-format
 msgid "User operator %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5393
+#: fortran/module.c:5395
 #, gcc-internal-format
 msgid "Intrinsic operator %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5628
+#: fortran/module.c:5630
 #, gcc-internal-format
 msgid "write_symbol(): bad module symbol %qs"
 msgstr ""
 
-#: fortran/module.c:5961
+#: fortran/module.c:5963
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr ""
 
-#: fortran/module.c:6148
+#: fortran/module.c:6150
 #, fuzzy, gcc-internal-format
 #| msgid "%s: can't open file `%s' for reading: %s\n"
 msgid "Can't open module file %qs for writing at %C: %s"
 msgstr "%s: немагчыма адчыніць файл `%s' для чытаньня: %s\n"
 
-#: fortran/module.c:6169
+#: fortran/module.c:6171
 #, fuzzy, gcc-internal-format
 #| msgid "%s: can't open file `%s' for reading: %s\n"
 msgid "Error writing module file %qs for writing: %s"
 msgstr "%s: немагчыма адчыніць файл `%s' для чытаньня: %s\n"
 
-#: fortran/module.c:6180
+#: fortran/module.c:6182
 #, fuzzy, gcc-internal-format
 #| msgid "%s: can't delete file `%s': %s\n"
 msgid "Can't delete module file %qs: %s"
 msgstr "%s: немагчыма знішчыць файл \"%s\": %s\n"
 
-#: fortran/module.c:6183
+#: fortran/module.c:6185
 #, fuzzy, gcc-internal-format
 #| msgid "%s: can't change mode of file `%s': %s\n"
 msgid "Can't rename module file %qs to %qs: %s"
 msgstr "%s: немагчыма зьмяніць рэжым файла `%s': %s\n"
 
-#: fortran/module.c:6189
+#: fortran/module.c:6191
 #, fuzzy, gcc-internal-format
 #| msgid "%s: can't delete file `%s': %s\n"
 msgid "Can't delete temporary module file %qs: %s"
 msgstr "%s: немагчыма знішчыць файл \"%s\": %s\n"
 
-#: fortran/module.c:6246
+#: fortran/module.c:6248
 #, gcc-internal-format
 msgid "Symbol %qs at %C already declared"
 msgstr ""
 
-#: fortran/module.c:6317
+#: fortran/module.c:6319
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr ""
 
-#: fortran/module.c:6425 fortran/module.c:6769
+#: fortran/module.c:6427 fortran/module.c:6771
 #, gcc-internal-format
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr ""
 
-#: fortran/module.c:6553
+#: fortran/module.c:6555
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr ""
 
-#: fortran/module.c:6574 fortran/module.c:6607 fortran/module.c:6649
+#: fortran/module.c:6576 fortran/module.c:6609 fortran/module.c:6651
 #, gcc-internal-format
 msgid "Symbol %qs already declared"
 msgstr ""
 
-#: fortran/module.c:6754
+#: fortran/module.c:6756
 #, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:6776
+#: fortran/module.c:6778
 #, gcc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr ""
 
-#: fortran/module.c:6844
+#: fortran/module.c:6846
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr ""
 
-#: fortran/module.c:6898
+#: fortran/module.c:6900
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr ""
 
-#: fortran/module.c:6924
+#: fortran/module.c:6926
 #, gcc-internal-format, gfc-internal-format
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr ""
 
-#: fortran/module.c:6953
+#: fortran/module.c:6955
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr ""
 
-#: fortran/module.c:6965
+#: fortran/module.c:6967
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
 msgstr ""
 
-#: fortran/module.c:6978
+#: fortran/module.c:6980
 #, gcc-internal-format
 msgid "Can't find an intrinsic module named %qs at %C"
 msgstr ""
 
-#: fortran/module.c:6984
+#: fortran/module.c:6986
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr ""
 
-#: fortran/module.c:6990
+#: fortran/module.c:6992
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr ""
 
-#: fortran/module.c:6996
+#: fortran/module.c:6998
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr ""
 
-#: fortran/module.c:7006
+#: fortran/module.c:7008
 #, fuzzy, gcc-internal-format
 #| msgid "%s: can't open file `%s' for reading: %s\n"
 msgid "Can't open module file %qs for reading at %C: %s"
 msgstr "%s: немагчыма адчыніць файл `%s' для чытаньня: %s\n"
 
-#: fortran/module.c:7009
+#: fortran/module.c:7011
 #, gcc-internal-format
 msgid "Module file %qs has not been generated, either because the module does not contain a MODULE PROCEDURE or there is an error in the module."
 msgstr ""
 
-#: fortran/module.c:7020
+#: fortran/module.c:7022
 #, gcc-internal-format
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:7043
+#: fortran/module.c:7045
 #, gcc-internal-format
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr ""
 
-#: fortran/module.c:7051
+#: fortran/module.c:7053
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr ""
 
-#: fortran/module.c:7066
+#: fortran/module.c:7068
 #, gcc-internal-format, gfc-internal-format
 msgid "Can't USE the same %smodule we're building"
 msgstr ""
 
 #: fortran/openmp.c:296 fortran/openmp.c:397 fortran/openmp.c:692
-#: fortran/openmp.c:3167
+#: fortran/openmp.c:3166
 #, gcc-internal-format, gfc-internal-format
 msgid "COMMON block /%s/ not found at %C"
 msgstr ""
@@ -57492,859 +57571,859 @@
 
 #: fortran/openmp.c:2180
 #, fuzzy, gcc-internal-format, gfc-internal-format
-msgid "Invalid argument to !$ACC WAIT at %L"
+msgid "Invalid argument to !$ACC WAIT at %C"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: fortran/openmp.c:2188
+#: fortran/openmp.c:2187
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT clause at %L requires a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/openmp.c:2221
+#: fortran/openmp.c:2220
 #, gcc-internal-format, gfc-internal-format
 msgid "ACC CACHE directive must be inside of loop %C"
 msgstr ""
 
-#: fortran/openmp.c:2252
+#: fortran/openmp.c:2251
 #, gcc-internal-format
 msgid "Multiple loop axes specified for routine"
 msgstr ""
 
-#: fortran/openmp.c:2278
+#: fortran/openmp.c:2277
 #, gcc-internal-format, gfc-internal-format
 msgid "Only the !$ACC ROUTINE form without list is allowed in interface block at %C"
 msgstr ""
 
-#: fortran/openmp.c:2306
+#: fortran/openmp.c:2305
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$ACC ROUTINE ( NAME ) at %C, invalid function name %s"
 msgstr ""
 
-#: fortran/openmp.c:2315
+#: fortran/openmp.c:2314
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$ACC ROUTINE ( NAME ) at %C"
 msgstr ""
 
-#: fortran/openmp.c:2322
+#: fortran/openmp.c:2321
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$ACC ROUTINE ( NAME ) at %C, expecting ')' after NAME"
 msgstr ""
 
-#: fortran/openmp.c:2457 fortran/openmp.c:2481
+#: fortran/openmp.c:2456 fortran/openmp.c:2480
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP CRITICAL statement at %C"
 msgstr ""
 
-#: fortran/openmp.c:2548
+#: fortran/openmp.c:2547
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP FLUSH statement at %C"
 msgstr ""
 
-#: fortran/openmp.c:2942 fortran/openmp.c:6225
+#: fortran/openmp.c:2941 fortran/openmp.c:6230
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined %s !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2946 fortran/openmp.c:6229
+#: fortran/openmp.c:2945 fortran/openmp.c:6234
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2951
+#: fortran/openmp.c:2950
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2953
+#: fortran/openmp.c:2952
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2973
+#: fortran/openmp.c:2972
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after !$OMP DECLARE REDUCTION at %C"
 msgstr ""
 
-#: fortran/openmp.c:3010
+#: fortran/openmp.c:3009
 #, gcc-internal-format, gfc-internal-format
 msgid "Only the !$OMP DECLARE TARGET form without clauses is allowed in interface block at %C"
 msgstr ""
 
-#: fortran/openmp.c:3025
+#: fortran/openmp.c:3024
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after !$OMP DECLARE TARGET at %C"
 msgstr ""
 
-#: fortran/openmp.c:3048
+#: fortran/openmp.c:3047
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET variable at %L is an element of a COMMON block"
 msgstr ""
 
-#: fortran/openmp.c:3053
+#: fortran/openmp.c:3052
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET variable at %L previously mentioned in LINK clause and later in TO clause"
 msgstr ""
 
-#: fortran/openmp.c:3059
+#: fortran/openmp.c:3058
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET variable at %L previously mentioned in TO clause and later in LINK clause"
 msgstr ""
 
-#: fortran/openmp.c:3063
+#: fortran/openmp.c:3062
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable at %L mentioned multiple times in clauses of the same OMP DECLARE TARGET directive"
 msgstr ""
 
-#: fortran/openmp.c:3078
+#: fortran/openmp.c:3077
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET COMMON at %L previously mentioned in LINK clause and later in TO clause"
 msgstr ""
 
-#: fortran/openmp.c:3084
+#: fortran/openmp.c:3083
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET COMMON at %L previously mentioned in TO clause and later in LINK clause"
 msgstr ""
 
-#: fortran/openmp.c:3088
+#: fortran/openmp.c:3087
 #, gcc-internal-format, gfc-internal-format
 msgid "COMMON at %L mentioned multiple times in clauses of the same OMP DECLARE TARGET directive"
 msgstr ""
 
-#: fortran/openmp.c:3115
+#: fortran/openmp.c:3114
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$OMP DECLARE TARGET list at %C"
 msgstr ""
 
-#: fortran/openmp.c:3147
+#: fortran/openmp.c:3146
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate variable at %C is an element of a COMMON block"
 msgstr ""
 
-#: fortran/openmp.c:3184
+#: fortran/openmp.c:3183
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after OMP THREADPRIVATE at %C"
 msgstr ""
 
-#: fortran/openmp.c:3191
+#: fortran/openmp.c:3190
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$OMP THREADPRIVATE list at %C"
 msgstr ""
 
-#: fortran/openmp.c:3405
+#: fortran/openmp.c:3404
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after TASKWAIT clause at %C"
 msgstr ""
 
-#: fortran/openmp.c:3419
+#: fortran/openmp.c:3418
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after TASKYIELD clause at %C"
 msgstr ""
 
-#: fortran/openmp.c:3478
+#: fortran/openmp.c:3477
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP WORKSHARE statement at %C"
 msgstr ""
 
-#: fortran/openmp.c:3492
+#: fortran/openmp.c:3491
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP MASTER statement at %C"
 msgstr ""
 
-#: fortran/openmp.c:3551
+#: fortran/openmp.c:3550
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP ATOMIC statement at %C"
 msgstr ""
 
-#: fortran/openmp.c:3578
+#: fortran/openmp.c:3577
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP BARRIER statement at %C"
 msgstr ""
 
-#: fortran/openmp.c:3592
+#: fortran/openmp.c:3591
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP TASKGROUP statement at %C"
 msgstr ""
 
-#: fortran/openmp.c:3642
+#: fortran/openmp.c:3641
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP CANCELLATION POINT statement at %C"
 msgstr ""
 
-#: fortran/openmp.c:3662
+#: fortran/openmp.c:3661
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after NOWAIT clause at %C"
 msgstr ""
 
-#: fortran/openmp.c:3704
+#: fortran/openmp.c:3703
 #, gcc-internal-format, gfc-internal-format
 msgid "%s clause at %L requires a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/openmp.c:3715
+#: fortran/openmp.c:3714
 #, gcc-internal-format, gfc-internal-format
 msgid "INTEGER expression of %s clause at %L must be positive"
 msgstr ""
 
-#: fortran/openmp.c:3726
+#: fortran/openmp.c:3725
 #, gcc-internal-format, gfc-internal-format
 msgid "INTEGER expression of %s clause at %L must be non-negative"
 msgstr ""
 
-#: fortran/openmp.c:3737
+#: fortran/openmp.c:3736
 #, gcc-internal-format
 msgid "POINTER object %qs of derived type in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3740
+#: fortran/openmp.c:3739
 #, gcc-internal-format
 msgid "Cray pointer object %qs of derived type in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3743
+#: fortran/openmp.c:3742
 #, gcc-internal-format
 msgid "Cray pointee object %qs of derived type in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3749 fortran/openmp.c:4687
+#: fortran/openmp.c:3748 fortran/openmp.c:4686
 #, gcc-internal-format
 msgid "POINTER object %qs of polymorphic type in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3754
+#: fortran/openmp.c:3753
 #, gcc-internal-format
 msgid "Cray pointer object %qs of polymorphic type in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3759
+#: fortran/openmp.c:3758
 #, gcc-internal-format
 msgid "Cray pointee object %qs of polymorphic type in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3769 fortran/openmp.c:4385 fortran/openmp.c:4490
+#: fortran/openmp.c:3768 fortran/openmp.c:4384 fortran/openmp.c:4489
 #, gcc-internal-format
 msgid "Assumed size array %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3772
+#: fortran/openmp.c:3771
 #, gcc-internal-format
 msgid "Assumed rank array %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3776
+#: fortran/openmp.c:3775
 #, gcc-internal-format
 msgid "Noncontiguous deferred shape array %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3784
+#: fortran/openmp.c:3783
 #, gcc-internal-format
 msgid "ALLOCATABLE object %qs of derived type in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3789
+#: fortran/openmp.c:3788
 #, gcc-internal-format
 msgid "ALLOCATABLE object %qs of polymorphic type in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3801 fortran/openmp.c:4480
+#: fortran/openmp.c:3800 fortran/openmp.c:4479
 #, gcc-internal-format
 msgid "POINTER object %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3806 fortran/openmp.c:4691
+#: fortran/openmp.c:3805 fortran/openmp.c:4690
 #, gcc-internal-format
 msgid "Cray pointer object %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3811 fortran/openmp.c:4694
+#: fortran/openmp.c:3810 fortran/openmp.c:4693
 #, gcc-internal-format
 msgid "Cray pointee object %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3816 fortran/openmp.c:4682
+#: fortran/openmp.c:3815 fortran/openmp.c:4681
 #, gcc-internal-format
 msgid "ALLOCATABLE object %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3819
+#: fortran/openmp.c:3818
 #, gcc-internal-format
 msgid "VALUE object %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3862
+#: fortran/openmp.c:3861
 #, gcc-internal-format, gfc-internal-format
 msgid "Implicitly declared function %s used in !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:3911
+#: fortran/openmp.c:3910
 #, gcc-internal-format, gfc-internal-format
 msgid "Implicitly declared subroutine %s used in !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:3944
+#: fortran/openmp.c:3943
 #, gcc-internal-format, gfc-internal-format
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:3952 fortran/openmp.c:3963 fortran/resolve.c:10028
-#: fortran/resolve.c:11295
+#: fortran/openmp.c:3951 fortran/openmp.c:3962 fortran/resolve.c:10041
+#: fortran/resolve.c:11315
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/openmp.c:3967
+#: fortran/openmp.c:3966
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause without modifier at %L used together with IF clauses with modifiers"
 msgstr ""
 
-#: fortran/openmp.c:4044
+#: fortran/openmp.c:4043
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause modifier %s at %L not appropriate for the current OpenMP construct"
 msgstr ""
 
-#: fortran/openmp.c:4054
+#: fortran/openmp.c:4053
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/openmp.c:4064
+#: fortran/openmp.c:4063
 #, gcc-internal-format, gfc-internal-format
 msgid "SCHEDULE clause's chunk_size at %L requires a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/openmp.c:4069
+#: fortran/openmp.c:4068
 #, gcc-internal-format, gfc-internal-format
 msgid "INTEGER expression of SCHEDULE clause's chunk_size at %L must be positive"
 msgstr ""
 
-#: fortran/openmp.c:4084
+#: fortran/openmp.c:4083
 #, gcc-internal-format
 msgid "Variable %qs is not a dummy argument at %L"
 msgstr ""
 
-#: fortran/openmp.c:4116
+#: fortran/openmp.c:4115 fortran/openmp.c:5998
 #, gcc-internal-format
 msgid "Object %qs is not a variable at %L"
 msgstr ""
 
-#: fortran/openmp.c:4132 fortran/openmp.c:4143 fortran/openmp.c:4151
-#: fortran/openmp.c:4162 fortran/openmp.c:4174 fortran/openmp.c:4189
-#: fortran/openmp.c:6023
+#: fortran/openmp.c:4131 fortran/openmp.c:4142 fortran/openmp.c:4150
+#: fortran/openmp.c:4161 fortran/openmp.c:4173 fortran/openmp.c:4188
+#: fortran/openmp.c:6028
 #, gcc-internal-format
 msgid "Symbol %qs present on multiple clauses at %L"
 msgstr ""
 
-#: fortran/openmp.c:4196
+#: fortran/openmp.c:4195
 #, gcc-internal-format
 msgid "Array %qs is not permitted in reduction at %L"
 msgstr ""
 
-#: fortran/openmp.c:4209
+#: fortran/openmp.c:4208
 #, gcc-internal-format
 msgid "Symbol %qs present on both FROM and TO clauses at %L"
 msgstr ""
 
-#: fortran/openmp.c:4231
+#: fortran/openmp.c:4230
 #, gcc-internal-format
 msgid "Non-THREADPRIVATE object %qs in COPYIN clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4239
+#: fortran/openmp.c:4238
 #, gcc-internal-format
 msgid "Assumed size array %qs in COPYPRIVATE clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4242
+#: fortran/openmp.c:4241
 #, gcc-internal-format
 msgid "INTENT(IN) POINTER %qs in COPYPRIVATE clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4250
+#: fortran/openmp.c:4249
 #, gcc-internal-format
 msgid "THREADPRIVATE object %qs in SHARED clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4253
+#: fortran/openmp.c:4252
 #, gcc-internal-format
 msgid "Cray pointee %qs in SHARED clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4256
+#: fortran/openmp.c:4255
 #, gcc-internal-format
 msgid "ASSOCIATE name %qs in SHARED clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4271
+#: fortran/openmp.c:4270
 #, gcc-internal-format
 msgid "%qs in ALIGNED clause must be POINTER, ALLOCATABLE, Cray pointer or C_PTR at %L"
 msgstr ""
 
-#: fortran/openmp.c:4283
+#: fortran/openmp.c:4282
 #, gcc-internal-format
 msgid "%qs in ALIGNED clause at %L requires a scalar positive constant integer alignment expression"
 msgstr ""
 
-#: fortran/openmp.c:4302
+#: fortran/openmp.c:4301
 #, gcc-internal-format, gfc-internal-format
 msgid "SINK dependence type only allowed on ORDERED directive at %L"
 msgstr ""
 
-#: fortran/openmp.c:4306
+#: fortran/openmp.c:4305
 #, gcc-internal-format, gfc-internal-format
 msgid "DEPEND SINK used together with DEPEND SOURCE on the same construct at %L"
 msgstr ""
 
-#: fortran/openmp.c:4316
+#: fortran/openmp.c:4315
 #, gcc-internal-format, gfc-internal-format
 msgid "SINK addend not a constant integer at %L"
 msgstr ""
 
-#: fortran/openmp.c:4322
+#: fortran/openmp.c:4321
 #, gcc-internal-format, gfc-internal-format
 msgid "Only SOURCE or SINK dependence types are allowed on ORDERED directive at %L"
 msgstr ""
 
-#: fortran/openmp.c:4333 fortran/openmp.c:4354
+#: fortran/openmp.c:4332 fortran/openmp.c:4353
 #, gcc-internal-format
 msgid "%qs in %s clause at %L is not a proper array section"
 msgstr ""
 
-#: fortran/openmp.c:4337
+#: fortran/openmp.c:4336
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coarrays not supported in %s clause at %L"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: fortran/openmp.c:4346
+#: fortran/openmp.c:4345
 #, gcc-internal-format, gfc-internal-format
 msgid "Stride should not be specified for array section in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4367
+#: fortran/openmp.c:4366
 #, gcc-internal-format
 msgid "%qs in DEPEND clause at %L is a zero size array section"
 msgstr ""
 
-#: fortran/openmp.c:4403
+#: fortran/openmp.c:4402
 #, gcc-internal-format, gfc-internal-format
 msgid "TARGET%s with map-type other than TO, FROM, TOFROM, or ALLOC on MAP clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4419
+#: fortran/openmp.c:4418
 #, gcc-internal-format, gfc-internal-format
 msgid "TARGET ENTER DATA with map-type other than TO, or ALLOC on MAP clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4434
+#: fortran/openmp.c:4433
 #, gcc-internal-format, gfc-internal-format
 msgid "TARGET EXIT DATA with map-type other than FROM, RELEASE, or DELETE on MAP clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4450 fortran/openmp.c:4466
+#: fortran/openmp.c:4449 fortran/openmp.c:4465
 #, gcc-internal-format
 msgid "THREADPRIVATE object %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4453 fortran/openmp.c:4469
+#: fortran/openmp.c:4452 fortran/openmp.c:4468
 #, gcc-internal-format
 msgid "Cray pointee %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4472
+#: fortran/openmp.c:4471
 #, gcc-internal-format
 msgid "ASSOCIATE name %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4477
+#: fortran/openmp.c:4476
 #, gcc-internal-format
 msgid "Procedure pointer %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4483
+#: fortran/openmp.c:4482
 #, gcc-internal-format
 msgid "Cray pointer %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4493
+#: fortran/openmp.c:4492
 #, gcc-internal-format
 msgid "Variable %qs in %s clause is used in NAMELIST statement at %L"
 msgstr ""
 
 #. case OMP_LIST_REDUCTION:
-#: fortran/openmp.c:4503
+#: fortran/openmp.c:4502
 #, gcc-internal-format
 msgid "INTENT(IN) POINTER %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4596
+#: fortran/openmp.c:4595
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP DECLARE REDUCTION %s not found for type %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:4622
+#: fortran/openmp.c:4621
 #, gcc-internal-format, gfc-internal-format
 msgid "LINEAR clause modifier used on DO or SIMD construct at %L"
 msgstr ""
 
-#: fortran/openmp.c:4627
+#: fortran/openmp.c:4626
 #, gcc-internal-format, gfc-internal-format
 msgid "LINEAR clause specified together with ORDERED clause with argument at %L"
 msgstr ""
 
-#: fortran/openmp.c:4632
+#: fortran/openmp.c:4631
 #, gcc-internal-format
 msgid "LINEAR variable %qs must be INTEGER at %L"
 msgstr ""
 
-#: fortran/openmp.c:4637
+#: fortran/openmp.c:4636
 #, gcc-internal-format
 msgid "LINEAR dummy argument %qs with VALUE attribute with %s modifier at %L"
 msgstr ""
 
-#: fortran/openmp.c:4648
+#: fortran/openmp.c:4647
 #, gcc-internal-format
 msgid "%qs in LINEAR clause at %L requires a scalar integer linear-step expression"
 msgstr ""
 
-#: fortran/openmp.c:4665
+#: fortran/openmp.c:4664
 #, gcc-internal-format
 msgid "%qs in LINEAR clause at %L requires a constant integer linear-step expression or dummy argument specified in UNIFORM clause"
 msgstr ""
 
-#: fortran/openmp.c:4699
+#: fortran/openmp.c:4698
 #, gcc-internal-format
 msgid "%s clause variable %qs at %L is neither a POINTER nor an array"
 msgstr ""
 
-#: fortran/openmp.c:4731
+#: fortran/openmp.c:4730
 #, gcc-internal-format, gfc-internal-format
 msgid "DIST_SCHEDULE clause's chunk_size at %L requires a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/openmp.c:4763
+#: fortran/openmp.c:4762
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible use of TILE and COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:4765
+#: fortran/openmp.c:4764
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE dependence type only allowed on ORDERED directive at %L"
 msgstr ""
 
-#: fortran/openmp.c:4778
+#: fortran/openmp.c:4777
 #, gcc-internal-format, gfc-internal-format
 msgid "%s must contain at least one MAP clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4875
+#: fortran/openmp.c:4874
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected !$OMP ATOMIC expression at %L"
 msgstr ""
 
-#: fortran/openmp.c:4904
+#: fortran/openmp.c:4903
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC statement must set a scalar variable of intrinsic type at %L"
 msgstr ""
 
-#: fortran/openmp.c:4929
+#: fortran/openmp.c:4928
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC READ statement must read from a scalar variable of intrinsic type at %L"
 msgstr ""
 
-#: fortran/openmp.c:4934
+#: fortran/openmp.c:4933
 #, gcc-internal-format, gfc-internal-format
 msgid "expr in !$OMP ATOMIC WRITE assignment var = expr must be scalar and cannot reference var at %L"
 msgstr ""
 
-#: fortran/openmp.c:4956 fortran/openmp.c:5247
+#: fortran/openmp.c:4955 fortran/openmp.c:5246
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE capture statement must read from a scalar variable of intrinsic type at %L"
 msgstr ""
 
-#: fortran/openmp.c:4971
+#: fortran/openmp.c:4970
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE update statement must set a scalar variable of intrinsic type at %L"
 msgstr ""
 
-#: fortran/openmp.c:4978 fortran/openmp.c:5254
+#: fortran/openmp.c:4977 fortran/openmp.c:5253
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE capture statement reads from different variable than update statement writes into at %L"
 msgstr ""
 
-#: fortran/openmp.c:4994
+#: fortran/openmp.c:4993
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC with ALLOCATABLE variable at %L"
 msgstr ""
 
-#: fortran/openmp.c:5036
+#: fortran/openmp.c:5035
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment operator must be binary +, *, -, /, .AND., .OR., .EQV. or .NEQV. at %L"
 msgstr ""
 
-#: fortran/openmp.c:5084
+#: fortran/openmp.c:5083
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment must be var = var op expr or var = expr op var at %L"
 msgstr ""
 
-#: fortran/openmp.c:5098
+#: fortran/openmp.c:5097
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC var = var op expr not mathematically equivalent to var = var op (expr) at %L"
 msgstr ""
 
-#: fortran/openmp.c:5130
+#: fortran/openmp.c:5129
 #, gcc-internal-format, gfc-internal-format
 msgid "expr in !$OMP ATOMIC assignment var = var op expr must be scalar and cannot reference var at %L"
 msgstr ""
 
-#: fortran/openmp.c:5154
+#: fortran/openmp.c:5153
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment intrinsic IAND, IOR or IEOR must have two arguments at %L"
 msgstr ""
 
-#: fortran/openmp.c:5161
+#: fortran/openmp.c:5160
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment intrinsic must be MIN, MAX, IAND, IOR or IEOR at %L"
 msgstr ""
 
-#: fortran/openmp.c:5178
+#: fortran/openmp.c:5177
 #, gcc-internal-format
 msgid "!$OMP ATOMIC intrinsic arguments except one must not reference %qs at %L"
 msgstr ""
 
-#: fortran/openmp.c:5185
+#: fortran/openmp.c:5184
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC intrinsic arguments must be scalar at %L"
 msgstr ""
 
-#: fortran/openmp.c:5193
+#: fortran/openmp.c:5192
 #, gcc-internal-format
 msgid "First or last !$OMP ATOMIC intrinsic argument must be %qs at %L"
 msgstr ""
 
-#: fortran/openmp.c:5211
+#: fortran/openmp.c:5210
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment must have an operator or intrinsic on right hand side at %L"
 msgstr ""
 
-#: fortran/openmp.c:5225
+#: fortran/openmp.c:5224
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE capture statement must set a scalar variable of intrinsic type at %L"
 msgstr ""
 
-#: fortran/openmp.c:5544
+#: fortran/openmp.c:5543
 #, gcc-internal-format, gfc-internal-format
 msgid "%s cannot be a DO WHILE or DO without loop control at %L"
 msgstr ""
 
-#: fortran/openmp.c:5550
+#: fortran/openmp.c:5549
 #, gcc-internal-format, gfc-internal-format
 msgid "%s cannot be a DO CONCURRENT loop at %L"
 msgstr ""
 
-#: fortran/openmp.c:5556
+#: fortran/openmp.c:5555
 #, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable must be of type integer at %L"
 msgstr ""
 
-#: fortran/openmp.c:5560
+#: fortran/openmp.c:5559
 #, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable must not be THREADPRIVATE at %L"
 msgstr ""
 
-#: fortran/openmp.c:5573
+#: fortran/openmp.c:5572
 #, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable present on clause other than PRIVATE or LASTPRIVATE at %L"
 msgstr ""
 
-#: fortran/openmp.c:5577
+#: fortran/openmp.c:5576
 #, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable present on clause other than LASTPRIVATE at %L"
 msgstr ""
 
-#: fortran/openmp.c:5581
+#: fortran/openmp.c:5580
 #, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable present on clause other than LINEAR at %L"
 msgstr ""
 
-#: fortran/openmp.c:5599
+#: fortran/openmp.c:5598
 #, gcc-internal-format, gfc-internal-format
 msgid "%s collapsed loops don't form rectangular iteration space at %L"
 msgstr ""
 
-#: fortran/openmp.c:5611
+#: fortran/openmp.c:5610
 #, gcc-internal-format, gfc-internal-format
 msgid "collapsed %s loops not perfectly nested at %L"
 msgstr ""
 
-#: fortran/openmp.c:5620 fortran/openmp.c:5628
+#: fortran/openmp.c:5619 fortran/openmp.c:5627
 #, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for collapsed %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:5712 fortran/openmp.c:5725
+#: fortran/openmp.c:5711 fortran/openmp.c:5724
 #, gcc-internal-format, gfc-internal-format
 msgid "The %s directive cannot be specified within a %s region at %L"
 msgstr ""
 
-#: fortran/openmp.c:5744
+#: fortran/openmp.c:5743
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP cannot be a DO WHILE or DO without loop control at %L"
 msgstr ""
 
-#: fortran/openmp.c:5750
+#: fortran/openmp.c:5749
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP iteration variable must be of type integer at %L"
 msgstr ""
 
-#: fortran/openmp.c:5766
+#: fortran/openmp.c:5765
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s loops don't form rectangular iteration space at %L"
 msgstr ""
 
-#: fortran/openmp.c:5778
+#: fortran/openmp.c:5777
 #, gcc-internal-format, gfc-internal-format
 msgid "%s !$ACC LOOP loops not perfectly nested at %L"
 msgstr ""
 
-#: fortran/openmp.c:5788 fortran/openmp.c:5797
+#: fortran/openmp.c:5787 fortran/openmp.c:5796
 #, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for %s !$ACC LOOP at %L"
 msgstr ""
 
-#: fortran/openmp.c:5812 fortran/openmp.c:5819
+#: fortran/openmp.c:5811 fortran/openmp.c:5818
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s in PARALLEL region doesn't allow %s arguments at %L"
 msgstr ""
 
-#: fortran/openmp.c:5841
+#: fortran/openmp.c:5840
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside another loop parallelized across gangs at %L"
 msgstr ""
 
-#: fortran/openmp.c:5845 fortran/openmp.c:5849
+#: fortran/openmp.c:5844 fortran/openmp.c:5848
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside loop parallelized across workers at %L"
 msgstr ""
 
-#: fortran/openmp.c:5856
+#: fortran/openmp.c:5855
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across workers at %L"
 msgstr ""
 
-#: fortran/openmp.c:5860
+#: fortran/openmp.c:5859
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across vectors at %L"
 msgstr ""
 
-#: fortran/openmp.c:5866
+#: fortran/openmp.c:5865
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across vectors is not allowed inside another loop parallelized across vectors at %L"
 msgstr ""
 
-#: fortran/openmp.c:5878
+#: fortran/openmp.c:5877
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with INDEPENDENT at %L"
 msgstr ""
 
-#: fortran/openmp.c:5880
+#: fortran/openmp.c:5879
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with GANG at %L"
 msgstr ""
 
-#: fortran/openmp.c:5882
+#: fortran/openmp.c:5881
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with WORKER at %L"
 msgstr ""
 
-#: fortran/openmp.c:5884
+#: fortran/openmp.c:5883
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with VECTOR at %L"
 msgstr ""
 
-#: fortran/openmp.c:5886
+#: fortran/openmp.c:5885
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with AUTO at %L"
 msgstr ""
 
-#: fortran/openmp.c:5891
+#: fortran/openmp.c:5890
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with GANG at %L"
 msgstr ""
 
-#: fortran/openmp.c:5893
+#: fortran/openmp.c:5892
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with WORKER at %L"
 msgstr ""
 
-#: fortran/openmp.c:5895
+#: fortran/openmp.c:5894
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with VECTOR at %L"
 msgstr ""
 
-#: fortran/openmp.c:5899
+#: fortran/openmp.c:5898
 #, gcc-internal-format, gfc-internal-format
 msgid "Tiled loop cannot be parallelized across gangs, workers and vectors at the same time at %L"
 msgstr ""
 
-#: fortran/openmp.c:5934
+#: fortran/openmp.c:5933
 #, gcc-internal-format, gfc-internal-format
 msgid "TILE requires constant expression at %L"
 msgstr ""
 
-#: fortran/openmp.c:5999
+#: fortran/openmp.c:6004
 #, gcc-internal-format
 msgid "PARAMETER object %qs is not allowed at %L"
 msgstr ""
 
-#: fortran/openmp.c:6006
+#: fortran/openmp.c:6011
 #, gcc-internal-format
 msgid "Array sections: %qs not allowed in !$ACC DECLARE at %L"
 msgstr ""
 
-#: fortran/openmp.c:6133
+#: fortran/openmp.c:6138
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP TARGET UPDATE at %L requires at least one TO or FROM clause"
 msgstr ""
 
-#: fortran/openmp.c:6155
+#: fortran/openmp.c:6160
 #, gcc-internal-format
 msgid "!$OMP DECLARE SIMD should refer to containing procedure %qs at %L"
 msgstr ""
 
-#: fortran/openmp.c:6179
+#: fortran/openmp.c:6184
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_PRIV or OMP_ORIG used in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6187
+#: fortran/openmp.c:6192
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_OUT or OMP_IN used in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6216
+#: fortran/openmp.c:6221
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid operator for !$OMP DECLARE REDUCTION %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:6238
+#: fortran/openmp.c:6243
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER length in !$OMP DECLARE REDUCTION %s not constant at %L"
 msgstr ""
 
-#: fortran/openmp.c:6254
+#: fortran/openmp.c:6259
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6269
+#: fortran/openmp.c:6274
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6279
+#: fortran/openmp.c:6284
 #, gcc-internal-format, gfc-internal-format
 msgid "One of actual subroutine arguments in INITIALIZER clause of !$OMP DECLARE REDUCTION must be OMP_PRIV at %L"
 msgstr ""
 
-#: fortran/openmp.c:6287
+#: fortran/openmp.c:6292
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing INITIALIZER clause for !$OMP DECLARE REDUCTION of derived type without default initializer at %L"
 msgstr ""
@@ -58455,494 +58534,494 @@
 msgid "Unclassifiable statement at %C"
 msgstr ""
 
-#: fortran/parse.c:629
+#: fortran/parse.c:631
 #, gcc-internal-format, gfc-internal-format
 msgid "OpenACC directives at %C may not appear in PURE procedures"
 msgstr ""
 
-#: fortran/parse.c:705
+#: fortran/parse.c:707
 #, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable OpenACC directive at %C"
 msgstr ""
 
-#: fortran/parse.c:831 fortran/parse.c:1040
+#: fortran/parse.c:835 fortran/parse.c:1044
 #, gcc-internal-format, gfc-internal-format
 msgid "OpenMP directives other than SIMD or DECLARE TARGET at %C may not appear in PURE or ELEMENTAL procedures"
 msgstr ""
 
-#: fortran/parse.c:1024
+#: fortran/parse.c:1028
 #, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable OpenMP directive at %C"
 msgstr ""
 
-#: fortran/parse.c:1076
+#: fortran/parse.c:1080
 #, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable GCC directive at %C"
 msgstr ""
 
-#: fortran/parse.c:1135 fortran/parse.c:1362
+#: fortran/parse.c:1139 fortran/parse.c:1366
 #, gcc-internal-format, gfc-internal-format
 msgid "Zero is not a valid statement label at %C"
 msgstr ""
 
-#: fortran/parse.c:1142 fortran/parse.c:1354
+#: fortran/parse.c:1146 fortran/parse.c:1358
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-numeric character in statement label at %C"
 msgstr "пустая сімвальная канстанта"
 
-#: fortran/parse.c:1154 fortran/parse.c:1403
+#: fortran/parse.c:1158 fortran/parse.c:1407
 #, gcc-internal-format, gfc-internal-format
 msgid "Semicolon at %C needs to be preceded by statement"
 msgstr ""
 
-#: fortran/parse.c:1161 fortran/parse.c:1418
+#: fortran/parse.c:1165 fortran/parse.c:1422
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label without statement at %L"
 msgstr ""
 
-#: fortran/parse.c:1224 fortran/parse.c:1405
+#: fortran/parse.c:1228 fortran/parse.c:1409
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Semicolon at %C without preceding statement"
 msgstr ""
 
-#: fortran/parse.c:1247 fortran/parse.c:1381
+#: fortran/parse.c:1251 fortran/parse.c:1385
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad continuation line at %C"
 msgstr ""
 
-#: fortran/parse.c:1679
+#: fortran/parse.c:1683
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT statement at %L does not have a statement label"
 msgstr ""
 
-#: fortran/parse.c:2435
+#: fortran/parse.c:2439
 #, gcc-internal-format
 msgid "gfc_ascii_statement(): Bad statement code"
 msgstr ""
 
-#: fortran/parse.c:2577
+#: fortran/parse.c:2581
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement at %C"
 msgstr ""
 
-#: fortran/parse.c:2732
+#: fortran/parse.c:2736
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot follow %s statement at %L"
 msgstr ""
 
-#: fortran/parse.c:2749
+#: fortran/parse.c:2753
 #, gcc-internal-format
 msgid "Unexpected end of file in %qs"
 msgstr ""
 
-#: fortran/parse.c:2784
+#: fortran/parse.c:2788
 #, gcc-internal-format
 msgid "Derived-type %qs with SEQUENCE must not have a CONTAINS section at %C"
 msgstr ""
 
-#: fortran/parse.c:2787
+#: fortran/parse.c:2791
 #, gcc-internal-format
 msgid "Derived-type %qs with BIND(C) must not have a CONTAINS section at %C"
 msgstr ""
 
-#: fortran/parse.c:2807
+#: fortran/parse.c:2811
 #, gcc-internal-format, gfc-internal-format
 msgid "Components in TYPE at %C must precede CONTAINS"
 msgstr ""
 
-#: fortran/parse.c:2811
+#: fortran/parse.c:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound procedure at %C"
 msgstr ""
 
-#: fortran/parse.c:2819
+#: fortran/parse.c:2823
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC binding at %C"
 msgstr ""
 
-#: fortran/parse.c:2827
+#: fortran/parse.c:2831
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure declaration at %C"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: fortran/parse.c:2839
+#: fortran/parse.c:2843
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type definition at %C with empty CONTAINS section"
 msgstr ""
 
-#: fortran/parse.c:2849 fortran/parse.c:3304
+#: fortran/parse.c:2853 fortran/parse.c:3308
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement in TYPE at %C must be inside a MODULE"
 msgstr ""
 
-#: fortran/parse.c:2856
+#: fortran/parse.c:2860
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede procedure bindings"
 msgstr ""
 
-#: fortran/parse.c:2863 fortran/parse.c:3317
+#: fortran/parse.c:2867 fortran/parse.c:3321
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PRIVATE statement at %C"
 msgstr ""
 
-#: fortran/parse.c:2873
+#: fortran/parse.c:2877
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede CONTAINS"
 msgstr ""
 
-#: fortran/parse.c:2877
+#: fortran/parse.c:2881
 #, gcc-internal-format, gfc-internal-format
 msgid "Already inside a CONTAINS block at %C"
 msgstr ""
 
-#: fortran/parse.c:2996
+#: fortran/parse.c:3000
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s at %L of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray, which is not possible as the component has the pointer attribute"
 msgstr ""
 
-#: fortran/parse.c:3002
+#: fortran/parse.c:3006
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer component %s at %L has a noncoarray subcomponent of type LOCK_TYPE, which must have a codimension or be a subcomponent of a coarray"
 msgstr ""
 
-#: fortran/parse.c:3007
+#: fortran/parse.c:3011
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L of type LOCK_TYPE must have a codimension"
 msgstr ""
 
-#: fortran/parse.c:3011
+#: fortran/parse.c:3015
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L must have a codimension as it has a noncoarray subcomponent of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/parse.c:3016
+#: fortran/parse.c:3020
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as already a coarray subcomponent exists)"
 msgstr ""
 
-#: fortran/parse.c:3023
+#: fortran/parse.c:3027
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as %s at %L has a codimension or a coarray subcomponent)"
 msgstr ""
 
-#: fortran/parse.c:3033
+#: fortran/parse.c:3037
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s at %L of type EVENT_TYPE must have a codimension or be a subcomponent of a coarray, which is not possible as the component has the pointer attribute"
 msgstr ""
 
-#: fortran/parse.c:3039
+#: fortran/parse.c:3043
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer component %s at %L has a noncoarray subcomponent of type EVENT_TYPE, which must have a codimension or be a subcomponent of a coarray"
 msgstr ""
 
-#: fortran/parse.c:3044
+#: fortran/parse.c:3048
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L of type EVENT_TYPE must have a codimension"
 msgstr ""
 
-#: fortran/parse.c:3048
+#: fortran/parse.c:3052
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L must have a codimension as it has a noncoarray subcomponent of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/parse.c:3053
+#: fortran/parse.c:3057
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as already a coarray subcomponent exists)"
 msgstr ""
 
-#: fortran/parse.c:3060
+#: fortran/parse.c:3064
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as %s at %L has a codimension or a coarray subcomponent)"
 msgstr ""
 
-#: fortran/parse.c:3112
+#: fortran/parse.c:3116
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to create map component '%s'"
 msgstr ""
 
-#: fortran/parse.c:3145
+#: fortran/parse.c:3149
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "failed to find class '%s'"
 msgid "failed to create union component '%s'"
 msgstr "не знойдзен клас \"%s\""
 
-#: fortran/parse.c:3200
+#: fortran/parse.c:3204
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in nested structure declaration at %C"
 msgstr ""
 
-#: fortran/parse.c:3287
+#: fortran/parse.c:3291
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside CONTAINS"
 msgstr ""
 
-#: fortran/parse.c:3295
+#: fortran/parse.c:3299
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type definition at %C without components"
 msgstr ""
 
-#: fortran/parse.c:3311
+#: fortran/parse.c:3315
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede structure components"
 msgstr ""
 
-#: fortran/parse.c:3328
+#: fortran/parse.c:3332
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede structure components"
 msgstr ""
 
-#: fortran/parse.c:3334
+#: fortran/parse.c:3338
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE attribute at %C already specified in TYPE statement"
 msgstr ""
 
-#: fortran/parse.c:3339
+#: fortran/parse.c:3343
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SEQUENCE statement at %C"
 msgstr ""
 
-#: fortran/parse.c:3349
+#: fortran/parse.c:3353
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS block in derived type definition at %C"
 msgstr ""
 
-#: fortran/parse.c:3407
+#: fortran/parse.c:3411
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM declaration at %C has no ENUMERATORS"
 msgstr ""
 
-#: fortran/parse.c:3494
+#: fortran/parse.c:3498
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in INTERFACE block at %C"
 msgstr ""
 
-#: fortran/parse.c:3518
+#: fortran/parse.c:3522
 #, gcc-internal-format
 msgid "Name %qs of ABSTRACT INTERFACE at %C cannot be the same as an intrinsic type"
 msgstr ""
 
-#: fortran/parse.c:3552
+#: fortran/parse.c:3556
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement at %C in INTERFACE body"
 msgstr ""
 
-#: fortran/parse.c:3570
+#: fortran/parse.c:3574
 #, gcc-internal-format
 msgid "INTERFACE procedure %qs at %L has the same name as the enclosing procedure"
 msgstr ""
 
-#: fortran/parse.c:3700
+#: fortran/parse.c:3704
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/parse.c:3732
+#: fortran/parse.c:3736
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement is not allowed inside of BLOCK DATA at %C"
 msgstr ""
 
-#: fortran/parse.c:3822
+#: fortran/parse.c:3826
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement must appear in a MODULE"
 msgstr ""
 
-#: fortran/parse.c:3830
+#: fortran/parse.c:3834
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C follows another accessibility specification"
 msgstr ""
 
-#: fortran/parse.c:3882
+#: fortran/parse.c:3886
 #, gcc-internal-format
 msgid "Bad kind expression for function %qs at %L"
 msgstr ""
 
-#: fortran/parse.c:3886
+#: fortran/parse.c:3890
 #, gcc-internal-format
 msgid "The type for function %qs at %L is not accessible"
 msgstr ""
 
-#: fortran/parse.c:3946
+#: fortran/parse.c:3950
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C follows previous unmasked ELSEWHERE"
 msgstr ""
 
-#: fortran/parse.c:3968
+#: fortran/parse.c:3972
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in WHERE block at %C"
 msgstr ""
 
-#: fortran/parse.c:4027
+#: fortran/parse.c:4031
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in FORALL block at %C"
 msgstr ""
 
-#: fortran/parse.c:4078
+#: fortran/parse.c:4082
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSE IF statement at %C cannot follow ELSE statement at %L"
 msgstr ""
 
-#: fortran/parse.c:4096
+#: fortran/parse.c:4100
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ELSE statements at %L and %C"
 msgstr ""
 
-#: fortran/parse.c:4157
+#: fortran/parse.c:4161
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected a CASE or END SELECT statement following SELECT CASE at %C"
 msgstr ""
 
-#: fortran/parse.c:4241
+#: fortran/parse.c:4245
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected TYPE IS, CLASS IS or END SELECT statement following SELECT TYPE at %C"
 msgstr ""
 
-#: fortran/parse.c:4303
+#: fortran/parse.c:4307
 #, gcc-internal-format
 msgid "Variable %qs at %C cannot be redefined inside loop beginning at %L"
 msgstr ""
 
-#: fortran/parse.c:4336
+#: fortran/parse.c:4340
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is within another block"
 msgstr ""
 
-#: fortran/parse.c:4346
+#: fortran/parse.c:4350
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is interwoven with another DO loop"
 msgstr ""
 
-#: fortran/parse.c:4372
+#: fortran/parse.c:4376
 #, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL block inside of OpenACC region at %C"
 msgstr ""
 
-#: fortran/parse.c:4373
+#: fortran/parse.c:4377
 #, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL block inside of OpenMP region at %C"
 msgstr ""
 
-#: fortran/parse.c:4399
+#: fortran/parse.c:4403
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label in END CRITICAL at %C does not match CRITICAL label"
 msgstr ""
 
-#: fortran/parse.c:4468
+#: fortran/parse.c:4472
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "In construct"
 msgid "BLOCK construct at %C"
 msgstr "У канструкцыі"
 
-#: fortran/parse.c:4502
+#: fortran/parse.c:4506
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSOCIATE construct at %C"
 msgstr ""
 
-#: fortran/parse.c:4690
+#: fortran/parse.c:4694
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label in ENDDO at %C doesn't match DO label"
 msgstr ""
 
-#: fortran/parse.c:4706
+#: fortran/parse.c:4710
 #, gcc-internal-format, gfc-internal-format
 msgid "Named block DO at %L requires matching ENDDO name"
 msgstr ""
 
-#: fortran/parse.c:4897
+#: fortran/parse.c:4901
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing !$OMP END ATOMIC after !$OMP ATOMIC CAPTURE at %C"
 msgstr ""
 
-#: fortran/parse.c:4913 fortran/parse.c:4972
+#: fortran/parse.c:4917 fortran/parse.c:4976
 #, gcc-internal-format, gfc-internal-format
 msgid "OpenACC directive inside of CRITICAL block at %C"
 msgstr ""
 
-#: fortran/parse.c:4947
+#: fortran/parse.c:4951
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s at %C"
 msgstr ""
 
-#: fortran/parse.c:4991
+#: fortran/parse.c:4995
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected DO loop at %C"
 msgstr ""
 
-#: fortran/parse.c:5011
+#: fortran/parse.c:5015
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant !$ACC END LOOP at %C"
 msgstr ""
 
-#: fortran/parse.c:5225
+#: fortran/parse.c:5229
 #, gcc-internal-format, gfc-internal-format
 msgid "Name after !$omp critical and !$omp end critical does not match at %C"
 msgstr ""
 
-#: fortran/parse.c:5283
+#: fortran/parse.c:5287
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot terminate a non-block DO loop"
 msgstr ""
 
-#: fortran/parse.c:5297
+#: fortran/parse.c:5301
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %C after the first executable statement"
 msgstr ""
 
-#: fortran/parse.c:5423
+#: fortran/parse.c:5427
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive does not commence a loop at %C"
 msgstr ""
 
-#: fortran/parse.c:5538
+#: fortran/parse.c:5542
 #, gcc-internal-format
 msgid "Contained procedure %qs at %C is already ambiguous"
 msgstr ""
 
-#: fortran/parse.c:5595
+#: fortran/parse.c:5599
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in CONTAINS section at %C"
 msgstr ""
 
-#: fortran/parse.c:5620
+#: fortran/parse.c:5624
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS statement without FUNCTION or SUBROUTINE statement at %L"
 msgstr ""
 
-#: fortran/parse.c:5732
+#: fortran/parse.c:5736
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS statement at %C is already in a contained program unit"
 msgstr ""
 
-#: fortran/parse.c:5784
+#: fortran/parse.c:5788
 #, gcc-internal-format
 msgid "Global binding name %qs at %L is already being used as a %s at %L"
 msgstr ""
 
-#: fortran/parse.c:5788
+#: fortran/parse.c:5792
 #, gcc-internal-format
 msgid "Global name %qs at %L is already being used as a %s at %L"
 msgstr ""
 
-#: fortran/parse.c:5794
+#: fortran/parse.c:5798
 #, gcc-internal-format
 msgid "Global binding name %qs at %L is already being used at %L"
 msgstr ""
 
-#: fortran/parse.c:5797
+#: fortran/parse.c:5801
 #, gcc-internal-format
 msgid "Global name %qs at %L is already being used at %L"
 msgstr ""
 
-#: fortran/parse.c:5819
+#: fortran/parse.c:5823
 #, gcc-internal-format, gfc-internal-format
 msgid "Blank BLOCK DATA at %C conflicts with prior BLOCK DATA at %L"
 msgstr ""
 
-#: fortran/parse.c:5845
+#: fortran/parse.c:5849
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in BLOCK DATA at %C"
 msgstr ""
 
-#: fortran/parse.c:5949
+#: fortran/parse.c:5953
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in MODULE at %C"
 msgstr ""
@@ -58950,7 +59029,7 @@
 #. If we see a duplicate main program, shut down.  If the second
 #. instance is an implied main program, i.e. data decls or executable
 #. statements, we're in for lots of errors.
-#: fortran/parse.c:6333
+#: fortran/parse.c:6337
 #, gcc-internal-format, gfc-internal-format
 msgid "Two main PROGRAMs at %L and %C"
 msgstr ""
@@ -59698,7 +59777,7 @@
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.c:1893 fortran/resolve.c:9560 fortran/resolve.c:11225
+#: fortran/resolve.c:1893 fortran/resolve.c:9573 fortran/resolve.c:11245
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr ""
@@ -59808,7 +59887,7 @@
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr ""
 
-#: fortran/resolve.c:2905 fortran/resolve.c:16283
+#: fortran/resolve.c:2905 fortran/resolve.c:16310
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr ""
@@ -59930,198 +60009,198 @@
 msgid "logical_to_bitwise(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:4059
+#: fortran/resolve.c:4065
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:4229 fortran/resolve.c:4252
+#: fortran/resolve.c:4235 fortran/resolve.c:4258
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:4347
+#: fortran/resolve.c:4353
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4352
+#: fortran/resolve.c:4358
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4362
+#: fortran/resolve.c:4368
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4367
+#: fortran/resolve.c:4373
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4387
+#: fortran/resolve.c:4393
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr ""
 
-#: fortran/resolve.c:4404
+#: fortran/resolve.c:4410
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4412
+#: fortran/resolve.c:4418
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4428
+#: fortran/resolve.c:4434
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4437
+#: fortran/resolve.c:4443
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4453
+#: fortran/resolve.c:4459
 #, gcc-internal-format
 msgid "check_dimension(): Bad array reference"
 msgstr ""
 
-#: fortran/resolve.c:4476
+#: fortran/resolve.c:4482
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:4486
+#: fortran/resolve.c:4492
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.c:4494
+#: fortran/resolve.c:4500
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.c:4510
+#: fortran/resolve.c:4516
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr ""
 
-#: fortran/resolve.c:4538
+#: fortran/resolve.c:4544
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4544
+#: fortran/resolve.c:4550
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr ""
 
-#: fortran/resolve.c:4550
+#: fortran/resolve.c:4556
 #, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr ""
 
-#: fortran/resolve.c:4589
+#: fortran/resolve.c:4595
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: fortran/resolve.c:4596
+#: fortran/resolve.c:4602
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr ""
 
-#: fortran/resolve.c:4641
+#: fortran/resolve.c:4647
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr ""
 
-#: fortran/resolve.c:4652
+#: fortran/resolve.c:4658
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.c:4663
+#: fortran/resolve.c:4669
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.c:4706
+#: fortran/resolve.c:4712
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr "памер масіва \"%s\" вельмі вялікі"
 
-#: fortran/resolve.c:4804
+#: fortran/resolve.c:4810
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:4811
+#: fortran/resolve.c:4817
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4820
+#: fortran/resolve.c:4826
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr ""
 
-#: fortran/resolve.c:4833
+#: fortran/resolve.c:4839
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:4840
+#: fortran/resolve.c:4846
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4850
+#: fortran/resolve.c:4856
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr ""
 
-#: fortran/resolve.c:4860
+#: fortran/resolve.c:4866
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "size of array `%s' is too large"
 msgid "Substring end index at %L is too large"
 msgstr "памер масіва \"%s\" вельмі вялікі"
 
-#: fortran/resolve.c:5013
+#: fortran/resolve.c:5019
 #, gcc-internal-format
 msgid "resolve_ref(): Bad array reference"
 msgstr ""
 
-#: fortran/resolve.c:5027
+#: fortran/resolve.c:5033
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:5037
+#: fortran/resolve.c:5043
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:5056
+#: fortran/resolve.c:5062
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:5154
+#: fortran/resolve.c:5160
 #, gcc-internal-format
 msgid "expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.c:5236
+#: fortran/resolve.c:5242
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr ""
 
-#: fortran/resolve.c:5246
+#: fortran/resolve.c:5252
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -60130,12 +60209,12 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5256
+#: fortran/resolve.c:5262
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5271
+#: fortran/resolve.c:5277
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -60144,268 +60223,268 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5281
+#: fortran/resolve.c:5287
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5292
+#: fortran/resolve.c:5298
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5301
+#: fortran/resolve.c:5307
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5316
+#: fortran/resolve.c:5322
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5478
+#: fortran/resolve.c:5484
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5483
+#: fortran/resolve.c:5489
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5553
+#: fortran/resolve.c:5559
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.c:5566
+#: fortran/resolve.c:5572
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.c:5919
+#: fortran/resolve.c:5925
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:5926
+#: fortran/resolve.c:5932
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5961
+#: fortran/resolve.c:5967
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5970
+#: fortran/resolve.c:5976
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr ""
 
 #. Nothing matching found!
-#: fortran/resolve.c:6158
+#: fortran/resolve.c:6164
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:6185
+#: fortran/resolve.c:6191
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:6236
+#: fortran/resolve.c:6242
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:6786
+#: fortran/resolve.c:6792
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr ""
 
-#: fortran/resolve.c:6812
+#: fortran/resolve.c:6818
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr ""
 
-#: fortran/resolve.c:6822
+#: fortran/resolve.c:6828
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr ""
 
-#: fortran/resolve.c:6826 fortran/resolve.c:6833
+#: fortran/resolve.c:6832 fortran/resolve.c:6839
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6875
+#: fortran/resolve.c:6881
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:6911
+#: fortran/resolve.c:6917
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.c:6928
+#: fortran/resolve.c:6934
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.c:6934
+#: fortran/resolve.c:6940
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.c:6995
+#: fortran/resolve.c:7001
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7000
+#: fortran/resolve.c:7006
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7007
+#: fortran/resolve.c:7013
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7015
+#: fortran/resolve.c:7021
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr ""
 
-#: fortran/resolve.c:7020
+#: fortran/resolve.c:7026
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:7033
+#: fortran/resolve.c:7039
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr ""
 
-#: fortran/resolve.c:7136 fortran/resolve.c:7428
+#: fortran/resolve.c:7142 fortran/resolve.c:7434
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:7144 fortran/resolve.c:7393
+#: fortran/resolve.c:7150 fortran/resolve.c:7399
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7250
+#: fortran/resolve.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7281
+#: fortran/resolve.c:7287
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.c:7439
+#: fortran/resolve.c:7445
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.c:7451
+#: fortran/resolve.c:7457
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.c:7465
+#: fortran/resolve.c:7471
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7480
+#: fortran/resolve.c:7486
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7493
+#: fortran/resolve.c:7499
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.c:7511
+#: fortran/resolve.c:7517
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.c:7592 fortran/resolve.c:7607
+#: fortran/resolve.c:7598 fortran/resolve.c:7613
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7599
+#: fortran/resolve.c:7605
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7622
+#: fortran/resolve.c:7628
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7649
+#: fortran/resolve.c:7655
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7668
+#: fortran/resolve.c:7674
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.c:7683
+#: fortran/resolve.c:7689
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7694
+#: fortran/resolve.c:7700
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7726
+#: fortran/resolve.c:7732
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:7749
+#: fortran/resolve.c:7755
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:7760
+#: fortran/resolve.c:7766
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.c:7771
+#: fortran/resolve.c:7782
 #, gcc-internal-format, gfc-internal-format
-msgid "Errmsg-variable at %L must be a scalar CHARACTER variable"
+msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:7794
+#: fortran/resolve.c:7805
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:7824
+#: fortran/resolve.c:7835
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.c:7830 fortran/resolve.c:7836
+#: fortran/resolve.c:7841 fortran/resolve.c:7847
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -60414,232 +60493,232 @@
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8064
+#: fortran/resolve.c:8075
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr ""
 
-#: fortran/resolve.c:8115
+#: fortran/resolve.c:8126
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr ""
 
-#: fortran/resolve.c:8126
+#: fortran/resolve.c:8137
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr ""
 
-#: fortran/resolve.c:8139
+#: fortran/resolve.c:8150
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:8185
+#: fortran/resolve.c:8196
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr ""
 
-#: fortran/resolve.c:8204
+#: fortran/resolve.c:8215
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr ""
 
-#: fortran/resolve.c:8214
+#: fortran/resolve.c:8225
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr ""
 
-#: fortran/resolve.c:8232 fortran/resolve.c:8240
+#: fortran/resolve.c:8243 fortran/resolve.c:8251
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr ""
 
-#: fortran/resolve.c:8302 fortran/resolve.c:8873
+#: fortran/resolve.c:8313 fortran/resolve.c:8884
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr ""
 
-#: fortran/resolve.c:8328
+#: fortran/resolve.c:8339
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:8340
+#: fortran/resolve.c:8351
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:8355
+#: fortran/resolve.c:8366
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr ""
 
-#: fortran/resolve.c:8458
+#: fortran/resolve.c:8469
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr ""
 
-#: fortran/resolve.c:8518
+#: fortran/resolve.c:8529
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr ""
 
-#: fortran/resolve.c:8523
+#: fortran/resolve.c:8534
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr ""
 
-#: fortran/resolve.c:8545
+#: fortran/resolve.c:8556
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.c:8556
+#: fortran/resolve.c:8567
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:8763
+#: fortran/resolve.c:8774
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8783 fortran/resolve.c:8795
+#: fortran/resolve.c:8794 fortran/resolve.c:8806
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.c:8824
+#: fortran/resolve.c:8835
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr ""
 
-#: fortran/resolve.c:8836
+#: fortran/resolve.c:8847
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr ""
 
-#: fortran/resolve.c:8848
+#: fortran/resolve.c:8859
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr ""
 
-#: fortran/resolve.c:8851
+#: fortran/resolve.c:8862
 #, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:8861
+#: fortran/resolve.c:8872
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.c:9108
+#: fortran/resolve.c:9119
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9204
+#: fortran/resolve.c:9215
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr ""
 
-#: fortran/resolve.c:9257
+#: fortran/resolve.c:9268
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr ""
 
-#: fortran/resolve.c:9267
+#: fortran/resolve.c:9278
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9280
+#: fortran/resolve.c:9291
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9289
+#: fortran/resolve.c:9300
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr ""
 
-#: fortran/resolve.c:9296
+#: fortran/resolve.c:9307
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9307
+#: fortran/resolve.c:9318
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr ""
 
-#: fortran/resolve.c:9313
+#: fortran/resolve.c:9324
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9328
+#: fortran/resolve.c:9339
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:9388
+#: fortran/resolve.c:9399
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:9398
+#: fortran/resolve.c:9409
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:9402
+#: fortran/resolve.c:9413
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr ""
 
-#: fortran/resolve.c:9405
+#: fortran/resolve.c:9416
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr ""
 
-#: fortran/resolve.c:9412 fortran/resolve.c:9533
+#: fortran/resolve.c:9423 fortran/resolve.c:9545
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:9424 fortran/resolve.c:9540
+#: fortran/resolve.c:9435 fortran/resolve.c:9553
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:9436
+#: fortran/resolve.c:9447
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr ""
 
-#: fortran/resolve.c:9449
+#: fortran/resolve.c:9460
 #, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:9510
+#: fortran/resolve.c:9521
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:9514 fortran/resolve.c:9524
+#: fortran/resolve.c:9525 fortran/resolve.c:9535
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr ""
 
-#: fortran/resolve.c:9567
+#: fortran/resolve.c:9580
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9577
+#: fortran/resolve.c:9590
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr ""
@@ -60646,12 +60725,12 @@
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:9594 fortran/resolve.c:9617
+#: fortran/resolve.c:9607 fortran/resolve.c:9630
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.c:9598 fortran/resolve.c:9623
+#: fortran/resolve.c:9611 fortran/resolve.c:9636
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -60659,107 +60738,107 @@
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:9638
+#: fortran/resolve.c:9651
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9710
+#: fortran/resolve.c:9723
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:9726
+#: fortran/resolve.c:9739
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:9734 fortran/resolve.c:9821
+#: fortran/resolve.c:9747 fortran/resolve.c:9834
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:9744 fortran/resolve.c:9831
+#: fortran/resolve.c:9757 fortran/resolve.c:9844
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:9775
+#: fortran/resolve.c:9788
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:9784
+#: fortran/resolve.c:9797
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr ""
 
-#: fortran/resolve.c:9949
+#: fortran/resolve.c:9962
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr ""
 
-#: fortran/resolve.c:9959
+#: fortran/resolve.c:9972
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr ""
 
-#: fortran/resolve.c:10036
+#: fortran/resolve.c:10049
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr ""
 
-#: fortran/resolve.c:10138
+#: fortran/resolve.c:10151
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:10251
+#: fortran/resolve.c:10264
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr ""
 
-#: fortran/resolve.c:10283
+#: fortran/resolve.c:10296
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:10288
+#: fortran/resolve.c:10301
 #, gcc-internal-format, gfc-internal-format
 msgid "The impure variable at %L is assigned to a derived type variable with a POINTER component in a PURE procedure (12.6)"
 msgstr ""
 
-#: fortran/resolve.c:10298
+#: fortran/resolve.c:10311
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:10330
+#: fortran/resolve.c:10343
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:10334
+#: fortran/resolve.c:10347
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:10339
+#: fortran/resolve.c:10352
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.c:10346
+#: fortran/resolve.c:10359
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr ""
 
-#: fortran/resolve.c:10357
+#: fortran/resolve.c:10370
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:10663
+#: fortran/resolve.c:10683
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
@@ -60766,67 +60845,67 @@
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:10905
+#: fortran/resolve.c:10925
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:10917
+#: fortran/resolve.c:10937
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr ""
 
-#: fortran/resolve.c:11157
+#: fortran/resolve.c:11177
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:11160
+#: fortran/resolve.c:11180
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr ""
 
-#: fortran/resolve.c:11171
+#: fortran/resolve.c:11191
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr ""
 
-#: fortran/resolve.c:11233
+#: fortran/resolve.c:11253
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:11278
+#: fortran/resolve.c:11298
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid NULL at %L"
 msgstr ""
 
-#: fortran/resolve.c:11282
+#: fortran/resolve.c:11302
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:11339
+#: fortran/resolve.c:11359
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:11344
+#: fortran/resolve.c:11364
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:11428
+#: fortran/resolve.c:11448
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:11507
+#: fortran/resolve.c:11527
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr ""
 
-#: fortran/resolve.c:11617
+#: fortran/resolve.c:11637
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
@@ -60833,7 +60912,7 @@
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:11630
+#: fortran/resolve.c:11650
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr ""
@@ -60841,58 +60920,58 @@
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:11647
+#: fortran/resolve.c:11667
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.c:11732
+#: fortran/resolve.c:11752
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "size of array `%s' is too large"
 msgid "String length at %L is too large"
 msgstr "памер масіва \"%s\" вельмі вялікі"
 
-#: fortran/resolve.c:11961
+#: fortran/resolve.c:11981
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:11965
+#: fortran/resolve.c:11985
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:11973
+#: fortran/resolve.c:11993
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:11983
+#: fortran/resolve.c:12003
 #, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:11998
+#: fortran/resolve.c:12018
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.c:12010
+#: fortran/resolve.c:12030
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.c:12041
+#: fortran/resolve.c:12061
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.c:12063
+#: fortran/resolve.c:12083
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
 
-#: fortran/resolve.c:12090
+#: fortran/resolve.c:12110
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
@@ -60899,889 +60978,894 @@
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12131
+#: fortran/resolve.c:12151
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr ""
 
-#: fortran/resolve.c:12150
+#: fortran/resolve.c:12170
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr ""
 
-#: fortran/resolve.c:12171
+#: fortran/resolve.c:12191
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr ""
 
-#: fortran/resolve.c:12178
+#: fortran/resolve.c:12198
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr ""
 
-#: fortran/resolve.c:12225
+#: fortran/resolve.c:12245
 #, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12228
+#: fortran/resolve.c:12248
 #, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12232
+#: fortran/resolve.c:12252
 #, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12235
+#: fortran/resolve.c:12255
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12238
+#: fortran/resolve.c:12258
 #, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12241
+#: fortran/resolve.c:12261
 #, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12283
+#: fortran/resolve.c:12303
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L"
 msgstr ""
 
-#: fortran/resolve.c:12310
+#: fortran/resolve.c:12330
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:12332
+#: fortran/resolve.c:12352
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:12354
+#: fortran/resolve.c:12374
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.c:12372
+#: fortran/resolve.c:12392
 #, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12381
+#: fortran/resolve.c:12401
 #, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12389
+#: fortran/resolve.c:12409
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr ""
 
-#: fortran/resolve.c:12399
+#: fortran/resolve.c:12419
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr ""
 
-#: fortran/resolve.c:12418
+#: fortran/resolve.c:12438
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr ""
 
-#: fortran/resolve.c:12422
+#: fortran/resolve.c:12442
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr ""
 
-#: fortran/resolve.c:12426
+#: fortran/resolve.c:12446
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr ""
 
-#: fortran/resolve.c:12430
+#: fortran/resolve.c:12450
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr ""
 
-#: fortran/resolve.c:12443
+#: fortran/resolve.c:12463
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12452
+#: fortran/resolve.c:12472
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:12458
+#: fortran/resolve.c:12478
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:12470
+#: fortran/resolve.c:12490
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:12527
+#: fortran/resolve.c:12547
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12533
+#: fortran/resolve.c:12553
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12539
+#: fortran/resolve.c:12559
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12547
+#: fortran/resolve.c:12567
 #, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12553
+#: fortran/resolve.c:12573
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.c:12596
+#: fortran/resolve.c:12616
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12604
+#: fortran/resolve.c:12624
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12612
+#: fortran/resolve.c:12632
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12621
+#: fortran/resolve.c:12641
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.c:12705
+#: fortran/resolve.c:12725
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:12714
+#: fortran/resolve.c:12734
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr ""
 
-#: fortran/resolve.c:12723
+#: fortran/resolve.c:12743
 #, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr ""
 
-#: fortran/resolve.c:12731
+#: fortran/resolve.c:12751
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:12737
+#: fortran/resolve.c:12757
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:12743
+#: fortran/resolve.c:12763
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr ""
 
-#: fortran/resolve.c:12751
+#: fortran/resolve.c:12771
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:12760
+#: fortran/resolve.c:12780
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr ""
 
-#: fortran/resolve.c:12782
+#: fortran/resolve.c:12802
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr ""
 
-#: fortran/resolve.c:12819
+#: fortran/resolve.c:12839
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr ""
 
-#: fortran/resolve.c:12859
+#: fortran/resolve.c:12879
 #, gcc-internal-format
 msgid "%qs and %qs can't be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12895
+#: fortran/resolve.c:12915
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.c:12954
+#: fortran/resolve.c:12974
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12966
+#: fortran/resolve.c:12986
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.c:12994
+#: fortran/resolve.c:13014
 #, gcc-internal-format
 msgid "GENERIC %qs at %L can't overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.c:13050
+#: fortran/resolve.c:13070
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L can't be NOPASS"
 msgstr ""
 
-#: fortran/resolve.c:13242
+#: fortran/resolve.c:13262
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr ""
 
-#: fortran/resolve.c:13284
+#: fortran/resolve.c:13304
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:13298
+#: fortran/resolve.c:13318
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:13312 fortran/resolve.c:13778
+#: fortran/resolve.c:13332 fortran/resolve.c:13798
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13320
+#: fortran/resolve.c:13340
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr ""
 
-#: fortran/resolve.c:13329
+#: fortran/resolve.c:13349
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:13335
+#: fortran/resolve.c:13355
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13341
+#: fortran/resolve.c:13361
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr ""
 
-#: fortran/resolve.c:13370
+#: fortran/resolve.c:13390
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:13380
+#: fortran/resolve.c:13400
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:13472
+#: fortran/resolve.c:13492
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.c:13574
+#: fortran/resolve.c:13594
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:13583
+#: fortran/resolve.c:13603
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13593
+#: fortran/resolve.c:13613
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.c:13602
+#: fortran/resolve.c:13622
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.c:13613
+#: fortran/resolve.c:13633
 #, gcc-internal-format
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.c:13711
+#: fortran/resolve.c:13731
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:13725
+#: fortran/resolve.c:13745
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:13741
+#: fortran/resolve.c:13761
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:13751
+#: fortran/resolve.c:13771
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:13760
+#: fortran/resolve.c:13780
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:13769
+#: fortran/resolve.c:13789
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13811
+#: fortran/resolve.c:13831
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr ""
 
-#: fortran/resolve.c:13824
+#: fortran/resolve.c:13844
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr ""
 
-#: fortran/resolve.c:13835
+#: fortran/resolve.c:13855
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13868
+#: fortran/resolve.c:13888
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:13876
+#: fortran/resolve.c:13896
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.c:13885
+#: fortran/resolve.c:13905
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr ""
 
-#: fortran/resolve.c:13903 fortran/resolve.c:13915
+#: fortran/resolve.c:13923 fortran/resolve.c:13935
 #, gcc-internal-format
 msgid "The pointer component %qs of %qs at %L is a type that has not been declared"
 msgstr ""
 
-#: fortran/resolve.c:13989
+#: fortran/resolve.c:14009
 #, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr ""
 
-#: fortran/resolve.c:14034
+#: fortran/resolve.c:14054
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.c:14047
+#: fortran/resolve.c:14067
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr ""
 
-#: fortran/resolve.c:14111
+#: fortran/resolve.c:14131
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14144
+#: fortran/resolve.c:14164
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.c:14216
+#: fortran/resolve.c:14236
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:14222
+#: fortran/resolve.c:14242
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14228
+#: fortran/resolve.c:14248
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14236
+#: fortran/resolve.c:14256
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14253
+#: fortran/resolve.c:14273
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14275
+#: fortran/resolve.c:14295
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14286
+#: fortran/resolve.c:14306
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14313
+#: fortran/resolve.c:14333
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14337
+#: fortran/resolve.c:14357
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:14353
+#: fortran/resolve.c:14373
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:14364
+#: fortran/resolve.c:14384
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr ""
 
-#: fortran/resolve.c:14372
+#: fortran/resolve.c:14392
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr ""
 
-#: fortran/resolve.c:14423
+#: fortran/resolve.c:14443
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr ""
 
-#: fortran/resolve.c:14434
+#: fortran/resolve.c:14454
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.c:14441
+#: fortran/resolve.c:14461
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.c:14480
+#: fortran/resolve.c:14500
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:14544
+#: fortran/resolve.c:14564
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:14547
+#: fortran/resolve.c:14567
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:14643
+#: fortran/resolve.c:14663
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:14664
+#: fortran/resolve.c:14684
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr ""
 
-#: fortran/resolve.c:14677
+#: fortran/resolve.c:14697
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14680
+#: fortran/resolve.c:14700
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14688
+#: fortran/resolve.c:14708
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14695
+#: fortran/resolve.c:14715
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:14708
+#: fortran/resolve.c:14728
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr ""
 
-#: fortran/resolve.c:14714
+#: fortran/resolve.c:14734
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14724
+#: fortran/resolve.c:14744
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:14733
+#: fortran/resolve.c:14753
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.c:14746 fortran/resolve.c:14923
+#: fortran/resolve.c:14766 fortran/resolve.c:14943
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.c:14760
+#: fortran/resolve.c:14780
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14769
+#: fortran/resolve.c:14789
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:14778
+#: fortran/resolve.c:14798
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14786
+#: fortran/resolve.c:14806
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:14793
+#: fortran/resolve.c:14813
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:14813
+#: fortran/resolve.c:14833
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.c:14820
+#: fortran/resolve.c:14840
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14827
+#: fortran/resolve.c:14847
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:14834
+#: fortran/resolve.c:14854
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:14860
+#: fortran/resolve.c:14880
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:14870
+#: fortran/resolve.c:14890
 #, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.c:14949
+#: fortran/resolve.c:14969
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:14964
+#: fortran/resolve.c:14984
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14977
+#: fortran/resolve.c:14997
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14995
+#: fortran/resolve.c:15015
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.c:15007
+#: fortran/resolve.c:15027
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:15016
+#: fortran/resolve.c:15036
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:15028
+#: fortran/resolve.c:15048
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr ""
 
-#: fortran/resolve.c:15037
+#: fortran/resolve.c:15057
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15049
+#: fortran/resolve.c:15069
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15065
+#: fortran/resolve.c:15085
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15073
+#: fortran/resolve.c:15093
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15080
+#: fortran/resolve.c:15100
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15092
+#: fortran/resolve.c:15112
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.c:15101
+#: fortran/resolve.c:15121
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15117
+#: fortran/resolve.c:15137
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15123
+#: fortran/resolve.c:15143
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15148
+#: fortran/resolve.c:15168
 #, gcc-internal-format
 msgid "Namelist %qs can not be an argument to subroutine or function at %L"
 msgstr ""
 
-#: fortran/resolve.c:15218
+#: fortran/resolve.c:15238
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:15229
+#: fortran/resolve.c:15249
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:15333
+#: fortran/resolve.c:15353
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:15339
+#: fortran/resolve.c:15359
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:15345
+#: fortran/resolve.c:15365
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.c:15354
+#: fortran/resolve.c:15374
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr ""
 
-#: fortran/resolve.c:15368
+#: fortran/resolve.c:15388
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:15414
+#: fortran/resolve.c:15434
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.c:15427
+#: fortran/resolve.c:15447
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.c:15526
+#: fortran/resolve.c:15546
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15534
+#: fortran/resolve.c:15554
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15542
+#: fortran/resolve.c:15562
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15667
+#: fortran/resolve.c:15687
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.c:15832
+#: fortran/resolve.c:15852
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "label `%s' defined but not used"
 msgid "Label %d at %L defined but not used"
 msgstr "адмеціна `%s' вызначана, але ня выкарыстоўваецца"
 
-#: fortran/resolve.c:15838
+#: fortran/resolve.c:15858
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "label `%s' defined but not used"
 msgid "Label %d at %L defined but cannot be used"
 msgstr "адмеціна `%s' вызначана, але ня выкарыстоўваецца"
 
-#: fortran/resolve.c:15922
+#: fortran/resolve.c:15942
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15931
+#: fortran/resolve.c:15951
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15939
+#: fortran/resolve.c:15959
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:15955
+#: fortran/resolve.c:15975
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16058
+#: fortran/resolve.c:16078
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:16073
+#: fortran/resolve.c:16093
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:16098
+#: fortran/resolve.c:16118
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:16107
+#: fortran/resolve.c:16127
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16180
+#: fortran/resolve.c:16200
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16191
+#: fortran/resolve.c:16211
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16202
+#: fortran/resolve.c:16222
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr ""
 
-#: fortran/resolve.c:16293
+#: fortran/resolve.c:16253
 #, gcc-internal-format
+msgid "Self reference in character length expression for %qs at %L"
+msgstr ""
+
+#: fortran/resolve.c:16320
+#, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.c:16306
+#: fortran/resolve.c:16333
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:16326
+#: fortran/resolve.c:16353
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:16336
+#: fortran/resolve.c:16363
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr ""
 
-#: fortran/resolve.c:16344
+#: fortran/resolve.c:16371
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:16358
+#: fortran/resolve.c:16385
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:16376
+#: fortran/resolve.c:16403
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:16383
+#: fortran/resolve.c:16410
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr ""
 
-#: fortran/resolve.c:16461
+#: fortran/resolve.c:16488
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -62114,20 +62198,12 @@
 msgid "simplify_min_max(): Bad type in arglist"
 msgstr ""
 
-#. Result is processor-dependent.
-#: fortran/simplify.c:5472
-#, gcc-internal-format, gfc-internal-format
-msgid "Second argument MOD at %L is zero"
+#: fortran/simplify.c:5470 fortran/simplify.c:5478
+#, gcc-internal-format
+msgid "Argument %qs of MOD at %L shall not be zero"
 msgstr ""
 
-#. Result is processor-dependent.
-#: fortran/simplify.c:5483
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "second argument of `%s' should be `char **'"
-msgid "Second argument of MOD at %L is zero"
-msgstr "другім аргументам \"%s\" павінен быць \"char **\""
-
-#: fortran/simplify.c:5494
+#: fortran/simplify.c:5484
 #, gcc-internal-format
 msgid "gfc_simplify_mod(): Bad arguments"
 msgstr ""
@@ -62135,97 +62211,97 @@
 #. Result is processor-dependent. This processor just opts
 #. to not handle it at all.
 #. Result is processor-dependent.
-#: fortran/simplify.c:5520 fortran/simplify.c:5532
+#: fortran/simplify.c:5525 fortran/simplify.c:5537
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of MODULO at %L is zero"
 msgstr ""
 
-#: fortran/simplify.c:5552
+#: fortran/simplify.c:5557
 #, gcc-internal-format
 msgid "gfc_simplify_modulo(): Bad arguments"
 msgstr ""
 
-#: fortran/simplify.c:5600
+#: fortran/simplify.c:5605
 #, gcc-internal-format, gfc-internal-format
 msgid "Result of NEAREST is NaN at %L"
 msgstr ""
 
-#: fortran/simplify.c:6081
+#: fortran/simplify.c:6086
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative at %L"
 msgstr ""
 
-#: fortran/simplify.c:6137
+#: fortran/simplify.c:6142
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument NCOPIES of REPEAT intrinsic is too large at %L"
 msgstr ""
 
-#: fortran/simplify.c:6174
+#: fortran/simplify.c:6179
 #, gcc-internal-format, gfc-internal-format
 msgid "Evaluation of string longer than 2**28 at %L deferred to runtime, expect bugs"
 msgstr ""
 
-#: fortran/simplify.c:6302
+#: fortran/simplify.c:6307
 #, gcc-internal-format, gfc-internal-format
 msgid "Reshaped array too large at %C"
 msgstr ""
 
-#: fortran/simplify.c:6416
+#: fortran/simplify.c:6421
 #, gcc-internal-format, gfc-internal-format
 msgid "Result of SCALE overflows its kind at %L"
 msgstr ""
 
-#: fortran/simplify.c:6995
+#: fortran/simplify.c:7000
 #, gcc-internal-format
 msgid "Bad type in gfc_simplify_sign"
 msgstr ""
 
-#: fortran/simplify.c:7024
+#: fortran/simplify.c:7029
 #, gcc-internal-format
 msgid "in gfc_simplify_sin(): Bad type"
 msgstr ""
 
-#: fortran/simplify.c:7151 fortran/simplify.c:7431
+#: fortran/simplify.c:7156 fortran/simplify.c:7436
 #, gcc-internal-format
 msgid "Failure getting length of a constant array."
 msgstr ""
 
-#: fortran/simplify.c:7161
+#: fortran/simplify.c:7166
 #, gcc-internal-format
 msgid "The number of elements (%d) in the array constructor at %L requires an increase of the allowed %d upper limit.  See %<-fmax-array-constructor%> option."
 msgstr ""
 
-#: fortran/simplify.c:7227
+#: fortran/simplify.c:7232
 #, gcc-internal-format, gfc-internal-format
 msgid "Simplification of SPREAD at %C not yet implemented"
 msgstr ""
 
-#: fortran/simplify.c:7251
+#: fortran/simplify.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SQRT at %L has a negative value"
 msgstr ""
 
-#: fortran/simplify.c:7267
+#: fortran/simplify.c:7272
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid argument of SQRT at %L"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: fortran/simplify.c:7598
+#: fortran/simplify.c:7603
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY lower bound is %ld)"
 msgstr ""
 
-#: fortran/simplify.c:7621
+#: fortran/simplify.c:7626
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY upper bound is %ld)"
 msgstr ""
 
-#: fortran/simplify.c:7993
+#: fortran/simplify.c:7998
 #, gcc-internal-format
 msgid "gfc_convert_constant(): Unexpected type"
 msgstr ""
 
-#: fortran/simplify.c:8078
+#: fortran/simplify.c:8083
 #, gcc-internal-format
 msgid "Character %qs in string at %L cannot be converted into character kind %d"
 msgstr ""
@@ -62328,7 +62404,7 @@
 msgid "BIND(C) applied to %s %s at %L"
 msgstr ""
 
-#: fortran/symbol.c:901 fortran/symbol.c:912 fortran/symbol.c:1762
+#: fortran/symbol.c:901 fortran/symbol.c:912 fortran/symbol.c:1776
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s attribute conflicts with %s attribute at %L"
 msgstr "\"%s\" атрыбут ігнарыруецца"
@@ -62403,17 +62479,22 @@
 msgid "Duplicate VOLATILE attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1367
+#: fortran/symbol.c:1360
 #, gcc-internal-format, gfc-internal-format
+msgid "VOLATILE attribute at %L cannot be specified in a PURE procedure"
+msgstr ""
+
+#: fortran/symbol.c:1381
+#, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ASYNCHRONOUS attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1758
+#: fortran/symbol.c:1772
 #, gcc-internal-format
 msgid "%s attribute of %qs conflicts with %s attribute at %L"
 msgstr ""
 
-#: fortran/symbol.c:1794
+#: fortran/symbol.c:1808
 #, gcc-internal-format, gfc-internal-format
 msgid ""
 "%s procedure at %L is already declared as %s procedure. \n"
@@ -62420,208 +62501,208 @@
 "F2008: A pointer function assignment is ambiguous if it is the first executable statement after the specification block. Please add any other kind of executable statement before it. FIXME"
 msgstr ""
 
-#: fortran/symbol.c:1802
+#: fortran/symbol.c:1816
 #, gcc-internal-format, gfc-internal-format
 msgid "%s procedure at %L is already declared as %s procedure"
 msgstr ""
 
-#: fortran/symbol.c:1837
+#: fortran/symbol.c:1851
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgstr ""
 
-#: fortran/symbol.c:1861
+#: fortran/symbol.c:1875
 #, gcc-internal-format, gfc-internal-format
 msgid "ACCESS specification at %L was already specified"
 msgstr ""
 
-#: fortran/symbol.c:1878
+#: fortran/symbol.c:1892
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate BIND attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1885
+#: fortran/symbol.c:1899
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) at %L"
 msgstr ""
 
-#: fortran/symbol.c:1901
+#: fortran/symbol.c:1915
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate EXTENDS attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1905
+#: fortran/symbol.c:1919
 #, gcc-internal-format, gfc-internal-format
 msgid "EXTENDS at %L"
 msgstr ""
 
-#: fortran/symbol.c:1931
+#: fortran/symbol.c:1945
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has an explicit interface"
 msgstr ""
 
-#: fortran/symbol.c:1938
+#: fortran/symbol.c:1952
 #, gcc-internal-format
 msgid "%qs at %L has attributes specified outside its INTERFACE body"
 msgstr ""
 
-#: fortran/symbol.c:1976
+#: fortran/symbol.c:1990
 #, gcc-internal-format
 msgid "Symbol %qs at %L conflicts with symbol from module %qs, use-associated at %L"
 msgstr ""
 
-#: fortran/symbol.c:1980
+#: fortran/symbol.c:1994
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr ""
 
-#: fortran/symbol.c:1987
+#: fortran/symbol.c:2001
 #, gcc-internal-format
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr ""
 
-#: fortran/symbol.c:1999
+#: fortran/symbol.c:2013
 #, gcc-internal-format
 msgid "Symbol %qs at %L cannot have a type"
 msgstr ""
 
-#: fortran/symbol.c:2242
+#: fortran/symbol.c:2256
 #, gcc-internal-format
 msgid "Component %qs at %C already in the parent type at %L"
 msgstr ""
 
-#: fortran/symbol.c:2327
+#: fortran/symbol.c:2341
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C is ambiguous"
 msgstr "памер \"%s\" - %d байт"
 
-#: fortran/symbol.c:2359
+#: fortran/symbol.c:2373
 #, gcc-internal-format
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr ""
 
-#: fortran/symbol.c:2508
+#: fortran/symbol.c:2522
 #, gcc-internal-format
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr ""
 
-#: fortran/symbol.c:2529
+#: fortran/symbol.c:2543
 #, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure; did you mean %qs?"
 msgstr ""
 
-#: fortran/symbol.c:2533
+#: fortran/symbol.c:2547
 #, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr ""
 
-#: fortran/symbol.c:2697
+#: fortran/symbol.c:2711
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr ""
 
-#: fortran/symbol.c:2708
+#: fortran/symbol.c:2722
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr ""
 
-#: fortran/symbol.c:2718
+#: fortran/symbol.c:2732
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr ""
 
-#: fortran/symbol.c:2724
+#: fortran/symbol.c:2738
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:2766
+#: fortran/symbol.c:2780
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr ""
 
-#: fortran/symbol.c:2775
+#: fortran/symbol.c:2789
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr ""
 
-#: fortran/symbol.c:2781
+#: fortran/symbol.c:2795
 #, gcc-internal-format, gfc-internal-format
 msgid "Shared DO termination label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:3110
+#: fortran/symbol.c:3124
 #, gcc-internal-format
 msgid "new_symbol(): Symbol name too long"
 msgstr ""
 
-#: fortran/symbol.c:3135
+#: fortran/symbol.c:3149
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr ""
 
-#: fortran/symbol.c:3138
+#: fortran/symbol.c:3152
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
 msgstr ""
 
 #. Symbol is from another namespace.
-#: fortran/symbol.c:3381
+#: fortran/symbol.c:3395
 #, gcc-internal-format
 msgid "Symbol %qs at %C has already been host associated"
 msgstr ""
 
-#: fortran/symbol.c:4397
+#: fortran/symbol.c:4411
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr ""
 
-#: fortran/symbol.c:4410
+#: fortran/symbol.c:4424
 #, gcc-internal-format
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr ""
 
-#: fortran/symbol.c:4428
+#: fortran/symbol.c:4442
 #, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr ""
 
-#: fortran/symbol.c:4449
+#: fortran/symbol.c:4463
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:4459
+#: fortran/symbol.c:4473
 #, gcc-internal-format
 msgid "Procedure pointer component %qs at %L cannot be a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:4470
+#: fortran/symbol.c:4484
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:4509
+#: fortran/symbol.c:4523
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.c:4519
+#: fortran/symbol.c:4533
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/symbol.c:4533
+#: fortran/symbol.c:4547
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot be declared with both PRIVATE and BIND(C) attributes"
 msgstr ""
 
-#: fortran/symbol.c:4541
+#: fortran/symbol.c:4555
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.c:5018 fortran/symbol.c:5023
+#: fortran/symbol.c:5032 fortran/symbol.c:5037
 #, gcc-internal-format
 msgid "Symbol %qs is used before it is typed at %L"
 msgstr ""
@@ -62668,7 +62749,7 @@
 msgid "Creating array temporary at %L for argument %qs"
 msgstr ""
 
-#: fortran/trans-array.c:10693
+#: fortran/trans-array.c:10724
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr ""
@@ -62873,12 +62954,12 @@
 msgid "%<dim%> argument of %s intrinsic at %L is not a valid dimension index"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:10572 fortran/trans-stmt.c:1050
+#: fortran/trans-intrinsic.c:10574 fortran/trans-stmt.c:1050
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, the event component of derived type at %L is not yet supported"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:10579
+#: fortran/trans-intrinsic.c:10581
 #, gcc-internal-format, gfc-internal-format
 msgid "The event variable at %L shall not be coindexed"
 msgstr ""
@@ -62918,7 +62999,7 @@
 msgid "Sorry, only support for integer kind %d implemented for image-set at %L"
 msgstr ""
 
-#: fortran/trans-stmt.c:3346
+#: fortran/trans-stmt.c:3343
 #, gcc-internal-format
 msgid "gfc_trans_select(): Bad type for case expr."
 msgstr ""
@@ -63051,7 +63132,7 @@
 msgid "two or more sections for %s"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: lto/lto-partition.c:516
+#: lto/lto-partition.c:570
 #, gcc-internal-format
 msgid "min partition size cannot be greater than max partition size"
 msgstr ""
@@ -63190,58 +63271,58 @@
 msgid "Cannot read %s"
 msgstr "не магу прачытаць з %s"
 
-#: lto/lto.c:2369
+#: lto/lto.c:2337
 #, gcc-internal-format
 msgid "lto_obj_file_open() failed"
 msgstr ""
 
-#: lto/lto.c:2394
+#: lto/lto.c:2362
 #, gcc-internal-format
 msgid "waitpid failed"
 msgstr ""
 
-#: lto/lto.c:2397
+#: lto/lto.c:2365
 #, gcc-internal-format
 msgid "streaming subprocess failed"
 msgstr ""
 
-#: lto/lto.c:2400
+#: lto/lto.c:2368
 #, gcc-internal-format
 msgid "streaming subprocess was killed by signal"
 msgstr ""
 
-#: lto/lto.c:2476
+#: lto/lto.c:2445
 #, gcc-internal-format
 msgid "no LTRANS output list filename provided"
 msgstr ""
 
-#: lto/lto.c:2564
+#: lto/lto.c:2525
 #, gcc-internal-format
 msgid "opening LTRANS output list %s: %m"
 msgstr ""
 
-#: lto/lto.c:2570
+#: lto/lto.c:2532
 #, gcc-internal-format
 msgid "writing to LTRANS output list %s: %m"
 msgstr ""
 
-#: lto/lto.c:2581
+#: lto/lto.c:2542
 #, gcc-internal-format
 msgid "closing LTRANS output list %s: %m"
 msgstr ""
 
-#: lto/lto.c:2833
+#: lto/lto.c:2794
 #, fuzzy, gcc-internal-format
 #| msgid "Could not open data file %s.\n"
 msgid "could not open symbol resolution file: %m"
 msgstr "Немагчыма адчыніць файл з дадзенымі %s.\n"
 
-#: lto/lto.c:2954
+#: lto/lto.c:2915
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing resolution data for %s"
 msgstr "прапушчан прабел пасля нумара \"%.*s\""
 
-#: lto/lto.c:2986
+#: lto/lto.c:2947
 #, gcc-internal-format
 msgid "errors during merging of translation units"
 msgstr ""
Index: gcc/po/ru.po
===================================================================
--- gcc/po/ru.po	(.../tags/gcc_8_2_0_release)
+++ gcc/po/ru.po	(.../branches/gcc-8-branch)
@@ -1,19 +1,19 @@
 # Translation of gcc messages to Russian
 # Copyright (C) 2006 Free Software Foundation, Inc.
 # This file is distributed under the same license as the gcc package.
-#
 # Nadezhda Vyukova <qniva@yandex.ru>, 2006, 2014.
 # Nickolay V. Shmyrev <nshmyrev@yandex.ru>, 2008.
 # Pavel Maryanov <acid_jack@ukr.net>, 2006, 2008.
 # Yuri Kozlov <yuray@komyakino.ru>, 2011.
-# Pavel Maryanov <acid@jack.kiev.ua>, 2012.
 # Vladimir Galatenko <galat@niisi.msk.ru>, 2016.
+# Pavel Maryanov <acid@jack.kiev.ua>, 2012, 2018.
+#
 msgid ""
 msgstr ""
-"Project-Id-Version: gcc 8.1-b20180128\n"
+"Project-Id-Version: gcc 8.2.0\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2018-05-01 20:30+0000\n"
-"PO-Revision-Date: 2018-01-30 10:25+0300\n"
+"POT-Creation-Date: 2018-07-25 14:25+0000\n"
+"PO-Revision-Date: 2018-10-01 13:43+0300\n"
 "Last-Translator: Pavel Maryanov <acid@jack.kiev.ua>\n"
 "Language-Team: Russian <gnu@d07.ru>\n"
 "Language: ru\n"
@@ -22,6 +22,7 @@
 "Content-Transfer-Encoding: 8bit\n"
 "X-Bugs: Report translation errors to the Language-Team address.\n"
 "Plural-Forms: nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);\n"
+"X-Generator: Poedit 2.1.1\n"
 
 #: cfgrtl.c:2679
 msgid "flow control insn inside a basic block"
@@ -44,12 +45,12 @@
 msgid "[cannot find %s]"
 msgstr "[не найдена программа %s]"
 
-#: collect2.c:1557
+#: collect2.c:1585
 #, c-format
 msgid "collect2 version %s\n"
 msgstr "collect2 версия %s\n"
 
-#: collect2.c:1664
+#: collect2.c:1692
 #, c-format
 msgid "%d constructor found\n"
 msgid_plural "%d constructors found\n"
@@ -57,7 +58,7 @@
 msgstr[1] "найдено %d конструктора\n"
 msgstr[2] "найдено %d конструкторов\n"
 
-#: collect2.c:1668
+#: collect2.c:1696
 #, c-format
 msgid "%d destructor found\n"
 msgid_plural "%d destructors found\n"
@@ -65,7 +66,7 @@
 msgstr[1] "найдено %d деструктора\n"
 msgstr[2] "найдено %d деструкторов\n"
 
-#: collect2.c:1672
+#: collect2.c:1700
 #, c-format
 msgid "%d frame table found\n"
 msgid_plural "%d frame tables found\n"
@@ -73,12 +74,12 @@
 msgstr[1] "найдено %d таблицы кадров\n"
 msgstr[2] "найдено %d таблиц кадров\n"
 
-#: collect2.c:1836
+#: collect2.c:1864
 #, c-format
 msgid "[Leaving %s]\n"
 msgstr "[Выход из %s]\n"
 
-#: collect2.c:2068
+#: collect2.c:2094
 #, c-format
 msgid ""
 "\n"
@@ -87,7 +88,7 @@
 "\n"
 "write_c_file - выходное имя %s, префикс %s\n"
 
-#: collect2.c:2584
+#: collect2.c:2610
 #, c-format
 msgid ""
 "\n"
@@ -110,7 +111,7 @@
 msgid "%s: some warnings being treated as errors"
 msgstr "%s: некоторые предупреждения считаются ошибками"
 
-#: diagnostic.c:324 input.c:222 input.c:1834 c-family/c-opts.c:1377
+#: diagnostic.c:324 input.c:222 input.c:1834 c-family/c-opts.c:1392
 #: fortran/cpp.c:576 fortran/error.c:1008 fortran/error.c:1028
 msgid "<built-in>"
 msgstr "<built-in>"
@@ -126,11 +127,7 @@
 msgstr "компиляция прервана из-за -Wfatal-errors.\n"
 
 #: diagnostic.c:525
-#, fuzzy, c-format
-#| msgid ""
-#| "Please submit a full bug report,\n"
-#| "with preprocessed source if appropriate.\n"
-#| "See %s for instructions.\n"
+#, c-format
 msgid ""
 "Please submit a full bug report,\n"
 "with preprocessed source if appropriate.\n"
@@ -137,13 +134,14 @@
 msgstr ""
 "Отправьте подробное сообщение об ошибке\n"
 "с препроцессированным исходным кодом.\n"
-"Смотрите инструкции в %s.\n"
+"\n"
 
 #: diagnostic.c:531
-#, fuzzy, c-format
-#| msgid "Use fp double instructions"
+#, c-format
 msgid "See %s for instructions.\n"
-msgstr "Использовать инструкции двойной точности плавающих вычислений"
+msgstr ""
+"Инструкции см. в %s.\n"
+"\n"
 
 #: diagnostic.c:540
 #, c-format
@@ -208,13 +206,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:4164 config/arc/arc.c:5784 config/i386/i386.c:17302
+#: final.c:4164 config/arc/arc.c:5775 config/i386/i386.c:17305
 #: config/pdp11/pdp11.c:1715
 #, c-format
 msgid "floating constant misused"
 msgstr "некорректное использование плавающей константы"
 
-#: final.c:4222 config/arc/arc.c:5881 config/i386/i386.c:17393
+#: final.c:4222 config/arc/arc.c:5872 config/i386/i386.c:17396
 #: config/pdp11/pdp11.c:1756
 #, c-format
 msgid "invalid expression as operand"
@@ -271,7 +269,8 @@
 msgstr ""
 "\n"
 "\n"
-"Продолжать? (y - да, n - нет) "
+"Продолжать? \n"
+"(y — да, n — нет) "
 
 #: gcc.c:3209
 #, c-format
@@ -288,300 +287,282 @@
 msgstr "Ключи:\n"
 
 #: gcc.c:3428
-#, fuzzy
-#| msgid "  -pass-exit-codes         Exit with highest error code from a phase\n"
 msgid "  -pass-exit-codes         Exit with highest error code from a phase.\n"
-msgstr "  -pass-exit-codes         Выход с максимальным кодом возврата от прохода\n"
+msgstr ""
+"  -pass-exit-codes          Выход с максимальным кодом возврата от прохода.\n"
+"\n"
 
 #: gcc.c:3429
-#, fuzzy
-#| msgid "  --help                   Display this information\n"
 msgid "  --help                   Display this information.\n"
-msgstr "  --help                   Вывести этот текст\n"
+msgstr ""
+"  --help                   Показать этот текст.\n"
+"\n"
 
 #: gcc.c:3430
-#, fuzzy
-#| msgid "  --target-help            Display target specific command line options\n"
 msgid "  --target-help            Display target specific command line options.\n"
-msgstr "  --target-help            Показать специфические ключи целевой платформы\n"
+msgstr ""
+"  --target-help             Показать специфические ключи целевой платформы.\n"
+"\n"
 
 #: gcc.c:3431
-#, fuzzy
-#| msgid "  --help={common|optimizers|params|target|warnings|[^]{joined|separate|undocumented}}[,...]\n"
 msgid "  --help={common|optimizers|params|target|warnings|[^]{joined|separate|undocumented}}[,...].\n"
-msgstr "  --help={common|optimizers|params|target|warnings|[^]{joined|separate|undocumented}}[,...]\n"
+msgstr ""
+"    --help={common|optimizers|params|target|warnings|[^]{joined|separate|undocumented}}[,...].\n"
+"\n"
 
 #: gcc.c:3432
-#, fuzzy
-#| msgid "                           Display specific types of command line options\n"
 msgid "                           Display specific types of command line options.\n"
-msgstr "                           Показать специфические ключи командной строки\n"
+msgstr ""
+"                           Показать специфические ключи командной строки.\n"
+"\n"
 
 #: gcc.c:3434
-#, fuzzy
-#| msgid "  (Use '-v --help' to display command line options of sub-processes)\n"
 msgid "  (Use '-v --help' to display command line options of sub-processes).\n"
-msgstr "  (Задайте '-v --help' для вывода ключей всех проходов компиляции)\n"
+msgstr ""
+"  ('-v --help' показывает ключи всех проходов компиляции).\n"
+"\n"
 
 #: gcc.c:3435
-#, fuzzy
-#| msgid "  --version                Display compiler version information\n"
 msgid "  --version                Display compiler version information.\n"
-msgstr "  --version                Показать информацию о версии компилятора\n"
+msgstr ""
+"  --version                Показать информацию о версии компилятора.\n"
+"\n"
 
 #: gcc.c:3436
-#, fuzzy
-#| msgid "  -dumpspecs               Display all of the built in spec strings\n"
 msgid "  -dumpspecs               Display all of the built in spec strings.\n"
-msgstr "  -dumpspecs               Показать встроенные спецификации\n"
+msgstr ""
+"  -dumpspecs               Показать все встроенные спецификации.\n"
+"\n"
 
 #: gcc.c:3437
-#, fuzzy
-#| msgid "  -dumpversion             Display the version of the compiler\n"
 msgid "  -dumpversion             Display the version of the compiler.\n"
-msgstr "  -dumpversion             Показать версию компилятора\n"
+msgstr ""
+"  -dumpversion             Показать версию компилятора.\n"
+"\n"
 
 #: gcc.c:3438
-#, fuzzy
-#| msgid "  -dumpmachine             Display the compiler's target processor\n"
 msgid "  -dumpmachine             Display the compiler's target processor.\n"
-msgstr "  -dumpmachine             Показать имя целевой платформы\n"
+msgstr ""
+"  -dumpmachine             Показать имя целевой платформы.\n"
+"\n"
 
 #: gcc.c:3439
-#, fuzzy
-#| msgid "  -print-search-dirs       Display the directories in the compiler's search path\n"
 msgid "  -print-search-dirs       Display the directories in the compiler's search path.\n"
-msgstr "  -print-search-dirs       Показать каталоги поиска\n"
+msgstr ""
+"  -print-search-dirs       Показать каталоги поиска.\n"
+"\n"
 
 #: gcc.c:3440
-#, fuzzy
-#| msgid "  -print-libgcc-file-name  Display the name of the compiler's companion library\n"
 msgid "  -print-libgcc-file-name  Display the name of the compiler's companion library.\n"
-msgstr "  -print-libgcc-file-name  Показать имя run-time библиотеки компилятора\n"
+msgstr ""
+"  -print-libgcc-file-name  Показать имя run-time библиотеки компилятора.\n"
+"\n"
 
 #: gcc.c:3441
-#, fuzzy
-#| msgid "  -print-file-name=<lib>   Display the full path to library <lib>\n"
 msgid "  -print-file-name=<lib>   Display the full path to library <lib>.\n"
-msgstr "  -print-file-name=<биб>   Показать полное маршрутное имя библиотеки <биб>\n"
+msgstr ""
+"  -print-file-name=<lib>   Показать полное маршрутное имя библиотеки <lib>.\n"
+"\n"
 
 #: gcc.c:3442
-#, fuzzy
-#| msgid "  -print-prog-name=<prog>  Display the full path to compiler component <prog>\n"
 msgid "  -print-prog-name=<prog>  Display the full path to compiler component <prog>.\n"
-msgstr "  -print-prog-name=<прог>  Показать полное имя компоненты компилятора <прог>\n"
+msgstr ""
+"  -print-prog-name=<prog>  Показать полное имя компонента компилятора <prog>.\n"
+"\n"
 
 #: gcc.c:3443
-#, fuzzy
-#| msgid ""
-#| "  -print-multiarch         Display the target's normalized GNU triplet, used as\n"
-#| "                           a component in the library path\n"
 msgid ""
 "  -print-multiarch         Display the target's normalized GNU triplet, used as\n"
 "                           a component in the library path.\n"
 msgstr ""
-"  -print-multiarch         Показать триплет GNU, используемый как компонент маршрутных\n"
-"                           имен библиотек\n"
+"  -print-multiarch         Показать триплет GNU, используемый как компонент\n"
+"\n"
+"                           маршрутных имён библиотек.\n"
 
 #: gcc.c:3446
-#, fuzzy
-#| msgid "  -print-multi-directory   Display the root directory for versions of libgcc\n"
 msgid "  -print-multi-directory   Display the root directory for versions of libgcc.\n"
-msgstr "  -print-multi-directory   Показать корневой каталог с версиями libgcc\n"
+msgstr ""
+"  -print-multi-directory   Показать корневой каталог с версиями libgcc.\n"
+"\n"
 
 #: gcc.c:3447
-#, fuzzy
-#| msgid ""
-#| "  -print-multi-lib         Display the mapping between command line options and\n"
-#| "                           multiple library search directories\n"
 msgid ""
 "  -print-multi-lib         Display the mapping between command line options and\n"
 "                           multiple library search directories.\n"
 msgstr ""
-"  -print-multi-lib         Показать соответствие между ключами и каталогами\n"
-"                           поиска библиотек\n"
+"  -print-multi-lib         Показать соответствие между ключами\n"
+"\n"
+"                           каталогами поиска библиотек.\n"
+"\n"
 
 #: gcc.c:3450
-#, fuzzy
-#| msgid "  -print-multi-os-directory Display the relative path to OS libraries\n"
 msgid "  -print-multi-os-directory Display the relative path to OS libraries.\n"
-msgstr "  -print-multi-os-directory Показать относительный маршрут к библиотекам операционной системы\n"
+msgstr ""
+"  -print-multi-os-directory Показать относительный путь к библиотекам операционной системы.\n"
+"\n"
 
 #: gcc.c:3451
-#, fuzzy
-#| msgid "  -print-sysroot           Display the target libraries directory\n"
 msgid "  -print-sysroot           Display the target libraries directory.\n"
-msgstr "  -print-sysroot           Показать каталог библиотек цели\n"
+msgstr ""
+"  -print-sysroot           Показать целевой каталог библиотек.\n"
+"\n"
 
 #: gcc.c:3452
-#, fuzzy
-#| msgid "  -print-sysroot-headers-suffix Display the sysroot suffix used to find headers\n"
 msgid "  -print-sysroot-headers-suffix Display the sysroot suffix used to find headers.\n"
-msgstr "  -print-sysroot-headers-suffix Вывести суффикс sysroot, используемый для поиска заголовочных файлов\n"
+msgstr ""
+"  -print-sysroot-headers-suffix Показать суффикс sysroot, используемый для поиска заголовочных файлов.\n"
+"\n"
 
 #: gcc.c:3453
-#, fuzzy
-#| msgid "  -Wa,<options>            Pass comma-separated <options> on to the assembler\n"
 msgid "  -Wa,<options>            Pass comma-separated <options> on to the assembler.\n"
-msgstr "  -Wa,<ключи>              Передать <ключи>, разделённые запятыми, ассемблеру\n"
+msgstr ""
+"  -Wa,<ключи>              Передать в ассемблер <ключи>, разделённые запятыми.\n"
+"\n"
 
 #: gcc.c:3454
-#, fuzzy
-#| msgid "  -Wp,<options>            Pass comma-separated <options> on to the preprocessor\n"
 msgid "  -Wp,<options>            Pass comma-separated <options> on to the preprocessor.\n"
-msgstr "  -Wp,<ключи>              Передать <ключи>, разделённые запятыми, препроцессору\n"
+msgstr ""
+"  -Wp,<ключи>              Передать в препроцессор <ключи>, разделённые запятыми.\n"
+"\n"
 
 #: gcc.c:3455
-#, fuzzy
-#| msgid "  -Wl,<options>            Pass comma-separated <options> on to the linker\n"
 msgid "  -Wl,<options>            Pass comma-separated <options> on to the linker.\n"
-msgstr "  -Wl,<ключи>              Передать <ключи>, разделённые запятыми, компоновщику\n"
+msgstr ""
+"  -Wl,<ключи>              Передать в компоновщик <ключи>, разделённые запятыми.\n"
+"\n"
 
 #: gcc.c:3456
-#, fuzzy
-#| msgid "  -Xassembler <arg>        Pass <arg> on to the assembler\n"
 msgid "  -Xassembler <arg>        Pass <arg> on to the assembler.\n"
-msgstr "  -Xassembler <арг>        Передать <арг> ассемблеру\n"
+msgstr ""
+"  -Xassembler <арг>        Передать <арг> ассемблеру.\n"
+"\n"
 
 #: gcc.c:3457
-#, fuzzy
-#| msgid "  -Xpreprocessor <arg>     Pass <arg> on to the preprocessor\n"
 msgid "  -Xpreprocessor <arg>     Pass <arg> on to the preprocessor.\n"
-msgstr "  -Xpreprocessor <арг>     Передать <арг> препроцессору\n"
+msgstr ""
+"  -Xpreprocessor <арг>     Передать <арг> препроцессору.\n"
+"\n"
 
 #: gcc.c:3458
-#, fuzzy
-#| msgid "  -Xlinker <arg>           Pass <arg> on to the linker\n"
 msgid "  -Xlinker <arg>           Pass <arg> on to the linker.\n"
-msgstr "  -Xlinker <арг>           Передать <арг> компоновщику\n"
+msgstr ""
+"  -Xlinker <арг>           Передать <арг> компоновщику.\n"
+"\n"
 
 #: gcc.c:3459
-#, fuzzy
-#| msgid "  -save-temps              Do not delete intermediate files\n"
 msgid "  -save-temps              Do not delete intermediate files.\n"
-msgstr "  -save-temps              Не удалять промежуточные файлы\n"
+msgstr ""
+"  -save-temps              Не удалять промежуточные файлы.\n"
+"\n"
 
 #: gcc.c:3460
-#, fuzzy
-#| msgid "  -save-temps=<arg>        Do not delete intermediate files\n"
 msgid "  -save-temps=<arg>        Do not delete intermediate files.\n"
-msgstr "  -save-temps=<arg>        Не удалять промежуточные файлы\n"
+msgstr ""
+"  -save-temps=<arg>        Не удалять промежуточные файлы.\n"
+"\n"
 
 #: gcc.c:3461
-#, fuzzy
-#| msgid ""
-#| "  -no-canonical-prefixes   Do not canonicalize paths when building relative\n"
-#| "                           prefixes to other gcc components\n"
 msgid ""
 "  -no-canonical-prefixes   Do not canonicalize paths when building relative\n"
 "                           prefixes to other gcc components.\n"
 msgstr ""
 "  -no-canonical-prefixes   Не канонизировать пути при сборке относительных\n"
-"                           префиксов к другим компонентам gcc\n"
+"                           префиксов к другим компонентам gcc.\n"
+"\n"
 
 #: gcc.c:3464
-#, fuzzy
-#| msgid "  -pipe                    Use pipes rather than intermediate files\n"
 msgid "  -pipe                    Use pipes rather than intermediate files.\n"
-msgstr "  -pipe                    Передавать промежуточные данные по конвейеру\n"
+msgstr ""
+"  -pipe                    Использовать конвейер, а не промежуточные файлы.\n"
+"\n"
 
 #: gcc.c:3465
-#, fuzzy
-#| msgid "  -time                    Time the execution of each subprocess\n"
 msgid "  -time                    Time the execution of each subprocess.\n"
-msgstr "  -time                    Включить хронометраж проходов\n"
+msgstr ""
+"  -time                    Включить хронометраж проходов.\n"
+"\n"
 
 #: gcc.c:3466
-#, fuzzy
-#| msgid "  -specs=<file>            Override built-in specs with the contents of <file>\n"
 msgid "  -specs=<file>            Override built-in specs with the contents of <file>.\n"
 msgstr ""
 "  -specs=<файл>            Использовать <файл> спецификаций вместо \n"
-"                             внутренних спецификаций компилятора\n"
+"                             внутренних спецификаций компилятора.\n"
+"\n"
 
 #: gcc.c:3467
-#, fuzzy
-#| msgid "  -std=<standard>          Assume that the input sources are for <standard>\n"
 msgid "  -std=<standard>          Assume that the input sources are for <standard>.\n"
-msgstr "  -std=<стандарт>          Считать, что исходный код следует <стандарту>\n"
+msgstr ""
+"  -std=<стандарт>          Считать, что исходный код следует <стандарту>.\n"
+"\n"
 
 #: gcc.c:3468
-#, fuzzy
-#| msgid ""
-#| "  --sysroot=<directory>    Use <directory> as the root directory for headers\n"
-#| "                           and libraries\n"
 msgid ""
 "  --sysroot=<directory>    Use <directory> as the root directory for headers\n"
 "                           and libraries.\n"
 msgstr ""
-"  --sysroot=<каталог>      Использовать <каталог> как головной каталог для заголовков\n"
-"                           и библиотек\n"
+"  --sysroot=<каталог>      Использовать <каталог> как корневой для заголовков\n"
+"\n"
+"                           и библиотек.\n"
 
 #: gcc.c:3471
-#, fuzzy
-#| msgid "  -B <directory>           Add <directory> to the compiler's search paths\n"
 msgid "  -B <directory>           Add <directory> to the compiler's search paths.\n"
 msgstr ""
-"  -B <каталог>             добавить <каталог> к списку поиска программ \n"
-"                             компилятора\n"
+"  -B <каталог>             Добавить <каталог> к списку поиска программ \n"
+"                             компилятора.\n"
+"\n"
 
 #: gcc.c:3472
-#, fuzzy
-#| msgid "  -v                       Display the programs invoked by the compiler\n"
 msgid "  -v                       Display the programs invoked by the compiler.\n"
-msgstr "  -v                       Отображать команды, запускаемые компилятором\n"
+msgstr ""
+"  -v                       Показать команды, запускаемые компилятором.\n"
+"\n"
 
 #: gcc.c:3473
-#, fuzzy
-#| msgid "  -###                     Like -v but options quoted and commands not executed\n"
 msgid "  -###                     Like -v but options quoted and commands not executed.\n"
-msgstr "  -###                     Как -v, но параметры берутся в кавычки и команды не запускаются\n"
+msgstr ""
+"  -###                     Как -v, но параметры берутся в кавычки и команды не запускаются.\n"
+"\n"
 
 #: gcc.c:3474
-#, fuzzy
-#| msgid "  -E                       Preprocess only; do not compile, assemble or link\n"
 msgid "  -E                       Preprocess only; do not compile, assemble or link.\n"
-msgstr "  -E                       Только препроцессирование - без компиляции, ассемблирования, компоновки\n"
+msgstr ""
+"  -E                       Только препроцессинг, без компиляции, сборки и компоновки.\n"
+"\n"
 
 #: gcc.c:3475
-#, fuzzy
-#| msgid "  -S                       Compile only; do not assemble or link\n"
 msgid "  -S                       Compile only; do not assemble or link.\n"
-msgstr "  -S                       Только компиляция - без ассемблирования и компоновки\n"
+msgstr ""
+"  -S                       Только компиляция, без ассемблирования сборки и компоновки.\n"
+"\n"
 
 #: gcc.c:3476
-#, fuzzy
-#| msgid "  -c                       Compile and assemble, but do not link\n"
 msgid "  -c                       Compile and assemble, but do not link.\n"
-msgstr "  -c                       Компиляция и ассемблирование, без компоновки\n"
+msgstr ""
+"  -c                       Компиляция и сборка, но без компоновки.\n"
+"\n"
 
 #: gcc.c:3477
-#, fuzzy
-#| msgid "  -o <file>                Place the output into <file>\n"
 msgid "  -o <file>                Place the output into <file>.\n"
-msgstr "  -o <файл>                Записать результат в <файл>\n"
+msgstr ""
+"  -o <файл>                Записать результат в <файл>.\n"
+"\n"
 
 #: gcc.c:3478
-#, fuzzy
-#| msgid "  -pie                     Create a position independent executable\n"
 msgid ""
 "  -pie                     Create a dynamically linked position independent\n"
 "                           executable.\n"
-msgstr "  -pie                     Генерировать позиционно-независимый код для выполняемых модулей\n"
+msgstr ""
+"  -pie                     Генерировать позиционно-независимый код для\n"
+"\n"
+"                           выполняемых модулей.\n"
 
 #: gcc.c:3480
-#, fuzzy
-#| msgid "  -shared                  Create a shared library\n"
 msgid "  -shared                  Create a shared library.\n"
-msgstr "  -shared                  Создать разделяемую библиотеку\n"
+msgstr ""
+"  -shared                  Создать разделяемую библиотеку.\n"
+"\n"
 
 #: gcc.c:3481
-#, fuzzy
-#| msgid ""
-#| "  -x <language>            Specify the language of the following input files\n"
-#| "                           Permissible languages include: c c++ assembler none\n"
-#| "                           'none' means revert to the default behavior of\n"
-#| "                           guessing the language based on the file's extension\n"
 msgid ""
 "  -x <language>            Specify the language of the following input files.\n"
 "                           Permissible languages include: c c++ assembler none\n"
@@ -588,10 +569,10 @@
 "                           'none' means revert to the default behavior of\n"
 "                           guessing the language based on the file's extension.\n"
 msgstr ""
-"  -x <язык>                Задать язык последующих входных файлов.\n"
-"                           <язык> может быть: c c++ assembler none\n"
-"                           'none' означает, что далее язык нужно\n"
-"                           определять по расширению имени файла\n"
+"  -x <язык>                    Указать язык для следующих входных файлов.\n"
+"                           Допустимые языки: c c++ assembler none\n"
+"                           'none' означает стандартное поведение\n"
+"                           угадывания языка по расширению файла.\n"
 
 #: gcc.c:3488
 #, c-format
@@ -602,8 +583,11 @@
 " other options on to these processes the -W<letter> options must be used.\n"
 msgstr ""
 "\n"
-"Ключи, начинающиеся с -g, -f, -m, -O, -W, или --param автоматически\n"
-"передаются процессам, запускаемым %s. Для передачи ключей этим процессам, используйте ключи -W<буква>.\n"
+"Ключи, начинающиеся с -g, -f, -m, -O, -W, или --param, автоматически\n"
+" передаются процессам, запускаемым %s.\n"
+"  Чтобы передать ключи\n"
+" этим процессам, используйте ключи -W<буква>.\n"
+"\n"
 
 #: gcc.c:5963
 #, c-format
@@ -639,11 +623,15 @@
 #, c-format
 msgid "The bug is not reproducible, so it is likely a hardware or OS problem.\n"
 msgstr ""
+"Ошибка не воспроизводится. Возможно, это проблема оборудования или ОС.\n"
+"\n"
 
 #: gcc.c:6945
 #, c-format
 msgid "Preprocessed source stored into %s file, please attach this to your bugreport.\n"
 msgstr ""
+"Предварительно обработанный исходный текст сохранён в файле %s. Приложите его к отчёту об ошибке.\n"
+"\n"
 
 #: gcc.c:7898
 #, c-format
@@ -685,9 +673,13 @@
 "\n"
 msgstr ""
 "Это свободно распространяемое программное обеспечение. Условия копирования\n"
-"приведены в исходных текстах. Без гарантии каких-либо качеств, включая \n"
+"приведены в исходных текстах.\n"
+"\n"
+"  Без гарантии каких-либо качеств, включая \n"
 "коммерческую ценность и применимость для каких-либо целей.\n"
 "\n"
+"\n"
+"\n"
 
 #: gcc.c:8346
 #, c-format
@@ -735,92 +727,116 @@
 #, c-format
 msgid "  merge [options] <dir1> <dir2>         Merge coverage file contents\n"
 msgstr ""
+"  merge [ключи] <dir1> <dir2>           Слияние содержимого файлов покрытия\n"
+"\n"
 
 #: gcov-tool.c:176 gcov-tool.c:271
-#, fuzzy, c-format
-#| msgid "  -n, --no-output                 Do not create an output file\n"
+#, c-format
 msgid "    -o, --output <dir>                  Output directory\n"
-msgstr "  -n, --no-output                 Не создавать выходной файл\n"
+msgstr ""
+"    -o, --output <dir>                  Выходной каталог\n"
+"\n"
 
 #: gcov-tool.c:177 gcov-tool.c:273 gcov-tool.c:425
-#, fuzzy, c-format
-#| msgid "  -v, --version                   Print version number, then exit\n"
+#, c-format
 msgid "    -v, --verbose                       Verbose mode\n"
-msgstr "  -v, --version                   Показать номер версии и выйти\n"
+msgstr ""
+"    -v, --verbose                       Подробный вывод\n"
+"\n"
 
 #: gcov-tool.c:178
 #, c-format
 msgid "    -w, --weight <w1,w2>                Set weights (float point values)\n"
 msgstr ""
+"    -w, --weight <w1,w2>                Веса каталогов 1, 2 (веществ. значения)\n"
+"\n"
 
 #: gcov-tool.c:194
 #, c-format
 msgid "Merge subcomand usage:"
-msgstr ""
+msgstr "Команда слияния (merge):"
 
 #: gcov-tool.c:269
 #, c-format
 msgid "  rewrite [options] <dir>               Rewrite coverage file contents\n"
 msgstr ""
+"  rewrite [опции] <каталог>             Перезаписать содержимое файла с данными покрытия\n"
+"\n"
 
 #: gcov-tool.c:270
 #, c-format
 msgid "    -n, --normalize <int64_t>           Normalize the profile\n"
 msgstr ""
+"    -n, --normalize <int64_t>           Нормализовать профиль\n"
+"\n"
 
 #: gcov-tool.c:272
 #, c-format
 msgid "    -s, --scale <float or simple-frac>  Scale the profile counters\n"
 msgstr ""
+"    -s, --scale <вещ. или дробь>        Масштабировать счётчики профиля\n"
+"\n"
 
 #: gcov-tool.c:290
 #, c-format
 msgid "Rewrite subcommand usage:"
-msgstr ""
+msgstr "Команда перезаписи (rewrite):"
 
 #: gcov-tool.c:329
 #, c-format
 msgid "scaling cannot co-exist with normalization, skipping\n"
 msgstr ""
+"масштабирование и нормализация не могут использоваться совместно\n"
+"\n"
 
 #: gcov-tool.c:342 gcov-tool.c:352
 #, c-format
 msgid "incorrect format in scaling, using 1/1\n"
 msgstr ""
+"некорректный формат для масштаба, используется 1/1\n"
+"\n"
 
 #: gcov-tool.c:362
 #, c-format
 msgid "normalization cannot co-exist with scaling\n"
 msgstr ""
+"нормализация и масштабирование не могут использоваться совместно\n"
+"\n"
 
 #: gcov-tool.c:419
 #, c-format
 msgid "  overlap [options] <dir1> <dir2>       Compute the overlap of two profiles\n"
 msgstr ""
+"  overlap [опции] <dir1> <dir2>              Вычислить перекрытие двух профилей\n"
+"\n"
 
 #: gcov-tool.c:420
-#, fuzzy, c-format
-#| msgid "  -h, --help                      Print this help, then exit\n"
+#, c-format
 msgid "    -f, --function                      Print function level info\n"
-msgstr "  -h, --help                      Показать эту справку и выйти\n"
+msgstr ""
+"    -f, --function                          Вывести информацию уровня функции\n"
+"\n"
 
 #: gcov-tool.c:421
-#, fuzzy, c-format
-#| msgid "  -h, --help                      Print this help, then exit\n"
+#, c-format
 msgid "    -F, --fullname                      Print full filename\n"
-msgstr "  -h, --help                      Показать эту справку и выйти\n"
+msgstr ""
+"    -F, --fullname                          Напечатать полное имя файла\n"
+"\n"
 
 #: gcov-tool.c:422
-#, fuzzy, c-format
-#| msgid "  -h, --help                      Print this help, then exit\n"
+#, c-format
 msgid "    -h, --hotonly                       Only print info for hot objects/functions\n"
-msgstr "  -h, --help                      Показать эту справку и выйти\n"
+msgstr ""
+"    -h, --hotonly                           Вывести информацию только о \"горячих\" объектах/функциях\n"
+"\n"
 
 #: gcov-tool.c:423
-#, fuzzy, c-format
-#| msgid "  -h, --help                      Print this help, then exit\n"
+#, c-format
 msgid "    -o, --object                        Print object level info\n"
-msgstr "  -h, --help                      Показать эту справку и выйти\n"
+msgstr ""
+"    -o, --object                            Вывести информацию уровня объекта\n"
+"\n"
 
 #: gcov-tool.c:424
 #, c-format
@@ -830,15 +846,14 @@
 #: gcov-tool.c:445
 #, c-format
 msgid "Overlap subcomand usage:"
-msgstr ""
+msgstr "Команда перекрытия (overlap):"
 
 #: gcov-tool.c:511
-#, fuzzy, c-format
-#| msgid "Usage: %s [OPTIONS]... CLASSNAMEmain [OUTFILE]\n"
+#, c-format
 msgid ""
 "Usage: %s [OPTION]... SUB_COMMAND [OPTION]...\n"
 "\n"
-msgstr "Использование: %s [КЛЮЧИ]... ИМЯ-КЛАССАmain [ВЫХОДНОЙ ФАЙЛ]\n"
+msgstr ""
 
 #: gcov-tool.c:512
 #, c-format
@@ -848,16 +863,14 @@
 msgstr ""
 
 #: gcov-tool.c:513
-#, fuzzy, c-format
-#| msgid "  -h, --help                      Print this help, then exit\n"
+#, c-format
 msgid "  -h, --help                            Print this help, then exit\n"
-msgstr "  -h, --help                      Показать эту справку и выйти\n"
+msgstr ""
 
 #: gcov-tool.c:514
-#, fuzzy, c-format
-#| msgid "  -v, --version                   Print version number, then exit\n"
+#, c-format
 msgid "  -v, --version                         Print version number, then exit\n"
-msgstr "  -v, --version                   Показать номер версии и выйти\n"
+msgstr ""
 
 #: gcov-tool.c:518 gcov.c:835
 #, c-format
@@ -884,21 +897,19 @@
 "\n"
 msgstr ""
 "Это свободно распространяемое программное обеспечение. Условия копирования\n"
-"приведены в исходных текстах. Без гарантии каких-либо качеств, включая \n"
-"коммерческую ценность и применимость для каких-либо целей.\n"
+"приведены в исходных текстах.\n"
 "\n"
+"\n"
+"There is NO warranty; not even for MERCHANTABILITY or \n"
+"FITNESS FOR A PARTICULAR PURPOSE.\n"
+"\n"
 
 #: gcov.c:811
-#, fuzzy, c-format
-#| msgid ""
-#| "Usage: gcov [OPTION]... SOURCE|OBJ...\n"
-#| "\n"
+#, c-format
 msgid ""
 "Usage: gcov [OPTION...] SOURCE|OBJ...\n"
 "\n"
 msgstr ""
-"Использование: gcov [КЛЮЧ]... ИСХОДНЫЙ/ОБЪЕКТНЫЙ ФАЙЛ...\n"
-"\n"
 
 #: gcov.c:812
 #, c-format
@@ -920,16 +931,11 @@
 msgstr "  -b, --branch-probabilities      Вывести вероятности переходов\n"
 
 #: gcov.c:815
-#, fuzzy, c-format
-#| msgid ""
-#| "  -c, --branch-counts             Given counts of branches taken\n"
-#| "                                    rather than percentages\n"
+#, c-format
 msgid ""
 "  -c, --branch-counts             Output counts of branches taken\n"
 "                                    rather than percentages\n"
 msgstr ""
-"  -c, --branch-counts             При счётчиках переходов, заданных\n"
-"                                    в абсолютных, а не в процентных значениях\n"
 
 #: gcov.c:817
 #, c-format
@@ -957,10 +963,9 @@
 msgstr ""
 
 #: gcov.c:822
-#, fuzzy, c-format
-#| msgid "  -n, --no-output                 Do not create an output file\n"
+#, c-format
 msgid "  -k, --use-colors                Emit colored output\n"
-msgstr "  -n, --no-output                 Не создавать выходной файл\n"
+msgstr ""
 
 #: gcov.c:823
 #, c-format
@@ -968,8 +973,6 @@
 "  -l, --long-file-names           Use long output file names for included\n"
 "                                    source files\n"
 msgstr ""
-"  -l, --long-file-names           Выводить длинные имена включаемых\n"
-"                                    исходных файлов\n"
 
 #: gcov.c:825
 #, c-format
@@ -1016,16 +1019,14 @@
 msgstr "  -v, --version                   Показать номер версии и выйти\n"
 
 #: gcov.c:833
-#, fuzzy, c-format
-#| msgid "  -v, --version                   Print version number, then exit\n"
+#, c-format
 msgid "  -w, --verbose                   Print verbose informations\n"
-msgstr "  -v, --version                   Показать номер версии и выйти\n"
+msgstr "  -w, --verbose                   Вывод подробной информации\n"
 
 #: gcov.c:834
-#, fuzzy, c-format
-#| msgid "  -p, --preserve-paths            Preserve all pathname components\n"
+#, c-format
 msgid "  -x, --hash-filenames            Hash long pathnames\n"
-msgstr "  -p, --preserve-paths            Сохранить все компоненты полного имени\n"
+msgstr "  -x, --hash-filenames            Хэшировать длинные пути к файлам\n"
 
 #: gcov.c:845
 #, c-format
@@ -1058,39 +1059,42 @@
 msgstr "\n"
 
 #: gcov.c:1299
-#, fuzzy, c-format
-#| msgid "%s: Cannot open output file: %s\n"
+#, c-format
 msgid "Cannot open intermediate output file %s\n"
-msgstr "%s: Ошибка открытия выходного файла: %s\n"
+msgstr "Не удалось открыть промежуточный выходной файл: %s\n"
 
 #: gcov.c:1505
-#, fuzzy, c-format
-#| msgid "%s:source file is newer than graph file '%s'\n"
+#, c-format
 msgid "%s:source file is newer than notes file '%s'\n"
-msgstr "%s:исходный файл новее чем файл графа '%s'\n"
+msgstr ""
+"%s: исходный файл новее файла заметок '%s'\n"
+"\n"
 
 #: gcov.c:1510
-#, fuzzy, c-format
-#| msgid "(the message is only displayed one per source file)\n"
+#, c-format
 msgid "(the message is displayed only once per source file)\n"
-msgstr "(для каждого файла исходных текстов сообщение будет выдано один раз)\n"
+msgstr ""
+"(сообщение выводится один раз для каждого исходного файла)\n"
+"\n"
 
 #: gcov.c:1530
-#, fuzzy, c-format
-#| msgid "%s:cannot open graph file\n"
+#, c-format
 msgid "%s:cannot open notes file\n"
-msgstr "%s:ошибка открытия графического файла\n"
+msgstr ""
+"%s: не удалось открыть файл заметок\n"
+"\n"
 
 #: gcov.c:1536
-#, fuzzy, c-format
-#| msgid "%s:not a gcov data file\n"
+#, c-format
 msgid "%s:not a gcov notes file\n"
-msgstr "%s:не файл данных gcov\n"
+msgstr ""
+"%s: не является файлом заметок gcov\n"
+"\n"
 
 #: gcov.c:1549
 #, c-format
 msgid "%s:version '%.4s', prefer '%.4s'\n"
-msgstr "%s:версия '%.4s', предпочтительно '%.4s'\n"
+msgstr "%s: версия '%.4s', предпочтительно '%.4s'\n"
 
 #: gcov.c:1600
 #, c-format
@@ -1123,15 +1127,16 @@
 msgstr "%s:версия '%.4s', предпочтительна версия '%.4s'\n"
 
 #: gcov.c:1764
-#, fuzzy, c-format
-#| msgid "%s:stamp mismatch with graph file\n"
+#, c-format
 msgid "%s:stamp mismatch with notes file\n"
-msgstr "%s:штамп не соответствует графическому файлу\n"
+msgstr ""
+"%s:штамп не соответствует файлу заметок\n"
+"\n"
 
 #: gcov.c:1807
 #, c-format
 msgid "%s:profile mismatch for '%s'\n"
-msgstr "%s:несоответствие профайла для '%s'\n"
+msgstr "%s:несоответствие профиля для '%s'\n"
 
 #: gcov.c:1825
 #, c-format
@@ -1214,21 +1219,19 @@
 msgstr "вызов  %2d ни разу не исполнялся\n"
 
 #: gcov.c:2692
-#, fuzzy, c-format
-#| msgid "branch %2d taken %s%s\n"
+#, c-format
 msgid "branch %2d taken %s%s"
-msgstr "переход %2d выполнен %s%s\n"
+msgstr "переход %2d выполнен %s%s"
 
 #: gcov.c:2697
-#, fuzzy, c-format
-#| msgid "branch %2d never executed\n"
+#, c-format
 msgid "branch %2d never executed"
-msgstr "переход %2d ни разу не исполнялся\n"
+msgstr "переход %2d ни разу не выполнялся"
 
 #: gcov.c:2700
 #, c-format
 msgid " (BB %d)"
-msgstr ""
+msgstr " (BB %d)"
 
 #: gcov.c:2707
 #, c-format
@@ -1253,16 +1256,15 @@
 msgid "GCSE disabled"
 msgstr "GCSE отключена"
 
-#: gimple-ssa-isolate-paths.c:542 c/c-typeck.c:10240
+#: gimple-ssa-isolate-paths.c:542 c/c-typeck.c:10245
 #, gcc-internal-format
 msgid "function returns address of local variable"
 msgstr "функция возвращает адрес локальной переменной"
 
 #: gimple-ssa-isolate-paths.c:544 gimple-ssa-isolate-paths.c:426
-#, fuzzy, gcc-internal-format
-#| msgid "function returns address of local variable"
+#, gcc-internal-format
 msgid "function may return address of local variable"
-msgstr "функция возвращает адрес локальной переменной"
+msgstr "функция может возвращать адрес локальной переменной"
 
 #: incpath.c:73
 #, c-format
@@ -1319,16 +1321,12 @@
 msgstr "В функции %qs"
 
 #: langhooks.c:454 cp/error.c:3396
-#, fuzzy
-#| msgid "    inlined from %qs at %s:%d:%d"
 msgid "    inlined from %qs at %r%s:%d:%d%R"
-msgstr "    включённом из %qs в %s:%d:%d"
+msgstr "    включённом из %qs в %r%s:%d:%d%R"
 
 #: langhooks.c:459 cp/error.c:3401
-#, fuzzy
-#| msgid "    inlined from %qs at %s:%d"
 msgid "    inlined from %qs at %r%s:%d%R"
-msgstr "    включённом из %qs в %s:%d"
+msgstr "    включённом из %qs в %r%s:%d%R"
 
 #: langhooks.c:465 cp/error.c:3407
 #, c-format
@@ -1345,31 +1343,28 @@
 
 #. What to print when a switch has no documentation.
 #: opts.c:185
-#, fuzzy
-#| msgid "This switch lacks documentation"
 msgid "This option lacks documentation."
 msgstr "Этот ключ не документирован"
 
 #: opts.c:186
 msgid "Uses of this option are diagnosed."
-msgstr ""
+msgstr "При использовании этого ключа выдается предупреждение"
 
 #: opts.c:1148
 #, c-format
 msgid "default %d minimum %d maximum %d"
-msgstr ""
+msgstr "по умолчанию %d, минимум %d, максимум %d"
 
 #: opts.c:1215
 #, c-format
 msgid "Same as %s.  Use the latter option instead."
-msgstr ""
+msgstr "Аналог %s.  Лучше использовать последний вариант."
 
 #
 #: opts.c:1223
-#, fuzzy, c-format
-#| msgid "(%s %s %s %s %s"
+#, c-format
 msgid "%s  Same as %s."
-msgstr "(%s %s %s %s %s"
+msgstr "(%s  Аналог %s."
 
 #: opts.c:1294
 msgid "[default]"
@@ -1386,13 +1381,14 @@
 #: opts.c:1333
 #, c-format
 msgid " No options with the desired characteristics were found\n"
-msgstr " Не найдено ключей с требуемыми характеристиками\n"
+msgstr " Не найдены ключи с требуемыми характеристиками\n"
 
 #: opts.c:1342
-#, fuzzy, c-format
-#| msgid " None found.  Use --help=%s to show *all* the options supported by the %s front-end\n"
+#, c-format
 msgid " None found.  Use --help=%s to show *all* the options supported by the %s front-end.\n"
-msgstr " Не найдено.  Задайте --help=%s для вывода *всех* ключей, поддерживаемых для языка %s\n"
+msgstr ""
+" Ничего не найдено.  --help=%s выводит *все* ключи, поддерживаемые для языка %s.\n"
+"\n"
 
 #: opts.c:1348
 #, c-format
@@ -1444,17 +1440,15 @@
 msgstr "Следующие ключи относятся к исходному языку"
 
 #: passes.c:1797
-#, fuzzy, c-format
-#| msgid "deducing %qT as %qT"
+#, c-format
 msgid "during %s pass: %s\n"
-msgstr "вывод %qT как %qT"
+msgstr "в течение прохода %s: %s\n"
 
 #
 #: passes.c:1802
-#, fuzzy, c-format
-#| msgid "In file %s:%d\n"
+#, c-format
 msgid "dump file: %s\n"
-msgstr "В файле %s:%d\n"
+msgstr "файл вывода: %s\n"
 
 #: plugin.c:923
 msgid "Event"
@@ -1544,10 +1538,11 @@
 msgstr "%s%s%s %sверсия %s (%s) скомпилировано CC, "
 
 #: toplev.c:635
-#, fuzzy, c-format
-#| msgid "GMP version %s, MPFR version %s, MPC version %s\n"
+#, c-format
 msgid "GMP version %s, MPFR version %s, MPC version %s, isl version %s\n"
-msgstr "Версия GMP %s, версия MPFR %s, версия MPC %s\n"
+msgstr ""
+"Версия GMP %s, версия MPFR %s, версия MPC %s, версия isl %s\n"
+"\n"
 
 #: toplev.c:637
 #, c-format
@@ -1567,7 +1562,7 @@
 msgid "options enabled: "
 msgstr "активные ключи: "
 
-#: tree-diagnostic.c:299 c/c-decl.c:5419 c/c-typeck.c:7259 cp/error.c:1042
+#: tree-diagnostic.c:299 c/c-decl.c:5439 c/c-typeck.c:7264 cp/error.c:1042
 #: c-family/c-pretty-print.c:413
 #, gcc-internal-format
 msgid "<anonymous>"
@@ -1578,10 +1573,8 @@
 msgstr "функция не подлежит inline-подстановке"
 
 #: cif-code.def:43
-#, fuzzy
-#| msgid "%qE is not initialized"
 msgid "caller is not optimized"
-msgstr "%qE не инициализирован"
+msgstr "вызывающая функция не оптимизирована"
 
 #: cif-code.def:47
 msgid "function body not available"
@@ -1640,14 +1633,12 @@
 msgstr "несовпадающие аргументы"
 
 #: cif-code.def:96
-#, fuzzy
-#| msgid "expected iteration declaration or initialization"
 msgid "mismatched declarations during linktime optimization"
-msgstr "ожидалась декларация итерации или инициализация"
+msgstr "несоответствие деклараций при оптимизации времени компоновки"
 
 #: cif-code.def:100
 msgid "variadic thunk call"
-msgstr ""
+msgstr "выбор вариантного thunk"
 
 #: cif-code.def:104
 msgid "originally indirect function call not considered for inlining"
@@ -1675,23 +1666,19 @@
 
 #: cif-code.def:129
 msgid "callee refers to comdat-local symbols"
-msgstr ""
+msgstr "вызываемая функция ссылается на локальные comdat символы"
 
 #: cif-code.def:133
-#, fuzzy
-#| msgid "optimization level attribute mismatch"
 msgid "function attribute mismatch"
-msgstr "несовпадение атрибута уровня оптимизации"
+msgstr "несовпадение атрибутов функции"
 
 #: cif-code.def:137
-#, fuzzy
-#| msgid "unrecoverable error"
 msgid "unreachable"
-msgstr "невосстанавливаемая ошибка"
+msgstr "недостижим"
 
 #: cif-code.def:141
 msgid "caller is instrumentation thunk"
-msgstr ""
+msgstr "вызывающая функция является thunk'ом инструментирования"
 
 #. The remainder are real diagnostic types.
 #: diagnostic.def:33
@@ -1741,164 +1728,139 @@
 msgstr "permerror: "
 
 #: params.def:49
-#, fuzzy, no-c-format
-#| msgid "Maximal estimated outcome of branch considered predictable"
+#, no-c-format
 msgid "Maximal estimated outcome of branch considered predictable."
-msgstr "Максимальная оценка перехода по ветвлению, которое считается предсказанным"
+msgstr "Максимальная оценка перехода по ветвлению, которое считается предсказанным."
 
 #: params.def:54
 #, no-c-format
 msgid "The minimal estimated speedup allowing inliner to ignore inline-insns-single and inline-insns-auto."
-msgstr ""
+msgstr "Минимальная оценка ускорения, при которой допускается игнорирование параметров inline-insns-single и inline-insns-auto."
 
 #: params.def:71
-#, fuzzy, no-c-format
-#| msgid "The maximum number of instructions in a single function eligible for inlining"
+#, no-c-format
 msgid "The maximum number of instructions in a single function eligible for inlining."
-msgstr "Максимальное число команд в функции, пригодной для inline-подстановки"
+msgstr "Максимальное число команд в функции, пригодной для inline-подстановки."
 
 #: params.def:83
-#, fuzzy, no-c-format
-#| msgid "The maximum number of instructions when automatically inlining"
+#, no-c-format
 msgid "The maximum number of instructions when automatically inlining."
-msgstr "Максимальное число команд при автоматической inline-подстановке"
+msgstr "Максимальное число команд при автоматической inline-подстановке."
 
 #: params.def:88
-#, fuzzy, no-c-format
-#| msgid "The maximum number of instructions inline function can grow to via recursive inlining"
+#, no-c-format
 msgid "The maximum number of instructions inline function can grow to via recursive inlining."
-msgstr "Максимальное число команд, на которое может увеличиться inline-функция в результате рекурсивной подстановки"
+msgstr "Максимальное число команд, на которое может увеличиться inline-функция в результате рекурсивной подстановки."
 
 #: params.def:93
-#, fuzzy, no-c-format
-#| msgid "The maximum number of instructions non-inline function can grow to via recursive inlining"
+#, no-c-format
 msgid "The maximum number of instructions non-inline function can grow to via recursive inlining."
-msgstr "Максимальное число инструкций, на которое может увеличится не-inline функция в результате рекурсивных inline-подстановок"
+msgstr "Максимальное число инструкций, на которое может увеличится не-inline функция в результате рекурсивных inline-подстановок."
 
 #: params.def:98
-#, fuzzy, no-c-format
-#| msgid "The maximum depth of recursive inlining for inline functions"
+#, no-c-format
 msgid "The maximum depth of recursive inlining for inline functions."
-msgstr "Максимальная глубина рекурсивных inline-подстановок для inline функций"
+msgstr "Максимальная глубина рекурсивных inline-подстановок для inline функций."
 
 #: params.def:103
-#, fuzzy, no-c-format
-#| msgid "The maximum depth of recursive inlining for non-inline functions"
+#, no-c-format
 msgid "The maximum depth of recursive inlining for non-inline functions."
-msgstr "Максимальная глубина рекурсивных inline-подстановок для не-inline функций"
+msgstr "Максимальная глубина рекурсивных inline-подстановок для не-inline функций."
 
 #: params.def:108
-#, fuzzy, no-c-format
-#| msgid "Inline recursively only when the probability of call being executed exceeds the parameter"
+#, no-c-format
 msgid "Inline recursively only when the probability of call being executed exceeds the parameter."
-msgstr "Выполнять рекурсивную inline-подстановку, только если вероятность данного вызова превышает значение этого параметра"
+msgstr "Выполнять рекурсивную inline-подстановку, только если вероятность данного вызова превышает значение этого параметра."
 
 #: params.def:116
-#, fuzzy, no-c-format
-#| msgid "The maximum number of nested indirect inlining performed by early inliner"
+#, no-c-format
 msgid "The maximum number of nested indirect inlining performed by early inliner."
-msgstr "Максимальное число вложенных косвенных inline-подстановок, выполняемых при первом проходе подстановок"
+msgstr "Максимальное число вложенных косвенных inline-подстановок, выполняемых при первом проходе подстановок."
 
 #: params.def:122
-#, fuzzy, no-c-format
-#| msgid "Probability that COMDAT function will be shared with different compilation unit"
+#, no-c-format
 msgid "Probability that COMDAT function will be shared with different compilation unit."
-msgstr "Вероятность того, что функция COMDAT будет разделена с другой единицей компиляции"
+msgstr "Вероятность того, что функция COMDAT будет разделена с другой единицей компиляции."
 
 #: params.def:128
-#, fuzzy, no-c-format
-#| msgid "Maximum probability of the entry BB of split region (in percent relative to entry BB of the function) to make partial inlining happen"
+#, no-c-format
 msgid "Maximum probability of the entry BB of split region (in percent relative to entry BB of the function) to make partial inlining happen."
-msgstr "Максимальная вероятность входного базового блока разбиваемого региона (в процентах по отношению к входному блоку функции) для выполнения частичной inline-подстановки"
+msgstr "Максимальная вероятность входного базового блока разбиваемого региона (в процентах по отношению к входному блоку функции) для выполнения частичной inline-подстановки."
 
 #: params.def:135
-#, fuzzy, no-c-format
-#| msgid "If -fvariable-expansion-in-unroller is used, the maximum number of times that an individual variable will be expanded during loop unrolling"
+#, no-c-format
 msgid "If -fvariable-expansion-in-unroller is used, the maximum number of times that an individual variable will be expanded during loop unrolling."
-msgstr "При использовании -fvariable-expansion-in-unroller - максимальное число копий каждой переменной, которое может быть создано при развертке цикла"
+msgstr "При использовании -fvariable-expansion-in-unroller - максимальное число копий каждой переменной, которое может быть создано при развертке цикла."
 
 #: params.def:141
-#, fuzzy, no-c-format
-#| msgid "If -ftree-vectorize is used, the minimal loop bound of a loop to be considered for vectorization"
+#, no-c-format
 msgid "If -ftree-vectorize is used, the minimal loop bound of a loop to be considered for vectorization."
-msgstr "При включенном -ftree-vectorize, минимальное число итераций цикла, пригодного для векторизации"
+msgstr "При включенном -ftree-vectorize, минимальное число итераций цикла, пригодного для векторизации."
 
 #: params.def:152
-#, fuzzy, no-c-format
-#| msgid "The maximum number of instructions to consider to fill a delay slot"
+#, no-c-format
 msgid "The maximum number of instructions to consider to fill a delay slot."
-msgstr "Максимальное число команд, рассматриваемых при заполнении гнезд задержки"
+msgstr "Максимальное число команд, рассматриваемых при заполнении гнезд задержки."
 
 #: params.def:163
-#, fuzzy, no-c-format
-#| msgid "The maximum number of instructions to consider to find accurate live register information"
+#, no-c-format
 msgid "The maximum number of instructions to consider to find accurate live register information."
-msgstr "Максимальное число команд, рассматриваемых при вычислении областей жизни значений на регистрах"
+msgstr "Максимальное число команд, рассматриваемых при вычислении областей жизни значений на регистрах."
 
 #: params.def:173
-#, fuzzy, no-c-format
-#| msgid "The maximum length of scheduling's pending operations list"
+#, no-c-format
 msgid "The maximum length of scheduling's pending operations list."
-msgstr "Максимальный размер списка ждущих операций при планировании"
+msgstr "Максимальный размер списка ждущих операций при планировании."
 
 #: params.def:180
-#, fuzzy, no-c-format
-#| msgid "The maximum number of backtrack attempts the scheduler should make when modulo scheduling a loop"
+#, no-c-format
 msgid "The maximum number of backtrack attempts the scheduler should make when modulo scheduling a loop."
-msgstr "Максимальное число попыток возврата при программной конвейеризации (планировании по модулю) цикла"
+msgstr "Максимальное число попыток возврата при программной конвейеризации (планировании по модулю) цикла."
 
 #: params.def:185
-#, fuzzy, no-c-format
-#| msgid "The size of function body to be considered large"
+#, no-c-format
 msgid "The size of function body to be considered large."
-msgstr "Размер тела \"большой\" функции"
+msgstr "Размер тела \"большой\" функции."
 
 #: params.def:189
-#, fuzzy, no-c-format
-#| msgid "Maximal growth due to inlining of large function (in percent)"
+#, no-c-format
 msgid "Maximal growth due to inlining of large function (in percent)."
-msgstr "Максимальный рост объема \"большой\" функции в результате inline-подстановок (в процентах)"
+msgstr "Максимальный рост объема \"большой\" функции в результате inline-подстановок (в процентах)."
 
 #: params.def:193
-#, fuzzy, no-c-format
-#| msgid "The size of translation unit to be considered large"
+#, no-c-format
 msgid "The size of translation unit to be considered large."
-msgstr "Размер тела \"большой\" функции"
+msgstr "Размер тела \"большой\" функции."
 
 #: params.def:197
-#, fuzzy, no-c-format
-#| msgid "How much can given compilation unit grow because of the inlining (in percent)"
+#, no-c-format
 msgid "How much can given compilation unit grow because of the inlining (in percent)."
-msgstr "Максимальный рост объема кода для единицы компиляции в результате inline-подстановок (в процентах)"
+msgstr "Максимальный рост объема кода для единицы компиляции в результате inline-подстановок (в процентах)."
 
 #: params.def:201
-#, fuzzy, no-c-format
-#| msgid "How much can given compilation unit grow because of the interprocedural constant propagation (in percent)"
+#, no-c-format
 msgid "How much can given compilation unit grow because of the interprocedural constant propagation (in percent)."
-msgstr "Максимальный рост объема кода для единицы компиляции в результате межпроцедурного распространения констант (в процентах)"
+msgstr "Максимальный рост объема кода для единицы компиляции в результате межпроцедурного распространения констант (в процентах)."
 
 #: params.def:205
-#, fuzzy, no-c-format
-#| msgid "Maximal estimated growth of function body caused by early inlining of single call"
+#, no-c-format
 msgid "Maximal estimated growth of function body caused by early inlining of single call."
-msgstr "Максимальная оценка роста тела функции в результате ранней inline-подстановки одного вызова"
+msgstr "Максимальная оценка роста тела функции в результате ранней inline-подстановки одного вызова."
 
 #: params.def:209
-#, fuzzy, no-c-format
-#| msgid "The size of stack frame to be considered large"
+#, no-c-format
 msgid "The size of stack frame to be considered large."
-msgstr "Размер окна стека, считающийся достаточно большим"
+msgstr "Размер кадра стека, считающийся большим."
 
 #: params.def:213
-#, fuzzy, no-c-format
-#| msgid "Maximal stack frame growth due to inlining (in percent)"
+#, no-c-format
 msgid "Maximal stack frame growth due to inlining (in percent)."
-msgstr "Максимальный рост окна стека из-за inline-подстановок функций (в процентах)"
+msgstr "Максимальный рост кадра стека из-за inline-подстановок функций (в процентах)."
 
 #: params.def:218
 #, no-c-format
 msgid "Size of the stack guard expressed as a power of two."
-msgstr ""
+msgstr "Size of the stack guard expressed as a power of two."
 
 #: params.def:223
 #, no-c-format
@@ -1906,406 +1868,344 @@
 msgstr ""
 
 #: params.def:230
-#, fuzzy, no-c-format
-#| msgid "The maximum amount of memory to be allocated by GCSE"
+#, no-c-format
 msgid "The maximum amount of memory to be allocated by GCSE."
-msgstr "Максимальный объем памяти для работы GCSE"
+msgstr "Максимальный объем памяти для работы GCSE."
 
 #: params.def:237
-#, fuzzy, no-c-format
-#| msgid "The maximum ratio of insertions to deletions of expressions in GCSE"
+#, no-c-format
 msgid "The maximum ratio of insertions to deletions of expressions in GCSE."
-msgstr "Максимальное отношение числа вставок к числу удалений выражений при глобальном исключении общих подвыражений (GCSE)"
+msgstr "Максимальное отношение числа вставок к числу удалений выражений при глобальном исключении общих подвыражений (GCSE)."
 
 #: params.def:248
-#, fuzzy, no-c-format
-#| msgid "The threshold ratio for performing partial redundancy elimination after reload"
+#, no-c-format
 msgid "The threshold ratio for performing partial redundancy elimination after reload."
-msgstr "Пороговое отношение для выполнения частичного удаления избыточных операций после прохода reload"
+msgstr "Пороговое отношение для выполнения частичного удаления избыточных операций после прохода reload."
 
 #: params.def:255
-#, fuzzy, no-c-format
-#| msgid "The threshold ratio of critical edges execution count that permit performing redundancy elimination after reload"
+#, no-c-format
 msgid "The threshold ratio of critical edges execution count that permit performing redundancy elimination after reload."
-msgstr "Пороговое соотношение счётчиков выполнения критических дуг, при котором после прохода reload может выполняться частичное удаление избыточных операций"
+msgstr "Пороговое соотношение счётчиков выполнения критических дуг, при котором после прохода reload может выполняться частичное удаление избыточных операций."
 
 #: params.def:263
-#, fuzzy, no-c-format
-#| msgid "Scaling factor in calculation of maximum distance an expression can be moved by GCSE optimizations"
+#, no-c-format
 msgid "Scaling factor in calculation of maximum distance an expression can be moved by GCSE optimizations."
-msgstr "Масштабирующий множитель при вычислении максимального расстояния, на которое выражение может быть смещено при GCSE"
+msgstr "Масштабирующий множитель при вычислении максимального расстояния, на которое выражение может быть смещено при GCSE."
 
 #: params.def:269
-#, fuzzy, no-c-format
-#| msgid "Cost at which GCSE optimizations will not constraint the distance an expression can travel"
+#, no-c-format
 msgid "Cost at which GCSE optimizations will not constraint the distance an expression can travel."
-msgstr "Стоимость, при которой в GCSE не будет ограничиваться расстояние перемещения выражений"
+msgstr "Стоимость, при которой в GCSE не будет ограничиваться расстояние перемещения выражений."
 
 #: params.def:277
-#, fuzzy, no-c-format
-#| msgid "Maximum depth of search in the dominator tree for expressions to hoist"
+#, no-c-format
 msgid "Maximum depth of search in the dominator tree for expressions to hoist."
-msgstr "Максимальная глубина поиска в дереве доминаторов для поднятия выражения"
+msgstr "Максимальная глубина поиска в дереве доминаторов для поднятия выражения."
 
 #: params.def:285
 #, no-c-format
 msgid "Maximum depth of sqrt chains to use when synthesizing exponentiation by a real constant."
-msgstr ""
+msgstr "Максимальная глубина цепочек sqrt при вычислении экспоненты вещественной константы."
 
 #: params.def:297
-#, fuzzy, no-c-format
-#| msgid "The maximum number of instructions to consider to unroll in a loop"
+#, no-c-format
 msgid "The maximum number of instructions to consider to unroll in a loop."
-msgstr "Максимальное число инструкций в развернутом цикле"
+msgstr "Максимальное число инструкций в развернутом цикле."
 
 #: params.def:303
-#, fuzzy, no-c-format
-#| msgid "The maximum number of instructions to consider to unroll in a loop on average"
+#, no-c-format
 msgid "The maximum number of instructions to consider to unroll in a loop on average."
-msgstr "Максимальное среднее число реально выполняемых инструкций в развернутом цикле"
+msgstr "Максимальное среднее число реально выполняемых инструкций в развернутом цикле."
 
 #: params.def:308
-#, fuzzy, no-c-format
-#| msgid "The maximum number of unrollings of a single loop"
+#, no-c-format
 msgid "The maximum number of unrollings of a single loop."
-msgstr "Максимальный коэффициент развертки цикла"
+msgstr "Максимальный коэффициент развертки цикла."
 
 #: params.def:313
-#, fuzzy, no-c-format
-#| msgid "The maximum number of insns of a peeled loop"
+#, no-c-format
 msgid "The maximum number of insns of a peeled loop."
-msgstr "Максимальное число инструкций в раскатанном цикле"
+msgstr "Максимальное число инструкций в раскатанном цикле."
 
 #: params.def:318
-#, fuzzy, no-c-format
-#| msgid "The maximum number of peelings of a single loop"
+#, no-c-format
 msgid "The maximum number of peelings of a single loop."
-msgstr "Максимальный коэффициент раскатки цикла"
+msgstr "Максимальный коэффициент раскатки цикла."
 
 #: params.def:323
-#, fuzzy, no-c-format
-#| msgid "The maximum number of iterations through CFG to extend regions"
+#, no-c-format
 msgid "The maximum number of branches on the path through the peeled sequence."
-msgstr "Максимальное число итераций по CFG для расширения регионов"
+msgstr "Максимальное число ветвлений на пути вдоль раскатанной последовательности."
 
 #: params.def:328
-#, fuzzy, no-c-format
-#| msgid "The maximum number of insns of a completely peeled loop"
+#, no-c-format
 msgid "The maximum number of insns of a completely peeled loop."
-msgstr "Максимальное число инструкций в полностью раскатанном цикле"
+msgstr "Максимальное число инструкций в полностью раскатанном цикле."
 
 #: params.def:333
-#, fuzzy, no-c-format
-#| msgid "The maximum number of peelings of a single loop that is peeled completely"
+#, no-c-format
 msgid "The maximum number of peelings of a single loop that is peeled completely."
-msgstr "Максимальный коэффициент для полной раскатки цикла"
+msgstr "Максимальный коэффициент, допустимый для полной раскатки цикла."
 
 #: params.def:338
-#, fuzzy, no-c-format
-#| msgid "The maximum number of insns of a peeled loop that rolls only once"
+#, no-c-format
 msgid "The maximum number of insns of a peeled loop that rolls only once."
-msgstr "Максимальное число инструкций в раскатанном цикле, выполняемом только один раз"
+msgstr "Максимальное число инструкций в раскатанном цикле, выполняемом только один раз."
 
 #: params.def:343
-#, fuzzy, no-c-format
-#| msgid "The maximum depth of a loop nest we completely peel"
+#, no-c-format
 msgid "The maximum depth of a loop nest we completely peel."
-msgstr "Максимальное число инструкций в цикле, который полностью раскатывается"
+msgstr "Максимальная глубина гнезда циклов, которое может быть полностью раскатано."
 
 #: params.def:349
-#, fuzzy, no-c-format
-#| msgid "The maximum number of insns of an unswitched loop"
+#, no-c-format
 msgid "The maximum number of insns of an unswitched loop."
-msgstr "Максимальное число инструкций в разомкнутом (unswitched) цикле"
+msgstr "Максимальное число инструкций в разомкнутом (unswitched) цикле."
 
 #: params.def:354
-#, fuzzy, no-c-format
-#| msgid "The maximum number of unswitchings in a single loop"
+#, no-c-format
 msgid "The maximum number of unswitchings in a single loop."
-msgstr "Максимальный число размыканий одного цикла"
+msgstr "Максимальный число размыканий одного цикла."
 
 #: params.def:361
-#, fuzzy, no-c-format
-#| msgid "The maximum number of insns to duplicate when unfactoring computed gotos"
+#, no-c-format
 msgid "The maximum number of insns in loop header duplicated by the copy loop headers pass."
-msgstr "Максимальное число дублируемых инструкций при факторизации вычисляемых goto"
+msgstr "Максимальное число инструкций в заголовке цикла, дублируемых в проходе копирования заголовков цикла."
 
 #: params.def:368
-#, fuzzy, no-c-format
-#| msgid "Bound on the number of iterations the brute force # of iterations analysis algorithm evaluates"
+#, no-c-format
 msgid "Bound on the number of iterations the brute force # of iterations analysis algorithm evaluates."
-msgstr "Максимальное число итераций, при вычислении которого будет применен метод \"грубой силы\""
+msgstr "Максимальное число итераций, при вычислении которого будет применен метод \"грубой силы\"."
 
 #: params.def:374
-#, fuzzy, no-c-format
-#| msgid "Bound on the cost of an expression to compute the number of iterations"
+#, no-c-format
 msgid "Bound on the cost of an expression to compute the number of iterations."
-msgstr "Граница цены выражения для вычисления числа итераций"
+msgstr "Граница цены выражения для вычисления числа итераций."
 
 #: params.def:380
-#, fuzzy, no-c-format
-#| msgid "A factor for tuning the upper bound that swing modulo scheduler uses for scheduling a loop"
+#, no-c-format
 msgid "A factor for tuning the upper bound that swing modulo scheduler uses for scheduling a loop."
-msgstr "Множитель для настройки верхней границы числа тактов при конвейеризации циклов методом swing modulo scheduling"
+msgstr "Множитель для настройки верхней границы числа тактов при конвейеризации циклов методом swing modulo scheduling."
 
 #: params.def:385
 #, no-c-format
 msgid "The minimum value of stage count that swing modulo scheduler will generate."
-msgstr "Минимальное число стадий в конвейеризованном цикле при планировании методом swing modulo scheduling"
+msgstr "Минимальное число стадий в конвейеризованном цикле при планировании методом swing modulo scheduling."
 
 #: params.def:389
-#, fuzzy, no-c-format
-#| msgid "The number of cycles the swing modulo scheduler considers when checking conflicts using DFA"
+#, no-c-format
 msgid "The number of cycles the swing modulo scheduler considers when checking conflicts using DFA."
-msgstr "Число тактов, учитываемых алгоритмом swing modulo scheduling при проверке конфликтов по ресурсам"
+msgstr "Число тактов, учитываемых алгоритмом swing modulo scheduling при проверке конфликтов по ресурсам."
 
 #: params.def:393
-#, fuzzy, no-c-format
-#| msgid "A threshold on the average loop count considered by the swing modulo scheduler"
+#, no-c-format
 msgid "A threshold on the average loop count considered by the swing modulo scheduler."
-msgstr "Пороговое значение среднего числа итераций цикла для применения конвейеризации методом swing modulo scheduling"
+msgstr "Пороговое значение среднего числа итераций цикла для применения конвейеризации методом swing modulo scheduling."
 
 #: params.def:398
 #, no-c-format
 msgid "A basic block profile count is considered hot if it contributes to the given permillage of the entire profiled execution."
-msgstr ""
+msgstr "Базовый блок будет считаться горячим, если его счётчик вносит вклад в заданный интервал всего профиля"
 
 #: params.def:403
-#, fuzzy, no-c-format
-#| msgid "Select fraction of the maximal frequency of executions of basic block in function given basic block needs to have to be considered hot"
+#, no-c-format
 msgid "Select fraction of the maximal frequency of executions of basic block in function given basic block needs to have to be considered hot."
-msgstr "Относительная максимальная частота повторений блока в программе, при превышении которой блок должен считаться критическим"
+msgstr "Относительная максимальная частота повторений блока в программе, при превышении которой блок должен считаться критическим."
 
 #: params.def:408
 #, no-c-format
 msgid "The minimum fraction of profile runs a given basic block execution count must be not to be considered unlikely."
-msgstr ""
+msgstr "Минимальная доля профиля, такая, что если счётчик блока ее превышает, то он не считается маловероятным"
 
 #: params.def:413
-#, fuzzy, no-c-format
-#| msgid "Select fraction of the maximal frequency of executions of basic block in function given basic block get alignment"
+#, no-c-format
 msgid "Select fraction of the maximal frequency of executions of basic block in function given basic block get alignment."
-msgstr "Относительная максимальная частота повторений блока в программе, при превышении которой блок должен выравниваться"
+msgstr "Относительная максимальная частота повторений блока в программе, при превышении которой блок должен выравниваться."
 
 #: params.def:418
-#, fuzzy, no-c-format
-#| msgid "Loops iterating at least selected number of iterations will get loop alignement."
+#, no-c-format
 msgid "Loops iterating at least selected number of iterations will get loop alignment.."
 msgstr "Циклы с таким или с большим количеством итераций будут выравниваться."
 
 #: params.def:434
-#, fuzzy, no-c-format
-#| msgid "The maximum number of loop iterations we predict statically"
+#, no-c-format
 msgid "The maximum number of loop iterations we predict statically."
-msgstr "Максимальное число итераций цикла для статического предсказания"
+msgstr "Максимальное число итераций цикла для статического предсказания."
 
 #: params.def:447
 #, no-c-format
 msgid "Set the estimated probability in percentage for builtin expect. The default value is 90% probability."
-msgstr ""
+msgstr "Оценка вероятности в процентах для builtin expect. По умолчанию 90%."
 
 #: params.def:451
-#, fuzzy, no-c-format
-#| msgid "The percentage of function, weighted by execution frequency, that must be covered by trace formation. Used when profile feedback is available"
+#, no-c-format
 msgid "The percentage of function, weighted by execution frequency, that must be covered by trace formation. Used when profile feedback is available."
-msgstr "Процент объёма кода функции, взвешенный по частоте выполнения, который должен быть охвачен при формировании трасс планирования. Используется, когда имеются данные профилирования"
+msgstr "Процент объёма кода функции, взвешенный по частоте выполнения, который должен быть охвачен при формировании трасс планирования. Используется, когда имеются данные профилирования."
 
 #: params.def:455
-#, fuzzy, no-c-format
-#| msgid "The percentage of function, weighted by execution frequency, that must be covered by trace formation. Used when profile feedback is not available"
+#, no-c-format
 msgid "The percentage of function, weighted by execution frequency, that must be covered by trace formation. Used when profile feedback is not available."
-msgstr "Процент объёма кода функции, взвешенный по частоте выполнения, который должен быть охвачен при формировании трасс планирования. используется, когда данные профилирования отсутствуют"
+msgstr "Процент объёма кода функции, взвешенный по частоте выполнения, который должен быть охвачен при формировании трасс планирования. Используется, когда имеются данные профилирования."
 
 #: params.def:459
-#, fuzzy, no-c-format
-#| msgid "Maximal code growth caused by tail duplication (in percent)"
+#, no-c-format
 msgid "Maximal code growth caused by tail duplication (in percent)."
-msgstr "Максимальный рост кода за счёт дублирования хвостов (в процентах)"
+msgstr "Максимальный рост кода за счёт дублирования хвостов (в процентах)."
 
 #: params.def:463
-#, fuzzy, no-c-format
-#| msgid "Stop reverse growth if the reverse probability of best edge is less than this threshold (in percent)"
+#, no-c-format
 msgid "Stop reverse growth if the reverse probability of best edge is less than this threshold (in percent)."
-msgstr "Прекратить обратный просмотр, если обратная вероятность лучшей дуги меньше заданного порогового значения (в процентах)"
+msgstr "Прекратить обратный просмотр, если обратная вероятность лучшей дуги меньше заданного порогового значения (в процентах)."
 
 #: params.def:467
-#, fuzzy, no-c-format
-#| msgid "Stop forward growth if the probability of best edge is less than this threshold (in percent). Used when profile feedback is available"
+#, no-c-format
 msgid "Stop forward growth if the probability of best edge is less than this threshold (in percent). Used when profile feedback is available."
-msgstr "Прекратить просмотр, если вероятность лучшей дуги меньше заданного порогового значения (в процентах). Используется, если доступны данные профилирования"
+msgstr "Прекратить просмотр, если вероятность лучшей дуги меньше заданного порогового значения (в процентах). Используется, когда имеются данные профилирования."
 
 #: params.def:471
-#, fuzzy, no-c-format
-#| msgid "Stop forward growth if the probability of best edge is less than this threshold (in percent). Used when profile feedback is not available"
+#, no-c-format
 msgid "Stop forward growth if the probability of best edge is less than this threshold (in percent). Used when profile feedback is not available."
-msgstr "Прекратить просмотр, если вероятность лучшей дуги меньше заданного порогового значения (в процентах). Используется при отсутствии данных профилирования"
+msgstr "Прекратить просмотр, если вероятность лучшей дуги меньше заданного порогового значения (в процентах). Используется, когда имеются данные профилирования."
 
 #: params.def:477
-#, fuzzy, no-c-format
-#| msgid "The maximum number of incoming edges to consider for crossjumping"
+#, no-c-format
 msgid "The maximum number of incoming edges to consider for crossjumping."
-msgstr "Максимальное число входящих дуг, рассматриваемых при перекрестных переходах"
+msgstr "Максимальное число входящих дуг, рассматриваемых при перекрестных переходах."
 
 #: params.def:483
-#, fuzzy, no-c-format
-#| msgid "The minimum number of matching instructions to consider for crossjumping"
+#, no-c-format
 msgid "The minimum number of matching instructions to consider for crossjumping."
-msgstr "Минимальное число совпадающих инструкций, при котором применяется оптимизация перекрестных ссылок"
+msgstr "Минимальное число совпадающих инструкций, при котором применяется оптимизация перекрестных переходов."
 
 #: params.def:489
-#, fuzzy, no-c-format
-#| msgid "The maximum expansion factor when copying basic blocks"
+#, no-c-format
 msgid "The maximum expansion factor when copying basic blocks."
-msgstr "Максимальный коэффициент увеличения размера кода при копировании базовых блоков"
+msgstr "Максимальный коэффициент увеличения размера кода при копировании базовых блоков."
 
 #: params.def:495
-#, fuzzy, no-c-format
-#| msgid "The maximum number of insns to duplicate when unfactoring computed gotos"
+#, no-c-format
 msgid "The maximum number of insns to duplicate when unfactoring computed gotos."
-msgstr "Максимальное число дублируемых инструкций при факторизации вычисляемых goto"
+msgstr "Максимальное число дублируемых инструкций при факторизации вычисляемых goto."
 
 #: params.def:501
-#, fuzzy, no-c-format
-#| msgid "The maximum length of path considered in cse"
+#, no-c-format
 msgid "The maximum length of path considered in cse."
-msgstr "Максимальная длина пути, рассматриваемого при экономии общих подвыражений"
+msgstr "Максимальная длина пути, рассматриваемого при экономии общих подвыражений."
 
 #: params.def:505
-#, fuzzy, no-c-format
-#| msgid "The maximum instructions CSE process before flushing"
+#, no-c-format
 msgid "The maximum instructions CSE process before flushing."
-msgstr "Максимальное число инструкций, обрабатываемых CSE между сбросами хеш-таблицы"
+msgstr "Максимальное число инструкций, обрабатываемых CSE между сбросами хеш-таблицы."
 
 #: params.def:512
-#, fuzzy, no-c-format
-#| msgid "The minimum cost of an expensive expression in the loop invariant motion"
+#, no-c-format
 msgid "The minimum cost of an expensive expression in the loop invariant motion."
-msgstr "При вынесении инвариантов цикла - минимальная цена выражения, рассматриваемого как дорогостоящее "
+msgstr "При вынесении инвариантов цикла - минимальная цена выражения, рассматриваемого как дорогостоящее."
 
 #: params.def:521
-#, fuzzy, no-c-format
-#| msgid "Bound on number of candidates below that all candidates are considered in iv optimizations"
+#, no-c-format
 msgid "Bound on number of candidates below that all candidates are considered in iv optimizations."
-msgstr "Если число кандидатов менее данного значения, при оптимизации индуктивных переменных рассматриваются все кандидаты"
+msgstr "Если число кандидатов менее данного значения, при оптимизации индуктивных переменных рассматриваются все кандидаты."
 
 #: params.def:529
-#, fuzzy, no-c-format
-#| msgid "Bound on number of iv uses in loop optimized in iv optimizations"
+#, no-c-format
 msgid "Bound on number of iv uses in loop optimized in iv optimizations."
-msgstr "Если число использований индуктивных переменных больше данного параметра, то их оптимизация не производится"
+msgstr "Если число использований индуктивных переменных больше данного параметра, то их оптимизация не производится."
 
 #: params.def:537
-#, fuzzy, no-c-format
-#| msgid "If number of candidates in the set is smaller, we always try to remove unused ivs during its optimization"
+#, no-c-format
 msgid "If number of candidates in the set is smaller, we always try to remove unused ivs during its optimization."
-msgstr "Если число кандидатов в множестве меньше этого значения, то при оптимизации множества всегда делается попытка удалить неиспользуемые независимые переменные"
+msgstr "Если число кандидатов в множестве меньше этого значения, то при оптимизации множества всегда делается попытка удалить неиспользуемые независимые переменные."
 
 #: params.def:542
-#, fuzzy, no-c-format
-#| msgid "The maximum number of peelings of a single loop"
+#, no-c-format
 msgid "Average number of iterations of a loop."
-msgstr "Максимальный коэффициент раскатки цикла"
+msgstr "Среднее число итераций цикла."
 
 #: params.def:547
-#, fuzzy, no-c-format
-#| msgid "Maximum number of active local stores in RTL dead store elimination"
+#, no-c-format
 msgid "Maximum size (in bytes) of objects tracked bytewise by dead store elimination."
-msgstr "Максимальное число активных локальных записей при исключении мертвых записей на RTL-представлении"
+msgstr "Максимальный размер (в байтах) объектов, отслеживаемых побайтно, при исключении мертвых записей в память."
 
 #: params.def:552
-#, fuzzy, no-c-format
-#| msgid "Bound on size of expressions used in the scalar evolutions analyzer"
+#, no-c-format
 msgid "Bound on size of expressions used in the scalar evolutions analyzer."
-msgstr "Верхняя граница размера выражений при анализе эволюции скалярных значений в циклах"
+msgstr "Верхняя граница размера выражений при анализе эволюции скалярных значений в циклах."
 
 #: params.def:557
-#, fuzzy, no-c-format
-#| msgid "Bound on the complexity of the expressions in the scalar evolutions analyzer"
+#, no-c-format
 msgid "Bound on the complexity of the expressions in the scalar evolutions analyzer."
-msgstr "Верхняя граница сложности выражений при анализе эволюции скалярных значений в циклах"
+msgstr "Верхняя граница сложности выражений при анализе эволюции скалярных значений в циклах."
 
 #: params.def:562
 #, no-c-format
 msgid "Maximum number of arguments in a PHI supported by TREE if-conversion unless the loop is marked with simd pragma."
-msgstr ""
+msgstr "Максимальное число аргументов PHI, поддерживаемое if-конверсией на древовидном представлении, если цикл не помечен прагмой simd."
 
 #: params.def:568
-#, fuzzy, no-c-format
-#| msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alignment check"
+#, no-c-format
 msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alignment check."
-msgstr "Максимальное число проверок времени выполнения, добавляемых в код при векторизации циклов для проверки выравнивания"
+msgstr "Максимальное число проверок времени выполнения, добавляемых в код при векторизации циклов для проверки выравнивания."
 
 #: params.def:573
-#, fuzzy, no-c-format
-#| msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alias check"
+#, no-c-format
 msgid "Bound on number of runtime checks inserted by the vectorizer's loop versioning for alias check."
-msgstr "Максимальное число проверок времени выполнения, добавляемых в код при векторизации циклов для проверки алиасов"
+msgstr "Максимальное число проверок времени выполнения, добавляемых в код при векторизации циклов для проверки алиасов."
 
 #: params.def:578
-#, fuzzy, no-c-format
-#| msgid "Maximum number of namespaces to search for alternatives when name lookup fails"
+#, no-c-format
 msgid "Maximum number of loop peels to enhance alignment of data references in a loop."
-msgstr "Максимальное число пространств имен для поиска альтернатив при неуспешном поиске имени"
+msgstr "Максимальное число начальных итераций цикла, которые могут быть раскатаны для выравнивания данных в цикле."
 
 #: params.def:583
-#, fuzzy, no-c-format
-#| msgid "The maximum memory locations recorded by cselib"
+#, no-c-format
 msgid "The maximum memory locations recorded by cselib."
-msgstr "Максимальное число позиций в памяти, записываемых cselib"
+msgstr "Максимальное число позиций в памяти, записываемых cselib."
 
 #: params.def:596
-#, fuzzy, no-c-format
-#| msgid "Minimum heap expansion to trigger garbage collection, as a percentage of the total size of the heap"
+#, no-c-format
 msgid "Minimum heap expansion to trigger garbage collection, as a percentage of the total size of the heap."
-msgstr "Минимальный объем кучи, при котором включается сбора мусора, в процентах от общего размера памяти, выделенного под кучу"
+msgstr "Минимальный объем кучи, при котором включается сбора мусора, в процентах от общего размера памяти, выделенного под кучу."
 
 #: params.def:601
-#, fuzzy, no-c-format
-#| msgid "Minimum heap size before we start collecting garbage, in kilobytes"
+#, no-c-format
 msgid "Minimum heap size before we start collecting garbage, in kilobytes."
-msgstr "Минимальный размер кучи в килобайтах, при котором включается сбор мусора, в килобайтах"
+msgstr "Минимальный размер кучи в килобайтах, при котором включается сбор мусора, в килобайтах."
 
 #: params.def:609
-#, fuzzy, no-c-format
-#| msgid "The maximum number of instructions to search backward when looking for equivalent reload"
+#, no-c-format
 msgid "The maximum number of instructions to search backward when looking for equivalent reload."
-msgstr "Максимальное число инструкций для обратного просмотра при поиске эквивалентной загрузки в регистр"
+msgstr "Максимальное число инструкций для обратного просмотра при поиске эквивалентной загрузки в регистр."
 
 #: params.def:614
-#, fuzzy, no-c-format
-#| msgid "Target block's relative execution frequency (as a percentage) required to sink a statement"
+#, no-c-format
 msgid "Target block's relative execution frequency (as a percentage) required to sink a statement."
-msgstr "Относительная частота выполнения целевого блока (в процентах), необходимая для погружения инструкции"
+msgstr "Относительная частота выполнения целевого блока (в процентах), необходимая для погружения инструкции."
 
 #: params.def:619 params.def:629
-#, fuzzy, no-c-format
-#| msgid "The maximum number of blocks in a region to be considered for interblock scheduling"
+#, no-c-format
 msgid "The maximum number of blocks in a region to be considered for interblock scheduling."
-msgstr "Максимальное число блоков в отрезке для междублочночного планирования"
+msgstr "Максимальное число блоков в отрезке для междублочночного планирования."
 
 #: params.def:624 params.def:634
-#, fuzzy, no-c-format
-#| msgid "The maximum number of insns in a region to be considered for interblock scheduling"
+#, no-c-format
 msgid "The maximum number of insns in a region to be considered for interblock scheduling."
-msgstr "Максимальное число инструкций в отрезке для межблочного планирования"
+msgstr "Максимальное число инструкций в отрезке для межблочного планирования."
 
 #: params.def:639
-#, fuzzy, no-c-format
-#| msgid "The minimum probability of reaching a source block for interblock speculative scheduling"
+#, no-c-format
 msgid "The minimum probability of reaching a source block for interblock speculative scheduling."
-msgstr "Минимальная вероятность достижения блока для спекулятивного межблочного планирования"
+msgstr "Минимальная вероятность достижения блока для спекулятивного межблочного планирования."
 
 #: params.def:644
-#, fuzzy, no-c-format
-#| msgid "The maximum number of iterations through CFG to extend regions"
+#, no-c-format
 msgid "The maximum number of iterations through CFG to extend regions."
-msgstr "Максимальное число итераций по CFG для расширения регионов"
+msgstr "Максимальное число итераций по CFG для расширения регионов."
 
 #: params.def:649
-#, fuzzy, no-c-format
-#| msgid "The maximum conflict delay for an insn to be considered for speculative motion"
+#, no-c-format
 msgid "The maximum conflict delay for an insn to be considered for speculative motion."
-msgstr "Максимальная отсрочка конфликта для команды, рассматриваемой как кандидат для спекулятивного перемещения"
+msgstr "Максимальная отсрочка конфликта для команды, рассматриваемой как кандидат для спекулятивного перемещения."
 
 #: params.def:654
 #, no-c-format
@@ -2315,125 +2215,107 @@
 #: params.def:659
 #, no-c-format
 msgid "The minimum probability an edge must have for the scheduler to save its state across it."
-msgstr ""
+msgstr "Минимальная вероятность, которую должно иметь ребро, чтобы планировщик сохранил свое состояние после прохождения ребра."
 
 #: params.def:664
-#, fuzzy, no-c-format
-#| msgid "The maximum size of the lookahead window of selective scheduling"
+#, no-c-format
 msgid "The maximum size of the lookahead window of selective scheduling."
-msgstr "Максимальный размер окна при селективном планировании"
+msgstr "Максимальный размер окна при селективном планировании."
 
 #: params.def:669
-#, fuzzy, no-c-format
-#| msgid "Maximum number of times that an insn could be scheduled"
+#, no-c-format
 msgid "Maximum number of times that an insn could be scheduled."
-msgstr "Максимальное возможное количество планируемых выполнений команды"
+msgstr "Максимальное возможное количество планируемых выполнений команды."
 
 #: params.def:674
-#, fuzzy, no-c-format
-#| msgid "Maximum number of instructions in the ready list that are considered eligible for renaming"
+#, no-c-format
 msgid "Maximum number of instructions in the ready list that are considered eligible for renaming."
-msgstr "Максимальное число команд в списке готовых, которые могут рассматриваться как кандидаты на переименование"
+msgstr "Максимальное число команд в списке готовых, которые могут рассматриваться как кандидаты на переименование."
 
 #: params.def:679
-#, fuzzy, no-c-format
-#| msgid "Minimal distance between possibly conflicting store and load"
+#, no-c-format
 msgid "Minimal distance between possibly conflicting store and load."
-msgstr "Минимальная дистанция между возможно конфликтующими записью и чтением"
+msgstr "Минимальная дистанция между возможно конфликтующими записью и чтением."
 
 #: params.def:684
 #, no-c-format
 msgid "Hardware autoprefetcher scheduler model control flag.  Number of lookahead cycles the model looks into; at '0' only enable instruction sorting heuristic.  Disabled by default."
-msgstr ""
+msgstr "Флаг модели планирования для аппаратной предвыборки.  Количество циклов, на которые ведётся планирование; при 0 используется только эвристика сортировки инструкций.  По умолчанию эта опция отключена."
 
 #: params.def:689
-#, fuzzy, no-c-format
-#| msgid "The maximum number of RTL nodes that can be recorded as combiner's last value"
+#, no-c-format
 msgid "The maximum number of RTL nodes that can be recorded as combiner's last value."
-msgstr "Максимальный размер выражения (число RTL-узлов), которое может быть записано как последнее известное значение псевдорегистра"
+msgstr "Максимальный размер выражения (число RTL-узлов), которое может быть записано как последнее известное значение псевдорегистра."
 
 #: params.def:694
-#, fuzzy, no-c-format
-#| msgid "The maximum number of incoming edges to consider for crossjumping"
+#, no-c-format
 msgid "The maximum number of insns combine tries to combine."
-msgstr "Максимальное число входящих дуг, рассматриваемых при перекрестных переходах"
+msgstr "Максимальное число инструкций, для которых на проходе combine рассматривается возможность комбинирования."
 
 #: params.def:703
-#, fuzzy, no-c-format
-#| msgid "The upper bound for sharing integer constants"
+#, no-c-format
 msgid "The upper bound for sharing integer constants."
-msgstr "Максимальное число небольших целочисленных констант, для которых в компиляторе будут использованы разделяемые структуры"
+msgstr "Максимальное число небольших целочисленных констант, для которых в компиляторе будут использованы разделяемые структуры."
 
 #: params.def:708
-#, fuzzy, no-c-format
-#| msgid "The lower bound for a buffer to be considered for stack smashing protection"
+#, no-c-format
 msgid "The lower bound for a buffer to be considered for stack smashing protection."
-msgstr "Ограничение снизу на буфер для защиты от разрушения стека"
+msgstr "Ограничение снизу на буфер для защиты от разрушения стека."
 
 #: params.def:713
 #, no-c-format
 msgid "The minimum size of variables taking part in stack slot sharing when not optimizing."
-msgstr ""
+msgstr "Минимальный размер переменных, которые могут разделять позицию в стеке в отсутствие оптимизации."
 
 #: params.def:732
-#, fuzzy, no-c-format
-#| msgid "Maximum number of statements allowed in a block that needs to be duplicated when threading jumps"
+#, no-c-format
 msgid "Maximum number of statements allowed in a block that needs to be duplicated when threading jumps."
-msgstr "Максимальное число инструкций в блоке, который необходимо дублировать при протягивании переходов"
+msgstr "Максимальное число инструкций в блоке, который необходимо дублировать при протягивании переходов."
 
 #: params.def:741
-#, fuzzy, no-c-format
-#| msgid "Maximum number of fields in a structure before pointer analysis treats the structure as a single variable"
+#, no-c-format
 msgid "Maximum number of fields in a structure before pointer analysis treats the structure as a single variable."
-msgstr "Если число  полей в структуре больше данного параметра, то при анализе указателей вся структура рассматривается как одна переменная"
+msgstr "Если число  полей в структуре больше данного параметра, то при анализе указателей вся структура рассматривается как одна переменная."
 
 #: params.def:746
-#, fuzzy, no-c-format
-#| msgid "The maximum number of instructions ready to be issued to be considered by the scheduler during the first scheduling pass"
+#, no-c-format
 msgid "The maximum number of instructions ready to be issued to be considered by the scheduler during the first scheduling pass."
-msgstr "Максимальное число готовых к исполнению инструкций, рассматриваемых планировщиком на первом проходе планирования"
+msgstr "Максимальное число готовых к исполнению инструкций, рассматриваемых планировщиком на первом проходе планирования."
 
 #: params.def:752
-#, fuzzy, no-c-format
-#| msgid "Maximum number of active local stores in RTL dead store elimination"
+#, no-c-format
 msgid "Maximum number of active local stores in RTL dead store elimination."
-msgstr "Максимальное число активных локальных записей при исключении мертвых записей на RTL-представлении"
+msgstr "Максимальное число активных локальных записей при исключении мертвых записей на RTL-представлении."
 
 #: params.def:762
-#, fuzzy, no-c-format
-#| msgid "The number of insns executed before prefetch is completed"
+#, no-c-format
 msgid "The number of insns executed before prefetch is completed."
-msgstr "Число инструкций, выполненных до завершения предвыборки"
+msgstr "Число инструкций, выполненных до завершения предвыборки."
 
 #: params.def:769
-#, fuzzy, no-c-format
-#| msgid "The number of prefetches that can run at the same time"
+#, no-c-format
 msgid "The number of prefetches that can run at the same time."
-msgstr "Число предвыборок, которые могут выполняться одновременно"
+msgstr "Число предвыборок, которые могут выполняться одновременно."
 
 #: params.def:776
-#, fuzzy, no-c-format
-#| msgid "The size of L1 cache"
+#, no-c-format
 msgid "The size of L1 cache."
-msgstr "Размер кэша L1"
+msgstr "Размер кэша L1."
 
 #: params.def:783
-#, fuzzy, no-c-format
-#| msgid "The size of L1 cache line"
+#, no-c-format
 msgid "The size of L1 cache line."
-msgstr "Размер строки кэша L1"
+msgstr "Размер строки кэша L1."
 
 #: params.def:790
-#, fuzzy, no-c-format
-#| msgid "The size of L2 cache"
+#, no-c-format
 msgid "The size of L2 cache."
-msgstr "Размер кэша L2"
+msgstr "Размер кэша L2."
 
 #: params.def:797
-#, fuzzy, no-c-format
-#| msgid "The maximum number of instructions to consider to unroll in a loop on average"
+#, no-c-format
 msgid "The maximum number of stmts in loop nest for loop interchange."
-msgstr "Максимальное среднее число реально выполняемых инструкций в развернутом цикле"
+msgstr "Максимальное среднее число реально выполняемых инструкций в развёрнутом цикле"
 
 #: params.def:804
 #, no-c-format
@@ -2441,85 +2323,74 @@
 msgstr ""
 
 #: params.def:815
-#, fuzzy, no-c-format
-#| msgid "Whether to use canonical types"
+#, no-c-format
 msgid "Whether to use canonical types."
-msgstr "Использовать ли канонические типы"
+msgstr "Использовать ли канонические типы."
 
 #: params.def:820
-#, fuzzy, no-c-format
-#| msgid "Maximum length of partial antic set when performing tree pre optimization"
+#, no-c-format
 msgid "Maximum length of partial antic set when performing tree pre optimization."
-msgstr "Максимальная длина частичного antic-множества при выполнении предоптимизации древовидного представления"
+msgstr "Максимальная длина частичного antic-множества при выполнении предоптимизации древовидного представления."
 
 #: params.def:830
-#, fuzzy, no-c-format
-#| msgid "Maximum size of a SCC before SCCVN stops processing a function"
+#, no-c-format
 msgid "Maximum size of a SCC before SCCVN stops processing a function."
-msgstr "Максимальный размер SCC (сильносвязанной компоненты), при котором алгоритм перечисления значений SCCVN завершает обработку функции"
+msgstr "Максимальный размер SCC (сильносвязанной компоненты), при котором алгоритм перечисления значений SCCVN завершает обработку функции."
 
 #: params.def:841
 #, no-c-format
 msgid "Maximum number of disambiguations to perform per memory access."
-msgstr ""
+msgstr "Максимальное число разрешений неоднозначности при выполнении доступа к памяти."
 
 #: params.def:846
-#, fuzzy, no-c-format
-#| msgid "Max loops number for regional RA"
+#, no-c-format
 msgid "Max loops number for regional RA."
-msgstr "Максимальное число циклов для использования распределения регистров по регионам"
+msgstr "Максимальное число циклов для использования распределения регистров по регионам."
 
 #: params.def:851
-#, fuzzy, no-c-format
-#| msgid "Max size of conflict table in MB"
+#, no-c-format
 msgid "Max size of conflict table in MB."
-msgstr "Максимальный размер таблицы конфликтов в мегабайтах"
+msgstr "Максимальный размер таблицы конфликтов в мегабайтах."
 
 #: params.def:856
-#, fuzzy, no-c-format
-#| msgid "The number of registers in each class kept unused by loop invariant motion"
+#, no-c-format
 msgid "The number of registers in each class kept unused by loop invariant motion."
-msgstr "Число регистров в каждом классе, оставляемых неиспользуемыми при вынесении инвариантов цикла"
+msgstr "Число регистров в каждом классе, оставляемых неиспользуемыми при вынесении инвариантов цикла."
 
 #: params.def:861
 #, no-c-format
 msgid "The max number of reload pseudos which are considered during spilling a non-reload pseudo."
-msgstr ""
+msgstr "Максимальное число reload-псевдорегистров, рассматриваемых при спиллинге не-reload псевдорегистра"
 
 #: params.def:866
 #, no-c-format
 msgid "Minimal fall-through edge probability in percentage used to add BB to inheritance EBB in LRA."
-msgstr ""
+msgstr "Минимальная вероятность сквозного перехода в процентах, чтобы добавить блок к EBB наследования при локальном распределении регистров (LRA)"
 
 #: params.def:874
-#, fuzzy, no-c-format
-#| msgid "The maximum ratio between array size and switch branches for a switch conversion to take place"
+#, no-c-format
 msgid "The maximum ratio between array size and switch branches for a switch conversion to take place."
-msgstr "Максимальное отношение между размером массива и числом веток в переключателе, при котором будет выполнена трансформация переключателя в таблицу"
+msgstr "Максимальное отношение между размером массива и числом веток в переключателе, при котором будет выполнена трансформация переключателя в таблицу."
 
 #: params.def:882
-#, fuzzy, no-c-format
-#| msgid "size of tiles for loop blocking"
+#, no-c-format
 msgid "size of tiles for loop blocking."
-msgstr "размер полос для блочной трансформации циклов"
+msgstr "размер полос для блочной трансформации циклов."
 
 #: params.def:889
-#, fuzzy, no-c-format
-#| msgid "maximum number of parameters in a SCoP"
+#, no-c-format
 msgid "maximum number of parameters in a SCoP."
-msgstr "максимальное число параметров в SCoP"
+msgstr "максимальное число параметров в SCoP."
 
 #: params.def:896
-#, fuzzy, no-c-format
-#| msgid "maximum number of parameters in a SCoP"
+#, no-c-format
 msgid "maximum number of arrays per scop."
-msgstr "максимальное число параметров в SCoP"
+msgstr "максимальное число массивов на один scop."
 
 #: params.def:901
-#, fuzzy, no-c-format
-#| msgid "The maximum number of insns of an unswitched loop"
+#, no-c-format
 msgid "maximum number of isl operations, 0 means unlimited"
-msgstr "Максимальное число инструкций в разомкнутом (unswitched) цикле"
+msgstr "Максимальное число isl-операций, 0 означает отсутствие ограничений"
 
 #: params.def:907
 #, no-c-format
@@ -2527,375 +2398,339 @@
 msgstr ""
 
 #: params.def:913
-#, fuzzy, no-c-format
-#| msgid "Maximum number of datarefs in loop for building loop data dependencies"
+#, no-c-format
 msgid "Maximum number of datarefs in loop for building loop data dependencies."
-msgstr "максимальное число ссылок на данные для построения циклических зависимостей по данным"
+msgstr "максимальное число ссылок на данные для построения циклических зависимостей по данным."
 
 #: params.def:920
-#, fuzzy, no-c-format
-#| msgid "Max basic blocks number in loop for loop invariant motion"
+#, no-c-format
 msgid "Max basic blocks number in loop for loop invariant motion."
-msgstr "максимальное число базовых блоков в цикле для вынесения инвариантов цикла"
+msgstr "максимальное число базовых блоков в цикле для вынесения инвариантов цикла."
 
 #: params.def:928
 #, no-c-format
 msgid "use internal function id in profile lookup."
-msgstr ""
+msgstr "использовать внутренний идентификатор функции при поиске в профиле."
 
 #: params.def:936
 #, no-c-format
 msgid "track topn target addresses in indirect-call profile."
-msgstr ""
+msgstr "отслеживать N наиболее частых адресов в профиле косвенных вызовов."
 
 #: params.def:942
-#, fuzzy, no-c-format
-#| msgid "Maximum number of instructions in basic block to be considered for SLP vectorization"
+#, no-c-format
 msgid "Maximum number of instructions in basic block to be considered for SLP vectorization."
-msgstr "Максимальное число инструкций в базовом блоке для его векторизации"
+msgstr "Максимальное число инструкций в базовом блоке для его векторизации."
 
 #: params.def:947
-#, fuzzy, no-c-format
-#| msgid "Min. ratio of insns to prefetches to enable prefetching for a loop with an unknown trip count"
+#, no-c-format
 msgid "Min. ratio of insns to prefetches to enable prefetching for a loop with an unknown trip count."
-msgstr "Минимальное отношение числа инструкций к числу предвыборок для включения предвыборок в циклах с неизвестным числом итераций"
+msgstr "Мин. отношение числа инструкций к числу предвыборок для включения предвыборок в циклах с неизвестным числом итераций."
 
 #: params.def:953
-#, fuzzy, no-c-format
-#| msgid "Min. ratio of insns to mem ops to enable prefetching in a loop"
+#, no-c-format
 msgid "Min. ratio of insns to mem ops to enable prefetching in a loop."
-msgstr "Минимальное отношение числа инструкций к числу операций с памятью для включения предвыборок в цикле"
+msgstr "Мин. отношение числа инструкций к числу операций с памятью для включения предвыборок в цикле."
 
 #: params.def:960
-#, fuzzy, no-c-format
-#| msgid "Max. size of var tracking hash tables"
+#, no-c-format
 msgid "Max. size of var tracking hash tables."
-msgstr "Максимальный размер хеш-таблиц для отслеживания переменных"
+msgstr "Макс. размер хеш-таблиц для отслеживания переменных."
 
 #: params.def:968
-#, fuzzy, no-c-format
-#| msgid "Max. recursion depth for expanding var tracking expressions"
+#, no-c-format
 msgid "Max. recursion depth for expanding var tracking expressions."
-msgstr "Максимальная глубина рекурсии в раскрытии выражений при отслеживании переменных"
+msgstr "Макс. глубина рекурсии в раскрытии выражений при отслеживании переменных."
 
 #: params.def:976
 #, no-c-format
 msgid "Max. size of loc list for which reverse ops should be added."
-msgstr ""
+msgstr "Макс. размер списка позиций, для которых должны добавляться обратные операции."
 
 #: params.def:985
 #, no-c-format
 msgid "Max. count of debug markers to expand or inline."
-msgstr ""
+msgstr "Макс. count of debug markers to expand or inline."
 
 #: params.def:992
-#, fuzzy, no-c-format
-#| msgid "The minimum UID to be used for a nondebug insn"
+#, no-c-format
 msgid "The minimum UID to be used for a nondebug insn."
-msgstr "Минимальный идентификатор (UID), используемый для неотладочных инструкций"
+msgstr "Минимальный идентификатор (UID), используемый для неотладочных инструкций."
 
 #: params.def:997
-#, fuzzy, no-c-format
-#| msgid "Maximum allowed growth of size of new parameters ipa-sra replaces a pointer to an aggregate with"
+#, no-c-format
 msgid "Maximum allowed growth of number and total size of new parameters that ipa-sra replaces a pointer to an aggregate with."
-msgstr "Максимальный допустимый размер новых параметров, при котором выполняется замена указателя на агрегат при -ftree-sra"
+msgstr "Максимальный допустимый размер новых параметров, при котором выполняется замена указателя на агрегат при ipa-sra."
 
 #: params.def:1003
-#, fuzzy, no-c-format
-#| msgid "Size in bytes after which thread-local aggregates should be instrumented with the logging functions instead of save/restore pairs"
+#, no-c-format
 msgid "Size in bytes after which thread-local aggregates should be instrumented with the logging functions instead of save/restore pairs."
-msgstr "Размер в байтах при превышении которого локальные для потоков агрегаты будут инструментированы функциями журналирования вместо команд сохранения/восстановления"
+msgstr "Размер в байтах, при превышении которого локальные для потоков агрегаты будут инструментированы функциями журналирования вместо команд сохранения/восстановления."
 
 #: params.def:1010
 #, no-c-format
 msgid "Maximum size, in storage units, of an aggregate which should be considered for scalarization when compiling for speed."
-msgstr ""
+msgstr "Максимальный размер агрегатных объектов (в единицах памяти), для которых при оптимизации по скорости может выполняться скаляризация."
 
 #: params.def:1016
 #, no-c-format
 msgid "Maximum size, in storage units, of an aggregate which should be considered for scalarization when compiling for size."
-msgstr ""
+msgstr "Максимальный размер агрегатных объектов (в единицах памяти), для которых при оптимизации по размеру может выполняться скаляризация."
 
 #: params.def:1022
-#, fuzzy, no-c-format
-#| msgid "Maximum size of a list of values associated with each parameter for interprocedural constant propagation"
+#, no-c-format
 msgid "Maximum size of a list of values associated with each parameter for interprocedural constant propagation."
-msgstr "Максимальный размер списка значений, ассоциированных с каждым параметром, при межпроцедурном распространении констант"
+msgstr "Максимальный размер списка значений, ассоциированных с каждым параметром, при межпроцедурном распространении констант."
 
 #: params.def:1028
-#, fuzzy, no-c-format
-#| msgid "Threshold ipa-cp opportunity evaluation that is still considered beneficial to clone."
+#, no-c-format
 msgid "Threshold ipa-cp opportunity evaluation that is still considered beneficial to clone.."
-msgstr "Пороговое значение оценки целесообразности клонирования при выполнении межпроцедурного распространения констант"
+msgstr "Пороговое значение оценки целесообразности клонирования при выполнении межпроцедурного распространения констант."
 
 #: params.def:1034
 #, no-c-format
 msgid "Percentage penalty the recursive functions will receive when they are evaluated for cloning.."
-msgstr ""
+msgstr "Штрафная наценка в процентах для рекурсивных функций при их оценке для клонирования."
 
 #: params.def:1040
 #, no-c-format
 msgid "Percentage penalty functions containing a single call to another function will receive when they are evaluated for cloning.."
-msgstr ""
+msgstr "Штрафная наценка в процентах для функций с единственным вызовом другой функции при их оценке для клонирования."
 
 #: params.def:1046
 #, no-c-format
 msgid "Maximum number of aggregate content items for a parameter in jump functions and lattices."
-msgstr ""
+msgstr "Максимальное число элементов совокупного содержимого для параметра в функциях перехода и решетках."
 
 #: params.def:1052
 #, no-c-format
 msgid "Compile-time bonus IPA-CP assigns to candidates which make loop bounds or strides known.."
-msgstr ""
+msgstr "Бонус времени компиляции, назначаемый IPA-CP тем кандидатам, которые позволяют определить границы или шаг цикла."
 
 #: params.def:1058
 #, no-c-format
 msgid "Compile-time bonus IPA-CP assigns to candidates which make an array index known.."
-msgstr ""
+msgstr "Бонус времени компиляции, назначаемый IPA-CP тем кандидатам, которые позволяют определить индекс массива."
 
 #: params.def:1064
 #, no-c-format
 msgid "Maximum number of statements that will be visited by IPA formal parameter analysis based on alias analysis in any given function."
-msgstr ""
+msgstr "Максимальное число операторов, исследуемых IPA при анализе формальных параметров на основе анализа алиасов в данной функции."
 
 #: params.def:1072
-#, fuzzy, no-c-format
-#| msgid "Number of partitions the program should be split to"
+#, no-c-format
 msgid "Number of partitions the program should be split to."
-msgstr "Число партиций для разбиения программы"
+msgstr "Число партиций для разбиения программы."
 
 #: params.def:1077
-#, fuzzy, no-c-format
-#| msgid "Minimal size of a partition for LTO (in estimated instructions)"
+#, no-c-format
 msgid "Minimal size of a partition for LTO (in estimated instructions)."
-msgstr "Минимальный размер (число инструкций в) партиции при разбиении программы во время LTO"
+msgstr "Минимальный размер (число инструкций в) партиции при разбиении программы во время LTO."
 
 #: params.def:1082
-#, fuzzy, no-c-format
-#| msgid "Minimal size of a partition for LTO (in estimated instructions)"
+#, no-c-format
 msgid "Maximal size of a partition for LTO (in estimated instructions)."
-msgstr "Минимальный размер (число инструкций в) партиции при разбиении программы во время LTO"
+msgstr "Минимальный размер (число инструкций в) партиции при разбиении программы во время LTO."
 
 #: params.def:1089
-#, fuzzy, no-c-format
-#| msgid "Maximum number of namespaces to search for alternatives when name lookup fails"
+#, no-c-format
 msgid "Maximum number of namespaces to search for alternatives when name lookup fails."
-msgstr "Максимальное число пространств имен для поиска альтернатив при неуспешном поиске имени"
+msgstr "Максимальное число пространств имен для поиска альтернатив при неуспешном поиске имени."
 
 #: params.def:1096
-#, fuzzy, no-c-format
-#| msgid "Maximum number of conditional store pairs that can be sunk"
+#, no-c-format
 msgid "Maximum number of conditional store pairs that can be sunk."
-msgstr "Число отложенных пар условной записи, которые могут быть \"утоплены\""
+msgstr "Число отложенных пар условной записи, которые могут быть \"утоплены\"."
 
 #: params.def:1104
-#, fuzzy, no-c-format
-#| msgid "The smallest number of different values for which it is best to use a jump-table instead of a tree of conditional branches, if 0, use the default for the machine"
+#, no-c-format
 msgid "The smallest number of different values for which it is best to use a jump-table instead of a tree of conditional branches, if 0, use the default for the machine."
-msgstr "Максимальное число различных значений, при котором выгоднее использовать таблицу переходов, чем дерево условных ветвлений; при 0 используется умолчание для данной машины"
+msgstr "Максимальное число различных значений, при котором выгоднее использовать таблицу переходов, чем дерево условных ветвлений; при 0 используется умолчание для данной машины."
 
 #: params.def:1112
-#, fuzzy, no-c-format
-#| msgid "Allow new data races on stores to be introduced"
+#, no-c-format
 msgid "Allow new data races on stores to be introduced."
-msgstr "Разрешить оптимизатору добавление новых гонок данных по записи данных"
+msgstr "Разрешить оптимизатору добавление новых гонок данных по записи данных."
 
 #: params.def:1118
-#, fuzzy, no-c-format
-#| msgid "Set the maximum number of instructions executed in parallel in reassociated tree. If 0, use the target dependent heuristic."
+#, no-c-format
 msgid "Set the maximum number of instructions executed in parallel in reassociated tree. If 0, use the target dependent heuristic.."
 msgstr "Максимальное число параллельно выполняемых инструкций в дереве при реассоциировании ассоциативных операций. При 0 использовать эвристику данной целевой платформы."
 
 #: params.def:1124
-#, fuzzy, no-c-format
-#| msgid "Maximum amount of similar bbs to compare a bb with"
+#, no-c-format
 msgid "Maximum amount of similar bbs to compare a bb with."
-msgstr "Максимальное число похожих базовых блоков, с которыми сравнивается данный блок"
+msgstr "Максимальное число похожих базовых блоков, с которыми сравнивается данный блок."
 
 #: params.def:1129
 #, no-c-format
 msgid "Allow the store merging pass to introduce unaligned stores if it is legal to do so."
-msgstr ""
+msgstr "Разрешить проходу слияния записей в память генерировать невыровненные записи, если это допустимо."
 
 #: params.def:1135
-#, fuzzy, no-c-format
-#| msgid "Maximum number of active local stores in RTL dead store elimination"
+#, no-c-format
 msgid "Maximum number of constant stores to merge in the store merging pass."
-msgstr "Максимальное число активных локальных записей при исключении мертвых записей на RTL-представлении"
+msgstr "Максимальное число активных локальных записей при исключении мертвых записей на RTL-представлении."
 
 #: params.def:1141
-#, fuzzy, no-c-format
-#| msgid "Maximum amount of iterations of the pass over a function"
+#, no-c-format
 msgid "Maximum amount of iterations of the pass over a function."
-msgstr "Максимальное число итераций обработки каждой функции"
+msgstr "Максимальное число итераций обработки каждой функции."
 
 #: params.def:1148
-#, fuzzy, no-c-format
-#| msgid "Maximum number of strings for which strlen optimization pass will track string lengths"
+#, no-c-format
 msgid "Maximum number of strings for which strlen optimization pass will track string lengths."
-msgstr "Максимальное число строк, для которых проход оптимизации strlen будет отслеживать длины"
+msgstr "Максимальное число строк, для которых проход оптимизации strlen будет отслеживать длины."
 
 #: params.def:1155
 #, no-c-format
 msgid "Which -fsched-pressure algorithm to apply."
-msgstr ""
+msgstr "Алгоритм для -fsched-pressure."
 
 #: params.def:1161
 #, no-c-format
 msgid "Maximum length of candidate scans for straight-line strength reduction."
-msgstr ""
+msgstr "Максимальная длина сканирования кандидатов для прямого понижения мощности операций."
 
 #: params.def:1167
-#, fuzzy, no-c-format
-#| msgid "Enable stack probing"
+#, no-c-format
 msgid "Enable asan stack protection."
-msgstr "Включить проверку стека зондированием"
+msgstr "Включить защиту стека средствами asan."
 
 #: params.def:1172
-#, fuzzy, no-c-format
-#| msgid "Enable all optional instructions"
+#, no-c-format
 msgid "Enable asan allocas/VLAs protection."
-msgstr "Включить все необязательные инструкции"
+msgstr "Включить защиту allocas/VLA средствами asan."
 
 #: params.def:1177
-#, fuzzy, no-c-format
-#| msgid "Enable all optional instructions"
+#, no-c-format
 msgid "Enable asan globals protection."
-msgstr "Включить все необязательные инструкции"
+msgstr "Включить защиту глобальных данных средствами asan."
 
 #: params.def:1182
-#, fuzzy, no-c-format
-#| msgid "Enable saturation instructions"
+#, no-c-format
 msgid "Enable asan store operations protection."
-msgstr "Включить инструкции насыщения"
+msgstr "Включить защиту от переполнения буферов при операциях записи средствами asan."
 
 #: params.def:1187
-#, fuzzy, no-c-format
-#| msgid "Enable all optional instructions"
+#, no-c-format
 msgid "Enable asan load operations protection."
-msgstr "Включить все необязательные инструкции"
+msgstr "Включить защиту от переполнения буферов при операциях чтения средствами asan."
 
 #: params.def:1192
-#, fuzzy, no-c-format
-#| msgid "Enable saturation instructions"
+#, no-c-format
 msgid "Enable asan builtin functions protection."
-msgstr "Включить инструкции насыщения"
+msgstr "Включить защиту от переполнения буферов для  средствами asan."
 
 #: params.def:1197
 #, no-c-format
 msgid "Enable asan detection of use-after-return bugs."
-msgstr ""
+msgstr "Включить выявление ошибок вида использование-после-выхода средствами asan"
 
 #: params.def:1202
 #, no-c-format
 msgid "Use callbacks instead of inline code if number of accesses in function becomes greater or equal to this number."
-msgstr ""
+msgstr "Использовать обратные вызовы (callbacks) вместо inline-подстановок, если число обращений к функции превышает указанное значение."
 
 #: params.def:1208
 #, no-c-format
 msgid "Use direct poisoning/unpoisoning instructions for variables smaller or equal to this number."
-msgstr ""
+msgstr "Использовать явно инструкции poison/unpoison для теневой памяти для переменных, размер которых не превышает указанного."
 
 #: params.def:1214
-#, fuzzy, no-c-format
-#| msgid "Maximum number of namespaces to search for alternatives when name lookup fails"
+#, no-c-format
 msgid "Maximum number of nested calls to search for control dependencies during uninitialized variable analysis."
-msgstr "Максимальное число пространств имен для поиска альтернатив при неуспешном поиске имени"
+msgstr "Максимальное вложенных вызовов для поиска зависимостей по управлению при анализе неинизиализированных имён."
 
 #: params.def:1220
 #, no-c-format
 msgid "Maximum number of statements to be included into a single static constructor generated by Pointer Bounds Checker."
-msgstr ""
+msgstr "Максимальное число операторов, включаемых в один статический конструктор, генерируемый при проверке выхода за границы по указателям."
 
 #: params.def:1226
 #, no-c-format
 msgid "Scale factor to apply to the number of statements in a threading path when comparing to the number of (scaled) blocks."
-msgstr ""
+msgstr "Масштабный множитель для применения к числу операторов в потоковом маршруте при сравнении с числом (масштабированных) блоков."
 
 #: params.def:1231
 #, no-c-format
 msgid "Maximum number of arguments a PHI may have before the FSM threader will not try to thread through its block."
-msgstr ""
+msgstr "Максимальное число аргументов PHI, при котором FSM не будет пытаться протягивать переходы через соответствующий блок."
 
 #: params.def:1236
 #, no-c-format
 msgid "Scale factor to apply to the number of blocks in a threading path when comparing to the number of (scaled) statements."
-msgstr ""
+msgstr "Масштабирующий множитель, применяемый к числу блоков на проходе протягивания переходов при сравнении с (масштабированным) числом операторов."
 
 #: params.def:1241
 #, no-c-format
 msgid "Maximum number of instructions to copy when duplicating blocks on a finite state automaton jump thread path."
-msgstr ""
+msgstr "Максимальное число копируемых инструкций при дублировании блоков конечного автомата на проходе протягивания переходов."
 
 #: params.def:1246
-#, fuzzy, no-c-format
-#| msgid "maximum number of basic blocks per function to be analyzed by Graphite"
+#, no-c-format
 msgid "Maximum number of basic blocks on a finite state automaton jump thread path."
-msgstr "максимальное число базовых блоков в функции, при котором применяются средства Graphite"
+msgstr "Максимальное число базовых блоков в конечном автомате, используемом на проходе протягивания переходов."
 
 #: params.def:1251
-#, fuzzy, no-c-format
-#| msgid "Maximum number of nops to insert for a hint (Default 2)"
+#, no-c-format
 msgid "Maximum number of new jump thread paths to create for a finite state automaton."
-msgstr "Максимальное число nops при вставке для подсказки (По умолчанию 2)"
+msgstr "Максимальное число новых путей протягивания переходов, которые могут быть созданы в конечном автомате."
 
 #: params.def:1256
 #, no-c-format
 msgid "Chunk size of omp schedule for loops parallelized by parloops."
-msgstr ""
+msgstr "Размер чанка в OMP-расписании для автоматически распараллеливаемых циклов."
 
 #: params.def:1261
 #, no-c-format
 msgid "Schedule type of omp schedule for loops parallelized by parloops (static, dynamic, guided, auto, runtime)."
-msgstr ""
+msgstr "Тип расписания OMP для автоматически распараллеливаемых циклов (static, dynamic, guided, auto, runtime)."
 
 #: params.def:1268
-#, fuzzy, no-c-format
-#| msgid "The maximum number of instructions to consider to unroll in a loop"
+#, no-c-format
 msgid "Minimum number of iterations per thread of an innermost parallelized loop."
-msgstr "Максимальное число инструкций в развернутом цикле"
+msgstr "Минимальное число инструкций итераций на поток в развёрнутом цикле"
 
 #: params.def:1274
 #, no-c-format
 msgid "Maximum recursion depth allowed when querying a property of an SSA name."
-msgstr ""
+msgstr "Максимальная глубина рекурсии, допустимая при запросах свойств SSA-имен."
 
 #: params.def:1280
-#, fuzzy, no-c-format
-#| msgid "Maximum number of instructions in basic block to be considered for SLP vectorization"
+#, no-c-format
 msgid "Maximum number of insns in a basic block to consider for RTL if-conversion."
-msgstr "Максимальное число инструкций в базовом блоке для его векторизации"
+msgstr "Максимальное число инструкций в базовом блоке, пригодном для if-конверсии."
 
 #: params.def:1286
 #, no-c-format
 msgid "Maximum permissible cost for the sequence that would be generated by the RTL if-conversion pass for a branch that is considered predictable."
-msgstr ""
+msgstr "Максимальная допустимая стоимость последовательности, генерируемой при if-конверсии для перехода, который считается предсказуемым."
 
 #: params.def:1293
 #, no-c-format
 msgid "Maximum permissible cost for the sequence that would be generated by the RTL if-conversion pass for a branch that is considered unpredictable."
-msgstr ""
+msgstr "Максимальная допустимая стоимость последовательности, генерируемой при if-конверсии для перехода, который считается непредсказуемым."
 
 #: params.def:1300
 #, no-c-format
 msgid "Level of hsa debug stores verbosity"
-msgstr ""
+msgstr "Уровень подробности отладочной информации HSA при записях в память"
 
 #: params.def:1305
 #, no-c-format
 msgid "Maximum number of may-defs visited when devirtualizing speculatively"
-msgstr ""
+msgstr "Максимальное число may-defs, просматриваемых при спекулятивной девиртуализации"
 
 #: params.def:1310
 #, no-c-format
 msgid "Maximum number of assertions to add along the default edge of a switch statement during VRP"
-msgstr ""
+msgstr "Максимальное число утверждений (assertions), добавляемых вдоль default-дуги оператора switch во время VPR"
 
 #: params.def:1316
-#, fuzzy, no-c-format
-#| msgid "Enable loop vectorization on trees"
+#, no-c-format
 msgid "Enable loop epilogue vectorization using smaller vector size."
-msgstr "Выполнить векторизацию циклов на древовидном представлении"
+msgstr "Выполнить векторизацию эпилогов циклов, используя меньший размер векторов."
 
 #: params.def:1321
 #, no-c-format
@@ -2908,10 +2743,9 @@
 msgstr ""
 
 #: params.def:1331
-#, fuzzy, no-c-format
-#| msgid "Maximum number of strings for which strlen optimization pass will track string lengths"
+#, no-c-format
 msgid "Maximum number of bits for which we avoid creating FMAs."
-msgstr "Максимальное число строк, для которых проход оптимизации strlen будет отслеживать длины"
+msgstr ""
 
 #: c-family/c-format.c:382
 msgid "format"
@@ -3182,71 +3016,64 @@
 msgstr "модификатор размера в формате strfmon"
 
 #. Handle deferred options from command-line.
-#: c-family/c-opts.c:1402 fortran/cpp.c:590
+#: c-family/c-opts.c:1417 fortran/cpp.c:590
 msgid "<command-line>"
 msgstr "<command-line>"
 
-#: config/aarch64/aarch64.c:6613
-#, fuzzy, c-format
-#| msgid "Unsupported operand for code '%c'"
+#: config/aarch64/aarch64.c:6629
+#, c-format
 msgid "unsupported operand for code '%c'"
-msgstr "Неподдерживаемый операнд для кода '%c'"
+msgstr ""
 
-#: config/aarch64/aarch64.c:6624 config/aarch64/aarch64.c:6640
-#: config/aarch64/aarch64.c:6652 config/aarch64/aarch64.c:6663
-#: config/aarch64/aarch64.c:6673 config/aarch64/aarch64.c:6694
-#: config/aarch64/aarch64.c:6764 config/aarch64/aarch64.c:6775
-#: config/aarch64/aarch64.c:6789 config/aarch64/aarch64.c:7011
-#: config/aarch64/aarch64.c:7029
-#, fuzzy, c-format
-#| msgid "invalid operand for code '%c'"
+#: config/aarch64/aarch64.c:6640 config/aarch64/aarch64.c:6656
+#: config/aarch64/aarch64.c:6668 config/aarch64/aarch64.c:6679
+#: config/aarch64/aarch64.c:6689 config/aarch64/aarch64.c:6710
+#: config/aarch64/aarch64.c:6780 config/aarch64/aarch64.c:6791
+#: config/aarch64/aarch64.c:6805 config/aarch64/aarch64.c:7027
+#: config/aarch64/aarch64.c:7045
+#, c-format
 msgid "invalid operand for '%%%c'"
-msgstr "недопустимый операнд для кода '%c'"
+msgstr "недопустимый операнд для кода '%%%c'"
 
-#: config/aarch64/aarch64.c:6709 config/aarch64/aarch64.c:6720
-#: config/aarch64/aarch64.c:6871 config/aarch64/aarch64.c:6882
-#, fuzzy, c-format
-#| msgid "invalid insn:"
+#: config/aarch64/aarch64.c:6725 config/aarch64/aarch64.c:6736
+#: config/aarch64/aarch64.c:6887 config/aarch64/aarch64.c:6898
+#, c-format
 msgid "invalid vector constant"
-msgstr "недопустимая инструкция:"
+msgstr ""
 
-#: config/aarch64/aarch64.c:6732 config/aarch64/aarch64.c:6744
-#: config/aarch64/aarch64.c:6755
+#: config/aarch64/aarch64.c:6748 config/aarch64/aarch64.c:6760
+#: config/aarch64/aarch64.c:6771
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
-msgstr ""
+msgstr "недопустимый операнд - плавающий или векторный регистр для кода '%%%c'"
 
-#: config/aarch64/aarch64.c:6823 config/arm/arm.c:22704
+#: config/aarch64/aarch64.c:6839 config/arm/arm.c:22704
 #, c-format
 msgid "missing operand"
 msgstr "отсутствует операнд"
 
-#: config/aarch64/aarch64.c:6908
-#, fuzzy, c-format
-#| msgid "invalid insn:"
+#: config/aarch64/aarch64.c:6924
+#, c-format
 msgid "invalid constant"
-msgstr "недопустимая инструкция:"
+msgstr "недопустимая константа"
 
-#: config/aarch64/aarch64.c:6911
-#, fuzzy, c-format
-#| msgid "invalid %%d operand"
+#: config/aarch64/aarch64.c:6927
+#, c-format
 msgid "invalid operand"
-msgstr "некорректный операнд для %%d"
+msgstr "некорректный операнд"
 
-#: config/aarch64/aarch64.c:7040 config/aarch64/aarch64.c:7045
-#, fuzzy, c-format
-#| msgid "invalid operand code '%c'"
+#: config/aarch64/aarch64.c:7056 config/aarch64/aarch64.c:7061
+#, c-format
 msgid "invalid operand prefix '%%%c'"
-msgstr "некорректный код операнда '%c'"
+msgstr "некорректный префикс операнда '%%%c'"
 
-#: config/aarch64/aarch64.c:7062
-#, fuzzy, c-format
-#| msgid "invalid addressing mode"
+#: config/aarch64/aarch64.c:7078
+#, c-format
 msgid "invalid address mode"
-msgstr "некорректный режим адресации"
+msgstr ""
 
-#: config/alpha/alpha.c:5125 config/i386/i386.c:18558
-#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21798
+#: config/alpha/alpha.c:5125 config/i386/i386.c:18561
+#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21875
 #: config/sparc/sparc.c:9290
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
@@ -3263,7 +3090,7 @@
 msgstr "некорректное значение %%r"
 
 #: config/alpha/alpha.c:5223 config/ia64/ia64.c:5534
-#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21506
+#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21583
 #: config/xtensa/xtensa.c:2429
 #, c-format
 msgid "invalid %%R value"
@@ -3270,13 +3097,13 @@
 msgstr "некорректное значение %%R"
 
 #: config/alpha/alpha.c:5229 config/powerpcspe/powerpcspe.c:23933
-#: config/rs6000/rs6000.c:21426 config/xtensa/xtensa.c:2396
+#: config/rs6000/rs6000.c:21503 config/xtensa/xtensa.c:2396
 #, c-format
 msgid "invalid %%N value"
 msgstr "некорректное значение %%N"
 
 #: config/alpha/alpha.c:5237 config/powerpcspe/powerpcspe.c:23961
-#: config/rs6000/rs6000.c:21454
+#: config/rs6000/rs6000.c:21531
 #, c-format
 msgid "invalid %%P value"
 msgstr "некорректное значение %%P"
@@ -3307,7 +3134,7 @@
 msgstr "некорректное значение %%U"
 
 #: config/alpha/alpha.c:5323 config/powerpcspe/powerpcspe.c:24021
-#: config/rs6000/rs6000.c:21514
+#: config/rs6000/rs6000.c:21591
 #, c-format
 msgid "invalid %%s value"
 msgstr "некорректное значение %%s"
@@ -3318,7 +3145,7 @@
 msgstr "некорректное значение %%C"
 
 #: config/alpha/alpha.c:5371 config/powerpcspe/powerpcspe.c:23797
-#: config/rs6000/rs6000.c:21290
+#: config/rs6000/rs6000.c:21367
 #, c-format
 msgid "invalid %%E value"
 msgstr "некорректное значение %%E"
@@ -3329,7 +3156,7 @@
 msgstr "некорректное unspec-перемещение"
 
 #: config/alpha/alpha.c:5405 config/cr16/cr16.c:1569
-#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21803
+#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21880
 #: config/spu/spu.c:1458
 #, c-format
 msgid "invalid %%xn code"
@@ -3336,86 +3163,79 @@
 msgstr "некорректный код %%xn"
 
 #: config/alpha/alpha.c:5511
-#, fuzzy, c-format
-#| msgid "invalid address"
+#, c-format
 msgid "invalid operand address"
-msgstr "некорректный адрес"
+msgstr "некорректный адрес операнда"
 
-#: config/arc/arc.c:3810
-#, fuzzy, c-format
-#| msgid "invalid operand to %%s code"
+#: config/arc/arc.c:3808
+#, c-format
 msgid "invalid operand to %%Z code"
-msgstr "некорректный операнд для кода %%s"
+msgstr "некорректный операнд для кода %%Z"
 
-#: config/arc/arc.c:3818
-#, fuzzy, c-format
-#| msgid "invalid operand to %%s code"
+#: config/arc/arc.c:3816
+#, c-format
 msgid "invalid operand to %%z code"
-msgstr "некорректный операнд для кода %%s"
+msgstr "некорректный операнд для кода %%z"
 
-#: config/arc/arc.c:3826
-#, fuzzy, c-format
-#| msgid "invalid operand to %%s code"
+#: config/arc/arc.c:3824
+#, c-format
 msgid "invalid operands to %%c code"
-msgstr "некорректный операнд для кода %%s"
+msgstr "некорректный операнд для кода %%c"
 
-#: config/arc/arc.c:3834
-#, fuzzy, c-format
-#| msgid "invalid operand to %%s code"
+#: config/arc/arc.c:3832
+#, c-format
 msgid "invalid operand to %%M code"
-msgstr "некорректный операнд для кода %%s"
+msgstr "некорректный операнд для кода %%M"
 
-#: config/arc/arc.c:3842 config/m32r/m32r.c:2100
+#: config/arc/arc.c:3840 config/m32r/m32r.c:2100
 #, c-format
 msgid "invalid operand to %%p code"
 msgstr "некорректный операнд для кода %%p"
 
-#: config/arc/arc.c:3853 config/m32r/m32r.c:2093
+#: config/arc/arc.c:3851 config/m32r/m32r.c:2093
 #, c-format
 msgid "invalid operand to %%s code"
 msgstr "некорректный операнд для кода %%s"
 
-#: config/arc/arc.c:4001 config/m32r/m32r.c:2126
+#: config/arc/arc.c:3999 config/m32r/m32r.c:2126
 #, c-format
 msgid "invalid operand to %%R code"
 msgstr "некорректный операнд для кода %%R"
 
-#: config/arc/arc.c:4077 config/m32r/m32r.c:2149
+#: config/arc/arc.c:4075 config/m32r/m32r.c:2149
 #, c-format
 msgid "invalid operand to %%H/%%L code"
 msgstr "некорректный операнд для кода %%H/%%L"
 
-#: config/arc/arc.c:4145 config/m32r/m32r.c:2220
+#: config/arc/arc.c:4143 config/m32r/m32r.c:2220
 #, c-format
 msgid "invalid operand to %%U code"
 msgstr "некорректный операнд для кода %%U"
 
-#: config/arc/arc.c:4157
+#: config/arc/arc.c:4155
 #, c-format
 msgid "invalid operand to %%V code"
 msgstr "некорректный операнд для кода %%V"
 
-#: config/arc/arc.c:4214
-#, fuzzy, c-format
-#| msgid "invalid operand to %%s code"
+#: config/arc/arc.c:4212
+#, c-format
 msgid "invalid operand to %%O code"
-msgstr "некорректный операнд для кода %%s"
+msgstr "некорректный операнд для кода %%O"
 
 #. Unknown flag.
 #. Undocumented flag.
-#: config/arc/arc.c:4240 config/epiphany/epiphany.c:1305
-#: config/m32r/m32r.c:2247 config/nds32/nds32.c:3079 config/sparc/sparc.c:9569
+#: config/arc/arc.c:4238 config/epiphany/epiphany.c:1305
+#: config/m32r/m32r.c:2247 config/nds32/nds32.c:3080 config/sparc/sparc.c:9569
 #, c-format
 msgid "invalid operand output code"
 msgstr "неверный код выходного операнда"
 
-#: config/arc/arc.c:5869
-#, fuzzy, c-format
-#| msgid "invalid UNSPEC as operand"
+#: config/arc/arc.c:5860
+#, c-format
 msgid "invalid UNSPEC as operand: %d"
-msgstr "некорректный операнд UNSPEC"
+msgstr "некорректный операнд UNSPEC: %d"
 
-#: config/arc/arc.c:6158 config/cris/cris.c:2568
+#: config/arc/arc.c:6149 config/cris/cris.c:2568
 msgid "unrecognized supposed constant"
 msgstr "неопознанная константа"
 
@@ -3423,7 +3243,7 @@
 #: config/arm/arm.c:19186 config/arm/arm.c:19195
 #, c-format
 msgid "invalid shift operand"
-msgstr "некорректный операнд сдвига"
+msgstr "некорректный оператор сдвига"
 
 #: config/arm/arm.c:22035 config/arm/arm.c:22053
 #, c-format
@@ -3450,7 +3270,7 @@
 #: config/arm/arm.c:22685 config/arm/arm.c:22692 config/bfin/bfin.c:1441
 #: config/bfin/bfin.c:1448 config/bfin/bfin.c:1455 config/bfin/bfin.c:1462
 #: config/bfin/bfin.c:1471 config/bfin/bfin.c:1478 config/bfin/bfin.c:1485
-#: config/bfin/bfin.c:1492 config/nds32/nds32.c:3098
+#: config/bfin/bfin.c:1492 config/nds32/nds32.c:3099
 #, c-format
 msgid "invalid operand for code '%c'"
 msgstr "недопустимый операнд для кода '%c'"
@@ -3462,10 +3282,9 @@
 
 #. Former Maverick support, removed after GCC-4.7.
 #: config/arm/arm.c:22399
-#, fuzzy, c-format
-#| msgid "Unsupported operand for code '%c'"
+#, c-format
 msgid "obsolete Maverick format code '%c'"
-msgstr "Неподдерживаемый операнд для кода '%c'"
+msgstr "устаревший код формата Maverick '%c'"
 
 #: config/avr/avr.c:2655
 #, c-format
@@ -3494,16 +3313,16 @@
 
 #: config/avr/avr.c:2939
 msgid "internal compiler error.  Bad address:"
-msgstr "внутренняя ошибка компилятора: некорректный адрес:"
+msgstr "внутренняя ошибка компилятора.  Некорректный адрес:"
 
 #: config/avr/avr.c:2972
 #, c-format
 msgid "Unsupported code '%c' for fixed-point:"
-msgstr ""
+msgstr "Неподдерживаемый код '%c' для значения с фикс. точкой:"
 
 #: config/avr/avr.c:2980
 msgid "internal compiler error.  Unknown mode:"
-msgstr "внутренняя ошибка компилятора: неизвестный режим:"
+msgstr "внутренняя ошибка компилятора.  Неизвестный режим:"
 
 #: config/avr/avr.c:4022 config/avr/avr.c:4966 config/avr/avr.c:5413
 msgid "invalid insn:"
@@ -3528,51 +3347,41 @@
 
 #: config/avr/avr.c:6387 config/avr/avr.c:6868 config/avr/avr.c:7283
 msgid "internal compiler error.  Incorrect shift:"
-msgstr "Внутренняя ошибка компилятора: некорректный сдвиг:"
+msgstr "внутренняя ошибка компилятора.  Некорректное смещение:"
 
 #: config/avr/avr.c:8689
-#, fuzzy
-#| msgid "invalid types in fixed-point conversion"
 msgid "unsupported fixed-point conversion"
-msgstr "неверные типы в преобразовании с фиксированной точкой"
+msgstr "неподдерживаемое преобразование с фиксированной точкой"
 
 #: config/avr/avr.c:10046
-#, fuzzy
-#| msgid "Loop variable"
 msgid "variable"
-msgstr "Переменная цикла"
+msgstr "переменная"
 
 #: config/avr/avr.c:10051
-#, fuzzy
-#| msgid "redefinition of parameter %q+D"
 msgid "function parameter"
-msgstr "повторное определение параметра %q+D"
+msgstr "параметр функции"
 
 #: config/avr/avr.c:10056
-#, fuzzy
-#| msgid "struct defined here"
 msgid "structure field"
-msgstr "структура определена здесь"
+msgstr "поле структуры"
 
 #: config/avr/avr.c:10062
-#, fuzzy
-#| msgid "creating array of functions"
 msgid "return type of function"
-msgstr "создание массива функций"
+msgstr "тип результата функции"
 
 #: config/avr/avr.c:10067
-#, fuzzy
-#| msgid "null pointer"
 msgid "pointer"
-msgstr "нулевой указатель"
+msgstr "указатель"
 
 #: config/avr/driver-avr.c:50
-#, fuzzy, c-format
-#| msgid "unknown spec function %qs"
+#, c-format
 msgid ""
 "Running spec function '%s' with %d args\n"
 "\n"
-msgstr "неизвестная функция %qs в спецификации"
+msgstr ""
+"Выполняется spec функция '%s' с %d аргументами\n"
+"\n"
+"\n"
 
 #: config/bfin/bfin.c:1390
 #, c-format
@@ -3803,117 +3612,106 @@
 msgid "bad output_condmove_single operand"
 msgstr "некорректный операнд для output_condmove_single"
 
-#: config/i386/i386.c:17387
+#: config/i386/i386.c:17390
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "некорректный операнд UNSPEC"
 
-#: config/i386/i386.c:17925
-#, fuzzy, c-format
-#| msgid "invalid use of %<restrict%>"
+#: config/i386/i386.c:17928
+#, c-format
 msgid "invalid use of register '%s'"
-msgstr "неверное употребление спецификатора %<restrict%>"
+msgstr "недопустимое использование регистра '%s'>"
 
-#: config/i386/i386.c:17930
-#, fuzzy, c-format
-#| msgid "invalid type for make function"
+#: config/i386/i386.c:17933
+#, c-format
 msgid "invalid use of asm flag output"
-msgstr "некорректный тип для make функции"
+msgstr "некорректное использование флага вывода в asm"
 
-#: config/i386/i386.c:18160
-#, fuzzy, c-format
-#| msgid "invalid operand size for operand code '%c'"
+#: config/i386/i386.c:18163
+#, c-format
 msgid "invalid operand size for operand code 'O'"
-msgstr "недопустимый размер операнда для кода '%c'"
+msgstr "недопустимый размер операнда для кода 'O'"
 
-#: config/i386/i386.c:18195
-#, fuzzy, c-format
-#| msgid "invalid operand size for operand code '%c'"
+#: config/i386/i386.c:18198
+#, c-format
 msgid "invalid operand size for operand code 'z'"
-msgstr "недопустимый размер операнда для кода '%c'"
+msgstr "недопустимый размер операнда для кода 'z'"
 
-#: config/i386/i386.c:18264
-#, fuzzy, c-format
-#| msgid "invalid operand type used with operand code '%c'"
+#: config/i386/i386.c:18267
+#, c-format
 msgid "invalid operand type used with operand code 'Z'"
-msgstr "недопустимый тип операнда для кода '%c'"
+msgstr "недопустимый тип операнда для кода 'Z'"
 
-#: config/i386/i386.c:18269
-#, fuzzy, c-format
-#| msgid "invalid operand size for operand code '%c'"
+#: config/i386/i386.c:18272
+#, c-format
 msgid "invalid operand size for operand code 'Z'"
-msgstr "недопустимый размер операнда для кода '%c'"
+msgstr "недопустимый размер операнда для кода 'Z'"
 
-#: config/i386/i386.c:18346
+#: config/i386/i386.c:18349
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "операнд не является кодом условия, неверный код операнда 'Y'"
 
-#: config/i386/i386.c:18425
+#: config/i386/i386.c:18428
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "операнд не является кодом условия, неверный код операнда 'D'"
 
-#: config/i386/i386.c:18443
-#, fuzzy, c-format
-#| msgid "operand is not a condition code, invalid operand code 'D'"
+#: config/i386/i386.c:18446
+#, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
-msgstr "операнд не является кодом условия, неверный код операнда 'D'"
+msgstr "операнд не является кодом условия, неверный код операнда '%c'"
 
-#: config/i386/i386.c:18456
+#: config/i386/i386.c:18459
 #, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "операнд не является ссылкой на память со смещением, неверный код операнда 'H'"
 
-#: config/i386/i386.c:18471
-#, fuzzy, c-format
-#| msgid "operand is not a condition code, invalid operand code 'Y'"
+#: config/i386/i386.c:18474
+#, c-format
 msgid "operand is not an integer, invalid operand code 'K'"
-msgstr "операнд не является кодом условия, неверный код операнда 'Y'"
+msgstr "операнд не является кодом условия, неверный код операнда 'K'"
 
-#: config/i386/i386.c:18499
-#, fuzzy, c-format
-#| msgid "operand is not a condition code, invalid operand code 'Y'"
+#: config/i386/i386.c:18502
+#, c-format
 msgid "operand is not a specific integer, invalid operand code 'r'"
-msgstr "операнд не является кодом условия, неверный код операнда 'Y'"
+msgstr "операнд не является специфическим целым, неверный код операнда 'r'"
 
-#: config/i386/i386.c:18517
-#, fuzzy, c-format
-#| msgid "operand is not a condition code, invalid operand code 'Y'"
+#: config/i386/i386.c:18520
+#, c-format
 msgid "operand is not an integer, invalid operand code 'R'"
-msgstr "операнд не является кодом условия, неверный код операнда 'Y'"
+msgstr "операнд не является целым, неверный код операнда 'R'"
 
-#: config/i386/i386.c:18540
-#, fuzzy, c-format
-#| msgid "operand is not a condition code, invalid operand code 'Y'"
+#: config/i386/i386.c:18543
+#, c-format
 msgid "operand is not a specific integer, invalid operand code 'R'"
-msgstr "операнд не является кодом условия, неверный код операнда 'Y'"
+msgstr "операнд не является специфическим целым, неверный код операнда 'R'"
 
-#: config/i386/i386.c:18626
+#: config/i386/i386.c:18629
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "некорректный код операнда '%c'"
 
-#: config/i386/i386.c:18688
+#: config/i386/i386.c:18691
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "некорректные ограничения для операнда"
 
-#: config/i386/i386.c:18738
-#, fuzzy, c-format
-#| msgid "invalid insn:"
+#: config/i386/i386.c:18741
+#, c-format
 msgid "invalid vector immediate"
-msgstr "недопустимая инструкция:"
+msgstr ""
 
-#: config/i386/i386.c:29572
+#: config/i386/i386.c:29575
 msgid "unknown insn mode"
 msgstr "некорректный режим инструкции"
 
 #: config/i386/djgpp.h:146
-#, fuzzy, c-format
-#| msgid "-f%s ignored for Unicos/Mk (not supported)"
+#, c-format
 msgid "-f%s ignored (not supported for DJGPP)\n"
-msgstr "ключ -f%s для Unicos/Mk проигнорирован (не поддерживается)"
+msgstr ""
+"ключ -f%s проигнорирован (не поддерживается для DJGPP)\n"
+"\n"
 
 #: config/ia64/ia64.c:5462
 #, c-format
@@ -3944,7 +3742,7 @@
 msgstr "неверный операнд для кода %%P"
 
 #: config/iq2000/iq2000.c:3185 config/powerpcspe/powerpcspe.c:23951
-#: config/rs6000/rs6000.c:21444
+#: config/rs6000/rs6000.c:21521
 #, c-format
 msgid "invalid %%p value"
 msgstr "неверное значение для кода %%p"
@@ -3998,7 +3796,7 @@
 msgstr "постинкрементный адрес - не регистр"
 
 #: config/m32r/m32r.c:2350 config/m32r/m32r.c:2365
-#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33292
+#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33348
 msgid "bad address"
 msgstr "некорректный адрес"
 
@@ -4098,16 +3896,14 @@
 msgstr "Внутреннее сообщение MMIX: это не константа:"
 
 #: config/msp430/msp430.c:3686
-#, fuzzy, c-format
-#| msgid "invalid reference prefix"
+#, c-format
 msgid "invalid operand prefix"
-msgstr "неверный префикс ссылки"
+msgstr "неверный префикс операнда"
 
 #: config/msp430/msp430.c:3720
-#, fuzzy, c-format
-#| msgid "invalid use of %<restrict%>"
+#, c-format
 msgid "invalid zero extract"
-msgstr "неверное употребление спецификатора %<restrict%>"
+msgstr "неверный операнд инструкции zero extract"
 
 #: config/powerpcspe/host-darwin.c:96 config/rs6000/host-darwin.c:96
 #, c-format
@@ -4119,198 +3915,187 @@
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr "Попробуйте выполнить '%s' в командной строке, чтобы увеличить его размер.\n"
 
-#: config/powerpcspe/powerpcspe.c:4411 config/rs6000/rs6000.c:4258
+#: config/powerpcspe/powerpcspe.c:4411 config/rs6000/rs6000.c:4278
 msgid "-maltivec=le not allowed for big-endian targets"
-msgstr ""
+msgstr "опция -maltivec=le недопустима для big-endian платформ"
 
-#: config/powerpcspe/powerpcspe.c:4423 config/rs6000/rs6000.c:4273
+#: config/powerpcspe/powerpcspe.c:4423 config/rs6000/rs6000.c:4293
 msgid "-mvsx requires hardware floating point"
 msgstr "-mvsx требует аппаратной реализации плавающей арифметики"
 
-#: config/powerpcspe/powerpcspe.c:4431 config/rs6000/rs6000.c:4281
+#: config/powerpcspe/powerpcspe.c:4431 config/rs6000/rs6000.c:4301
 msgid "-mvsx and -mpaired are incompatible"
 msgstr "ключи -mvsx и -mpaired несовместимы"
 
-#: config/powerpcspe/powerpcspe.c:4433 config/rs6000/rs6000.c:4283
+#: config/powerpcspe/powerpcspe.c:4433 config/rs6000/rs6000.c:4303
 msgid "-mvsx needs indexed addressing"
 msgstr "для -mvsx требуется индексная адресация"
 
-#: config/powerpcspe/powerpcspe.c:4438 config/rs6000/rs6000.c:4288
+#: config/powerpcspe/powerpcspe.c:4438 config/rs6000/rs6000.c:4308
 msgid "-mvsx and -mno-altivec are incompatible"
 msgstr "ключи -mvsx и -mno-altivec несовместимы"
 
-#: config/powerpcspe/powerpcspe.c:4440 config/rs6000/rs6000.c:4290
+#: config/powerpcspe/powerpcspe.c:4440 config/rs6000/rs6000.c:4310
 msgid "-mno-altivec disables vsx"
 msgstr "-mno-altivec отменяет vsx"
 
-#: config/powerpcspe/powerpcspe.c:4648 config/rs6000/rs6000.c:4416
-#, fuzzy
-#| msgid "--resource requires -o"
+#: config/powerpcspe/powerpcspe.c:4648 config/rs6000/rs6000.c:4436
 msgid "-mquad-memory requires 64-bit mode"
-msgstr "ключ --resource требует задания -o"
+msgstr "ключ -mquad-memory требует 64-битного режима"
 
-#: config/powerpcspe/powerpcspe.c:4651 config/rs6000/rs6000.c:4419
+#: config/powerpcspe/powerpcspe.c:4651 config/rs6000/rs6000.c:4439
 msgid "-mquad-memory-atomic requires 64-bit mode"
-msgstr ""
+msgstr "ключ -mquad-memory-atomic требует 64-битного режима"
 
-#: config/powerpcspe/powerpcspe.c:4663 config/rs6000/rs6000.c:4431
-#, fuzzy
-#| msgid "Generate code in little endian mode"
+#: config/powerpcspe/powerpcspe.c:4663 config/rs6000/rs6000.c:4451
 msgid "-mquad-memory is not available in little endian mode"
-msgstr "Генерировать код для обратного (little endian) порядка байт"
+msgstr "ключ -mquad-memory не поддерживается для обратного (little endian) порядка байт"
 
-#: config/powerpcspe/powerpcspe.c:4735 config/rs6000/rs6000.c:4512
-#, fuzzy
-#| msgid "--resource requires -o"
+#: config/powerpcspe/powerpcspe.c:4735 config/rs6000/rs6000.c:4532
 msgid "-mtoc-fusion requires 64-bit"
-msgstr "ключ --resource требует задания -o"
+msgstr "ключ -mtoc-fusion требует 64-битного режима"
 
-#: config/powerpcspe/powerpcspe.c:4742 config/rs6000/rs6000.c:4519
+#: config/powerpcspe/powerpcspe.c:4742 config/rs6000/rs6000.c:4539
 msgid "-mtoc-fusion requires medium/large code model"
-msgstr ""
+msgstr "для -mtoc-fusion требуется модель кода medium/large"
 
-#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10915
+#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10947
 msgid "bad move"
 msgstr "некорректная пересылка"
 
-#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21087
+#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21164
 msgid "Bad 128-bit move"
-msgstr ""
+msgstr "некорректная 128-битная пересылка"
 
-#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21278
-#, fuzzy, c-format
-#| msgid "invalid %%H value"
+#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21355
+#, c-format
 msgid "invalid %%e value"
-msgstr "некорректное %%H значение"
+msgstr "некорректное %%e значение"
 
-#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21299
+#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21376
 #, c-format
 msgid "invalid %%f value"
 msgstr "недопустимое значение для кода %%f"
 
-#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21308
+#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21385
 #, c-format
 msgid "invalid %%F value"
 msgstr "недопустимое значение для кода %%F"
 
-#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21317
+#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21394
 #, c-format
 msgid "invalid %%G value"
 msgstr "недопустимое значение для кода %%G"
 
-#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21352
+#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21429
 #, c-format
 msgid "invalid %%j code"
 msgstr "недопустимое значение для кода %%j"
 
-#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21362
+#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21439
 #, c-format
 msgid "invalid %%J code"
 msgstr "недопустимое значение для кода %%J"
 
-#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21372
+#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21449
 #, c-format
 msgid "invalid %%k value"
 msgstr "недопустимое значение для кода %%k"
 
-#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21387
+#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21464
 #: config/xtensa/xtensa.c:2415
 #, c-format
 msgid "invalid %%K value"
 msgstr "недопустимое значение для кода %%K"
 
-#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21434
+#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21511
 #, c-format
 msgid "invalid %%O value"
 msgstr "недопустимое значение для кода %%O"
 
-#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21481
+#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21558
 #, c-format
 msgid "invalid %%q value"
 msgstr "недопустимое значение для кода %%q"
 
-#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21534
+#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21611
 #, c-format
 msgid "invalid %%T value"
 msgstr "недопустимое значение для кода %%T"
 
-#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21546
+#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21623
 #, c-format
 msgid "invalid %%u value"
 msgstr "недопустимое значение для кода %%u"
 
-#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21560
+#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21637
 #: config/xtensa/xtensa.c:2384
 #, c-format
 msgid "invalid %%v value"
 msgstr "недопустимое значение для кода %%v"
 
-#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21627
+#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21704
 #: config/xtensa/xtensa.c:2436
 #, c-format
 msgid "invalid %%x value"
 msgstr "неверное значение для кода %%x"
 
-#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21747
+#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21824
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "некорректное значение %%y, попробуйте использовать ограничитель 'Z'"
 
-#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22282
+#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22359
 msgid "__float128 and __ibm128 cannot be used in the same expression"
-msgstr ""
+msgstr "__float128 и __ibm128 нельзя использовать в одном выражении"
 
-#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22288
+#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22365
 msgid "__ibm128 and long double cannot be used in the same expression"
-msgstr ""
+msgstr "__ibm128 и long double нельзя использовать в одном выражении"
 
-#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22294
+#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22371
 msgid "__float128 and long double cannot be used in the same expression"
-msgstr ""
+msgstr "__float128 и long double нельзя использовать в одном выражении"
 
-#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36572
+#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36628
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "Аргумент AltiVec передан в функцию без прототипа"
 
-#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38739
-#, fuzzy
-#| msgid "Do not generate a single exit point for each function"
+#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38795
 msgid "Could not generate addis value for fusion"
-msgstr "Не генерировать одну выходную точку для каждой функции"
+msgstr "Не удалось сгенерировать дополнительное значение для синтеза"
 
-#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38809
-#, fuzzy
-#| msgid "unable to generate reloads for:"
+#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38865
 msgid "Unable to generate load/store offset for fusion"
-msgstr "ошибка при генерации загрузок операндов на регистры для:"
+msgstr "Не удалось сгенерировать смещение загрузки/сохранения для синтеза"
 
-#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38908
+#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38964
 msgid "Bad GPR fusion"
-msgstr ""
+msgstr "Некорректный GPR синтез"
 
-#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39126
+#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39182
 msgid "emit_fusion_p9_load, bad reg #1"
-msgstr ""
+msgstr "emit_fusion_p9_load, некорректный регистр #1"
 
-#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39172
+#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39228
 msgid "emit_fusion_p9_load, bad reg #2"
-msgstr ""
+msgstr "emit_fusion_p9_load, некорректный регистр #2"
 
-#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39175
+#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39231
 msgid "emit_fusion_p9_load not MEM"
-msgstr ""
+msgstr "emit_fusion_p9_load не память"
 
-#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39213
+#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39269
 msgid "emit_fusion_p9_store, bad reg #1"
-msgstr ""
+msgstr "emit_fusion_p9_store, некорректный регистр #1"
 
-#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39259
+#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39315
 msgid "emit_fusion_p9_store, bad reg #2"
-msgstr ""
+msgstr "emit_fusion_p9_store, некорректный регистр #2"
 
-#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39262
+#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39318
 msgid "emit_fusion_p9_store not MEM"
-msgstr ""
+msgstr "emit_fusion_p9_store не память"
 
 #: config/rl78/rl78.c:2004 config/rl78/rl78.c:2090
 #, c-format
@@ -4378,10 +4163,9 @@
 msgstr "некорректная константа - попытайтесь использовать модификатор вывода"
 
 #: config/s390/s390.c:8004
-#, fuzzy, c-format
-#| msgid "invalid constant for output modifier '%c'"
+#, c-format
 msgid "invalid constant vector for output modifier '%c'"
-msgstr "некорректная константа для модификатора вывода '%c'"
+msgstr "некорректная константный вектор для модификатора вывода '%c'"
 
 #: config/s390/s390.c:8011
 #, c-format
@@ -4394,28 +4178,24 @@
 msgstr "некорректное выражение для модификатора вывода '%c'"
 
 #: config/s390/s390.c:12149
-#, fuzzy
-#| msgid "AltiVec argument passed to unprototyped function"
 msgid "vector argument passed to unprototyped function"
-msgstr "Аргумент AltiVec передан в функцию без прототипа"
+msgstr "векторный аргумент передан в функцию без прототипа"
 
 #: config/s390/s390.c:16391
-#, fuzzy
-#| msgid "pointer targets in return differ in signedness"
 msgid "types differ in signedness"
-msgstr "при возврате результата указуемые типы различаются знаковостью"
+msgstr "типы различаются знаковостью"
 
 #: config/s390/s390.c:16401
 msgid "binary operator does not support two vector bool operands"
-msgstr ""
+msgstr "бинарный оператор не поддерживает два операнда-вектора с булевыми компонентами"
 
 #: config/s390/s390.c:16404
 msgid "binary operator does not support vector bool operand"
-msgstr ""
+msgstr "бинарный оператор не поддерживает операнд - вектор с булевыми компонентами"
 
 #: config/s390/s390.c:16412
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
-msgstr ""
+msgstr "бинарный оператор не поддерживает сочетание операндов вектор с булевыми компонентами и вектор с плавающими компонентами"
 
 #: config/sh/sh.c:1210
 #, c-format
@@ -4476,8 +4256,7 @@
 msgstr "некорректный операнд для %%s"
 
 #: config/sparc/sparc.c:9600
-#, fuzzy, c-format
-#| msgid "floating point constant not a valid immediate operand"
+#, c-format
 msgid "floating-point constant not a valid immediate operand"
 msgstr "плавающая константа не является корректным непосредственным операндом"
 
@@ -4614,34 +4393,24 @@
 msgstr "обнаружен некорректный операнд"
 
 #: config/visium/visium.c:3374
-#, fuzzy
-#| msgid "illegal operand detected"
 msgid "illegal operand "
-msgstr "обнаружен некорректный операнд"
+msgstr "недопустимый операнд "
 
 #: config/visium/visium.c:3425
-#, fuzzy
-#| msgid "illegal operand detected"
 msgid "illegal operand address (1)"
-msgstr "обнаружен некорректный операнд"
+msgstr "некорректный адрес операнда (1)"
 
 #: config/visium/visium.c:3432
-#, fuzzy
-#| msgid "illegal operand detected"
 msgid "illegal operand address (2)"
-msgstr "обнаружен некорректный операнд"
+msgstr "некорректный адрес операнда (2)"
 
 #: config/visium/visium.c:3447
-#, fuzzy
-#| msgid "illegal operand detected"
 msgid "illegal operand address (3)"
-msgstr "обнаружен некорректный операнд"
+msgstr "некорректный адрес операнда (3)"
 
 #: config/visium/visium.c:3455
-#, fuzzy
-#| msgid "illegal operand detected"
 msgid "illegal operand address (4)"
-msgstr "обнаружен некорректный операнд"
+msgstr "некорректный адрес операнда (4)"
 
 #: config/xtensa/xtensa.c:802 config/xtensa/xtensa.c:834
 #: config/xtensa/xtensa.c:843
@@ -4677,7 +4446,7 @@
 
 #: c/c-objc-common.c:173
 msgid "aka"
-msgstr ""
+msgstr "aka"
 
 #: c/c-objc-common.c:206
 msgid "({anonymous})"
@@ -4701,14 +4470,14 @@
 #: c/gimple-parser.c:188 c/gimple-parser.c:197 c/gimple-parser.c:226
 #: c/gimple-parser.c:1375 c/gimple-parser.c:1404 c/gimple-parser.c:1484
 #: c/gimple-parser.c:1511 c/c-parser.c:3204 c/c-parser.c:9967
-#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27841
-#: cp/parser.c:28430
+#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27838
+#: cp/parser.c:28427
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "ожидалось %<;%>"
 
 #: c/c-parser.c:2431 c/c-parser.c:7573 c/c-parser.c:8015 c/c-parser.c:8058
-#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27839 cp/parser.c:28448
+#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27836 cp/parser.c:28445
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "ожидалась %<,%>"
@@ -4723,7 +4492,7 @@
 #: c/gimple-parser.c:821 c/gimple-parser.c:837 c/gimple-parser.c:853
 #: c/gimple-parser.c:880 c/gimple-parser.c:915 c/gimple-parser.c:1038
 #: c/gimple-parser.c:1209 c/gimple-parser.c:1220 c/gimple-parser.c:1342
-#: c/gimple-parser.c:1441 cp/parser.c:28478
+#: c/gimple-parser.c:1441 cp/parser.c:28475
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "ожидалась %<)%>"
@@ -4731,7 +4500,7 @@
 #: c/c-parser.c:3824 c/c-parser.c:4733 c/c-parser.c:4769 c/c-parser.c:6441
 #: c/c-parser.c:8125 c/c-parser.c:8983 c/c-parser.c:9127 c/c-parser.c:11588
 #: c/c-parser.c:18220 c/c-parser.c:18222 c/gimple-parser.c:1015
-#: cp/parser.c:28442
+#: cp/parser.c:28439
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "ожидалась %<]%>"
@@ -4745,7 +4514,7 @@
 #: c/c-parser.c:17792 c/gimple-parser.c:363 c/gimple-parser.c:811
 #: c/gimple-parser.c:873 c/gimple-parser.c:911 c/gimple-parser.c:1198
 #: c/gimple-parser.c:1339 c/gimple-parser.c:1438 c/c-parser.c:11911
-#: cp/parser.c:28433
+#: cp/parser.c:28430
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "ожидалась %<(%>"
@@ -4752,7 +4521,7 @@
 
 #: c/c-parser.c:4903 c/c-parser.c:10310 c/c-parser.c:16212 c/c-parser.c:18449
 #: c/gimple-parser.c:141 c/gimple-parser.c:1444 c/c-parser.c:3018
-#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18155 cp/parser.c:28439
+#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18152 cp/parser.c:28436
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "ожидалась %<{%>"
@@ -4762,13 +4531,13 @@
 #: c/c-parser.c:12351 c/c-parser.c:12493 c/c-parser.c:12864 c/c-parser.c:12957
 #: c/c-parser.c:13566 c/c-parser.c:17636 c/c-parser.c:17695
 #: c/gimple-parser.c:431 c/gimple-parser.c:1492 c/gimple-parser.c:1519
-#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28472 cp/parser.c:29597
-#: cp/parser.c:32279
+#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28469 cp/parser.c:29594
+#: cp/parser.c:32276
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "ожидалось %<:%>"
 
-#: c/c-parser.c:5974 cp/parser.c:28365
+#: c/c-parser.c:5974 cp/parser.c:28362
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "ожидалось %<while%>"
@@ -4777,18 +4546,18 @@
 msgid "expected %<.%>"
 msgstr "ожидалась %<.%>"
 
-#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30172
-#: cp/parser.c:30246
+#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30169
+#: cp/parser.c:30243
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "ожидалось %<@end%>"
 
-#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28457
+#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28454
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "ожидалось %<>%>"
 
-#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28481
+#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28478
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "ожидалась %<,%> или %<)%>"
@@ -4796,32 +4565,32 @@
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15190 c/c-parser.c:15234 c/c-parser.c:15466 c/c-parser.c:15701
 #: c/c-parser.c:17833 c/gimple-parser.c:286 c/c-parser.c:4792
-#: cp/parser.c:28460
+#: cp/parser.c:28457
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "ожидалось %<=%>"
 
-#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28436
-#: cp/parser.c:30389
+#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28433
+#: cp/parser.c:30386
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "ожидалась %<}%>"
 
-#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35674
+#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35671
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "ожидалось %<#pragma omp section%> или %<}%>"
 
-#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28445 cp/parser.c:31535
+#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28442 cp/parser.c:31532
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "ожидалось %<[%>"
 
-#: c/c-typeck.c:7847
+#: c/c-typeck.c:7852
 msgid "(anonymous)"
 msgstr "(anonymous)"
 
-#: c/gimple-parser.c:795 cp/parser.c:15791 cp/parser.c:28454
+#: c/gimple-parser.c:795 cp/parser.c:15788 cp/parser.c:28451
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "ожидалось %<<%>"
@@ -4828,10 +4597,9 @@
 
 #: c/gimple-parser.c:1488 c/gimple-parser.c:1515 c/gimple-parser.c:1543
 #: c/gimple-parser.c:1369 c/gimple-parser.c:1398
-#, fuzzy, gcc-internal-format
-#| msgid "expected channel"
+#, gcc-internal-format
 msgid "expected label"
-msgstr "ожидался канал"
+msgstr "ожидалась метка"
 
 #: cp/call.c:10487
 msgid "candidate 1:"
@@ -4850,34 +4618,24 @@
 msgstr "переход по case-метке"
 
 #: cp/decl.c:3236
-#, fuzzy
-#| msgid "  enters try block"
 msgid "enters try block"
-msgstr "  входит в try-блок"
+msgstr "входит в try-блок"
 
 #: cp/decl.c:3242
-#, fuzzy
-#| msgid "  enters catch block"
 msgid "enters catch block"
-msgstr "  входит в catch-блок"
+msgstr "входит в catch-блок"
 
 #: cp/decl.c:3248
-#, fuzzy
-#| msgid "  enters OpenMP structured block"
 msgid "enters OpenMP structured block"
-msgstr "  входит в OpenMP структурный блок"
+msgstr "входит в OpenMP структурный блок"
 
 #: cp/decl.c:3254
-#, fuzzy
-#| msgid "Generate code for huge switch statements"
 msgid "enters synchronized or atomic statement"
-msgstr "Генерировать код для больших переключателей"
+msgstr "входит в синхронизируемый или атомарный оператор"
 
 #: cp/decl.c:3261
-#, fuzzy
-#| msgid "expected statement"
 msgid "enters constexpr if statement"
-msgstr "ожидался оператор"
+msgstr ""
 
 #: cp/error.c:365
 msgid "<missing>"
@@ -4901,10 +4659,9 @@
 msgstr "<unnamed>"
 
 #: cp/error.c:730
-#, fuzzy, c-format
-#| msgid "<unnamed>"
+#, c-format
 msgid "<unnamed %s>"
-msgstr "<unnamed>"
+msgstr "<unnamed %s>"
 
 #. A lambda's "type" is essentially its signature.
 #: cp/error.c:735
@@ -4942,14 +4699,12 @@
 msgstr "{anonymous}"
 
 #: cp/error.c:1184
-#, fuzzy
-#| msgid "(anonymous)"
 msgid "(anonymous namespace)"
-msgstr "(anonymous)"
+msgstr "(anonymous namespace)"
 
 #: cp/error.c:1276
 msgid "<template arguments error>"
-msgstr "<ошибка параметра шаблона>"
+msgstr "<ошибка в аргументах шаблона>"
 
 #: cp/error.c:1298
 msgid "<enumerator>"
@@ -4980,7 +4735,7 @@
 
 #: cp/error.c:2197
 msgid "<ubsan routine call>"
-msgstr ""
+msgstr "<ubsan routine call>"
 
 #: cp/error.c:2645
 msgid "<unparsed>"
@@ -4987,14 +4742,12 @@
 msgstr "<unparsed>"
 
 #: cp/error.c:2800
-#, fuzzy
-#| msgid "<lambda"
 msgid "<lambda>"
-msgstr "<lambda"
+msgstr "<lambda>"
 
 #: cp/error.c:2843
 msgid "*this"
-msgstr ""
+msgstr "*this"
 
 #: cp/error.c:2857
 msgid "<expression error>"
@@ -5002,7 +4755,7 @@
 
 #: cp/error.c:2872
 msgid "<unknown operator>"
-msgstr "<Неизвестный оператор>"
+msgstr "<неизвестный оператор>"
 
 #: cp/error.c:3327
 msgid "At global scope:"
@@ -5042,16 +4795,12 @@
 msgstr "%s: В конкретизации %q#D:\n"
 
 #: cp/error.c:3487
-#, fuzzy
-#| msgid "%s:%d:%d:   "
 msgid "%r%s:%d:%d:%R   "
-msgstr "%s:%d:%d"
+msgstr "%r%s:%d:%d:%R   "
 
 #: cp/error.c:3490
-#, fuzzy
-#| msgid "%s:%d:   "
 msgid "%r%s:%d:%R   "
-msgstr "%s:%d:   "
+msgstr "%r%s:%d:%R   "
 
 #: cp/error.c:3498
 #, c-format
@@ -5072,51 +4821,39 @@
 msgstr "требуемый из %q#D\n"
 
 #: cp/error.c:3512
-#, fuzzy
-#| msgid "recursively required from here"
 msgid "recursively required from here\n"
-msgstr "рекурсивно требуемый отсюда"
+msgstr ""
 
 #: cp/error.c:3513
-#, fuzzy
-#| msgid "required from here"
 msgid "required from here\n"
-msgstr "требуемый отсюда"
+msgstr ""
 
 #: cp/error.c:3565
-#, fuzzy
-#| msgid "%s:%d:%d:   [ skipping %d instantiation contexts ]\n"
 msgid "%r%s:%d:%d:%R   [ skipping %d instantiation contexts, use -ftemplate-backtrace-limit=0 to disable ]\n"
-msgstr "%s:%d:%d:   [ пропуск %d контекстов конкретизации ]\n"
+msgstr ""
 
 #: cp/error.c:3571
-#, fuzzy
-#| msgid "%s:%d:%d:   [ skipping %d instantiation contexts ]\n"
 msgid "%r%s:%d:%R   [ skipping %d instantiation contexts, use -ftemplate-backtrace-limit=0 to disable ]\n"
-msgstr "%s:%d:%d:   [ пропуск %d контекстов конкретизации ]\n"
+msgstr ""
 
 #: cp/error.c:3625
-#, fuzzy
-#| msgid "%s:%d:%d:   in constexpr expansion of %qs"
 msgid "%r%s:%d:%d:%R   in %<constexpr%> expansion of %qs"
-msgstr "%s:%d:%d:   в раскрытии константного выражения %qs"
+msgstr ""
 
 #: cp/error.c:3629
-#, fuzzy
-#| msgid "%s:%d:   in constexpr expansion of %qs"
 msgid "%r%s:%d:%R   in %<constexpr%> expansion of %qs"
-msgstr "%s:%d:   в раскрытии константного выражения %qs"
+msgstr ""
 
-#: cp/pt.c:1949 cp/semantics.c:5268
+#: cp/pt.c:1949 cp/semantics.c:5271
 msgid "candidates are:"
 msgstr "претенденты:"
 
-#: cp/pt.c:1951 cp/pt.c:22975
+#: cp/pt.c:1951 cp/pt.c:23053
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "кандидат"
-msgstr[1] "кандидаты"
-msgstr[2] "кандидаты"
+msgstr[1] "претенденты:"
+msgstr[2] "претенденты:"
 
 #: cp/rtti.c:575
 msgid "target is not pointer or reference to class"
@@ -5158,27 +4895,27 @@
 msgid "source type is not polymorphic"
 msgstr "тип источника не является полиморфным"
 
-#: cp/typeck.c:6083 c/c-typeck.c:4261
+#: cp/typeck.c:6083 c/c-typeck.c:4266
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "неверный тип аргумента для унарного минуса"
 
-#: cp/typeck.c:6084 c/c-typeck.c:4248
+#: cp/typeck.c:6084 c/c-typeck.c:4253
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "неверный тип аргумента для унарного плюса"
 
-#: cp/typeck.c:6111 c/c-typeck.c:4302
+#: cp/typeck.c:6111 c/c-typeck.c:4307
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "неверный тип аргумента для побитового дополнения"
 
-#: cp/typeck.c:6128 c/c-typeck.c:4310
+#: cp/typeck.c:6128 c/c-typeck.c:4315
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "неверный тип аргумента для abs"
 
-#: cp/typeck.c:6140 c/c-typeck.c:4322
+#: cp/typeck.c:6140 c/c-typeck.c:4327
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "неверный тип аргумента для сопряжения"
@@ -5251,46 +4988,36 @@
 msgstr "аргументы '%s' и '%s' для внутренней функции '%s'"
 
 #: fortran/error.c:868
-#, fuzzy
-#| msgid "Fortran 2008 obsolescent feature: ENTRY statement at %C"
 msgid "Fortran 2018 deleted feature:"
-msgstr "Fortran 2008 устаревшая возможность: ENTRY оператор в %C"
+msgstr ""
 
 #: fortran/error.c:871
-#, fuzzy
-#| msgid "Fortran 2008 obsolescent feature: ENTRY statement at %C"
 msgid "Fortran 2018 obsolescent feature:"
-msgstr "Fortran 2008 устаревшая возможность: ENTRY оператор в %C"
+msgstr ""
 
 #: fortran/error.c:874
 msgid "Fortran 2018:"
-msgstr ""
+msgstr "Fortran 2018:"
 
 #: fortran/error.c:880
-#, fuzzy
-#| msgid "Fortran 2008 obsolescent feature: ENTRY statement at %C"
 msgid "Fortran 2008 obsolescent feature:"
-msgstr "Fortran 2008 устаревшая возможность: ENTRY оператор в %C"
+msgstr "Fortran 2008 устаревшая возможность:"
 
 #: fortran/error.c:889
 msgid "GNU Extension:"
-msgstr ""
+msgstr "Расширение GNU:"
 
 #: fortran/error.c:892
 msgid "Legacy Extension:"
-msgstr ""
+msgstr "Устаревшее Расширение:"
 
 #: fortran/error.c:895
-#, fuzzy
-#| msgid "Obsolescent feature: Computed GOTO at %C"
 msgid "Obsolescent feature:"
-msgstr "Устаревшая возможность: Вычисляемый GOTO в %C"
+msgstr "Устаревшая возможность:"
 
 #: fortran/error.c:898
-#, fuzzy
-#| msgid "expected operator"
 msgid "Deleted feature:"
-msgstr "ожидался оператор"
+msgstr "Отмененная возможность:"
 
 #: fortran/expr.c:3359
 msgid "array assignment"
@@ -5314,10 +5041,8 @@
 msgstr "Требуется неотрицательная ширина"
 
 #: fortran/io.c:601
-#, fuzzy
-#| msgid "Unexpected element '%c' in format string at %L"
 msgid "Unexpected element %qc in format string at %L"
-msgstr "Неожиданный элемент '%c' в строке формата в %L"
+msgstr "Неожиданный элемент %qc в строке формата в %L"
 
 #: fortran/io.c:603
 msgid "Unexpected end of format string"
@@ -5332,10 +5057,8 @@
 msgstr "Отсутствует открывающая скобка"
 
 #: fortran/io.c:653
-#, fuzzy
-#| msgid "Left parenthesis required after '*'"
 msgid "Left parenthesis required after %<*%>"
-msgstr "Левая скобка требуется после '*'"
+msgstr "Левая скобка требуется после %<*%>"
 
 #: fortran/io.c:684
 msgid "Expected P edit descriptor"
@@ -5363,10 +5086,9 @@
 msgstr "Положительная ширина экспоненты требуется"
 
 #: fortran/io.c:1013
-#, fuzzy, c-format
-#| msgid "Missing right parenthesis at %C"
+#, c-format
 msgid "Right parenthesis expected at %C"
-msgstr "Отсутствует правая скобка в %C"
+msgstr "Ожидалась правая скобка в %C"
 
 #: fortran/io.c:1047
 msgid "Period required in format specifier"
@@ -5433,67 +5155,67 @@
 msgid "Expected attribute bit name"
 msgstr "Ожидалось имя атрибутного бита"
 
-#: fortran/module.c:3223
+#: fortran/module.c:3225
 msgid "Expected integer string"
 msgstr "Ожидалась integer строка"
 
-#: fortran/module.c:3227
+#: fortran/module.c:3229
 msgid "Error converting integer"
 msgstr "Ошибка при преобразовании целого"
 
-#: fortran/module.c:3249
+#: fortran/module.c:3251
 msgid "Expected real string"
 msgstr "Ожидалась real строка"
 
-#: fortran/module.c:3474
+#: fortran/module.c:3476
 msgid "Expected expression type"
 msgstr "Ожидался тип выражения"
 
-#: fortran/module.c:3554
+#: fortran/module.c:3556
 msgid "Bad operator"
 msgstr "Некорректный оператор"
 
-#: fortran/module.c:3671
+#: fortran/module.c:3673
 msgid "Bad type in constant expression"
 msgstr "Некорректный тип в константном выражении"
 
-#: fortran/module.c:7038
+#: fortran/module.c:7040
 msgid "Unexpected end of module"
 msgstr "Неожиданный конец модуля"
 
-#: fortran/parse.c:1757
+#: fortran/parse.c:1761
 msgid "arithmetic IF"
 msgstr "арифметический IF"
 
-#: fortran/parse.c:1766
+#: fortran/parse.c:1770
 msgid "attribute declaration"
 msgstr "декларация атрибута"
 
-#: fortran/parse.c:1802
+#: fortran/parse.c:1806
 msgid "data declaration"
 msgstr "декларация данных"
 
-#: fortran/parse.c:1820
+#: fortran/parse.c:1824
 msgid "derived type declaration"
 msgstr "декларация производного типа"
 
-#: fortran/parse.c:1947
+#: fortran/parse.c:1951
 msgid "block IF"
 msgstr "блочный IF"
 
-#: fortran/parse.c:1956
+#: fortran/parse.c:1960
 msgid "implied END DO"
 msgstr "предписанный END DO"
 
-#: fortran/parse.c:2050 fortran/resolve.c:11199
+#: fortran/parse.c:2054 fortran/resolve.c:11219
 msgid "assignment"
 msgstr "присваивание"
 
-#: fortran/parse.c:2053 fortran/resolve.c:11250 fortran/resolve.c:11253
+#: fortran/parse.c:2057 fortran/resolve.c:11270 fortran/resolve.c:11273
 msgid "pointer assignment"
 msgstr "присваивание указателя"
 
-#: fortran/parse.c:2071
+#: fortran/parse.c:2075
 msgid "simple IF"
 msgstr "простой IF"
 
@@ -5502,108 +5224,78 @@
 msgstr "элементная процедура"
 
 #: fortran/resolve.c:2366
-#, fuzzy
-#| msgid "no arguments"
 msgid "allocatable argument"
-msgstr "отсутствуют аргументы"
+msgstr "размещаемый аргумент"
 
 #: fortran/resolve.c:2371
-#, fuzzy
-#| msgid "not enough arguments"
 msgid "asynchronous argument"
-msgstr "недостаточно аргументов"
+msgstr "асинхронный аргумент"
 
 #: fortran/resolve.c:2376
-#, fuzzy
-#| msgid "invalid PHI argument"
 msgid "optional argument"
-msgstr "некорректный аргумент PHI"
+msgstr "необязательный аргумент"
 
 #: fortran/resolve.c:2381
-#, fuzzy
-#| msgid "pointer assignment"
 msgid "pointer argument"
-msgstr "присваивание указателя"
+msgstr "аргумент-указатель"
 
 #: fortran/resolve.c:2386
-#, fuzzy
-#| msgid "too many arguments"
 msgid "target argument"
-msgstr "слишком много аргументов"
+msgstr "целевой аргумент"
 
 #: fortran/resolve.c:2391
-#, fuzzy
-#| msgid "invalid PHI argument"
 msgid "value argument"
-msgstr "некорректный аргумент PHI"
+msgstr "value аргумент"
 
 #: fortran/resolve.c:2396
-#, fuzzy
-#| msgid "no arguments"
 msgid "volatile argument"
-msgstr "отсутствуют аргументы"
+msgstr "volatile аргумент"
 
 #: fortran/resolve.c:2401
-#, fuzzy
-#| msgid "mismatched arguments"
 msgid "assumed-shape argument"
-msgstr "несовпадающие аргументы"
+msgstr "assumed-shape аргумент"
 
 #: fortran/resolve.c:2406
-#, fuzzy
-#| msgid "mismatched arguments"
 msgid "assumed-rank argument"
-msgstr "несовпадающие аргументы"
+msgstr "assumed-rank аргумент"
 
 #: fortran/resolve.c:2411
-#, fuzzy
-#| msgid "array assignment"
 msgid "coarray argument"
-msgstr "присваивание массивов"
+msgstr "coarray аргумент"
 
 #: fortran/resolve.c:2416
 msgid "parametrized derived type argument"
-msgstr ""
+msgstr "аргумент параметризованного производного типа"
 
 #: fortran/resolve.c:2421
-#, fuzzy
-#| msgid "no arguments"
 msgid "polymorphic argument"
-msgstr "отсутствуют аргументы"
+msgstr "полиморфный аргумент"
 
 #: fortran/resolve.c:2426
 msgid "NO_ARG_CHECK attribute"
-msgstr ""
+msgstr "атрибут NO_ARG_CHECK"
 
 #. As assumed-type is unlimited polymorphic (cf. above).
 #. See also TS 29113, Note 6.1.
 #: fortran/resolve.c:2433
-#, fuzzy
-#| msgid "mismatched arguments"
 msgid "assumed-type argument"
-msgstr "несовпадающие аргументы"
+msgstr "аргумент предполагаемого типа"
 
 #: fortran/resolve.c:2444
 msgid "array result"
-msgstr ""
+msgstr "результат-массив"
 
 #: fortran/resolve.c:2449
-#, fuzzy
-#| msgid "Coindexed allocatable object at %L"
 msgid "pointer or allocatable result"
-msgstr "Коиндексированный размещаемый объект в %L"
+msgstr "указательный или размещаемый результат"
 
 #: fortran/resolve.c:2456
-#, fuzzy
-#| msgid "COMMON variable '%s' at %L must have constant character length"
 msgid "result with non-constant character length"
-msgstr "COMMON переменная '%s' в %L должна иметь константную character длину"
+msgstr "результат с неконстантной character длиной"
 
 #: fortran/resolve.c:2468
-#, fuzzy
-#| msgid "module procedure"
 msgid "bind(c) procedure"
-msgstr "процедура модуля"
+msgstr "процедура bind(c)"
 
 #: fortran/resolve.c:3846
 #, c-format
@@ -5611,118 +5303,115 @@
 msgstr "Некорректный контекст для NULL() указателя в %%L"
 
 #: fortran/resolve.c:3862
-#, fuzzy, c-format
-#| msgid "Operand of unary numeric operator '%s' at %%L is %s"
+#, c-format
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
-msgstr "Операнд унарного числового оператора '%s' в %%L есть %s"
+msgstr "Операнд унарного числового оператора %%<%s%%> в %%L есть %s"
 
-#: fortran/resolve.c:3878
-#, fuzzy, c-format
-#| msgid "Operands of binary numeric operator '%s' at %%L are %s/%s"
+#: fortran/resolve.c:3879
+#, c-format
+msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
+msgstr ""
+
+#: fortran/resolve.c:3884
+#, c-format
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
-msgstr "Операнды бинарного числового оператора '%s' в %%L есть %s/%s"
+msgstr "Операнды бинарного числового оператора %%<%s%%> в %%L есть %s/%s"
 
-#: fortran/resolve.c:3893
+#: fortran/resolve.c:3899
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr "Операнды оператора конкатенации строк в %%L есть %s/%s"
 
-#: fortran/resolve.c:3926
-#, fuzzy, c-format
-#| msgid "Operands of logical operator '%s' at %%L are %s/%s"
+#: fortran/resolve.c:3932
+#, c-format
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
-msgstr "Операнды логического оператора '%s' в %%L есть %s/%s"
+msgstr "Операнды логического оператора %%<%s%%> в %%L есть %s/%s"
 
-#: fortran/resolve.c:3949
+#: fortran/resolve.c:3955
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
-msgstr "Операнд .not. оператора в %%L есть %s"
+msgstr ""
 
-#: fortran/resolve.c:3963
+#: fortran/resolve.c:3969
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "COMPLEX величины не могут сравниваться в %L"
 
-#: fortran/resolve.c:4015
+#: fortran/resolve.c:4021
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr "Логические в %%L должны сравниваться посредством %s вместо %s"
 
-#: fortran/resolve.c:4021
-#, fuzzy, c-format
-#| msgid "Operands of comparison operator '%s' at %%L are %s/%s"
+#: fortran/resolve.c:4027
+#, c-format
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
-msgstr "Операнды оператора сравнения '%s' в %%L есть %s/%s"
+msgstr "Операнды оператора сравнения %%<%s%%> в %%L есть %s/%s"
 
-#: fortran/resolve.c:4034
-#, fuzzy, c-format
-#| msgid "Unknown operator '%s' at %%L"
+#: fortran/resolve.c:4040
+#, c-format
 msgid "Unknown operator %%<%s%%> at %%L; did you mean '%s'?"
-msgstr "Неизвестный оператор '%s' в %%L"
+msgstr ""
 
-#: fortran/resolve.c:4037
-#, fuzzy, c-format
-#| msgid "Unknown operator '%s' at %%L"
+#: fortran/resolve.c:4043
+#, c-format
 msgid "Unknown operator %%<%s%%> at %%L"
-msgstr "Неизвестный оператор '%s' в %%L"
+msgstr "Неизвестный оператор %%<%s%%> в %%L"
 
-#: fortran/resolve.c:4040
-#, fuzzy, c-format
-#| msgid "Operand of user operator '%s' at %%L is %s"
+#: fortran/resolve.c:4046
+#, c-format
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
-msgstr "Операнд пользовательского оператора '%s' в %%L есть %s"
+msgstr "Операнд пользовательского оператора %%<%s%%> в %%L есть %s"
 
-#: fortran/resolve.c:4044
-#, fuzzy, c-format
-#| msgid "Operands of user operator '%s' at %%L are %s/%s"
+#: fortran/resolve.c:4050
+#, c-format
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
-msgstr "Операнды пользовательского оператора '%s' в %%L есть %s/%s"
+msgstr "Операнды пользовательского оператора %%<%s%%> в %%L есть %s/%s"
 
-#: fortran/resolve.c:4132
+#: fortran/resolve.c:4138
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "Противоречивые ранги для оператора в %%L и %%L"
 
-#: fortran/resolve.c:6849
+#: fortran/resolve.c:6855
 msgid "Loop variable"
 msgstr "Переменная цикла"
 
-#: fortran/resolve.c:6853
+#: fortran/resolve.c:6859
 msgid "iterator variable"
 msgstr "Переменная итератора"
 
-#: fortran/resolve.c:6857
+#: fortran/resolve.c:6863
 msgid "Start expression in DO loop"
 msgstr "Начальное выражение в DO цикле"
 
-#: fortran/resolve.c:6861
+#: fortran/resolve.c:6867
 msgid "End expression in DO loop"
 msgstr "Конечное выражение в DO цикле"
 
-#: fortran/resolve.c:6865
+#: fortran/resolve.c:6871
 msgid "Step expression in DO loop"
 msgstr "Шаговое выражение в DO цикле"
 
-#: fortran/resolve.c:7150 fortran/resolve.c:7153
+#: fortran/resolve.c:7156 fortran/resolve.c:7159
 msgid "DEALLOCATE object"
 msgstr "DEALLOCATE объект"
 
-#: fortran/resolve.c:7525 fortran/resolve.c:7528
+#: fortran/resolve.c:7531 fortran/resolve.c:7534
 msgid "ALLOCATE object"
 msgstr "ALLOCATE объект"
 
-#: fortran/resolve.c:7720 fortran/resolve.c:9417
+#: fortran/resolve.c:7726 fortran/resolve.c:9428
 msgid "STAT variable"
 msgstr "STAT переменная"
 
-#: fortran/resolve.c:7764 fortran/resolve.c:9429
+#: fortran/resolve.c:7770 fortran/resolve.c:9440
 msgid "ERRMSG variable"
 msgstr "ERRMSG переменная"
 
-#: fortran/resolve.c:9219
+#: fortran/resolve.c:9230
 msgid "item in READ"
 msgstr "элемент в READ"
 
-#: fortran/resolve.c:9441
+#: fortran/resolve.c:9452
 msgid "ACQUIRED_LOCK variable"
 msgstr "ACQUIRED_LOCK переменная"
 
@@ -5755,9 +5444,9 @@
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr "Цель переотображения ранга слишком мала (%ld < %ld)"
 
-#: fortran/trans-expr.c:10154
+#: fortran/trans-expr.c:10157
 msgid "Assignment of scalar to unallocated array"
-msgstr ""
+msgstr "Присваивание скаляра неразмещенному массиву"
 
 #: fortran/trans-intrinsic.c:894
 #, c-format
@@ -5764,12 +5453,12 @@
 msgid "Unequal character lengths (%ld/%ld) in %s"
 msgstr "Неравные character длины (%ld/%ld) в %s"
 
-#: fortran/trans-intrinsic.c:8088
+#: fortran/trans-intrinsic.c:8090
 #, c-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative (its value is %ld)"
 msgstr "Аргумент NCOPIES от REPEAT встроенной функции отрицателен (его значение равно %ld)"
 
-#: fortran/trans-intrinsic.c:8120
+#: fortran/trans-intrinsic.c:8122
 msgid "Argument NCOPIES of REPEAT intrinsic is too large"
 msgstr "Аргумент NCOPIES от REPEAT встроенной функции слишком велик"
 
@@ -5790,15 +5479,15 @@
 msgid "Invalid image number %d in SYNC IMAGES"
 msgstr "Некорректный image номер %d в SYNC IMAGES"
 
-#: fortran/trans-stmt.c:2180
+#: fortran/trans-stmt.c:2177
 msgid "Loop iterates infinitely"
-msgstr ""
+msgstr "Бесконечный цикл"
 
-#: fortran/trans-stmt.c:2200 fortran/trans-stmt.c:2456
+#: fortran/trans-stmt.c:2197 fortran/trans-stmt.c:2453
 msgid "Loop variable has been modified"
 msgstr "Переменная цикла изменена"
 
-#: fortran/trans-stmt.c:2309
+#: fortran/trans-stmt.c:2306
 msgid "DO step value is zero"
 msgstr "Значение DO шага нулевое"
 
@@ -5834,76 +5523,54 @@
 
 #. The remainder are real diagnostic types.
 #: fortran/gfc-diagnostic.def:33
-#, fuzzy
-#| msgid "Fatal Error:"
 msgid "Fatal Error"
-msgstr "Фатальная ошибка: "
+msgstr "Фатальная ошибка"
 
 #. This is like DK_ICE, but backtrace is not printed.  Used in the driver
 #. when reporting fatal signal in the compiler.
 #: fortran/gfc-diagnostic.def:34 fortran/gfc-diagnostic.def:50
-#, fuzzy
-#| msgid "internal compiler error: "
 msgid "internal compiler error"
-msgstr "внутренняя ошибка компилятора: "
+msgstr "внутренняя ошибка компилятора"
 
 #: fortran/gfc-diagnostic.def:35
-#, fuzzy
-#| msgid "Error:"
 msgid "Error"
-msgstr "ошибка:"
+msgstr "ошибка"
 
 #: fortran/gfc-diagnostic.def:36
-#, fuzzy
-#| msgid "sorry, unimplemented: "
 msgid "sorry, unimplemented"
-msgstr "пока не реализовано: "
+msgstr "простите, не реализовано"
 
 #: fortran/gfc-diagnostic.def:37
-#, fuzzy
-#| msgid "Warning:"
 msgid "Warning"
-msgstr "Предупреждение:"
+msgstr "Предупреждение"
 
 #: fortran/gfc-diagnostic.def:38
-#, fuzzy
-#| msgid "anachronism: "
 msgid "anachronism"
-msgstr "анахронизм: "
+msgstr "анахронизм"
 
 #: fortran/gfc-diagnostic.def:39
-#, fuzzy
-#| msgid "note: "
 msgid "note"
-msgstr "замечание: "
+msgstr "замечание"
 
 #: fortran/gfc-diagnostic.def:40
-#, fuzzy
-#| msgid "debug: "
 msgid "debug"
-msgstr "отладка: "
+msgstr "отладка"
 
 #. These two would be re-classified as DK_WARNING or DK_ERROR, so the
 #. prefix does not matter.
 #: fortran/gfc-diagnostic.def:43
-#, fuzzy
-#| msgid "pedwarn: "
 msgid "pedwarn"
-msgstr "pedwarn: "
+msgstr "pedwarn"
 
 #: fortran/gfc-diagnostic.def:44
-#, fuzzy
-#| msgid "permerror: "
 msgid "permerror"
-msgstr "permerror: "
+msgstr "permerror"
 
 #. This one is just for counting DK_WARNING promoted to DK_ERROR
 #. due to -Werror and -Werror=warning.
 #: fortran/gfc-diagnostic.def:47
-#, fuzzy
-#| msgid "error: "
 msgid "error"
-msgstr "ошибка: "
+msgstr "ошибка"
 
 #: go/go-backend.c:165
 msgid "lseek failed while reading export data"
@@ -5922,16 +5589,12 @@
 msgstr "короткое чтение при чтении экспортных данных"
 
 #: gcc.c:755 gcc.c:759 gcc.c:814
-#, fuzzy
-#| msgid "-m%s not supported in this configuration"
 msgid "-gz is not supported in this configuration"
-msgstr "-m%s в данной конфигурации не поддерживается"
+msgstr "-gz в данной конфигурации не поддерживается"
 
 #: gcc.c:765 gcc.c:825
-#, fuzzy
-#| msgid "ifunc is not supported in this configuration"
 msgid "-gz=zlib is not supported in this configuration"
-msgstr "ifunc в данной конфигурации не поддерживается"
+msgstr "-gz=zlib в данной конфигурации не поддерживается"
 
 #: gcc.c:969
 msgid "-fuse-linker-plugin is not supported in this configuration"
@@ -5939,23 +5602,19 @@
 
 #: gcc.c:984
 msgid "cannot specify -static with -fsanitize=address"
-msgstr ""
+msgstr "нельзя использовать -static вместе с -fsanitize=address"
 
 #: gcc.c:986
 msgid "cannot specify -static with -fsanitize=thread"
-msgstr ""
+msgstr "нельзя использовать -static вместе с -fsanitize=thread"
 
 #: gcc.c:1008
-#, fuzzy
-#| msgid "weakref is not supported in this configuration"
 msgid "-fvtable-verify=std is not supported in this configuration"
-msgstr "weakref в данной конфигурации не поддерживается"
+msgstr "-fvtable-verify=std в данной конфигурации не поддерживается"
 
 #: gcc.c:1010
-#, fuzzy
-#| msgid "weakref is not supported in this configuration"
 msgid "-fvtable-verify=preinit is not supported in this configuration"
-msgstr "weakref в данной конфигурации не поддерживается"
+msgstr "-fvtable-verify=preinit в данной конфигурации не поддерживается"
 
 #: gcc.c:1142 ada/gcc-interface/lang-specs.h:33
 msgid "-pg and -fomit-frame-pointer are incompatible"
@@ -5970,10 +5629,8 @@
 msgstr "ввод со стандартного ввода возможен только с ключом -E или -x"
 
 #: config/darwin.h:171
-#, fuzzy
-#| msgid "-fpic is not supported"
 msgid "rdynamic is not supported"
-msgstr "ключ -fpic не поддерживается"
+msgstr "rdynamic не поддерживается"
 
 #: config/darwin.h:259
 msgid "-current_version only allowed with -dynamiclib"
@@ -6027,10 +5684,8 @@
 msgstr "не поддерживает мультибиблиотеку"
 
 #: config/sol2.h:418
-#, fuzzy
-#| msgid "ifunc is not supported in this configuration"
 msgid "-pie is not supported in this configuration"
-msgstr "ifunc в данной конфигурации не поддерживается"
+msgstr "-pie не поддерживается в этой конфигурации"
 
 #: config/vxworks.h:118
 msgid "-Xbind-now and -Xbind-lazy are incompatible"
@@ -6038,10 +5693,8 @@
 
 #: config/aarch64/aarch64-freebsd.h:37 config/arm/freebsd.h:49
 #: config/riscv/freebsd.h:44
-#, fuzzy
-#| msgid "consider using `-pg' instead of `-p' with gprof(1)"
 msgid "consider using `-pg' instead of `-p' with gprof (1) "
-msgstr "попробуйте `-pg' вместо `-p' для gprof(1)"
+msgstr ""
 
 #: config/arc/arc.h:68 config/mips/mips.h:1397
 msgid "may not use both -EB and -EL"
@@ -6056,10 +5709,8 @@
 msgstr "ключи -mbig-endian и -mlittle-endian несовместимы"
 
 #: config/avr/specs.h:71
-#, fuzzy
-#| msgid "-fpic is not supported"
 msgid "shared is not supported"
-msgstr "ключ -fpic не поддерживается"
+msgstr "shared не поддерживается"
 
 #: config/bfin/elf.h:55
 msgid "no processor type specified for linking"
@@ -6087,14 +5738,12 @@
 msgstr "ключи -msingle-float и -msoft-float несовместимы"
 
 #: config/moxie/moxiebox.h:43
-#, fuzzy
-#| msgid "Assume target CPU is configured as little endian"
 msgid "this target is little-endian"
-msgstr "Считать что процессор имеет обратный порядок байт (little endian)"
+msgstr "эта цель little-endian"
 
 #: config/nios2/elf.h:44
 msgid "You need a C startup file for -msys-crt0="
-msgstr ""
+msgstr "Нужен стартовый файл Си для -msys-crt0="
 
 #: config/pa/pa-hpux10.h:102 config/pa/pa-hpux10.h:105
 #: config/pa/pa-hpux10.h:113 config/pa/pa-hpux10.h:116
@@ -6125,10 +5774,8 @@
 msgstr "ключ -mas100-syntax несовместим с -gdwarf"
 
 #: config/rx/rx.h:81
-#, fuzzy
-#| msgid "rx200 cpu does not have FPU hardware"
 msgid "rx100 cpu does not have FPU hardware"
-msgstr "rx200 cpu не имеет FPU оборудования"
+msgstr "rx100 cpu не имеет FPU оборудования"
 
 #: config/rx/rx.h:82
 msgid "rx200 cpu does not have FPU hardware"
@@ -6165,10 +5812,8 @@
 msgstr "-c требуется для gnat2why"
 
 #: ada/gcc-interface/lang-specs.h:65
-#, fuzzy
-#| msgid "-c required for gnat2why"
 msgid "-c required for gnat2scil"
-msgstr "-c требуется для gnat2why"
+msgstr "-c требуется для gnat2scil"
 
 #: fortran/lang-specs.h:54 fortran/lang-specs.h:68
 msgid "gfortran does not support -E without -cpp"
@@ -6187,65 +5832,49 @@
 msgstr "objc++-cpp-output устарело; пожалуйста используйте objective-c++-cpp-output взамен"
 
 #: fortran/lang.opt:146
-#, fuzzy
-#| msgid "-J<directory>\tPut MODULE files in 'directory'"
 msgid "-J<directory>\tPut MODULE files in 'directory'."
-msgstr "-J<каталог>  \tПомещать файлы MODULE в 'каталог'"
+msgstr "-J<каталог>\tПомещать файлы MODULE в 'каталог'."
 
 #: fortran/lang.opt:198
-#, fuzzy
-#| msgid "Warn about possible aliasing of dummy arguments"
 msgid "Warn about possible aliasing of dummy arguments."
-msgstr "Предупреждать о возможном перекрытии формальных аргументов"
+msgstr "Предупреждать о возможном перекрытии формальных аргументов."
 
 #: fortran/lang.opt:202
-#, fuzzy
-#| msgid "Warn about alignment of COMMON blocks"
 msgid "Warn about alignment of COMMON blocks."
-msgstr "Предупреждать о выравнивании COMMON блоков"
+msgstr "Предупреждать о выравнивании COMMON блоков."
 
 #: fortran/lang.opt:206
-#, fuzzy
-#| msgid "Warn about missing ampersand in continued character constants"
 msgid "Warn about missing ampersand in continued character constants."
-msgstr "Предупреждать об отсутствующих знаках & в строковых константах с продолжением"
+msgstr "Предупреждать об отсутствующих знаках & в строковых константах с продолжением."
 
 #: fortran/lang.opt:210
-#, fuzzy
-#| msgid "Warn about creation of array temporaries"
 msgid "Warn about creation of array temporaries."
-msgstr "Предупреждать о создании временных массивов"
+msgstr "Предупреждать о создании временных массивов."
 
 #: fortran/lang.opt:214
 msgid "Warn about type and rank mismatches between arguments and parameters."
-msgstr ""
+msgstr "Предупреждать о несоответствии типа и размерности между формальными и фактическими параметрами."
 
 #: fortran/lang.opt:218
 msgid "Warn if the type of a variable might be not interoperable with C."
-msgstr ""
+msgstr "Предупреждать, если тип переменной, возможно, не совместим с Си."
 
 #: fortran/lang.opt:226
-#, fuzzy
-#| msgid "Warn about truncated character expressions"
 msgid "Warn about truncated character expressions."
-msgstr "Предупреждать об усеченных строковых выражениях"
+msgstr "Предупреждать об усеченных строковых выражениях."
 
 #: fortran/lang.opt:230
 msgid "Warn about equality comparisons involving REAL or COMPLEX expressions."
-msgstr ""
+msgstr "Предупреждать о сравнении на равенство с участием REAL или COMPLEX выражений."
 
 #: fortran/lang.opt:238
-#, fuzzy
-#| msgid "Warn about most implicit conversions"
 msgid "Warn about most implicit conversions."
-msgstr "Предупреждать о неявных преобразованиях"
+msgstr "Предупреждать о неявных преобразованиях."
 
 #
 #: fortran/lang.opt:242
-#, fuzzy
-#| msgid "Warn about possibly confusing type conversions"
 msgid "Warn about possibly incorrect subscripts in do loops."
-msgstr "Предупреждать о возможно спутанных преобразованиях типов"
+msgstr ""
 
 #: fortran/lang.opt:250
 msgid "Warn if loops have been interchanged."
@@ -6252,100 +5881,68 @@
 msgstr ""
 
 #: fortran/lang.opt:254
-#, fuzzy
-#| msgid "Warn about function call elimination"
 msgid "Warn about function call elimination."
-msgstr "Предупреждать об удалении вызовов функций"
+msgstr "Предупреждать об удалении вызовов функций."
 
 #: fortran/lang.opt:258
-#, fuzzy
-#| msgid "Warn about calls with implicit interface"
 msgid "Warn about calls with implicit interface."
-msgstr "Предупреждать о вызовах с неявным интерфейсом"
+msgstr "Предупреждать о вызовах с неявным интерфейсом."
 
 #: fortran/lang.opt:262
-#, fuzzy
-#| msgid "Warn about called procedures not explicitly declared"
 msgid "Warn about called procedures not explicitly declared."
-msgstr "Предупреждать о вызовах функций, не продекларированных явно"
+msgstr "Предупреждать о вызовах функций, не продекларированных явно."
 
 #: fortran/lang.opt:266
-#, fuzzy
-#| msgid "Warn about compile-time integer division by zero"
 msgid "Warn about constant integer divisions with truncated results."
-msgstr "Предупреждать о целочисленном делении на ноль при вычислениях времени компиляции"
+msgstr "Предупреждать о делениях целых констант с усеченными результатами."
 
 #: fortran/lang.opt:270
-#, fuzzy
-#| msgid "Warn about truncated source lines"
 msgid "Warn about truncated source lines."
-msgstr "Предупреждать об усеченных строках исходного кода"
+msgstr "Предупреждать об усеченных строках исходного кода."
 
 #: fortran/lang.opt:274
-#, fuzzy
-#| msgid "Warn on intrinsics not part of the selected standard"
 msgid "Warn on intrinsics not part of the selected standard."
-msgstr "Предупреждать о встроенных функциях, не входящих в заданный стандарт языка"
+msgstr "Предупреждать о встроенных функциях, не входящих в заданный стандарт языка."
 
 #: fortran/lang.opt:286
-#, fuzzy
-#| msgid "Warn about format strings that are not literals"
 msgid "Warn about USE statements that have no ONLY qualifier."
-msgstr "Предупреждать о форматных строках, не являющихся литералами"
+msgstr "Предупреждать о USE операторах, которые не имеют ONLY квалификатор."
 
 #: fortran/lang.opt:298
-#, fuzzy
-#| msgid "Warn about real-literal-constants with 'q' exponent-letter"
 msgid "Warn about real-literal-constants with 'q' exponent-letter."
-msgstr "Предупреждать о вещественных константах с экспонентой, заданной буквой 'q'"
+msgstr "Предупреждать о вещественных константах с экспонентой, заданной буквой 'q'."
 
 #: fortran/lang.opt:302
-#, fuzzy
-#| msgid "Warn when a register variable is declared volatile"
 msgid "Warn when a left-hand-side array variable is reallocated."
-msgstr "Предупреждать о регистровых переменных, объявленных volatile"
+msgstr "Предупреждать, когда массивная переменная в левой части переразмещается."
 
 #: fortran/lang.opt:306
-#, fuzzy
-#| msgid "Warn when a register variable is declared volatile"
 msgid "Warn when a left-hand-side variable is reallocated."
-msgstr "Предупреждать о регистровых переменных, объявленных volatile"
+msgstr "Предупреждать, когда переменная в левой части переразмещается."
 
 #: fortran/lang.opt:310
-#, fuzzy
-#| msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgid "Warn if the pointer in a pointer assignment might outlive its target."
-msgstr "Целевое выражение в присваивании указателя в %L должна выдавать указательный результат"
+msgstr "Предупреждать, если указатель в указательном присваивании может пережить свою цель."
 
 #: fortran/lang.opt:318
-#, fuzzy
-#| msgid "Warn about \"suspicious\" constructs"
 msgid "Warn about \"suspicious\" constructs."
-msgstr "Предупреждать о \"подозрительных\" конструкциях"
+msgstr "Предупреждать о \"подозрительных\" конструкциях."
 
 #: fortran/lang.opt:322
-#, fuzzy
-#| msgid "Permit nonconforming uses of the tab character"
 msgid "Permit nonconforming uses of the tab character."
-msgstr "Разрешить неправильное употребление символов табуляции"
+msgstr "Разрешить неправильное употребление символов табуляции."
 
 #: fortran/lang.opt:326
-#, fuzzy
-#| msgid "Warn about zero-length formats"
 msgid "Warn about an invalid DO loop."
-msgstr "Предупреждать о форматных строках нулевой длины"
+msgstr "Предупреждать о некорректном DO цикле."
 
 #: fortran/lang.opt:330
-#, fuzzy
-#| msgid "Warn about underflow of numerical constant expressions"
 msgid "Warn about underflow of numerical constant expressions."
-msgstr "Предупреждать о недополнении при вычислении константных выражений"
+msgstr "Предупреждать о недополнении при вычислении константных выражений."
 
 #: fortran/lang.opt:338
-#, fuzzy
-#| msgid "Warn if a user-procedure has the same name as an intrinsic"
 msgid "Warn if a user-procedure has the same name as an intrinsic."
-msgstr "Предупреждать о пользовательских процедурах с именами, совпадающими с именами встроенных процедур"
+msgstr "Предупреждать о пользовательских процедурах с именами, совпадающими с именами встроенных процедур."
 
 #: fortran/lang.opt:346
 msgid "Warn about unused dummy arguments."
@@ -6352,265 +5949,188 @@
 msgstr "Предупреждать о неиспользуемых формальных аргументах"
 
 #: fortran/lang.opt:350
-#, fuzzy
-#| msgid "Warn about zero-length formats"
 msgid "Warn about zero-trip DO loops."
-msgstr "Предупреждать о форматных строках нулевой длины"
+msgstr "Предупреждать о выполняющихся ноль раз DO циклах."
 
 #: fortran/lang.opt:354
-#, fuzzy
-#| msgid "Enable preprocessing"
 msgid "Enable preprocessing."
-msgstr "Включить препроцессирование"
+msgstr "Включить препроцессирование."
 
 #: fortran/lang.opt:362
-#, fuzzy
-#| msgid "Disable preprocessing"
 msgid "Disable preprocessing."
-msgstr "Отключить препроцессирование"
+msgstr "Отключить препроцессирование."
 
 #: fortran/lang.opt:370
-#, fuzzy
-#| msgid "Eliminate multiple function invokations also for impure functions"
 msgid "Eliminate multiple function invocations also for impure functions."
-msgstr "Исключить повторные вызовы также для не-pure функций"
+msgstr "Исключить повторные вызовы также для не-pure функций."
 
 #: fortran/lang.opt:374
-#, fuzzy
-#| msgid "Enable alignment of COMMON blocks"
 msgid "Enable alignment of COMMON blocks."
-msgstr "Включить выравнивание COMMON блоков"
+msgstr "Включить выравнивание COMMON блоков."
 
 #: fortran/lang.opt:378
-#, fuzzy
-#| msgid "All intrinsics procedures are available regardless of selected standard"
 msgid "All intrinsics procedures are available regardless of selected standard."
-msgstr "Считать, что доступны все встроенные процедуры, независимо от выбранного стандарта"
+msgstr "Считать, что доступны все встроенные процедуры, независимо от выбранного стандарта."
 
 #: fortran/lang.opt:386
-#, fuzzy
-#| msgid "Do not treat local variables and COMMON blocks as if they were named in SAVE statements"
 msgid "Do not treat local variables and COMMON blocks as if they were named in SAVE statements."
-msgstr "Не трактовать локальные переменные и COMMON блоки как если бы они были перечислены в операторах SAVE"
+msgstr "Не трактовать локальные переменные и COMMON блоки как если бы они были перечислены в операторах SAVE."
 
 #: fortran/lang.opt:390
-#, fuzzy
-#| msgid "Specify that backslash in string introduces an escape character"
 msgid "Specify that backslash in string introduces an escape character."
-msgstr "Использовать обратный слеш в строках как символ экранирования"
+msgstr "Использовать обратный слеш в строках как символ экранирования."
 
 #: fortran/lang.opt:394
-#, fuzzy
-#| msgid "Produce a backtrace when a runtime error is encountered"
 msgid "Produce a backtrace when a runtime error is encountered."
-msgstr "При ошибках выполнения выводить последовательность вызовов"
+msgstr "При ошибках выполнения выводить последовательность вызовов."
 
 #: fortran/lang.opt:398
-#, fuzzy
-#| msgid "-fblas-matmul-limit=<n>\tSize of the smallest matrix for which matmul will use BLAS"
 msgid "-fblas-matmul-limit=<n>\tSize of the smallest matrix for which matmul will use BLAS."
-msgstr "-fblas-matmul-limit=<n>\tРазмер минимальной матрицы, для которой matmul будет использовать BLAS"
+msgstr "-fblas-matmul-limit=<n>\tРазмер минимальной матрицы, для которой matmul будет использовать BLAS."
 
 #: fortran/lang.opt:402
-#, fuzzy
-#| msgid "Produce a warning at runtime if a array temporary has been created for a procedure argument"
 msgid "Produce a warning at runtime if a array temporary has been created for a procedure argument."
-msgstr "Генерировать runtime-предупреждение, если для аргумента процедуры был создан временный массив"
+msgstr "Генерировать runtime-предупреждение, если для аргумента процедуры был создан временный массив."
 
 #: fortran/lang.opt:406
 msgid "-fconvert=<big-endian|little-endian|native|swap> The endianness used for unformatted files."
-msgstr ""
+msgstr "-fconvert=<big-endian|little-endian|native|swap> Порядок байт, используемый для неформатированных файлов."
 
 #: fortran/lang.opt:409
-#, fuzzy, c-format
-#| msgid "Unrecognized option to -finit-real: %s"
+#, c-format
 msgid "Unrecognized option to endianness value: %qs"
-msgstr "Неопознанная опция для -finit-real: %s"
+msgstr "Неопознанная опция для порядка байт: %qs"
 
 #: fortran/lang.opt:425
-#, fuzzy
-#| msgid "Use the Cray Pointer extension"
 msgid "Use the Cray Pointer extension."
-msgstr "Использовать расширение указателей Cray"
+msgstr "Использовать Cray Pointer расширение."
 
 #: fortran/lang.opt:429
-#, fuzzy
-#| msgid "Warn about unprototyped function declarations"
 msgid "Generate C prototypes from BIND(C) declarations."
-msgstr "Предупреждать о непрототипных декларациях функций"
+msgstr ""
 
 #: fortran/lang.opt:433
-#, fuzzy
-#| msgid "Ignore 'D' in column one in fixed form"
 msgid "Ignore 'D' in column one in fixed form."
-msgstr "Игнорировать 'D' в первой колонке в фиксированном формате"
+msgstr "Игнорировать 'D' в первой колонке в фиксированном формате."
 
 #: fortran/lang.opt:437
-#, fuzzy
-#| msgid "Treat lines with 'D' in column one as comments"
 msgid "Treat lines with 'D' in column one as comments."
-msgstr "Трактовать строки с 'D' в первой колонке как комментарии"
+msgstr "Трактовать строки с 'D' в первой колонке как комментарии."
 
 #: fortran/lang.opt:441
-#, fuzzy
-#| msgid "Enable Plan 9 language extensions"
 msgid "Enable all DEC language extensions."
-msgstr "Включить расширения языка Plan 9"
+msgstr "Включить все DEC расширения языка."
 
 #: fortran/lang.opt:445
 msgid "Enable kind-specific variants of integer intrinsic functions."
-msgstr ""
+msgstr "Включить kind-специфичные варианты целочисленных встроенных функций."
 
 #: fortran/lang.opt:449
 msgid "Enable legacy math intrinsics for compatibility."
-msgstr ""
+msgstr "Включить унаследованные математические встроенные функции для совместимости."
 
 #: fortran/lang.opt:453
-#, fuzzy
-#| msgid "Enable support for huge objects"
 msgid "Enable support for DEC STRUCTURE/RECORD."
-msgstr "Включить поддержку больших объектов"
+msgstr "Включить поддержку для DEC STRUCTURE/RECORD."
 
 #: fortran/lang.opt:457
 msgid "Enable DEC-style STATIC and AUTOMATIC attributes."
-msgstr ""
+msgstr "Включить DEC-стиль атрибутов STATIC и AUTOMATIC"
 
 #: fortran/lang.opt:461
-#, fuzzy
-#| msgid "Set the default double precision kind to an 8 byte wide type"
 msgid "Set the default double precision kind to an 8 byte wide type."
-msgstr "Установить по умолчанию размер 8 байт для типов double precision"
+msgstr "Установить подразумеваемый вид двойной точности в тип широкий 8-байт."
 
 #: fortran/lang.opt:465
-#, fuzzy
-#| msgid "Set the default integer kind to an 8 byte wide type"
 msgid "Set the default integer kind to an 8 byte wide type."
-msgstr "Установить по умолчанию размер 8 байт для целочисленных типов"
+msgstr "Установить по умолчанию размер 8 байт для целочисленных типов."
 
 #: fortran/lang.opt:469
-#, fuzzy
-#| msgid "Set the default real kind to an 8 byte wide type"
 msgid "Set the default real kind to an 8 byte wide type."
-msgstr "Установить по умолчанию размер 8 байт для типов real"
+msgstr "Установить по умолчанию размер 8 байт для типов real."
 
 #: fortran/lang.opt:473
-#, fuzzy
-#| msgid "Set the default real kind to an 8 byte wide type"
 msgid "Set the default real kind to an 10 byte wide type."
-msgstr "Установить по умолчанию размер 8 байт для типов real"
+msgstr "Установить по умолчанию размер 10 байт для типов real."
 
 #: fortran/lang.opt:477
-#, fuzzy
-#| msgid "Set the default real kind to an 8 byte wide type"
 msgid "Set the default real kind to an 16 byte wide type."
-msgstr "Установить по умолчанию размер 8 байт для типов real"
+msgstr "Установить по умолчанию размер 16 байт для типов real."
 
 #: fortran/lang.opt:481
-#, fuzzy
-#| msgid "Allow dollar signs in entity names"
 msgid "Allow dollar signs in entity names."
-msgstr "Разрешить использование символа $ в именах"
+msgstr "Разрешить использование символа $ в именах."
 
-#: fortran/lang.opt:485 config/alpha/alpha.opt:31 common.opt:783
-#: common.opt:985 common.opt:989 common.opt:993 common.opt:997 common.opt:1532
-#: common.opt:1588 common.opt:1712 common.opt:1716 common.opt:1946
-#: common.opt:2116 common.opt:2792
+#: fortran/lang.opt:485 config/alpha/alpha.opt:31 common.opt:649
+#: common.opt:783 common.opt:989 common.opt:993 common.opt:997 common.opt:1001
+#: common.opt:1536 common.opt:1592 common.opt:1716 common.opt:1720
+#: common.opt:1950 common.opt:2120 common.opt:2796
 msgid "Does nothing. Preserved for backward compatibility."
-msgstr "Игнорируется. Сохранен для обратной совместимости."
+msgstr "Ничего не делает. Сохранён для обратной совместимости."
 
 #: fortran/lang.opt:489
-#, fuzzy
-#| msgid "Display the code tree after parsing"
 msgid "Display the code tree after parsing."
-msgstr "Показать дерево кода после синтаксического разбора"
+msgstr "Показать дерево кода после синтаксического разбора."
 
 #: fortran/lang.opt:493
-#, fuzzy
-#| msgid "Display the code tree after front end optimization"
 msgid "Display the code tree after front end optimization."
-msgstr "Показать дерево кода после front end оптимизации"
+msgstr "Показать дерево кода после front end оптимизации."
 
 #: fortran/lang.opt:497
-#, fuzzy
-#| msgid "Display the code tree after parsing; deprecated option"
 msgid "Display the code tree after parsing; deprecated option."
-msgstr "Показать дерево кода после синтаксического разбора; устаревший ключ"
+msgstr "Показать дерево кода после синтаксического разбора; устаревший ключ."
 
 #: fortran/lang.opt:501
-#, fuzzy
-#| msgid "Specify that an external BLAS library should be used for matmul calls on large-size arrays"
 msgid "Specify that an external BLAS library should be used for matmul calls on large-size arrays."
-msgstr "Задать использование внешней библиотеки BLAS для вызовов matmul для больших массивов"
+msgstr "Задать использование внешней библиотеки BLAS для вызовов matmul для больших массивов."
 
 #: fortran/lang.opt:505
-#, fuzzy
-#| msgid "Use f2c calling convention"
 msgid "Use f2c calling convention."
-msgstr "Использовать f2c соглашения о вызовах"
+msgstr "Использовать f2c соглашения о вызовах."
 
 #: fortran/lang.opt:509
-#, fuzzy
-#| msgid "Assume that the source file is fixed form"
 msgid "Assume that the source file is fixed form."
-msgstr "Считать, что входной файл имеет фиксированный формат"
+msgstr "Считать, что входной файл имеет фиксированный формат."
 
 #: fortran/lang.opt:513
 msgid "Force creation of temporary to test infrequently-executed forall code."
-msgstr ""
+msgstr "Создавать временный объект для проверки нечасто выполняемого forall кода."
 
 #: fortran/lang.opt:517
-#, fuzzy
-#| msgid "Interpret any INTEGER(4) as an INTEGER(8)"
 msgid "Interpret any INTEGER(4) as an INTEGER(8)."
-msgstr "Трактовать INTEGER(4) как INTEGER(8)"
+msgstr "Трактовать INTEGER(4) как INTEGER(8)."
 
 #: fortran/lang.opt:521 fortran/lang.opt:525
-#, fuzzy
-#| msgid "Specify where to find the compiled intrinsic modules"
 msgid "Specify where to find the compiled intrinsic modules."
-msgstr "Указать расположение скомпилированных модулей со встроенными процедурами"
+msgstr "Указать расположение скомпилированных модулей со встроенными процедурами."
 
 #: fortran/lang.opt:529
-#, fuzzy
-#| msgid "Allow arbitrary character line width in fixed mode"
 msgid "Allow arbitrary character line width in fixed mode."
-msgstr "Разрешить произвольную ширину строк в фиксированном формате"
+msgstr "Разрешить произвольную ширину строк в фиксированном формате."
 
 #: fortran/lang.opt:533
-#, fuzzy
-#| msgid "-ffixed-line-length-<n>\tUse n as character line width in fixed mode"
 msgid "-ffixed-line-length-<n>\tUse n as character line width in fixed mode."
-msgstr "-ffixed-line-length-<n>\tИспользовать n как ширину строки в фиксированной форме"
+msgstr "-ffixed-line-length-<n>\tИспользовать n как ширину строки в фиксированной форме."
 
 #: fortran/lang.opt:537
-#, fuzzy
-#| msgid "-ffpe-trap=[...]\tStop on following floating point exceptions"
 msgid "-ffpe-trap=[...]\tStop on following floating point exceptions."
-msgstr "-ffpe-trap=[...]\tОстановиться при указанном исключении плавающей арифметики"
+msgstr "-ffpe-trap=[...]\tОстановиться при указанном исключении плавающей арифметики."
 
 #: fortran/lang.opt:541
-#, fuzzy
-#| msgid "-ffpe-trap=[...]\tStop on following floating point exceptions"
 msgid "-ffpe-summary=[...]\tPrint summary of floating point exceptions."
-msgstr "-ffpe-trap=[...]\tОстановиться при указанном исключении плавающей арифметики"
+msgstr "-ffpe-summary=[...]\tПечатать сводку исключении плавающей арифметики."
 
 #: fortran/lang.opt:545
-#, fuzzy
-#| msgid "Assume that the source file is free form"
 msgid "Assume that the source file is free form."
-msgstr "Считать, что исходный файл имеет свободную форму"
+msgstr "Считать, что исходный файл имеет свободную форму."
 
 #: fortran/lang.opt:549
-#, fuzzy
-#| msgid "Allow arbitrary character line width in free mode"
 msgid "Allow arbitrary character line width in free mode."
-msgstr "Допускать произвольную ширину строки в свободной форме"
+msgstr "Допускать произвольную ширину строки в свободной форме."
 
 #: fortran/lang.opt:553
-#, fuzzy
-#| msgid "-ffree-line-length-<n>\tUse n as character line width in free mode"
 msgid "-ffree-line-length-<n>\tUse n as character line width in free mode."
-msgstr "-ffree-line-length-<n>\tИспользовать n как ширину строки в свободной форме"
+msgstr "-ffree-line-length-<n>\tИспользовать n как ширину строки в свободной форме."
 
 #: fortran/lang.opt:557
 msgid "Try to interchange loops if profitable."
@@ -6617,86 +6137,61 @@
 msgstr ""
 
 #: fortran/lang.opt:561
-#, fuzzy
-#| msgid "Enable front end optimization"
 msgid "Enable front end optimization."
-msgstr "Включить оптимизации переднего плана"
+msgstr "Включить оптимизации переднего плана."
 
 #: fortran/lang.opt:565
-#, fuzzy
-#| msgid "Specify that no implicit typing is allowed, unless overridden by explicit IMPLICIT statements"
 msgid "Specify that no implicit typing is allowed, unless overridden by explicit IMPLICIT statements."
-msgstr "Запретить неявное определение типов, если не заданы явно операторы IMPLICIT"
+msgstr "Запретить неявное определение типов, если не заданы явно операторы IMPLICIT."
 
 #: fortran/lang.opt:569
-#, fuzzy
-#| msgid "-finit-character=<n>\tInitialize local character variables to ASCII value n"
 msgid "-finit-character=<n>\tInitialize local character variables to ASCII value n."
-msgstr "-finit-character=<n>\tИнициализировать локальные символьные переменные ASCII значением n"
+msgstr "-finit-character=<n>\tИнициализировать локальные символьные переменные ASCII значением n."
 
 #: fortran/lang.opt:573
 msgid "Initialize components of derived type variables according to other init flags."
-msgstr ""
+msgstr "Инициализировать компоненты переменных производного типа в соответствии с другими флагами инициализации."
 
 #: fortran/lang.opt:577
-#, fuzzy
-#| msgid "-finit-integer=<n>\tInitialize local integer variables to n"
 msgid "-finit-integer=<n>\tInitialize local integer variables to n."
-msgstr "-finit-integer=<n>\tИнициализировать локальные целые переменные значением n"
+msgstr "-finit-integer=<n>\tИнициализировать локальные целые переменные значением n."
 
 #: fortran/lang.opt:581
-#, fuzzy
-#| msgid "Initialize local variables to zero (from g77)"
 msgid "Initialize local variables to zero (from g77)."
-msgstr "Инициализировать локальные переменные нулем (как в g77)"
+msgstr "Инициализировать локальные переменные нулем (как в g77)."
 
 #: fortran/lang.opt:585
-#, fuzzy
-#| msgid "-finit-logical=<true|false>\tInitialize local logical variables"
 msgid "-finit-logical=<true|false>\tInitialize local logical variables."
-msgstr "-finit-logical=<true|false>\tИнициализировать локальные логические переменные"
+msgstr "-finit-logical=<true|false>\tИнициализировать локальные логические переменные."
 
 #: fortran/lang.opt:589
-#, fuzzy
-#| msgid "-finit-real=<zero|nan|inf|-inf>\tInitialize local real variables"
 msgid "-finit-real=<zero|snan|nan|inf|-inf>\tInitialize local real variables."
-msgstr "-finit-real=<zero|nan|inf|-inf>\tИнициализировать локальные вещественные переменные"
+msgstr "-finit-real=<zero|snan|nan|inf|-inf>\tИнициализировать локальные вещественные переменные."
 
 #: fortran/lang.opt:592
-#, fuzzy, c-format
-#| msgid "Unrecognized option to -finit-real: %s"
+#, c-format
 msgid "Unrecognized option to floating-point init value: %qs"
-msgstr "Неопознанная опция для -finit-real: %s"
+msgstr "Неопознанная опция для начального значения с плавающей точкой: %qs"
 
 #: fortran/lang.opt:611
-#, fuzzy
-#| msgid "-fblas-matmul-limit=<n>\tSize of the smallest matrix for which matmul will use BLAS"
 msgid "-finline-matmul-limit=<n>\tSpecify the size of the largest matrix for which matmul will be inlined."
-msgstr "-fblas-matmul-limit=<n>\tРазмер минимальной матрицы, для которой matmul будет использовать BLAS"
+msgstr "-finline-matmul-limit=<n>\tЗадать размер наибольшей матрицы, для которой matmul будет включенным."
 
 #: fortran/lang.opt:615
-#, fuzzy
-#| msgid "-fmax-array-constructor=<n>\tMaximum number of objects in an array constructor"
 msgid "-fmax-array-constructor=<n>\tMaximum number of objects in an array constructor."
-msgstr "-fmax-array-constructor=<n>\tМаксимальное число объектов в конструкторе массива"
+msgstr "-fmax-array-constructor=<n>\tМаксимальное число объектов в конструкторе массива."
 
 #: fortran/lang.opt:619
-#, fuzzy
-#| msgid "-fmax-identifier-length=<n>\tMaximum identifier length"
 msgid "-fmax-identifier-length=<n>\tMaximum identifier length."
-msgstr "-fmax-identifier-length=<n>\tМаксимальная длина идентификатора"
+msgstr "-fmax-identifier-length=<n>\tМаксимальная длина идентификатора."
 
 #: fortran/lang.opt:623
-#, fuzzy
-#| msgid "-fmax-subrecord-length=<n>\tMaximum length for subrecords"
 msgid "-fmax-subrecord-length=<n>\tMaximum length for subrecords."
-msgstr "-fmax-subrecord-length=<n>\tМаксимальная длина субзаписей"
+msgstr "-fmax-subrecord-length=<n>\tМаксимальная длина субзаписей."
 
 #: fortran/lang.opt:627
-#, fuzzy
-#| msgid "-fmax-stack-var-size=<n>\tSize in bytes of the largest array that will be put on the stack"
 msgid "-fmax-stack-var-size=<n>\tSize in bytes of the largest array that will be put on the stack."
-msgstr "-fmax-stack-var-size=<n>\tРазмер в байтах максимального массива, размещаемого в стеке"
+msgstr "-fmax-stack-var-size=<n>\tРазмер в байтах максимального массива, размещаемого в стеке."
 
 #: fortran/lang.opt:631
 msgid "Put all local arrays on stack."
@@ -6707,182 +6202,127 @@
 msgstr "Установить PRIVATE как умолчание для атрибута доступности элементов модуля."
 
 #: fortran/lang.opt:655
-#, fuzzy
-#| msgid "Try to lay out derived types as compactly as possible"
 msgid "Try to lay out derived types as compactly as possible."
-msgstr "Использовать наиболее компактное представление производных типов"
+msgstr "Использовать наиболее компактное представление производных типов."
 
 #: fortran/lang.opt:663
-#, fuzzy
-#| msgid "Protect parentheses in expressions"
 msgid "Protect parentheses in expressions."
-msgstr "Защитить скобки в выражениях"
+msgstr "Защитить скобки в выражениях."
 
 #: fortran/lang.opt:667
-#, fuzzy
-#| msgid "Enable range checking during compilation"
 msgid "Enable range checking during compilation."
-msgstr "Включить проверку диапазонов при компиляции"
+msgstr "Включить проверку диапазонов при компиляции."
 
 #: fortran/lang.opt:671
-#, fuzzy
-#| msgid "Interpret any REAL(4) as a REAL(8)"
 msgid "Interpret any REAL(4) as a REAL(8)."
-msgstr "Трактовать REAL(4) как REAL(8)"
+msgstr "Трактовать REAL(4) как REAL(8)."
 
 #: fortran/lang.opt:675
-#, fuzzy
-#| msgid "Interpret any REAL(4) as a REAL(10)"
 msgid "Interpret any REAL(4) as a REAL(10)."
-msgstr "Трактовать REAL(4) как REAL(10)"
+msgstr "Трактовать REAL(4) как REAL(10)."
 
 #: fortran/lang.opt:679
-#, fuzzy
-#| msgid "Interpret any REAL(4) as a REAL(16)"
 msgid "Interpret any REAL(4) as a REAL(16)."
-msgstr "Трактовать REAL(4) как REAL(16)"
+msgstr "Трактовать REAL(4) как REAL(16)."
 
 #: fortran/lang.opt:683
-#, fuzzy
-#| msgid "Interpret any REAL(8) as a REAL(4)"
 msgid "Interpret any REAL(8) as a REAL(4)."
-msgstr "Трактовать REAL(8) как REAL(4)"
+msgstr "Трактовать REAL(8) как REAL(4)."
 
 #: fortran/lang.opt:687
-#, fuzzy
-#| msgid "Interpret any REAL(8) as a REAL(10)"
 msgid "Interpret any REAL(8) as a REAL(10)."
-msgstr "Трактовать REAL(8) как REAL(10)"
+msgstr "Трактовать REAL(8) как REAL(10)."
 
 #: fortran/lang.opt:691
-#, fuzzy
-#| msgid "Interpret any REAL(8) as a REAL(16)"
 msgid "Interpret any REAL(8) as a REAL(16)."
-msgstr "Трактовать REAL(8) как REAL(16)"
+msgstr "Трактовать REAL(8) как REAL(16)."
 
 #: fortran/lang.opt:695
-#, fuzzy
-#| msgid "Reallocate the LHS in assignments"
 msgid "Reallocate the LHS in assignments."
-msgstr "Выделять память заново для левых частей присваиваний"
+msgstr "Выделять память заново для левых частей присваиваний."
 
 #: fortran/lang.opt:699
-#, fuzzy
-#| msgid "Use a 4-byte record marker for unformatted files"
 msgid "Use a 4-byte record marker for unformatted files."
-msgstr "Использовать 4-байтный маркер записей в неформатированных файлах"
+msgstr "Использовать 4-байтный маркер записей в неформатированных файлах."
 
 #: fortran/lang.opt:703
-#, fuzzy
-#| msgid "Use an 8-byte record marker for unformatted files"
 msgid "Use an 8-byte record marker for unformatted files."
-msgstr "Использовать 8-байтный маркер записей в неформатированных файлах"
+msgstr "Использовать 8-байтный маркер записей в неформатированных файлах."
 
 #: fortran/lang.opt:707
-#, fuzzy
-#| msgid "Allocate local variables on the stack to allow indirect recursion"
 msgid "Allocate local variables on the stack to allow indirect recursion."
-msgstr "Размещать локальные переменные в стеке для поддержки неявной рекурсии"
+msgstr "Размещать локальные переменные в стеке для поддержки неявной рекурсии."
 
 #: fortran/lang.opt:711
-#, fuzzy
-#| msgid "Copy array sections into a contiguous block on procedure entry"
 msgid "Copy array sections into a contiguous block on procedure entry."
-msgstr "При входе в процедуру копировать секции массивов в последовательный блок"
+msgstr "При входе в процедуру копировать секции массивов в последовательный блок."
 
 #: fortran/lang.opt:715
-#, fuzzy
-#| msgid "-fcoarray=[...]\tSpecify which coarray parallelization should be used"
 msgid "-fcoarray=<none|single|lib>\tSpecify which coarray parallelization should be used."
-msgstr "-fcoarray=[...]\tЗадать способ coarray распараллеливания"
+msgstr "-fcoarray=<none|single|lib>\tЗадать, какое распараллеливание комассивов должно использоваться."
 
 #: fortran/lang.opt:718
-#, fuzzy, c-format
-#| msgid "unrecognized option %<-%s%>"
+#, c-format
 msgid "Unrecognized option: %qs"
-msgstr "неопознанный ключ %<-%s%>"
+msgstr "неопознанный ключ: %qs"
 
 #: fortran/lang.opt:731
-#, fuzzy
-#| msgid "-fcheck=[...]\tSpecify which runtime checks are to be performed"
 msgid "-fcheck=[...]\tSpecify which runtime checks are to be performed."
-msgstr "-fcheck=[...]\tЗадать набор runtime-проверок"
+msgstr "-fcheck=[...]\tЗадать набор runtime-проверок."
 
 #: fortran/lang.opt:735
-#, fuzzy
-#| msgid "Append a second underscore if the name already contains an underscore"
 msgid "Append a second underscore if the name already contains an underscore."
-msgstr "Добавлять второй символ подчеркивания к именам, уже содержащим подчеркивание"
+msgstr "Добавлять второй символ подчеркивания к именам, уже содержащим подчеркивание."
 
 #: fortran/lang.opt:743
-#, fuzzy
-#| msgid "Apply negative sign to zero values"
 msgid "Apply negative sign to zero values."
-msgstr "Применять знак минус к нулевым значениям"
+msgstr "Применять знак минус к нулевым значениям."
 
 #: fortran/lang.opt:747
-#, fuzzy
-#| msgid "Append underscores to externally visible names"
 msgid "Append underscores to externally visible names."
-msgstr "Добавлять подчёркивания к доступным извне именам"
+msgstr "Добавлять подчёркивания к доступным извне именам."
 
 #: fortran/lang.opt:751 c-family/c.opt:1356 c-family/c.opt:1384
-#: c-family/c.opt:1634 config/pa/pa.opt:42 config/pa/pa.opt:70 common.opt:1154
-#: common.opt:1333 common.opt:1408 common.opt:1676 common.opt:1799
-#: common.opt:2169 common.opt:2205 common.opt:2298 common.opt:2302
-#: common.opt:2407 common.opt:2498 common.opt:2506 common.opt:2514
-#: common.opt:2522 common.opt:2623 common.opt:2675 common.opt:2755
-#: common.opt:2893 common.opt:2897 common.opt:2901 common.opt:2905
+#: c-family/c.opt:1634 config/pa/pa.opt:42 config/pa/pa.opt:70 common.opt:1158
+#: common.opt:1337 common.opt:1412 common.opt:1680 common.opt:1803
+#: common.opt:2173 common.opt:2209 common.opt:2302 common.opt:2306
+#: common.opt:2411 common.opt:2502 common.opt:2510 common.opt:2518
+#: common.opt:2526 common.opt:2627 common.opt:2679 common.opt:2759
+#: common.opt:2897 common.opt:2901 common.opt:2905 common.opt:2909
 msgid "Does nothing.  Preserved for backward compatibility."
-msgstr "Игнорируется. Сохранен для обратной совместимости"
+msgstr "Ничего не делает.  Сохранён для обратной совместимости."
 
 #: fortran/lang.opt:791
-#, fuzzy
-#| msgid "Statically link the GNU Fortran helper library (libgfortran)"
 msgid "Statically link the GNU Fortran helper library (libgfortran)."
-msgstr "Выполнить статическую компоновку с библиотекой GNU Fortran (libgfortran)"
+msgstr "Выполнить статическую компоновку с библиотекой GNU Fortran (libgfortran)."
 
 #: fortran/lang.opt:795
-#, fuzzy
-#| msgid "Conform to the ISO Fortran 2003 standard"
 msgid "Conform to the ISO Fortran 2003 standard."
-msgstr "Компилировать в соответствии со стандартом ISO Fortran 2003"
+msgstr "Компилировать в соответствии со стандартом ISO Fortran 2003."
 
 #: fortran/lang.opt:799
-#, fuzzy
-#| msgid "Conform to the ISO Fortran 2008 standard"
 msgid "Conform to the ISO Fortran 2008 standard."
-msgstr "Компилировать в соответствии со стандартом ISO Fortran 2008"
+msgstr "Компилировать в соответствии со стандартом ISO Fortran 2008."
 
 #: fortran/lang.opt:803
-#, fuzzy
-#| msgid "Conform to the ISO Fortran 2008 standard including TS 29113"
 msgid "Conform to the ISO Fortran 2008 standard including TS 29113."
-msgstr "Компилировать в соответствии со стандартом ISO Fortran 2008, включая TS 29113"
+msgstr "Компилировать в соответствии со стандартом ISO Fortran 2008, включая TS 29113."
 
 #: fortran/lang.opt:807
-#, fuzzy
-#| msgid "Conform to the ISO Fortran 2008 standard"
 msgid "Conform to the ISO Fortran 2018 standard."
-msgstr "Компилировать в соответствии со стандартом ISO Fortran 2008"
+msgstr "Компилировать в соответствии со стандартом ISO Fortran 2018."
 
 #: fortran/lang.opt:811
-#, fuzzy
-#| msgid "Conform to the ISO Fortran 95 standard"
 msgid "Conform to the ISO Fortran 95 standard."
-msgstr "Компилировать в соответствии со стандартом ISO Fortran 95"
+msgstr "Компилировать в соответствии со стандартом ISO Fortran 95."
 
 #: fortran/lang.opt:815
-#, fuzzy
-#| msgid "Conform to nothing in particular"
 msgid "Conform to nothing in particular."
-msgstr "Не соответствует ничему конкретному"
+msgstr "Не соответствует ничему конкретному."
 
 #: fortran/lang.opt:819
-#, fuzzy
-#| msgid "Accept extensions to support legacy code"
 msgid "Accept extensions to support legacy code."
-msgstr "Принимать расширения для поддержки унаследованного кода"
+msgstr "Принимать расширения для поддержки унаследованного кода."
 
 #: c-family/c.opt:43 c-family/c.opt:46 c-family/c.opt:181
 #, c-format
@@ -6898,7 +6338,7 @@
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:220 c-family/c.opt:224
 #: c-family/c.opt:236 c-family/c.opt:1855 c-family/c.opt:1863 brig/lang.opt:39
-#: config/darwin.opt:56 common.opt:338 common.opt:341 common.opt:3046
+#: config/darwin.opt:56 common.opt:338 common.opt:341 common.opt:3050
 #, c-format
 msgid "missing filename after %qs"
 msgstr "не задано имя файла после %qs"
@@ -6911,94 +6351,64 @@
 msgstr "не задан маршрут после %qs"
 
 #: c-family/c.opt:182
-#, fuzzy
-#| msgid "-A<question>=<answer>\tAssert the <answer> to <question>.  Putting '-' before <question> disables the <answer> to <question>"
 msgid "-A<question>=<answer>\tAssert the <answer> to <question>.  Putting '-' before <question> disables the <answer> to <question>."
-msgstr "-A<вопрос>=<ответ>\tЗадать <ответ> на <вопрос>. Добавление '-' перед <вопросом> отменяет <ответ> на <вопрос>"
+msgstr "-A<вопрос>=<ответ>                 Задать <ответ> на <вопрос>.  Добавление '-' перед <вопросом> отменяет <ответ> на <вопрос>."
 
 #: c-family/c.opt:186
-#, fuzzy
-#| msgid "Do not discard comments"
 msgid "Do not discard comments."
-msgstr "Не удалять комментарии"
+msgstr "Не удалять комментарии."
 
 #: c-family/c.opt:190
-#, fuzzy
-#| msgid "Do not discard comments in macro expansions"
 msgid "Do not discard comments in macro expansions."
-msgstr "Не удалять комментарии при макроподстановках"
+msgstr "Не удалять комментарии при макроподстановках."
 
 #: c-family/c.opt:194
-#, fuzzy
-#| msgid "-D<macro>[=<val>]\tDefine a <macro> with <val> as its value.  If just <macro> is given, <val> is taken to be 1"
 msgid "-D<macro>[=<val>]\tDefine a <macro> with <val> as its value.  If just <macro> is given, <val> is taken to be 1."
-msgstr "-D<макрос>[=<знач.>]\tОпределить <макрос> со значением <знач.>. Если задан только <макрос>, <знач.> считается равным 1"
+msgstr ""
 
 #: c-family/c.opt:201
-#, fuzzy
-#| msgid "-F <dir>\tAdd <dir> to the end of the main framework include path"
 msgid "-F <dir>\tAdd <dir> to the end of the main framework include path."
-msgstr "-F <каталог>\tДобавить <каталог> в конец основного пути поиска включаемых инфраструктур"
+msgstr "-F <каталог>\tДобавить <каталог> в конец основного пути поиска включаемых инфраструктур."
 
 #: c-family/c.opt:205
-#, fuzzy
-#| msgid "Enable preprocessing"
 msgid "Enable parsing GIMPLE."
-msgstr "Включить препроцессирование"
+msgstr "Включить разбор GIMPLE."
 
 #: c-family/c.opt:209
-#, fuzzy
-#| msgid "Print the name of header files as they are used"
 msgid "Print the name of header files as they are used."
-msgstr "Печатать имена используемых заголовочных файлов"
+msgstr "Печатать имена используемых заголовочных файлов."
 
 #: c-family/c.opt:213
-#, fuzzy
-#| msgid "-I <dir>\tAdd <dir> to the end of the main include path"
 msgid "-I <dir>\tAdd <dir> to the end of the main include path."
-msgstr "-I <каталог>\tДобавить <каталог> в конец основного пути поиска заголовков"
+msgstr "-I <каталог>\tДобавить <каталог> в конец основного пути поиска заголовков."
 
 #: c-family/c.opt:217
-#, fuzzy
-#| msgid "Generate make dependencies"
 msgid "Generate make dependencies."
-msgstr "Генерировать зависимости для make"
+msgstr "Генерировать зависимости для make."
 
 #: c-family/c.opt:221
-#, fuzzy
-#| msgid "Generate make dependencies and compile"
 msgid "Generate make dependencies and compile."
-msgstr "Генерировать make-зависимости и компилировать"
+msgstr "Генерировать make-зависимости и компилировать."
 
 #: c-family/c.opt:225
-#, fuzzy
-#| msgid "-MF <file>\tWrite dependency output to the given file"
 msgid "-MF <file>\tWrite dependency output to the given file."
-msgstr "-MF <файл>\tВывести зависимости в указанный <файл>"
+msgstr "-MF <файл>\tВывести зависимости в указанный <файл>."
 
 #: c-family/c.opt:229
-#, fuzzy
-#| msgid "Treat missing header files as generated files"
 msgid "Treat missing header files as generated files."
-msgstr "Трактовать отсутствующие заголовки как генерируемые файлы"
+msgstr "Трактовать отсутствующие заголовки как генерируемые файлы."
 
 #: c-family/c.opt:233
-#, fuzzy
-#| msgid "Like -M but ignore system header files"
 msgid "Like -M but ignore system header files."
-msgstr "Как -M, но игнорировать системные заголовки"
+msgstr "Как -M, но игнорировать системные заголовки."
 
 #: c-family/c.opt:237
-#, fuzzy
-#| msgid "Like -MD but ignore system header files"
 msgid "Like -MD but ignore system header files."
-msgstr "Как -MD, но игнорировать системные заголовки "
+msgstr "Как -MD, но игнорировать системные заголовки."
 
 #: c-family/c.opt:241
-#, fuzzy
-#| msgid "Generate phony targets for all headers"
 msgid "Generate phony targets for all headers."
-msgstr "Добавлять фиктивные правила для всех заголовочных файлов"
+msgstr "Добавлять фиктивные правила для всех заголовочных файлов."
 
 #: c-family/c.opt:244 c-family/c.opt:248
 #, c-format
@@ -7006,416 +6416,300 @@
 msgstr "не задана цель после %qs"
 
 #: c-family/c.opt:245
-#, fuzzy
-#| msgid "-MQ <target>\tAdd a MAKE-quoted target"
 msgid "-MQ <target>\tAdd a MAKE-quoted target."
-msgstr "-MQ <цель>\tДобавить экранированную MAKE-цель"
+msgstr "-MQ <цель>\tДобавить экранированную MAKE-цель."
 
 #: c-family/c.opt:249
-#, fuzzy
-#| msgid "-MT <target>\tAdd an unquoted target"
 msgid "-MT <target>\tAdd an unquoted target."
-msgstr "-MT <цель>\tДобавить неэкранированную MAKE-цель"
+msgstr "-MT <цель>\tДобавить неэкранированную MAKE-цель."
 
 #: c-family/c.opt:253
-#, fuzzy
-#| msgid "Do not generate #line directives"
 msgid "Do not generate #line directives."
-msgstr "Не генерировать директивы #строка"
+msgstr "Не генерировать директивы #строка."
 
 #: c-family/c.opt:257
-#, fuzzy
-#| msgid "-U<macro>\tUndefine <macro>"
 msgid "-U<macro>\tUndefine <macro>."
-msgstr "-U<макрос>\tОтменить определение макроса"
+msgstr "-U<макрос>\tОтменить определение макроса."
 
 #: c-family/c.opt:261
-#, fuzzy
-#| msgid "Warn about things that will change when compiling with an ABI-compliant compiler"
 msgid "Warn about things that will change when compiling with an ABI-compliant compiler."
-msgstr "Предупреждать о различиях по сравнению с компиляцией при помощи компилятора, совместимого с ABI"
+msgstr "Предупреждать о различиях по сравнению с компиляцией при помощи компилятора, совместимого с ABI."
 
 #: c-family/c.opt:265
 msgid "Warn about things that change between the current -fabi-version and the specified version."
-msgstr ""
+msgstr "Предупреждать о различиях между текущей -fabi-version и заданной версией ABI."
 
 #: c-family/c.opt:269
 msgid "Warn if a subobject has an abi_tag attribute that the complete object type does not have."
-msgstr ""
+msgstr "Предупреждать, если подобъект имеет атрибут abi_tag, которого не имеет весь объект."
 
 #: c-family/c.opt:276
-#, fuzzy
-#| msgid "Warn about suspicious uses of memory addresses"
 msgid "Warn about suspicious uses of memory addresses."
-msgstr "Предупреждать о подозрительных использованиях адресов памяти"
+msgstr "Предупреждать о подозрительных использованиях адресов памяти."
 
 #: c-family/c.opt:279
-#, fuzzy
-#| msgid "argument %qs to %<-Wnormalized%> not recognized"
 msgid "argument %qs to %<-Waligned-new%> not recognized"
-msgstr "некорректный аргумент %qs ключа %<-Wnormalized%>"
+msgstr "аргумент %qs ключа %<-Waligned-new%> не распознан"
 
 #: c-family/c.opt:292
 msgid "Warn about 'new' of type with extended alignment without -faligned-new."
-msgstr ""
+msgstr "Предупреждать об операторах new для типов с расширенным выравниванием, если не задано -faligned-new."
 
 #: c-family/c.opt:296
 msgid "-Waligned-new=[none|global|all]\tWarn even if 'new' uses a class member allocation function."
-msgstr ""
+msgstr "-Waligned-new=[none|global|all]\tПредупреждать даже если 'new' использует функцию для размещения членов класса."
 
 #: c-family/c.opt:300 ada/gcc-interface/lang.opt:57
-#, fuzzy
-#| msgid "Enable most warning messages"
 msgid "Enable most warning messages."
-msgstr "Включить все основные виды предупреждений"
+msgstr "Включить все основные виды предупреждений."
 
 #: c-family/c.opt:304
-#, fuzzy
-#| msgid "Warn about misuses of pragmas"
 msgid "Warn on any use of alloca."
-msgstr "Предупреждать о неправильном использовании прагм"
+msgstr "Предупреждать обо всех использованиях alloca."
 
 #: c-family/c.opt:308
 msgid "-Walloc-size-larger-than=<bytes> Warn for calls to allocation functions that attempt to allocate objects larger than the specified number of bytes."
-msgstr ""
+msgstr "-Walloc-size-larger-than=<bytes> Предупреждать о вызовах функций выделения памяти под объекты размером более указанного числа байт."
 
 #: c-family/c.opt:313
 msgid "-Walloc-zero Warn for calls to allocation functions that specify zero bytes."
-msgstr ""
+msgstr "-Walloc-zero Предупреждать о вызовах функций выделения памяти с размером 0 байт."
 
 #: c-family/c.opt:317
-#, fuzzy
-#| msgid "-Wlarger-than=<number>\tWarn if an object is larger than <number> bytes"
 msgid "-Walloca-larger-than=<number>\tWarn on unbounded uses of alloca, and on bounded uses of alloca whose bound can be larger than <number> bytes."
-msgstr "-Wlarger-than=<число>\tПредупреждать об объектах, размер которых превышает <число> байт"
+msgstr "-Walloca-larger-than=<число>\tПредупреждать об вызовах alloca для объектов неограниченного размера или размера более чем <число> байт."
 
 #: c-family/c.opt:331
-#, fuzzy
-#| msgid "Warn whenever an Objective-C assignment is being intercepted by the garbage collector"
 msgid "Warn whenever an Objective-C assignment is being intercepted by the garbage collector."
-msgstr "Предупреждать, если присваивание Objective-C прерывается сбором мусора"
+msgstr "Предупреждать, если присваивание Objective-C прерывается сбором мусора."
 
 #: c-family/c.opt:335
-#, fuzzy
-#| msgid "Warn about casting functions to incompatible types"
 msgid "Warn about casting functions to incompatible types."
-msgstr "Предупреждать о приведений функций к несовместимым типам"
+msgstr "Предупреждать о приведений функций к несовместимым типам."
 
 #: c-family/c.opt:339
 msgid "Warn about boolean expression compared with an integer value different from true/false."
-msgstr ""
+msgstr "Предупреждать о сравнении булева выражения с целым значением, отличным от true/false."
 
 #: c-family/c.opt:343
-#, fuzzy
-#| msgid "Warn about truncated character expressions"
 msgid "Warn about certain operations on boolean expressions."
-msgstr "Предупреждать об усеченных строковых выражениях"
+msgstr "Предупреждать о некоторых операциях над булевыми выражениями."
 
 #: c-family/c.opt:347
 msgid "Warn when __builtin_frame_address or __builtin_return_address is used unsafely."
-msgstr ""
+msgstr "Предупреждать о небезопасных использованиях __builtin_frame_address или __builtin_return_address."
 
 #: c-family/c.opt:351
-#, fuzzy
-#| msgid "Warn when an inlined function cannot be inlined"
 msgid "Warn when a built-in function is declared with the wrong signature."
-msgstr "Предупреждать об inline-функциях, подстановка которых невозможна"
+msgstr "Предупреждать, если встроенная функция декларируется с неправильной сигнатурой."
 
 #: c-family/c.opt:355
-#, fuzzy
-#| msgid "Warn when a built-in preprocessor macro is undefined or redefined"
 msgid "Warn when a built-in preprocessor macro is undefined or redefined."
-msgstr "Предупреждать о случаях переопределения или отмены встроенных макросов препроцессора"
+msgstr "Предупреждать о случаях переопределения или отмены встроенных макросов препроцессора."
 
 #: c-family/c.opt:359
-#, fuzzy
-#| msgid "Warn about features not present in traditional C"
 msgid "Warn about features not present in ISO C90, but present in ISO C99."
-msgstr "Предупреждать об использовании средств, отсутствующих в традиционном C"
+msgstr "Предупреждать об использовании средств, отсутствующих в ISO C90, но имеющихся в ISO C99."
 
 #: c-family/c.opt:363
-#, fuzzy
-#| msgid "Warn about features not present in traditional C"
 msgid "Warn about features not present in ISO C99, but present in ISO C11."
-msgstr "Предупреждать об использовании средств, отсутствующих в традиционном C"
+msgstr "Предупреждать об использовании средств, отсутствующих в ISO C99, но имеющихся в ISO C11."
 
 #: c-family/c.opt:367
-#, fuzzy
-#| msgid "Warn about C constructs that are not in the common subset of C and C++"
 msgid "Warn about C constructs that are not in the common subset of C and C++."
-msgstr "Предупреждать о конструкциях C, не являющихся общими для C и C++"
+msgstr "Предупреждать о конструкциях C, не являющихся общими для C и C++."
 
 #: c-family/c.opt:374
-#, fuzzy
-#| msgid "Warn about C++ constructs whose meaning differs between ISO C++ 1998 and ISO C++ 2011"
 msgid "Warn about C++ constructs whose meaning differs between ISO C++ 1998 and ISO C++ 2011."
-msgstr "Предупреждать о конструкциях C++, смысл которых различается в ISO C++ 1998 и ISO C++ 2011"
+msgstr "Предупреждать о конструкциях C++, смысл которых различается в ISO C++ 1998 и ISO C++ 2011."
 
 #: c-family/c.opt:378
-#, fuzzy
-#| msgid "Warn about C++ constructs whose meaning differs between ISO C++ 1998 and ISO C++ 2011"
 msgid "Warn about C++ constructs whose meaning differs between ISO C++ 2011 and ISO C++ 2014."
-msgstr "Предупреждать о конструкциях C++, смысл которых различается в ISO C++ 1998 и ISO C++ 2011"
+msgstr "Предупреждать о конструкциях C++, смысл которых различается в ISO C++ 2011 и ISO C++ 2014."
 
 #: c-family/c.opt:385
-#, fuzzy
-#| msgid "Warn about C++ constructs whose meaning differs between ISO C++ 1998 and ISO C++ 2011"
 msgid "Warn about C++ constructs whose meaning differs between ISO C++ 2014 and ISO C++ 2017."
-msgstr "Предупреждать о конструкциях C++, смысл которых различается в ISO C++ 1998 и ISO C++ 2011"
+msgstr ""
 
 #: c-family/c.opt:389
-#, fuzzy
-#| msgid "Warn about casting functions to incompatible types"
 msgid "Warn about casts between incompatible function types."
-msgstr "Предупреждать о приведений функций к несовместимым типам"
+msgstr ""
 
 #: c-family/c.opt:393
-#, fuzzy
-#| msgid "Warn about casts which discard qualifiers"
 msgid "Warn about casts which discard qualifiers."
-msgstr "Предупреждать о приведении типов, отменяющих квалификаторы"
+msgstr "Предупреждать о приведении типов, отменяющих квалификаторы."
 
 #: c-family/c.opt:397 c-family/c.opt:401
-#, fuzzy
-#| msgid "Warn about comparison of different enum types"
 msgid "Warn about catch handlers of non-reference type."
-msgstr "Предупреждать о сравнениях значений разных перечислимых типов"
+msgstr ""
 
 #: c-family/c.opt:405
-#, fuzzy
-#| msgid "Warn about subscripts whose type is \"char\""
 msgid "Warn about subscripts whose type is \"char\"."
-msgstr "Предупреждать об индексах типа \"char\""
+msgstr "Предупреждать об индексах типа \"char\"."
 
 #: c-family/c.opt:409
 msgid "Warn about memory access errors found by Pointer Bounds Checker."
-msgstr ""
+msgstr "Предупреждать об ошибках доступа к памяти, обнаруженных при помощи Pointer Bounds Checker."
 
 #: c-family/c.opt:413
-#, fuzzy
-#| msgid "Warn about variables that might be changed by \"longjmp\" or \"vfork\""
 msgid "Warn about variables that might be changed by \"longjmp\" or \"vfork\"."
-msgstr "Предупреждать о переменных, которые могут быть испорчены вызовами \"longjmp\" или \"vfork\""
+msgstr "Предупреждать о переменных, которые могут быть испорчены вызовами \"longjmp\" или \"vfork\"."
 
 #: c-family/c.opt:417
-#, fuzzy
-#| msgid "Warn about possibly nested block comments, and C++ comments spanning more than one physical line"
 msgid "Warn about possibly nested block comments, and C++ comments spanning more than one physical line."
-msgstr "Предупреждать о возможно вложенных комментариях и комментариях C++, продолжающихся на нескольких физических строках"
+msgstr "Предупреждать о возможно вложенных комментариях и комментариях C++, продолжающихся на нескольких физических строках."
 
 #: c-family/c.opt:421
-#, fuzzy
-#| msgid "Synonym for -Wcomment"
 msgid "Synonym for -Wcomment."
-msgstr "То же, что -Wcomment"
+msgstr "То же, что -Wcomment."
 
 #: c-family/c.opt:425
 msgid "Warn for conditionally-supported constructs."
-msgstr ""
+msgstr "Предупреждать об условно поддерживаемых конструкциях."
 
 #: c-family/c.opt:429
-#, fuzzy
-#| msgid "Warn for implicit type conversions that may change a value"
 msgid "Warn for implicit type conversions that may change a value."
-msgstr "Предупреждать, если неявное преобразование типа может изменить значение"
+msgstr "Предупреждать, если неявное преобразование типа может изменить значение."
 
 #: c-family/c.opt:433
-#, fuzzy
-#| msgid "Warn for converting NULL from/to a non-pointer type"
 msgid "Warn for converting NULL from/to a non-pointer type."
-msgstr "Предупреждать о преобразованиях NULL к неуказательному типу или из неуказательного к указательному"
+msgstr "Предупреждать о преобразованиях NULL к неуказательному типу или из неуказательного к указательному."
 
 #: c-family/c.opt:441
-#, fuzzy
-#| msgid "Warn when all constructors and destructors are private"
 msgid "Warn when all constructors and destructors are private."
-msgstr "Предупреждать о классах, в которых все конструкторы и деструкторы private"
+msgstr "Предупреждать о классах, в которых все конструкторы и деструкторы private."
 
 #: c-family/c.opt:445
-#, fuzzy
-#| msgid "Warn about implicit declarations"
 msgid "Warn about dangling else."
-msgstr "Предупреждать о неявных декларациях"
+msgstr "Предупреждать о непарных конструкциях else."
 
 #: c-family/c.opt:449
 msgid "Warn about __TIME__, __DATE__ and __TIMESTAMP__ usage."
-msgstr ""
+msgstr "Предупреждать об использовании __TIME__, __DATE__ и __TIMESTAMP__ ."
 
 #: c-family/c.opt:453
-#, fuzzy
-#| msgid "Warn when a declaration is found after a statement"
 msgid "Warn when a declaration is found after a statement."
-msgstr "Предупреждать о декларациях, встретившихся после операторов"
+msgstr "Предупреждать о декларациях, встретившихся после операторов."
 
 #: c-family/c.opt:457
-#, fuzzy
-#| msgid "dereferencing pointer to incomplete type"
 msgid "Warn when deleting a pointer to incomplete type."
-msgstr "доступ по указателю на неполный тип"
+msgstr "Предупреждать об удалении указателя на неполный тип."
 
 #: c-family/c.opt:461
-#, fuzzy
-#| msgid "Warn about deleting polymorphic objects with non-virtual destructors"
 msgid "Warn about deleting polymorphic objects with non-virtual destructors."
-msgstr "Предупреждать об уничтожении полиморфных объектов с невиртуальными деструкторами"
+msgstr "Предупреждать об уничтожении полиморфных объектов с невиртуальными деструкторами."
 
 #: c-family/c.opt:465
-#, fuzzy
-#| msgid "Warn if a deprecated compiler feature, class, method, or field is used"
 msgid "Warn if a deprecated compiler feature, class, method, or field is used."
-msgstr "Предупреждать об устаревших (deprecated) возможностях компилятора, классах, методах или полях, используемых в программе"
+msgstr "Предупреждать об устаревших (deprecated) возможностях компилятора, классах, методах или полях, используемых в программе."
 
 #: c-family/c.opt:469
-#, fuzzy
-#| msgid "Warn about possibly missing braces around initializers"
 msgid "Warn about positional initialization of structs requiring designated initializers."
-msgstr "Предупреждать о возможно отсутствующих скобках в инициализаторах"
+msgstr "Предупреждать о позиционной инициализации структур, требующих инициализации по именам."
 
 #: c-family/c.opt:473
 msgid "Warn if qualifiers on arrays which are pointer targets are discarded."
-msgstr ""
+msgstr "Предупреждать, если квалификаторы массивов, являющихся целями указателей, отбрасываются."
 
 #: c-family/c.opt:477
-#, fuzzy
-#| msgid "Warn whenever type qualifiers are ignored."
 msgid "Warn if type qualifiers on pointers are discarded."
-msgstr "Предупреждать о случаях игнорирования квалификаторов типа."
+msgstr "Предупреждать о случаях пропуска квалификаторов типа в указателях."
 
 #: c-family/c.opt:481
-#, fuzzy
-#| msgid "Warn about compile-time integer division by zero"
 msgid "Warn about compile-time integer division by zero."
-msgstr "Предупреждать о целочисленном делении на ноль при вычислениях времени компиляции"
+msgstr "Предупреждать о целочисленном делении на ноль при вычислениях времени компиляции."
 
 #: c-family/c.opt:485
-#, fuzzy
-#| msgid "Warn about an empty body in an if or else statement"
 msgid "Warn about duplicated branches in if-else statements."
-msgstr "Предупреждать о пустых if- и else-частях условных операторов"
+msgstr "Предупреждать о дублировании ветвей в операторах if-else."
 
 #: c-family/c.opt:489
 msgid "Warn about duplicated conditions in an if-else-if chain."
-msgstr ""
+msgstr "Предупреждать о повторяющихся условиях в цепочке if-else-if."
 
 #: c-family/c.opt:493
-#, fuzzy
-#| msgid "Warn about violations of Effective C++ style rules"
 msgid "Warn about violations of Effective C++ style rules."
-msgstr "Предупреждать о отступлениях от стиля Effective C++"
+msgstr "Предупреждать о отступлениях от стиля Effective C++."
 
 #: c-family/c.opt:497
-#, fuzzy
-#| msgid "Warn about an empty body in an if or else statement"
 msgid "Warn about an empty body in an if or else statement."
-msgstr "Предупреждать о пустых if- и else-частях условных операторов"
+msgstr "Предупреждать о пустых if- и else-частях условных операторов."
 
 #: c-family/c.opt:501
-#, fuzzy
-#| msgid "Warn about stray tokens after #elif and #endif"
 msgid "Warn about stray tokens after #else and #endif."
-msgstr "Предупреждать о наличии лишнего текста после #elif и #endif"
+msgstr "Предупреждать о наличии лишнего текста после #else и #endif"
 
 #: c-family/c.opt:505
-#, fuzzy
-#| msgid "Warn about comparison of different enum types"
 msgid "Warn about comparison of different enum types."
-msgstr "Предупреждать о сравнениях значений разных перечислимых типов"
+msgstr "Предупреждать о сравнениях значений разных перечислимых типов."
 
 #: c-family/c.opt:513
-#, fuzzy
-#| msgid "This switch is deprecated; use -Werror=implicit-function-declaration instead"
 msgid "This switch is deprecated; use -Werror=implicit-function-declaration instead."
-msgstr "Этот ключ устарел; используйте -Werror=implicit-function-declaration"
+msgstr "Этот ключ устарел; используйте -Werror=implicit-function-declaration."
 
 #: c-family/c.opt:521
-#, fuzzy
-#| msgid "Warn about implicit function declarations"
 msgid "Warn about semicolon after in-class function definition."
-msgstr "Предупреждать о неявных декларациях функций"
+msgstr ""
 
 #: c-family/c.opt:525
-#, fuzzy
-#| msgid "Warn for implicit type conversions that may change a value"
 msgid "Warn for implicit type conversions that cause loss of floating point precision."
-msgstr "Предупреждать, если неявное преобразование типа может изменить значение"
+msgstr "Предупреждать, если неявное преобразование типа может привести к потере точности значений с плавающей точкой."
 
 #: c-family/c.opt:529
-#, fuzzy
-#| msgid "Warn if testing floating point numbers for equality"
 msgid "Warn if testing floating point numbers for equality."
-msgstr "Предупреждать о сравнениях вещественных чисел на равенство"
+msgstr "Предупреждать о сравнениях вещественных чисел на равенство."
 
 #: c-family/c.opt:533 c-family/c.opt:575
-#, fuzzy
-#| msgid "Warn about printf/scanf/strftime/strfmon format string anomalies"
 msgid "Warn about printf/scanf/strftime/strfmon format string anomalies."
-msgstr "Предупреждать о некорректных форматах printf/scanf/strftime/strfmon"
+msgstr "Предупреждать о некорректных форматах printf/scanf/strftime/strfmon."
 
 #: c-family/c.opt:537
-#, fuzzy
-#| msgid "Warn about format strings that contain NUL bytes"
 msgid "Warn about format strings that contain NUL bytes."
-msgstr "Предупреждать о форматных строках, содержащих нулевые байты"
+msgstr "Предупреждать о форматных строках, содержащих нулевые байты."
 
 #: c-family/c.opt:541
-#, fuzzy
-#| msgid "Warn if passing too many arguments to a function for its format string"
 msgid "Warn if passing too many arguments to a function for its format string."
-msgstr "Предупреждать об избыточных аргументах для функций форматирования"
+msgstr "Предупреждать об избыточных аргументах для функций форматирования."
 
 #: c-family/c.opt:545
-#, fuzzy
-#| msgid "Warn about format strings that are not literals"
 msgid "Warn about format strings that are not literals."
-msgstr "Предупреждать о форматных строках, не являющихся литералами"
+msgstr "Предупреждать о форматных строках, не являющихся литералами."
 
 #: c-family/c.opt:549
 msgid "Warn about function calls with format strings that write past the end of the destination region.  Same as -Wformat-overflow=1."
-msgstr ""
+msgstr "Предупреждать о вызовах функций с форматными строками, производящими запись за границей целевой области памяти.  Аналог -Wformat-overflow=1."
 
 #: c-family/c.opt:554
-#, fuzzy
-#| msgid "Warn about possible security problems with format functions"
 msgid "Warn about possible security problems with format functions."
-msgstr "Предупреждать о проблемах с безопасностью при использовании функций форматирования"
+msgstr "Предупреждать о проблемах с безопасностью при использовании функций форматирования."
 
 #: c-family/c.opt:558
-#, fuzzy
-#| msgid "Warn about possible security problems with format functions"
 msgid "Warn about sign differences with format functions."
-msgstr "Предупреждать о проблемах с безопасностью при использовании функций форматирования"
+msgstr "Предупреждать о различиях в знаковости при использовании функций форматирования."
 
 #: c-family/c.opt:562
 msgid "Warn about calls to snprintf and similar functions that truncate output. Same as -Wformat-truncation=1."
-msgstr ""
+msgstr "Предупреждать о вызовах snprintf и других подобных функций, которые могут усекать вывод. Аналог -Wformat-truncation=1."
 
 #: c-family/c.opt:567
-#, fuzzy
-#| msgid "Warn about strftime formats yielding 2-digit years"
 msgid "Warn about strftime formats yielding 2-digit years."
-msgstr "Предупреждать о strftime-форматах, дающих только 2 цифры года"
+msgstr "Предупреждать о strftime-форматах, дающих только 2 цифры года."
 
 #: c-family/c.opt:571
-#, fuzzy
-#| msgid "Warn about zero-length formats"
 msgid "Warn about zero-length formats."
-msgstr "Предупреждать о форматных строках нулевой длины"
+msgstr "Предупреждать о форматных строках нулевой длины."
 
 #: c-family/c.opt:579
 msgid "Warn about function calls with format strings that write past the end of the destination region."
-msgstr ""
+msgstr "Предупреждать о вызовах функций с форматными строками, производящими запись за границей целевой области памяти."
 
 #: c-family/c.opt:584
-#, fuzzy
-#| msgid "Warn about casting functions to incompatible types"
 msgid "Warn about calls to snprintf and similar functions that truncate output."
-msgstr "Предупреждать о приведений функций к несовместимым типам"
+msgstr "Предупреждать о вызовах snprintf и других подобных функций, которые могут усекать вывод."
 
 #: c-family/c.opt:588
-#, fuzzy
-#| msgid "Warn when a Cell microcoded instruction is emitted"
 msgid "Warn when the field in a struct is not aligned."
-msgstr "Предупреждать о выдаче микрокодированных Cell инструкций"
+msgstr ""
 
 #: c-family/c.opt:592
 msgid "Warn whenever type qualifiers are ignored."
@@ -7422,144 +6716,108 @@
 msgstr "Предупреждать о случаях игнорирования квалификаторов типа."
 
 #: c-family/c.opt:596
-#, fuzzy
-#| msgid "Warn whenever type qualifiers are ignored."
 msgid "Warn whenever attributes are ignored."
-msgstr "Предупреждать о случаях игнорирования квалификаторов типа."
+msgstr "Предупреждать о случаях игнорирования атрибутов."
 
 #: c-family/c.opt:600
 msgid "Warn when there is a conversion between pointers that have incompatible types."
-msgstr ""
+msgstr "Предупреждать о преобразованиях указателей к несовместимым типам."
 
 #: c-family/c.opt:604
-#, fuzzy
-#| msgid "Warn about variables which are initialized to themselves"
 msgid "Warn about variables which are initialized to themselves."
-msgstr "Предупреждать о переменных, в инициализации которых используется их значение"
+msgstr "Предупреждать о переменных, в инициализации которых используется их значение."
 
 #: c-family/c.opt:608
-#, fuzzy
-#| msgid "Warn about implicit declarations"
 msgid "Warn about implicit declarations."
-msgstr "Предупреждать о неявных декларациях"
+msgstr "Предупреждать о неявных декларациях."
 
 #: c-family/c.opt:616
-#, fuzzy
-#| msgid "Warn about implicit conversions from \"float\" to \"double\""
 msgid "Warn about implicit conversions from \"float\" to \"double\"."
-msgstr "Предупреждать о неявных преобразованиях \"float\" в \"double\" "
+msgstr "Предупреждать о неявных преобразованиях \"float\" в \"double\"."
 
 #: c-family/c.opt:620
-#, fuzzy
-#| msgid "Warn if an undefined macro is used in an #if directive"
 msgid "Warn if \"defined\" is used outside #if."
-msgstr "Предупреждать об использовании неопределенных макросов в директивах #if"
+msgstr "Предупреждать об использовании \"defined\" где-либо кроме директив #if."
 
 #: c-family/c.opt:624
-#, fuzzy
-#| msgid "Warn about implicit function declarations"
 msgid "Warn about implicit function declarations."
-msgstr "Предупреждать о неявных декларациях функций"
+msgstr "Предупреждать о неявных декларациях функций."
 
 #: c-family/c.opt:628
-#, fuzzy
-#| msgid "Warn when a declaration does not specify a type"
 msgid "Warn when a declaration does not specify a type."
-msgstr "Предупреждать о декларациях, в которых не задан тип"
+msgstr "Предупреждать о декларациях, в которых не задан тип."
 
 #: c-family/c.opt:635
 msgid "Warn about C++11 inheriting constructors when the base has a variadic constructor."
-msgstr ""
+msgstr "Предупреждать о наследовании конструкторов C++11, когда в базовом классе есть конструктор с переменным числом аргументов."
 
 #: c-family/c.opt:639
 msgid "Warn about incompatible integer to pointer and pointer to integer conversions."
-msgstr ""
+msgstr "Предупреждать о несовместимостях при конверсии целого к указателю или указателя к целому."
 
 #: c-family/c.opt:643
 msgid "Warn for suspicious integer expressions in boolean context."
-msgstr ""
+msgstr "Предупреждать о подозрительных целочисленных выражениях там, где ожидается булево выражение."
 
 #: c-family/c.opt:647
-#, fuzzy
-#| msgid "Warn when there is a cast to a pointer from an integer of a different size"
 msgid "Warn when there is a cast to a pointer from an integer of a different size."
-msgstr "Предупреждать о приведении к типу указателя от целого другого размера"
+msgstr "Предупреждать о приведении к типу указателя от целого другого размера."
 
 #: c-family/c.opt:651
-#, fuzzy
-#| msgid "Warn about invalid uses of the \"offsetof\" macro"
 msgid "Warn about invalid uses of the \"offsetof\" macro."
-msgstr "Предупреждать о некорректном использовании макроса \"offsetof\""
+msgstr "Предупреждать о некорректном использовании макроса \"offsetof\"."
 
 #: c-family/c.opt:655
-#, fuzzy
-#| msgid "Warn about PCH files that are found but not used"
 msgid "Warn about PCH files that are found but not used."
-msgstr "Предупреждать о PCH, которые были найдены, но не использованы"
+msgstr "Предупреждать о PCH, которые были найдены, но не использованы."
 
 #: c-family/c.opt:659
-#, fuzzy
-#| msgid "Warn when a jump misses a variable initialization"
 msgid "Warn when a jump misses a variable initialization."
-msgstr "Предупреждать, если безусловный переход обходит инициализацию переменных"
+msgstr "Предупреждать, если безусловный переход обходит инициализацию переменных."
 
 #: c-family/c.opt:663
 msgid "Warn when a string or character literal is followed by a ud-suffix which does not begin with an underscore."
-msgstr ""
+msgstr "Предупреждать, если за строковым или символьным литералом следует пользовательский суффикс, не начинающийся с подчеркивания."
 
 #: c-family/c.opt:667
-#, fuzzy
-#| msgid "Warn when a logical operator is suspiciously always evaluating to true or false"
 msgid "Warn when a logical operator is suspiciously always evaluating to true or false."
-msgstr "Предупреждать, если значение логической операции всегда истина или всегда ложь"
+msgstr "Предупреждать, если значение логической операции всегда истина или всегда ложь."
 
 #: c-family/c.opt:671
 msgid "Warn when logical not is used on the left hand side operand of a comparison."
-msgstr ""
+msgstr "Предупреждать, если логическое отрицание используется в левом операнде сравнения."
 
 #: c-family/c.opt:675
-#, fuzzy
-#| msgid "Do not warn about using \"long long\" when -pedantic"
 msgid "Do not warn about using \"long long\" when -pedantic."
-msgstr "Не предупреждать об использовании \"long long\" с -pedantic"
+msgstr "Не предупреждать об использовании \"long long\" с -pedantic."
 
 #: c-family/c.opt:679
-#, fuzzy
-#| msgid "Warn about suspicious declarations of \"main\""
 msgid "Warn about suspicious declarations of \"main\"."
-msgstr "Предупреждать о нестандартных декларациях для \"main\""
+msgstr "Предупреждать о нестандартных декларациях для \"main\"."
 
 #: c-family/c.opt:687
 msgid "Warn about suspicious calls to memset where the third argument is constant literal zero and the second is not."
-msgstr ""
+msgstr "Предупреждать о подозрительных вызовах memset, в которых третий аргумент есть литерал, равный нулю, а второй - нет."
 
 #: c-family/c.opt:691
 msgid "Warn about suspicious calls to memset where the third argument contains the number of elements not multiplied by the element size."
-msgstr ""
+msgstr "Предупреждать о подозрительных вызовах memset, в которых третий аргумент содержит число элементов, не умноженное на размер элемента."
 
 #: c-family/c.opt:695
-#, fuzzy
-#| msgid "Warn when the packed attribute has no effect on struct layout"
 msgid "Warn when the indentation of the code does not reflect the block structure."
-msgstr "Предупреждать о случаях, когда атрибут packed не влияет на "
+msgstr "Предупреждать, когда отступы в исходном коде не отражают блочную структуру программы."
 
 #: c-family/c.opt:699
-#, fuzzy
-#| msgid "Warn about possibly missing braces around initializers"
 msgid "Warn about possibly missing braces around initializers."
-msgstr "Предупреждать о возможно отсутствующих скобках в инициализаторах"
+msgstr "Предупреждать о возможно отсутствующих скобках в инициализаторах."
 
 #: c-family/c.opt:703
-#, fuzzy
-#| msgid "Warn about global functions without previous declarations"
 msgid "Warn about global functions without previous declarations."
-msgstr "Предупреждать о глобальных функциях без предшествующих деклараций"
+msgstr "Предупреждать о глобальных функциях без предшествующих деклараций."
 
 #: c-family/c.opt:707
-#, fuzzy
-#| msgid "Warn about missing fields in struct initializers"
 msgid "Warn about missing fields in struct initializers."
-msgstr "Предупреждать о возможно отсутствующих скобках в инициализаторах структур"
+msgstr "Предупреждать о возможно отсутствующих скобках в инициализаторах структур."
 
 #: c-family/c.opt:711
 msgid "Warn about unsafe macros expanding to multiple statements used as a body of a clause such as if, else, while, switch, or for."
@@ -7567,11 +6825,11 @@
 
 #: c-family/c.opt:715
 msgid "Warn on direct multiple inheritance."
-msgstr ""
+msgstr "Предупреждать о прямом множественном наследовании."
 
 #: c-family/c.opt:719
 msgid "Warn on namespace definition."
-msgstr ""
+msgstr "Предупреждать об определении пространства имен."
 
 #: c-family/c.opt:723
 msgid "Warn when fields in a struct with the packed attribute are misaligned."
@@ -7578,10 +6836,8 @@
 msgstr ""
 
 #: c-family/c.opt:727
-#, fuzzy
-#| msgid "Warn about missing fields in struct initializers"
 msgid "Warn about missing sized deallocation functions."
-msgstr "Предупреждать о возможно отсутствующих скобках в инициализаторах структур"
+msgstr "Предупреждать об отсутствии функций деаллокации объектов с указанием размера."
 
 #: c-family/c.opt:731
 msgid "Warn about suspicious divisions of two sizeof expressions that don't work correctly with pointers."
@@ -7589,19 +6845,19 @@
 
 #: c-family/c.opt:735
 msgid "Warn about suspicious length parameters to certain string functions if the argument uses sizeof."
-msgstr ""
+msgstr "Предупреждать о подозрительных параметрах, задающих длину для некоторых строковых функций, если аргумент использует вызов sizeof."
 
 #: c-family/c.opt:739
 msgid "Warn when sizeof is applied on a parameter declared as an array."
-msgstr ""
+msgstr "Предупреждать, если sizeof применяется к параметру, декларированному как массив."
 
 #: c-family/c.opt:743
 msgid "Warn about buffer overflow in string manipulation functions like memcpy and strcpy."
-msgstr ""
+msgstr "Предупреждать о переполнении буфера в строковых функциях, таких как memcpy и strcpy."
 
 #: c-family/c.opt:748
 msgid "Under the control of Object Size type, warn about buffer overflow in string manipulation functions like memcpy and strcpy."
-msgstr ""
+msgstr "Предупреждать о переполнении буфера в строковых функциях, таких как memcpy и strcpy с учетом указанного типа type."
 
 #: c-family/c.opt:753
 msgid "Warn about truncation in string manipulation functions like strncat and strncpy."
@@ -7608,44 +6864,32 @@
 msgstr ""
 
 #: c-family/c.opt:757
-#, fuzzy
-#| msgid "Warn about functions which might be candidates for format attributes"
 msgid "Warn about functions which might be candidates for format attributes."
-msgstr "Предупреждать о функциях, которым можно назначить атрибут format"
+msgstr "Предупреждать о функциях, которым можно назначить атрибут format."
 
 #: c-family/c.opt:761
 msgid "Suggest that the override keyword be used when the declaration of a virtual function overrides another."
-msgstr ""
+msgstr "Предлагать использовать ключевое слово override, если декларация виртуальной функции перекрывает другую декларацию."
 
 #: c-family/c.opt:766
-#, fuzzy
-#| msgid "Warn about enumerated switches, with no default, missing a case"
 msgid "Warn about enumerated switches, with no default, missing a case."
-msgstr "Предупреждать о переключателях по enum-типу, содержащих не все альтернативы и без метки default"
+msgstr "Предупреждать о переключателях по enum-типу, содержащих не все альтернативы и без метки default."
 
 #: c-family/c.opt:770
-#, fuzzy
-#| msgid "Warn about enumerated switches missing a \"default:\" statement"
 msgid "Warn about enumerated switches missing a \"default:\" statement."
-msgstr "Предупреждать о переключателях по enum-типу без метки default"
+msgstr "Предупреждать о переключателях по enum-типу без метки default."
 
 #: c-family/c.opt:774
-#, fuzzy
-#| msgid "Warn about all enumerated switches missing a specific case"
 msgid "Warn about all enumerated switches missing a specific case."
-msgstr "Предупреждать о переключателях по enum-типу, содержащих не все альтернативы"
+msgstr "Предупреждать о переключателях по enum-типу, содержащих не все альтернативы."
 
 #: c-family/c.opt:778
-#, fuzzy
-#| msgid "Warn about truncated character expressions"
 msgid "Warn about switches with boolean controlling expression."
-msgstr "Предупреждать об усеченных строковых выражениях"
+msgstr "Предупреждать о переключателях с управляющими выражениями логического типа."
 
 #: c-family/c.opt:782
-#, fuzzy
-#| msgid "for template declaration %q+D"
 msgid "Warn on primary template declaration."
-msgstr "для декларации шаблона %q+D"
+msgstr "Предупреждать о первичной декларации шаблона."
 
 #: c-family/c.opt:786
 msgid "Warn about declarations of entities that may be missing attributes that related entities have been declared with it."
@@ -7652,22 +6896,16 @@
 msgstr ""
 
 #: c-family/c.opt:795
-#, fuzzy
-#| msgid "Warn about user-specified include directories that do not exist"
 msgid "Warn about user-specified include directories that do not exist."
-msgstr "Предупреждать о заданных пользователем, но не существующих каталогах заголовков"
+msgstr "Предупреждать о заданных пользователем, но не существующих каталогах заголовков."
 
 #: c-family/c.opt:799
-#, fuzzy
-#| msgid "Warn about function parameters declared without a type specifier in K&R-style functions"
 msgid "Warn about function parameters declared without a type specifier in K&R-style functions."
-msgstr "Предупреждать о параметрах функций, декларированных без типа в функциях, описанных в стиле K&R"
+msgstr "Предупреждать о параметрах функций, декларированных без типа в функциях, описанных в стиле K&R."
 
 #: c-family/c.opt:803
-#, fuzzy
-#| msgid "Warn about global functions without prototypes"
 msgid "Warn about global functions without prototypes."
-msgstr "Предупреждать о глобальных функциях без прототипов"
+msgstr "Предупреждать о глобальных функциях без прототипов."
 
 #: c-family/c.opt:806 c-family/c.opt:1219 c-family/c.opt:1226
 #: c-family/c.opt:1422 c-family/c.opt:1441 c-family/c.opt:1464
@@ -7676,34 +6914,26 @@
 #: c-family/c.opt:1525 c-family/c.opt:1528 c-family/c.opt:1569
 #: c-family/c.opt:1704 c-family/c.opt:1731 c-family/c.opt:1771
 #: c-family/c.opt:1802 c-family/c.opt:1806 c-family/c.opt:1822
-#: config/ia64/ia64.opt:167 config/ia64/ia64.opt:170 c-family/c-opts.c:434
+#: config/ia64/ia64.opt:167 config/ia64/ia64.opt:170 c-family/c-opts.c:432
 #, gcc-internal-format
 msgid "switch %qs is no longer supported"
 msgstr "ключ %qs больше не поддерживается"
 
 #: c-family/c.opt:810
-#, fuzzy
-#| msgid "Warn about use of multi-character character constants"
 msgid "Warn about use of multi-character character constants."
-msgstr "Предупреждать о char-константах, содержащих несколько литер "
+msgstr "Предупреждать о char-константах, содержащих несколько литер."
 
 #: c-family/c.opt:814
-#, fuzzy
-#| msgid "Warn about narrowing conversions within { } that are ill-formed in C++11"
 msgid "Warn about narrowing conversions within { } that are ill-formed in C++11."
-msgstr "Предупреждать о сужающих преобразованиях в { }, являющихся дефектными в C++11"
+msgstr "Предупреждать о сужающих преобразованиях в { }, являющихся дефектными в C++11."
 
 #: c-family/c.opt:818
-#, fuzzy
-#| msgid "Warn about \"extern\" declarations not at file scope"
 msgid "Warn about \"extern\" declarations not at file scope."
-msgstr "Предупреждать об \"extern\" декларациях не на уровне файла"
+msgstr "Предупреждать об \"extern\" декларациях не на уровне файла."
 
 #: c-family/c.opt:822
-#, fuzzy
-#| msgid "Warn when a noexcept expression evaluates to false even though the expression can't actually throw"
 msgid "Warn when a noexcept expression evaluates to false even though the expression can't actually throw."
-msgstr "Предупреждать, если noexcept-выражение имеет значение false, даже если выражение не может вызвать исключение"
+msgstr "Предупреждать, если noexcept-выражение имеет значение false, даже если выражение не может вызвать исключение."
 
 #: c-family/c.opt:826
 msgid "Warn if C++17 noexcept function type will change the mangled name of a symbol."
@@ -7710,10 +6940,8 @@
 msgstr ""
 
 #: c-family/c.opt:830
-#, fuzzy
-#| msgid "Warn when non-templatized friend functions are declared within a template"
 msgid "Warn when non-templatized friend functions are declared within a template."
-msgstr "Предупреждать о нешаблонных friend-функциях, декларированных внутри шаблона"
+msgstr "Предупреждать о нешаблонных friend-функциях, декларированных внутри шаблона."
 
 #: c-family/c.opt:834
 msgid "Warn for unsafe raw memory writes to objects of class types."
@@ -7720,22 +6948,16 @@
 msgstr ""
 
 #: c-family/c.opt:838
-#, fuzzy
-#| msgid "Warn about non-virtual destructors"
 msgid "Warn about non-virtual destructors."
-msgstr "Предупреждать о невиртуальных деструкторах"
+msgstr "Предупреждать о невиртуальных деструкторах."
 
 #: c-family/c.opt:842
-#, fuzzy
-#| msgid "Warn about NULL being passed to argument slots marked as requiring non-NULL"
 msgid "Warn about NULL being passed to argument slots marked as requiring non-NULL."
-msgstr "Предупреждать о передаче NULL в качестве аргумента, который отмечен как требующий не-NULL значения"
+msgstr "Предупреждать о передаче NULL в качестве аргумента, который отмечен как требующий не-NULL значения."
 
 #: c-family/c.opt:858
-#, fuzzy
-#| msgid "-Wnormalized=<id|nfc|nfkc>\tWarn about non-normalised Unicode strings"
 msgid "-Wnormalized=[none|id|nfc|nfkc]\tWarn about non-normalized Unicode strings."
-msgstr "-Wnormalized=<id|nfc|nfkc>\tПредупреждать о ненормализованных строках Unicode"
+msgstr "-Wnormalized=[none|id|nfc|nfkc]\tПредупреждать о ненормализованных строках Unicode."
 
 #: c-family/c.opt:865
 msgid "argument %qs to %<-Wnormalized%> not recognized"
@@ -7742,433 +6964,313 @@
 msgstr "некорректный аргумент %qs ключа %<-Wnormalized%>"
 
 #: c-family/c.opt:881
-#, fuzzy
-#| msgid "Warn if a C-style cast is used in a program"
 msgid "Warn if a C-style cast is used in a program."
-msgstr "Предупреждать об использовании приведения типов в стиле C"
+msgstr "Предупреждать об использовании приведения типов в стиле C."
 
 #: c-family/c.opt:885
-#, fuzzy
-#| msgid "Warn for obsolescent usage in a declaration"
 msgid "Warn for obsolescent usage in a declaration."
-msgstr "Предупреждать об использовании устаревшего синтаксиса деклараций"
+msgstr "Предупреждать об использовании устаревшего синтаксиса деклараций."
 
 #: c-family/c.opt:889
-#, fuzzy
-#| msgid "Warn if an old-style parameter definition is used"
 msgid "Warn if an old-style parameter definition is used."
-msgstr "Предупреждать об определениях параметров в старом стиле"
+msgstr "Предупреждать об определениях параметров в старом стиле."
 
 #: c-family/c.opt:893
 msgid "Warn if a simd directive is overridden by the vectorizer cost model."
-msgstr ""
+msgstr "Предупреждать, если директива simd игнорируется с учетом стоимостной модели, применяемой векторизатором."
 
 #: c-family/c.opt:897
-#, fuzzy
-#| msgid "Warn if a string is longer than the maximum portable length specified by the standard"
 msgid "Warn if a string is longer than the maximum portable length specified by the standard."
-msgstr "Предупреждать, если строка длиннее чем максимальный размер, указанный в стандарте"
+msgstr "Предупреждать, если строка длиннее чем максимальный размер, указанный в стандарте."
 
 #: c-family/c.opt:901
-#, fuzzy
-#| msgid "Warn about overloaded virtual function names"
 msgid "Warn about overloaded virtual function names."
-msgstr "Предупреждать о перегруженных именах виртуальных функций"
+msgstr "Предупреждать о перегруженных именах виртуальных функций."
 
 #: c-family/c.opt:905
-#, fuzzy
-#| msgid "Warn about overriding initializers without side effects"
 msgid "Warn about overriding initializers without side effects."
-msgstr "Предупреждать о переопределении инициализированных элементов без побочных эффектов"
+msgstr "Предупреждать о переопределении инициализированных элементов без побочных эффектов."
 
 #: c-family/c.opt:909
-#, fuzzy
-#| msgid "Warn about overriding initializers without side effects"
 msgid "Warn about overriding initializers with side effects."
-msgstr "Предупреждать о переопределении инициализированных элементов без побочных эффектов"
+msgstr "Предупреждать о переопределении инициализированных элементов с побочными эффектами."
 
 #: c-family/c.opt:913
-#, fuzzy
-#| msgid "Warn about packed bit-fields whose offset changed in GCC 4.4"
 msgid "Warn about packed bit-fields whose offset changed in GCC 4.4."
-msgstr "Предупреждать об упакованных битовых полях, смещение которых изменено в GCC 4.4"
+msgstr "Предупреждать об упакованных битовых полях, смещение которых изменено в GCC 4.4."
 
 #: c-family/c.opt:917
-#, fuzzy
-#| msgid "Warn about possibly missing parentheses"
 msgid "Warn about possibly missing parentheses."
-msgstr "Предупреждать о возможно отсутствующих скобках"
+msgstr "Предупреждать о возможно отсутствующих скобках."
 
 #: c-family/c.opt:925
-#, fuzzy
-#| msgid "Warn when converting the type of pointers to member functions"
 msgid "Warn when converting the type of pointers to member functions."
-msgstr "Предупреждать о преобразовании типа указателя к функции-элементу"
+msgstr "Предупреждать о преобразовании типа указателя к функции-элементу."
 
 #: c-family/c.opt:929
-#, fuzzy
-#| msgid "Warn about function pointer arithmetic"
 msgid "Warn about function pointer arithmetic."
-msgstr "Предупреждать об арифметических действиях над указателями на функции"
+msgstr "Предупреждать об арифметических действиях над указателями на функции."
 
 #: c-family/c.opt:933
-#, fuzzy
-#| msgid "Warn when a pointer differs in signedness in an assignment"
 msgid "Warn when a pointer differs in signedness in an assignment."
-msgstr "Предупреждать о различиях в знаковости указателя в присваивании"
+msgstr "Предупреждать о различиях в знаковости указателя в присваивании."
 
 #: c-family/c.opt:937
-#, fuzzy
-#| msgid "Warn about use of multi-character character constants"
 msgid "Warn when a pointer is compared with a zero character constant."
-msgstr "Предупреждать о char-константах, содержащих несколько литер "
+msgstr "Предупреждать о сравнении указателя с нулевой символьной константой."
 
 #: c-family/c.opt:941
-#, fuzzy
-#| msgid "Warn when a pointer is cast to an integer of a different size"
 msgid "Warn when a pointer is cast to an integer of a different size."
-msgstr "Предупреждать о приведении указателя к целому другого размера"
+msgstr "Предупреждать о приведении указателя к целому другого размера."
 
 #: c-family/c.opt:945
-#, fuzzy
-#| msgid "Warn about misuses of pragmas"
 msgid "Warn about misuses of pragmas."
-msgstr "Предупреждать о неправильном использовании прагм"
+msgstr "Предупреждать о неправильном использовании прагм."
 
 #: c-family/c.opt:949
-#, fuzzy
-#| msgid "Warn if a property for an Objective-C object has no assign semantics specified"
 msgid "Warn if a property for an Objective-C object has no assign semantics specified."
-msgstr "Предупреждать, если для свойства объекта Objective-C не задана семантика присваивания"
+msgstr "Предупреждать, если для свойства объекта Objective-C не задана семантика присваивания."
 
 #: c-family/c.opt:953
-#, fuzzy
-#| msgid "Warn if inherited methods are unimplemented"
 msgid "Warn if inherited methods are unimplemented."
-msgstr "Предупреждать о нереализованных наследуемых методах"
+msgstr "Предупреждать о нереализованных наследуемых методах."
 
 #: c-family/c.opt:957 c-family/c.opt:961
 msgid "Warn for placement new expressions with undefined behavior."
-msgstr ""
+msgstr "Предупреждать о выражениях placement new с неопределенным поведением."
 
 #: c-family/c.opt:965
-#, fuzzy
-#| msgid "Warn about multiple declarations of the same object"
 msgid "Warn about multiple declarations of the same object."
-msgstr "Предупреждать о множественных декларациях объектов"
+msgstr "Предупреждать о множественных декларациях объектов."
 
 #: c-family/c.opt:969
-#, fuzzy
-#| msgid "Warn about misuses of pragmas"
 msgid "Warn about uses of register storage specifier."
-msgstr "Предупреждать о неправильном использовании прагм"
+msgstr "Предупреждать об использовании спецификатора register."
 
 #: c-family/c.opt:973
-#, fuzzy
-#| msgid "Warn when the compiler reorders code"
 msgid "Warn when the compiler reorders code."
-msgstr "Предупреждать о переупорядочении кода компилятором"
+msgstr "Предупреждать о переупорядочении кода компилятором."
 
 #: c-family/c.opt:977
-#, fuzzy
-#| msgid "Warn whenever a function's return type defaults to \"int\" (C), or about inconsistent return types (C++)"
 msgid "Warn whenever a function's return type defaults to \"int\" (C), or about inconsistent return types (C++)."
-msgstr "Предупреждать, если тип возвращаемого значения по берется умолчанию как \"int\" (C), или о несовместимом типе результата (C++)"
+msgstr "Предупреждать, если тип возвращаемого значения по берется умолчанию как \"int\" (C), или о несовместимом типе результата (C++)."
 
 #: c-family/c.opt:981
 msgid "Warn on suspicious constructs involving reverse scalar storage order."
-msgstr ""
+msgstr "Предупреждать о подозрительных конструкциях, использующих обратный порядок хранения скаляров в памяти."
 
 #: c-family/c.opt:985
-#, fuzzy
-#| msgid "Warn if a selector has multiple methods"
 msgid "Warn if a selector has multiple methods."
-msgstr "Предупреждать о селекторах с множественными методами"
+msgstr "Предупреждать о селекторах с множественными методами."
 
 #: c-family/c.opt:989
-#, fuzzy
-#| msgid "Warn about possible violations of sequence point rules"
 msgid "Warn about possible violations of sequence point rules."
-msgstr "Предупреждать о возможном нарушении правил точек следования"
+msgstr "Предупреждать о возможном нарушении правил точек следования."
 
 #: c-family/c.opt:993
-#, fuzzy
-#| msgid "local declaration of %qE hides instance variable"
 msgid "Warn if a local declaration hides an instance variable."
-msgstr "локальная декларация %qE скрывает instance переменную"
+msgstr "Предупреждать, если локальная декларация скрывает instance переменную."
 
 #: c-family/c.opt:997 c-family/c.opt:1001
 msgid "Warn if left shift of a signed value overflows."
-msgstr ""
+msgstr "Предупреждать, если сдвиг влево знакового значений вызывает переполнение."
 
 #: c-family/c.opt:1005
-#, fuzzy
-#| msgid "right shift count is negative"
 msgid "Warn if shift count is negative."
-msgstr "сдвиг вправо на отрицательное число позиций"
+msgstr "Предупреждать о сдвигах на отрицательное число позиций."
 
 #: c-family/c.opt:1009
-#, fuzzy
-#| msgid "right shift count >= width of type"
 msgid "Warn if shift count >= width of type."
-msgstr "величина сдвига вправо больше или равна ширине данного типа"
+msgstr "Предупреждать, если величина сдвига вправо больше или равна ширине данного типа."
 
 #: c-family/c.opt:1013
-#, fuzzy
-#| msgid "left shift count is negative"
 msgid "Warn if left shifting a negative value."
-msgstr "сдвиг влево на отрицательное число позиций"
+msgstr "Предупреждать, если сдвиг влево осуществляется на отрицательное число позиций."
 
 #: c-family/c.opt:1017
-#, fuzzy
-#| msgid "Warn about signed-unsigned comparisons"
 msgid "Warn about signed-unsigned comparisons."
-msgstr "Предупреждать о сравнениях между signed и unsigned значениями"
+msgstr "Предупреждать о сравнениях между signed и unsigned значениями."
 
 #: c-family/c.opt:1025
-#, fuzzy
-#| msgid "Warn for implicit type conversions between signed and unsigned integers"
 msgid "Warn for implicit type conversions between signed and unsigned integers."
-msgstr "Предупреждать о неявных преобразованиях между знаковыми и беззнаковыми целыми типами"
+msgstr "Предупреждать о неявных преобразованиях между знаковыми и беззнаковыми целыми типами."
 
 #: c-family/c.opt:1029
-#, fuzzy
-#| msgid "Warn when overload promotes from unsigned to signed"
 msgid "Warn when overload promotes from unsigned to signed."
-msgstr "Предупреждать когда перегруженное имя преобразуется от unsigned к signed"
+msgstr "Предупреждать, когда перегруженное имя преобразуется от unsigned к signed."
 
 #: c-family/c.opt:1033
-#, fuzzy
-#| msgid "Warn about uncasted NULL used as sentinel"
 msgid "Warn about uncasted NULL used as sentinel."
-msgstr "Предупреждать на всякий случай об отсутствии приведения NULL"
+msgstr "Предупреждать об отсутствии приведения NULL, используемого в качестве sentinel."
 
 #: c-family/c.opt:1037
-#, fuzzy
-#| msgid "Warn about unprototyped function declarations"
 msgid "Warn about unprototyped function declarations."
-msgstr "Предупреждать о непрототипных декларациях функций"
+msgstr "Предупреждать о непрототипных декларациях функций."
 
 #: c-family/c.opt:1049
-#, fuzzy
-#| msgid "Warn if type signatures of candidate methods do not match exactly"
 msgid "Warn if type signatures of candidate methods do not match exactly."
-msgstr "Предупреждать о несовпадении сигнатур применимых методов"
+msgstr "Предупреждать о несовпадении сигнатур применимых методов."
 
 #: c-family/c.opt:1053
-#, fuzzy
-#| msgid "Warn when __sync_fetch_and_nand and __sync_nand_and_fetch built-in functions are used"
 msgid "Warn when __sync_fetch_and_nand and __sync_nand_and_fetch built-in functions are used."
-msgstr "Предупреждать об использовании встроенных функций __sync_fetch_and_nand и __sync_nand_and_fetch"
+msgstr "Предупреждать об использовании встроенных функций __sync_fetch_and_nand и __sync_nand_and_fetch."
 
 #: c-family/c.opt:1057
-#, fuzzy
-#| msgid "Deprecated.  This switch has no effect"
 msgid "Deprecated.  This switch has no effect."
-msgstr "Устаревший ключ. Игнорируется."
+msgstr "Устарел.  Ничего не делает."
 
 #: c-family/c.opt:1065
-#, fuzzy
-#| msgid "Warn when a logical operator is suspiciously always evaluating to true or false"
 msgid "Warn if a comparison always evaluates to true or false."
-msgstr "Предупреждать, если значение логической операции всегда истина или всегда ложь"
+msgstr "Предупреждать, если результат сравнения всегда истина или всегда ложь."
 
 #: c-family/c.opt:1069
 msgid "Warn if a throw expression will always result in a call to terminate()."
-msgstr ""
+msgstr "Предупреждать, если throw выражение всегда приводит к вызову terminate()."
 
 #: c-family/c.opt:1073
-#, fuzzy
-#| msgid "Warn about features not present in traditional C"
 msgid "Warn about features not present in traditional C."
-msgstr "Предупреждать об использовании средств, отсутствующих в традиционном C"
+msgstr "Предупреждать об использовании средств, отсутствующих в традиционном C."
 
 #: c-family/c.opt:1077
-#, fuzzy
-#| msgid "Warn of prototypes causing type conversions different from what would happen in the absence of prototype"
 msgid "Warn of prototypes causing type conversions different from what would happen in the absence of prototype."
-msgstr "Предупреждать о прототипах, приводящих к преобразованиям типа, отличным от преобразований, которые были бы выполнены в отсутствие прототипа"
+msgstr "Предупреждать о прототипах, приводящих к преобразованиям типа, отличным от преобразований, которые были бы выполнены в отсутствие прототипа."
 
 #: c-family/c.opt:1081
-#, fuzzy
-#| msgid "Warn if trigraphs are encountered that might affect the meaning of the program"
 msgid "Warn if trigraphs are encountered that might affect the meaning of the program."
-msgstr "Предупреждать о встретившихся триграфах, которые могут влиять на смысл программы"
+msgstr "Предупреждать о встретившихся триграфах, которые могут влиять на смысл программы."
 
 #: c-family/c.opt:1085
-#, fuzzy
-#| msgid "Warn about @selector()s without previously declared methods"
 msgid "Warn about @selector()s without previously declared methods."
-msgstr "Предупреждать о @selector() без предварительно декларированных методов"
+msgstr "Предупреждать о @selector() без предварительно декларированных методов."
 
 #: c-family/c.opt:1089
-#, fuzzy
-#| msgid "Warn if an undefined macro is used in an #if directive"
 msgid "Warn if an undefined macro is used in an #if directive."
-msgstr "Предупреждать об использовании неопределенных макросов в директивах #if"
+msgstr "Предупреждать об использовании неопределенных макросов в директивах #if."
 
 #: c-family/c.opt:1101
-#, fuzzy
-#| msgid "Warn about unrecognized pragmas"
 msgid "Warn about unrecognized pragmas."
-msgstr "Предупреждать о наличии неизвестных прагм"
+msgstr "Предупреждать о наличии неизвестных прагм."
 
 #: c-family/c.opt:1105
-#, fuzzy
-#| msgid "Warn about unsuffixed float constants"
 msgid "Warn about unsuffixed float constants."
-msgstr "Предупреждать о плавающих константах без суффиксов"
+msgstr "Предупреждать о плавающих константах без суффиксов."
 
 #: c-family/c.opt:1113
-#, fuzzy
-#| msgid "Warn when typedefs locally defined in a function are not used"
 msgid "Warn when typedefs locally defined in a function are not used."
-msgstr "Предупреждать о неиспользованных typedef-декларациях на уровне функции"
+msgstr "Предупреждать о неиспользованных typedef-декларациях на уровне функции."
 
 #: c-family/c.opt:1117
-#, fuzzy
-#| msgid "Warn about macros defined in the main file that are not used"
 msgid "Warn about macros defined in the main file that are not used."
-msgstr "Предупреждать об определенных в основном файле, но неиспользованных макросах"
+msgstr "Предупреждать об определенных в основном файле, но неиспользованных макросах."
 
 #: c-family/c.opt:1121
-#, fuzzy
-#| msgid "Warn if a caller of a function, marked with attribute warn_unused_result, does not use its return value"
 msgid "Warn if a caller of a function, marked with attribute warn_unused_result, does not use its return value."
-msgstr "Предупреждать, если результат вызова функции, декларированной с атрибутом warn_unused_result, не используется"
+msgstr "Предупреждать, если результат вызова функции, декларированной с атрибутом warn_unused_result, не используется."
 
 #: c-family/c.opt:1129 c-family/c.opt:1133
-#, fuzzy
-#| msgid "Warn when a variable is unused"
 msgid "Warn when a const variable is unused."
-msgstr "Предупреждать о неиспользуемых переменных"
+msgstr "Предупреждать о неиспользуемых переменных."
 
 #: c-family/c.opt:1137
-#, fuzzy
-#| msgid "Do not warn about using variadic macros when -pedantic"
 msgid "Warn about using variadic macros."
-msgstr "Не предупреждать об использовании макросов с переменным числом аргументов с -pedantic"
+msgstr "Предупреждать об использовании макросов с переменным числом аргументов."
 
 #: c-family/c.opt:1141
 msgid "Warn about questionable usage of the macros used to retrieve variable arguments."
-msgstr ""
+msgstr "Предупреждать о сомнительном применении макросов для выборки переменных аргументов."
 
 #: c-family/c.opt:1145
-#, fuzzy
-#| msgid "Warn if a variable length array is used"
 msgid "Warn if a variable length array is used."
-msgstr "Предупреждать об использовании массивов переменной длины"
+msgstr "Предупреждать об использовании массивов переменной длины."
 
 #: c-family/c.opt:1149
 msgid "-Wvla-larger-than=<number>\tWarn on unbounded uses of variable-length arrays, and on bounded uses of variable-length arrays whose bound can be larger than <number> bytes."
-msgstr ""
+msgstr "-Wvla-larger-than=<число>\tПредупреждать об использовании массивов переменной длины без ограничений или массивов с ограничением на размер, которое превышает <число> bytes."
 
 #: c-family/c.opt:1155
-#, fuzzy
-#| msgid "Warn when a register variable is declared volatile"
 msgid "Warn when a register variable is declared volatile."
-msgstr "Предупреждать о регистровых переменных, объявленных volatile"
+msgstr "Предупреждать о регистровых переменных, объявленных volatile."
 
 #: c-family/c.opt:1159
 msgid "Warn on direct virtual inheritance."
-msgstr ""
+msgstr "Предупреждать о прямом виртуальном наследовании."
 
 #: c-family/c.opt:1163
-#, fuzzy
-#| msgid "%qT has virtual bases, default move assignment operator cannot be generated"
 msgid "Warn if a virtual base has a non-trivial move assignment operator."
-msgstr "%qT имеет виртуальные базы, подразумеваемый оператор присваивания с перемещением не может быть сгенерирован"
+msgstr "Предупреждать, если виртуальная база имеет нетривиальный оператор присваивания с перемещением (move)."
 
 #: c-family/c.opt:1167
 msgid "In C++, nonzero means warn about deprecated conversion from string literals to 'char *'.  In C, similar warning, except that the conversion is of course not deprecated by the ISO C standard."
-msgstr "В C++ не 0 означает предупреждать об устаревших преобразованиях из строковых литералов в 'char *'. В C аналогичные предупреждения, с той разницей, что это преобразование допустимо в ISO C."
+msgstr "В C++ не 0 означает предупреждать об устаревших преобразованиях из строковых литералов в 'char *'.  В C аналогичные предупреждения, с той разницей, что это преобразование допустимо в ISO C."
 
 #: c-family/c.opt:1171
-#, fuzzy
-#| msgid "Warn when a literal '0' is used as null pointer"
 msgid "Warn when a literal '0' is used as null pointer."
-msgstr "Предупреждать, если литерал '0' используется как пустой указатель"
+msgstr "Предупреждать, если литерал '0' используется как пустой указатель."
 
 #: c-family/c.opt:1175
-#, fuzzy
-#| msgid "Warn about misuses of pragmas"
 msgid "Warn about useless casts."
-msgstr "Предупреждать о неправильном использовании прагм"
+msgstr "Предупреждать о бесполезных приведениях типов."
 
 #: c-family/c.opt:1179
 msgid "Warn if a class type has a base or a field whose type uses the anonymous namespace or depends on a type with no linkage."
-msgstr ""
+msgstr "Предупреждать, если тип класса имеет базу или поле, тип которого использует анонимное пространство имен или зависит от типа, не имеющего связывания."
 
 #: c-family/c.opt:1183
-#, fuzzy
-#| msgid "Warn when a declaration does not specify a type"
 msgid "Warn when a declaration has duplicate const, volatile, restrict or _Atomic specifier."
-msgstr "Предупреждать о декларациях, в которых не задан тип"
+msgstr "Предупреждать о декларациях, в которых продублированы спецификаторы const, volatile, restrict или _Atomic."
 
 #: c-family/c.opt:1187
 msgid "Warn when an argument passed to a restrict-qualified parameter aliases with another argument."
-msgstr ""
+msgstr "Предупреждать, если аргумент, переданный в качестве restrict-параметра, перекрывается с другим аргументом."
 
 #: c-family/c.opt:1192
-#, fuzzy
-#| msgid "A synonym for -std=c89 (for C) or -std=c++98 (for C++)"
 msgid "A synonym for -std=c89 (for C) or -std=c++98 (for C++)."
-msgstr "То же, что -std=c89 (для C) или -std=c++98 (для C++)"
+msgstr "То же, что -std=c89 (для C) или -std=c++98 (для C++)."
 
 #: c-family/c.opt:1200
 msgid "The version of the C++ ABI used for -Wabi warnings and link compatibility aliases."
-msgstr ""
+msgstr "Версия C++ ABI, используемая для предупреждений по -Wabi и алиасов при линковке."
 
 #: c-family/c.opt:1204
-#, fuzzy
-#| msgid "Enforce class member access control semantics"
 msgid "Enforce class member access control semantics."
-msgstr "Реализовать семантику управления доступом для элементов классов"
+msgstr "Реализовать семантику управления доступом для элементов классов."
 
 #: c-family/c.opt:1208
 msgid "-fada-spec-parent=unit  Dump Ada specs as child units of given parent."
-msgstr ""
+msgstr "-fada-spec-parent=unit  Выдать Ada спецификации как дочерние элементы заданного предка."
 
 #: c-family/c.opt:1212
 msgid "Support C++17 allocation of over-aligned types."
-msgstr ""
+msgstr "Включить поддержку размещения типов с повышенным выравниванием стандарта C++17."
 
 #: c-family/c.opt:1216
 msgid "-faligned-new=<N> Use C++17 over-aligned type allocation for alignments greater than N."
-msgstr ""
+msgstr "-faligned-new=<N> Использовать размещение типов с повышенным выравниванием C++17, когда выравнивание превышает N."
 
 #: c-family/c.opt:1223
-#, fuzzy
-#| msgid "Allow variadic functions without named parameter"
 msgid "Allow variadic functions without named parameter."
-msgstr "Разрешить функции с переменным числом аргументов без именованных параметров"
+msgstr "Разрешить функции с переменным числом аргументов без именованных параметров."
 
 #: c-family/c.opt:1227 c-family/c.opt:1478 c-family/c.opt:1803
 #: c-family/c.opt:1807 c-family/c.opt:1823
-#, fuzzy
-#| msgid "No longer supported"
 msgid "No longer supported."
-msgstr "Больше не поддерживается"
+msgstr "Больше не поддерживается."
 
 #: c-family/c.opt:1231
-#, fuzzy
-#| msgid "Recognize the \"asm\" keyword"
 msgid "Recognize the \"asm\" keyword."
-msgstr "Распознавать ключевое слово \"asm\""
+msgstr "Распознавать ключевое слово \"asm\"."
 
 #: c-family/c.opt:1239
-#, fuzzy
-#| msgid "Recognize built-in functions"
 msgid "Recognize built-in functions."
-msgstr "Включить поддержку встроенных функций"
+msgstr "Включить поддержку встроенных функций."
 
 #: c-family/c.opt:1246
 msgid "Where shorter, use canonicalized paths to systems headers."
-msgstr ""
+msgstr "Использовать канонизированные маршруты к системным заголовкам, если они короче."
 
 #: c-family/c.opt:1250
 msgid "Add Pointer Bounds Checker instrumentation.  fchkp-* flags are used to control instrumentation.  Currently available for C, C++ and ObjC."
-msgstr ""
+msgstr "Выполнить инструментирование для проверки границ указателей.  Для управления инструментированием используйте ключи fchkp-*.  Поддерживается для C, C++, ObjC."
 
 #: c-family/c.opt:1255
 msgid "Generate pointer bounds checks for variables with incomplete type."
@@ -8176,15 +7278,15 @@
 
 #: c-family/c.opt:1259
 msgid "Use zero bounds for all incoming arguments in 'main' function.  It helps when instrumented binaries are used with legacy libs."
-msgstr ""
+msgstr "Использовать нулевые границы для входных аргументов функции 'main'.  Это помогает, когда инструментированные бинарные файлы используются с унаследованными библиотеками."
 
 #: c-family/c.opt:1264
 msgid "Forces Pointer Bounds Checker to use narrowed bounds for address of the first field in the structure.  By default pointer to the first field has the same bounds as pointer to the whole structure."
-msgstr ""
+msgstr "При проверке границ указателей для адреса первого поля в структуре использовать более узкие границы.  По умолчанию указатель на первое поле имеет те же границы, что и указатель на всю структуру."
 
 #: c-family/c.opt:1270
 msgid "Control how Pointer Bounds Checker handle pointers to object fields.  When narrowing is on, field bounds are used.  Otherwise full object bounds are used."
-msgstr ""
+msgstr "Задает режим проверки границ указателей на поля объектов.  Если сужение границ включено, то используются границы для полей.  Иначе применяются границы для всего объекта."
 
 #: c-family/c.opt:1275
 msgid "Forces Pointer Bounds Checker to use bounds of the innermost arrays in case of nested static arrays access.  By default outermost array is used."
@@ -8200,75 +7302,59 @@
 
 #: c-family/c.opt:1291
 msgid "Allow to use *_nobnd versions of string functions by Pointer Bounds Checker."
-msgstr ""
+msgstr "Разрешить использование *_nobnd версий строковых функций при проверке границ указателей."
 
 #: c-family/c.opt:1295
 msgid "Allow to use *_nochk versions of string functions by Pointer Bounds Checker."
-msgstr ""
+msgstr "Разрешить использование *_nochk версий строковых функций при проверке границ указателей."
 
 #: c-family/c.opt:1299
 msgid "Use statically initialized variable for vars bounds instead of generating them each time it is required."
-msgstr ""
+msgstr "Использовать статически инициализированные переменные для границ переменных вместо генерации этих границ всякий раз, когда они требуются."
 
 #: c-family/c.opt:1304
 msgid "Use statically initialized variable for constant bounds instead of generating them each time it is required."
-msgstr ""
+msgstr "Использовать статически инициализированные переменные для границ константных значений вместо генерации этих границ всякий раз, когда они требуются."
 
 #: c-family/c.opt:1309
 msgid "With this option zero size obtained dynamically for objects with incomplete type will be treated as infinite."
-msgstr ""
+msgstr "При проверке границ указателей трактовать полученный динамически нулевой размер для объектов с неполным типом как бесконечный размер."
 
 #: c-family/c.opt:1314
-#, fuzzy
-#| msgid "Generate checks for references to NULL"
 msgid "Generate checks for all read accesses to memory."
-msgstr "Генерировать код проверки ссылок по NULL-указателям"
+msgstr "Генерировать проверки для всех доступов к памяти на чтение."
 
 #: c-family/c.opt:1318
-#, fuzzy
-#| msgid "Generate checks for references to NULL"
 msgid "Generate checks for all write accesses to memory."
-msgstr "Генерировать код проверки ссылок по NULL-указателям"
+msgstr "Генерировать проверки для всех доступов к памяти на запись."
 
 #: c-family/c.opt:1322
-#, fuzzy
-#| msgid "Generate phony targets for all headers"
 msgid "Generate bounds stores for pointer writes."
-msgstr "Добавлять фиктивные правила для всех заголовочных файлов"
+msgstr "генерировать сохранение границ для записей по указателям."
 
 #: c-family/c.opt:1326
-#, fuzzy
-#| msgid "Generate call insns as indirect calls"
 msgid "Generate bounds passing for calls."
-msgstr "Генерировать инструкции вызова как косвенные вызовы"
+msgstr "Генерировать передачу границ при вызовах функций."
 
 #: c-family/c.opt:1330
-#, fuzzy
-#| msgid "argument of function call might be a candidate for a format attribute"
 msgid "Instrument only functions marked with bnd_instrument attribute."
-msgstr "аргумент вызова функции мог быть кандидатом для атрибута формата"
+msgstr "Инструментировать только функции с атрибутом аргумент bnd_instrument."
 
 #: c-family/c.opt:1334
 msgid "Transform instrumented builtin calls into calls to wrappers."
-msgstr ""
+msgstr "Трансформировать инструментированные вызовы встроенных функций в вызовы оберток."
 
 #: c-family/c.opt:1344
-#, fuzzy
-#| msgid "Deprecated.  This switch has no effect"
 msgid "Deprecated in GCC 8.  This switch has no effect."
-msgstr "Устаревший ключ. Игнорируется."
+msgstr "Deprecated in GCC 8.  Ничего не делает."
 
 #: c-family/c.opt:1348
-#, fuzzy
-#| msgid "Enable support for huge objects"
 msgid "Enable support for C++ concepts."
-msgstr "Включить поддержку больших объектов"
+msgstr "Включить поддержку концептов C++."
 
 #: c-family/c.opt:1352
-#, fuzzy
-#| msgid "Allow the arguments of the '?' operator to have different types"
 msgid "Allow the arguments of the '?' operator to have different types."
-msgstr "Разрешить разные типы для операндов операции '?'"
+msgstr "Разрешить разные типы для операндов операции '?'."
 
 #: c-family/c.opt:1359
 #, c-format
@@ -8276,40 +7362,28 @@
 msgstr "не задано имя класса для %qs"
 
 #: c-family/c.opt:1360
-#, fuzzy
-#| msgid "-fconst-string-class=<name>\tUse class <name> for constant strings"
 msgid "-fconst-string-class=<name>\tUse class <name> for constant strings."
-msgstr "-fconst-string-class=<имя>\tИспользовать class <имя> как тип строковых констант"
+msgstr "-fconst-string-class=<имя>\tИспользовать class <имя> как тип строковых констант."
 
 #: c-family/c.opt:1364
-#, fuzzy
-#| msgid "-fconstexpr-depth=<number>\tSpecify maximum constexpr recursion depth"
 msgid "-fconstexpr-depth=<number>\tSpecify maximum constexpr recursion depth."
-msgstr "-fconstexpr-depth=<number>\tМаксимальная глубина рекурсии константных выражений"
+msgstr "-fconstexpr-depth=<number>\tМаксимальная глубина рекурсии константных выражений."
 
 #: c-family/c.opt:1368
-#, fuzzy
-#| msgid "-fconstexpr-depth=<number>\tSpecify maximum constexpr recursion depth"
 msgid "-fconstexpr-loop-limit=<number>\tSpecify maximum constexpr loop iteration count."
-msgstr "-fconstexpr-depth=<number>\tМаксимальная глубина рекурсии константных выражений"
+msgstr "-fconstexpr-loop-limit=<number>\tМаксимальное значение константного счетчика итераций цикла."
 
 #: c-family/c.opt:1372
-#, fuzzy
-#| msgid "Emit debug annotations during preprocessing"
 msgid "Emit debug annotations during preprocessing."
-msgstr "Генерировать отладочные аннотации во время препроцессирования"
+msgstr "Генерировать отладочные аннотации во время препроцессирования."
 
 #: c-family/c.opt:1376
-#, fuzzy
-#| msgid "-fdeduce-init-list\tenable deduction of std::initializer_list for a template type parameter from a brace-enclosed initializer-list"
 msgid "-fdeduce-init-list\tenable deduction of std::initializer_list for a template type parameter from a brace-enclosed initializer-list."
-msgstr "-fdeduce-init-list\tвключить дедукцию std::initializer_list для параметра с шаблонным типом из списка инициализации в фигурных скобках"
+msgstr "-fdeduce-init-list\tвключить дедукцию std::initializer_list для параметра с шаблонным типом из списка инициализации в фигурных скобках."
 
 #: c-family/c.opt:1380
-#, fuzzy
-#| msgid "Warn when all constructors and destructors are private"
 msgid "Factor complex constructors and destructors to favor space over speed."
-msgstr "Предупреждать о классах, в которых все конструкторы и деструкторы private"
+msgstr "Факторизовать сложные конструкторы и деструкторы для оптимизации по памяти, а не по скорости."
 
 #: c-family/c.opt:1388
 msgid "Print hierarchical comparisons when template types are mismatched."
@@ -8320,10 +7394,8 @@
 msgstr "Препроцессировать только директивы"
 
 #: c-family/c.opt:1396
-#, fuzzy
-#| msgid "Permit '$' as an identifier character"
 msgid "Permit '$' as an identifier character."
-msgstr "Разрешить использование '$' в идентификаторах"
+msgstr "Разрешить использование '$' в идентификаторах."
 
 #: c-family/c.opt:1400
 msgid "-fmacro-prefix-map=<old>=<new> Map one directory name to another in __FILE__, __BASE_FILE__, and __builtin_FILE()."
@@ -8331,11 +7403,11 @@
 
 #: c-family/c.opt:1404
 msgid "Write all declarations as Ada code transitively."
-msgstr ""
+msgstr "Выдать транзитивный дамп всех деклараций в виде кода Ada."
 
 #: c-family/c.opt:1408
 msgid "Write all declarations as Ada code for the given file only."
-msgstr ""
+msgstr "Выдать транзитивный дамп всех деклараций в виде кода Ada только для заданного файла."
 
 #: c-family/c.opt:1415
 msgid "-fno-elide-type Do not elide common elements in template comparisons."
@@ -8342,62 +7414,44 @@
 msgstr ""
 
 #: c-family/c.opt:1419
-#, fuzzy
-#| msgid "Generate code to check exception specifications"
 msgid "Generate code to check exception specifications."
-msgstr "Генерировать код для проверки исключительных ситуаций"
+msgstr "Генерировать код для проверки исключительных ситуаций."
 
 #: c-family/c.opt:1426
-#, fuzzy
-#| msgid "-fexec-charset=<cset>\tConvert all strings and character constants to character set <cset>"
 msgid "-fexec-charset=<cset>\tConvert all strings and character constants to character set <cset>."
-msgstr "-fexec-charset=<кодировка>\tКонвертировать строковые и char-константы в указанную <кодировку>"
+msgstr "-fexec-charset=<кодировка>\tКонвертировать строковые и char-константы в указанную <кодировку>."
 
 #: c-family/c.opt:1430
-#, fuzzy
-#| msgid "Permit universal character names (\\u and \\U) in identifiers"
 msgid "Permit universal character names (\\u and \\U) in identifiers."
-msgstr "Разрешить универсальные имена литер (\\u and \\U) в идентификаторах"
+msgstr "Разрешить универсальные имена литер (\\u and \\U) в идентификаторах."
 
 #: c-family/c.opt:1434
-#, fuzzy
-#| msgid "-finput-charset=<cset>\tSpecify the default character set for source files"
 msgid "-finput-charset=<cset>\tSpecify the default character set for source files."
-msgstr "-finput-charset=<кодировка>\tКодировка исходных файлов по умолчанию"
+msgstr "-finput-charset=<кодировка>\tКодировка исходных файлов по умолчанию."
 
 #: c-family/c.opt:1438
 msgid "Support dynamic initialization of thread-local variables in a different translation unit."
-msgstr ""
+msgstr "Включить поддержку динамической инициализации локальных для потока переменных в другой единице трансляции."
 
 #: c-family/c.opt:1445
-#, fuzzy
-#| msgid "Scope of for-init-statement variables is local to the loop"
 msgid "Scope of for-init-statement variables is local to the loop."
-msgstr "Область действия переменных, объявленных в заголовке цикла, ограничивается рамками цикла"
+msgstr "Область действия переменных, объявленных в заголовке цикла, ограничивается рамками цикла."
 
 #: c-family/c.opt:1449
-#, fuzzy
-#| msgid "Do not assume that standard C libraries and \"main\" exist"
 msgid "Do not assume that standard C libraries and \"main\" exist."
-msgstr "Не предполагать наличие стандартных библиотек C и функции \"main\""
+msgstr "Не предполагать наличие стандартных библиотек C и функции \"main\"."
 
 #: c-family/c.opt:1453
-#, fuzzy
-#| msgid "Recognize GNU-defined keywords"
 msgid "Recognize GNU-defined keywords."
-msgstr "Распознавать ключевые слова GNU-расширений"
+msgstr "Распознавать ключевые слова GNU-расширений."
 
 #: c-family/c.opt:1457
-#, fuzzy
-#| msgid "Generate code for GNU runtime environment"
 msgid "Generate code for GNU runtime environment."
-msgstr "Генерировать код для среды выполнения GNU"
+msgstr "Генерировать код для среды выполнения GNU."
 
 #: c-family/c.opt:1461
-#, fuzzy
-#| msgid "Use traditional GNU semantics for inline functions"
 msgid "Use traditional GNU semantics for inline functions."
-msgstr "Использовать для inline функций традиционную семантику GNU"
+msgstr "Использовать для inline функций традиционную семантику GNU."
 
 #: c-family/c.opt:1467
 msgid "-fhandle-exceptions has been renamed -fexceptions (and is now on by default)"
@@ -8404,44 +7458,32 @@
 msgstr "-fhandle-exceptions переименован в -fexceptions (и действует по умолчанию)"
 
 #: c-family/c.opt:1474
-#, fuzzy
-#| msgid "Assume normal C execution environment"
 msgid "Assume normal C execution environment."
-msgstr "Генерировать код для стандартной среды выполнения C"
+msgstr "Генерировать код для стандартной среды выполнения C."
 
 #: c-family/c.opt:1482
-#, fuzzy
-#| msgid "Export functions even if they can be inlined"
 msgid "Export functions even if they can be inlined."
-msgstr "Экспортировать функции, даже если возможна их inline-подстановка"
+msgstr "Экспортировать функции, даже если возможна их inline-подстановка."
 
 #: c-family/c.opt:1486
-#, fuzzy
-#| msgid "Emit implicit instantiations of inline templates"
 msgid "Emit implicit instantiations of inline templates."
-msgstr "Генерировать неявные конкретизации inline-шаблонов"
+msgstr "Генерировать неявные конкретизации inline-шаблонов."
 
 #: c-family/c.opt:1490
-#, fuzzy
-#| msgid "Emit implicit instantiations of templates"
 msgid "Emit implicit instantiations of templates."
-msgstr "Генерировать неявные конкретизации шаблонов"
+msgstr "Генерировать неявные конкретизации шаблонов."
 
 #: c-family/c.opt:1494
 msgid "Implement C++17 inheriting constructor semantics."
-msgstr ""
+msgstr "Включить реализацию семантики наследующих конструкторов C++17."
 
 #: c-family/c.opt:1498
-#, fuzzy
-#| msgid "Inject friend functions into enclosing namespace"
 msgid "Inject friend functions into enclosing namespace."
-msgstr "Вставлять friend-функции в объемлющие namespace-области"
+msgstr "Вставлять friend-функции в объемлющие пространства имен."
 
 #: c-family/c.opt:1502
-#, fuzzy
-#| msgid "Don't emit dllexported inline functions unless needed"
 msgid "Don't emit dllexported inline functions unless needed."
-msgstr "Не генерировать dll-экспортированные inline функции без необходимости"
+msgstr "Не генерировать dll-экспортированные inline функции без необходимости."
 
 #: c-family/c.opt:1509
 msgid "Allow implicit conversions between vectors with differing numbers of subparts and/or differing element types."
@@ -8448,48 +7490,37 @@
 msgstr "Разрешить неявные преобразования типов между векторами с разным числом элементов или с разными типами элементов"
 
 #: c-family/c.opt:1513
-#, fuzzy
-#| msgid "Don't warn about uses of Microsoft extensions"
 msgid "Don't warn about uses of Microsoft extensions."
-msgstr "Не предупреждать об использовании расширений Microsoft"
+msgstr "Не предупреждать об использовании расширений Microsoft."
 
 #: c-family/c.opt:1532
 msgid "Implement resolution of DR 150 for matching of template template arguments."
-msgstr ""
+msgstr "Включить реализацию исправления DR 150 для сопоставления аргументов шаблона, являющихся шаблонами."
 
 #: c-family/c.opt:1536
-#, fuzzy
-#| msgid "Generate code for NeXT (Apple Mac OS X) runtime environment"
 msgid "Generate code for NeXT (Apple Mac OS X) runtime environment."
-msgstr "Генерировать код для среды выполнения NeXT (Apple Mac OS X)"
+msgstr "Генерировать код для среды выполнения NeXT (Apple Mac OS X)."
 
 #: c-family/c.opt:1540
-#, fuzzy
-#| msgid "Assume that receivers of Objective-C messages may be nil"
 msgid "Assume that receivers of Objective-C messages may be nil."
-msgstr "Предполагать что получатели сообщений Objective-C могут быть пустыми"
+msgstr "Предполагать что получатели сообщений Objective-C могут быть пустыми."
 
 #: c-family/c.opt:1544
 msgid "Allow access to instance variables as if they were local declarations within instance method implementations."
-msgstr ""
+msgstr "Разрешить доступ к instance-переменным как если бы они были локальными декларациями в реализациях instance-методов."
 
 #: c-family/c.opt:1548
-#, fuzzy
-#| msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility"
 msgid "-fvisibility=[private|protected|public|package]\tSet the default symbol visibility."
-msgstr "-fvisibility=[default|internal|hidden|protected]\tУстановить атрибут видимости символов по умолчанию"
+msgstr "-fvisibility=[private|protected|public|package]\tУстановить атрибут видимости символов по умолчанию."
 
 #: c-family/c.opt:1551
-#, fuzzy, c-format
-#| msgid "unrecognized visibility value %qs"
+#, c-format
 msgid "unrecognized ivar visibility value %qs"
-msgstr "некорректный тип видимости %qs"
+msgstr "некорректный тип видимости ivar %qs"
 
 #: c-family/c.opt:1573
-#, fuzzy
-#| msgid "Treat a throw() exception specification as noexcept to improve code size"
 msgid "Treat a throw() exception specification as noexcept to improve code size."
-msgstr "Трактовать спецификации throw() как noexcept для сокращения размера кода"
+msgstr "Трактовать спецификации throw() как noexcept для сокращения размера кода."
 
 #: c-family/c.opt:1577
 msgid "Specify which ABI to use for Objective-C family code and meta-data generation."
@@ -8496,28 +7527,20 @@
 msgstr "Задать ABI кода для языков семейства Objective-C и генерации метаданных."
 
 #: c-family/c.opt:1583
-#, fuzzy
-#| msgid "Generate special Objective-C methods to initialize/destroy non-POD C++ ivars, if needed"
 msgid "Generate special Objective-C methods to initialize/destroy non-POD C++ ivars, if needed."
-msgstr "Генерировать специальные методы Objective-C для инициации/разрушения не-POD С++ instance-переменных, при необходимости"
+msgstr "Генерировать специальные методы Objective-C для инициации/разрушения не-POD С++ instance-переменных, при необходимости."
 
 #: c-family/c.opt:1587
-#, fuzzy
-#| msgid "Allow fast jumps to the message dispatcher"
 msgid "Allow fast jumps to the message dispatcher."
-msgstr "Разрешать быстрый переход к обработчику сообщений"
+msgstr "Разрешать быстрый переход к обработчику сообщений."
 
 #: c-family/c.opt:1593
-#, fuzzy
-#| msgid "Enable Objective-C exception and synchronization syntax"
 msgid "Enable Objective-C exception and synchronization syntax."
-msgstr "Поддерживать синтаксис исключений и синхронизации Objective-C"
+msgstr "Поддерживать синтаксис исключений и синхронизации Objective-C."
 
 #: c-family/c.opt:1597
-#, fuzzy
-#| msgid "Enable garbage collection (GC) in Objective-C/Objective-C++ programs"
 msgid "Enable garbage collection (GC) in Objective-C/Objective-C++ programs."
-msgstr "Включить сборку мусора (GC) в программах на Objective-C/Objective-C++"
+msgstr "Включить сборку мусора (GC) в программах на Objective-C/Objective-C++."
 
 #: c-family/c.opt:1601
 msgid "Enable inline checks for nil receivers with the NeXT runtime and ABI version 2."
@@ -8524,656 +7547,451 @@
 msgstr "Включить inline проверки нулевых получателей при помощи runtime NeXT и ABI версии 2."
 
 #: c-family/c.opt:1606
-#, fuzzy
-#| msgid "Enable Objective-C setjmp exception handling runtime"
 msgid "Enable Objective-C setjmp exception handling runtime."
-msgstr "Подключить поддержку времени выполнения для обработки исключений Objective-C setjmp"
+msgstr "Подключить поддержку времени выполнения для обработки исключений Objective-C setjmp."
 
 #: c-family/c.opt:1610
-#, fuzzy
-#| msgid "Conform to the Objective-C 1.0 language as implemented in GCC 4.0"
 msgid "Conform to the Objective-C 1.0 language as implemented in GCC 4.0."
-msgstr "Компилировать в соответствии со спецификацией языка Objective-C 1.0 в реализации GCC 4.0"
+msgstr "Компилировать в соответствии со спецификацией языка Objective-C 1.0 в реализации GCC 4.0."
 
 #
 #: c-family/c.opt:1614
-#, fuzzy
-#| msgid "Enable OpenMP"
 msgid "Enable OpenACC."
-msgstr "Включить OpenMP"
+msgstr "Включить OpenACC."
 
 #: c-family/c.opt:1618
 msgid "Specify default OpenACC compute dimensions."
-msgstr ""
+msgstr "Задает измерения вычислений OpenACC по умолчанию."
 
 #: c-family/c.opt:1622
-#, fuzzy
-#| msgid "Enable OpenMP (implies -frecursive in Fortran)"
 msgid "Enable OpenMP (implies -frecursive in Fortran)."
-msgstr "Включить OpenMP (для Фортрана подразумевает -frecursive)"
+msgstr "Включить OpenMP (для Фортрана подразумевает -frecursive)."
 
 #: c-family/c.opt:1626
-#, fuzzy
-#| msgid "Unclassifiable OpenMP directive at %C"
 msgid "Enable OpenMP's SIMD directives."
-msgstr "Неклассифицируемая OpenMP директива в %C"
+msgstr "Включить SIMD-директивы OpenMP."
 
 #: c-family/c.opt:1630
-#, fuzzy
-#| msgid "Recognize C++ keywords like \"compl\" and \"xor\""
 msgid "Recognize C++ keywords like \"compl\" and \"xor\"."
-msgstr "Распознавать ключевые слова C++, такие как \"compl\" и \"xor\""
+msgstr "Распознавать ключевые слова C++, такие как \"compl\" и \"xor\"."
 
 #: c-family/c.opt:1641
-#, fuzzy
-#| msgid "Look for and use PCH files even when preprocessing"
 msgid "Look for and use PCH files even when preprocessing."
-msgstr "Использовать и искать файлы PCH даже во время препроцессирования"
+msgstr "Использовать и искать файлы PCH даже во время препроцессирования."
 
 #: c-family/c.opt:1645
-#, fuzzy
-#| msgid "Downgrade conformance errors to warnings"
 msgid "Downgrade conformance errors to warnings."
-msgstr "Ошибки соответствия трактовать как предупреждения"
+msgstr "Ошибки соответствия трактовать как предупреждения."
 
 #: c-family/c.opt:1649
-#, fuzzy
-#| msgid "Enable Plan 9 language extensions"
 msgid "Enable Plan 9 language extensions."
-msgstr "Включить расширения языка Plan 9"
+msgstr "Включить расширения языка Plan 9."
 
 #: c-family/c.opt:1653
-#, fuzzy
-#| msgid "Treat the input file as already preprocessed"
 msgid "Treat the input file as already preprocessed."
-msgstr "Считать, что входной файл уже препроцессирован"
+msgstr "Считать, что входной файл уже препроцессирован."
 
 #: c-family/c.opt:1661
-#, fuzzy
-#| msgid "-ftrack-macro-expansion=<0|1|2>  Track locations of tokens coming from macro expansion and display them in error messages"
 msgid "-ftrack-macro-expansion=<0|1|2>  Track locations of tokens coming from macro expansion and display them in error messages."
-msgstr "-ftrack-macro-expansion=<0|1|2>  Отслеживать позиции элементов из макроподстановок и показывать их в сообщениях об ошибках"
+msgstr "-ftrack-macro-expansion=<0|1|2>  Отслеживать позиции элементов из макроподстановок и показывать их в сообщениях об ошибках."
 
 #: c-family/c.opt:1665
-#, fuzzy
-#| msgid "-fno-pretty-templates Do not pretty-print template specializations as the template signature followed by the arguments"
 msgid "-fno-pretty-templates Do not pretty-print template specializations as the template signature followed by the arguments."
-msgstr "-fno-pretty-templates Не использовать красивую печать специализаций шаблонов в виде сигнатуры шаблона с последующими аргументами"
+msgstr "-fno-pretty-templates Не использовать красивую печать специализаций шаблонов в виде сигнатуры шаблона с последующими аргументами."
 
 #: c-family/c.opt:1669
 msgid "Treat known sprintf return values as constants."
-msgstr ""
+msgstr "Трактовать известные возвращаемые значений sprintf как константы."
 
 #: c-family/c.opt:1673
-#, fuzzy
-#| msgid "Used in Fix-and-Continue mode to indicate that object files may be swapped in at runtime"
 msgid "Used in Fix-and-Continue mode to indicate that object files may be swapped in at runtime."
-msgstr "Используется в режиме Fix-and-Continue для указания о том, что возможна подкачка объектных файлов во время выполнения"
+msgstr "Используется в режиме Fix-and-Continue для указания о том, что возможна подкачка объектных файлов во время выполнения."
 
 #: c-family/c.opt:1677
-#, fuzzy
-#| msgid "Enable automatic template instantiation"
 msgid "Enable automatic template instantiation."
-msgstr "Включить автоматическую конкретизацию шаблонов"
+msgstr "Включить автоматическую конкретизацию шаблонов."
 
 #: c-family/c.opt:1681
-#, fuzzy
-#| msgid "Generate run time type descriptor information"
 msgid "Generate run time type descriptor information."
-msgstr "Генерировать информацию о типах, доступную во время выполнения"
+msgstr "Генерировать информацию о типах, доступную во время выполнения."
 
 #: c-family/c.opt:1685 ada/gcc-interface/lang.opt:77
-#, fuzzy
-#| msgid "Use the narrowest integer type possible for enumeration types"
 msgid "Use the narrowest integer type possible for enumeration types."
-msgstr "Использовать для перечислимых типов минимальный целочисленный тип"
+msgstr "Использовать для перечислимых типов минимальный целочисленный тип."
 
 #: c-family/c.opt:1689
-#, fuzzy
-#| msgid "Force the underlying type for \"wchar_t\" to be \"unsigned short\""
 msgid "Force the underlying type for \"wchar_t\" to be \"unsigned short\"."
-msgstr "Установить для \"wchar_t\" тип \"unsigned short\""
+msgstr "Установить для \"wchar_t\" тип \"unsigned short\"."
 
 #: c-family/c.opt:1693
-#, fuzzy
-#| msgid "When \"signed\" or \"unsigned\" is not given make the bitfield signed"
 msgid "When \"signed\" or \"unsigned\" is not given make the bitfield signed."
-msgstr "По умолчанию считать битовые поля знаковыми"
+msgstr "По умолчанию считать битовые поля знаковыми."
 
 #: c-family/c.opt:1697 ada/gcc-interface/lang.opt:81
-#, fuzzy
-#| msgid "Make \"char\" signed by default"
 msgid "Make \"char\" signed by default."
-msgstr "По умолчанию считать тип \"char\" знаковым"
+msgstr "По умолчанию считать тип \"char\" знаковым."
 
 #: c-family/c.opt:1701
-#, fuzzy
-#| msgid "Enable decimal floating point hardware support"
 msgid "Enable C++14 sized deallocation support."
-msgstr "Использовать аппаратную реализацию десятичной плавающей арифметики"
+msgstr "Включить поддержку деаллокации по размеру C++14."
 
 #: c-family/c.opt:1708
 msgid "-fsso-struct=[big-endian|little-endian|native]\tSet the default scalar storage order."
-msgstr ""
+msgstr "-fsso-struct=[big-endian|little-endian|native]\tУстановить порядок байт для хранения скалярных объектов в памяти."
 
 #: c-family/c.opt:1711
-#, fuzzy, c-format
-#| msgid "unrecognized register name %qs"
+#, c-format
 msgid "unrecognized scalar storage order value %qs"
-msgstr "некорректное имя регистра %qs"
+msgstr "некорректное значение порядка байт для хранения скаляров в памяти %qs"
 
 #: c-family/c.opt:1724
-#, fuzzy
-#| msgid "Display statistics accumulated during compilation"
 msgid "Display statistics accumulated during compilation."
-msgstr "Показать статистику компиляции"
+msgstr "Показать статистику компиляции."
 
 #: c-family/c.opt:1728
-#, fuzzy
-#| msgid "Assume that values of enumeration type are always within the minimum range of that type"
 msgid "Assume that values of enumeration type are always within the minimum range of that type."
-msgstr "Предполагать, что значения перечислимого типа всегда находятся в минимальном диапазоне этого типа"
+msgstr "Предполагать, что значения перечислимого типа всегда находятся в минимальном диапазоне этого типа."
 
 #: c-family/c.opt:1735 c-family/c.opt:1740
 msgid "Follow the C++17 evaluation order requirements for assignment expressions, shift, member function calls, etc."
-msgstr ""
+msgstr "Следовать порядку вычислений C++17 для выражений присваивания, сдвигов, вызовов функций-членов и т.д."
 
 #: c-family/c.opt:1757
-#, fuzzy
-#| msgid "-ftabstop=<number>\tDistance between tab stops for column reporting"
 msgid "-ftabstop=<number>\tDistance between tab stops for column reporting."
-msgstr "-ftabstop=<number>\tИнтервал табуляции для правильного определения номера колонки в диагностике"
+msgstr "-ftabstop=<number>\tИнтервал табуляции для правильного определения номера колонки в диагностике."
 
 #: c-family/c.opt:1761
-#, fuzzy
-#| msgid "Set the maximum number of iterations for RPTS to N"
 msgid "Set the maximum number of template instantiation notes for a single warning or error."
-msgstr "Задать максимальное число итераций для RPTS"
+msgstr "Задать максимальное число замечаний о подстановке шаблона для одного предупреждения или сообщения об ошибке."
 
 #: c-family/c.opt:1768
-#, fuzzy
-#| msgid "-ftemplate-depth=<number>\tSpecify maximum template instantiation depth"
 msgid "-ftemplate-depth=<number>\tSpecify maximum template instantiation depth."
-msgstr "-ftemplate-depth=<number>\tМаксимальная глубина конкретизации шаблонов"
+msgstr "-ftemplate-depth=<number>\tМаксимальная глубина конкретизации шаблонов."
 
 #: c-family/c.opt:1775
-#, fuzzy
-#| msgid "-fno-threadsafe-statics\tDo not generate thread-safe code for initializing local statics"
 msgid "-fno-threadsafe-statics\tDo not generate thread-safe code for initializing local statics."
-msgstr "-fno-threadsafe-statics\tНе генерировать поточно-безопасный код для инициализации локальных статических переменных"
+msgstr "-fno-threadsafe-statics\tНе генерировать поточно-безопасный код для инициализации локальных статических переменных."
 
 #: c-family/c.opt:1779
-#, fuzzy
-#| msgid "When \"signed\" or \"unsigned\" is not given make the bitfield unsigned"
 msgid "When \"signed\" or \"unsigned\" is not given make the bitfield unsigned."
-msgstr "По умолчанию считать битовые поля беззнаковыми"
+msgstr "По умолчанию считать битовые поля беззнаковыми."
 
 #: c-family/c.opt:1783
-#, fuzzy
-#| msgid "Make \"char\" unsigned by default"
 msgid "Make \"char\" unsigned by default."
-msgstr "По умолчанию считать тип char беззнаковым"
+msgstr "По умолчанию считать тип char беззнаковым."
 
 #: c-family/c.opt:1787
-#, fuzzy
-#| msgid "Use __cxa_atexit to register destructors"
 msgid "Use __cxa_atexit to register destructors."
-msgstr "Использовать __cxa_atexit для регистрации деструкторов"
+msgstr "Использовать __cxa_atexit для регистрации деструкторов."
 
 #: c-family/c.opt:1791
-#, fuzzy
-#| msgid "Use __cxa_get_exception_ptr in exception handling"
 msgid "Use __cxa_get_exception_ptr in exception handling."
-msgstr "Использовать __cxa_get_exception_ptr для обработки исключений"
+msgstr "Использовать __cxa_get_exception_ptr для обработки исключений."
 
 #: c-family/c.opt:1795
-#, fuzzy
-#| msgid "Marks all inlined functions and methods as having hidden visibility"
 msgid "Marks all inlined functions and methods as having hidden visibility."
-msgstr "Отметить область видимости всех inline-подставленных функций и методов как hidden"
+msgstr "Отметить область видимости всех inline-подставленных функций и методов как hidden."
 
 #: c-family/c.opt:1799
-#, fuzzy
-#| msgid "Changes visibility to match Microsoft Visual Studio by default"
 msgid "Changes visibility to match Microsoft Visual Studio by default."
-msgstr "Изменить атрибуты видимости в соответствии с правилами Microsoft Visual Studio"
+msgstr "Изменить атрибуты видимости в соответствии с правилами Microsoft Visual Studio."
 
 #: c-family/c.opt:1811
-#, fuzzy
-#| msgid "Emit common-like symbols as weak symbols"
 msgid "Emit common-like symbols as weak symbols."
-msgstr "common-символы считать слабыми (weak)"
+msgstr "common-символы считать слабыми (weak)."
 
 #: c-family/c.opt:1815
-#, fuzzy
-#| msgid "-fwide-exec-charset=<cset>\tConvert all wide strings and character constants to character set <cset>"
 msgid "-fwide-exec-charset=<cset>\tConvert all wide strings and character constants to character set <cset>."
-msgstr "-fwide-exec-charset=<кодировка>\tКонстантные широкие символы и строки широких символов конвертировать в заданную <кодировку>"
+msgstr "-fwide-exec-charset=<кодировка>\tКонстантные широкие символы и строки широких символов конвертировать в заданную <кодировку>."
 
 #: c-family/c.opt:1819
-#, fuzzy
-#| msgid "Generate a #line directive pointing at the current working directory"
 msgid "Generate a #line directive pointing at the current working directory."
-msgstr "Генерировать директиву #строка, указывающую на текущий рабочий каталог"
+msgstr "Генерировать директиву #строка, указывающую на текущий рабочий каталог."
 
 #: c-family/c.opt:1827
-#, fuzzy
-#| msgid "Generate lazy class lookup (via objc_getClass()) for use in Zero-Link mode"
 msgid "Generate lazy class lookup (via objc_getClass()) for use in Zero-Link mode."
-msgstr "Генерировать ленивый поиск классов (при помощи objc_getClass()) для использования в режиме Zero-Link"
+msgstr "Генерировать ленивый поиск классов (при помощи objc_getClass()) для использования в режиме Zero-Link."
 
 #: c-family/c.opt:1831
-#, fuzzy
-#| msgid "Dump declarations to a .decl file"
 msgid "Dump declarations to a .decl file."
-msgstr "Вывести декларации в файл .decl"
+msgstr "Вывести декларации в файл .decl."
 
 #: c-family/c.opt:1835
-#, fuzzy
-#| msgid "-femit-struct-debug-baseonly\tAggressive reduced debug info for structs"
 msgid "-femit-struct-debug-baseonly\tAggressive reduced debug info for structs."
-msgstr "-femit-struct-debug-baseonly\tСильно сокращать отладочную информацию для структур"
+msgstr "-femit-struct-debug-baseonly\tСильно сокращать отладочную информацию для структур."
 
 #: c-family/c.opt:1839
-#, fuzzy
-#| msgid "-femit-struct-debug-reduced\tConservative reduced debug info for structs"
 msgid "-femit-struct-debug-reduced\tConservative reduced debug info for structs."
-msgstr "-femit-struct-debug-reduced\tУмеренно сокращать отладочную информацию для структур"
+msgstr "-femit-struct-debug-reduced\tУмеренно сокращать отладочную информацию для структур."
 
 #: c-family/c.opt:1843
-#, fuzzy
-#| msgid "-femit-struct-debug-detailed=<spec-list>\tDetailed reduced debug info for structs"
 msgid "-femit-struct-debug-detailed=<spec-list>\tDetailed reduced debug info for structs."
-msgstr "-femit-struct-debug-detailed=<spec-list>\tЗадает детальные инструкции по сокращению отладочной информации для структур"
+msgstr "-femit-struct-debug-detailed=<spec-list>\tЗадает детальные инструкции по сокращению отладочной информации для структур."
 
 #: c-family/c.opt:1847
 msgid "Interpret imaginary, fixed-point, or other gnu number suffix as the corresponding number literal rather than a user-defined number literal."
-msgstr ""
+msgstr "Интерпретировать суффиксы GNU для мнимой части, чисел с фиксированной точкой или другие суффиксы GNU для чисел как соответствующий числовой литерал, а не как пользовательский числовой литерал."
 
 #: c-family/c.opt:1852
-#, fuzzy
-#| msgid "-idirafter <dir>\tAdd <dir> to the end of the system include path"
 msgid "-idirafter <dir>\tAdd <dir> to the end of the system include path."
-msgstr "-idirafter <каталог>\tДобавить <каталог> в конец пути поиска системных заголовков"
+msgstr "-idirafter <каталог>\tДобавить <каталог> в конец пути поиска системных заголовков."
 
 #: c-family/c.opt:1856
-#, fuzzy
-#| msgid "-imacros <file>\tAccept definition of macros in <file>"
 msgid "-imacros <file>\tAccept definition of macros in <file>."
-msgstr "-imacros <файл>\tИспользовать макроопределения из <файла>"
+msgstr "-imacros <файл>\tИспользовать макроопределения из <файла>."
 
 #: c-family/c.opt:1860
-#, fuzzy
-#| msgid "-imultilib <dir>\tSet <dir> to be the multilib include subdirectory"
 msgid "-imultilib <dir>\tSet <dir> to be the multilib include subdirectory."
-msgstr "-imultilib <каталог>\tУстановить <каталог> как подкаталог мультибиблиотеки заголовков"
+msgstr "-imultilib <каталог>\tУстановить <каталог> как подкаталог мультибиблиотеки заголовков."
 
 #: c-family/c.opt:1864
-#, fuzzy
-#| msgid "-include <file>\tInclude the contents of <file> before other files"
 msgid "-include <file>\tInclude the contents of <file> before other files."
-msgstr "-include <файл>\tВключить содержимое <файла> перед компиляцией других файлов"
+msgstr "-include <файл>\tВключить содержимое <файла> перед компиляцией других файлов."
 
 #: c-family/c.opt:1868
-#, fuzzy
-#| msgid "-iprefix <path>\tSpecify <path> as a prefix for next two options"
 msgid "-iprefix <path>\tSpecify <path> as a prefix for next two options."
-msgstr "-iprefix <префикс>\tЗадает <префикс> для следующих двух ключей"
+msgstr "-iprefix <префикс>\tЗадает <префикс> для следующих двух ключей."
 
 #: c-family/c.opt:1872
-#, fuzzy
-#| msgid "-isysroot <dir>\tSet <dir> to be the system root directory"
 msgid "-isysroot <dir>\tSet <dir> to be the system root directory."
-msgstr "-isysroot <каталог>\tСчитать <каталог> корневым каталогом системы"
+msgstr "-isysroot <каталог>\tСчитать <каталог> корневым каталогом системы."
 
 #: c-family/c.opt:1876
-#, fuzzy
-#| msgid "-isystem <dir>\tAdd <dir> to the start of the system include path"
 msgid "-isystem <dir>\tAdd <dir> to the start of the system include path."
-msgstr "-isystem <каталог>\tДобавить <каталог> в начало пути поиска системных заголовков"
+msgstr "-isystem <каталог>\tДобавить <каталог> в начало пути поиска системных заголовков."
 
 #: c-family/c.opt:1880
-#, fuzzy
-#| msgid "-iquote <dir>\tAdd <dir> to the end of the quote include path"
 msgid "-iquote <dir>\tAdd <dir> to the end of the quote include path."
-msgstr "-iquote <каталог>\tДобавить <каталог> в конец пути поиска заголовков \"в кавычках\""
+msgstr "-iquote <каталог>\tДобавить <каталог> в конец пути поиска заголовков \"в кавычках\"."
 
 #: c-family/c.opt:1884
-#, fuzzy
-#| msgid "-iwithprefix <dir>\tAdd <dir> to the end of the system include path"
 msgid "-iwithprefix <dir>\tAdd <dir> to the end of the system include path."
-msgstr "-iwithprefix <каталог>\tДобавить <каталог> в конец пути поиска системных заголовков"
+msgstr "-iwithprefix <каталог>\tДобавить <каталог> в конец пути поиска системных заголовков."
 
 #: c-family/c.opt:1888
-#, fuzzy
-#| msgid "-iwithprefixbefore <dir>\tAdd <dir> to the end of the main include path"
 msgid "-iwithprefixbefore <dir>\tAdd <dir> to the end of the main include path."
-msgstr "-iwithprefixbefore <каталог>\tДобавить <каталог> в конец основного пути поиска заголовков"
+msgstr "-iwithprefixbefore <каталог>\tДобавить <каталог> в конец основного пути поиска заголовков."
 
 #: c-family/c.opt:1898
-#, fuzzy
-#| msgid "Do not search standard system include directories (those specified with -isystem will still be used)"
 msgid "Do not search standard system include directories (those specified with -isystem will still be used)."
-msgstr "Не искать системные заголовки в стандартных каталогах поиска (но искать в каталогах, заданных при помощи -isystem)"
+msgstr "Не искать системные заголовки в стандартных каталогах поиска (но искать в каталогах, заданных при помощи -isystem)."
 
 #: c-family/c.opt:1902
-#, fuzzy
-#| msgid "Do not search standard system include directories for C++"
 msgid "Do not search standard system include directories for C++."
-msgstr "Не искать системные заголовки C++ в стандартных каталогах"
+msgstr "Не искать системные заголовки C++ в стандартных каталогах."
 
 #: c-family/c.opt:1914
-#, fuzzy
-#| msgid "Generate C header of platform-specific features"
 msgid "Generate C header of platform-specific features."
-msgstr "Сгенерировать C-заголовок описаний, специфических для целевой платформы"
+msgstr "Сгенерировать C-заголовок описаний, специфических для целевой платформы."
 
 #: c-family/c.opt:1918
-#, fuzzy
-#| msgid "Remap file names when including files"
 msgid "Remap file names when including files."
-msgstr "Преобразовывать имена файлов при включении"
+msgstr "Преобразовывать имена файлов при включении."
 
 #: c-family/c.opt:1922 c-family/c.opt:1926
-#, fuzzy
-#| msgid "Conform to the ISO 1998 C++ standard revised by the 2003 technical corrigendum"
 msgid "Conform to the ISO 1998 C++ standard revised by the 2003 technical corrigendum."
-msgstr "Компилировать в соответствии с ISO 1998 C++ с учетом технических поправок 2003 года"
+msgstr "Компилировать в соответствии с ISO 1998 C++ с учетом технических поправок 2003 года."
 
 #: c-family/c.opt:1930
-#, fuzzy
-#| msgid "Conform to the ISO 1998 C++ standard"
 msgid "Conform to the ISO 2011 C++ standard."
-msgstr "Компилировать в соответствии с ISO 1998 C++"
+msgstr "Компилировать в соответствии с ISO 2011 C++."
 
 #: c-family/c.opt:1934
-#, fuzzy
-#| msgid "Deprecated in favor of -std=c++11"
 msgid "Deprecated in favor of -std=c++11."
-msgstr "Не рекомендуется; используйте -std=c++11"
+msgstr "Не рекомендуется; используйте -std=c++11."
 
 #: c-family/c.opt:1938
-#, fuzzy
-#| msgid "Deprecated in favor of -std=c++11"
 msgid "Deprecated in favor of -std=c++14."
-msgstr "Не рекомендуется; используйте -std=c++11"
+msgstr "Не рекомендуется; используйте -std=c++14."
 
 #: c-family/c.opt:1942
-#, fuzzy
-#| msgid "Conform to the ISO 1998 C++ standard"
 msgid "Conform to the ISO 2014 C++ standard."
-msgstr "Компилировать в соответствии с ISO 1998 C++"
+msgstr "Компилировать в соответствии с ISO 2014 C++."
 
 #: c-family/c.opt:1946
-#, fuzzy
-#| msgid "Deprecated in favor of -std=c++11"
 msgid "Deprecated in favor of -std=c++17."
-msgstr "Не рекомендуется; используйте -std=c++11"
+msgstr ""
 
 #: c-family/c.opt:1950
-#, fuzzy
-#| msgid "Conform to the ISO 1998 C++ standard"
 msgid "Conform to the ISO 2017 C++ standard."
-msgstr "Компилировать в соответствии с ISO 1998 C++"
+msgstr ""
 
 #: c-family/c.opt:1954
-#, fuzzy
-#| msgid "Conform to the ISO 2011 C++ standard (experimental and incomplete support)"
 msgid "Conform to the ISO 2020(?) C++ draft standard (experimental and incomplete support)."
-msgstr "Компилировать в соответствии со стандартом ISO 2011 C++ (неполная экспериментальная поддержка)"
+msgstr ""
 
 #: c-family/c.opt:1958 c-family/c.opt:2076
-#, fuzzy
-#| msgid "Conform to the ISO 1990 C standard"
 msgid "Conform to the ISO 2011 C standard."
-msgstr "Компилировать в соответствии с ISO 1990 C"
+msgstr "Компилировать в соответствии с ISO 2011 C."
 
 #: c-family/c.opt:1962
-#, fuzzy
-#| msgid "Deprecated in favor of -std=c11"
 msgid "Deprecated in favor of -std=c11."
-msgstr "Не рекомендуется; используйте -std=c11"
+msgstr "Не рекомендуется; используйте -std=c11."
 
 #: c-family/c.opt:1966 c-family/c.opt:1970 c-family/c.opt:2080
 #: c-family/c.opt:2084
-#, fuzzy
-#| msgid "Conform to the ISO 1990 C standard as amended in 1994"
 msgid "Conform to the ISO 2017 C standard (expected to be published in 2018)."
-msgstr "Компилировать в соответствии с ISO 1990 C с дополнениями от 1994"
+msgstr ""
 
 #: c-family/c.opt:1974 c-family/c.opt:1978 c-family/c.opt:2060
-#, fuzzy
-#| msgid "Conform to the ISO 1990 C standard"
 msgid "Conform to the ISO 1990 C standard."
-msgstr "Компилировать в соответствии с ISO 1990 C"
+msgstr "Компилировать в соответствии с ISO 1990 C."
 
 #: c-family/c.opt:1982 c-family/c.opt:2068
-#, fuzzy
-#| msgid "Conform to the ISO 1999 C standard"
 msgid "Conform to the ISO 1999 C standard."
-msgstr "Компилировать в соответствии с ISO 1999 C"
+msgstr "Компилировать в соответствии с ISO 1999 C."
 
 #: c-family/c.opt:1986
-#, fuzzy
-#| msgid "Deprecated in favor of -std=c99"
 msgid "Deprecated in favor of -std=c99."
-msgstr "Не рекомендуется; используйте -std=c99"
+msgstr "Не рекомендуется; используйте -std=c99."
 
 #: c-family/c.opt:1990 c-family/c.opt:1995
-#, fuzzy
-#| msgid "Conform to the ISO 1998 C++ standard revised by the 2003 technical corrigendum with GNU extensions"
 msgid "Conform to the ISO 1998 C++ standard revised by the 2003 technical corrigendum with GNU extensions."
-msgstr "Компилировать в соответствии с ISO 1998 C++ с учетом технических поправок 2003 года, с расширениями GNU"
+msgstr "Компилировать в соответствии с ISO 1998 C++ с учетом технических поправок 2003 года, с расширениями GNU."
 
 #: c-family/c.opt:2000
-#, fuzzy
-#| msgid "Conform to the ISO 1990 C standard with GNU extensions"
 msgid "Conform to the ISO 2011 C++ standard with GNU extensions."
-msgstr "Компилировать в соответствии с ISO 1990 C с расширениями GNU"
+msgstr "Компилировать в соответствии с ISO 2011 C++ с расширениями GNU."
 
 #: c-family/c.opt:2004
-#, fuzzy
-#| msgid "Deprecated in favor of -std=gnu++11"
 msgid "Deprecated in favor of -std=gnu++11."
-msgstr "Устаревший ключ, используйте -std=gnu++11"
+msgstr "Устаревший ключ, используйте -std=gnu++11."
 
 #: c-family/c.opt:2008
-#, fuzzy
-#| msgid "Deprecated in favor of -std=gnu++11"
 msgid "Deprecated in favor of -std=gnu++14."
-msgstr "Устаревший ключ, используйте -std=gnu++11"
+msgstr "Устаревший ключ, используйте -std=gnu++14."
 
 #: c-family/c.opt:2012
-#, fuzzy
-#| msgid "Conform to the ISO 1990 C standard with GNU extensions"
 msgid "Conform to the ISO 2014 C++ standard with GNU extensions."
-msgstr "Компилировать в соответствии с ISO 1990 C с расширениями GNU"
+msgstr "Компилировать в соответствии с ISO 2014 C++ с расширениями GNU."
 
 #: c-family/c.opt:2016
-#, fuzzy
-#| msgid "Deprecated in favor of -std=gnu++11"
 msgid "Deprecated in favor of -std=gnu++17."
-msgstr "Устаревший ключ, используйте -std=gnu++11"
+msgstr ""
 
 #: c-family/c.opt:2020
-#, fuzzy
-#| msgid "Conform to the ISO 1990 C standard with GNU extensions"
 msgid "Conform to the ISO 2017 C++ standard with GNU extensions."
-msgstr "Компилировать в соответствии с ISO 1990 C с расширениями GNU"
+msgstr ""
 
 #: c-family/c.opt:2024
-#, fuzzy
-#| msgid "Conform to the ISO 2011 C++ standard with GNU extensions (experimental and incomplete support)"
 msgid "Conform to the ISO 2020(?) C++ draft standard with GNU extensions (experimental and incomplete support)."
-msgstr "Компилировать в соответствии с ISO 2011 C++ с расширениями GNU (неполная экспериментальная поддержка)"
+msgstr ""
 
 #: c-family/c.opt:2028
-#, fuzzy
-#| msgid "Conform to the ISO 1990 C standard with GNU extensions"
 msgid "Conform to the ISO 2011 C standard with GNU extensions."
-msgstr "Компилировать в соответствии с ISO 1990 C с расширениями GNU"
+msgstr "Компилировать в соответствии с ISO 2011 C с расширениями GNU."
 
 #: c-family/c.opt:2032
-#, fuzzy
-#| msgid "Deprecated in favor of -std=gnu11"
 msgid "Deprecated in favor of -std=gnu11."
-msgstr "Устаревший ключ, используйте -std=gnu11"
+msgstr "Устаревший ключ, используйте -std=gnu11."
 
 #: c-family/c.opt:2036 c-family/c.opt:2040
-#, fuzzy
-#| msgid "Conform to the ISO 1990 C standard with GNU extensions"
 msgid "Conform to the ISO 2017 C standard (expected to be published in 2018) with GNU extensions."
-msgstr "Компилировать в соответствии с ISO 1990 C с расширениями GNU"
+msgstr ""
 
 #: c-family/c.opt:2044 c-family/c.opt:2048
-#, fuzzy
-#| msgid "Conform to the ISO 1990 C standard with GNU extensions"
 msgid "Conform to the ISO 1990 C standard with GNU extensions."
-msgstr "Компилировать в соответствии с ISO 1990 C с расширениями GNU"
+msgstr "Компилировать в соответствии с ISO 1990 C с расширениями GNU."
 
 #: c-family/c.opt:2052
-#, fuzzy
-#| msgid "Conform to the ISO 1999 C standard with GNU extensions"
 msgid "Conform to the ISO 1999 C standard with GNU extensions."
-msgstr "Компилировать в соответствии с ISO 1999 C с расширениями GNU"
+msgstr "Компилировать в соответствии с ISO 1999 C с расширениями GNU."
 
 #: c-family/c.opt:2056
-#, fuzzy
-#| msgid "Deprecated in favor of -std=gnu99"
 msgid "Deprecated in favor of -std=gnu99."
-msgstr "Устаревший ключ, теперь следует использовать -std=gnu99"
+msgstr "Устаревший ключ, теперь следует использовать -std=gnu99."
 
 #: c-family/c.opt:2064
-#, fuzzy
-#| msgid "Conform to the ISO 1990 C standard as amended in 1994"
 msgid "Conform to the ISO 1990 C standard as amended in 1994."
-msgstr "Компилировать в соответствии с ISO 1990 C с дополнениями от 1994"
+msgstr "Компилировать в соответствии с ISO 1990 C с дополнениями от 1994."
 
 #: c-family/c.opt:2072
-#, fuzzy
-#| msgid "Deprecated in favor of -std=iso9899:1999"
 msgid "Deprecated in favor of -std=iso9899:1999."
-msgstr "Устаревший ключ; используйте -std=iso9899:1999"
+msgstr "Устаревший ключ; используйте -std=iso9899:1999."
 
 #: c-family/c.opt:2091
-#, fuzzy
-#| msgid "Enable traditional preprocessing"
 msgid "Enable traditional preprocessing."
-msgstr "Традиционное препроцессирование"
+msgstr "Традиционное препроцессирование."
 
 #: c-family/c.opt:2095
-#, fuzzy
-#| msgid "-trigraphs\tSupport ISO C trigraphs"
 msgid "-trigraphs\tSupport ISO C trigraphs."
-msgstr "-trigraphs\tПоддержка триграфов, предусмотренных ISO C"
+msgstr "-trigraphs\tПоддержка триграфов, предусмотренных ISO C."
 
 #: c-family/c.opt:2099
-#, fuzzy
-#| msgid "Do not predefine system-specific and GCC-specific macros"
 msgid "Do not predefine system-specific and GCC-specific macros."
-msgstr "Не предопределять системные макросы и макросы GCC"
+msgstr "Не предопределять системные макросы и макросы GCC."
 
 #: ada/gcc-interface/lang.opt:61
-#, fuzzy
-#| msgid "Synonym of -gnatk8"
 msgid "Synonym of -gnatk8."
-msgstr "То же, что -gnatk8"
+msgstr "То же, что -gnatk8."
 
 #: ada/gcc-interface/lang.opt:69
-#, fuzzy
-#| msgid "Do not look for object files in standard path"
 msgid "Do not look for object files in standard path."
-msgstr "Не искать объектные файлы по стандартным маршрутам"
+msgstr "Не искать объектные файлы по стандартным маршрутам."
 
 #: ada/gcc-interface/lang.opt:73
-#, fuzzy
-#| msgid "Select the runtime"
 msgid "Select the runtime."
-msgstr "Выбрать runtime-поддержку"
+msgstr "Выбрать runtime-поддержку."
 
 #: ada/gcc-interface/lang.opt:85
-#, fuzzy
-#| msgid "Catch typos"
 msgid "Catch typos."
-msgstr "Ловить опечатки"
+msgstr "Ловить опечатки."
 
 #: ada/gcc-interface/lang.opt:89
-#, fuzzy
-#| msgid "Set name of output ALI file (internal switch)"
 msgid "Set name of output ALI file (internal switch)."
-msgstr "Задать имя выходного ALI файла (внутренний ключ)"
+msgstr "Задать имя выходного ALI файла (внутренний ключ)."
 
 #: ada/gcc-interface/lang.opt:93
-#, fuzzy
-#| msgid "-gnat<options>\tSpecify options to GNAT"
 msgid "-gnat<options>\tSpecify options to GNAT."
-msgstr "-gnat<options>\tЗадать ключи GNAT"
+msgstr "-gnat<options>\tЗадать ключи GNAT."
 
 #: ada/gcc-interface/lang.opt:97
 msgid "Ignored."
-msgstr ""
+msgstr "Игнорируется."
 
 #: go/lang.opt:42
-#, fuzzy
-#| msgid "-fdump-go-spec=filename\tWrite all declarations to file as Go code"
 msgid "-fgo-c-header=<file>\tWrite Go struct definitions to file as C code."
-msgstr "-fdump-go-spec=файл\tЗаписать в файл все декларации в виде кода Go"
+msgstr "-fgo-c-header=<file>\tЗаписать определения структур Go в файл в виде кода на языке C."
 
 #: go/lang.opt:46
-#, fuzzy
-#| msgid "Add explicit checks for division by zero"
 msgid "Add explicit checks for division by zero."
-msgstr "Включить явные проверки деления на ноль"
+msgstr "Включить явные проверки деления на ноль."
 
 #: go/lang.opt:50
-#, fuzzy
-#| msgid "Add explicit checks for division overflow in INT_MIN / -1"
 msgid "Add explicit checks for division overflow in INT_MIN / -1."
-msgstr "Включить явные проверки переполнения при делении INT_MIN / -1"
+msgstr "Включить явные проверки переполнения при делении INT_MIN / -1."
 
 #: go/lang.opt:54
 msgid "Apply special rules for compiling runtime package."
-msgstr ""
+msgstr "Применить специальные правила для компиляции пакета времени выполнения."
 
 #: go/lang.opt:58
-#, fuzzy
-#| msgid "-fgo-dump-<type>\tDump Go frontend internal information"
 msgid "-fgo-dump-<type>\tDump Go frontend internal information."
-msgstr "-fgo-dump-<type>\tВыдать дамп внутренней информации компилятора переднего плана Go"
+msgstr "-fgo-dump-<type>\tВыдать дамп внутренней информации компилятора переднего плана Go."
 
 #: go/lang.opt:62
-#, fuzzy
-#| msgid "-fgo-optimize-<type>\tTurn on optimization passes in the frontend"
 msgid "-fgo-optimize-<type>\tTurn on optimization passes in the frontend."
-msgstr "-fgo-optimize-<type>\tВключить проходы оптимизации в компиляторе переднего плана"
+msgstr "-fgo-optimize-<type>\tВключить проходы оптимизации в компиляторе переднего плана."
 
 #: go/lang.opt:66
-#, fuzzy
-#| msgid "-fgo-pkgpath=<string>\tSet Go package path"
 msgid "-fgo-pkgpath=<string>\tSet Go package path."
-msgstr "-fgo-pkgpath=<string>\tУказать каталог пакетов Go"
+msgstr "-fgo-pkgpath=<string>\tУказать каталог пакетов Go."
 
 #: go/lang.opt:70
-#, fuzzy
-#| msgid "-fgo-prefix=<string>\tSet package-specific prefix for exported Go names"
 msgid "-fgo-prefix=<string>\tSet package-specific prefix for exported Go names."
-msgstr "-fgo-prefix=<string>\tУказать префикс пакетов для экспортируемых имен Go"
+msgstr "-fgo-prefix=<string>\tУказать префикс пакетов для экспортируемых имен Go."
 
 #: go/lang.opt:74
-#, fuzzy
-#| msgid "-fgo-relative-import-path=<path> Treat a relative import as relative to path"
 msgid "-fgo-relative-import-path=<path>\tTreat a relative import as relative to path."
-msgstr "-fgo-relative-import-path=<path> Префикс для относительных имен в импорте"
+msgstr "-fgo-relative-import-path=<path>\tПрефикс для относительных имен в импорте"
 
 #: go/lang.opt:78
-#, fuzzy
-#| msgid "Functions which return values must end with return statements"
 msgid "Functions which return values must end with return statements."
-msgstr "функция, возвращающая результат, должна заканчиваться выполнением оператора return"
+msgstr "функция, возвращающая результат, должна заканчиваться выполнением оператора return."
 
 #: go/lang.opt:82
 msgid "Emit debugging information related to the escape analysis pass when run with -fgo-optimize-allocs."
-msgstr ""
+msgstr "Генерировать отладочную информацию, относящуюся к escape-анализу, при наличии ключа -fgo-optimize-allocs."
 
 #: go/lang.opt:86
 msgid "-fgo-debug-escape-hash=<string>\tHash value to debug escape analysis."
@@ -9180,30 +7998,25 @@
 msgstr ""
 
 #: config/vms/vms.opt:27
-#, fuzzy
-#| msgid "Malloc data into P2 space"
 msgid "Malloc data into P2 space."
-msgstr "Malloc данные в P2 пространство"
+msgstr "Malloc данные в P2 пространство."
 
 #: config/vms/vms.opt:31
-#, fuzzy
-#| msgid "Set name of main routine for the debugger"
 msgid "Set name of main routine for the debugger."
-msgstr "Установить имя главной программы для отладчика"
+msgstr "Установить имя главной программы для отладчика."
 
 #: config/vms/vms.opt:35
 msgid "Use VMS exit codes instead of posix ones."
-msgstr ""
+msgstr "Использовать коды возврата VMS вместо кодов POSIX."
 
 #: config/vms/vms.opt:39
 msgid "-mpointer-size=[no,32,short,64,long]\tSet the default pointer size."
-msgstr ""
+msgstr "-mpointer-size=[no,32,short,64,long]\tУстановить размер указателя по умолчанию."
 
 #: config/vms/vms.opt:42
-#, fuzzy, c-format
-#| msgid "unknown TLS model %qs"
+#, c-format
 msgid "unknown pointer size model %qs"
-msgstr "неизвестная модель генерации кода TLS %qs"
+msgstr "неизвестная модель для размера указателя %qs"
 
 #: config/mcore/mcore.opt:23
 msgid "Generate code for the M*Core M210"
@@ -9214,70 +8027,48 @@
 msgstr "Генерировать код для M*Core M340"
 
 #: config/mcore/mcore.opt:31
-#, fuzzy
-#| msgid "Force functions to be aligned to a 4 byte boundary"
 msgid "Force functions to be aligned to a 4 byte boundary."
-msgstr "Выравнивать функции по границе 4 байт"
+msgstr "Выравнивать функции по границе 4 байт."
 
 #: config/mcore/mcore.opt:35 config/moxie/moxie.opt:23
-#, fuzzy
-#| msgid "Generate big-endian code"
 msgid "Generate big-endian code."
-msgstr "Генерировать код для прямого порядка байт (big endian)"
+msgstr "Генерировать код для прямого порядка байт (big endian)."
 
 #: config/mcore/mcore.opt:39
-#, fuzzy
-#| msgid "Emit call graph information"
 msgid "Emit call graph information."
-msgstr "Выдавать граф вызовов"
+msgstr "Выдавать граф вызовов."
 
 #: config/mcore/mcore.opt:43
-#, fuzzy
-#| msgid "Use the divide instruction"
 msgid "Use the divide instruction."
-msgstr "Использовать команды деления"
+msgstr "Использовать команды деления."
 
 #: config/mcore/mcore.opt:47
-#, fuzzy
-#| msgid "Inline constants if it can be done in 2 insns or less"
 msgid "Inline constants if it can be done in 2 insns or less."
-msgstr "Использовать непосредственные константы, если это требует не более 2 команд"
+msgstr "Использовать непосредственные константы, если это требует не более 2 команд."
 
 #: config/mcore/mcore.opt:51 config/moxie/moxie.opt:27
-#, fuzzy
-#| msgid "Generate little-endian code"
 msgid "Generate little-endian code."
-msgstr "Генерировать код для обратного порядка байт (little endian)"
+msgstr "Генерировать код для обратного порядка байт (little endian)."
 
 #: config/mcore/mcore.opt:56 config/fr30/fr30.opt:27
-#, fuzzy
-#| msgid "Assume that run-time support has been provided, so omit -lsim from the linker command line"
 msgid "Assume that run-time support has been provided, so omit -lsim from the linker command line."
-msgstr "Предполагать что предоставляется поддержка времени выполнения, поэтому опустить -lsim в командной строке компоновщика"
+msgstr "Предполагать, что предоставляется поддержка времени выполнения, поэтому опустить -lsim в командной строке компоновщика."
 
 #: config/mcore/mcore.opt:60
-#, fuzzy
-#| msgid "Use arbitrary sized immediates in bit operations"
 msgid "Use arbitrary sized immediates in bit operations."
-msgstr "Использовать непосредственные константы произвольного размера в битовых операциях"
+msgstr "Использовать непосредственные константы произвольного размера в битовых операциях."
 
 #: config/mcore/mcore.opt:64
-#, fuzzy
-#| msgid "Prefer word accesses over byte accesses"
 msgid "Prefer word accesses over byte accesses."
-msgstr "Отдавать предпочтение пословному доступу к памяти перед побайтным"
+msgstr "Отдавать предпочтение пословному доступу к памяти перед побайтным."
 
 #: config/mcore/mcore.opt:71
-#, fuzzy
-#| msgid "Set the maximum amount for a single stack increment operation"
 msgid "Set the maximum amount for a single stack increment operation."
-msgstr "Задать максимальную величину одной операции инкрементации стека"
+msgstr "Задать максимальную величину одной операции инкрементации стека."
 
 #: config/mcore/mcore.opt:75
-#, fuzzy
-#| msgid "Always treat bitfields as int-sized"
 msgid "Always treat bitfields as int-sized."
-msgstr "Всегда считать, что битовое поле имеет размер int"
+msgstr "Всегда считать, что битовое поле имеет размер int."
 
 #: config/linux-android.opt:23
 msgid "Generate code for the Android platform."
@@ -9284,286 +8075,196 @@
 msgstr "Генерировать код для платформы Android"
 
 #: config/mmix/mmix.opt:24
-#, fuzzy
-#| msgid "For intrinsics library: pass all parameters in registers"
 msgid "For intrinsics library: pass all parameters in registers."
-msgstr "Для внутренней библиотеки: передавать все параметры на регистрах"
+msgstr "Для внутренней библиотеки: передавать все параметры на регистрах."
 
 #: config/mmix/mmix.opt:28
-#, fuzzy
-#| msgid "Use register stack for parameters and return value"
 msgid "Use register stack for parameters and return value."
-msgstr "Использовать регистровый стек для передачи параметров и возврата значения"
+msgstr "Использовать регистровый стек для передачи параметров и возврата значения."
 
 #: config/mmix/mmix.opt:32
-#, fuzzy
-#| msgid "Use call-clobbered registers for parameters and return value"
 msgid "Use call-clobbered registers for parameters and return value."
-msgstr "Использовать несохраняемые регистры для передачи параметров и возврата значения"
+msgstr "Использовать несохраняемые регистры для передачи параметров и возврата значения."
 
 #: config/mmix/mmix.opt:37
-#, fuzzy
-#| msgid "Use epsilon-respecting floating point compare instructions"
 msgid "Use epsilon-respecting floating point compare instructions."
-msgstr "Использовать команды сравнения плавающих значений, учитывающие epsilon-регистр"
+msgstr "Использовать команды сравнения плавающих значений, учитывающие epsilon-регистр."
 
 #: config/mmix/mmix.opt:41
-#, fuzzy
-#| msgid "Use zero-extending memory loads, not sign-extending ones"
 msgid "Use zero-extending memory loads, not sign-extending ones."
-msgstr "Использовать команды загрузки из памяти с расширением нулями, а не знаковым битом"
+msgstr "Использовать команды загрузки из памяти с расширением нулями, а не знаковым битом."
 
 #: config/mmix/mmix.opt:45
-#, fuzzy
-#| msgid "Generate divide results with reminder having the same sign as the divisor (not the dividend)"
 msgid "Generate divide results with reminder having the same sign as the divisor (not the dividend)."
-msgstr "Генерировать код так, чтобы остаток от деления имел знак делителя (а не делимого)"
+msgstr "Генерировать код так, чтобы остаток от деления имел знак делителя (а не делимого)."
 
 #: config/mmix/mmix.opt:49
-#, fuzzy
-#| msgid "Prepend global symbols with \":\" (for use with PREFIX)"
 msgid "Prepend global symbols with \":\" (for use with PREFIX)."
-msgstr "Приписывать префикс \":\" глобальным символам (для использования с PREFIX)"
+msgstr "Приписывать префикс \":\" глобальным символам (для использования с PREFIX)."
 
 #: config/mmix/mmix.opt:53
-#, fuzzy
-#| msgid "Do not provide a default start-address 0x100 of the program"
 msgid "Do not provide a default start-address 0x100 of the program."
-msgstr "Не задавать стандартный стартовый адрес программы 0x100"
+msgstr "Не задавать стандартный стартовый адрес программы 0x100."
 
 #: config/mmix/mmix.opt:57
-#, fuzzy
-#| msgid "Link to emit program in ELF format (rather than mmo)"
 msgid "Link to emit program in ELF format (rather than mmo)."
-msgstr "При компоновке создавать файл в формате ELF (а не mmo)"
+msgstr "При компоновке создавать файл в формате ELF (а не mmo)."
 
 #: config/mmix/mmix.opt:61
-#, fuzzy
-#| msgid "Use P-mnemonics for branches statically predicted as taken"
 msgid "Use P-mnemonics for branches statically predicted as taken."
-msgstr "Использовать P-мнемонику для статически предсказанных переходов"
+msgstr "Использовать P-мнемонику для статически предсказанных переходов."
 
 #: config/mmix/mmix.opt:65
-#, fuzzy
-#| msgid "Don't use P-mnemonics for branches"
 msgid "Don't use P-mnemonics for branches."
-msgstr "Не использовать P-мнемонику для статически предсказанных переходов"
+msgstr "Не использовать P-мнемонику для статически предсказанных переходов."
 
 #: config/mmix/mmix.opt:79
-#, fuzzy
-#| msgid "Use addresses that allocate global registers"
 msgid "Use addresses that allocate global registers."
-msgstr "Использовать формирование адресов для глобальных регистров"
+msgstr "Использовать формирование адресов для глобальных регистров."
 
 #: config/mmix/mmix.opt:83
-#, fuzzy
-#| msgid "Do not use addresses that allocate global registers"
 msgid "Do not use addresses that allocate global registers."
-msgstr "Не использовать формирование адресов для глобальных регистров"
+msgstr "Не использовать формирование адресов для глобальных регистров."
 
 #: config/mmix/mmix.opt:87
-#, fuzzy
-#| msgid "Generate a single exit point for each function"
 msgid "Generate a single exit point for each function."
-msgstr "Генерировать одну выходную точку для каждой функции"
+msgstr "Генерировать одну выходную точку для каждой функции."
 
 #: config/mmix/mmix.opt:91
-#, fuzzy
-#| msgid "Do not generate a single exit point for each function"
 msgid "Do not generate a single exit point for each function."
-msgstr "Не генерировать одну выходную точку для каждой функции"
+msgstr "Не генерировать одну выходную точку для каждой функции."
 
 #: config/mmix/mmix.opt:95
-#, fuzzy
-#| msgid "Set start-address of the program"
 msgid "Set start-address of the program."
-msgstr "Стартовый адрес программы"
+msgstr "Стартовый адрес программы."
 
 #: config/mmix/mmix.opt:99
-#, fuzzy
-#| msgid "Set start-address of data"
 msgid "Set start-address of data."
-msgstr "Стартовый адрес данных"
+msgstr "Стартовый адрес данных."
 
 #: config/darwin.opt:117
-#, fuzzy
-#| msgid "Generate compile-time CFString objects"
 msgid "Generate compile-time CFString objects."
-msgstr "Генерировать CFString объекты времени компиляции"
+msgstr "Генерировать CFString объекты времени компиляции."
 
 #: config/darwin.opt:214
-#, fuzzy
-#| msgid "Warn if constant CFString objects contain non-portable characters"
 msgid "Warn if constant CFString objects contain non-portable characters."
-msgstr "Предупреждать если константный CFString объект содержит непереносимые символы"
+msgstr "Предупреждать, если константный CFString объект содержит непереносимые символы."
 
 #: config/darwin.opt:219
-#, fuzzy
-#| msgid "Generate AT&T-style stubs for Mach-O"
 msgid "Generate AT&T-style stubs for Mach-O."
-msgstr "Генерировать суррогаты AT&T стиля для Mach-O"
+msgstr "Генерировать суррогаты AT&T стиля для Mach-O."
 
 #: config/darwin.opt:223
-#, fuzzy
-#| msgid "Generate code suitable for executables (NOT shared libs)"
 msgid "Generate code suitable for executables (NOT shared libs)."
-msgstr "Генерировать код для выполняемых файлов (а не разделяемых библиотек)"
+msgstr "Генерировать код для выполняемых файлов (а не разделяемых библиотек)."
 
 #: config/darwin.opt:227
-#, fuzzy
-#| msgid "Generate code suitable for fast turn around debugging"
 msgid "Generate code suitable for fast turn around debugging."
-msgstr "Генерировать код для быстрого возврата к отладке"
+msgstr "Генерировать код для быстрого возврата к отладке."
 
 #: config/darwin.opt:235
-#, fuzzy
-#| msgid "The earliest MacOS X version on which this program will run"
 msgid "The earliest MacOS X version on which this program will run."
-msgstr "Наиболее младшая версия MacOS X в которой будет запускаться программа"
+msgstr "Наиболее младшая версия MacOS X, в которой будет запускаться программа."
 
 #: config/darwin.opt:239
-#, fuzzy
-#| msgid "Set sizeof(bool) to 1"
 msgid "Set sizeof(bool) to 1."
-msgstr "Установить sizeof(bool) в 1"
+msgstr "Установить sizeof(bool) в 1."
 
 #: config/darwin.opt:243
-#, fuzzy
-#| msgid "Generate code for darwin loadable kernel extensions"
 msgid "Generate code for darwin loadable kernel extensions."
-msgstr "Генерировать код для darwin загружаемых расширений ядра"
+msgstr "Генерировать код для darwin загружаемых расширений ядра."
 
 #: config/darwin.opt:247
-#, fuzzy
-#| msgid "Generate code for the kernel or loadable kernel extensions"
 msgid "Generate code for the kernel or loadable kernel extensions."
-msgstr "Генерировать код для ядра или загружаемых расширений ядра"
+msgstr "Генерировать код для ядра или загружаемых расширений ядра."
 
 #: config/darwin.opt:251
-#, fuzzy
-#| msgid "-iframework <dir>\tAdd <dir> to the end of the system framework include path"
 msgid "-iframework <dir>\tAdd <dir> to the end of the system framework include path."
-msgstr "-iframework <dir>\tДобавить <dir> в конец основного пути поиска включаемых системных инфраструктур"
+msgstr "-iframework <dir>\tДобавить <dir> в конец основного пути поиска включаемых системных инфраструктур."
 
 #: config/darwin.opt:401
 msgid "The version of ld64 in use for this toolchain."
-msgstr ""
+msgstr "Версия ld64, которую следует использовать с данным инструментарием."
 
 #: config/bfin/bfin.opt:40 config/msp430/msp430.opt:3 config/c6x/c6x.opt:38
-#, fuzzy
-#| msgid "Use simulator runtime"
 msgid "Use simulator runtime."
-msgstr "Использовать среду запуска симулятора"
+msgstr "Использовать среду запуска симулятора."
 
 #: config/bfin/bfin.opt:44 config/arm/arm.opt:111
-#, fuzzy
-#| msgid "Specify the name of the target CPU"
 msgid "Specify the name of the target CPU."
-msgstr "Имя целевого процессора"
+msgstr "Имя целевого процессора."
 
 #: config/bfin/bfin.opt:48
-#, fuzzy
-#| msgid "Omit frame pointer for leaf functions"
 msgid "Omit frame pointer for leaf functions."
-msgstr "Исключать указатель кадра в листовых функциях"
+msgstr "Исключать указатель кадра в листовых функциях."
 
 #: config/bfin/bfin.opt:52
-#, fuzzy
-#| msgid "Program is entirely located in low 64k of memory"
 msgid "Program is entirely located in low 64k of memory."
-msgstr "Программа полностью расположена в нижних 64k памяти"
+msgstr "Программа полностью расположена в нижних 64k памяти."
 
 #: config/bfin/bfin.opt:56
-#, fuzzy
-#| msgid "Work around a hardware anomaly by adding a number of NOPs before a"
 msgid "Work around a hardware anomaly by adding a number of NOPs before a CSYNC or SSYNC instruction."
-msgstr "Обходить аппаратную ошибку с помощью добавления NOP-ов перед a"
+msgstr "Обходить аппаратную ошибку с помощью добавления NOP-ов перед инструкцией CSYNC или SSYNC."
 
 #: config/bfin/bfin.opt:61
 msgid "Avoid speculative loads to work around a hardware anomaly."
-msgstr "Избегать спекулятивной загрузки из памяти для обхода аппаратной ошибки"
+msgstr "Избегать спекулятивной загрузки из памяти для обхода аппаратной ошибки."
 
 #: config/bfin/bfin.opt:65
-#, fuzzy
-#| msgid "Enabled ID based shared library"
 msgid "Enabled ID based shared library."
-msgstr "Включить поддержку разделяемых библиотек на основе ID"
+msgstr "Включить поддержку разделяемых библиотек на основе ID."
 
 #: config/bfin/bfin.opt:69
-#, fuzzy
-#| msgid "Generate code that won't be linked against any other ID shared libraries,"
 msgid "Generate code that won't be linked against any other ID shared libraries, but may be used as a shared library."
-msgstr "Генерировать код который не будет компоноваться с другими ID разделяемыми библиотеками,"
+msgstr "Генерировать код, который не будет компоноваться с другими ID разделяемыми библиотеками, но может использоваться как разделяемая библиотека."
 
 #: config/bfin/bfin.opt:74 config/m68k/m68k.opt:175
-#, fuzzy
-#| msgid "ID of shared library to build"
 msgid "ID of shared library to build."
-msgstr "ID разделяемой библиотеки, которая будет создана"
+msgstr "ID разделяемой библиотеки, которая будет создана."
 
 #: config/bfin/bfin.opt:78 config/m68k/m68k.opt:171
-#, fuzzy
-#| msgid "Enable separate data segment"
 msgid "Enable separate data segment."
-msgstr "Размещать данные в отдельном сегменте"
+msgstr "Размещать данные в отдельном сегменте."
 
 #: config/bfin/bfin.opt:82 config/c6x/c6x.opt:63
-#, fuzzy
-#| msgid "Avoid generating pc-relative calls; use indirection"
 msgid "Avoid generating pc-relative calls; use indirection."
-msgstr "Избегать генерацию вызовов по смещению от pc, использовать косвенные вызовы"
+msgstr "Избегать генерацию вызовов по смещению от pc, использовать косвенные вызовы."
 
 #: config/bfin/bfin.opt:86
-#, fuzzy
-#| msgid "Link with the fast floating-point library"
 msgid "Link with the fast floating-point library."
-msgstr "Компоновать с библиотекой быстрой плавающей арифметики"
+msgstr "Компоновать с библиотекой быстрой плавающей арифметики."
 
 #: config/bfin/bfin.opt:90 config/frv/frv.opt:130
-#, fuzzy
-#| msgid "Enable Function Descriptor PIC mode"
 msgid "Enable Function Descriptor PIC mode."
-msgstr "Включить режим Function Descriptor PIC"
+msgstr "Включить режим Function Descriptor PIC."
 
 #: config/bfin/bfin.opt:94 config/frv/frv.opt:162
-#, fuzzy
-#| msgid "Enable inlining of PLT in function calls"
 msgid "Enable inlining of PLT in function calls."
-msgstr "Встраивать PLT в вызовы функций"
+msgstr "Встраивать PLT в вызовы функций."
 
 #: config/bfin/bfin.opt:98
-#, fuzzy
-#| msgid "Do stack checking using bounds in L1 scratch memory"
 msgid "Do stack checking using bounds in L1 scratch memory."
-msgstr "Делать проверку стека с использованием границ в L1 scratch памяти"
+msgstr "Делать проверку стека с использованием границ в L1 scratch памяти."
 
 #: config/bfin/bfin.opt:102
-#, fuzzy
-#| msgid "Enable multicore support"
 msgid "Enable multicore support."
-msgstr "Включить поддержку многоядерности"
+msgstr "Включить поддержку многоядерности."
 
 #: config/bfin/bfin.opt:106
-#, fuzzy
-#| msgid "Build for Core A"
 msgid "Build for Core A."
-msgstr "Строить для Core A"
+msgstr "Строить для Core A."
 
 #: config/bfin/bfin.opt:110
-#, fuzzy
-#| msgid "Build for Core B"
 msgid "Build for Core B."
-msgstr "Строить для Core B"
+msgstr "Строить для Core B."
 
 #: config/bfin/bfin.opt:114
-#, fuzzy
-#| msgid "Build for SDRAM"
 msgid "Build for SDRAM."
-msgstr "Строить для SDRAM"
+msgstr "Строить для SDRAM."
 
 #: config/bfin/bfin.opt:118
 msgid "Assume ICPLBs are enabled at runtime."
-msgstr "Предполагать что ICPLBs включены во время выполнения."
+msgstr "Предполагать, что ICPLBs включены во время выполнения."
 
 #: config/m68k/m68k-tables.opt:25
 msgid "Known M68K CPUs (for use with the -mcpu= option):"
@@ -9578,319 +8279,217 @@
 msgstr "Известные M68K ISAs (для использования с опцией -march=):"
 
 #: config/m68k/ieee.opt:24 config/i386/i386.opt:368
-#, fuzzy
-#| msgid "Use IEEE math for fp comparisons"
 msgid "Use IEEE math for fp comparisons."
-msgstr "При сравнениях плавающих значений следовать стандарту IEEE"
+msgstr "При сравнениях плавающих значений следовать стандарту IEEE."
 
 #: config/m68k/m68k.opt:30
-#, fuzzy
-#| msgid "Generate code for a 520X"
 msgid "Generate code for a 520X."
-msgstr "Генерировать код для 520X"
+msgstr "Генерировать код для 520X."
 
 #: config/m68k/m68k.opt:34
-#, fuzzy
-#| msgid "Generate code for a 5206e"
 msgid "Generate code for a 5206e."
-msgstr "Генерировать код для 5206e"
+msgstr "Генерировать код для 5206e."
 
 #: config/m68k/m68k.opt:38
-#, fuzzy
-#| msgid "Generate code for a 528x"
 msgid "Generate code for a 528x."
-msgstr "Генерировать код для 528x"
+msgstr "Генерировать код для 528x."
 
 #: config/m68k/m68k.opt:42
-#, fuzzy
-#| msgid "Generate code for a 5307"
 msgid "Generate code for a 5307."
-msgstr "Генерировать код для 5307"
+msgstr "Генерировать код для 5307."
 
 #: config/m68k/m68k.opt:46
-#, fuzzy
-#| msgid "Generate code for a 5407"
 msgid "Generate code for a 5407."
-msgstr "Генерировать код для 5407"
+msgstr "Генерировать код для 5407."
 
 #: config/m68k/m68k.opt:50 config/m68k/m68k.opt:111
-#, fuzzy
-#| msgid "Generate code for a 68000"
 msgid "Generate code for a 68000."
-msgstr "Генерировать код для 68000"
+msgstr "Генерировать код для 68000."
 
 #: config/m68k/m68k.opt:54
-#, fuzzy
-#| msgid "Generate code for a 68010"
 msgid "Generate code for a 68010."
-msgstr "Генерировать код для 68010"
+msgstr "Генерировать код для 68010."
 
 #: config/m68k/m68k.opt:58 config/m68k/m68k.opt:115
-#, fuzzy
-#| msgid "Generate code for a 68020"
 msgid "Generate code for a 68020."
-msgstr "Генерировать код для 68020"
+msgstr "Генерировать код для 68020."
 
 #: config/m68k/m68k.opt:62
-#, fuzzy
-#| msgid "Generate code for a 68040, without any new instructions"
 msgid "Generate code for a 68040, without any new instructions."
-msgstr "Генерировать код для 68040 без новых команд"
+msgstr "Генерировать код для 68040 без новых команд."
 
 #: config/m68k/m68k.opt:66
-#, fuzzy
-#| msgid "Generate code for a 68060, without any new instructions"
 msgid "Generate code for a 68060, without any new instructions."
-msgstr "Генерировать код для 68060 без новых команд"
+msgstr "Генерировать код для 68060 без новых команд."
 
 #: config/m68k/m68k.opt:70
-#, fuzzy
-#| msgid "Generate code for a 68030"
 msgid "Generate code for a 68030."
-msgstr "Генерировать код для 68030"
+msgstr "Генерировать код для 68030."
 
 #: config/m68k/m68k.opt:74
-#, fuzzy
-#| msgid "Generate code for a 68040"
 msgid "Generate code for a 68040."
-msgstr "Генерировать код для 68040"
+msgstr "Генерировать код для 68040."
 
 #: config/m68k/m68k.opt:78
-#, fuzzy
-#| msgid "Generate code for a 68060"
 msgid "Generate code for a 68060."
-msgstr "Генерировать код для 68060"
+msgstr "Генерировать код для 68060."
 
 #: config/m68k/m68k.opt:82
-#, fuzzy
-#| msgid "Generate code for a 68302"
 msgid "Generate code for a 68302."
-msgstr "Генерировать код для 68302"
+msgstr "Генерировать код для 68302."
 
 #: config/m68k/m68k.opt:86
-#, fuzzy
-#| msgid "Generate code for a 68332"
 msgid "Generate code for a 68332."
-msgstr "Генерировать код для 68332"
+msgstr "Генерировать код для 68332."
 
 #: config/m68k/m68k.opt:91
-#, fuzzy
-#| msgid "Generate code for a 68851"
 msgid "Generate code for a 68851."
-msgstr "Генерировать код для 68851"
+msgstr "Генерировать код для 68851."
 
 #: config/m68k/m68k.opt:95
-#, fuzzy
-#| msgid "Generate code that uses 68881 floating-point instructions"
 msgid "Generate code that uses 68881 floating-point instructions."
-msgstr "Генерировать код с использованием плавающих инструкций 68881"
+msgstr "Генерировать код с использованием плавающих инструкций 68881."
 
 #: config/m68k/m68k.opt:99
-#, fuzzy
-#| msgid "Align variables on a 32-bit boundary"
 msgid "Align variables on a 32-bit boundary."
-msgstr "Выравнивать переменные по границе 32 бит"
+msgstr "Выравнивать переменные по границе 32 бит."
 
 #: config/m68k/m68k.opt:103 config/arm/arm.opt:86 config/nios2/nios2.opt:570
 #: config/nds32/nds32.opt:131 config/c6x/c6x.opt:67
-#, fuzzy
-#| msgid "Specify the name of the target architecture"
 msgid "Specify the name of the target architecture."
-msgstr "Имя целевой архитектуры"
+msgstr "Имя целевой архитектуры."
 
 #: config/m68k/m68k.opt:107
-#, fuzzy
-#| msgid "Use the bit-field instructions"
 msgid "Use the bit-field instructions."
-msgstr "Использовать команды работы с битовыми полями"
+msgstr "Использовать команды работы с битовыми полями."
 
 #: config/m68k/m68k.opt:119
-#, fuzzy
-#| msgid "Generate code for a ColdFire v4e"
 msgid "Generate code for a ColdFire v4e."
-msgstr "Генерировать код для ColdFire v4e"
+msgstr "Генерировать код для ColdFire v4e."
 
 #: config/m68k/m68k.opt:123
-#, fuzzy
-#| msgid "Specify the target CPU"
 msgid "Specify the target CPU."
-msgstr "Задать целевой CPU"
+msgstr "Задать целевой CPU."
 
 #: config/m68k/m68k.opt:127
-#, fuzzy
-#| msgid "Generate code for a cpu32"
 msgid "Generate code for a cpu32."
-msgstr "Генерировать код для cpu32"
+msgstr "Генерировать код для cpu32."
 
 #: config/m68k/m68k.opt:131
-#, fuzzy
-#| msgid "Use hardware division instructions on ColdFire"
 msgid "Use hardware division instructions on ColdFire."
-msgstr "Использовать аппаратные инструкции деления в ColdFire"
+msgstr "Использовать аппаратные инструкции деления в ColdFire."
 
 #: config/m68k/m68k.opt:135
-#, fuzzy
-#| msgid "Generate code for a Fido A"
 msgid "Generate code for a Fido A."
-msgstr "Генерировать код для Fido A"
+msgstr "Генерировать код для Fido A."
 
 #: config/m68k/m68k.opt:139
-#, fuzzy
-#| msgid "Generate code which uses hardware floating point instructions"
 msgid "Generate code which uses hardware floating point instructions."
-msgstr "Генерировать код с использованием аппаратных инструкций вещественной арифметики"
+msgstr "Генерировать код с использованием аппаратных инструкций вещественной арифметики."
 
 #: config/m68k/m68k.opt:143
-#, fuzzy
-#| msgid "Enable ID based shared library"
 msgid "Enable ID based shared library."
-msgstr "Поддерживать разделяемые библиотеки на основе ID"
+msgstr "Поддерживать разделяемые библиотеки на основе ID."
 
 #: config/m68k/m68k.opt:147
 msgid "Use 32-bit offsets in jump tables rather than 16-bit offsets."
-msgstr ""
+msgstr "Использовать 32-разрядные смещения в таблицах переходов вместо 16-разрядных."
 
 #: config/m68k/m68k.opt:151
-#, fuzzy
-#| msgid "Do not use the bit-field instructions"
 msgid "Do not use the bit-field instructions."
-msgstr "Не использовать команды работы с битовыми полями"
+msgstr "Не использовать команды работы с битовыми полями."
 
 #: config/m68k/m68k.opt:155
-#, fuzzy
-#| msgid "Use normal calling convention"
 msgid "Use normal calling convention."
-msgstr "Использовать обычные соглашения о вызовах"
+msgstr "Использовать обычные соглашения о вызовах."
 
 #: config/m68k/m68k.opt:159
-#, fuzzy
-#| msgid "Consider type 'int' to be 32 bits wide"
 msgid "Consider type 'int' to be 32 bits wide."
-msgstr "Считать тип 'int' 32-битным"
+msgstr "Считать тип 'int' 32-битным."
 
 #: config/m68k/m68k.opt:163
-#, fuzzy
-#| msgid "Generate pc-relative code"
 msgid "Generate pc-relative code."
-msgstr "Генерировать код относительно pc"
+msgstr "Генерировать код относительно pc."
 
 #: config/m68k/m68k.opt:167
-#, fuzzy
-#| msgid "Use different calling convention using 'rtd'"
 msgid "Use different calling convention using 'rtd'."
-msgstr "Использовать альтернативные соглашения о вызовах с 'rtd'"
+msgstr "Использовать альтернативные соглашения о вызовах с 'rtd'."
 
 #: config/m68k/m68k.opt:179
-#, fuzzy
-#| msgid "Consider type 'int' to be 16 bits wide"
 msgid "Consider type 'int' to be 16 bits wide."
-msgstr "Считать тип 'int' 16-битным"
+msgstr "Считать тип 'int' 16-битным."
 
 #: config/m68k/m68k.opt:183
-#, fuzzy
-#| msgid "Generate code with library calls for floating point"
 msgid "Generate code with library calls for floating point."
-msgstr "Генерировать библиотечные вызовы для плавающих операций"
+msgstr "Генерировать библиотечные вызовы для плавающих операций."
 
 #: config/m68k/m68k.opt:187
-#, fuzzy
-#| msgid "Do not use unaligned memory references"
 msgid "Do not use unaligned memory references."
-msgstr "Не использовать невыровненные ссылки на память"
+msgstr "Не использовать невыровненные ссылки на память."
 
 #: config/m68k/m68k.opt:191
-#, fuzzy
-#| msgid "Tune for the specified target CPU or architecture"
 msgid "Tune for the specified target CPU or architecture."
-msgstr "Настроить для заданного целевого CPU или архитектуры"
+msgstr "Настроить для заданного целевого CPU или архитектуры."
 
 #: config/m68k/m68k.opt:195
-#, fuzzy
-#| msgid "Support more than 8192 GOT entries on ColdFire"
 msgid "Support more than 8192 GOT entries on ColdFire."
-msgstr "Поддерживать более чем 8192 GOT входов на ColdFire"
+msgstr "Поддерживать более чем 8192 GOT входов на ColdFire."
 
 #: config/m68k/m68k.opt:199
-#, fuzzy
-#| msgid "Support TLS segment larger than 64K"
 msgid "Support TLS segment larger than 64K."
-msgstr "Поддерживать TLS сегмент больше чем 64K"
+msgstr "Поддерживать TLS сегмент больше чем 64K."
 
 #: config/riscv/riscv.opt:26
-#, fuzzy
-#| msgid "-mbranch-cost=COST\tSet the cost of branches to roughly COST instructions"
 msgid "-mbranch-cost=N\tSet the cost of branches to roughly N instructions."
-msgstr "-mbranch-cost=COST\tУстановить цену переходов равной примерно COST команд"
+msgstr ""
 
 #: config/riscv/riscv.opt:30
-#, fuzzy
-#| msgid "When generating -mabicalls code, allow executables to use PLTs and copy relocations"
 msgid "When generating -fpic code, allow the use of PLTs. Ignored for fno-pic."
-msgstr "При генерации кода -mabicalls разрешить выполняемому модулю использование PLT и копирование перемещений"
+msgstr ""
 
 #: config/riscv/riscv.opt:34
-#, fuzzy
-#| msgid "Specify the name of the target floating point hardware/format"
 msgid "Specify integer and floating-point calling convention."
-msgstr "Задать целевую аппаратуру для плавающей точки и формат вычислений"
+msgstr "Задать соглашения о связях для целочисленных и плавающих значений."
 
 #: config/riscv/riscv.opt:38 config/i386/i386.opt:416
-#, fuzzy
-#| msgid "Attempt to keep stack aligned to this power of 2"
 msgid "Attempt to keep stack aligned to this power of 2."
-msgstr "Пытаться сохранять выравнивание стека по адресам, кратным указанной степени числа 2"
+msgstr "Пытаться сохранять выравнивание стека по адресам, кратным указанной степени числа 2."
 
 #: config/riscv/riscv.opt:42
-#, fuzzy
-#| msgid "Known ABIs (for use with the -mabi= option):"
 msgid "Supported ABIs (for use with the -mabi= option):"
 msgstr "Допустимые ABI (возможные аргументы ключа -mabi=):"
 
 #: config/riscv/riscv.opt:64
-#, fuzzy
-#| msgid "Use hardware floating point square root instruction"
 msgid "Use hardware floating-point divide and square root instructions."
-msgstr "Использовать команду плавающей арифметики извлечения квадратного корня"
+msgstr "Использовать машинные команды для деления и извлечения квадратного корня с плавающей арифметики."
 
 #: config/riscv/riscv.opt:68
-#, fuzzy
-#| msgid "Use trap instructions to check for integer divide by zero"
 msgid "Use hardware instructions for integer division."
-msgstr "Проверка целочисленного деления на ноль при помощи условных trap"
+msgstr "Использовать машинные команды для целочисленного деления."
 
 #: config/riscv/riscv.opt:72
 msgid "-march=\tGenerate code for given RISC-V ISA (e.g. RV64IM).  ISA strings must be lower-case."
-msgstr ""
+msgstr "-march=\tГенерировать код для заданного RISC-V ISA (например, RV64IM).  ISA задается строчными буквами."
 
 #: config/riscv/riscv.opt:77 config/mips/mips.opt:401
-#, fuzzy
-#| msgid "-mtune=PROCESSOR\tOptimize the output for PROCESSOR"
 msgid "-mtune=PROCESSOR\tOptimize the output for PROCESSOR."
-msgstr "-mtune=ПРОЦЕССОР\tОптимизировать код для указанного ПРОЦЕССОРа"
+msgstr "-mtune=ПРОЦЕССОР\tОптимизировать код для указанного ПРОЦЕССОРа."
 
 #: config/riscv/riscv.opt:81
-#, fuzzy
-#| msgid "-G<number>\tPut global and static data smaller than <number> bytes into a special section (on some targets)"
 msgid "-msmall-data-limit=N\tPut global and static data smaller than <number> bytes into a special section (on some targets)."
-msgstr "-G<number>\tРазмещать глобальные и статические данные меньше заданного <числа> байт в специальных секциях (для некоторых платформ)"
+msgstr "-msmall-data-limit=N\tРазмещать глобальные и статические данные размером не более N в специальных секциях (для некоторых платформ)"
 
 #: config/riscv/riscv.opt:85
-#, fuzzy
-#| msgid "Use subroutines for function prologues and epilogues"
 msgid "Use smaller but slower prologue and epilogue code."
-msgstr "Использовать подпрограммы для прологов/эпилогов функций"
+msgstr "Использовать более короткие, но менее быстрые прологи и эпилоги функций."
 
 #: config/riscv/riscv.opt:89 config/aarch64/aarch64.opt:85
-#, fuzzy
-#| msgid "Select code model"
 msgid "Specify the code model."
 msgstr "Выбрать модель кода"
 
 #: config/riscv/riscv.opt:93
-#, fuzzy
-#| msgid "Do not use unaligned memory references"
 msgid "Do not generate unaligned memory accesses."
-msgstr "Не использовать невыровненные ссылки на память"
+msgstr ""
 
 #: config/riscv/riscv.opt:97 config/i386/i386.opt:287
 #: config/powerpcspe/aix64.opt:36 config/powerpcspe/linux64.opt:32
@@ -9901,7 +8500,7 @@
 
 #: config/riscv/riscv.opt:107
 msgid "Use %reloc() operators, rather than assembly macros, to load addresses."
-msgstr ""
+msgstr "Использовать операторы %reloc() а не макросы ассемблера для загрузки адресов."
 
 #: config/riscv/riscv.opt:111
 msgid "Take advantage of linker relaxations to reduce the number of instructions required to materialize symbol addresses."
@@ -9908,206 +8507,170 @@
 msgstr ""
 
 #: config/m32c/m32c.opt:23
-#, fuzzy
-#| msgid "-msim\tUse simulator runtime"
 msgid "-msim\tUse simulator runtime."
-msgstr "-msim\tИспользовать симулятор runtime"
+msgstr "-msim\tИспользовать runtime для симулятора."
 
 #: config/m32c/m32c.opt:27
-#, fuzzy
-#| msgid "-mcpu=r8c\tCompile code for R8C variants"
 msgid "-mcpu=r8c\tCompile code for R8C variants."
-msgstr "-mcpu=r8c\tКомпилировать код для R8C вариантов"
+msgstr "-mcpu=r8c\tКомпилировать код для R8C вариантов."
 
 #: config/m32c/m32c.opt:31
-#, fuzzy
-#| msgid "-mcpu=m16c\tCompile code for M16C variants"
 msgid "-mcpu=m16c\tCompile code for M16C variants."
-msgstr "-mcpu=m16c\tКомпилировать код для M16C вариантов"
+msgstr "-mcpu=m16c\tКомпилировать код для M16C вариантов."
 
 #: config/m32c/m32c.opt:35
-#, fuzzy
-#| msgid "-mcpu=m32cm\tCompile code for M32CM variants"
 msgid "-mcpu=m32cm\tCompile code for M32CM variants."
-msgstr "-mcpu=m32c\tКомпилировать код для M32CM вариантов"
+msgstr "-mcpu=m32c\tКомпилировать код для M32CM вариантов."
 
 #: config/m32c/m32c.opt:39
-#, fuzzy
-#| msgid "-mcpu=m32c\tCompile code for M32C variants"
 msgid "-mcpu=m32c\tCompile code for M32C variants."
-msgstr "-mcpu=m32c\tКомпилировать код для M32C вариантов"
+msgstr "-mcpu=m32c\tКомпилировать код для M32C вариантов."
 
 #: config/m32c/m32c.opt:43
-#, fuzzy
-#| msgid "-memregs=\tNumber of memreg bytes (default: 16, range: 0..16)"
 msgid "-memregs=\tNumber of memreg bytes (default: 16, range: 0..16)."
-msgstr "-memregs=\tЧисло memreg байт (по умолчанию: 16, диапазон: 0..16)"
+msgstr "-memregs=\tЧисло memreg байт (по умолчанию: 16, диапазон: 0..16)."
 
 #: config/msp430/msp430.opt:7
 msgid "Force assembly output to always use hex constants."
-msgstr ""
+msgstr "При генерации ассемблерного кода всегда использовать шестнадцатеричные константы."
 
 #: config/msp430/msp430.opt:11
 msgid "Specify the MCU to build for."
-msgstr ""
+msgstr "Задает целевую микросхему."
 
 #: config/msp430/msp430.opt:15
 msgid "Warn if an MCU name is unrecognized or conflicts with other options (default: on)."
-msgstr ""
+msgstr "Предупреждать, если имя микросхемы некорректно или конфликтует с другими ключами (по умолчанию включено)."
 
 #: config/msp430/msp430.opt:19
 msgid "Specify the ISA to build for: msp430, msp430x, msp430xv2."
-msgstr ""
+msgstr "Задать целевую архитектуру: msp430, msp430x, msp430xv2."
 
 #: config/msp430/msp430.opt:23
 msgid "Select large model - 20-bit addresses/pointers."
-msgstr ""
+msgstr "Выбрать модель large с 20-разрядными адресами/указателями."
 
 #: config/msp430/msp430.opt:27
 msgid "Select small model - 16-bit addresses/pointers (default)."
-msgstr ""
+msgstr "Выбрать модель smzll с 16-разрядными адресами/указателями (действует по умолчанию)."
 
 #: config/msp430/msp430.opt:31
 msgid "Optimize opcode sizes at link time."
-msgstr ""
+msgstr "Оптимизировать размеры кодов операций во время компоновки."
 
 #: config/msp430/msp430.opt:38
 msgid "Use a minimum runtime (no static initializers or ctors) for memory-constrained devices."
-msgstr ""
+msgstr "Использовать минимальный runtime (без статических инициализаций и конструкторов) для устройств с ограниченной памятью."
 
 #: config/msp430/msp430.opt:45
-#, fuzzy
-#| msgid "Select hardware or software multiplication support."
 msgid "Specify the type of hardware multiply to support."
-msgstr "Выбрать аппаратную или программную поддержку умножения."
+msgstr "Выбрать тип аппаратной поддержки умножения."
 
 #: config/msp430/msp430.opt:67
-#, fuzzy
-#| msgid "Specifies whether interrupt functions should save and restore the accumulator register."
 msgid "Specify whether functions should be placed into low or high memory."
-msgstr "Специфицирует должны ли функции прерываний сохранять и восстанавливать регистр сумматора."
+msgstr "Специфицирует, должны ли функции размещаться в нижнем или верхнем сегменте памяти."
 
 #: config/msp430/msp430.opt:71
 msgid "Specify whether variables should be placed into low or high memory."
-msgstr ""
+msgstr "Специфицирует, должны ли переменные размещаться в нижнем или верхнем сегменте памяти."
 
 #: config/msp430/msp430.opt:90
 msgid "Passes on a request to the assembler to enable fixes for various silicon errata."
-msgstr ""
+msgstr "Передается ассемблеру для исправления различных аппаратных ошибок."
 
 #: config/msp430/msp430.opt:94
 msgid "Passes on a request to the assembler to warn about various silicon errata."
-msgstr ""
+msgstr "Передается ассемблеру для выдачи предупреждений о различных аппаратных ошибках."
 
 #: config/aarch64/aarch64.opt:40
 msgid "The possible TLS dialects:"
-msgstr ""
+msgstr "Возможные диалекты TLS:"
 
 #: config/aarch64/aarch64.opt:52
 msgid "The code model option names for -mcmodel:"
-msgstr ""
+msgstr "Имена опций для различных моделей кода для -mcmodel:"
 
 #: config/aarch64/aarch64.opt:65 config/arm/arm.opt:99
 #: config/microblaze/microblaze.opt:60
-#, fuzzy
-#| msgid "Assume target CPU is configured as big endian"
 msgid "Assume target CPU is configured as big endian."
-msgstr "Считать что процессор имеет прямой порядок байт (big endian)"
+msgstr "Считать, что процессор имеет прямой порядок байт (big endian)."
 
 #: config/aarch64/aarch64.opt:69 config/i386/i386.opt:1007
-#, fuzzy
-#| msgid "Generate code which uses hardware floating point instructions"
 msgid "Generate code which uses only the general registers."
-msgstr "Генерировать код с использованием аппаратных инструкций вещественной арифметики"
+msgstr "Генерировать код с использованием только регистров общего назначения."
 
 #: config/aarch64/aarch64.opt:73
 msgid "Workaround for ARM Cortex-A53 Erratum number 835769."
-msgstr ""
+msgstr "Генерировать код для обхода аппаратной ошибки ARM Cortex-A53 номер 835769."
 
 #: config/aarch64/aarch64.opt:77
 msgid "Workaround for ARM Cortex-A53 Erratum number 843419."
-msgstr ""
+msgstr "Генерировать код для обхода аппаратной ошибки ARM Cortex-A53 номер 843419."
 
 #: config/aarch64/aarch64.opt:81 config/arm/arm.opt:164
 #: config/microblaze/microblaze.opt:64
-#, fuzzy
-#| msgid "Assume target CPU is configured as little endian"
 msgid "Assume target CPU is configured as little endian."
-msgstr "Считать что процессор имеет обратный порядок байт (little endian)"
+msgstr "Считать, что процессор имеет обратный порядок байт (little endian)."
 
 #: config/aarch64/aarch64.opt:89
 msgid "Don't assume that unaligned accesses are handled by the system."
-msgstr ""
+msgstr "Не предполагать, что система поддерживает невыровненный доступ к памяти."
 
 #: config/aarch64/aarch64.opt:93 config/i386/i386.opt:400
-#, fuzzy
-#| msgid "Omit the frame pointer in leaf functions"
 msgid "Omit the frame pointer in leaf functions."
-msgstr "Исключать указатель кадра в листовых функциях"
+msgstr "Исключать указатель кадра в листовых функциях."
 
 #: config/aarch64/aarch64.opt:97
 msgid "Specify TLS dialect."
-msgstr ""
+msgstr "Задать диалект TLS."
 
 #: config/aarch64/aarch64.opt:101
-#, fuzzy
-#| msgid "Specify bit size of immediate TLS offsets"
 msgid "Specifies bit size of immediate TLS offsets.  Valid values are 12, 24, 32, 48."
-msgstr "Битовый размер смещений для непосредственных TLS"
+msgstr "Битовый размер для непосредственных смещений TLS.  Допустимые значения: 12, 24, 32, 48."
 
 #: config/aarch64/aarch64.opt:120
-#, fuzzy
-#| msgid "-mcpu=CPU\tUse features of and schedule code for given CPU"
 msgid "-march=ARCH\tUse features of architecture ARCH."
-msgstr "-mcpu=CPU\tИспользовать возможности и планировать код для заданного CPU"
+msgstr "-march=ARCH\tИспользовать возможности и планировать код для заданной архитектуры."
 
 #: config/aarch64/aarch64.opt:124
-#, fuzzy
-#| msgid "-mcpu=CPU\tUse features of and schedule code for given CPU"
 msgid "-mcpu=CPU\tUse features of and optimize for CPU."
-msgstr "-mcpu=CPU\tИспользовать возможности и планировать код для заданного CPU"
+msgstr "-mcpu=CPU\tИспользовать возможности заданного CPU и оптимизировать код для него."
 
 #: config/aarch64/aarch64.opt:128
 msgid "-mtune=CPU\tOptimize for CPU."
-msgstr ""
+msgstr "-mtune=CPU\tОптимизировать код для заданного процессора."
 
 #: config/aarch64/aarch64.opt:132
-#, fuzzy
-#| msgid "-mabi=ABI\tGenerate code that conforms to the given ABI"
 msgid "-mabi=ABI\tGenerate code that conforms to the specified ABI."
-msgstr "-mabi=ABI\tГенерировать код в соответствии с заданным ABI"
+msgstr "-mabi=ABI\tГенерировать код в соответствии с заданным ABI."
 
 #: config/aarch64/aarch64.opt:136
 msgid "-moverride=STRING\tPower users only! Override CPU optimization parameters."
-msgstr ""
+msgstr "-moverride=STRING\tТолько для опытных пользователей! Переопределить параметры оптимизации CPU."
 
 #: config/aarch64/aarch64.opt:140
-#, fuzzy
-#| msgid "Known ARM ABIs (for use with the -mabi= option):"
 msgid "Known AArch64 ABIs (for use with the -mabi= option):"
-msgstr "Известные ARM ABIs (для использования с -mabi= опцией):"
+msgstr "Известные AArch64 ABIs (для использования с -mabi= опцией):"
 
 #: config/aarch64/aarch64.opt:150
 msgid "PC relative literal loads."
-msgstr ""
+msgstr "Загрузки литеральных значений относительно счетчика команд (PC)."
 
 #: config/aarch64/aarch64.opt:154
 msgid "Select return address signing scope."
-msgstr ""
+msgstr "Выбрать область применения подписанных адресов возврата из функций."
 
 #: config/aarch64/aarch64.opt:158
-#, fuzzy
-#| msgid "Known code models (for use with the -mcmodel= option):"
 msgid "Supported AArch64 return address signing scope (for use with -msign-return-address= option):"
-msgstr "Известные модели кода (значения ключа -mcmodel= ):"
+msgstr "Допустимые значения ключа -msign-return-address=option:"
 
 #: config/aarch64/aarch64.opt:171
 msgid "Enable the reciprocal square root approximation.  Enabling this reduces precision of reciprocal square root results to about 16 bits for single precision and to 32 bits for double precision."
-msgstr ""
+msgstr "Разрешить аппроксимацию обратного значения корня квадратного.   При этом точность вычисления обратного значения корня квадратного сокращается до примерно 16 разрядов для одинарной точности и до 32 разрядов для двойной точности."
 
 #: config/aarch64/aarch64.opt:177
 msgid "Enable the square root approximation.  Enabling this reduces precision of square root results to about 16 bits for single precision and to 32 bits for double precision. If enabled, it implies -mlow-precision-recip-sqrt."
-msgstr ""
+msgstr "Разрешить аппроксимацию квадратного корня.   При этом точность вычисления квадратного корня сокращается до примерно 16 разрядов для одинарной точности и до 32 разрядов для двойной точности. If enabled, it implies -mlow-precision-recip-sqrt."
 
 #: config/aarch64/aarch64.opt:184
 msgid "Enable the division approximation.  Enabling this reduces precision of division results to about 16 bits for single precision and to 32 bits for double precision."
@@ -10115,193 +8678,135 @@
 
 #: config/aarch64/aarch64.opt:190
 msgid "The possible SVE vector lengths:"
-msgstr ""
+msgstr "Возможные длины вектора SVE:"
 
 #: config/aarch64/aarch64.opt:212
 msgid "-msve-vector-bits=N\tSet the number of bits in an SVE vector register to N."
-msgstr ""
+msgstr "-msve-vector-bits=N\tЗадаёт число бит в регистре вектора SVE, равное N."
 
 #: config/aarch64/aarch64.opt:216
 msgid "Enables verbose cost model dumping in the debug dump files."
-msgstr ""
+msgstr "Включает подробный режим выдачи дампа стоимостной модели в файлы отладочных дампов."
 
 #: config/linux.opt:24
-#, fuzzy
-#| msgid "Use Bionic C library"
 msgid "Use Bionic C library."
-msgstr "Использовать Bionic C библиотеку"
+msgstr "Использовать Bionic C библиотеку."
 
 #: config/linux.opt:28
-#, fuzzy
-#| msgid "Use GNU C library"
 msgid "Use GNU C library."
-msgstr "Использовать GNU C библиотеку"
+msgstr "Использовать GNU C библиотеку."
 
 #: config/linux.opt:32
-#, fuzzy
-#| msgid "Use uClibc C library"
 msgid "Use uClibc C library."
-msgstr "Использовать uClibc C библиотеку"
+msgstr "Использовать uClibc C библиотеку."
 
 #: config/linux.opt:36
-#, fuzzy
-#| msgid "Use uClibc C library"
 msgid "Use musl C library."
-msgstr "Использовать uClibc C библиотеку"
+msgstr "Использовать musl C библиотеку."
 
 #: config/ia64/ilp32.opt:3
-#, fuzzy
-#| msgid "Generate ILP32 code"
 msgid "Generate ILP32 code."
-msgstr "Генерировать код для ILP32"
+msgstr "Генерировать код для ILP32."
 
 #: config/ia64/ilp32.opt:7
-#, fuzzy
-#| msgid "Generate LP64 code"
 msgid "Generate LP64 code."
-msgstr "Генерировать код для LP64"
+msgstr "Генерировать код для LP64."
 
 #: config/ia64/ia64.opt:28
-#, fuzzy
-#| msgid "Generate big endian code"
 msgid "Generate big endian code."
-msgstr "Генерировать код для прямого порядка байт (big endian)"
+msgstr "Генерировать код для прямого порядка байт (big endian)."
 
 #: config/ia64/ia64.opt:32
-#, fuzzy
-#| msgid "Generate little endian code"
 msgid "Generate little endian code."
-msgstr "Генерировать код для обратного порядка байт (big endian)"
+msgstr "Генерировать код для обратного порядка байт (big endian)."
 
 #: config/ia64/ia64.opt:36
-#, fuzzy
-#| msgid "Generate code for GNU as"
 msgid "Generate code for GNU as."
-msgstr "Генерировать код для GNU-ассемблера"
+msgstr "Генерировать код для GNU-ассемблера."
 
 #: config/ia64/ia64.opt:40
-#, fuzzy
-#| msgid "Generate code for GNU ld"
 msgid "Generate code for GNU ld."
-msgstr "Генерировать код для компоновщика GNU"
+msgstr "Генерировать код для компоновщика GNU."
 
 #: config/ia64/ia64.opt:44
-#, fuzzy
-#| msgid "Emit stop bits before and after volatile extended asms"
 msgid "Emit stop bits before and after volatile extended asms."
-msgstr "Генерировать stop-биты до и после расширенных операторов volatile asm"
+msgstr "Генерировать stop-биты до и после расширенных операторов volatile asm."
 
 #: config/ia64/ia64.opt:48
-#, fuzzy
-#| msgid "Use in/loc/out register names"
 msgid "Use in/loc/out register names."
-msgstr "Использовать имена регистров in/loc/out"
+msgstr "Использовать имена регистров in/loc/out."
 
 #: config/ia64/ia64.opt:55
-#, fuzzy
-#| msgid "Enable use of sdata/scommon/sbss"
 msgid "Enable use of sdata/scommon/sbss."
-msgstr "Включить использование sdata/scommon/sbss"
+msgstr "Включить использование sdata/scommon/sbss."
 
 #: config/ia64/ia64.opt:59
-#, fuzzy
-#| msgid "Generate code without GP reg"
 msgid "Generate code without GP reg."
-msgstr "Генерировать код без GP-регистра"
+msgstr "Генерировать код без GP-регистра."
 
 #: config/ia64/ia64.opt:63
-#, fuzzy
-#| msgid "gp is constant (but save/restore gp on indirect calls)"
 msgid "gp is constant (but save/restore gp on indirect calls)."
-msgstr "значение gp постоянно (но при косвенных вызовах его нужно сохранять и восстанавливать)"
+msgstr "значение gp постоянно (но при косвенных вызовах его нужно сохранять и восстанавливать)."
 
 #: config/ia64/ia64.opt:67
-#, fuzzy
-#| msgid "Generate self-relocatable code"
 msgid "Generate self-relocatable code."
-msgstr "Генерировать самоперемещаемый код"
+msgstr "Генерировать самоперемещаемый код."
 
 #: config/ia64/ia64.opt:71
-#, fuzzy
-#| msgid "Generate inline floating point division, optimize for latency"
 msgid "Generate inline floating point division, optimize for latency."
-msgstr "Выполнять inline-подстановку кода для плавающего деления, оптимизировать по латентности"
+msgstr "Выполнять inline-подстановку кода для плавающего деления, оптимизировать по латентности."
 
 #: config/ia64/ia64.opt:75
-#, fuzzy
-#| msgid "Generate inline floating point division, optimize for throughput"
 msgid "Generate inline floating point division, optimize for throughput."
-msgstr "Выполнять inline-подстановку кода для плавающего деления, оптимизировать по пропускной способности"
+msgstr "Выполнять inline-подстановку кода для плавающего деления, оптимизировать по пропускной способности."
 
 #: config/ia64/ia64.opt:82
-#, fuzzy
-#| msgid "Generate inline integer division, optimize for latency"
 msgid "Generate inline integer division, optimize for latency."
-msgstr "Выполнять inline-подстановку кода для целочисленного деления, оптимизировать по латентности"
+msgstr "Выполнять inline-подстановку кода для целочисленного деления, оптимизировать по латентности."
 
 #: config/ia64/ia64.opt:86
-#, fuzzy
-#| msgid "Generate inline integer division, optimize for throughput"
 msgid "Generate inline integer division, optimize for throughput."
-msgstr "Выполнять inline-подстановку кода для целочисленного деления, оптимизировать по пропускной способности"
+msgstr "Выполнять inline-подстановку кода для целочисленного деления, оптимизировать по пропускной способности."
 
 #: config/ia64/ia64.opt:90
-#, fuzzy
-#| msgid "Do not inline integer division"
 msgid "Do not inline integer division."
-msgstr "Не включать в код деление целых"
+msgstr "Не выполнять inline-подстановку деления целых."
 
 #: config/ia64/ia64.opt:94
-#, fuzzy
-#| msgid "Generate inline square root, optimize for latency"
 msgid "Generate inline square root, optimize for latency."
-msgstr "Генерировать inline-подстановку sqrt, оптимизированную по латентности"
+msgstr "Генерировать inline-подстановку sqrt, оптимизированную по латентности."
 
 #: config/ia64/ia64.opt:98
-#, fuzzy
-#| msgid "Generate inline square root, optimize for throughput"
 msgid "Generate inline square root, optimize for throughput."
-msgstr "Генерировать inline-подстановку sqrt, оптимизированную по пропускной способности"
+msgstr "Генерировать inline-подстановку sqrt, оптимизированную по пропускной способности."
 
 #: config/ia64/ia64.opt:102
-#, fuzzy
-#| msgid "Do not inline square root"
 msgid "Do not inline square root."
-msgstr "Не включать в код вычисление квадратного корня"
+msgstr "Не включать в код вычисление квадратного корня."
 
 #: config/ia64/ia64.opt:106
-#, fuzzy
-#| msgid "Enable Dwarf 2 line debug info via GNU as"
 msgid "Enable DWARF line debug info via GNU as."
-msgstr "Включить отладочную информацию Dwarf 2 посредством GNU-ассемблера"
+msgstr "Включить отладочную информацию Dwarf для номеров строк посредством GNU-ассемблера."
 
 #: config/ia64/ia64.opt:110
-#, fuzzy
-#| msgid "Enable earlier placing stop bits for better scheduling"
 msgid "Enable earlier placing stop bits for better scheduling."
-msgstr "Включить раннее размещение stop-битов для улучшения планирования"
+msgstr "Включить раннее размещение stop-битов для улучшения планирования."
 
 #: config/ia64/ia64.opt:114 config/spu/spu.opt:72 config/pa/pa.opt:62
 #: config/sh/sh.opt:227
-#, fuzzy
-#| msgid "Specify range of registers to make fixed"
 msgid "Specify range of registers to make fixed."
-msgstr "Диапазон регистров с фиксированным назначением"
+msgstr "Диапазон регистров с фиксированным назначением."
 
 #: config/ia64/ia64.opt:118 config/powerpcspe/sysv4.opt:32
 #: config/alpha/alpha.opt:130
-#, fuzzy
-#| msgid "Specify bit size of immediate TLS offsets"
 msgid "Specify bit size of immediate TLS offsets."
-msgstr "Битовый размер смещений для непосредственных TLS"
+msgstr "Битовый размер для непосредственных смещений TLS."
 
 #: config/ia64/ia64.opt:122 config/spu/spu.opt:84 config/i386/i386.opt:514
 #: config/s390/s390.opt:200 config/sparc/sparc.opt:146
 #: config/visium/visium.opt:49
-#, fuzzy
-#| msgid "Schedule code for given CPU"
 msgid "Schedule code for given CPU."
-msgstr "Планировать код для указанного процессора"
+msgstr "Планировать код для указанного процессора."
 
 #: config/ia64/ia64.opt:126
 msgid "Known Itanium CPUs (for use with the -mtune= option):"
@@ -10308,202 +8813,136 @@
 msgstr "Известные Itanium CPUs (для использования с опцией -mtune=):"
 
 #: config/ia64/ia64.opt:136
-#, fuzzy
-#| msgid "Use data speculation before reload"
 msgid "Use data speculation before reload."
-msgstr "Использовать предвыборку данных перед перезагрузкой"
+msgstr "Использовать предвыборку данных перед перезагрузкой."
 
 #: config/ia64/ia64.opt:140
-#, fuzzy
-#| msgid "Use data speculation after reload"
 msgid "Use data speculation after reload."
-msgstr "Использовать предвыборку данных после перезагрузки"
+msgstr "Использовать предвыборку данных после перезагрузки."
 
 #: config/ia64/ia64.opt:144
-#, fuzzy
-#| msgid "Use control speculation"
 msgid "Use control speculation."
-msgstr "Использовать предвыборку управления"
+msgstr "Использовать планирование, спекулятивное по управлению."
 
 #: config/ia64/ia64.opt:148
-#, fuzzy
-#| msgid "Use in block data speculation before reload"
 msgid "Use in block data speculation before reload."
-msgstr "Использовать в блочной предвыборке данных перед перезагрузкой"
+msgstr "Использовать блочное спекулятивное планирование перед проходом перезагрузки."
 
 #: config/ia64/ia64.opt:152
-#, fuzzy
-#| msgid "Use in block data speculation after reload"
 msgid "Use in block data speculation after reload."
-msgstr "Использовать в блочной предвыборке данных после перезагрузки"
+msgstr "Использовать блочное спекулятивное планирование после прохода перезагрузки."
 
 #: config/ia64/ia64.opt:156
-#, fuzzy
-#| msgid "Use in block control speculation"
 msgid "Use in block control speculation."
-msgstr "Использовать в блочной предвыборке управления"
+msgstr "Использовать блочное спекулятивное планирование."
 
 #: config/ia64/ia64.opt:160
-#, fuzzy
-#| msgid "Use simple data speculation check"
 msgid "Use simple data speculation check."
-msgstr "Использовать простую проверку предвыборки данных"
+msgstr "Использовать простую проверку спекулятивной выборки данных."
 
 #: config/ia64/ia64.opt:164
-#, fuzzy
-#| msgid "Use simple data speculation check for control speculation"
 msgid "Use simple data speculation check for control speculation."
-msgstr "Использовать простую проверку предвыборки данных для предвыборки управления"
+msgstr "Использовать простую проверку спекулятивной выборки данных для при спекулятивном планировании по управлению."
 
 #: config/ia64/ia64.opt:174
-#, fuzzy
-#| msgid "Count speculative dependencies while calculating priority of instructions"
 msgid "Count speculative dependencies while calculating priority of instructions."
-msgstr "Учесть зависимости предвыборки при вычислении приоритета инструкций"
+msgstr "Учесть зависимости спекулятивной выборки при вычислении приоритета инструкций."
 
 #: config/ia64/ia64.opt:178
-#, fuzzy
-#| msgid "Place a stop bit after every cycle when scheduling"
 msgid "Place a stop bit after every cycle when scheduling."
-msgstr "Поместить stop бит после каждого цикла при планировании"
+msgstr "Поместить stop бит после каждого цикла при планировании."
 
 #: config/ia64/ia64.opt:182
-#, fuzzy
-#| msgid "Assume that floating-point stores and loads are not likely to cause conflict when placed into one instruction group"
 msgid "Assume that floating-point stores and loads are not likely to cause conflict when placed into one instruction group."
-msgstr "Предполагается что плавающие запись и чтение едва ли вызовут конфликт если помещены в одну группу инструкций"
+msgstr "Предполагать, что плавающие запись и чтение вряд ли вызовут конфликт, если помещены в одну группу инструкций"
 
 #: config/ia64/ia64.opt:186
-#, fuzzy
-#| msgid "Soft limit on number of memory insns per instruction group, giving lower priority to subsequent memory insns attempting to schedule in the same insn group. Frequently useful to prevent cache bank conflicts.  Default value is 1"
 msgid "Soft limit on number of memory insns per instruction group, giving lower priority to subsequent memory insns attempting to schedule in the same insn group. Frequently useful to prevent cache bank conflicts.  Default value is 1."
-msgstr "Мягкий лимит на число инструкций памяти на группу инструкций, давая более низкий приоритет последующим инструкциям памяти для планирования в той же группе. Часто полезно для предотвращения конфликтов банков кэша. Подразумеваемое значение есть 1"
+msgstr "Мягкий лимит на число инструкций памяти на группу инструкций, давая более низкий приоритет последующим инструкциям памяти для планирования в той же группе. Часто полезно для предотвращения конфликтов банков кэша.  Значение по умолчанию — 1."
 
 #: config/ia64/ia64.opt:190
-#, fuzzy
-#| msgid "Disallow more than 'msched-max-memory-insns' in instruction group. Otherwise, limit is 'soft' (prefer non-memory operations when limit is reached)"
 msgid "Disallow more than 'msched-max-memory-insns' in instruction group. Otherwise, limit is 'soft' (prefer non-memory operations when limit is reached)."
-msgstr "Запрет более чем 'msched-max-memory-insns' в группе инструкций. В противном случае лимит является 'мягким' (предпочитаются операции не с памятью когда лимит достигается)"
+msgstr "Запрет более чем 'msched-max-memory-insns' в группе инструкций. В противном случае лимит является 'мягким' (предпочитаются операции не с памятью, когда лимит достигается)."
 
 #: config/ia64/ia64.opt:194
-#, fuzzy
-#| msgid "Don't generate checks for control speculation in selective scheduling"
 msgid "Don't generate checks for control speculation in selective scheduling."
-msgstr "Не генерировать проверки для предвыборки управления в выборочном планировании"
+msgstr "Не генерировать проверки для спекулятивного планирования по управления при выборочном планировании."
 
 #: config/spu/spu.opt:20
-#, fuzzy
-#| msgid "Emit warnings when run-time relocations are generated"
 msgid "Emit warnings when run-time relocations are generated."
-msgstr "Выдавать предупреждение при генерации настроек времени выполнения"
+msgstr "Выдавать предупреждение при генерации настроек времени выполнения."
 
 #: config/spu/spu.opt:24
-#, fuzzy
-#| msgid "Emit errors when run-time relocations are generated"
 msgid "Emit errors when run-time relocations are generated."
-msgstr "Выдавать ошибки при генерации настроек времени выполнения"
+msgstr "Выдавать ошибки при генерации настроек времени выполнения."
 
 #: config/spu/spu.opt:28
-#, fuzzy
-#| msgid "Specify cost of branches (Default 20)"
 msgid "Specify cost of branches (Default 20)."
-msgstr "Установить цену переходов (По умолчанию 20)"
+msgstr "Установить цену переходов (По умолчанию 20)."
 
 #: config/spu/spu.opt:32
-#, fuzzy
-#| msgid "Make sure loads and stores are not moved past DMA instructions"
 msgid "Make sure loads and stores are not moved past DMA instructions."
-msgstr "Обеспечить чтобы загрузки и сохранения не были перемещены после DMA инструкций"
+msgstr "Обеспечить, чтобы загрузки и сохранения не перемещались после DMA инструкций."
 
 #: config/spu/spu.opt:36
-#, fuzzy
-#| msgid "volatile must be specified on any memory that is effected by DMA"
 msgid "volatile must be specified on any memory that is effected by DMA."
-msgstr "volatile должно быть задано на любую память, затрагиваемую DMA"
+msgstr "volatile должно быть задано на любую память, затрагиваемую DMA."
 
 #: config/spu/spu.opt:40 config/spu/spu.opt:44
-#, fuzzy
-#| msgid "Insert nops when it might improve performance by allowing dual issue (default)"
 msgid "Insert nops when it might improve performance by allowing dual issue (default)."
-msgstr "Вставлять nops когда это может повысить производительность путем разрешения двойного запуска (по умолчанию)"
+msgstr "Вставлять nops, когда это может повысить производительность путем разрешения двойного запуска (по умолчанию)."
 
 #: config/spu/spu.opt:48
-#, fuzzy
-#| msgid "Use standard main function as entry for startup"
 msgid "Use standard main function as entry for startup."
-msgstr "Использовать стандартную главную функцию как вход для startup"
+msgstr "Использовать стандартную главную функцию main как точку входа при старте программы."
 
 #: config/spu/spu.opt:52
-#, fuzzy
-#| msgid "Generate branch hints for branches"
 msgid "Generate branch hints for branches."
-msgstr "Генерировать подсказки для ветвлений"
+msgstr "Генерировать подсказки для ветвлений."
 
 #: config/spu/spu.opt:56
-#, fuzzy
-#| msgid "Maximum number of nops to insert for a hint (Default 2)"
 msgid "Maximum number of nops to insert for a hint (Default 2)."
-msgstr "Максимальное число nops при вставке для подсказки (По умолчанию 2)"
+msgstr "Максимальное число nops при вставке для подсказки (По умолчанию 2)."
 
 #: config/spu/spu.opt:60
-#, fuzzy
-#| msgid "Approximate maximum number of instructions to allow between a hint and its branch [125]"
 msgid "Approximate maximum number of instructions to allow between a hint and its branch [125]."
-msgstr "Примерное максимальное число инструкций допустимых между подсказкой и соответствующим ветвлением [125]"
+msgstr "Примерное максимальное число инструкций допустимых между подсказкой и соответствующим ветвлением [125]."
 
 #: config/spu/spu.opt:64
-#, fuzzy
-#| msgid "Generate code for 18 bit addressing"
 msgid "Generate code for 18 bit addressing."
-msgstr "Генерировать код для 18-битной адресации"
+msgstr "Генерировать код для 18-битной адресации."
 
 #: config/spu/spu.opt:68
-#, fuzzy
-#| msgid "Generate code for 32 bit addressing"
 msgid "Generate code for 32 bit addressing."
-msgstr "Генерировать код для 32-битной адресации"
+msgstr "Генерировать код для 32-битной адресации."
 
 #: config/spu/spu.opt:76
-#, fuzzy
-#| msgid "Insert hbrp instructions after hinted branch targets to avoid the SPU hang issue"
 msgid "Insert hbrp instructions after hinted branch targets to avoid the SPU hang issue."
-msgstr "Вставлять hbrp инструкции после подсказанных целей ветвлений чтобы избежать SPU hang запуска"
+msgstr "Вставлять hbrp инструкции после подсказанных целей ветвлений, чтобы избежать SPU hang запуска."
 
 #: config/spu/spu.opt:80 config/i386/i386.opt:257 config/s390/s390.opt:56
-#, fuzzy
-#| msgid "Generate code for given CPU"
 msgid "Generate code for given CPU."
-msgstr "Генерировать код для указанного процессора"
+msgstr "Генерировать код для указанного процессора."
 
 #: config/spu/spu.opt:88
-#, fuzzy
-#| msgid "Access variables in 32-bit PPU objects (default)"
 msgid "Access variables in 32-bit PPU objects (default)."
-msgstr "Обращаться к переменным в 32-битных PPU объектах (по умолчанию)"
+msgstr "Обращаться к переменным в 32-битных PPU объектах (по умолчанию)."
 
 #: config/spu/spu.opt:92
-#, fuzzy
-#| msgid "Access variables in 64-bit PPU objects"
 msgid "Access variables in 64-bit PPU objects."
-msgstr "Обращаться к переменным в 64-битных PPU объектах"
+msgstr "Обращаться к переменным в 64-битных PPU объектах."
 
 #: config/spu/spu.opt:96
-#, fuzzy
-#| msgid "Allow conversions between __ea and generic pointers (default)"
 msgid "Allow conversions between __ea and generic pointers (default)."
-msgstr "Разрешить преобразования между __ea и generic указателями (по умолчанию)"
+msgstr "Разрешить преобразования между __ea и generic указателями (по умолчанию)."
 
 #: config/spu/spu.opt:100
-#, fuzzy
-#| msgid "Size (in KB) of software data cache"
 msgid "Size (in KB) of software data cache."
-msgstr "Размер (в KB) программного кэша данных"
+msgstr "Размер (в KB) программного кэша данных."
 
 #: config/spu/spu.opt:104
-#, fuzzy
-#| msgid "Atomically write back software data cache lines (default)"
 msgid "Atomically write back software data cache lines (default)."
-msgstr "Автоматически write back строки программного кэша данных (по умолчанию)"
+msgstr "Автоматически write back строки программного кэша данных (по умолчанию)."
 
 #: config/epiphany/epiphany.opt:24
 msgid "Don't use any of r32..r63."
@@ -10511,13 +8950,11 @@
 
 #: config/epiphany/epiphany.opt:28
 msgid "preferentially allocate registers that allow short instruction generation."
-msgstr "Предпочтительно выделять регистры которые допускают генерацию коротких инструкций."
+msgstr "Предпочтительно выделять регистры, которые допускают генерацию коротких инструкций."
 
 #: config/epiphany/epiphany.opt:32
-#, fuzzy
-#| msgid "Set branch cost"
 msgid "Set branch cost."
-msgstr "Установить цену ветвлений"
+msgstr "Установить цену ветвлений."
 
 #: config/epiphany/epiphany.opt:36
 msgid "enable conditional move instruction usage."
@@ -10524,34 +8961,24 @@
 msgstr "включить использование инструкции условного перемещения."
 
 #: config/epiphany/epiphany.opt:40
-#, fuzzy
-#| msgid "set number of nops to emit before each insn pattern"
 msgid "set number of nops to emit before each insn pattern."
-msgstr "установить максимальное число nops для выдачи перед каждым шаблоном инструкций"
+msgstr "установить максимальное число nops для выдачи перед каждым шаблоном инструкций."
 
 #: config/epiphany/epiphany.opt:52
-#, fuzzy
-#| msgid "Use software floating point comparisons"
 msgid "Use software floating point comparisons."
-msgstr "Использовать программные сравнения плавающих"
+msgstr "Использовать программные сравнения плавающих."
 
 #: config/epiphany/epiphany.opt:56
-#, fuzzy
-#| msgid "Enable split of 32 bit immediate loads into low / high part"
 msgid "Enable split of 32 bit immediate loads into low / high part."
-msgstr "Включить расщепление загрузок 32-битных непосредственных на low / high части"
+msgstr "Включить расщепление загрузок 32-битных непосредственных на low / high части."
 
 #: config/epiphany/epiphany.opt:60
-#, fuzzy
-#| msgid "Enable use of POST_INC / POST_DEC"
 msgid "Enable use of POST_INC / POST_DEC."
-msgstr "Включить использование POST_INC / POST_DEC"
+msgstr "Включить использование POST_INC / POST_DEC."
 
 #: config/epiphany/epiphany.opt:64
-#, fuzzy
-#| msgid "Enable use of POST_MODIFY"
 msgid "Enable use of POST_MODIFY."
-msgstr "Включить использование POST_MODIFY"
+msgstr "Включить использование POST_MODIFY."
 
 #: config/epiphany/epiphany.opt:68
 msgid "Set number of bytes on the stack preallocated for use by the callee."
@@ -10559,27 +8986,23 @@
 
 #: config/epiphany/epiphany.opt:72
 msgid "Assume round to nearest is selected for purposes of scheduling."
-msgstr "Предполагать что выбрано округление до ближайшего для целей планирования."
+msgstr "Предполагать, что выбрано округление до ближайшего для целей планирования."
 
 #: config/epiphany/epiphany.opt:76
-#, fuzzy
-#| msgid "Generate call insns as indirect calls"
 msgid "Generate call insns as indirect calls."
-msgstr "Генерировать инструкции вызова как косвенные вызовы"
+msgstr "Генерировать инструкции вызова как косвенные вызовы."
 
 #: config/epiphany/epiphany.opt:80
-#, fuzzy
-#| msgid "Generate call insns as direct calls"
 msgid "Generate call insns as direct calls."
-msgstr "Генерировать инструкции вызова как прямые вызовы"
+msgstr "Генерировать инструкции вызова как непосредственные вызовы."
 
 #: config/epiphany/epiphany.opt:84
 msgid "Assume labels and symbols can be addressed using 16 bit absolute addresses."
-msgstr "Предполагать что метки и символы могут адресоваться с использованием 16-битных абсолютных адресов."
+msgstr "Предполагать, что метки и символы могут адресоваться с использованием 16-битных абсолютных адресов."
 
 #: config/epiphany/epiphany.opt:108
 msgid "A floatig point to integer truncation may be replaced with rounding to save mode switching."
-msgstr ""
+msgstr "Усечение вещественного до целого можно заменить округлением для сокращения переключений режима."
 
 #: config/epiphany/epiphany.opt:112
 msgid "Vectorize for double-word operations."
@@ -10590,30 +9013,24 @@
 msgstr "Расщеплять невыровненные 8-байтные пересылки векторов перед генерацией post-modify адресов."
 
 #: config/epiphany/epiphany.opt:132
-#, fuzzy
-#| msgid "Use hardware floating point conversion instructions"
 msgid "Use the floating point unit for integer add/subtract."
-msgstr "Использовать аппаратные инструкции преобразования чисел с плавающей точкой"
+msgstr "Использовать устройство плавающей арифметики для целочисленных операций сложения и вычитания."
 
 #: config/epiphany/epiphany.opt:136
 msgid "Set register to hold -1."
-msgstr "Установить регистр чтобы содержать -1."
+msgstr "Установить регистр равным -1."
 
 #: config/ft32/ft32.opt:23
 msgid "target the software simulator."
-msgstr ""
+msgstr "генерировать код для программного симулятора."
 
 #: config/ft32/ft32.opt:27 config/s390/s390.opt:231 config/mips/mips.opt:389
-#, fuzzy
-#| msgid "Use ROM instead of RAM"
 msgid "Use LRA instead of reload."
-msgstr "Использовать ROM вместо RAM"
+msgstr "Использовать LRA вместо перезагрузки."
 
 #: config/ft32/ft32.opt:31
-#, fuzzy
-#| msgid "Allow the use of MDMX instructions"
 msgid "Avoid use of the DIV and MOD instructions"
-msgstr "Разрешить использование команд MDMX"
+msgstr "Не использовать команды DIV and MOD."
 
 #: config/ft32/ft32.opt:35
 msgid "target the FT32B architecture"
@@ -10628,264 +9045,182 @@
 msgstr ""
 
 #: config/h8300/h8300.opt:23
-#, fuzzy
-#| msgid "Generate H8S code"
 msgid "Generate H8S code."
-msgstr "Генерировать код H8S"
+msgstr "Генерировать код H8S."
 
 #: config/h8300/h8300.opt:27
-#, fuzzy
-#| msgid "Generate H8SX code"
 msgid "Generate H8SX code."
-msgstr "Генерировать код H8SX"
+msgstr "Генерировать код H8SX."
 
 #: config/h8300/h8300.opt:31
-#, fuzzy
-#| msgid "Generate H8S/2600 code"
 msgid "Generate H8S/2600 code."
-msgstr "Генерировать код H8S/2600"
+msgstr "Генерировать код H8S/2600."
 
 #: config/h8300/h8300.opt:35
-#, fuzzy
-#| msgid "Make integers 32 bits wide"
 msgid "Make integers 32 bits wide."
-msgstr "Установить ширину целых типов 32 бита"
+msgstr "Установить размер целых значений 32 бита."
 
 #: config/h8300/h8300.opt:42
-#, fuzzy
-#| msgid "Use registers for argument passing"
 msgid "Use registers for argument passing."
-msgstr "Использовать регистры для передачи аргументов"
+msgstr "Использовать регистры для передачи аргументов."
 
 #: config/h8300/h8300.opt:46
-#, fuzzy
-#| msgid "Consider access to byte sized memory slow"
 msgid "Consider access to byte sized memory slow."
-msgstr "Считать, что доступ к байтным данным медленный"
+msgstr "Считать, что доступ к байтным данным медленный."
 
 #: config/h8300/h8300.opt:50
-#, fuzzy
-#| msgid "Enable linker relaxing"
 msgid "Enable linker relaxing."
-msgstr "Использовать ключ --relax при компоновке"
+msgstr "Использовать ключ --relax при компоновке."
 
 #: config/h8300/h8300.opt:54
-#, fuzzy
-#| msgid "Generate H8/300H code"
 msgid "Generate H8/300H code."
-msgstr "Генерировать код H8/300H"
+msgstr "Генерировать код H8/300H."
 
 #: config/h8300/h8300.opt:58
-#, fuzzy
-#| msgid "Enable the normal mode"
 msgid "Enable the normal mode."
-msgstr "Установить нормальный режим"
+msgstr "Установить нормальный режим."
 
 #: config/h8300/h8300.opt:62
-#, fuzzy
-#| msgid "Use H8/300 alignment rules"
 msgid "Use H8/300 alignment rules."
-msgstr "Использовать правила выравнивания H8/300H"
+msgstr "Использовать правила выравнивания H8/300H."
 
 #: config/h8300/h8300.opt:66
 msgid "Push extended registers on stack in monitor functions."
-msgstr ""
+msgstr "Помещать расширенные регистры на стек в функциях монитора."
 
 #: config/h8300/h8300.opt:70
 msgid "Do not push extended registers on stack in monitor functions."
-msgstr ""
+msgstr "Не помещать расширенные регистры на стек в функциях монитора."
 
 #: config/pdp11/pdp11.opt:23
-#, fuzzy
-#| msgid "Generate code for an 11/10"
 msgid "Generate code for an 11/10."
-msgstr "Генерировать код для 11/10"
+msgstr "Генерировать код для 11/10."
 
 #: config/pdp11/pdp11.opt:27
-#, fuzzy
-#| msgid "Generate code for an 11/40"
 msgid "Generate code for an 11/40."
-msgstr "Генерировать код для 11/40"
+msgstr "Генерировать код для 11/40."
 
 #: config/pdp11/pdp11.opt:31
-#, fuzzy
-#| msgid "Generate code for an 11/45"
 msgid "Generate code for an 11/45."
-msgstr "Генерировать код для 11/45"
+msgstr "Генерировать код для 11/45."
 
 #: config/pdp11/pdp11.opt:35
-#, fuzzy
-#| msgid "Return floating-point results in ac0 (fr0 in Unix assembler syntax)"
 msgid "Return floating-point results in ac0 (fr0 in Unix assembler syntax)."
-msgstr "Возвращать результаты плавающего типа в ac0 (fr0 в синтаксисе ассемблера Unix)"
+msgstr "Возвращать результаты плавающего типа в ac0 (fr0 в синтаксисе ассемблера Unix)."
 
 #: config/pdp11/pdp11.opt:39
-#, fuzzy
-#| msgid "Do not use inline patterns for copying memory"
 msgid "Do not use inline patterns for copying memory."
-msgstr "Не использовать встроенные шаблоны для копирования памяти"
+msgstr "Не использовать встроенные шаблоны для копирования памяти."
 
 #: config/pdp11/pdp11.opt:43
-#, fuzzy
-#| msgid "Use inline patterns for copying memory"
 msgid "Use inline patterns for copying memory."
-msgstr "Использовать встроенные шаблоны для копирования памяти"
+msgstr "Использовать встроенные шаблоны для копирования памяти."
 
 #: config/pdp11/pdp11.opt:47
-#, fuzzy
-#| msgid "Do not pretend that branches are expensive"
 msgid "Do not pretend that branches are expensive."
-msgstr "Не считать переходы затратными"
+msgstr "Не считать переходы затратными."
 
 #: config/pdp11/pdp11.opt:51
-#, fuzzy
-#| msgid "Pretend that branches are expensive"
 msgid "Pretend that branches are expensive."
-msgstr "Считать, что переходы затратны"
+msgstr "Считать, что переходы затратны."
 
 #: config/pdp11/pdp11.opt:55
-#, fuzzy
-#| msgid "Use the DEC assembler syntax"
 msgid "Use the DEC assembler syntax."
-msgstr "Использовать DEC-синтаксис для ассемблерного кода"
+msgstr "Использовать DEC-синтаксис для ассемблерного кода."
 
 #: config/pdp11/pdp11.opt:59
-#, fuzzy
-#| msgid "Use 32 bit float"
 msgid "Use 32 bit float."
-msgstr "Использовать 32-битное представление типа float"
+msgstr "Использовать 32-битное представление типа float."
 
 #: config/pdp11/pdp11.opt:63
-#, fuzzy
-#| msgid "Use 64 bit float"
 msgid "Use 64 bit float."
-msgstr "Использовать 64-битное представление типа float"
+msgstr "Использовать 64-битное представление типа float."
 
 #: config/pdp11/pdp11.opt:67 config/powerpcspe/powerpcspe.opt:177
 #: config/rs6000/rs6000.opt:196 config/frv/frv.opt:158
-#, fuzzy
-#| msgid "Use hardware floating point"
 msgid "Use hardware floating point."
-msgstr "Использовать аппаратную реализацию плавающей арифметики"
+msgstr "Использовать аппаратную реализацию плавающей арифметики."
 
 #: config/pdp11/pdp11.opt:71
-#, fuzzy
-#| msgid "Use 16 bit int"
 msgid "Use 16 bit int."
-msgstr "Использовать 16-битное представление типа int"
+msgstr "Использовать 16-битное представление типа int."
 
 #: config/pdp11/pdp11.opt:75
-#, fuzzy
-#| msgid "Use 32 bit int"
 msgid "Use 32 bit int."
-msgstr "Использовать 32-битное представление типа int"
+msgstr "Использовать 32-битное представление типа int."
 
 #: config/pdp11/pdp11.opt:79 config/powerpcspe/powerpcspe.opt:173
 #: config/rs6000/rs6000.opt:192
-#, fuzzy
-#| msgid "Do not use hardware floating point"
 msgid "Do not use hardware floating point."
-msgstr "Не использовать аппаратную плавающую арифметику"
+msgstr "Не использовать аппаратную плавающую арифметику."
 
 #: config/pdp11/pdp11.opt:83
-#, fuzzy
-#| msgid "Target has split I&D"
 msgid "Target has split I&D."
-msgstr "Целевая архитектура имеет разбиение памяти для кода и данных"
+msgstr "Целевая архитектура имеет разбиение памяти для кода и данных."
 
 #: config/pdp11/pdp11.opt:87
-#, fuzzy
-#| msgid "Use UNIX assembler syntax"
 msgid "Use UNIX assembler syntax."
-msgstr "Использовать UNIX-синтаксис для ассемблерного кода"
+msgstr "Использовать UNIX-синтаксис для ассемблерного кода."
 
 #: config/xtensa/xtensa.opt:23
-#, fuzzy
-#| msgid "Use CONST16 instruction to load constants"
 msgid "Use CONST16 instruction to load constants."
-msgstr "Использовать команды CONST16 для загрузки констант"
+msgstr "Использовать команды CONST16 для загрузки констант."
 
 #: config/xtensa/xtensa.opt:27
-#, fuzzy
-#| msgid "Disable position-independent code (PIC) for use in OS kernel code"
 msgid "Disable position-independent code (PIC) for use in OS kernel code."
-msgstr "Выключить позиционно-независимый код (PIC) для использования в коде ядра OS"
+msgstr "Выключить позиционно-независимый код (PIC) для использования в коде ядра OS."
 
 #: config/xtensa/xtensa.opt:31
-#, fuzzy
-#| msgid "Use indirect CALLXn instructions for large programs"
 msgid "Use indirect CALLXn instructions for large programs."
-msgstr "Использовать команды косвенного вызова CALLXn в больших программах"
+msgstr "Использовать команды косвенного вызова CALLXn в больших программах."
 
 #: config/xtensa/xtensa.opt:35
-#, fuzzy
-#| msgid "Automatically align branch targets to reduce branch penalties"
 msgid "Automatically align branch targets to reduce branch penalties."
-msgstr "Автоматически выравнивать позиции меток для сокращения задержек переходов"
+msgstr "Автоматически выравнивать позиции меток для сокращения задержек переходов."
 
 #: config/xtensa/xtensa.opt:39
-#, fuzzy
-#| msgid "Intersperse literal pools with code in the text section"
 msgid "Intersperse literal pools with code in the text section."
-msgstr "Помещать литеральные данные вместе с кодом в секцию text"
+msgstr "Помещать литеральные данные вместе с кодом в секцию text."
 
 #: config/xtensa/xtensa.opt:43
 msgid "Relax literals in assembler and place them automatically in the text section."
-msgstr ""
+msgstr "Ослабить литералы в ассемблере и помещать их автоматически в секцию text."
 
 #: config/xtensa/xtensa.opt:47
-#, fuzzy
-#| msgid "-mno-serialize-volatile\tDo not serialize volatile memory references with MEMW instructions"
 msgid "-mno-serialize-volatile\tDo not serialize volatile memory references with MEMW instructions."
-msgstr "-mno-serialize-volatile\tНе упорядочивать обращения к volatile памяти с MEMW инструкциями"
+msgstr "-mno-serialize-volatile\tНе упорядочивать обращения к volatile памяти с MEMW инструкциями."
 
 #: config/i386/cygming.opt:23
-#, fuzzy
-#| msgid "Create console application"
 msgid "Create console application."
-msgstr "Создать консольное приложение"
+msgstr "Создать консольное приложение."
 
 #: config/i386/cygming.opt:27
-#, fuzzy
-#| msgid "Generate code for a DLL"
 msgid "Generate code for a DLL."
-msgstr "Генерировать код для DLL"
+msgstr "Генерировать код для DLL."
 
 #: config/i386/cygming.opt:31
-#, fuzzy
-#| msgid "Ignore dllimport for functions"
 msgid "Ignore dllimport for functions."
-msgstr "Игнорировать dllimport для функций"
+msgstr "Игнорировать dllimport для функций."
 
 #: config/i386/cygming.opt:35
-#, fuzzy
-#| msgid "Use Mingw-specific thread support"
 msgid "Use Mingw-specific thread support."
-msgstr "Использовать поддержку потоков Mingw"
+msgstr "Использовать поддержку потоков Mingw."
 
 #: config/i386/cygming.opt:39
-#, fuzzy
-#| msgid "Set Windows defines"
 msgid "Set Windows defines."
-msgstr "Включить определения макросов Windows"
+msgstr "Включить определения макросов Windows."
 
 #: config/i386/cygming.opt:43
-#, fuzzy
-#| msgid "Create GUI application"
 msgid "Create GUI application."
-msgstr "Создать приложение с интерактивным графическим интерфейсом"
+msgstr "Создать приложение с интерактивным графическим интерфейсом."
 
 #: config/i386/cygming.opt:47
-#, fuzzy
-#| msgid "Use the GNU extension to the PE format for aligned common data"
 msgid "Use the GNU extension to the PE format for aligned common data."
-msgstr "Использовать GNU расширения PE формата для выравненных common данных"
+msgstr "Использовать GNU расширения PE формата для выравненных common данных."
 
 #: config/i386/cygming.opt:51
-#, fuzzy
-#| msgid "Compile code that relies on Cygwin DLL wrappers to support C++ operator new/delete replacement"
 msgid "Compile code that relies on Cygwin DLL wrappers to support C++ operator new/delete replacement."
-msgstr "Компилировать код, использующий обертки Cygwin DLL для поддержки замены операторов C++ new/delete"
+msgstr "Компилировать код, использующий обертки Cygwin DLL для поддержки замены операторов C++ new/delete."
 
 #: config/i386/cygming.opt:55
 msgid "For nested functions on stack executable permission is set."
@@ -10893,147 +9228,101 @@
 
 #: config/i386/cygming.opt:62
 msgid "Put relocated read-only data into .data section."
-msgstr ""
+msgstr "Помещать перемещаемые данные только для чтения в секцию .data."
 
 #: config/i386/mingw.opt:29
-#, fuzzy
-#| msgid "Warn about none ISO msvcrt scanf/printf width extensions"
 msgid "Warn about none ISO msvcrt scanf/printf width extensions."
-msgstr "Предупреждать об отсутствии расширений ISO msvcrt scanf/printf ширины"
+msgstr "Предупреждать об отсутствии расширений ISO msvcrt scanf/printf ширины."
 
 #: config/i386/mingw-w64.opt:23
-#, fuzzy
-#| msgid "Use unicode startup and define UNICODE macro"
 msgid "Use unicode startup and define UNICODE macro."
-msgstr "Использовать инициализацию unicode и определить макрос UNICODE"
+msgstr "Использовать инициализацию unicode и определить макрос UNICODE."
 
 #: config/i386/i386.opt:192
-#, fuzzy
-#| msgid "sizeof(long double) is 16"
 msgid "sizeof(long double) is 16."
-msgstr "sizeof(long double) равно 16"
+msgstr "sizeof(long double) равно 16."
 
 #: config/i386/i386.opt:196 config/i386/i386.opt:364
-#, fuzzy
-#| msgid "Use hardware fp"
 msgid "Use hardware fp."
-msgstr "Использовать аппаратную плавающую арифметику"
+msgstr "Использовать аппаратную плавающую арифметику."
 
 #: config/i386/i386.opt:200
-#, fuzzy
-#| msgid "sizeof(long double) is 12"
 msgid "sizeof(long double) is 12."
-msgstr "sizeof(long double) равно 12"
+msgstr "sizeof(long double) равно 12."
 
 #: config/i386/i386.opt:204
-#, fuzzy
-#| msgid "Use 128-bit long double"
 msgid "Use 80-bit long double."
-msgstr "Использовать 128-битное представление long double"
+msgstr "Использовать 80-битное представление long double"
 
 #: config/i386/i386.opt:208 config/s390/s390.opt:160
 #: config/sparc/long-double-switch.opt:27 config/alpha/alpha.opt:102
-#, fuzzy
-#| msgid "Use 64-bit long double"
 msgid "Use 64-bit long double."
-msgstr "Использовать 64-битное представление long double"
+msgstr "Использовать 64-битное представление long double."
 
 #: config/i386/i386.opt:212 config/s390/s390.opt:156
 #: config/sparc/long-double-switch.opt:23 config/alpha/alpha.opt:98
-#, fuzzy
-#| msgid "Use 128-bit long double"
 msgid "Use 128-bit long double."
-msgstr "Использовать 128-битное представление long double"
+msgstr "Использовать 128-битное представление long double."
 
 #: config/i386/i386.opt:216 config/sh/sh.opt:179
-#, fuzzy
-#| msgid "Reserve space for outgoing arguments in the function prologue"
 msgid "Reserve space for outgoing arguments in the function prologue."
-msgstr "Выделять место для возвращаемых аргументов в прологе функции"
+msgstr "Выделять место для возвращаемых аргументов в прологе функции."
 
 #: config/i386/i386.opt:220
-#, fuzzy
-#| msgid "Align some doubles on dword boundary"
 msgid "Align some doubles on dword boundary."
-msgstr "Выравнивать некоторые значения double по границе двойного слова"
+msgstr "Выравнивать некоторые значения double по границе двойного слова."
 
 #: config/i386/i386.opt:224
-#, fuzzy
-#| msgid "Function starts are aligned to this power of 2"
 msgid "Function starts are aligned to this power of 2."
-msgstr "Выравнивать функции по адресам, кратным указанной степени числа 2"
+msgstr "Выравнивать функции по адресам, кратным указанной степени числа 2."
 
 #: config/i386/i386.opt:228
-#, fuzzy
-#| msgid "Jump targets are aligned to this power of 2"
 msgid "Jump targets are aligned to this power of 2."
-msgstr "Выравнивать метки переходов по адресам, кратным указанной степени числа 2"
+msgstr "Выравнивать метки переходов по адресам, кратным указанной степени числа 2."
 
 #: config/i386/i386.opt:232
-#, fuzzy
-#| msgid "Loop code aligned to this power of 2"
 msgid "Loop code aligned to this power of 2."
-msgstr "Выравнивать циклы по адресам, кратным указанной степени числа 2"
+msgstr "Выравнивать циклы по адресам, кратным указанной степени числа 2."
 
 #: config/i386/i386.opt:236
-#, fuzzy
-#| msgid "Align destination of the string operations"
 msgid "Align destination of the string operations."
-msgstr "Выравнивать результаты строковых операций"
+msgstr "Выравнивать результаты строковых операций."
 
 #: config/i386/i386.opt:240
-#, fuzzy
-#| msgid "Do not tune writable data alignment"
 msgid "Use the given data alignment."
-msgstr "Не выравнивать данные, доступные на запись"
+msgstr "Использовать заданное выравнивание данных."
 
 #: config/i386/i386.opt:244
-#, fuzzy
-#| msgid "Known TLS dialects (for use with the -mtls-dialect= option):"
 msgid "Known data alignment choices (for use with the -malign-data= option):"
-msgstr "Диалекты TLS (возможные аргументы ключа -mtls-dialect=):"
+msgstr "Допустимые значения выравнивания (для ключа -malign-data=):"
 
 #: config/i386/i386.opt:261
-#, fuzzy
-#| msgid "Use given assembler dialect"
 msgid "Use given assembler dialect."
-msgstr "Использовать указанный диалект ассемблера"
+msgstr "Использовать указанный диалект ассемблера."
 
 #: config/i386/i386.opt:265
-#, fuzzy
-#| msgid "Known assembler dialects (for use with the -masm-dialect= option):"
 msgid "Known assembler dialects (for use with the -masm= option):"
-msgstr "Известные диалекты ассемблера (значения ключа -masm-dialect= ):"
+msgstr "Известные диалекты ассемблера (значения ключа -masm= ):"
 
 #: config/i386/i386.opt:275
-#, fuzzy
-#| msgid "Branches are this expensive (1-5, arbitrary units)"
 msgid "Branches are this expensive (arbitrary units)."
-msgstr "Стоимость переходов (1-5, произвольные единицы)"
+msgstr "Стоимость переходов (произвольные единицы)."
 
 #: config/i386/i386.opt:279
-#, fuzzy
-#| msgid "Data greater than given threshold will go into .ldata section in x86-64 medium model"
 msgid "-mlarge-data-threshold=<number>\tData greater than given threshold will go into .ldata section in x86-64 medium model."
-msgstr "Данные с размером, превышающим данное значение при генерации кода для medium-модели x86-64 будут размещаться в разделе .ldata"
+msgstr "-mlarge-data-threshold=<number>\tДанные с размером, превышающим данное значение при генерации кода для medium-модели x86-64 будут размещаться в разделе .ldata."
 
 #: config/i386/i386.opt:283
-#, fuzzy
-#| msgid "Use given x86-64 code model"
 msgid "Use given x86-64 code model."
-msgstr "Использовать указанную модель кода x86-64"
+msgstr "Использовать указанную модель кода x86-64."
 
 #: config/i386/i386.opt:306
-#, fuzzy
-#| msgid "Use given x86-64 code model"
 msgid "Use given address mode."
-msgstr "Использовать указанную модель кода x86-64"
+msgstr "Использовать указанную модель адресации."
 
 #: config/i386/i386.opt:310
-#, fuzzy
-#| msgid "Known code models (for use with the -mcmodel= option):"
 msgid "Known address mode (for use with the -maddress-mode= option):"
-msgstr "Известные модели кода (значения ключа -mcmodel= ):"
+msgstr "Известные модели адресации (значения ключа -maddress-mode= ):"
 
 #: config/i386/i386.opt:319
 msgid "%<-mcpu=%> is deprecated; use %<-mtune=%> or %<-march=%> instead"
@@ -11040,28 +9329,20 @@
 msgstr "ключ %<-mcpu=%> устарел; используйте %<-mtune=%> или %<-march=%>"
 
 #: config/i386/i386.opt:323
-#, fuzzy
-#| msgid "Generate sin, cos, sqrt for FPU"
 msgid "Generate sin, cos, sqrt for FPU."
-msgstr "Генерировать sin, cos, sqrt для FPU"
+msgstr "Генерировать sin, cos, sqrt для FPU."
 
 #: config/i386/i386.opt:327
-#, fuzzy
-#| msgid "Always use Dynamic Realigned Argument Pointer (DRAP) to realign stack"
 msgid "Always use Dynamic Realigned Argument Pointer (DRAP) to realign stack."
-msgstr "Всегда используйте Dynamic Realigned Argument Pointer (DRAP) для выравнивания стека"
+msgstr "Всегда используйте Dynamic Realigned Argument Pointer (DRAP) для выравнивания стека."
 
 #: config/i386/i386.opt:331
-#, fuzzy
-#| msgid "Return values of functions in FPU registers"
 msgid "Return values of functions in FPU registers."
-msgstr "Возвращать результаты функций в регистрах FPU"
+msgstr "Возвращать результаты функций в регистрах FPU."
 
 #: config/i386/i386.opt:335
-#, fuzzy
-#| msgid "Generate floating point mathematics using given instruction set"
 msgid "Generate floating point mathematics using given instruction set."
-msgstr "Генерировать код для плавающей арифметики используя заданный набор команд"
+msgstr "Генерировать код для плавающей арифметики используя заданный набор команд."
 
 #: config/i386/i386.opt:339
 msgid "Valid arguments to -mfpmath=:"
@@ -11068,16 +9349,12 @@
 msgstr "Допустимые аргументы -mfpmath=:"
 
 #: config/i386/i386.opt:372
-#, fuzzy
-#| msgid "Inline all known string operations"
 msgid "Inline all known string operations."
-msgstr "Выполнять inline-подстановку всех известных строковых операций"
+msgstr "Выполнять inline-подстановку всех известных строковых операций."
 
 #: config/i386/i386.opt:376
-#, fuzzy
-#| msgid "Inline memset/memcpy string operations, but perform inline version only for small blocks"
 msgid "Inline memset/memcpy string operations, but perform inline version only for small blocks."
-msgstr "Делать inline-подстановки строковых функций memset/memcpy, но выполнять inline-версии только для маленьких блоков памяти"
+msgstr "Делать inline-подстановки строковых функций memset/memcpy, но выполнять inline-версии только для маленьких блоков памяти."
 
 #: config/i386/i386.opt:379
 msgid "%<-mintel-syntax%> and %<-mno-intel-syntax%> are deprecated; use %<-masm=intel%> and %<-masm=att%> instead"
@@ -11084,96 +9361,68 @@
 msgstr "ключи %<-mintel-syntax%> и %<-mno-intel-syntax%> устарели; используйте %<-masm=intel%> и %<-masm=att%>"
 
 #: config/i386/i386.opt:384
-#, fuzzy
-#| msgid "Use native (MS) bitfield layout"
 msgid "Use native (MS) bitfield layout."
-msgstr "Использовать размещение битовых полей по соглашениям MS"
+msgstr "Использовать размещение битовых полей по соглашениям MS."
 
 #: config/i386/i386.opt:404
-#, fuzzy
-#| msgid "Set 80387 floating-point precision to 32-bit"
 msgid "Set 80387 floating-point precision to 32-bit."
-msgstr "Установить для 80387 32-битную точность плавающей арифметики"
+msgstr "Установить для 80387 32-битную точность плавающей арифметики."
 
 #: config/i386/i386.opt:408
-#, fuzzy
-#| msgid "Set 80387 floating-point precision to 64-bit"
 msgid "Set 80387 floating-point precision to 64-bit."
-msgstr "Установить для 80387 64-битную точность плавающей арифметики"
+msgstr "Установить для 80387 64-битную точность плавающей арифметики."
 
 #: config/i386/i386.opt:412
-#, fuzzy
-#| msgid "Set 80387 floating-point precision to 80-bit"
 msgid "Set 80387 floating-point precision to 80-bit."
-msgstr "Установить для 80387 80-битную точность плавающей арифметики"
+msgstr "Установить для 80387 80-битную точность плавающей арифметики."
 
 #: config/i386/i386.opt:420
-#, fuzzy
-#| msgid "Assume incoming stack aligned to this power of 2"
 msgid "Assume incoming stack aligned to this power of 2."
-msgstr "Считать, что при входе в функцию стек выровнен по адресу, кратному указанной степени числа 2"
+msgstr "Считать, что при входе в функцию стек выровнен по адресу, кратному указанной степени числа 2."
 
 #: config/i386/i386.opt:424
-#, fuzzy
-#| msgid "Use push instructions to save outgoing arguments"
 msgid "Use push instructions to save outgoing arguments."
-msgstr "Использовать команды push для сохранения выходных аргументов"
+msgstr "Использовать команды push для сохранения выходных аргументов."
 
 #: config/i386/i386.opt:428
-#, fuzzy
-#| msgid "Use red-zone in the x86-64 code"
 msgid "Use red-zone in the x86-64 code."
-msgstr "Использовать red-zone в коде x86-64"
+msgstr "Использовать red-zone в коде x86-64."
 
 #: config/i386/i386.opt:432
-#, fuzzy
-#| msgid "Number of registers used to pass integer arguments"
 msgid "Number of registers used to pass integer arguments."
-msgstr "Число регистров для передачи целочисленных аргументов"
+msgstr "Число регистров для передачи целочисленных аргументов."
 
 #: config/i386/i386.opt:436
-#, fuzzy
-#| msgid "Alternate calling convention"
 msgid "Alternate calling convention."
-msgstr "Альтернативные соглашения о вызовах"
+msgstr "Альтернативные соглашения о вызовах."
 
 #: config/i386/i386.opt:440 config/alpha/alpha.opt:23
-#, fuzzy
-#| msgid "Do not use hardware fp"
 msgid "Do not use hardware fp."
-msgstr "Не использовать аппаратную плавающую арифметику"
+msgstr "Не использовать аппаратную плавающую арифметику."
 
 #: config/i386/i386.opt:444
-#, fuzzy
-#| msgid "Use SSE register passing conventions for SF and DF mode"
 msgid "Use SSE register passing conventions for SF and DF mode."
-msgstr "Использовать соглашения по передаче регистров SSE для режимов SF и DF"
+msgstr "Использовать соглашения по передаче регистров SSE для режимов SF и DF."
 
 #: config/i386/i386.opt:448
-#, fuzzy
-#| msgid "Realign stack in prologue"
 msgid "Realign stack in prologue."
-msgstr "Повторно выравнивать стек в прологе"
+msgstr "Повторно выравнивать стек в прологе."
 
 #: config/i386/i386.opt:452
-#, fuzzy
-#| msgid "Enable stack probing"
 msgid "Enable stack probing."
-msgstr "Включить проверку стека зондированием"
+msgstr "Включить проверку стека зондированием."
 
 #: config/i386/i386.opt:456
 msgid "Specify memcpy expansion strategy when expected size is known."
-msgstr ""
+msgstr "Задать стратегию подстановки memcpy, когда ожидаемый размер известен."
 
 #: config/i386/i386.opt:460
 msgid "Specify memset expansion strategy when expected size is known."
-msgstr ""
+msgstr "Задать стратегию подстановки memset, когда ожидаемый размер известен."
 
 #: config/i386/i386.opt:464
-#, fuzzy
-#| msgid "Chose strategy to generate stringop using"
 msgid "Chose strategy to generate stringop using."
-msgstr "Выбрать стратегию генерации строковых операций"
+msgstr "Выбрать стратегию генерации строковых операций."
 
 #: config/i386/i386.opt:468
 msgid "Valid arguments to -mstringop-strategy=:"
@@ -11180,10 +9429,8 @@
 msgstr "Допустимые аргументы ключа -mstringop-strategy=:"
 
 #: config/i386/i386.opt:496
-#, fuzzy
-#| msgid "Use given thread-local storage dialect"
 msgid "Use given thread-local storage dialect."
-msgstr "Использовать указанный диалект локально-поточной памяти"
+msgstr "Использовать указанный диалект локально-поточной памяти."
 
 #: config/i386/i386.opt:500
 msgid "Known TLS dialects (for use with the -mtls-dialect= option):"
@@ -11190,30 +9437,25 @@
 msgstr "Диалекты TLS (возможные аргументы ключа -mtls-dialect=):"
 
 #: config/i386/i386.opt:510
-#, fuzzy, c-format
-#| msgid "Use direct references against %gs when accessing tls data"
+#, c-format
 msgid "Use direct references against %gs when accessing tls data."
-msgstr "Использовать непосредственные ссылки относительно %gs при доступе к TLS-данным"
+msgstr "Использовать непосредственные ссылки относительно %gs при доступе к TLS-данным."
 
 #: config/i386/i386.opt:518
 msgid "Fine grain control of tune features."
-msgstr ""
+msgstr "Задать настройки генерации кода для x86."
 
 #: config/i386/i386.opt:522
 msgid "Clear all tune features."
-msgstr ""
+msgstr "Отключить все настройки генерации кода для x86."
 
 #: config/i386/i386.opt:529
-#, fuzzy
-#| msgid "Generate code that conforms to the given ABI"
 msgid "Generate code that conforms to Intel MCU psABI."
-msgstr "Генерировать код в соответствии с заданным ABI"
+msgstr "Генерировать код в соответствии с Intel MCU psABI."
 
 #: config/i386/i386.opt:533
-#, fuzzy
-#| msgid "Generate code that conforms to the given ABI"
 msgid "Generate code that conforms to the given ABI."
-msgstr "Генерировать код в соответствии с заданным ABI"
+msgstr "Генерировать код в соответствии с заданным ABI."
 
 #: config/i386/i386.opt:537 config/nds32/nds32.opt:44
 msgid "Known ABIs (for use with the -mabi= option):"
@@ -11225,10 +9467,8 @@
 
 #: config/i386/i386.opt:551 config/powerpcspe/powerpcspe.opt:189
 #: config/rs6000/rs6000.opt:208
-#, fuzzy
-#| msgid "Vector library ABI to use"
 msgid "Vector library ABI to use."
-msgstr "ABI для библиотеки векторных операций"
+msgstr "ABI для библиотеки векторных операций."
 
 #: config/i386/i386.opt:555
 msgid "Known vectorization library ABIs (for use with the -mveclibabi= option):"
@@ -11235,10 +9475,8 @@
 msgstr "Допустимые ABI библиотеки векторных операций (возможные аргументы ключа -mveclibabi=):"
 
 #: config/i386/i386.opt:565
-#, fuzzy
-#| msgid "Return 8-byte vectors in memory"
 msgid "Return 8-byte vectors in memory."
-msgstr "Возвращать 8-байтные векторы в памяти"
+msgstr "Возвращать 8-байтные векторы в памяти."
 
 #: config/i386/i386.opt:569
 msgid "Generate reciprocals instead of divss and sqrtss."
@@ -11253,20 +9491,16 @@
 msgstr "Генерировать команду cld в прологе функции."
 
 #: config/i386/i386.opt:581
-#, fuzzy
-#| msgid "Generate vzeroupper instruction before a transfer of control flow out of"
 msgid "Generate vzeroupper instruction before a transfer of control flow out of the function."
-msgstr "Генерировать команду vzeroupper перед выходом из функции"
+msgstr "Генерировать команду vzeroupper перед выходом из функции."
 
 #: config/i386/i386.opt:586
 msgid "Disable Scalar to Vector optimization pass transforming 64-bit integer computations into a vector ones."
-msgstr ""
+msgstr "Отменить проход трансформации скалярных 64-разрядных целочисленных вычислений в векторные вычисления."
 
 #: config/i386/i386.opt:591
-#, fuzzy
-#| msgid "Do dispatch scheduling if processor is bdver1 or bdver2 and Haifa scheduling is selected."
 msgid "Do dispatch scheduling if processor is bdver1, bdver2, bdver3, bdver4 or znver1 and Haifa scheduling is selected."
-msgstr "Выполнять быстрое планирование, если процессор bdver1 или bdver2 и выбран планировщик Haifa"
+msgstr "Выполнять быстрое планирование для процессоров bdver1, bdver2, bdver3, bdver4 или znver1 и выбран планировщик Haifa."
 
 #: config/i386/i386.opt:596
 msgid "Use 128-bit AVX instructions instead of 256-bit AVX instructions in the auto-vectorizer."
@@ -11273,100 +9507,68 @@
 msgstr "Использовать 128-битные инструкций AVX вместо 256-битных при автовекторизации кода."
 
 #: config/i386/i386.opt:600
-#, fuzzy
-#| msgid "Use 128-bit AVX instructions instead of 256-bit AVX instructions in the auto-vectorizer."
 msgid "Use given register vector width instructions instead of maximum register width in the auto-vectorizer."
-msgstr "Использовать 128-битные инструкций AVX вместо 256-битных при автовекторизации кода."
+msgstr ""
 
 #: config/i386/i386.opt:604
-#, fuzzy
-#| msgid "Known ARM architectures (for use with the -march= option):"
 msgid "Known preferred register vector length (to use with the -mprefer-vector-width= option)"
-msgstr "Известные ARM архитектуры (для использования с -march= опцией):"
+msgstr ""
 
 #: config/i386/i386.opt:622
-#, fuzzy
-#| msgid "Generate 32bit i386 code"
 msgid "Generate 32bit i386 code."
-msgstr "Генерировать 32-битный код i386"
+msgstr "Генерировать 32-битный код i386."
 
 #: config/i386/i386.opt:626
-#, fuzzy
-#| msgid "Generate 64bit x86-64 code"
 msgid "Generate 64bit x86-64 code."
-msgstr "Генерировать 64-битный код x86-64"
+msgstr "Генерировать 64-битный код x86-64."
 
 #: config/i386/i386.opt:630
-#, fuzzy
-#| msgid "Generate 32bit x86-64 code"
 msgid "Generate 32bit x86-64 code."
-msgstr "Генерировать 32-битный код x86-64"
+msgstr "Генерировать 32-битный код x86-64."
 
 #: config/i386/i386.opt:634
-#, fuzzy
-#| msgid "Generate 32bit i386 code"
 msgid "Generate 16bit i386 code."
-msgstr "Генерировать 32-битный код i386"
+msgstr "Генерировать 32-битный код i386."
 
 #: config/i386/i386.opt:638
-#, fuzzy
-#| msgid "Support MMX built-in functions"
 msgid "Support MMX built-in functions."
-msgstr "Включить поддержку внутренних функций MMX"
+msgstr "Включить поддержку внутренних функций MMX."
 
 #: config/i386/i386.opt:642
-#, fuzzy
-#| msgid "Support 3DNow! built-in functions"
 msgid "Support 3DNow! built-in functions."
-msgstr "Включить поддержку внутренних функций 3DNow!"
+msgstr "Включить поддержку 3DNow! встроенных функций."
 
 #: config/i386/i386.opt:646
-#, fuzzy
-#| msgid "Support Athlon 3Dnow! built-in functions"
 msgid "Support Athlon 3Dnow! built-in functions."
-msgstr "Включить поддержку внутренних функций Athlon 3Dnow!"
+msgstr "Включить поддержку Athlon 3Dnow! встроенных функций."
 
 #: config/i386/i386.opt:650
-#, fuzzy
-#| msgid "Support MMX and SSE built-in functions and code generation"
 msgid "Support MMX and SSE built-in functions and code generation."
-msgstr "Включить поддержку внутренних функций и генерацию команд MMX и SSE"
+msgstr "Включить поддержку внутренних функций и генерацию команд MMX, SSE."
 
 #: config/i386/i386.opt:654
-#, fuzzy
-#| msgid "Support MMX, SSE and SSE2 built-in functions and code generation"
 msgid "Support MMX, SSE and SSE2 built-in functions and code generation."
-msgstr "Включить поддержку внутренних функций и генерацию команд MMX, SSE и SSE2"
+msgstr "Включить поддержку внутренних функций и генерацию команд MMX, SSE и SSE2."
 
 #: config/i386/i386.opt:658
-#, fuzzy
-#| msgid "Support MMX, SSE, SSE2 and SSE3 built-in functions and code generation"
 msgid "Support MMX, SSE, SSE2 and SSE3 built-in functions and code generation."
-msgstr "Включить поддержку встроенных функций и генерацию команд MMX, SSE, SSE2, SSE3"
+msgstr "Включить поддержку встроенных функций и генерацию команд MMX, SSE, SSE2, SSE3."
 
 #: config/i386/i386.opt:662
-#, fuzzy
-#| msgid "Support MMX, SSE, SSE2, SSE3 and SSSE3 built-in functions and code generation"
 msgid "Support MMX, SSE, SSE2, SSE3 and SSSE3 built-in functions and code generation."
-msgstr "Включить поддержку встроенных функций и генерацию команд MMX, SSE, SSE2, SSE3 и SSSE3"
+msgstr "Включить поддержку встроенных функций и генерацию команд MMX, SSE, SSE2, SSE3 и SSSE3."
 
 #: config/i386/i386.opt:666
-#, fuzzy
-#| msgid "Support MMX, SSE, SSE2, SSE3, SSSE3 and SSE4.1 built-in functions and code generation"
 msgid "Support MMX, SSE, SSE2, SSE3, SSSE3 and SSE4.1 built-in functions and code generation."
-msgstr "Включить поддержку встроенных функций и генерацию команд MMX, SSE, SSE2, SSE3, SSSE3 и SSE4.1"
+msgstr "Включить поддержку встроенных функций и генерацию команд MMX, SSE, SSE2, SSE3, SSSE3 и SSE4.1."
 
 #: config/i386/i386.opt:670 config/i386/i386.opt:674
-#, fuzzy
-#| msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1 and SSE4.2 built-in functions and code generation"
 msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1 and SSE4.2 built-in functions and code generation."
-msgstr "Включить поддержку встроенных функций и генерацию команд MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1 и SSE4.2"
+msgstr "Включить поддержку встроенных функций и генерацию команд MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1 и SSE4.2."
 
 #: config/i386/i386.opt:678
-#, fuzzy
-#| msgid "Do not support SSE4.1 and SSE4.2 built-in functions and code generation"
 msgid "Do not support SSE4.1 and SSE4.2 built-in functions and code generation."
-msgstr "Не поддерживать внутренние функции и команды SSE4.1 и SSE4.2"
+msgstr "Не поддерживать внутренние функции и команды SSE4.1 и SSE4.2."
 
 #: config/i386/i386.opt:681
 msgid "%<-msse5%> was removed"
@@ -11373,136 +9575,92 @@
 msgstr "ключ %<-msse5%> был удален"
 
 #: config/i386/i386.opt:686
-#, fuzzy
-#| msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2 and AVX built-in functions and code generation"
 msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2 and AVX built-in functions and code generation."
-msgstr "Включить поддержку встроенных функций и генерацию команд MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2 и AVX"
+msgstr "Включить поддержку встроенных функций и генерацию команд MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2 и AVX."
 
 #: config/i386/i386.opt:690
-#, fuzzy
-#| msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX and AVX2 built-in functions and code generation"
 msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX and AVX2 built-in functions and code generation."
-msgstr "Включить поддержку встроенных функций и генерацию команд MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX и AVX2"
+msgstr "Включить поддержку встроенных функций и генерацию команд MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX и AVX2."
 
 #: config/i386/i386.opt:694
-#, fuzzy
-#| msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX and AVX2 built-in functions and code generation"
 msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 and AVX512F built-in functions and code generation."
-msgstr "Включить поддержку встроенных функций и генерацию команд MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX и AVX2"
+msgstr "Включить поддержку встроенных функций и генерацию команд MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 и AVX512F."
 
 #: config/i386/i386.opt:698
-#, fuzzy
-#| msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX and AVX2 built-in functions and code generation"
 msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 and AVX512F and AVX512PF built-in functions and code generation."
-msgstr "Включить поддержку встроенных функций и генерацию команд MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX и AVX2"
+msgstr "Включить поддержку встроенных функций и генерацию команд MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 and AVX512F и AVX512PF."
 
 #: config/i386/i386.opt:702
-#, fuzzy
-#| msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX and AVX2 built-in functions and code generation"
 msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 and AVX512F and AVX512ER built-in functions and code generation."
-msgstr "Включить поддержку встроенных функций и генерацию команд MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX и AVX2"
+msgstr "Включить поддержку встроенных функций и генерацию команд MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2, AVX512F и AVX512ER."
 
 #: config/i386/i386.opt:706
-#, fuzzy
-#| msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX and AVX2 built-in functions and code generation"
 msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 and AVX512F and AVX512CD built-in functions and code generation."
-msgstr "Включить поддержку встроенных функций и генерацию команд MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX и AVX2"
+msgstr "Включить поддержку встроенных функций и генерацию команд MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2, AVX512F и AVX512CD."
 
 #: config/i386/i386.opt:710
-#, fuzzy
-#| msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX and AVX2 built-in functions and code generation"
 msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 and AVX512F and AVX512DQ built-in functions and code generation."
-msgstr "Включить поддержку встроенных функций и генерацию команд MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX и AVX2"
+msgstr "Включить поддержку встроенных функций и генерацию команд MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2, AVX512F и AVX512DQ."
 
 #: config/i386/i386.opt:714
-#, fuzzy
-#| msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX and AVX2 built-in functions and code generation"
 msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 and AVX512F and AVX512BW built-in functions and code generation."
-msgstr "Включить поддержку встроенных функций и генерацию команд MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX и AVX2"
+msgstr "Включить поддержку встроенных функций и генерацию команд MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2, AVX512F и AVX512BW."
 
 #: config/i386/i386.opt:718
-#, fuzzy
-#| msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX and AVX2 built-in functions and code generation"
 msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 and AVX512F and AVX512VL built-in functions and code generation."
-msgstr "Включить поддержку встроенных функций и генерацию команд MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX и AVX2"
+msgstr "Включить поддержку встроенных функций и генерацию команд MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2, AVX512F и AVX512VL."
 
 #: config/i386/i386.opt:722
-#, fuzzy
-#| msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX and AVX2 built-in functions and code generation"
 msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 and AVX512F and AVX512IFMA built-in functions and code generation."
-msgstr "Включить поддержку встроенных функций и генерацию команд MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX и AVX2"
+msgstr "Включить поддержку встроенных функций и генерацию команд MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2, AVX512F и AVX512IFMA."
 
 #: config/i386/i386.opt:726
-#, fuzzy
-#| msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX and AVX2 built-in functions and code generation"
 msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2 and AVX512F and AVX512VBMI built-in functions and code generation."
-msgstr "Включить поддержку встроенных функций и генерацию команд MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX и AVX2"
+msgstr "Включить поддержку встроенных функций и генерацию команд MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2, AVX512F и AVX512VBMI."
 
 #: config/i386/i386.opt:730
-#, fuzzy
-#| msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX and AVX2 built-in functions and code generation"
 msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2, AVX512F and AVX5124FMAPS built-in functions and code generation."
-msgstr "Включить поддержку встроенных функций и генерацию команд MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX и AVX2"
+msgstr "Включить поддержку встроенных функций и генерацию команд MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2, AVX512F и AVX5124FMAPS."
 
 #: config/i386/i386.opt:734
-#, fuzzy
-#| msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX and AVX2 built-in functions and code generation"
 msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2, AVX512F and AVX5124VNNIW built-in functions and code generation."
-msgstr "Включить поддержку встроенных функций и генерацию команд MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX и AVX2"
+msgstr "Включить поддержку встроенных функций и генерацию команд MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2, AVX512F и AVX5124VNNIW."
 
 #: config/i386/i386.opt:738
-#, fuzzy
-#| msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX and AVX2 built-in functions and code generation"
 msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2, AVX512F and AVX512VPOPCNTDQ built-in functions and code generation."
-msgstr "Включить поддержку встроенных функций и генерацию команд MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX и AVX2"
+msgstr "Включить поддержку встроенных функций и генерацию команд MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2, AVX512F и AVX512VPOPCNTDQ."
 
 #: config/i386/i386.opt:742
-#, fuzzy
-#| msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX and AVX2 built-in functions and code generation"
 msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2, AVX512F and AVX512VBMI2 built-in functions and code generation."
-msgstr "Включить поддержку встроенных функций и генерацию команд MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX и AVX2"
+msgstr "Включить поддержку встроенных функций и генерацию команд MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2, AVX512F и AVX512VBMI2."
 
 #: config/i386/i386.opt:746
-#, fuzzy
-#| msgid "Support BMI built-in functions and code generation"
 msgid "Support AVX512VNNI built-in functions and code generation."
-msgstr "Включить поддержку внутренних функций MMX и SSE при генерации кода"
+msgstr "Включить поддержку внутренних функций и генерацию команд AVX512VNNI."
 
 #: config/i386/i386.opt:750
-#, fuzzy
-#| msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX and AVX2 built-in functions and code generation"
 msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2, AVX512F and AVX512BITALG built-in functions and code generation."
-msgstr "Включить поддержку встроенных функций и генерацию команд MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX и AVX2"
+msgstr "Включить поддержку встроенных функций и генерацию команд MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX, AVX2, AVX512F и AVX512BITALG."
 
 #: config/i386/i386.opt:754
-#, fuzzy
-#| msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX and FMA built-in functions and code generation"
 msgid "Support MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX and FMA built-in functions and code generation."
-msgstr "Включить поддержку встроенных функций и генерацию команд MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX и FMA"
+msgstr "Включить поддержку встроенных функций и генерацию команд MMX, SSE, SSE2, SSE3, SSSE3, SSE4.1, SSE4.2, AVX и FMA."
 
 #: config/i386/i386.opt:758
-#, fuzzy
-#| msgid "Support MMX, SSE, SSE2, SSE3 and SSE4A built-in functions and code generation"
 msgid "Support MMX, SSE, SSE2, SSE3 and SSE4A built-in functions and code generation."
-msgstr "Включить поддержку встроенных функций и генерацию команд MMX, SSE, SSE2, SSE3 и SSE4A"
+msgstr "Включить поддержку встроенных функций и генерацию команд MMX, SSE, SSE2, SSE3 и SSE4A."
 
 #: config/i386/i386.opt:762
-#, fuzzy
-#| msgid "Support FMA4 built-in functions and code generation "
 msgid "Support FMA4 built-in functions and code generation."
-msgstr "Включить поддержку внутренних функций и генерацию команд FMA4"
+msgstr "Включить поддержку внутренних функций и генерацию команд FMA4."
 
 #: config/i386/i386.opt:766
-#, fuzzy
-#| msgid "Support XOP built-in functions and code generation "
 msgid "Support XOP built-in functions and code generation."
-msgstr "Включить поддержку внутренних функций и генерацию команд XOP"
+msgstr "Включить поддержку внутренних функций и генерацию команд XOP."
 
 #: config/i386/i386.opt:770
-#, fuzzy
-#| msgid "Support LWP built-in functions and code generation "
 msgid "Support LWP built-in functions and code generation."
-msgstr "Включить поддержку внутренних функций и генерацию команд LWP"
+msgstr "Включить поддержку внутренних функций и генерацию команд LWP."
 
 #: config/i386/i386.opt:774
 msgid "Support code generation of Advanced Bit Manipulation (ABM) instructions."
@@ -11513,132 +9671,96 @@
 msgstr "Включить генерацию команды popcnt."
 
 #: config/i386/i386.opt:782
-#, fuzzy
-#| msgid "Support BMI built-in functions and code generation"
 msgid "Support PCONFIG built-in functions and code generation."
-msgstr "Включить поддержку внутренних функций MMX и SSE при генерации кода"
+msgstr "Включить поддержку внутренних функций и генерацию команд PCONFIG."
 
 #: config/i386/i386.opt:786
-#, fuzzy
-#| msgid "Support BMI built-in functions and code generation"
 msgid "Support WBNOINVD built-in functions and code generation."
-msgstr "Включить поддержку внутренних функций MMX и SSE при генерации кода"
+msgstr "Включить поддержку внутренних функций и генерацию команд WBNOINVD."
 
 #: config/i386/i386.opt:790
-#, fuzzy
-#| msgid "Support XOP built-in functions and code generation "
 msgid "Support SGX built-in functions and code generation."
-msgstr "Включить поддержку внутренних функций и генерацию команд XOP"
+msgstr "Включить поддержку внутренних функций и генерацию команд SGX."
 
 #: config/i386/i386.opt:794
-#, fuzzy
-#| msgid "Support RDRND built-in functions and code generation"
 msgid "Support RDPID built-in functions and code generation."
-msgstr "Включить поддержку внутренних функций и генерацию команд RDRND"
+msgstr "Включить поддержку внутренних функций и генерацию команд RDPID."
 
 #: config/i386/i386.opt:798
-#, fuzzy
-#| msgid "Support BMI built-in functions and code generation"
 msgid "Support GFNI built-in functions and code generation."
-msgstr "Включить поддержку внутренних функций MMX и SSE при генерации кода"
+msgstr "Включить поддержку внутренних функций и генерацию команд GFNI."
 
 #: config/i386/i386.opt:802
-#, fuzzy
-#| msgid "Support AES built-in functions and code generation"
 msgid "Support VAES built-in functions and code generation."
-msgstr "Включить поддержку внутренних функций и генерацию команд AES"
+msgstr "Включить поддержку внутренних функций и генерацию команд VAES."
 
 #: config/i386/i386.opt:806
-#, fuzzy
-#| msgid "Support PCLMUL built-in functions and code generation"
 msgid "Support VPCLMULQDQ built-in functions and code generation."
-msgstr "Включить поддержку внутренних функций и генерацию команд PCLMUL"
+msgstr "Включить поддержку внутренних функций и генерацию команд VPCLMULQDQ."
 
 #: config/i386/i386.opt:810
-#, fuzzy
-#| msgid "Support BMI built-in functions and code generation"
 msgid "Support BMI built-in functions and code generation."
-msgstr "Включить поддержку внутренних функций MMX и SSE при генерации кода"
+msgstr "Включить поддержку внутренних функций BMI при генерации кода."
 
 #: config/i386/i386.opt:814
-#, fuzzy
-#| msgid "Support BMI2 built-in functions and code generation"
 msgid "Support BMI2 built-in functions and code generation."
-msgstr "Включить поддержку внутренних функций и генерацию команд BMI2"
+msgstr "Включить поддержку внутренних функций и генерацию команд BMI2."
 
 #: config/i386/i386.opt:818
-#, fuzzy
-#| msgid "Support LZCNT built-in function and code generation"
 msgid "Support LZCNT built-in function and code generation."
-msgstr "Включить поддержку внутренних функций и генерацию команд LZCNT"
+msgstr "Включить поддержку внутренних функций и генерацию команд LZCNT."
 
 #: config/i386/i386.opt:822
 msgid "Support Hardware Lock Elision prefixes."
-msgstr ""
+msgstr "Включить поддержку элизии аппаратных блокировок (hle)."
 
 #: config/i386/i386.opt:826
-#, fuzzy
-#| msgid "Use SmartMIPS instructions"
 msgid "Support RDSEED instruction."
-msgstr "Использовать команды SmartMIPS"
+msgstr "Включить поддержку команды RDSEED."
 
 #: config/i386/i386.opt:830
 msgid "Support PREFETCHW instruction."
-msgstr ""
+msgstr "Включить поддержку команды PREFETCHW."
 
 #: config/i386/i386.opt:834
-#, fuzzy
-#| msgid "Support code generation of crc32 instruction."
 msgid "Support flag-preserving add-carry instructions."
-msgstr "Включить генерацию команды crc32."
+msgstr "Включить поддержку команд сложения с переносом, не изменяющих флаги."
 
 #: config/i386/i386.opt:838
 msgid "Support CLFLUSHOPT instructions."
-msgstr ""
+msgstr "Поддерживать инструкции CLFLUSHOPT."
 
 #: config/i386/i386.opt:842
-#, fuzzy
-#| msgid "Pack VLIW instructions"
 msgid "Support CLWB instruction."
-msgstr "Упаковывать команды во VLIW"
+msgstr "Включить поддержку команды CLWB."
 
 #: config/i386/i386.opt:845
-#, fuzzy
-#| msgid "protocol %qE is deprecated"
 msgid "%<-mpcommit%> was deprecated"
-msgstr "протокол %qE устарел"
+msgstr "ключ %<-mpcommit%> устарел"
 
 #: config/i386/i386.opt:850
 msgid "Support FXSAVE and FXRSTOR instructions."
-msgstr ""
+msgstr "Включить поддержку команд FXSAVE и FXRSTOR."
 
 #: config/i386/i386.opt:854
-#, fuzzy
-#| msgid "Support code generation of movbe instruction."
 msgid "Support XSAVE and XRSTOR instructions."
-msgstr "Включить генерацию команды movbe."
+msgstr "Включить поддержку команд XSAVE и XRSTOR."
 
 #: config/i386/i386.opt:858
-#, fuzzy
-#| msgid "Support MMX built-in functions"
 msgid "Support XSAVEOPT instruction."
-msgstr "Включить поддержку внутренних функций MMX"
+msgstr "Включить поддержку команды XSAVEOPT."
 
 #: config/i386/i386.opt:862
-#, fuzzy
-#| msgid "Support MMX built-in functions"
 msgid "Support XSAVEC instructions."
-msgstr "Включить поддержку внутренних функций MMX"
+msgstr "Включить поддержку команд XSAVEC."
 
 #: config/i386/i386.opt:866
 msgid "Support XSAVES and XRSTORS instructions."
-msgstr ""
+msgstr "Включить поддержку команд XSAVES и XRSTORS."
 
 #: config/i386/i386.opt:870
-#, fuzzy
-#| msgid "Support TBM built-in functions and code generation"
 msgid "Support TBM built-in functions and code generation."
-msgstr "Включить поддержку внутренних функций и генерацию команд TBM"
+msgstr "Включить поддержку внутренних функций и генерацию команд TBM."
 
 #: config/i386/i386.opt:874
 msgid "Support code generation of cmpxchg16b instruction."
@@ -11657,52 +9779,36 @@
 msgstr "Включить генерацию команды crc32."
 
 #: config/i386/i386.opt:890
-#, fuzzy
-#| msgid "Support AES built-in functions and code generation"
 msgid "Support AES built-in functions and code generation."
-msgstr "Включить поддержку внутренних функций и генерацию команд AES"
+msgstr "Включить поддержку внутренних функций и генерацию команд AES."
 
 #: config/i386/i386.opt:894
-#, fuzzy
-#| msgid "Support MMX and SSE built-in functions and code generation"
 msgid "Support SHA1 and SHA256 built-in functions and code generation."
-msgstr "Включить поддержку внутренних функций и генерацию команд MMX и SSE"
+msgstr "Включить поддержку внутренних функций и генерацию команд SHA1 и SHA256."
 
 #: config/i386/i386.opt:898
-#, fuzzy
-#| msgid "Support PCLMUL built-in functions and code generation"
 msgid "Support PCLMUL built-in functions and code generation."
-msgstr "Включить поддержку внутренних функций и генерацию команд PCLMUL"
+msgstr "Включить поддержку внутренних функций и генерацию команд PCLMUL."
 
 #: config/i386/i386.opt:902
-#, fuzzy
-#| msgid "Encode SSE instructions with VEX prefix"
 msgid "Encode SSE instructions with VEX prefix."
-msgstr "Кодировать команды SSE с префиксом VEX"
+msgstr "Кодировать команды SSE с префиксом VEX."
 
 #: config/i386/i386.opt:906
-#, fuzzy
-#| msgid "Support FSGSBASE built-in functions and code generation"
 msgid "Support FSGSBASE built-in functions and code generation."
-msgstr "Включить поддержку внутренних функций и генерацию команд FSGSBASE"
+msgstr "Включить поддержку внутренних функций и генерацию команд FSGSBASE."
 
 #: config/i386/i386.opt:910
-#, fuzzy
-#| msgid "Support RDRND built-in functions and code generation"
 msgid "Support RDRND built-in functions and code generation."
-msgstr "Включить поддержку внутренних функций и генерацию команд RDRND"
+msgstr "Включить поддержку внутренних функций и генерацию команд RDRND."
 
 #: config/i386/i386.opt:914
-#, fuzzy
-#| msgid "Support F16C built-in functions and code generation"
 msgid "Support F16C built-in functions and code generation."
-msgstr "Включить поддержку внутренних функций и генерацию команд F16C"
+msgstr "Включить поддержку внутренних функций и генерацию команд F16C."
 
 #: config/i386/i386.opt:918
-#, fuzzy
-#| msgid "Support F16C built-in functions and code generation"
 msgid "Support PREFETCHWT1 built-in functions and code generation."
-msgstr "Включить поддержку внутренних функций и генерацию команд F16C"
+msgstr "Включить поддержку внутренних функций и генерацию команд PREFETCHWT1."
 
 #: config/i386/i386.opt:922
 msgid "Emit profiling counter call at function entry before prologue."
@@ -11710,92 +9816,74 @@
 
 #: config/i386/i386.opt:926
 msgid "Generate __mcount_loc section with all mcount or __fentry__ calls."
-msgstr ""
+msgstr "Генерировать секцию __mcount_loc, включающую все вызовы mcount или __fentry__."
 
 #: config/i386/i386.opt:930
 msgid "Generate mcount/__fentry__ calls as nops. To activate they need to be patched in."
-msgstr ""
+msgstr "Генерировать вызовы mcount/__fentry__ как nop'ы. Для активации эти вызовы должны быть вставлены в код."
 
 #: config/i386/i386.opt:935
 msgid "Skip setting up RAX register when passing variable arguments."
-msgstr ""
+msgstr "Не устанавливать регистр RAX при передаче переменных аргументов."
 
 #: config/i386/i386.opt:939
-#, fuzzy
-#| msgid "Expand 32bit/64bit integer divide into 8bit unsigned integer divide with run-time check"
 msgid "Expand 32bit/64bit integer divide into 8bit unsigned integer divide with run-time check."
-msgstr "Расширять 32-битное/64-битное целочисленное деление в 8-битное беззнаковое целочисленное деление с проверкой времени выполнения"
+msgstr "Расширять 32-битное/64-битное целочисленное деление в 8-битное беззнаковое целочисленное деление с проверкой времени выполнения."
 
 #: config/i386/i386.opt:943
-#, fuzzy
-#| msgid "Split 32-byte AVX unaligned load"
 msgid "Split 32-byte AVX unaligned load."
-msgstr "Разбивать 32-битные команды невыровненной загрузки AVX"
+msgstr "Разбивать 32-битные команды невыровненной загрузки AVX."
 
 #: config/i386/i386.opt:947
-#, fuzzy
-#| msgid "Split 32-byte AVX unaligned store"
 msgid "Split 32-byte AVX unaligned store."
-msgstr "Разбивать 32-битные команды невыровненной записи AVX"
+msgstr "Разбивать 32-битные команды невыровненной записи AVX."
 
 #: config/i386/i386.opt:951
-#, fuzzy
-#| msgid "Support TBM built-in functions and code generation"
 msgid "Support RTM built-in functions and code generation."
-msgstr "Включить поддержку внутренних функций и генерацию команд TBM"
+msgstr "Поддерживать RTM внутренние функции и генерацию кода."
 
 #: config/i386/i386.opt:955
-#, fuzzy
-#| msgid "Support code generation of movbe instruction."
 msgid "Support MPX code generation."
-msgstr "Включить генерацию команды movbe."
+msgstr "Поддерживать MPX генерацию кода."
 
 #: config/i386/i386.opt:959
-#, fuzzy
-#| msgid "Support MMX and SSE built-in functions and code generation"
 msgid "Support MWAITX and MONITORX built-in functions and code generation."
-msgstr "Включить поддержку внутренних функций и генерацию команд MMX и SSE"
+msgstr "Поддерживать MWAITX и MONITORX внутренние функций и генерацию кода."
 
 #: config/i386/i386.opt:963
-#, fuzzy
-#| msgid "Support AES built-in functions and code generation"
 msgid "Support CLZERO built-in functions and code generation."
-msgstr "Включить поддержку внутренних функций и генерацию команд AES"
+msgstr "Поддерживать CLZERO внутренние функций и генерацию кода."
 
 #: config/i386/i386.opt:967
-#, fuzzy
-#| msgid "Support PCLMUL built-in functions and code generation"
 msgid "Support PKU built-in functions and code generation."
-msgstr "Включить поддержку внутренних функций и генерацию команд PCLMUL"
+msgstr "Поддерживать PKU внутренние функций и генерацию кода."
 
 #: config/i386/i386.opt:971 config/powerpcspe/powerpcspe.opt:678
 #: config/rs6000/rs6000.opt:597
 msgid "Use given stack-protector guard."
-msgstr ""
+msgstr "Использовать заданную защиту стека"
 
 #: config/i386/i386.opt:975
-#, fuzzy
-#| msgid "Known ARM architectures (for use with the -march= option):"
 msgid "Known stack protector guard (for use with the -mstack-protector-guard= option):"
-msgstr "Известные ARM архитектуры (для использования с -march= опцией):"
+msgstr "Известные защиты стека (для использования с -mstack-protector-guard= опцией):"
 
 #: config/i386/i386.opt:985 config/powerpcspe/powerpcspe.opt:692
 #: config/rs6000/rs6000.opt:611
 msgid "Use the given base register for addressing the stack-protector guard."
-msgstr ""
+msgstr "Использовать заданный базовый регистр для адресации защиты стека."
 
 #: config/i386/i386.opt:992 config/powerpcspe/powerpcspe.opt:699
 #: config/rs6000/rs6000.opt:618
 msgid "Use the given offset for addressing the stack-protector guard."
-msgstr ""
+msgstr "Использовать заданное смещение для адресации защиты стека."
 
 #: config/i386/i386.opt:999
 msgid "Use the given symbol for addressing the stack-protector guard."
-msgstr ""
+msgstr "Использовать заданный символ для адресации защиты стека."
 
 #: config/i386/i386.opt:1003
 msgid "Attempt to avoid generating instruction sequences containing ret bytes."
-msgstr ""
+msgstr "Пытаться избегать генерации последовательностей инструкций, содержащих байты возврата."
 
 #: config/i386/i386.opt:1011
 msgid "Enable shadow stack built-in functions from Control-flow Enforcement Technology (CET)."
@@ -11806,10 +9894,8 @@
 msgstr ""
 
 #: config/i386/i386.opt:1021
-#, fuzzy
-#| msgid "Use call and rtc for function calls and returns"
 msgid "Make all function calls indirect."
-msgstr "Использовать call и rtc для вызовов функций и возвратов"
+msgstr ""
 
 #: config/i386/i386.opt:1025
 msgid "Convert indirect call and jump to call and return thunks."
@@ -11816,16 +9902,12 @@
 msgstr ""
 
 #: config/i386/i386.opt:1029
-#, fuzzy
-#| msgid "function return type cannot be function"
 msgid "Convert function return to call and return thunk."
-msgstr "результат функции не может иметь тип функции"
+msgstr ""
 
 #: config/i386/i386.opt:1033 config/s390/s390.opt:274
-#, fuzzy
-#| msgid "Known TLS dialects (for use with the -mtls-dialect= option):"
 msgid "Known indirect branch choices (for use with the -mindirect-branch=/-mfunction-return= options):"
-msgstr "Диалекты TLS (возможные аргументы ключа -mtls-dialect=):"
+msgstr ""
 
 #: config/i386/i386.opt:1049
 msgid "Force indirect call and jump via register."
@@ -11832,501 +9914,341 @@
 msgstr ""
 
 #: config/i386/i386.opt:1053
-#, fuzzy
-#| msgid "Support BMI built-in functions and code generation"
 msgid "Support MOVDIRI built-in functions and code generation."
-msgstr "Включить поддержку внутренних функций MMX и SSE при генерации кода"
+msgstr ""
 
 #: config/i386/i386.opt:1057
-#, fuzzy
-#| msgid "Support BMI built-in functions and code generation"
 msgid "Support MOVDIR64B built-in functions and code generation."
-msgstr "Включить поддержку внутренних функций MMX и SSE при генерации кода"
+msgstr ""
 
 #: config/pa/pa64-hpux.opt:23
-#, fuzzy
-#| msgid "Assume code will be linked by GNU ld"
 msgid "Assume code will be linked by GNU ld."
-msgstr "Предполагать что для компоновки будет применяться GAS ld"
+msgstr "Предполагать, что для компоновки будет применяться GAS ld."
 
 #: config/pa/pa64-hpux.opt:27
-#, fuzzy
-#| msgid "Assume code will be linked by HP ld"
 msgid "Assume code will be linked by HP ld."
-msgstr "Предполагать что для компоновки будет применяться HP ld"
+msgstr "Предполагать, что для компоновки будет применяться HP ld."
 
 #: config/pa/pa-hpux1010.opt:23 config/pa/pa-hpux.opt:31
 #: config/pa/pa-hpux1131.opt:23 config/pa/pa-hpux1111.opt:23
-#, fuzzy
-#| msgid "Specify UNIX standard for predefines and linking"
 msgid "Specify UNIX standard for predefines and linking."
-msgstr "Задать стандарт UNIX для определённых переменных и компоновки"
+msgstr "Задать стандарт UNIX для определённых переменных и компоновки."
 
 #: config/pa/pa-hpux.opt:27
-#, fuzzy
-#| msgid "Generate cpp defines for server IO"
 msgid "Generate cpp defines for server IO."
-msgstr "Генерировать определения препроцессора для серверного ввода-вывода"
+msgstr "Генерировать определения препроцессора для серверного ввода-вывода."
 
 #: config/pa/pa-hpux.opt:35
-#, fuzzy
-#| msgid "Generate cpp defines for workstation IO"
 msgid "Generate cpp defines for workstation IO."
-msgstr "Генерировать определения препроцессора для ввода-вывода рабочей станции"
+msgstr "Генерировать определения препроцессора для ввода-вывода рабочей станции."
 
 #: config/pa/pa.opt:30 config/pa/pa.opt:87 config/pa/pa.opt:95
-#, fuzzy
-#| msgid "Generate PA1.0 code"
 msgid "Generate PA1.0 code."
-msgstr "Генерировать код PA1.0"
+msgstr "Генерировать код PA1.0."
 
 #: config/pa/pa.opt:34 config/pa/pa.opt:99 config/pa/pa.opt:140
-#, fuzzy
-#| msgid "Generate PA1.1 code"
 msgid "Generate PA1.1 code."
-msgstr "Генерировать код PA1.1"
+msgstr "Генерировать код PA1.1."
 
 #: config/pa/pa.opt:38 config/pa/pa.opt:103
-#, fuzzy
-#| msgid "Generate PA2.0 code (requires binutils 2.10 or later)"
 msgid "Generate PA2.0 code (requires binutils 2.10 or later)."
-msgstr "Генерировать код PA2.0 (требуются бин. утилиты 2.10 или старше)"
+msgstr "Генерировать код PA2.0 (требуются бин. утилиты 2.10 или старше)."
 
 #: config/pa/pa.opt:46
 msgid "Caller copies function arguments passed by hidden reference."
-msgstr ""
+msgstr "Вызывающая сторона копирует аргументы функций, переданные скрытыми ссылками."
 
 #: config/pa/pa.opt:50
-#, fuzzy
-#| msgid "Disable FP regs"
 msgid "Disable FP regs."
-msgstr "Исключить использование плавающих регистров"
+msgstr "Исключить использование плавающих регистров."
 
 #: config/pa/pa.opt:54
-#, fuzzy
-#| msgid "Disable indexed addressing"
 msgid "Disable indexed addressing."
-msgstr "Не использовать индексную адресацию"
+msgstr "Не использовать индексную адресацию."
 
 #: config/pa/pa.opt:58
-#, fuzzy
-#| msgid "Generate fast indirect calls"
 msgid "Generate fast indirect calls."
-msgstr "Генерировать быстрые косвенные вызовы"
+msgstr "Генерировать быстрые косвенные вызовы."
 
 #: config/pa/pa.opt:66
-#, fuzzy
-#| msgid "Assume code will be assembled by GAS"
 msgid "Assume code will be assembled by GAS."
-msgstr "Предполагать, что код будет ассемблироваться при помощи GAS"
+msgstr "Предполагать, что код будет ассемблироваться при помощи GAS."
 
 #: config/pa/pa.opt:75
-#, fuzzy
-#| msgid "Enable linker optimizations"
 msgid "Enable linker optimizations."
-msgstr "Включить оптимизации компоновки"
+msgstr "Включить оптимизации компоновки."
 
 #: config/pa/pa.opt:79
-#, fuzzy
-#| msgid "Always generate long calls"
 msgid "Always generate long calls."
-msgstr "Всегда генерировать дальние вызовы"
+msgstr "Всегда генерировать дальние вызовы."
 
 #: config/pa/pa.opt:83
-#, fuzzy
-#| msgid "Emit long load/store sequences"
 msgid "Emit long load/store sequences."
-msgstr "Генерировать длинные последовательности чтения/записи"
+msgstr "Генерировать длинные последовательности чтения/записи."
 
 #: config/pa/pa.opt:91
-#, fuzzy
-#| msgid "Disable space regs"
 msgid "Disable space regs."
-msgstr "Исключить использование space-регистров"
+msgstr "Исключить использование space-регистров."
 
 #: config/pa/pa.opt:107
-#, fuzzy
-#| msgid "Use portable calling conventions"
 msgid "Use portable calling conventions."
-msgstr "Использовать портируемые соглашения о вызовах"
+msgstr "Использовать портируемые соглашения о вызовах."
 
 #: config/pa/pa.opt:111
-#, fuzzy
-#| msgid "Specify CPU for scheduling purposes.  Valid arguments are 700, 7100, 7100LC, 7200, 7300, and 8000"
 msgid "Specify CPU for scheduling purposes.  Valid arguments are 700, 7100, 7100LC, 7200, 7300, and 8000."
-msgstr "Задать тип ЦП для оптимизации планирования. Допустимые значения 700, 7100, 7100LC, 7200, 7300, 8000"
+msgstr "Процессор, для которого осуществляется планирование команд.  Valid arguments are 700, 7100, 7100LC, 7200, 7300, and 8000."
 
 #: config/pa/pa.opt:136 config/frv/frv.opt:215
-#, fuzzy
-#| msgid "Use software floating point"
 msgid "Use software floating point."
-msgstr "Использовать программную реализацию плавающей арифметики"
+msgstr "Использовать программную реализацию плавающей арифметики."
 
 #: config/pa/pa.opt:144
-#, fuzzy
-#| msgid "Do not disable space regs"
 msgid "Do not disable space regs."
-msgstr "Не исключать использование space-регистров"
+msgstr "Не исключать использование space-регистров."
 
 #: config/v850/v850.opt:29
-#, fuzzy
-#| msgid "Use registers r2 and r5"
 msgid "Use registers r2 and r5."
-msgstr "Использовать регистры r2 и r5"
+msgstr "Использовать регистры r2 и r5."
 
 #: config/v850/v850.opt:33
-#, fuzzy
-#| msgid "Use 4 byte entries in switch tables"
 msgid "Use 4 byte entries in switch tables."
-msgstr "Генерировать 4-байтные элементы в таблицах переключателей"
+msgstr "Генерировать 4-байтные элементы в таблицах переключателей."
 
 #: config/v850/v850.opt:37
-#, fuzzy
-#| msgid "Enable backend debugging"
 msgid "Enable backend debugging."
-msgstr "Включить отладочную печать"
+msgstr "Включить backend отладку."
 
 #: config/v850/v850.opt:41
-#, fuzzy
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the callt instruction (default)."
-msgstr "Не использовать команды callt"
+msgstr "Не использовать команды callt (по умолчанию)."
 
 #: config/v850/v850.opt:45
-#, fuzzy
-#| msgid "Reuse r30 on a per function basis"
 msgid "Reuse r30 on a per function basis."
-msgstr "Включить использование r30"
+msgstr "Переиспользовать r30 на пофункциональной основе."
 
 #: config/v850/v850.opt:52
-#, fuzzy
-#| msgid "Prohibit PC relative function calls"
 msgid "Prohibit PC relative function calls."
-msgstr "Запретить вызовы функций относительно PC"
+msgstr "Запретить вызовы функций относительно PC."
 
 #: config/v850/v850.opt:56
-#, fuzzy
-#| msgid "Use stubs for function prologues"
 msgid "Use stubs for function prologues."
-msgstr "Использовать заготовки прологов функций"
+msgstr "Использовать заготовки прологов функций."
 
 #: config/v850/v850.opt:60
-#, fuzzy
-#| msgid "Set the max size of data eligible for the SDA area"
 msgid "Set the max size of data eligible for the SDA area."
-msgstr "Максимальный размер данных для размещения в области SDA"
+msgstr "Максимальный размер данных для размещения в области SDA."
 
 #: config/v850/v850.opt:67
-#, fuzzy
-#| msgid "Enable the use of the short load instructions"
 msgid "Enable the use of the short load instructions."
-msgstr "Включить использование коротких команд загрузки"
+msgstr "Включить использование коротких команд загрузки."
 
 #: config/v850/v850.opt:71
-#, fuzzy
-#| msgid "Same as: -mep -mprolog-function"
 msgid "Same as: -mep -mprolog-function."
-msgstr "То же, что -mep -mprolog-function"
+msgstr "То же, что: -mep -mprolog-function."
 
 #: config/v850/v850.opt:75
-#, fuzzy
-#| msgid "Set the max size of data eligible for the TDA area"
 msgid "Set the max size of data eligible for the TDA area."
-msgstr "Максимальный размер данных для размещения в области TDA"
+msgstr "Максимальный размер данных для размещения в области TDA."
 
 #: config/v850/v850.opt:82
-#, fuzzy
-#| msgid "Do not enforce strict alignment"
 msgid "Do not enforce strict alignment."
-msgstr "Не требовать строгое выравнивание"
+msgstr "Не требовать строгое выравнивание."
 
 #: config/v850/v850.opt:86
-#, fuzzy
-#| msgid "Put jump tables for switch statements into the .data section rather than the .code section"
 msgid "Put jump tables for switch statements into the .data section rather than the .code section."
-msgstr "Помещать таблицу переходов для switch операторов в .data секцию а не в .code секцию"
+msgstr "Помещать таблицу переходов для switch операторов в .data секцию а не в .code секцию."
 
 #: config/v850/v850.opt:93
-#, fuzzy
-#| msgid "Compile for the v850 processor"
 msgid "Compile for the v850 processor."
-msgstr "Компилировать для процессора v850"
+msgstr "Компилировать для процессора v850."
 
 #: config/v850/v850.opt:97
-#, fuzzy
-#| msgid "Compile for the v850e processor"
 msgid "Compile for the v850e processor."
-msgstr "Компилировать для процессора v850e"
+msgstr "Компилировать для процессора v850e."
 
 #: config/v850/v850.opt:101
-#, fuzzy
-#| msgid "Compile for the v850e1 processor"
 msgid "Compile for the v850e1 processor."
-msgstr "Компилировать для процессора v850e1"
+msgstr "Компилировать для процессора v850e1."
 
 #: config/v850/v850.opt:105
-#, fuzzy
-#| msgid "Compile for the v850es variant of the v850e1"
 msgid "Compile for the v850es variant of the v850e1."
-msgstr "Компилировать для v850es варианта v850e1"
+msgstr "Компилировать для v850es варианта v850e1."
 
 #: config/v850/v850.opt:109
-#, fuzzy
-#| msgid "Compile for the v850e2 processor"
 msgid "Compile for the v850e2 processor."
-msgstr "Компилировать для процессора v850e2"
+msgstr "Компилировать для процессора v850e2."
 
 #: config/v850/v850.opt:113
-#, fuzzy
-#| msgid "Compile for the v850e2v3 processor"
 msgid "Compile for the v850e2v3 processor."
-msgstr "Компилировать для процессора v850e2v3"
+msgstr "Компилировать для процессора v850e2v3."
 
 #: config/v850/v850.opt:117
-#, fuzzy
-#| msgid "Compile for the v850e processor"
 msgid "Compile for the v850e3v5 processor."
-msgstr "Компилировать для процессора v850e"
+msgstr "Компилировать для процессора v850e3v5."
 
 #: config/v850/v850.opt:124
-#, fuzzy
-#| msgid "Enable clip instructions"
 msgid "Enable v850e3v5 loop instructions."
-msgstr "Включить clip инструкции"
+msgstr "Включить v850e3v5 инструкции цикла."
 
 #: config/v850/v850.opt:128
-#, fuzzy
-#| msgid "Set the max size of data eligible for the ZDA area"
 msgid "Set the max size of data eligible for the ZDA area."
-msgstr "Максимальный размер данных для размещения в области ZDA"
+msgstr "Максимальный размер данных для размещения в области ZDA."
 
 #: config/v850/v850.opt:135
-#, fuzzy
-#| msgid "Enable the rank heuristic in the scheduler"
 msgid "Enable relaxing in the assembler."
-msgstr "Установить эвристику ранжирования для планировщика"
+msgstr "Включить ослабление в ассемблере."
 
 #: config/v850/v850.opt:139
-#, fuzzy
-#| msgid "Prohibit PC relative function calls"
 msgid "Prohibit PC relative jumps."
-msgstr "Запретить вызовы функций относительно PC"
+msgstr "Запретить переходы относительно PC."
 
 #: config/v850/v850.opt:143
-#, fuzzy
-#| msgid "Prevent the use of all hardware floating-point instructions"
 msgid "Inhibit the use of hardware floating point instructions."
-msgstr "Не использовать аппаратную реализацию плавающих операций"
+msgstr "Не использовать аппаратную реализацию плавающих операций."
 
 #: config/v850/v850.opt:147
-#, fuzzy
-#| msgid "Allow the use of hardware floating-point ABI and instructions"
 msgid "Allow the use of hardware floating point instructions for V850E2V3 and up."
-msgstr "Разрешить использование аппаратных команд и ABI для операций с плавающей точкой"
+msgstr "Разрешить использование аппаратных команд с плавающей точкой для V850E2V3 и выше."
 
 #: config/v850/v850.opt:151
-#, fuzzy
-#| msgid "Enable the use of RX FPU instructions.  This is the default."
 msgid "Enable support for the RH850 ABI.  This is the default."
-msgstr "Включить использование RX FPU инструкций.  Это умолчание."
+msgstr "Включить поддержку для RH850 ABI.  Используется по умолчанию."
 
 #: config/v850/v850.opt:155
-#, fuzzy
-#| msgid "Enable support for huge objects"
 msgid "Enable support for the old GCC ABI."
-msgstr "Включить поддержку больших объектов"
+msgstr "Включить поддержку для старого GCC ABI."
 
 #: config/v850/v850.opt:159
 msgid "Support alignments of up to 64-bits."
-msgstr ""
+msgstr "Поддерживать выравнивания вплоть до 64 бит."
 
 #: config/powerpcspe/darwin.opt:38 config/powerpcspe/sysv4.opt:141
 #: config/rs6000/darwin.opt:38 config/rs6000/sysv4.opt:145
-#, fuzzy
-#| msgid "Generate 64-bit code"
 msgid "Generate 64-bit code."
-msgstr "Генерировать 64-битный код"
+msgstr "Генерировать 64-битный код."
 
 #: config/powerpcspe/darwin.opt:42 config/powerpcspe/sysv4.opt:145
 #: config/rs6000/darwin.opt:42 config/rs6000/sysv4.opt:149
-#, fuzzy
-#| msgid "Generate 32-bit code"
 msgid "Generate 32-bit code."
-msgstr "Генерировать 32-битный код"
+msgstr "Генерировать 32-битный код."
 
 #: config/powerpcspe/powerpcspe-tables.opt:23
 #: config/rs6000/rs6000-tables.opt:24
 msgid "Known CPUs (for use with the -mcpu= and -mtune= options):"
-msgstr "Известные CPUs (для использования с -mcpu= и -mtune= options):"
+msgstr "Известные CPUs (для использования с -mcpu= и -mtune= ключами):"
 
 #: config/powerpcspe/powerpcspe.opt:109 config/rs6000/rs6000.opt:121
-#, fuzzy
-#| msgid "Use PowerPC-64 instruction set"
 msgid "Use PowerPC-64 instruction set."
-msgstr "Использовать систему команд PowerPC-64"
+msgstr "Использовать систему команд PowerPC-64."
 
 #: config/powerpcspe/powerpcspe.opt:113 config/rs6000/rs6000.opt:125
-#, fuzzy
-#| msgid "Use PowerPC General Purpose group optional instructions"
 msgid "Use PowerPC General Purpose group optional instructions."
-msgstr "Использовать необязательные команды PowerPC группы General Purpose"
+msgstr "Использовать необязательные команды PowerPC группы General Purpose."
 
 #: config/powerpcspe/powerpcspe.opt:117 config/rs6000/rs6000.opt:129
-#, fuzzy
-#| msgid "Use PowerPC Graphics group optional instructions"
 msgid "Use PowerPC Graphics group optional instructions."
-msgstr "Использовать необязательные команды PowerPC группы Graphics"
+msgstr "Использовать необязательные команды PowerPC группы Graphics."
 
 #: config/powerpcspe/powerpcspe.opt:121 config/rs6000/rs6000.opt:133
-#, fuzzy
-#| msgid "Use PowerPC V2.01 single field mfcr instruction"
 msgid "Use PowerPC V2.01 single field mfcr instruction."
-msgstr "Использовать команду mfcr с одним полем из PowerPC V2.01"
+msgstr "Использовать команду mfcr с одним полем из PowerPC V2.01."
 
 #: config/powerpcspe/powerpcspe.opt:125 config/rs6000/rs6000.opt:137
-#, fuzzy
-#| msgid "Use PowerPC V2.02 popcntb instruction"
 msgid "Use PowerPC V2.02 popcntb instruction."
-msgstr "Использовать команду popcntb из PowerPC V2.02"
+msgstr "Использовать команду popcntb из PowerPC V2.02."
 
 #: config/powerpcspe/powerpcspe.opt:129 config/rs6000/rs6000.opt:141
-#, fuzzy
-#| msgid "Use PowerPC V2.02 floating point rounding instructions"
 msgid "Use PowerPC V2.02 floating point rounding instructions."
-msgstr "Использовать команды округления плавающих чисел из PowerPC V2.02"
+msgstr "Использовать команды округления плавающих чисел из PowerPC V2.02."
 
 #: config/powerpcspe/powerpcspe.opt:133 config/rs6000/rs6000.opt:145
-#, fuzzy
-#| msgid "Use PowerPC V2.05 compare bytes instruction"
 msgid "Use PowerPC V2.05 compare bytes instruction."
-msgstr "Использовать инструкцию сравнения байт PowerPC V2.05"
+msgstr "Использовать инструкцию сравнения байт PowerPC V2.05."
 
 #: config/powerpcspe/powerpcspe.opt:137 config/rs6000/rs6000.opt:149
-#, fuzzy
-#| msgid "Use extended PowerPC V2.05 move floating point to/from GPR instructions"
 msgid "Use extended PowerPC V2.05 move floating point to/from GPR instructions."
-msgstr "Использовать расширенные инструкции PowerPC V2.05 перемещения плавающих в/из GPR"
+msgstr "Использовать расширенные инструкции PowerPC V2.05 перемещения плавающих в/из GPR."
 
 #: config/powerpcspe/powerpcspe.opt:141 config/rs6000/rs6000.opt:153
-#, fuzzy
-#| msgid "Use AltiVec instructions"
 msgid "Use AltiVec instructions."
-msgstr "Использовать команды AltiVec"
+msgstr "Использовать команды AltiVec."
 
 #: config/powerpcspe/powerpcspe.opt:145 config/rs6000/rs6000.opt:157
-#, fuzzy
-#| msgid "Generate code in little endian mode"
 msgid "Generate AltiVec instructions using little-endian element order."
-msgstr "Генерировать код для обратного (little endian) порядка байт"
+msgstr "Генерировать AltiVec инструкции использующие обратный (little-endian) порядок элементов."
 
 #: config/powerpcspe/powerpcspe.opt:149 config/rs6000/rs6000.opt:161
-#, fuzzy
-#| msgid "Generate VRSAVE instructions when generating AltiVec code"
 msgid "Generate AltiVec instructions using big-endian element order."
-msgstr "Генерировать инструкции VRSAVE при генерации кода AltiVec"
+msgstr "Генерировать AltiVec инструкции использующие прямой (big-endian) порядок элементов."
 
 #: config/powerpcspe/powerpcspe.opt:153 config/rs6000/rs6000.opt:169
-#, fuzzy
-#| msgid "Use decimal floating point instructions"
 msgid "Use decimal floating point instructions."
-msgstr "Использовать инструкции десятичных плавающих"
+msgstr "Использовать инструкции десятичных плавающих."
 
 #: config/powerpcspe/powerpcspe.opt:157 config/rs6000/rs6000.opt:173
-#, fuzzy
-#| msgid "Use 4xx half-word multiply instructions"
 msgid "Use 4xx half-word multiply instructions."
-msgstr "Использовать 4xx инструкции полусловного умножения"
+msgstr "Использовать 4xx инструкции полусловного умножения."
 
 #: config/powerpcspe/powerpcspe.opt:161 config/rs6000/rs6000.opt:177
-#, fuzzy
-#| msgid "Use 4xx string-search dlmzb instruction"
 msgid "Use 4xx string-search dlmzb instruction."
-msgstr "Использовать 4xx dlmzb инструкцию поиска в строке"
+msgstr "Использовать 4xx dlmzb инструкцию поиска в строке."
 
 #: config/powerpcspe/powerpcspe.opt:165 config/rs6000/rs6000.opt:181
-#, fuzzy
-#| msgid "Generate load/store multiple instructions"
 msgid "Generate load/store multiple instructions."
-msgstr "Генерировать команды множественного чтения/записи"
+msgstr "Генерировать команды множественного чтения/записи."
 
 #: config/powerpcspe/powerpcspe.opt:169
-#, fuzzy
-#| msgid "Generate string instructions for block moves"
 msgid "Generate string instructions for block moves."
-msgstr "Генерировать строковые команды для блочных пересылок"
+msgstr "Генерировать строковые команды для блочных пересылок."
 
 #: config/powerpcspe/powerpcspe.opt:181 config/rs6000/rs6000.opt:200
-#, fuzzy
-#| msgid "Use PowerPC V2.06 popcntd instruction"
 msgid "Use PowerPC V2.06 popcntd instruction."
-msgstr "Использовать PowerPC V2.06 popcntd инструкцию"
+msgstr "Использовать PowerPC V2.06 popcntd инструкцию."
 
 #: config/powerpcspe/powerpcspe.opt:185 config/rs6000/rs6000.opt:204
-#, fuzzy
-#| msgid "Under -ffast-math, generate a FRIZ instruction for (double)(long long) conversions"
 msgid "Under -ffast-math, generate a FRIZ instruction for (double)(long long) conversions."
-msgstr "При -ffast-math, генерировать FRIZ инструкцию для (double)(long long) преобразований"
+msgstr "При -ffast-math, генерировать FRIZ инструкцию для (double)(long long) преобразований."
 
 #: config/powerpcspe/powerpcspe.opt:193 config/rs6000/rs6000.opt:212
-#, fuzzy
-#| msgid "Use vector/scalar (VSX) instructions"
 msgid "Use vector/scalar (VSX) instructions."
-msgstr "Использовать vector/scalar (VSX) инструкции"
+msgstr "Использовать vector/scalar (VSX) инструкции."
 
 #: config/powerpcspe/powerpcspe.opt:240 config/rs6000/rs6000.opt:240
-#, fuzzy
-#| msgid "Do not generate load/store with update instructions"
 msgid "Do not generate load/store with update instructions."
-msgstr "Не генерировать команды чтения/записи с изменением адресного регистра"
+msgstr "Не генерировать команды чтения/записи с изменением адресного регистра."
 
 #: config/powerpcspe/powerpcspe.opt:244 config/rs6000/rs6000.opt:244
-#, fuzzy
-#| msgid "Generate load/store with update instructions"
 msgid "Generate load/store with update instructions."
-msgstr "Генерировать команды чтения/записи с изменением адресного регистра"
+msgstr "Генерировать команды чтения/записи с изменением адресного регистра."
 
 #: config/powerpcspe/powerpcspe.opt:248 config/arm/arm.opt:188
 #: config/rs6000/rs6000.opt:248
-#, fuzzy
-#| msgid "Do not load the PIC register in function prologues"
 msgid "Do not load the PIC register in function prologues."
-msgstr "Не загружать PIC-регистр в прологах функций"
+msgstr "Не загружать PIC-регистр в прологах функций."
 
 #: config/powerpcspe/powerpcspe.opt:252 config/rs6000/rs6000.opt:252
-#, fuzzy
-#| msgid "Avoid generation of indexed load/store instructions when possible"
 msgid "Avoid generation of indexed load/store instructions when possible."
-msgstr "Избегать генерации индексированных инструкций загрузки/сохранения если возможно"
+msgstr "Избегать генерации индексированных инструкций загрузки/сохранения, если возможно."
 
 #: config/powerpcspe/powerpcspe.opt:256 config/rs6000/rs6000.opt:256
-#, fuzzy
-#| msgid "Mark __tls_get_addr calls with argument info"
 msgid "Mark __tls_get_addr calls with argument info."
-msgstr "Пометить __tls_get_addr вызовы информацией об аргументах"
+msgstr "Пометить __tls_get_addr вызовы информацией об аргументах."
 
 #: config/powerpcspe/powerpcspe.opt:263 config/rs6000/rs6000.opt:263
-#, fuzzy
-#| msgid "Schedule the start and end of the procedure"
 msgid "Schedule the start and end of the procedure."
-msgstr "Планировать начало и конец процедуры"
+msgstr "Планировать начало и конец процедуры."
 
 #: config/powerpcspe/powerpcspe.opt:267 config/rs6000/rs6000.opt:267
-#, fuzzy
-#| msgid "Return all structures in memory (AIX default)"
 msgid "Return all structures in memory (AIX default)."
-msgstr "Возвращать все структуры в памяти (умолчание для AIX)"
+msgstr "Возвращать все структуры в памяти (умолчание для AIX)."
 
 #: config/powerpcspe/powerpcspe.opt:271 config/rs6000/rs6000.opt:271
-#, fuzzy
-#| msgid "Return small structures in registers (SVR4 default)"
 msgid "Return small structures in registers (SVR4 default)."
-msgstr "Возвращать короткие структуры в регистрах (умолчание для SVR4)"
+msgstr "Возвращать короткие структуры в регистрах (умолчание для SVR4)."
 
 #: config/powerpcspe/powerpcspe.opt:275 config/rs6000/rs6000.opt:275
-#, fuzzy
-#| msgid "Conform more closely to IBM XLC semantics"
 msgid "Conform more closely to IBM XLC semantics."
-msgstr "Более подробно следовать семантике IBM XLC"
+msgstr "Более подробно следовать семантике IBM XLC."
 
 #: config/powerpcspe/powerpcspe.opt:279 config/powerpcspe/powerpcspe.opt:283
 #: config/rs6000/rs6000.opt:279 config/rs6000/rs6000.opt:283
@@ -12335,67 +10257,47 @@
 
 #: config/powerpcspe/powerpcspe.opt:287 config/rs6000/rs6000.opt:287
 msgid "Assume that the reciprocal estimate instructions provide more accuracy."
-msgstr "Предполагать что инструкции оценки обратного обеспечивают более высокую точность."
+msgstr "Предполагать, что инструкции оценки обратного обеспечивают более высокую точность."
 
 #: config/powerpcspe/powerpcspe.opt:291 config/rs6000/rs6000.opt:291
-#, fuzzy
-#| msgid "Do not place floating point constants in TOC"
 msgid "Do not place floating point constants in TOC."
-msgstr "Не помещать плавающие константы в TOC"
+msgstr "Не помещать плавающие константы в TOC."
 
 #: config/powerpcspe/powerpcspe.opt:295 config/rs6000/rs6000.opt:295
-#, fuzzy
-#| msgid "Place floating point constants in TOC"
 msgid "Place floating point constants in TOC."
-msgstr "Помещать плавающие константы в TOC"
+msgstr "Помещать плавающие константы в TOC."
 
 #: config/powerpcspe/powerpcspe.opt:299 config/rs6000/rs6000.opt:299
-#, fuzzy
-#| msgid "Do not place symbol+offset constants in TOC"
 msgid "Do not place symbol+offset constants in TOC."
-msgstr "Не помещать константы вида \"символ+смещение\" в TOC"
+msgstr "Не помещать константы вида \"символ+смещение\" в TOC."
 
 #: config/powerpcspe/powerpcspe.opt:303 config/rs6000/rs6000.opt:303
-#, fuzzy
-#| msgid "Place symbol+offset constants in TOC"
 msgid "Place symbol+offset constants in TOC."
-msgstr "Помещать константы вида \"символ+смещение\" в TOC"
+msgstr "Помещать константы вида \"символ+смещение\" в TOC."
 
 #: config/powerpcspe/powerpcspe.opt:314 config/rs6000/rs6000.opt:314
-#, fuzzy
-#| msgid "Use only one TOC entry per procedure"
 msgid "Use only one TOC entry per procedure."
-msgstr "Использовать только одно поле TOC на процедуру"
+msgstr "Использовать только одно поле TOC на процедуру."
 
 #: config/powerpcspe/powerpcspe.opt:318 config/rs6000/rs6000.opt:318
-#, fuzzy
-#| msgid "Put everything in the regular TOC"
 msgid "Put everything in the regular TOC."
-msgstr "Помещать все в обычный TOC"
+msgstr "Помещать все в обычный TOC."
 
 #: config/powerpcspe/powerpcspe.opt:322 config/rs6000/rs6000.opt:322
-#, fuzzy
-#| msgid "Generate VRSAVE instructions when generating AltiVec code"
 msgid "Generate VRSAVE instructions when generating AltiVec code."
-msgstr "Генерировать инструкции VRSAVE при генерации кода AltiVec"
+msgstr "Генерировать инструкции VRSAVE при генерации кода AltiVec."
 
 #: config/powerpcspe/powerpcspe.opt:326 config/rs6000/rs6000.opt:326
-#, fuzzy
-#| msgid "Deprecated option.  Use -mno-vrsave instead"
 msgid "Deprecated option.  Use -mno-vrsave instead."
-msgstr "Устаревший ключ.  Используйте -mno-vrsave взамен"
+msgstr "Устаревший ключ.  Используйте вместо него -mno-vrsave."
 
 #: config/powerpcspe/powerpcspe.opt:330 config/rs6000/rs6000.opt:330
-#, fuzzy
-#| msgid "Deprecated option.  Use -mvrsave instead"
 msgid "Deprecated option.  Use -mvrsave instead."
-msgstr "Устаревший ключ.  Используйте -mvrsave взамен"
+msgstr "Устаревший ключ.  Используйте вместо него -mvrsave."
 
 #: config/powerpcspe/powerpcspe.opt:334
-#, fuzzy
-#| msgid "Specify how many bytes should be moved inline before calling out to memcpy/memmove"
 msgid "Specify how many bytes should be moved inline before calling out to memcpy/memmove."
-msgstr "Задать сколько байт следует перемещать inline прежде чем вызывать memcpy/memmove"
+msgstr "Задать сколько байт следует перемещать inline прежде чем вызывать memcpy/memmove."
 
 #: config/powerpcspe/powerpcspe.opt:338
 msgid "Specify the maximum number pairs of load instructions that should be generated inline for the compare.  If the number needed exceeds the limit, a call to memcmp will be generated instead."
@@ -12406,89 +10308,61 @@
 msgstr ""
 
 #: config/powerpcspe/powerpcspe.opt:346 config/rs6000/rs6000.opt:350
-#, fuzzy
-#| msgid "Generate isel instructions"
 msgid "Generate isel instructions."
-msgstr "Генерировать команды isel"
+msgstr "Генерировать isel инструкции."
 
 #: config/powerpcspe/powerpcspe.opt:350 config/rs6000/rs6000.opt:354
-#, fuzzy
-#| msgid "Deprecated option.  Use -mno-isel instead"
 msgid "Deprecated option.  Use -mno-isel instead."
-msgstr "Устаревший ключ.  Используйте -mno-isel взамен"
+msgstr "Устаревший ключ.  Используйте вместо него -mno-isel."
 
 #: config/powerpcspe/powerpcspe.opt:354 config/rs6000/rs6000.opt:358
-#, fuzzy
-#| msgid "Deprecated option.  Use -misel instead"
 msgid "Deprecated option.  Use -misel instead."
-msgstr "Устаревший ключ.  Используйте -misel взамен"
+msgstr "Устаревший ключ.  Используйте вместо него -misel."
 
 #: config/powerpcspe/powerpcspe.opt:358
-#, fuzzy
-#| msgid "Generate SPE SIMD instructions on E500"
 msgid "Generate SPE SIMD instructions on E500."
-msgstr "Генерировать команды SPE SIMD на E500"
+msgstr "Генерировать команды SPE SIMD на E500."
 
 #
 #: config/powerpcspe/powerpcspe.opt:362 config/rs6000/rs6000.opt:362
-#, fuzzy
-#| msgid "Generate PPC750CL paired-single instructions"
 msgid "Generate PPC750CL paired-single instructions."
-msgstr "Генерировать PPC750CL paired-single инструкции"
+msgstr "Генерировать PPC750CL paired-single инструкции."
 
 #: config/powerpcspe/powerpcspe.opt:366
-#, fuzzy
-#| msgid "Deprecated option.  Use -mno-spe instead"
 msgid "Deprecated option.  Use -mno-spe instead."
-msgstr "Устаревший ключ.  Используйте -mno-spe взамен"
+msgstr "Устаревший ключ.  Используйте вместо него -mno-spe."
 
 #: config/powerpcspe/powerpcspe.opt:370
-#, fuzzy
-#| msgid "Deprecated option.  Use -mspe instead"
 msgid "Deprecated option.  Use -mspe instead."
-msgstr "Устаревший ключ.  Используйте -mspe взамен"
+msgstr "Устаревший ключ.  Используйте вместо него -mspe."
 
 #: config/powerpcspe/powerpcspe.opt:374 config/rs6000/rs6000.opt:366
-#, fuzzy
-#| msgid "-mdebug=\tEnable debug output"
 msgid "-mdebug=\tEnable debug output."
-msgstr "-mdebug=\tВключить отладочную выдачу"
+msgstr "-mdebug=\tВключить отладочную выдачу."
 
 #: config/powerpcspe/powerpcspe.opt:378 config/rs6000/rs6000.opt:370
-#, fuzzy
-#| msgid "Use the AltiVec ABI extensions"
 msgid "Use the AltiVec ABI extensions."
-msgstr "Использовать расширения AltiVec ABI"
+msgstr "Использовать расширения AltiVec ABI."
 
 #: config/powerpcspe/powerpcspe.opt:382 config/rs6000/rs6000.opt:374
-#, fuzzy
-#| msgid "Do not use the AltiVec ABI extensions"
 msgid "Do not use the AltiVec ABI extensions."
-msgstr "Не использовать расширения AltiVec ABI"
+msgstr "Не использовать расширения AltiVec ABI."
 
 #: config/powerpcspe/powerpcspe.opt:386
-#, fuzzy
-#| msgid "Use the SPE ABI extensions"
 msgid "Use the SPE ABI extensions."
-msgstr "Использовать расширения SPE ABI"
+msgstr "Использовать расширения SPE ABI."
 
 #: config/powerpcspe/powerpcspe.opt:390
-#, fuzzy
-#| msgid "Do not use the SPE ABI extensions"
 msgid "Do not use the SPE ABI extensions."
-msgstr "Не использовать расширения SPE ABI"
+msgstr "Не использовать расширения SPE ABI."
 
 #: config/powerpcspe/powerpcspe.opt:394 config/rs6000/rs6000.opt:378
-#, fuzzy
-#| msgid "Use EABI"
 msgid "Use the ELFv1 ABI."
-msgstr "Использовать EABI"
+msgstr "Использовать ELFv1 ABI."
 
 #: config/powerpcspe/powerpcspe.opt:398 config/rs6000/rs6000.opt:382
-#, fuzzy
-#| msgid "Use EABI"
 msgid "Use the ELFv2 ABI."
-msgstr "Использовать EABI"
+msgstr "Использовать ELFv2 ABI."
 
 #: config/powerpcspe/powerpcspe.opt:405 config/rs6000/rs6000.opt:389
 msgid "using darwin64 ABI"
@@ -12507,52 +10381,36 @@
 msgstr "использование IBM extended precision long double"
 
 #: config/powerpcspe/powerpcspe.opt:418 config/rs6000/rs6000.opt:402
-#, fuzzy
-#| msgid "-mcpu=\tUse features of and schedule code for given CPU"
 msgid "-mcpu=\tUse features of and schedule code for given CPU."
-msgstr "-mcpu=\tИспользовать свойства указанного процессора и планировать код для него"
+msgstr "-mcpu=\tИспользовать свойства указанного процессора и планировать код для него."
 
 #: config/powerpcspe/powerpcspe.opt:422 config/rs6000/rs6000.opt:406
-#, fuzzy
-#| msgid "-mtune=\tSchedule code for given CPU"
 msgid "-mtune=\tSchedule code for given CPU."
-msgstr "-mtune=\tПланировать код для указанного процессора"
+msgstr "-mtune=\tПланировать код для указанного процессора."
 
 #: config/powerpcspe/powerpcspe.opt:426
-#, fuzzy
-#| msgid "-mtraceback=\tSelect full, part, or no traceback table"
 msgid "-mtraceback=\tSelect full, part, or no traceback table."
-msgstr "-mtraceback=\tВывод traceback-таблицы: full (полная), part (частичная), no (не выводить таблицу)"
+msgstr "-mtraceback=\tВывод traceback-таблицы: full (полная), part (частичная), no (не выводить таблицу)."
 
 #: config/powerpcspe/powerpcspe.opt:442 config/rs6000/rs6000.opt:426
-#, fuzzy
-#| msgid "Avoid all range limits on call instructions"
 msgid "Avoid all range limits on call instructions."
-msgstr "Не устанавливать предельные диапазоны для команд вызова"
+msgstr "Не устанавливать предельные диапазоны для команд вызова."
 
 #: config/powerpcspe/powerpcspe.opt:446
-#, fuzzy
-#| msgid "Generate Cell microcode"
 msgid "Generate Cell microcode."
-msgstr "Генерировать Cell микрокод"
+msgstr "Генерировать Cell микрокод."
 
 #: config/powerpcspe/powerpcspe.opt:450
-#, fuzzy
-#| msgid "Warn when a Cell microcoded instruction is emitted"
 msgid "Warn when a Cell microcoded instruction is emitted."
-msgstr "Предупреждать о выдаче микрокодированных Cell инструкций"
+msgstr "Предупреждать о выдаче микрокодированных Cell инструкций."
 
 #: config/powerpcspe/powerpcspe.opt:454 config/rs6000/rs6000.opt:434
-#, fuzzy
-#| msgid "Warn about deprecated 'vector long ...' AltiVec type usage"
 msgid "Warn about deprecated 'vector long ...' AltiVec type usage."
-msgstr "Предупреждать об использовании устаревших типов AltiVec 'vector long ...'"
+msgstr "Предупреждать об использовании устаревших типов AltiVec 'vector long ...'."
 
 #: config/powerpcspe/powerpcspe.opt:458
-#, fuzzy
-#| msgid "-mfloat-gprs=\tSelect GPR floating point method"
 msgid "-mfloat-gprs=\tSelect GPR floating point method."
-msgstr "-mfloat-gprs=\tВыбрать метод GPR работы с плавающими значениями"
+msgstr "-mfloat-gprs=\tВыбрать метод GPR работы с плавающими значениями."
 
 #: config/powerpcspe/powerpcspe.opt:462
 msgid "Valid arguments to -mfloat-gprs=:"
@@ -12559,34 +10417,24 @@
 msgstr "Корректные аргументы ключа -mfloat-gprs=:"
 
 #: config/powerpcspe/powerpcspe.opt:478
-#, fuzzy
-#| msgid "-mlong-double-<n>\tSpecify size of long double (64 or 128 bits)"
 msgid "-mlong-double-<n>\tSpecify size of long double (64 or 128 bits)."
-msgstr "-mlong-double-<n>\tЗадать размер long double (64 или 128 бит)"
+msgstr "-mlong-double-<n>\tЗадать размер long double (64 или 128 бит)."
 
 #: config/powerpcspe/powerpcspe.opt:482 config/sparc/sparc.opt:62
-#, fuzzy
-#| msgid "Enable clip instructions"
 msgid "Enable Local Register Allocation."
-msgstr "Включить clip инструкции"
+msgstr "Включить выделение Локальных Регистров."
 
 #: config/powerpcspe/powerpcspe.opt:486 config/rs6000/rs6000.opt:446
-#, fuzzy
-#| msgid "Determine which dependences between insns are considered costly"
 msgid "Determine which dependences between insns are considered costly."
-msgstr "Задает стоимость зависимостей между командами"
+msgstr "Задает стоимость зависимостей между командами."
 
 #: config/powerpcspe/powerpcspe.opt:490 config/rs6000/rs6000.opt:450
-#, fuzzy
-#| msgid "Specify which post scheduling nop insertion scheme to apply"
 msgid "Specify which post scheduling nop insertion scheme to apply."
-msgstr "Задает схему расстановки nop"
+msgstr "Задает схему расстановки nop."
 
 #: config/powerpcspe/powerpcspe.opt:494 config/rs6000/rs6000.opt:454
-#, fuzzy
-#| msgid "Specify alignment of structure fields default/natural"
 msgid "Specify alignment of structure fields default/natural."
-msgstr "Задает выравнивание полей структур default/natural"
+msgstr "Задает выравнивание полей структур default/natural."
 
 #: config/powerpcspe/powerpcspe.opt:498 config/rs6000/rs6000.opt:458
 msgid "Valid arguments to -malign-:"
@@ -12593,34 +10441,24 @@
 msgstr "Корректные аргументы ключа -malign-:"
 
 #: config/powerpcspe/powerpcspe.opt:508 config/rs6000/rs6000.opt:468
-#, fuzzy
-#| msgid "Specify scheduling priority for dispatch slot restricted insns"
 msgid "Specify scheduling priority for dispatch slot restricted insns."
-msgstr "Задать приоритет планирования для команд с ограничениями по dispatch-слотам"
+msgstr "Задать приоритет планирования для команд с ограничениями по dispatch-слотам."
 
 #: config/powerpcspe/powerpcspe.opt:512 config/rs6000/rs6000.opt:472
-#, fuzzy
-#| msgid "Single-precision floating point unit"
 msgid "Single-precision floating point unit."
-msgstr "Устройство плавающей арифметики одинарной точности"
+msgstr "Устройство плавающей арифметики одинарной точности."
 
 #: config/powerpcspe/powerpcspe.opt:516 config/rs6000/rs6000.opt:476
-#, fuzzy
-#| msgid "Double-precision floating point unit"
 msgid "Double-precision floating point unit."
-msgstr "Устройство плавающей арифметики двойной точности"
+msgstr "Устройство плавающей арифметики двойной точности."
 
 #: config/powerpcspe/powerpcspe.opt:520 config/rs6000/rs6000.opt:480
-#, fuzzy
-#| msgid "Floating point unit does not support divide & sqrt"
 msgid "Floating point unit does not support divide & sqrt."
-msgstr "Устройство плавающей арифметики не поддерживает деление и sqrt"
+msgstr "Устройство плавающей арифметики не поддерживает деление и sqrt."
 
 #: config/powerpcspe/powerpcspe.opt:524 config/rs6000/rs6000.opt:484
-#, fuzzy
-#| msgid "-mfpu=\tSpecify FP (sp, dp, sp-lite, dp-lite) (implies -mxilinx-fpu)"
 msgid "-mfpu=\tSpecify FP (sp, dp, sp-lite, dp-lite) (implies -mxilinx-fpu)."
-msgstr "-mfpu=\tЗадать FP (sp, dp, sp-lite, dp-lite) (влечет -mxilinx-fpu)"
+msgstr "-mfpu=\tЗадать FP (sp, dp, sp-lite, dp-lite) (влечет -mxilinx-fpu)."
 
 #: config/powerpcspe/powerpcspe.opt:546 config/rs6000/rs6000.opt:506
 msgid "Specify Xilinx FPU."
@@ -12627,240 +10465,188 @@
 msgstr "Задать Xilinx FPU."
 
 #: config/powerpcspe/powerpcspe.opt:550 config/rs6000/rs6000.opt:510
-#, fuzzy
-#| msgid "Use/do not use r11 to hold the static link in calls to functions via pointers."
 msgid "Use r11 to hold the static link in calls to functions via pointers."
-msgstr "(Не) использовать r11 для хранения статической ссылки в вызовах функций через указатели."
+msgstr "Использовать r11 для хранения статической ссылки в вызовах функций через указатели."
 
 #: config/powerpcspe/powerpcspe.opt:554 config/rs6000/rs6000.opt:514
-#, fuzzy
-#| msgid "Control whether we save the TOC in the prologue for indirect calls or generate the save inline"
 msgid "Save the TOC in the prologue for indirect calls rather than inline."
-msgstr "Контролировать, сохраняем ли мы TOC в прологе для косвенных вызовов или генерируем сохранение inline"
+msgstr "Сохранять TOC в прологе для косвенных вызовов а не inline."
 
 #: config/powerpcspe/powerpcspe.opt:558
 msgid "Allow 128-bit integers in VSX registers."
-msgstr ""
+msgstr "Разрешить 128-битные целые в VSX регистрах."
 
 #: config/powerpcspe/powerpcspe.opt:562 config/rs6000/rs6000.opt:522
 msgid "Fuse certain integer operations together for better performance on power8."
-msgstr ""
+msgstr "Слить определенные целочисленные операции вместе для для повышения производительности на power8."
 
 #: config/powerpcspe/powerpcspe.opt:566 config/rs6000/rs6000.opt:526
-#, fuzzy
-#| msgid "Align destination of the string operations"
 msgid "Allow sign extension in fusion operations."
-msgstr "Выравнивать результаты строковых операций"
+msgstr "Разрешить расширение знака в операциях слияния."
 
 #: config/powerpcspe/powerpcspe.opt:570 config/rs6000/rs6000.opt:530
-#, fuzzy
-#| msgid "Use vector/scalar (VSX) instructions"
 msgid "Use vector and scalar instructions added in ISA 2.07."
-msgstr "Использовать vector/scalar (VSX) инструкции"
+msgstr "Использовать векторные и скалярные инструкции добавленные в ISA 2.07."
 
 #: config/powerpcspe/powerpcspe.opt:574 config/rs6000/rs6000.opt:534
 msgid "Use ISA 2.07 Category:Vector.AES and Category:Vector.SHA2 instructions."
-msgstr ""
+msgstr "Использовать ISA 2.07 Category:Vector.AES и Category:Vector.SHA2 инструкции."
 
 #: config/powerpcspe/powerpcspe.opt:578
 msgid "Use ISA 2.07 direct move between GPR & VSX register instructions."
-msgstr ""
+msgstr "Использовать ISA 2.07 инструкции прямого перемещения между регистрами GPR & VSX."
 
 #: config/powerpcspe/powerpcspe.opt:582 config/rs6000/rs6000.opt:541
-#, fuzzy
-#| msgid "Use vector/scalar (VSX) instructions"
 msgid "Use ISA 2.07 transactional memory (HTM) instructions."
-msgstr "Использовать vector/scalar (VSX) инструкции"
+msgstr "Использовать ISA 2.07 инструкции транзакционной памяти (HTM)."
 
 #: config/powerpcspe/powerpcspe.opt:586 config/rs6000/rs6000.opt:545
-#, fuzzy
-#| msgid "Generate load/store multiple instructions"
 msgid "Generate the quad word memory instructions (lq/stq)."
-msgstr "Генерировать команды множественного чтения/записи"
+msgstr "Генерировать инструкции четверных слов памяти (lq/stq)."
 
 #: config/powerpcspe/powerpcspe.opt:590 config/rs6000/rs6000.opt:549
 msgid "Generate the quad word memory atomic instructions (lqarx/stqcx)."
-msgstr ""
+msgstr "Генерировать атомарные инструкции четверных слов памяти (lqarx/stqcx)."
 
 #: config/powerpcspe/powerpcspe.opt:594 config/rs6000/rs6000.opt:553
 msgid "Generate aggregate parameter passing code with at most 64-bit alignment."
-msgstr ""
+msgstr "Генерировать код агрегированной передачи параметров с не более чем 64-битным выравниванием."
 
 #: config/powerpcspe/powerpcspe.opt:598
 msgid "Allow double variables in upper registers with -mcpu=power7 or -mvsx."
-msgstr ""
+msgstr "Разрешить double переменные в верхних регистрах с -mcpu=power7 или -mvsx."
 
 #: config/powerpcspe/powerpcspe.opt:602
 msgid "Allow float variables in upper registers with -mcpu=power8 or -mpower8-vector."
-msgstr ""
+msgstr "Разрешить float переменные в верхних регистрах с -mcpu=power8 или -mpower8-vector."
 
 #: config/powerpcspe/powerpcspe.opt:606
 msgid "Allow float/double variables in upper registers if cpu allows it."
-msgstr ""
+msgstr "Разрешить float/double переменные в верхних регистрах, если процессор это позволяет."
 
 #: config/powerpcspe/powerpcspe.opt:610
 msgid "Allow 64-bit integer variables in upper registers with -mcpu=power7 or -mvsx."
-msgstr ""
+msgstr "Разрешить 64-битные целые переменные в верхних регистрах с -mcpu=power7 или -mvsx."
 
 #: config/powerpcspe/powerpcspe.opt:614 config/rs6000/rs6000.opt:557
 msgid "Analyze and remove doubleword swaps from VSX computations."
-msgstr ""
+msgstr "Анализировать и удалять перестановки двойных слов из VSX вычислений."
 
 #: config/powerpcspe/powerpcspe.opt:618 config/rs6000/rs6000.opt:561
 msgid "Fuse certain operations together for better performance on power9."
-msgstr ""
+msgstr "Сливать определенные операции вместе для повышения производительности на power9."
 
 #: config/powerpcspe/powerpcspe.opt:622 config/rs6000/rs6000.opt:565
-#, fuzzy
-#| msgid "Use pattern compare instructions"
 msgid "Use certain scalar instructions added in ISA 3.0."
-msgstr "Использовать инструкции сравнения шаблонов"
+msgstr "Использовать определенные скалярные инструкции добавленные в ISA 3.0."
 
 #: config/powerpcspe/powerpcspe.opt:626 config/rs6000/rs6000.opt:569
-#, fuzzy
-#| msgid "Use vector/scalar (VSX) instructions"
 msgid "Use vector instructions added in ISA 3.0."
-msgstr "Использовать vector/scalar (VSX) инструкции"
+msgstr "Использовать векторные инструкции добавленные в ISA 3.0."
 
 #: config/powerpcspe/powerpcspe.opt:630
 msgid "Use scalar register+offset memory instructions added in ISA 3.0."
-msgstr ""
+msgstr "Использовать инструкции памяти скаляр регистр+смещение добавленные в ISA 3.0."
 
 #: config/powerpcspe/powerpcspe.opt:634
 msgid "Use vector register+offset memory instructions added in ISA 3.0."
-msgstr ""
+msgstr "Использовать инструкции памяти вектор регистр+смещение добавленные в ISA 3.0."
 
 #: config/powerpcspe/powerpcspe.opt:638
 msgid "Use register+offset memory instructions added in ISA 3.0."
-msgstr ""
+msgstr "Использовать инструкции памяти регистр+смещение добавленные в ISA 3.0."
 
 #: config/powerpcspe/powerpcspe.opt:642 config/rs6000/rs6000.opt:573
-#, fuzzy
-#| msgid "Enable min/max instructions"
 msgid "Use the new min/max instructions defined in ISA 3.0."
-msgstr "Включить инструкции min/max"
+msgstr "Использовать новые min/max инструкции определенные в ISA 3.0."
 
 #: config/powerpcspe/powerpcspe.opt:646 config/rs6000/rs6000.opt:577
 msgid "Fuse medium/large code model toc references with the memory instruction."
-msgstr ""
+msgstr "Слить toc ссылки medium/large моделей кода с инструкцией памяти."
 
 #: config/powerpcspe/powerpcspe.opt:650 config/rs6000/rs6000.opt:581
-#, fuzzy
-#| msgid "Generate isel instructions"
 msgid "Generate the integer modulo instructions."
-msgstr "Генерировать команды isel"
+msgstr "Генерировать целочисленные по модулю инструкции."
 
 #: config/powerpcspe/powerpcspe.opt:658
 msgid "Allow the IEEE 128-bit types without requiring the __float128 keyword."
-msgstr ""
+msgstr "Разрешить IEEE 128-битные типы без требования __float128 ключевого слова."
 
 #: config/powerpcspe/powerpcspe.opt:662 config/rs6000/rs6000.opt:585
-#, fuzzy
-#| msgid "Use decimal floating point instructions"
 msgid "Enable IEEE 128-bit floating point via the __float128 keyword."
-msgstr "Использовать инструкции десятичных плавающих"
+msgstr "Включить IEEE 128-битную плавающую точку посредством __float128 ключевого слова."
 
 #: config/powerpcspe/powerpcspe.opt:666 config/rs6000/rs6000.opt:589
-#, fuzzy
-#| msgid "Use decimal floating point instructions"
 msgid "Enable using IEEE 128-bit floating point instructions."
-msgstr "Использовать инструкции десятичных плавающих"
+msgstr "Включить использование инструкций IEEE 128-битной плавающей точки."
 
 #: config/powerpcspe/powerpcspe.opt:670 config/rs6000/rs6000.opt:593
 msgid "Enable default conversions between __float128 & long double."
-msgstr ""
+msgstr "Включить подразумеваемое преобразование между __float128 & long double."
 
 #: config/powerpcspe/powerpcspe.opt:674
-#, fuzzy
-#| msgid "Return small aggregates in registers"
 msgid "Enable small integers to be in VSX registers."
-msgstr "Возвращать короткие агрегатные значения в регистрах"
+msgstr "Включить размещение небольших целых в VSX регистрах."
 
 #: config/powerpcspe/powerpcspe.opt:682 config/rs6000/rs6000.opt:601
-#, fuzzy
-#| msgid "Valid arguments to -mfloat-gprs=:"
 msgid "Valid arguments to -mstack-protector-guard=:"
-msgstr "Корректные аргументы ключа -mfloat-gprs=:"
+msgstr "Корректные аргументы ключа -mstack-protector-guard=:"
 
 #: config/powerpcspe/476.opt:24 config/rs6000/476.opt:24
-#, fuzzy
-#| msgid "Preserve the PowerPC 476's link stack by matching up a blr with the bcl/bl insns used for GOT accesses"
 msgid "Preserve the PowerPC 476's link stack by matching up a blr with the bcl/bl insns used for GOT accesses."
-msgstr "Сохранять PowerPC 476's стек ссылок путем установления соответствия blr с bcl/bl инструкциями используемыми для GOT доступов"
+msgstr "Сохранять PowerPC 476's стек ссылок путем установления соответствия blr с bcl/bl инструкциями используемыми для GOT доступов."
 
 #: config/powerpcspe/aix64.opt:24 config/rs6000/aix64.opt:24
-#, fuzzy
-#| msgid "Compile for 64-bit pointers"
 msgid "Compile for 64-bit pointers."
-msgstr "Генерировать код с 64-битными указателями"
+msgstr "Компилировать для 64-битных указателей."
 
 #: config/powerpcspe/aix64.opt:28 config/rs6000/aix64.opt:28
-#, fuzzy
-#| msgid "Compile for 32-bit pointers"
 msgid "Compile for 32-bit pointers."
-msgstr "Генерировать код с 32-битными указателями"
+msgstr "Компилировать для 32-битных указателей."
 
 #: config/powerpcspe/aix64.opt:32 config/powerpcspe/linux64.opt:28
 #: config/rs6000/aix64.opt:32 config/rs6000/linux64.opt:28
-#, fuzzy
-#| msgid "Select code model"
 msgid "Select code model."
-msgstr "Выбрать модель кода"
+msgstr "Выбрать модель кода."
 
 #: config/powerpcspe/aix64.opt:49 config/rs6000/aix64.opt:49
-#, fuzzy
-#| msgid "Support message passing with the Parallel Environment"
 msgid "Support message passing with the Parallel Environment."
-msgstr "Передача сообщений средствами Parallel Environment"
+msgstr "Передача сообщений средствами Parallel Environment."
 
 #: config/powerpcspe/linux64.opt:24 config/rs6000/linux64.opt:24
-#, fuzzy
-#| msgid "Call mcount for profiling before a function prologue"
 msgid "Call mcount for profiling before a function prologue."
-msgstr "Вызывать mcount для профилирования перед прологом функции"
+msgstr "Вызывать mcount для профилирования перед прологом функции."
 
 #: config/powerpcspe/sysv4.opt:24
-#, fuzzy
-#| msgid "Select ABI calling convention"
 msgid "Select ABI calling convention."
-msgstr "Использовать соглашения о вызовах для ABI"
+msgstr "Использовать ABI соглашение о вызовах."
 
 #: config/powerpcspe/sysv4.opt:28 config/c6x/c6x.opt:42
-#, fuzzy
-#| msgid "Select method for sdata handling"
 msgid "Select method for sdata handling."
-msgstr "Метод обработки sdata"
+msgstr "Выбрать метод обработки sdata."
 
 #: config/powerpcspe/sysv4.opt:48 config/rs6000/sysv4.opt:52
-#, fuzzy
-#| msgid "Align to the base type of the bit-field"
 msgid "Align to the base type of the bit-field."
-msgstr "Выравнивать для базового типа битового поля"
+msgstr "Выравнивать к базовому типу битового поля."
 
 #: config/powerpcspe/sysv4.opt:52 config/rs6000/sysv4.opt:56
 msgid "Align to the base type of the bit-field. Don't assume that unaligned accesses are handled by the system."
-msgstr ""
+msgstr "Выравнивать к базовому типу битового поля. Не предполагать, что система поддерживает невыровненный доступ к памяти."
 
 #: config/powerpcspe/sysv4.opt:57 config/powerpcspe/sysv4.opt:61
 #: config/rs6000/sysv4.opt:61 config/rs6000/sysv4.opt:65
-#, fuzzy
-#| msgid "Produce code relocatable at runtime"
 msgid "Produce code relocatable at runtime."
-msgstr "Генерировать код, перемещаемый во время выполнения"
+msgstr "Порождать код, перемещаемый во время выполнения"
 
 #: config/powerpcspe/sysv4.opt:65 config/powerpcspe/sysv4.opt:69
 #: config/rs6000/sysv4.opt:69 config/rs6000/sysv4.opt:73
-#, fuzzy
-#| msgid "Produce little endian code"
 msgid "Produce little endian code."
-msgstr "Генерировать код для обратного порядка байт (little endian)"
+msgstr "Порождать little endian код."
 
 #: config/powerpcspe/sysv4.opt:73 config/powerpcspe/sysv4.opt:77
 #: config/rs6000/sysv4.opt:77 config/rs6000/sysv4.opt:81
-#, fuzzy
-#| msgid "Produce big endian code"
 msgid "Produce big endian code."
-msgstr "Генерировать код для прямого порядка байт (big endian)"
+msgstr "Порождать big endian код."
 
 #: config/powerpcspe/sysv4.opt:82 config/powerpcspe/sysv4.opt:86
 #: config/powerpcspe/sysv4.opt:95 config/powerpcspe/sysv4.opt:137
@@ -12867,196 +10653,140 @@
 #: config/powerpcspe/sysv4.opt:149 config/rs6000/sysv4.opt:86
 #: config/rs6000/sysv4.opt:90 config/rs6000/sysv4.opt:99
 #: config/rs6000/sysv4.opt:141 config/rs6000/sysv4.opt:153
-#, fuzzy
-#| msgid "no description yet"
 msgid "no description yet."
-msgstr "описание отсутствует"
+msgstr "описание отсутствует."
 
 #: config/powerpcspe/sysv4.opt:90 config/rs6000/sysv4.opt:94
-#, fuzzy
-#| msgid "Assume all variable arg functions are prototyped"
 msgid "Assume all variable arg functions are prototyped."
-msgstr "Предполагать, что все функции с переменными аргументами имеют прототипы"
+msgstr "Предполагать, что все функции с переменными аргументами имеют прототипы."
 
 #: config/powerpcspe/sysv4.opt:99 config/rs6000/sysv4.opt:103
-#, fuzzy
-#| msgid "Use EABI"
 msgid "Use EABI."
-msgstr "Использовать EABI"
+msgstr "Использовать EABI."
 
 #: config/powerpcspe/sysv4.opt:103 config/rs6000/sysv4.opt:107
-#, fuzzy
-#| msgid "Allow bit-fields to cross word boundaries"
 msgid "Allow bit-fields to cross word boundaries."
-msgstr "Разрешить битовые поля, пересекающие границу слова"
+msgstr "Разрешить битовым полям пересекать границы слов."
 
 #: config/powerpcspe/sysv4.opt:107 config/rs6000/sysv4.opt:111
-#, fuzzy
-#| msgid "Use alternate register names"
 msgid "Use alternate register names."
-msgstr "Использовать альтернативные имена регистров"
+msgstr "Использовать альтернативные имена регистров."
 
 #: config/powerpcspe/sysv4.opt:113 config/rs6000/sysv4.opt:117
-#, fuzzy
-#| msgid "Use default method for sdata handling"
 msgid "Use default method for sdata handling."
-msgstr "Использовать метод обработки sdata по умолчанию"
+msgstr "Использовать подразумеваемый метод обработки sdata."
 
 #: config/powerpcspe/sysv4.opt:117 config/rs6000/sysv4.opt:121
-#, fuzzy
-#| msgid "Link with libsim.a, libc.a and sim-crt0.o"
 msgid "Link with libsim.a, libc.a and sim-crt0.o."
-msgstr "Компоновать с libsim.a, libc.a и sim-crt0.o"
+msgstr "Компоновать с libsim.a, libc.a и sim-crt0.o."
 
 #: config/powerpcspe/sysv4.opt:121 config/rs6000/sysv4.opt:125
-#, fuzzy
-#| msgid "Link with libads.a, libc.a and crt0.o"
 msgid "Link with libads.a, libc.a and crt0.o."
-msgstr "Компоновать с libads.a, libc.a и crt0.o"
+msgstr "Компоновать с libads.a, libc.a и crt0.o."
 
 #: config/powerpcspe/sysv4.opt:125 config/rs6000/sysv4.opt:129
-#, fuzzy
-#| msgid "Link with libyk.a, libc.a and crt0.o"
 msgid "Link with libyk.a, libc.a and crt0.o."
-msgstr "Компоновать с libyk.a, libc.a и crt0.o"
+msgstr "Компоновать с libyk.a, libc.a и crt0.o."
 
 #: config/powerpcspe/sysv4.opt:129 config/rs6000/sysv4.opt:133
-#, fuzzy
-#| msgid "Link with libmvme.a, libc.a and crt0.o"
 msgid "Link with libmvme.a, libc.a and crt0.o."
-msgstr "Компоновать с libmvme.a, libc.a и crt0.o"
+msgstr "Компоновать с libmvme.a, libc.a и crt0.o."
 
 #: config/powerpcspe/sysv4.opt:133 config/rs6000/sysv4.opt:137
-#, fuzzy
-#| msgid "Set the PPC_EMB bit in the ELF flags header"
 msgid "Set the PPC_EMB bit in the ELF flags header."
-msgstr "Установить бит PPC_EMB в заголовке ELF-файла"
+msgstr "Установить бит PPC_EMB в заголовке ELF флагов."
 
 #: config/powerpcspe/sysv4.opt:153 config/rs6000/sysv4.opt:157
-#, fuzzy
-#| msgid "Generate code to use a non-exec PLT and GOT"
 msgid "Generate code to use a non-exec PLT and GOT."
-msgstr "Генерировать код для использования не выполняющихся PLT и GOT"
+msgstr "Генерировать код для использования не выполняющихся PLT и GOT."
 
 #: config/powerpcspe/sysv4.opt:157 config/rs6000/sysv4.opt:161
-#, fuzzy
-#| msgid "Generate code for old exec BSS PLT"
 msgid "Generate code for old exec BSS PLT."
-msgstr "Генерировать код для старой выполняющей BSS PLT"
+msgstr "Генерировать код для старых выполняющихся BSS PLT."
 
 #: config/powerpcspe/sysv4.opt:161 config/rs6000/sysv4.opt:165
 msgid "Emit .gnu_attribute tags."
-msgstr ""
+msgstr "Порождать .gnu_attribute теги."
 
 #: config/g.opt:27
-#, fuzzy
-#| msgid "-G<number>\tPut global and static data smaller than <number> bytes into a special section (on some targets)"
 msgid "-G<number>\tPut global and static data smaller than <number> bytes into a special section (on some targets)."
-msgstr "-G<number>\tРазмещать глобальные и статические данные меньше заданного <числа> байт в специальных секциях (для некоторых платформ)"
+msgstr "-G<number>\tРазмещать глобальные и статические данные меньше заданного <числа> байт в специальных секциях (для некоторых платформ)."
 
 #: config/lynx.opt:23
-#, fuzzy
-#| msgid "Support legacy multi-threading"
 msgid "Support legacy multi-threading."
-msgstr "Поддержка унаследованной модели многопоточности"
+msgstr "Поддержка унаследованной модели многопоточности."
 
 #: config/lynx.opt:27
-#, fuzzy
-#| msgid "Use shared libraries"
 msgid "Use shared libraries."
-msgstr "Использовать разделяемые библиотеки"
+msgstr "Использовать разделяемые библиотеки."
 
 #: config/lynx.opt:31
-#, fuzzy
-#| msgid "Support multi-threading"
 msgid "Support multi-threading."
-msgstr "Поддержка многопоточности"
+msgstr "Поддержка многопоточности."
 
 #: config/nvptx/nvptx.opt:22
-#, fuzzy
-#| msgid "Generate code for a Fido A"
 msgid "Generate code for a 32-bit ABI."
-msgstr "Генерировать код для Fido A"
+msgstr "Генерировать код для 32-битного ABI."
 
 #: config/nvptx/nvptx.opt:26
-#, fuzzy
-#| msgid "Generate code for a Fido A"
 msgid "Generate code for a 64-bit ABI."
-msgstr "Генерировать код для Fido A"
+msgstr "Генерировать код для 64-битного ABI."
 
 #: config/nvptx/nvptx.opt:30
 msgid "Link in code for a __main kernel."
-msgstr ""
+msgstr "Ссылка в коде для ядра __main."
 
 #: config/nvptx/nvptx.opt:34
 msgid "Optimize partition neutering."
-msgstr ""
+msgstr "Оптимизировать усреднение разделов."
 
 #: config/nvptx/nvptx.opt:38
 msgid "Use custom stacks instead of local memory for automatic storage."
-msgstr ""
+msgstr "Использовать специальные стеки вместо локальной памяти для автоматической памяти."
 
 #: config/nvptx/nvptx.opt:42
 msgid "Specify size of .local memory used for stack when the exact amount is not known."
-msgstr ""
+msgstr "Задать размер .local памяти, использованной под стек, когда точное количество неизвестно."
 
 #: config/nvptx/nvptx.opt:46
-#, fuzzy
-#| msgid "Generate code that can be used in SVR4-style dynamic objects"
 msgid "Generate code that can keep local state uniform across all lanes."
-msgstr "Генерировать код, который может использоваться в динамических объектах SVR4"
+msgstr "Генерировать код, который может сохранять локальное состояние однородным для всех проходов."
 
 #: config/nvptx/nvptx.opt:50
 msgid "Generate code for OpenMP offloading: enables -msoft-stack and -muniform-simt."
-msgstr ""
+msgstr "Генерировать код для разгрузки OpenMP: включает -msoft-stack and -muniform-simt."
 
 #: config/vxworks.opt:36
-#, fuzzy
-#| msgid "Assume the VxWorks RTP environment"
 msgid "Assume the VxWorks RTP environment."
-msgstr "Генерировать код для среды выполнения VxWorks RTP"
+msgstr "Генерировать код для среды выполнения VxWorks RTP."
 
 #: config/vxworks.opt:43
-#, fuzzy
-#| msgid "Assume the VxWorks vThreads environment"
 msgid "Assume the VxWorks vThreads environment."
-msgstr "Генерировать код для среды выполнения VxWorks vThreads"
+msgstr "Генерировать код для среды выполнения VxWorks vThreads."
 
 #: config/cr16/cr16.opt:23
-#, fuzzy
-#| msgid "-msim   Use simulator runtime"
 msgid "-msim   Use simulator runtime."
-msgstr "-msim   Использовать поддержку времени выполнения симулятора"
+msgstr "-msim   Использовать поддержку времени выполнения симулятора."
 
 #: config/cr16/cr16.opt:27
-#, fuzzy
-#| msgid "Generate SBIT, CBIT instructions"
 msgid "Generate SBIT, CBIT instructions."
-msgstr "Генерировать инструкции SBIT, CBIT"
+msgstr "Генерировать инструкции SBIT, CBIT."
 
 #: config/cr16/cr16.opt:31
-#, fuzzy
-#| msgid "Support multiply accumulate instructions"
 msgid "Support multiply accumulate instructions."
-msgstr "Использовать команды умножения со сложением"
+msgstr "Использовать команды умножения со сложением."
 
 #: config/cr16/cr16.opt:38
-#, fuzzy
-#| msgid "Treat data references as near, far or medium. medium is default"
 msgid "Treat data references as near, far or medium. medium is default."
-msgstr "Трактовать обращения к данным как near, far или medium. medium является подразумеваемым"
+msgstr "Трактовать обращения к данным как near, far или medium. По умолчанию используется medium."
 
 #: config/cr16/cr16.opt:42
-#, fuzzy
-#| msgid "Generate code for CR16C architecture"
 msgid "Generate code for CR16C architecture."
-msgstr "Генерировать код для CR16C архитектуры"
+msgstr "Генерировать код для CR16C архитектуры."
 
 #: config/cr16/cr16.opt:46
-#, fuzzy
-#| msgid "Generate code for CR16C+ architecture (Default)"
 msgid "Generate code for CR16C+ architecture (Default)."
-msgstr "Генерировать код для CR16C+ архитектуры (По умолчанию)"
+msgstr "Генерировать код для CR16C+ архитектуры (По умолчанию)."
 
 #: config/cr16/cr16.opt:50
 msgid "Treat integers as 32-bit."
@@ -13063,40 +10793,33 @@
 msgstr "Трактовать целые как 32-битные."
 
 #: config/avr/avr.opt:23
-#, fuzzy
-#| msgid "Use subroutines for function prologues and epilogues"
 msgid "Use subroutines for function prologues and epilogues."
-msgstr "Использовать подпрограммы для прологов/эпилогов функций"
+msgstr "Использовать подпрограммы для прологов/эпилогов функций."
 
 #: config/avr/avr.opt:26
-#, fuzzy, c-format
-#| msgid "missing makefile target after %qs"
+#, c-format
 msgid "missing device or architecture after %qs"
-msgstr "не задана цель после %qs"
+msgstr "отсутствует устройство или архитектура после %qs"
 
 #: config/avr/avr.opt:27
-#, fuzzy
-#| msgid "-mmcu=MCU\tSelect the target MCU"
 msgid "-mmcu=MCU\tSelect the target MCU."
-msgstr "-mmcu=MCU\tВыбрать целевой MCU"
+msgstr "-mmcu=MCU\tВыбрать целевой MCU."
 
 #: config/avr/avr.opt:31
-#, fuzzy
-#| msgid "Use subroutines for function prologues and epilogues"
 msgid "Allow usage of __gcc_isr pseudo instructions in ISR prologues and epilogues."
-msgstr "Использовать подпрограммы для прологов/эпилогов функций"
+msgstr ""
 
 #: config/avr/avr.opt:35
 msgid "Set the number of 64 KiB flash segments."
-msgstr ""
+msgstr "Установить число 64 КБ флэш сегментов."
 
 #: config/avr/avr.opt:39
 msgid "Indicate presence of a processor erratum."
-msgstr ""
+msgstr "Указать наличие ошибок процессора."
 
 #: config/avr/avr.opt:43
 msgid "Enable Read-Modify-Write (RMW) instructions support/use."
-msgstr ""
+msgstr "Включить поддержку/использование инструкций Read-Modify-Write (RMW)"
 
 #: config/avr/avr.opt:53
 msgid "Use RJMP / RCALL even though CALL / JMP are available."
@@ -13103,20 +10826,16 @@
 msgstr ""
 
 #: config/avr/avr.opt:57
-#, fuzzy
-#| msgid "Use an 8-bit 'int' type"
 msgid "Use an 8-bit 'int' type."
-msgstr "Использовать 8-битный 'int' тип"
+msgstr "Использовать 8-битный 'int' тип."
 
 #: config/avr/avr.opt:61
-#, fuzzy
-#| msgid "Change the stack pointer without disabling interrupts"
 msgid "Change the stack pointer without disabling interrupts."
-msgstr "Изменять указатель стека без отмены прерываний"
+msgstr "Изменять указатель стека без отмены прерываний."
 
 #: config/avr/avr.opt:65
 msgid "Set the branch costs for conditional branch instructions.  Reasonable values are small, non-negative integers.  The default branch cost is 0."
-msgstr "Установить цены ветвлений для инструкций условного перехода.  Разумные значения небольшие, неотрицательные целые.  Подразумеваемая цена ветвления есть 0."
+msgstr ""
 
 #: config/avr/avr.opt:69
 msgid "Treat main as if it had attribute OS_task."
@@ -13123,40 +10842,32 @@
 msgstr ""
 
 #: config/avr/avr.opt:79
-#, fuzzy
-#| msgid "Change only the low 8 bits of the stack pointer"
 msgid "Change only the low 8 bits of the stack pointer."
-msgstr "Изменять только младшие 8 бит указателя стека"
+msgstr "Изменять только младшие 8 бит указателя стека."
 
 #: config/avr/avr.opt:83
-#, fuzzy
-#| msgid "Relax branches"
 msgid "Relax branches."
-msgstr "Ослабить ветвления"
+msgstr "Ослабить ветвления."
 
 #: config/avr/avr.opt:87
 msgid "Make the linker relaxation machine assume that a program counter wrap-around occurs."
-msgstr "Заставить машину ослаблений компоновщика предполагать что произошло переполнение счетчика команд."
+msgstr "Заставить машину ослаблений компоновщика предполагать, что произошло переполнение счетчика команд."
 
 #: config/avr/avr.opt:91
-#, fuzzy
-#| msgid "Accumulate outgoing function arguments and acquire/release the needed stack space for outpoing function arguments in function prologue/epilogue.  Without this option, outgoing arguments are pushed before calling a function and popped afterwards.  This option can lead to reduced code size for functions that call many functions that get their arguments on the stack like, for example printf."
 msgid "Accumulate outgoing function arguments and acquire/release the needed stack space for outgoing function arguments in function prologue/epilogue.  Without this option, outgoing arguments are pushed before calling a function and popped afterwards.  This option can lead to reduced code size for functions that call many functions that get their arguments on the stack like, for example printf."
-msgstr "Накапливать выходные аргументы функций и взять/отдать требуемое пространство стека для выходных аргументов функций в прологе/эпилоге функции.  Без этой опции выходные аргументы вталкиваются перед вызовом функции и выталкиваются после.  Эта опция может уменьшить размер кода для функций которые вызывают много функций которые получают свои аргументы на стеке как, например printf."
+msgstr ""
 
 #: config/avr/avr.opt:95
 msgid "When accessing RAM, use X as imposed by the hardware, i.e. just use pre-decrement, post-increment and indirect addressing with the X register.  Without this option, the compiler may assume that there is an addressing mode X+const similar to Y+const and Z+const and emit instructions to emulate such an addressing mode for X."
-msgstr "При доступе к ОЗУ использовать X как велит аппаратура, т.е. просто использовать предекремент, постинкремент и косвенную адресацию с X регистром.  Без этой опции компилятор может предполагать что имеет место режим адресации X+const аналогичный Y+const и Z+const и выдавать инструкции для эмуляции такого режима адресации для X."
+msgstr ""
 
 #: config/avr/avr.opt:100
 msgid "The device has no SPH special function register. This option will be overridden by the compiler driver with the correct setting if presence/absence of SPH can be deduced from -mmcu=MCU."
-msgstr "Устройство не имеет SPH специального функционального регистра. Эта опция будет перебита драйвером компилятора с корректной установкой если присутствие/отсутствие SPH могут быть выведено из -mmcu=MCU."
+msgstr ""
 
 #: config/avr/avr.opt:104
-#, fuzzy
-#| msgid "taking the address of a label is non-standard"
 msgid "Warn if the address space of an address is changed."
-msgstr "взятие адреса метки не поддерживается ISO C/C++"
+msgstr "Предупреждать, если адресное пространство адресов изменяется."
 
 #: config/avr/avr.opt:108
 msgid "Warn if the ISR is misspelled, i.e. without __vector prefix. Enabled by default."
@@ -13164,7 +10875,7 @@
 
 #: config/avr/avr.opt:112
 msgid "Allow to use truncation instead of rounding towards zero for fractional fixed-point types."
-msgstr ""
+msgstr "Разрешить использовать усечение вместо округления к нулю для дробных типов с фиксированной точкой."
 
 #: config/avr/avr.opt:116
 msgid "Assume that all data in static storage can be accessed by LDS / STS.  This option is only useful for reduced Tiny devices."
@@ -13172,151 +10883,103 @@
 
 #: config/avr/avr.opt:120
 msgid "Do not link against the device-specific library lib<MCU>.a."
-msgstr ""
+msgstr "Не компоновать с зависящей от устройства библиотекой lib<MCU>.a."
 
 #: config/m32r/m32r.opt:34
-#, fuzzy
-#| msgid "Compile for the m32rx"
 msgid "Compile for the m32rx."
-msgstr "Компилировать для m32rx"
+msgstr "Компилировать для m32rx."
 
 #: config/m32r/m32r.opt:38
-#, fuzzy
-#| msgid "Compile for the m32r2"
 msgid "Compile for the m32r2."
-msgstr "Компилировать для m32r2"
+msgstr "Компилировать для m32r2."
 
 #: config/m32r/m32r.opt:42
-#, fuzzy
-#| msgid "Compile for the m32r"
 msgid "Compile for the m32r."
-msgstr "Компилировать для m32r"
+msgstr "Компилировать для m32r."
 
 #: config/m32r/m32r.opt:46
-#, fuzzy
-#| msgid "Align all loops to 32 byte boundary"
 msgid "Align all loops to 32 byte boundary."
-msgstr "Выравнивать циклы по границе 32 байт"
+msgstr "Выравнивать циклы по границе 32 байт."
 
 #: config/m32r/m32r.opt:50
-#, fuzzy
-#| msgid "Prefer branches over conditional execution"
 msgid "Prefer branches over conditional execution."
-msgstr "Отдавать предпочтение переходам, а не условному выполнению"
+msgstr "Отдавать предпочтение переходам, а не условному выполнению."
 
 #: config/m32r/m32r.opt:54
-#, fuzzy
-#| msgid "Give branches their default cost"
 msgid "Give branches their default cost."
-msgstr "Присваивать переходам цену по умолчанию"
+msgstr "Присваивать переходам цену по умолчанию."
 
 #: config/m32r/m32r.opt:58
-#, fuzzy
-#| msgid "Display compile time statistics"
 msgid "Display compile time statistics."
-msgstr "Показать статистику времени компиляции"
+msgstr "Показать статистику времени компиляции."
 
 #: config/m32r/m32r.opt:62
-#, fuzzy
-#| msgid "Specify cache flush function"
 msgid "Specify cache flush function."
-msgstr "Функция сброса кэша"
+msgstr "Функция сброса кэша."
 
 #: config/m32r/m32r.opt:66
-#, fuzzy
-#| msgid "Specify cache flush trap number"
 msgid "Specify cache flush trap number."
-msgstr "Номер прерывания по сбросу кэша"
+msgstr "Номер прерывания по сбросу кэша."
 
 #: config/m32r/m32r.opt:70
-#, fuzzy
-#| msgid "Only issue one instruction per cycle"
 msgid "Only issue one instruction per cycle."
-msgstr "Генерировать код с выдачей одной команды на такт"
+msgstr "Генерировать код с выдачей одной команды на такт."
 
 #: config/m32r/m32r.opt:74
-#, fuzzy
-#| msgid "Allow two instructions to be issued per cycle"
 msgid "Allow two instructions to be issued per cycle."
-msgstr "Генерировать код с выдачей двух команд на такт"
+msgstr "Генерировать код с выдачей двух команд на такт."
 
 #: config/m32r/m32r.opt:78
-#, fuzzy
-#| msgid "Code size: small, medium or large"
 msgid "Code size: small, medium or large."
-msgstr "Модель кода: small, medium, large+"
+msgstr "Модель кода: small, medium, large+."
 
 #: config/m32r/m32r.opt:94
-#, fuzzy
-#| msgid "Don't call any cache flush functions"
 msgid "Don't call any cache flush functions."
-msgstr "Не вызывать функции сброса кэша"
+msgstr "Не вызывать функции сброса кэша."
 
 #: config/m32r/m32r.opt:98
-#, fuzzy
-#| msgid "Don't call any cache flush trap"
 msgid "Don't call any cache flush trap."
-msgstr "Не вызывать прерывание по сбросу кэша"
+msgstr "Не вызывать прерывание по сбросу кэша."
 
 #: config/m32r/m32r.opt:105
-#, fuzzy
-#| msgid "Small data area: none, sdata, use"
 msgid "Small data area: none, sdata, use."
-msgstr "Область малых данных: none, sdata, use"
+msgstr "Область малых данных: none, sdata, use."
 
 #: config/s390/tpf.opt:23
-#, fuzzy
-#| msgid "Enable TPF-OS tracing code"
 msgid "Enable TPF-OS tracing code."
-msgstr "Включить код трассировки TPF-OS"
+msgstr "Включить код трассировки TPF-OS."
 
 #: config/s390/tpf.opt:27
-#, fuzzy
-#| msgid "Specify main object for TPF-OS"
 msgid "Specify main object for TPF-OS."
-msgstr "Задать главный объект для TPF-OS"
+msgstr "Задать главный объект для TPF-OS."
 
 #: config/s390/s390.opt:48
-#, fuzzy
-#| msgid "31 bit ABI"
 msgid "31 bit ABI."
-msgstr "31-битный ABI"
+msgstr "31-битный ABI."
 
 #: config/s390/s390.opt:52
-#, fuzzy
-#| msgid "64 bit ABI"
 msgid "64 bit ABI."
-msgstr "64-битный ABI"
+msgstr "64-битный ABI."
 
 #: config/s390/s390.opt:126
-#, fuzzy
-#| msgid "Maintain backchain pointer"
 msgid "Maintain backchain pointer."
-msgstr "Сохранять указатель на вызванную функцию"
+msgstr "Поддерживать обратную ссылку."
 
 #: config/s390/s390.opt:130
-#, fuzzy
-#| msgid "Additional debug prints"
 msgid "Additional debug prints."
-msgstr "Выводить отладочную печать"
+msgstr "Дополнительная отладочная печать."
 
 #: config/s390/s390.opt:134
-#, fuzzy
-#| msgid "ESA/390 architecture"
 msgid "ESA/390 architecture."
-msgstr "архитектура ESA/390"
+msgstr "архитектура ESA/390."
 
 #: config/s390/s390.opt:138
-#, fuzzy
-#| msgid "Enable decimal floating point hardware support"
 msgid "Enable decimal floating point hardware support."
-msgstr "Использовать аппаратную реализацию десятичной плавающей арифметики"
+msgstr "Включить аппаратную поддержку десятичной плавающей арифметики."
 
 #: config/s390/s390.opt:142
-#, fuzzy
-#| msgid "Enable hardware floating point"
 msgid "Enable hardware floating point."
-msgstr "Использовать аппаратную реализацию плавающей арифметики"
+msgstr "Включить аппаратную плавающую арифметику."
 
 #: config/s390/s390.opt:146
 msgid "Takes two non-negative integer numbers separated by a comma. Prepend the function label with the number of two-byte Nop instructions indicated by the first.  Append Nop instructions covering the number of halfwords indicated by the second after the label.  Nop instructions of the largest possible size are used (six, four or two bytes), beginning with the largest possible size.  Using 0 for both values disables hotpatching."
@@ -13323,95 +10986,69 @@
 msgstr ""
 
 #: config/s390/s390.opt:164
-#, fuzzy
-#| msgid "Use hardware floating point instructions"
 msgid "Use hardware transactional execution instructions."
-msgstr "Использовать аппаратные инструкции плавающей арифметики"
+msgstr "Использовать аппаратные инструкции транзакционного выполнения"
 
 #: config/s390/s390.opt:168
-#, fuzzy
-#| msgid "hardware decimal floating point instructions not available on %s"
 msgid "Use hardware vector facility instructions and enable the vector ABI."
-msgstr "аппаратные инструкции десятичной плавающей точки отсутствуют на %s"
+msgstr "Использовать аппаратные векторные инструкции и включить векторный ABI."
 
 #: config/s390/s390.opt:172
-#, fuzzy
-#| msgid "Use packed stack layout"
 msgid "Use packed stack layout."
-msgstr "Использовать компактную раскладку в стеке"
+msgstr "Использовать компактную раскладку в стеке."
 
 #: config/s390/s390.opt:176
-#, fuzzy
-#| msgid "Use bras for executable < 64k"
 msgid "Use bras for executable < 64k."
-msgstr "Использовать команду bras, если выполняемый файл < 64Кб"
+msgstr "Использовать команду bras, если выполняемый файл < 64К."
 
 #: config/s390/s390.opt:180
-#, fuzzy
-#| msgid "Disable hardware floating point"
 msgid "Disable hardware floating point."
-msgstr "Не использовать аппаратную реализацию плавающей арифметики"
+msgstr "выключить аппаратную вещественную арифметику."
 
 #: config/s390/s390.opt:184
-#, fuzzy
-#| msgid "Set the max. number of bytes which has to be left to stack size before a trap instruction is triggered"
 msgid "Set the max. number of bytes which has to be left to stack size before a trap instruction is triggered."
-msgstr "Максимальное число байт до границы стека, при достижении которого будет выполнена команда trap"
+msgstr ""
 
 #: config/s390/s390.opt:188
 msgid "Switches off the -mstack-guard= option."
-msgstr ""
+msgstr "Выключает -mstack-guard= опцию."
 
 #: config/s390/s390.opt:192
-#, fuzzy
-#| msgid "Emit extra code in the function prologue in order to trap if the stack size exceeds the given limit"
 msgid "Emit extra code in the function prologue in order to trap if the stack size exceeds the given limit."
-msgstr "Генерировать в прологе код, обеспечивающий выполнение trap при переполнении стека"
+msgstr "Генерировать в прологе код, обеспечивающий выполнение trap при переполнении стека."
 
 #: config/s390/s390.opt:196
 msgid "Switches off the -mstack-size= option."
-msgstr ""
+msgstr "Выключает -mstack-size= опцию."
 
 #: config/s390/s390.opt:204
-#, fuzzy
-#| msgid "Generate string instructions for block moves"
 msgid "Use the mvcle instruction for block moves."
-msgstr "Генерировать строковые команды для блочных пересылок"
+msgstr "Использовать mvcle инструкцию для блочных пересылок."
 
 #: config/s390/s390.opt:208
 msgid "Enable the z vector language extension providing the context-sensitive vector macro and enable the Altivec-style builtins in vecintrin.h."
-msgstr ""
+msgstr "Включить z векторное расширение языка обеспечивая контекстно-зависимые векторные макросы и включить встроенные функции в Altivec-стиле в vecintrin.h."
 
 #: config/s390/s390.opt:213
-#, fuzzy
-#| msgid "Warn if a function uses alloca or creates an array with dynamic size"
 msgid "Warn if a function uses alloca or creates an array with dynamic size."
-msgstr "Предупреждать, если функция использует alloca или создаёт массив изменяемого размера"
+msgstr "Предупреждать, если функция использует alloca или создаёт массив изменяемого размера."
 
 #: config/s390/s390.opt:217
-#, fuzzy
-#| msgid "Warn if a single function's framesize exceeds the given framesize"
 msgid "Warn if a single function's framesize exceeds the given framesize."
-msgstr "Предупреждать, если размер окна функции превосходит заданное значение"
+msgstr "Предупреждать, если размер окна функции превосходит заданное значение."
 
 #: config/s390/s390.opt:221
-#, fuzzy
-#| msgid "z/Architecture"
 msgid "z/Architecture."
-msgstr "z/Архитектура"
+msgstr "z/Архитектура."
 
 #: config/s390/s390.opt:225
-#, fuzzy
-#| msgid "Set the branch costs for conditional branch instructions.  Reasonable values are small, non-negative integers.  The default branch cost is 0."
 msgid "Set the branch costs for conditional branch instructions.  Reasonable values are small, non-negative integers.  The default branch cost is 1."
-msgstr "Установить цены ветвлений для инструкций условного перехода.  Разумные значения небольшие, неотрицательные целые.  Подразумеваемая цена ветвления есть 0."
+msgstr ""
 
 #
 #: config/s390/s390.opt:235 config/arm/arm.opt:172
-#, fuzzy
-#| msgid "Assume arguments alias no other storage"
 msgid "Assume data segments are relative to text segment."
-msgstr "Предполагается что синонимы аргументов не требуют дополнительной памяти"
+msgstr "Предполагать, что сегменты данных заданы относительно сегмента команд."
 
 #: config/s390/s390.opt:240
 msgid "Wrap all indirect branches into execute in order to disable branch prediction."
@@ -13447,13 +11084,11 @@
 
 #: config/rl78/rl78.opt:31
 msgid "Selects the type of hardware multiplication and division to use (none/g13/g14)."
-msgstr ""
+msgstr "Выбирает используемый тип аппаратного умножения и деления (none/g13/g14)."
 
 #: config/rl78/rl78.opt:50
-#, fuzzy
-#| msgid "Specifies the number of registers to reserve for interrupt handlers."
 msgid "Use all registers, reserving none for interrupt handlers."
-msgstr "Задает число регистров резервируемых для обработчиков прерываний."
+msgstr "Использовать все регистры, ничего не резервировать для обработчиков прерываний."
 
 #: config/rl78/rl78.opt:54
 msgid "Enable assembler and linker relaxation.  Enabled by default at -Os."
@@ -13464,38 +11099,28 @@
 msgstr ""
 
 #: config/rl78/rl78.opt:77
-#, fuzzy
-#| msgid "Alias for --help=target"
 msgid "Alias for -mcpu=g10."
-msgstr "Синоним --help=target"
+msgstr "Синоним -mcpu=g10."
 
 #: config/rl78/rl78.opt:81
-#, fuzzy
-#| msgid "Alias for --help=target"
 msgid "Alias for -mcpu=g13."
-msgstr "Синоним --help=target"
+msgstr "Синоним -mcpu=g13."
 
 #: config/rl78/rl78.opt:85 config/rl78/rl78.opt:89
-#, fuzzy
-#| msgid "Alias for --help=target"
 msgid "Alias for -mcpu=g14."
-msgstr "Синоним --help=target"
+msgstr "Синоним -mcpu=g14."
 
 #: config/rl78/rl78.opt:93
 msgid "Assume ES is zero throughout program execution, use ES: for read-only data."
-msgstr ""
+msgstr "Считать ES нулевым при выполнении программы, использовать ES: для константных данных."
 
 #: config/rl78/rl78.opt:97
-#, fuzzy
-#| msgid "Specifies the number of registers to reserve for interrupt handlers."
 msgid "Stores the MDUC registers in interrupt handlers for G13 target."
-msgstr "Задает число регистров резервируемых для обработчиков прерываний."
+msgstr "Сохраняет MDUC регистры в обработчиках прерываний для целевой платформы G13."
 
 #: config/stormy16/stormy16.opt:24
-#, fuzzy
-#| msgid "Provide libraries for the simulator"
 msgid "Provide libraries for the simulator."
-msgstr "Создавать библиотеке для симулятора"
+msgstr "Создавать библиотеке для симулятора."
 
 #: config/arm/arm-tables.opt:25
 msgid "Known ARM CPUs (for use with the -mcpu= and -mtune= options):"
@@ -13514,10 +11139,8 @@
 msgstr "TLS диалект для использования:"
 
 #: config/arm/arm.opt:45
-#, fuzzy
-#| msgid "Specify an ABI"
 msgid "Specify an ABI."
-msgstr "Задать интерфейс (ABI)"
+msgstr "Задать ABI."
 
 #: config/arm/arm.opt:49
 msgid "Known ARM ABIs (for use with the -mabi= option):"
@@ -13524,22 +11147,16 @@
 msgstr "Известные ARM ABIs (для использования с -mabi= опцией):"
 
 #: config/arm/arm.opt:68
-#, fuzzy
-#| msgid "Generate a call to abort if a noreturn function returns"
 msgid "Generate a call to abort if a noreturn function returns."
-msgstr "Генерировать вызов abort, если в noreturn-функции выполняется возврат управления"
+msgstr "Генерировать вызов abort, если в noreturn-функции выполняется возврат управления."
 
 #: config/arm/arm.opt:75
-#, fuzzy
-#| msgid "Generate APCS conformant stack frames"
 msgid "Generate APCS conformant stack frames."
-msgstr "Генерировать APCS-совместимые кадры стека"
+msgstr "Генерировать APCS-совместимые кадры стека."
 
 #: config/arm/arm.opt:79
-#, fuzzy
-#| msgid "Generate re-entrant, PIC code"
 msgid "Generate re-entrant, PIC code."
-msgstr "Генерировать реентерабельный PIC-код"
+msgstr "Генерировать реентерабельный PIC-код."
 
 #: config/arm/arm.opt:95
 msgid "Generate code in 32 bit ARM state."
@@ -13546,26 +11163,20 @@
 msgstr "Генерировать код в 32-битном ARM состоянии."
 
 #: config/arm/arm.opt:103
-#, fuzzy
-#| msgid "Thumb: Assume non-static functions may be called from ARM code"
 msgid "Thumb: Assume non-static functions may be called from ARM code."
-msgstr "Thumb: считать, что нестатические функции могут быть вызваны из ARM-программ"
+msgstr "Thumb: считать, что нестатические функции могут быть вызваны из ARM-программ."
 
 #: config/arm/arm.opt:107
-#, fuzzy
-#| msgid "Thumb: Assume function pointers may go to non-Thumb aware code"
 msgid "Thumb: Assume function pointers may go to non-Thumb aware code."
-msgstr "Thumb: считать, что указатели на функции могут ссылаться на не-Thumb код"
+msgstr "Thumb: считать, что указатели на функции могут ссылаться на не-Thumb код."
 
 #: config/arm/arm.opt:115
-#, fuzzy
-#| msgid "Specify if floating point hardware should be used"
 msgid "Specify if floating point hardware should be used."
-msgstr "Использовать ли аппаратуру для вычислений с плавающей точкой"
+msgstr "Использовать ли аппаратуру для вычислений с плавающей точкой."
 
 #: config/arm/arm.opt:119
 msgid "Specify that the compiler should target secure code as per ARMv8-M Security Extensions."
-msgstr ""
+msgstr "Указать, что компилятор должен генерировать безопасный код как для ARMv8-M расширений безопасности."
 
 #: config/arm/arm.opt:123
 msgid "Known floating-point ABIs (for use with the -mfloat-abi= option):"
@@ -13572,16 +11183,12 @@
 msgstr "Известные плавающие ABIs (для использования с -mfloat-abi= опцией):"
 
 #: config/arm/arm.opt:136
-#, fuzzy
-#| msgid "Switch on/off MIPS16 ASE on alternating functions for compiler testing"
 msgid "Switch ARM/Thumb modes on alternating functions for compiler testing."
-msgstr "Включить/выключить MIPS16 ASE на альтернативных функциях для тестирования компилятора"
+msgstr "Переключить ARM/Thumb режимы на альтернативных функциях для тестирования компилятора."
 
 #: config/arm/arm.opt:140
-#, fuzzy
-#| msgid "Specify the __fp16 floating-point format"
 msgid "Specify the __fp16 floating-point format."
-msgstr "Задать __fp16 формат плавающей точки"
+msgstr "Задать __fp16 формат плавающей точки."
 
 #: config/arm/arm.opt:144
 msgid "Known __fp16 formats (for use with the -mfp16-format= option):"
@@ -13588,64 +11195,44 @@
 msgstr "Известные __fp16 форматы (для использования с -mfp16-format= опцией):"
 
 #: config/arm/arm.opt:157
-#, fuzzy
-#| msgid "Specify the name of the target floating point hardware/format"
 msgid "Specify the name of the target floating point hardware/format."
-msgstr "Задать целевую аппаратуру для плавающей точки и формат вычислений"
+msgstr "Задать целевую аппаратуру для плавающей точки и формат вычислений."
 
 #: config/arm/arm.opt:168
-#, fuzzy
-#| msgid "Generate call insns as indirect calls, if necessary"
 msgid "Generate call insns as indirect calls, if necessary."
-msgstr "Генерировать косвенные вызовы, если нужно"
+msgstr "Генерировать косвенные вызовы, если нужно."
 
 #: config/arm/arm.opt:176
-#, fuzzy
-#| msgid "Specify the register to be used for PIC addressing"
 msgid "Specify the register to be used for PIC addressing."
-msgstr "Регистр для PIC-адресации"
+msgstr "Задать регистр используемый для PIC-адресации."
 
 #: config/arm/arm.opt:180
-#, fuzzy
-#| msgid "Store function names in object code"
 msgid "Store function names in object code."
-msgstr "Сохранять имена функций в объектном коде"
+msgstr "Сохранять имена функций в объектном коде."
 
 #: config/arm/arm.opt:184
-#, fuzzy
-#| msgid "Permit scheduling of a function's prologue sequence"
 msgid "Permit scheduling of a function's prologue sequence."
-msgstr "Разрешать планирование пролога функции"
+msgstr "Разрешать планирование пролога функции."
 
 #: config/arm/arm.opt:195
-#, fuzzy
-#| msgid "Specify the minimum bit alignment of structures"
 msgid "Specify the minimum bit alignment of structures. (Deprecated)."
-msgstr "Минимальное битовое выравнивание в структурах"
+msgstr "Минимальное битовое выравнивание в структурах. (Deprecated)."
 
 #: config/arm/arm.opt:199
-#, fuzzy
-#| msgid "Generate code for Thumb state"
 msgid "Generate code for Thumb state."
-msgstr "Генерировать код для Thumb состояния"
+msgstr "Генерировать код для Thumb состояния."
 
 #: config/arm/arm.opt:203
-#, fuzzy
-#| msgid "Support calls between Thumb and ARM instruction sets"
 msgid "Support calls between Thumb and ARM instruction sets."
-msgstr "Поддерживать вызовы между Thumb и ARM системами команд"
+msgstr "Поддерживать вызовы между Thumb и ARM системами команд."
 
 #: config/arm/arm.opt:207
-#, fuzzy
-#| msgid "Specify thread local storage scheme"
 msgid "Specify thread local storage scheme."
-msgstr "Задать схему thread local памяти"
+msgstr "Задать схему thread local памяти."
 
 #: config/arm/arm.opt:211
-#, fuzzy
-#| msgid "Specify how to access the thread pointer"
 msgid "Specify how to access the thread pointer."
-msgstr "Способ доступа к указателю на нить"
+msgstr "Способ доступа к указателю на нить."
 
 #: config/arm/arm.opt:215
 msgid "Valid arguments to -mtp=:"
@@ -13652,22 +11239,16 @@
 msgstr "Корректные аргументы для -mtp=:"
 
 #: config/arm/arm.opt:228
-#, fuzzy
-#| msgid "Thumb: Generate (non-leaf) stack frames even if not needed"
 msgid "Thumb: Generate (non-leaf) stack frames even if not needed."
-msgstr "Thumb: генерировать (не листовые) кадры стека, даже если они не нужны"
+msgstr "Thumb: генерировать (не листовые) кадры стека, даже если они не нужны."
 
 #: config/arm/arm.opt:232
-#, fuzzy
-#| msgid "Thumb: Generate (leaf) stack frames even if not needed"
 msgid "Thumb: Generate (leaf) stack frames even if not needed."
-msgstr "Thumb: генерировать (листовые) кадры стека, даже если они не нужны"
+msgstr "Thumb: генерировать (листовые) кадры стека, даже если они не нужны."
 
 #: config/arm/arm.opt:236 config/mn10300/mn10300.opt:42
-#, fuzzy
-#| msgid "Tune code for the given processor"
 msgid "Tune code for the given processor."
-msgstr "Адаптировать код для указанного процессора"
+msgstr "Адаптировать код для указанного процессора."
 
 #: config/arm/arm.opt:240
 msgid "Print CPU tuning information as comment in assembler file.  This is an option used only for regression testing of the compiler and not intended for ordinary use in compiling code."
@@ -13674,16 +11255,12 @@
 msgstr ""
 
 #: config/arm/arm.opt:251
-#, fuzzy
-#| msgid "Use Neon quad-word (rather than double-word) registers for vectorization"
 msgid "Use Neon quad-word (rather than double-word) registers for vectorization."
-msgstr "Использовать четырехсловные (а не двухсловные) Neon регистры для векторизации"
+msgstr "Использовать четырехсловные (а не двухсловные) Neon регистры для векторизации."
 
 #: config/arm/arm.opt:255
-#, fuzzy
-#| msgid "Use Neon double-word (rather than quad-word) registers for vectorization"
 msgid "Use Neon double-word (rather than quad-word) registers for vectorization."
-msgstr "Использовать двухсловные (а не четырехсловные) Neon регистры для векторизации"
+msgstr "Использовать двухсловные (а не четырехсловные) Neon регистры для векторизации."
 
 #: config/arm/arm.opt:259
 msgid "Enable more verbose RTX cost dumps during debug.  For GCC developers use only."
@@ -13695,13 +11272,11 @@
 
 #: config/arm/arm.opt:267
 msgid "Generate IT blocks appropriate for ARMv8."
-msgstr ""
+msgstr "Генерировать IT блоки подходящие для ARMv8."
 
 #: config/arm/arm.opt:271
-#, fuzzy
-#| msgid "Avoid overlapping destination and address registers on LDRD instructions"
 msgid "Avoid overlapping destination and address registers on LDRD instructions that may trigger Cortex-M3 errata."
-msgstr "Избегать перекрытия целевых и адресных регистров в LDRD инструкциях"
+msgstr "Избегать перекрытия целевых и адресных регистров в LDRD инструкциях, которые могут спровоцировать Cortex-M3 ошибки."
 
 #: config/arm/arm.opt:276 config/nds32/nds32.opt:330 config/arc/arc.opt:496
 msgid "Enable unaligned word and halfword accesses to packed data."
@@ -13709,21 +11284,19 @@
 
 #: config/arm/arm.opt:280
 msgid "Use Neon to perform 64-bits operations rather than core registers."
-msgstr ""
+msgstr "Использовать Neon для выполнения 64-битных операций, а не регистры ядра."
 
 #: config/arm/arm.opt:284
 msgid "Assume loading data from flash is slower than fetching instructions."
-msgstr ""
+msgstr "Считать, что загрузка данных из флэш-памяти медленнее чем инструкции выборки."
 
 #: config/arm/arm.opt:288
 msgid "Assume unified syntax for inline assembly code."
-msgstr ""
+msgstr "Предполагать унифицированный синтаксис для вставляемого ассемблерного кода."
 
 #: config/arm/arm.opt:292
-#, fuzzy
-#| msgid "Allow branches to be packed with other instructions"
 msgid "Do not allow constant data to be placed in code sections."
-msgstr "Комбинировать условные переходы с другими инструкциями"
+msgstr "Не допускать размещение константных данных в секциях кода."
 
 #: config/arm/arm.opt:296
 msgid "When linking for big-endian targets, generate a BE8 format image."
@@ -13734,181 +11307,125 @@
 msgstr ""
 
 #: config/arm/arm.opt:304 config/sh/sh.opt:195
-#, fuzzy
-#| msgid "Cost to assume for a branch insn"
 msgid "Cost to assume for a branch insn."
-msgstr "Предполагаемая цена для инструкции ветвления"
+msgstr "Предполагаемая цена для инструкции ветвления."
 
 #: config/sparc/sparc.opt:30 config/sparc/sparc.opt:34
 #: config/visium/visium.opt:37
-#, fuzzy
-#| msgid "Use hardware FP"
 msgid "Use hardware FP."
-msgstr "Использовать аппаратную вещественную арифметику"
+msgstr "Использовать аппаратную вещественную арифметику."
 
 #: config/sparc/sparc.opt:38 config/visium/visium.opt:41
-#, fuzzy
-#| msgid "Do not use hardware FP"
 msgid "Do not use hardware FP."
-msgstr "Не использовать аппаратную вещественную арифметику"
+msgstr "Не использовать аппаратную вещественную арифметику."
 
 #: config/sparc/sparc.opt:42
-#, fuzzy
-#| msgid "Use flat register window model"
 msgid "Use flat register window model."
-msgstr "Использовать плоскую модель регистрового окна"
+msgstr "Использовать плоскую модель регистрового окна."
 
 #: config/sparc/sparc.opt:46
-#, fuzzy
-#| msgid "Assume possible double misalignment"
 msgid "Assume possible double misalignment."
-msgstr "Предполагать, что значения double могут быть невыровненными"
+msgstr "Предполагать, что значения double могут быть невыровненными."
 
 #: config/sparc/sparc.opt:50
-#, fuzzy
-#| msgid "Use ABI reserved registers"
 msgid "Use ABI reserved registers."
-msgstr "Использовать зарезервированные регистры ABI"
+msgstr "Использовать ABI-зарезервированные регистры."
 
 #: config/sparc/sparc.opt:54
-#, fuzzy
-#| msgid "Use hardware quad FP instructions"
 msgid "Use hardware quad FP instructions."
-msgstr "Использовать аппаратные средства quad-плавающей арифметики"
+msgstr "Использовать аппаратные средства quad-плавающей арифметики."
 
 #: config/sparc/sparc.opt:58
-#, fuzzy
-#| msgid "Do not use hardware quad fp instructions"
 msgid "Do not use hardware quad fp instructions."
-msgstr "Не использовать аппаратные средства quad-плавающей арифметики"
+msgstr "Не использовать аппаратные средства quad-плавающей арифметики."
 
 #: config/sparc/sparc.opt:66
-#, fuzzy
-#| msgid "Compile for V8+ ABI"
 msgid "Compile for V8+ ABI."
-msgstr "Использовать ABI для V8+"
+msgstr "Использовать ABI для V8+."
 
 #: config/sparc/sparc.opt:70
-#, fuzzy
-#| msgid "Use UltraSPARC Visual Instruction Set version 1.0 extensions"
 msgid "Use UltraSPARC Visual Instruction Set version 1.0 extensions."
-msgstr "Использовать расширения UltraSPARC Visual Instruction Set version 1.0"
+msgstr "Использовать UltraSPARC Visual Instruction Set version 1.0 расширения."
 
 #: config/sparc/sparc.opt:74
-#, fuzzy
-#| msgid "Use UltraSPARC Visual Instruction Set version 2.0 extensions"
 msgid "Use UltraSPARC Visual Instruction Set version 2.0 extensions."
-msgstr "Использовать расширения UltraSPARC Visual Instruction Set version 2.0"
+msgstr "Использовать UltraSPARC Visual Instruction Set version 2.0 расширения."
 
 #: config/sparc/sparc.opt:78
-#, fuzzy
-#| msgid "Use UltraSPARC Visual Instruction Set version 3.0 extensions"
 msgid "Use UltraSPARC Visual Instruction Set version 3.0 extensions."
-msgstr "Использовать расширения UltraSPARC Visual Instruction Set version 3.0"
+msgstr "Использовать UltraSPARC Visual Instruction Set version 3.0 расширения."
 
 #: config/sparc/sparc.opt:82
-#, fuzzy
-#| msgid "Use UltraSPARC Visual Instruction Set version 1.0 extensions"
 msgid "Use UltraSPARC Visual Instruction Set version 4.0 extensions."
-msgstr "Использовать расширения UltraSPARC Visual Instruction Set version 1.0"
+msgstr "Использовать UltraSPARC Visual Instruction Set version 4.0 расширения."
 
 #: config/sparc/sparc.opt:86
 msgid "Use additional VIS instructions introduced in OSA2017."
-msgstr ""
+msgstr "Использовать дополнительные VIS инструкции введенные в OSA2017."
 
 #: config/sparc/sparc.opt:90
-#, fuzzy
-#| msgid "Use UltraSPARC Fused Multiply-Add extensions"
 msgid "Use UltraSPARC Compare-and-Branch extensions."
-msgstr "Использовать расширения UltraSPARC Fused Multiply-Add "
+msgstr "Использовать UltraSPARC Compare-and-Branch расширения."
 
 #: config/sparc/sparc.opt:94
-#, fuzzy
-#| msgid "Use UltraSPARC Fused Multiply-Add extensions"
 msgid "Use UltraSPARC Fused Multiply-Add extensions."
-msgstr "Использовать расширения UltraSPARC Fused Multiply-Add "
+msgstr "Использовать UltraSPARC Fused Multiply-Add расширения."
 
 #: config/sparc/sparc.opt:98
-#, fuzzy
-#| msgid "Generate floating-point multiply-add instructions"
 msgid "Use Floating-point Multiply Single to Double (FsMULd) instruction."
-msgstr "Генерировать плавающие команды умножения с накоплением"
+msgstr "Использовать Floating-point Multiply Single to Double (FsMULd) инструкцию."
 
 #: config/sparc/sparc.opt:102
-#, fuzzy
-#| msgid "Use UltraSPARC Population-Count instruction"
 msgid "Use UltraSPARC Population-Count instruction."
-msgstr "Использовать инструкцию UltraSPARC Population-Count"
+msgstr "Использовать UltraSPARC Population-Count инструкцию."
 
 #: config/sparc/sparc.opt:106
-#, fuzzy
-#| msgid "Use UltraSPARC Population-Count instruction"
 msgid "Use UltraSPARC Subtract-Extended-with-Carry instruction."
-msgstr "Использовать инструкцию UltraSPARC Population-Count"
+msgstr "Использовать UltraSPARC Subtract-Extended-with-Carry инструкцию."
 
 #: config/sparc/sparc.opt:110
-#, fuzzy
-#| msgid "Pointers are 64-bit"
 msgid "Pointers are 64-bit."
-msgstr "Генерировать код с 64-битными указателями"
+msgstr "Указатели 64-битные."
 
 #: config/sparc/sparc.opt:114
-#, fuzzy
-#| msgid "Pointers are 32-bit"
 msgid "Pointers are 32-bit."
-msgstr "Генерировать код с 32-битными указателями"
+msgstr "Указатели 32-битные."
 
 #: config/sparc/sparc.opt:118
-#, fuzzy
-#| msgid "Use 64-bit ABI"
 msgid "Use 64-bit ABI."
-msgstr "Использовать 64-битный ABI"
+msgstr "Использовать 64-битный ABI."
 
 #: config/sparc/sparc.opt:122
-#, fuzzy
-#| msgid "Use 32-bit ABI"
 msgid "Use 32-bit ABI."
-msgstr "Использовать 32-битный ABI"
+msgstr "Использовать 32-битный ABI."
 
 #: config/sparc/sparc.opt:126
-#, fuzzy
-#| msgid "Use stack bias"
 msgid "Use stack bias."
-msgstr "Использовать смещение в стеке"
+msgstr "Использовать смещение в стеке."
 
 #: config/sparc/sparc.opt:130
-#, fuzzy
-#| msgid "Use structs on stronger alignment for double-word copies"
 msgid "Use structs on stronger alignment for double-word copies."
-msgstr "Использовать более строгое выравнивание структур для копирования двойными словами"
+msgstr "Использовать более строгое выравнивание структур для копирования двойными словами."
 
 #: config/sparc/sparc.opt:134
-#, fuzzy
-#| msgid "Optimize tail call instructions in assembler and linker"
 msgid "Optimize tail call instructions in assembler and linker."
-msgstr "Оптимизировать хвостовые команды вызова в ассемблере и компоновщике"
+msgstr "Оптимизировать хвостовые команды вызова в ассемблере и компоновщике."
 
 #: config/sparc/sparc.opt:138
 msgid "Do not generate code that can only run in supervisor mode (default)."
-msgstr ""
+msgstr "Не генерировать код, который может выполняться только в режиме супервизора (подразумевается)."
 
 #: config/sparc/sparc.opt:142 config/visium/visium.opt:45
-#, fuzzy
-#| msgid "Use features of and schedule code for given CPU"
 msgid "Use features of and schedule code for given CPU."
-msgstr "Использовать свойства указанного процессора и планировать код для него"
+msgstr "Использовать свойства указанного процессора и планировать код для него."
 
 #: config/sparc/sparc.opt:225
-#, fuzzy
-#| msgid "Use given SPARC-V9 code model"
 msgid "Use given SPARC-V9 code model."
-msgstr "Использовать указанную модель кодирования SPARC-V9"
+msgstr "Использовать указанную модель кодирования SPARC-V9."
 
 #: config/sparc/sparc.opt:229
-#, fuzzy
-#| msgid "Enable debug output"
 msgid "Enable debug output."
-msgstr "Включить отладочную выдачу"
+msgstr "Включить отладочную выдачу."
 
 #: config/sparc/sparc.opt:233
 msgid "Enable strict 32-bit psABI struct return checking."
@@ -13915,28 +11432,20 @@
 msgstr "Включить строгую проверку возврата структуры 32-битного psABI"
 
 #: config/sparc/sparc.opt:237
-#, fuzzy
-#| msgid "Enable workaround for single erratum of AT697F processor"
 msgid "Enable workaround for single erratum of AT697F processor (corresponding to erratum #13 of AT697E processor)."
-msgstr "Включить обход для single erratum AT697F процессора"
+msgstr "Включить обход для single erratum AT697F процессора (соответствует erratum #13 AT697E процессора)."
 
 #: config/sparc/sparc.opt:242
-#, fuzzy
-#| msgid "Enable workaround for single erratum of AT697F processor"
 msgid "Enable workarounds for the errata of the UT699 processor."
-msgstr "Включить обход для single erratum AT697F процессора"
+msgstr "Включить обходы для single errata UT699 процессора."
 
 #: config/sparc/sparc.opt:246
-#, fuzzy
-#| msgid "Enable workaround for single erratum of AT697F processor"
 msgid "Enable workarounds for the errata of the UT699E/UT700 processor."
-msgstr "Включить обход для single erratum AT697F процессора"
+msgstr "Включить обходы для single errata UT699E/UT700 процессора."
 
 #: config/sparc/sparc.opt:250
-#, fuzzy
-#| msgid "Enable workaround for single erratum of AT697F processor"
 msgid "Enable workarounds for the errata of the GR712RC processor."
-msgstr "Включить обход для single erratum AT697F процессора"
+msgstr "Включить обходы для errata GR712RC процессора."
 
 #: config/sparc/sparc.opt:287
 msgid "Specify the memory model in effect for the program."
@@ -13943,28 +11452,20 @@
 msgstr "Задать действующую модель памяти для программы."
 
 #: config/rs6000/rs6000.opt:165
-#, fuzzy
-#| msgid "Enable tail merging on trees"
 msgid "Enable early gimple folding of builtins."
-msgstr "Включить слияние хвостов в древовидном представлении"
+msgstr ""
 
 #: config/rs6000/rs6000.opt:188
-#, fuzzy
-#| msgid "%qE is deprecated"
 msgid "%<-mstring%> is deprecated"
-msgstr "имя %qE будет исключено в будущих версиях"
+msgstr ""
 
 #: config/rs6000/rs6000.opt:325
-#, fuzzy
-#| msgid "%<-mcpu=%> is deprecated; use %<-mtune=%> or %<-march=%> instead"
 msgid "%<-mvrsave=no%> is deprecated; use %<-mno-vrsave%> instead"
-msgstr "ключ %<-mcpu=%> устарел; используйте %<-mtune=%> или %<-march=%>"
+msgstr ""
 
 #: config/rs6000/rs6000.opt:329
-#, fuzzy
-#| msgid "%<-mfused-madd%> is deprecated; use %<-ffp-contract=%> instead"
 msgid "%<-mvrsave=yes%> is deprecated; use %<-mvrsave%> instead"
-msgstr "Ключ %<-mfused-madd%> устарел; используйте %<-ffp-contract=%>."
+msgstr ""
 
 #: config/rs6000/rs6000.opt:334
 msgid "Max number of bytes to move inline."
@@ -13971,67 +11472,48 @@
 msgstr ""
 
 #: config/rs6000/rs6000.opt:338
-#, fuzzy
-#| msgid "The maximum number of insns of an unswitched loop"
 msgid "Max number of bytes to compare without loops."
-msgstr "Максимальное число инструкций в разомкнутом (unswitched) цикле"
+msgstr ""
 
 #: config/rs6000/rs6000.opt:342
-#, fuzzy
-#| msgid "The maximum number of insns of an unswitched loop"
 msgid "Max number of bytes to compare with loops."
-msgstr "Максимальное число инструкций в разомкнутом (unswitched) цикле"
+msgstr ""
 
 #: config/rs6000/rs6000.opt:346
-#, fuzzy
-#| msgid "The maximum number of peelings of a single loop"
 msgid "Max number of pairs of load insns for compare."
-msgstr "Максимальный коэффициент раскатки цикла"
+msgstr ""
 
 #: config/rs6000/rs6000.opt:353
-#, fuzzy
-#| msgid "%<-mcpu=%> is deprecated; use %<-mtune=%> or %<-march=%> instead"
 msgid "%<-misel=no%> is deprecated; use %<-mno-isel%> instead"
-msgstr "ключ %<-mcpu=%> устарел; используйте %<-mtune=%> или %<-march=%>"
+msgstr ""
 
 #: config/rs6000/rs6000.opt:357
-#, fuzzy
-#| msgid "%<-mcpu=%> is deprecated; use %<-mtune=%> or %<-march=%> instead"
 msgid "%<-misel=yes%> is deprecated; use %<-misel%> instead"
-msgstr "ключ %<-mcpu=%> устарел; используйте %<-mtune=%> или %<-march=%>"
+msgstr ""
 
 #: config/rs6000/rs6000.opt:410
-#, fuzzy
-#| msgid "-mtraceback=\tSelect full, part, or no traceback table"
 msgid "-mtraceback=[full,part,no]\tSelect type of traceback table."
-msgstr "-mtraceback=\tВывод traceback-таблицы: full (полная), part (частичная), no (не выводить таблицу)"
+msgstr ""
 
 #: config/rs6000/rs6000.opt:438
-#, fuzzy
-#| msgid "-mlong-double-<n>\tSpecify size of long double (64 or 128 bits)"
 msgid "-mlong-double-[64,128]\tSpecify size of long double."
-msgstr "-mlong-double-<n>\tЗадать размер long double (64 или 128 бит)"
+msgstr ""
 
 #: config/rs6000/rs6000.opt:537 config/arc/arc.opt:173 config/arc/arc.opt:339
 #: config/arc/arc.opt:346 config/arc/arc.opt:350 config/arc/arc.opt:354
 #: config/arc/arc.opt:358 config/arc/arc.opt:361 config/arc/arc.opt:364
 #: config/arc/arc.opt:381
-#, fuzzy, c-format
-#| msgid "%qE is deprecated"
+#, c-format
 msgid "%qs is deprecated"
-msgstr "имя %qE будет исключено в будущих версиях"
+msgstr "%qs устарело"
 
 #: config/rs6000/sysv4.opt:24
-#, fuzzy
-#| msgid "Select ABI calling convention"
 msgid "-mcall-ABI\tSelect ABI calling convention."
-msgstr "Использовать соглашения о вызовах для ABI"
+msgstr ""
 
 #: config/rs6000/sysv4.opt:28
-#, fuzzy
-#| msgid "Select method for sdata handling"
 msgid "-msdata=[none,data,sysv,eabi]\tSelect method for sdata handling."
-msgstr "Метод обработки sdata"
+msgstr ""
 
 #: config/rs6000/sysv4.opt:32
 msgid "Allow readonly data in sdata."
@@ -14038,154 +11520,104 @@
 msgstr ""
 
 #: config/rs6000/sysv4.opt:36
-#, fuzzy
-#| msgid "Specify bit size of immediate TLS offsets"
 msgid "-mtls-size=[16,32]\tSpecify bit size of immediate TLS offsets."
-msgstr "Битовый размер смещений для непосредственных TLS"
+msgstr ""
 
 #: config/alpha/alpha.opt:27
-#, fuzzy
-#| msgid "Use fp registers"
 msgid "Use fp registers."
-msgstr "Использовать плавающие регистры"
+msgstr "Использовать fp регистры."
 
 #: config/alpha/alpha.opt:35
-#, fuzzy
-#| msgid "Request IEEE-conformant math library routines (OSF/1)"
 msgid "Request IEEE-conformant math library routines (OSF/1)."
-msgstr "Требовать IEEE-совместимую библиотеку математических подпрограмм (OSF/1)"
+msgstr "Требовать IEEE-совместимую библиотеку математических подпрограмм (OSF/1)."
 
 #: config/alpha/alpha.opt:39
-#, fuzzy
-#| msgid "Emit IEEE-conformant code, without inexact exceptions"
 msgid "Emit IEEE-conformant code, without inexact exceptions."
-msgstr "Генерировать IEEE-совместимый код без искл. ситуаций inexact"
+msgstr "Порождать IEEE-совместимый код без inexact исключительных ситуаций."
 
 #: config/alpha/alpha.opt:46
-#, fuzzy
-#| msgid "Do not emit complex integer constants to read-only memory"
 msgid "Do not emit complex integer constants to read-only memory."
-msgstr "Не размещать целые комплексные константы в read-only-памяти"
+msgstr "Не помещать комплексные целые константы в read-only-память."
 
 #: config/alpha/alpha.opt:50
-#, fuzzy
-#| msgid "Use VAX fp"
 msgid "Use VAX fp."
-msgstr "Использовать плавающую арифметику VAX"
+msgstr "Использовать VAX fp."
 
 #: config/alpha/alpha.opt:54
-#, fuzzy
-#| msgid "Do not use VAX fp"
 msgid "Do not use VAX fp."
-msgstr "Не использовать плавающую арифметику VAX"
+msgstr "Не использовать VAX fp."
 
 #: config/alpha/alpha.opt:58
-#, fuzzy
-#| msgid "Emit code for the byte/word ISA extension"
 msgid "Emit code for the byte/word ISA extension."
-msgstr "Генерировать код для ISA расширения byte/word"
+msgstr "Порождать код для byte/word ISA расширения."
 
 #: config/alpha/alpha.opt:62
-#, fuzzy
-#| msgid "Emit code for the motion video ISA extension"
 msgid "Emit code for the motion video ISA extension."
-msgstr "Генерировать код для ISA-расширения motion video"
+msgstr "Порождать код для расширения ISA motion video."
 
 #: config/alpha/alpha.opt:66
-#, fuzzy
-#| msgid "Emit code for the fp move and sqrt ISA extension"
 msgid "Emit code for the fp move and sqrt ISA extension."
-msgstr "Генерировать код для ISA-расширения fp move и sqrt"
+msgstr "Порождать код для расширения ISA fp move and sqrt."
 
 #: config/alpha/alpha.opt:70
-#, fuzzy
-#| msgid "Emit code for the counting ISA extension"
 msgid "Emit code for the counting ISA extension."
-msgstr "Генерировать код для ISA-расширения counting"
+msgstr "Порождать код для расширения ISA counting."
 
 #: config/alpha/alpha.opt:74
-#, fuzzy
-#| msgid "Emit code using explicit relocation directives"
 msgid "Emit code using explicit relocation directives."
-msgstr "Генерировать код с явными директивами перемещения"
+msgstr "Порождать код, использующий явные директивы настройки."
 
 #: config/alpha/alpha.opt:78
-#, fuzzy
-#| msgid "Emit 16-bit relocations to the small data areas"
 msgid "Emit 16-bit relocations to the small data areas."
-msgstr "Генерировать 16-битные перемещения в области малых данных"
+msgstr "Порождать 16-битные настройки для областей малых данных."
 
 #: config/alpha/alpha.opt:82
-#, fuzzy
-#| msgid "Emit 32-bit relocations to the small data areas"
 msgid "Emit 32-bit relocations to the small data areas."
-msgstr "Генерировать 32-битные перемещения в области малых данных"
+msgstr "Порождать 32-битные настройки для областей малых данных."
 
 #: config/alpha/alpha.opt:86
-#, fuzzy
-#| msgid "Emit direct branches to local functions"
 msgid "Emit direct branches to local functions."
-msgstr "Генерировать непосредственные переходы в локальные функции"
+msgstr "Порождать прямые переходы на локальные функции."
 
 #: config/alpha/alpha.opt:90
-#, fuzzy
-#| msgid "Emit indirect branches to local functions"
 msgid "Emit indirect branches to local functions."
-msgstr "Генерировать косвенные переходы в локальные функции"
+msgstr "Порождать косвенные переходы на локальные функции."
 
 #: config/alpha/alpha.opt:94
-#, fuzzy
-#| msgid "Emit rdval instead of rduniq for thread pointer"
 msgid "Emit rdval instead of rduniq for thread pointer."
-msgstr "Генерировать rdval вместо rduniq для указателя потока"
+msgstr "Порождать rdval вместо rduniq для указателя потока."
 
 #: config/alpha/alpha.opt:106
-#, fuzzy
-#| msgid "Use features of and schedule given CPU"
 msgid "Use features of and schedule given CPU."
-msgstr "Использовать свойства указанного процессора и планировать код для него"
+msgstr "Использовать свойства указанного процессора и планировать код для него."
 
 #: config/alpha/alpha.opt:110
-#, fuzzy
-#| msgid "Schedule given CPU"
 msgid "Schedule given CPU."
-msgstr "Планировать код для указанного процессора"
+msgstr "Планировать код для указанного процессора."
 
 #: config/alpha/alpha.opt:114
-#, fuzzy
-#| msgid "Control the generated fp rounding mode"
 msgid "Control the generated fp rounding mode."
-msgstr "Выбрать режим округления"
+msgstr "Выбрать fp режим округления."
 
 #: config/alpha/alpha.opt:118
-#, fuzzy
-#| msgid "Control the IEEE trap mode"
 msgid "Control the IEEE trap mode."
-msgstr "Выбрать режим прерываний IEEE"
+msgstr "Выбрать IEEE trap режим."
 
 #: config/alpha/alpha.opt:122
-#, fuzzy
-#| msgid "Control the precision given to fp exceptions"
 msgid "Control the precision given to fp exceptions."
-msgstr "Выбрать точность локализации плавающих прерываний"
+msgstr "Выбрать точность передающуюся в fp исключительные ситуации."
 
 #: config/alpha/alpha.opt:126
-#, fuzzy
-#| msgid "Tune expected memory latency"
 msgid "Tune expected memory latency."
-msgstr "Задать уточненную информацию о латентности памяти"
+msgstr "Настроить ожидаемую латентность памяти."
 
 #: config/tilepro/tilepro.opt:23
-#, fuzzy
-#| msgid "Compile with 32 bit longs and pointers, which is the only supported"
 msgid "Compile with 32 bit longs and pointers, which is the only supported behavior and thus the flag is ignored."
-msgstr "Компилировать с 32-битными длинными и указателями, которые только и поддерживаются"
+msgstr "Компилировать с 32-битными длинными и указателями, что является единственным поддерживаемым поведением и поэтому флаг игнорируется."
 
 #: config/tilepro/tilepro.opt:28 config/tilegx/tilegx.opt:26
-#, fuzzy
-#| msgid "-mcpu=CPU\tUse features of and schedule code for given CPU"
 msgid "-mcpu=CPU\tUse features of and schedule code for given CPU."
-msgstr "-mcpu=CPU\tИспользовать возможности и планировать код для заданного CPU"
+msgstr "-mcpu=CPU\tИспользовать возможности и планировать код для заданного CPU."
 
 #: config/tilepro/tilepro.opt:32
 msgid "Known TILEPro CPUs (for use with the -mcpu= option):"
@@ -14192,720 +11624,574 @@
 msgstr "Известные TILEPro CPUs (для использования с -mcpu= опцией):"
 
 #: config/lm32/lm32.opt:24
-#, fuzzy
-#| msgid "Enable multiply instructions"
 msgid "Enable multiply instructions."
-msgstr "Включить инструкции умножения"
+msgstr "Включить инструкции умножения."
 
 #: config/lm32/lm32.opt:28
-#, fuzzy
-#| msgid "Enable divide and modulus instructions"
 msgid "Enable divide and modulus instructions."
-msgstr "Включить инструкции деления и деления с остатком"
+msgstr "Включить инструкции деления и деления с остатком."
 
 #: config/lm32/lm32.opt:32
-#, fuzzy
-#| msgid "Enable barrel shift instructions"
 msgid "Enable barrel shift instructions."
-msgstr "Включить инструкции циклического сдвига"
+msgstr "Включить инструкции циклического сдвига."
 
 #: config/lm32/lm32.opt:36
-#, fuzzy
-#| msgid "Enable sign extend instructions"
 msgid "Enable sign extend instructions."
-msgstr "Включить инструкции размножения знака"
+msgstr "Включить инструкции размножения знака."
 
 #: config/lm32/lm32.opt:40
-#, fuzzy
-#| msgid "Enable user-defined instructions"
 msgid "Enable user-defined instructions."
-msgstr "Включить определяемые пользователем инструкции"
+msgstr "Включить определяемые пользователем инструкции."
 
 #: config/nios2/elf.opt:26
-#, fuzzy
-#| msgid "Link with the fast floating-point library"
 msgid "Link with a limited version of the C library."
-msgstr "Компоновать с библиотекой быстрой плавающей арифметики"
+msgstr "Компоновать с ограниченной версией C-библиотеки."
 
 #: config/nios2/elf.opt:30
 msgid "Name of system library to link against."
-msgstr ""
+msgstr "Имя системной библиотеки для компоновки."
 
 #: config/nios2/elf.opt:34
 msgid "Name of the startfile."
-msgstr ""
+msgstr "Имя стартового файла."
 
 #: config/nios2/elf.opt:38
 msgid "Link with HAL BSP."
-msgstr ""
+msgstr "Компоновать с HAL BSP."
 
 #: config/nios2/nios2.opt:35
 msgid "Enable DIV, DIVU."
-msgstr ""
+msgstr "Включить DIV, DIVU."
 
 #: config/nios2/nios2.opt:39
-#, fuzzy
-#| msgid "Enable clip instructions"
 msgid "Enable MUL instructions."
-msgstr "Включить clip инструкции"
+msgstr "Включить MUL инструкции"
 
 #: config/nios2/nios2.opt:43
 msgid "Enable MULX instructions, assume fast shifter."
-msgstr ""
+msgstr "Включить MULX инструкции, предполагая быстрый сдвиг."
 
 #: config/nios2/nios2.opt:47
-#, fuzzy
-#| msgid "Use the software emulation for divides (default)"
 msgid "Use table based fast divide (default at -O3)."
-msgstr "Использовать программную эмуляцию для делений (умолчание)"
+msgstr "Использовать основанное на таблицах быстрое деление (умолчание в -O3)."
 
 #: config/nios2/nios2.opt:51
-#, fuzzy
-#| msgid "Enable unaligned load/store instruction"
 msgid "All memory accesses use I/O load/store instructions."
-msgstr "Включить инструкции невыровненной загрузки/сохранения"
+msgstr "Все доступы к памяти используют I/O инструкции загрузки/сохранения."
 
 #: config/nios2/nios2.opt:55
-#, fuzzy
-#| msgid "Enable unaligned load/store instruction"
 msgid "Volatile memory accesses use I/O load/store instructions."
-msgstr "Включить инструкции невыровненной загрузки/сохранения"
+msgstr "Доступы к волатильной памяти используют I/O инструкции загрузки/сохранения."
 
 #: config/nios2/nios2.opt:59
 msgid "Volatile memory accesses do not use I/O load/store instructions."
-msgstr ""
+msgstr "Доступ к волатильной памяти не использует I/O load/store инструкции."
 
 #: config/nios2/nios2.opt:63
-#, fuzzy
-#| msgid "unusual TP-relative address"
 msgid "Enable/disable GP-relative addressing."
-msgstr "необычный адрес относительно TP"
+msgstr "Включить/выключить адресацию относительно GP."
 
 #: config/nios2/nios2.opt:67
 msgid "Valid options for GP-relative addressing (for -mgpopt):"
-msgstr ""
+msgstr "Допустимые ключи для GP-относительной адресации (для -mgpopt):"
 
 #: config/nios2/nios2.opt:86
 msgid "Equivalent to -mgpopt=local."
-msgstr ""
+msgstr "Эквивалент -mgpopt=local."
 
 #: config/nios2/nios2.opt:90
 msgid "Equivalent to -mgpopt=none."
-msgstr ""
+msgstr "Эквивалент -mgpopt=none."
 
 #: config/nios2/nios2.opt:94 config/c6x/c6x.opt:30 config/mips/mips.opt:134
 #: config/tilegx/tilegx.opt:45
-#, fuzzy
-#| msgid "Use big-endian byte order"
 msgid "Use big-endian byte order."
-msgstr "Использовать прямой (big-endian) порядок байт "
+msgstr "Использовать прямой (big-endian) порядок байт."
 
 #: config/nios2/nios2.opt:98 config/c6x/c6x.opt:34 config/mips/mips.opt:138
 #: config/tilegx/tilegx.opt:49
-#, fuzzy
-#| msgid "Use little-endian byte order"
 msgid "Use little-endian byte order."
-msgstr "Использовать обратный (little-endian) порядок байт"
+msgstr "Использовать обратный (little-endian) порядок байт."
 
 #: config/nios2/nios2.opt:102
 msgid "Floating point custom instruction configuration name."
-msgstr ""
+msgstr "Имя специализированной конфигурации инструкций вещественной арифметики."
 
 #: config/nios2/nios2.opt:106
-#, fuzzy
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the ftruncds custom instruction."
-msgstr "Не использовать команды callt"
+msgstr "Не использовать ftruncds специализированную инструкцию."
 
 #: config/nios2/nios2.opt:110
 msgid "Integer id (N) of ftruncds custom instruction."
-msgstr ""
+msgstr "Целый идентификатор (N) ftruncds специализированной инструкции."
 
 #: config/nios2/nios2.opt:114
-#, fuzzy
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fextsd custom instruction."
-msgstr "Не использовать команды callt"
+msgstr "Не использовать fextsd специализированную инструкцию."
 
 #: config/nios2/nios2.opt:118
 msgid "Integer id (N) of fextsd custom instruction."
-msgstr ""
+msgstr "Целый идентификатор (N) fextsd специализированной инструкции."
 
 #: config/nios2/nios2.opt:122
-#, fuzzy
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fixdu custom instruction."
-msgstr "Не использовать команды callt"
+msgstr "Не использовать fixdu специализированную инструкцию."
 
 #: config/nios2/nios2.opt:126
 msgid "Integer id (N) of fixdu custom instruction."
-msgstr ""
+msgstr "Целый идентификатор (N) fixdu специализированной инструкции."
 
 #: config/nios2/nios2.opt:130
-#, fuzzy
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fixdi custom instruction."
-msgstr "Не использовать команды callt"
+msgstr "Не использовать fixdi специализированную инструкцию."
 
 #: config/nios2/nios2.opt:134
 msgid "Integer id (N) of fixdi custom instruction."
-msgstr ""
+msgstr "Целый идентификатор (N) fixdi специализированной инструкции."
 
 #: config/nios2/nios2.opt:138
-#, fuzzy
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fixsu custom instruction."
-msgstr "Не использовать команды callt"
+msgstr "Не использовать fixsu специализированную инструкцию."
 
 #: config/nios2/nios2.opt:142
 msgid "Integer id (N) of fixsu custom instruction."
-msgstr ""
+msgstr "Целый идентификатор (N) fixsu специализированной инструкции."
 
 #: config/nios2/nios2.opt:146
-#, fuzzy
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fixsi custom instruction."
-msgstr "Не использовать команды callt"
+msgstr "Не использовать fixsi специализированную инструкцию."
 
 #: config/nios2/nios2.opt:150
 msgid "Integer id (N) of fixsi custom instruction."
-msgstr ""
+msgstr "Целый идентификатор (N) fixsi специализированной инструкции."
 
 #: config/nios2/nios2.opt:154
-#, fuzzy
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the floatud custom instruction."
-msgstr "Не использовать команды callt"
+msgstr "Не использовать floatud специализированную инструкцию."
 
 #: config/nios2/nios2.opt:158
 msgid "Integer id (N) of floatud custom instruction."
-msgstr ""
+msgstr "Целый идентификатор (N) floatud специализированной инструкции."
 
 #: config/nios2/nios2.opt:162
-#, fuzzy
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the floatid custom instruction."
-msgstr "Не использовать команды callt"
+msgstr "Не использовать floatid специализированную инструкцию."
 
 #: config/nios2/nios2.opt:166
 msgid "Integer id (N) of floatid custom instruction."
-msgstr ""
+msgstr "Целый идентификатор (N) floatid специализированной инструкции."
 
 #: config/nios2/nios2.opt:170
-#, fuzzy
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the floatus custom instruction."
-msgstr "Не использовать команды callt"
+msgstr "Не использовать floatus специализированную инструкцию."
 
 #: config/nios2/nios2.opt:174
 msgid "Integer id (N) of floatus custom instruction."
-msgstr ""
+msgstr "Целый идентификатор (N) floatus специализированной инструкции."
 
 #: config/nios2/nios2.opt:178
-#, fuzzy
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the floatis custom instruction."
-msgstr "Не использовать команды callt"
+msgstr "Не использовать floatis специализированную инструкцию."
 
 #: config/nios2/nios2.opt:182
 msgid "Integer id (N) of floatis custom instruction."
-msgstr ""
+msgstr "Целый идентификатор (N) floatis специализированной инструкции."
 
 #: config/nios2/nios2.opt:186
-#, fuzzy
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fcmpned custom instruction."
-msgstr "Не использовать команды callt"
+msgstr "Не использовать fcmpned специализированную инструкцию."
 
 #: config/nios2/nios2.opt:190
 msgid "Integer id (N) of fcmpned custom instruction."
-msgstr ""
+msgstr "Целый идентификатор (N) fcmpned специализированной инструкции."
 
 #: config/nios2/nios2.opt:194
-#, fuzzy
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fcmpeqd custom instruction."
-msgstr "Не использовать команды callt"
+msgstr "Не использовать fcmpeqd специализированную инструкцию."
 
 #: config/nios2/nios2.opt:198
 msgid "Integer id (N) of fcmpeqd custom instruction."
-msgstr ""
+msgstr "Целый идентификатор (N) fcmpeqd специализированной инструкции."
 
 #: config/nios2/nios2.opt:202
-#, fuzzy
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fcmpged custom instruction."
-msgstr "Не использовать команды callt"
+msgstr "Не использовать fcmpged специализированную инструкцию."
 
 #: config/nios2/nios2.opt:206
 msgid "Integer id (N) of fcmpged custom instruction."
-msgstr ""
+msgstr "Целый идентификатор (N) fcmpged специализированной инструкции."
 
 #: config/nios2/nios2.opt:210
-#, fuzzy
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fcmpgtd custom instruction."
-msgstr "Не использовать команды callt"
+msgstr "Не использовать fcmpgtd специализированную инструкцию."
 
 #: config/nios2/nios2.opt:214
 msgid "Integer id (N) of fcmpgtd custom instruction."
-msgstr ""
+msgstr "Целый идентификатор (N) fcmpgtd специализированной инструкции."
 
 #: config/nios2/nios2.opt:218
-#, fuzzy
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fcmpled custom instruction."
-msgstr "Не использовать команды callt"
+msgstr "Не использовать fcmpled специализированную инструкцию."
 
 #: config/nios2/nios2.opt:222
 msgid "Integer id (N) of fcmpled custom instruction."
-msgstr ""
+msgstr "Целый идентификатор (N) fcmpled специализированной инструкции."
 
 #: config/nios2/nios2.opt:226
-#, fuzzy
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fcmpltd custom instruction."
-msgstr "Не использовать команды callt"
+msgstr "Не использовать fcmpltd специализированную инструкцию."
 
 #: config/nios2/nios2.opt:230
 msgid "Integer id (N) of fcmpltd custom instruction."
-msgstr ""
+msgstr "Целый идентификатор (N) fcmpltd специализированной инструкции."
 
 #: config/nios2/nios2.opt:234
-#, fuzzy
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the flogd custom instruction."
-msgstr "Не использовать команды callt"
+msgstr "Не использовать flogd специализированную инструкцию."
 
 #: config/nios2/nios2.opt:238
 msgid "Integer id (N) of flogd custom instruction."
-msgstr ""
+msgstr "Целый идентификатор (N) flogd специализированной инструкции."
 
 #: config/nios2/nios2.opt:242
-#, fuzzy
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fexpd custom instruction."
-msgstr "Не использовать команды callt"
+msgstr "Не использовать fexpd специализированную инструкцию."
 
 #: config/nios2/nios2.opt:246
 msgid "Integer id (N) of fexpd custom instruction."
-msgstr ""
+msgstr "Целый идентификатор (N) fexpd специализированной инструкции."
 
 #: config/nios2/nios2.opt:250
-#, fuzzy
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fatand custom instruction."
-msgstr "Не использовать команды callt"
+msgstr "Не использовать fatand специализированную инструкцию."
 
 #: config/nios2/nios2.opt:254
 msgid "Integer id (N) of fatand custom instruction."
-msgstr ""
+msgstr "Целый идентификатор (N) fatand специализированной инструкции."
 
 #: config/nios2/nios2.opt:258
-#, fuzzy
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the ftand custom instruction."
-msgstr "Не использовать команды callt"
+msgstr "Не использовать ftand специализированную инструкцию."
 
 #: config/nios2/nios2.opt:262
 msgid "Integer id (N) of ftand custom instruction."
-msgstr ""
+msgstr "Целый идентификатор (N) ftand специализированной инструкции."
 
 #: config/nios2/nios2.opt:266
-#, fuzzy
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fsind custom instruction."
-msgstr "Не использовать команды callt"
+msgstr "Не использовать fsind специализированную инструкцию."
 
 #: config/nios2/nios2.opt:270
 msgid "Integer id (N) of fsind custom instruction."
-msgstr ""
+msgstr "Целый идентификатор (N) fsind специализированной инструкции."
 
 #: config/nios2/nios2.opt:274
-#, fuzzy
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fcosd custom instruction."
-msgstr "Не использовать команды callt"
+msgstr "Не использовать fcosd специализированную инструкцию."
 
 #: config/nios2/nios2.opt:278
 msgid "Integer id (N) of fcosd custom instruction."
-msgstr ""
+msgstr "Целый идентификатор (N) fcosd специализированной инструкции."
 
 #: config/nios2/nios2.opt:282
-#, fuzzy
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fsqrtd custom instruction."
-msgstr "Не использовать команды callt"
+msgstr "Не использовать fsqrtd специализированную инструкцию."
 
 #: config/nios2/nios2.opt:286
 msgid "Integer id (N) of fsqrtd custom instruction."
-msgstr ""
+msgstr "Целый идентификатор (N) fsqrtd специализированной инструкции."
 
 #: config/nios2/nios2.opt:290
-#, fuzzy
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fabsd custom instruction."
-msgstr "Не использовать команды callt"
+msgstr "Не использовать fabsd специализированную инструкцию."
 
 #: config/nios2/nios2.opt:294
 msgid "Integer id (N) of fabsd custom instruction."
-msgstr ""
+msgstr "Целый идентификатор (N) fabsd специализированной инструкции."
 
 #: config/nios2/nios2.opt:298
-#, fuzzy
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fnegd custom instruction."
-msgstr "Не использовать команды callt"
+msgstr "Не использовать fnegd специализированную инструкцию."
 
 #: config/nios2/nios2.opt:302
 msgid "Integer id (N) of fnegd custom instruction."
-msgstr ""
+msgstr "Целый идентификатор (N) fnegd специализированной инструкции."
 
 #: config/nios2/nios2.opt:306
-#, fuzzy
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fmaxd custom instruction."
-msgstr "Не использовать команды callt"
+msgstr "Не использовать fmaxd специализированную инструкцию."
 
 #: config/nios2/nios2.opt:310
 msgid "Integer id (N) of fmaxd custom instruction."
-msgstr ""
+msgstr "Целый идентификатор (N) fmaxd специализированной инструкции."
 
 #: config/nios2/nios2.opt:314
-#, fuzzy
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fmind custom instruction."
-msgstr "Не использовать команды callt"
+msgstr "Не использовать fmind специализированную инструкцию."
 
 #: config/nios2/nios2.opt:318
 msgid "Integer id (N) of fmind custom instruction."
-msgstr ""
+msgstr "Целый идентификатор (N) fmind специализированной инструкции."
 
 #: config/nios2/nios2.opt:322
-#, fuzzy
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fdivd custom instruction."
-msgstr "Не использовать команды callt"
+msgstr "Не использовать fdivd специализированную инструкцию."
 
 #: config/nios2/nios2.opt:326
 msgid "Integer id (N) of fdivd custom instruction."
-msgstr ""
+msgstr "Целый идентификатор (N) fdivd специализированной инструкции."
 
 #: config/nios2/nios2.opt:330
-#, fuzzy
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fmuld custom instruction."
-msgstr "Не использовать команды callt"
+msgstr "Не использовать fmuld специализированную инструкцию."
 
 #: config/nios2/nios2.opt:334
 msgid "Integer id (N) of fmuld custom instruction."
-msgstr ""
+msgstr "Целый идентификатор (N) fmuld специализированной инструкции."
 
 #: config/nios2/nios2.opt:338
-#, fuzzy
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fsubd custom instruction."
-msgstr "Не использовать команды callt"
+msgstr "Не использовать fsubd специализированную инструкцию."
 
 #: config/nios2/nios2.opt:342
 msgid "Integer id (N) of fsubd custom instruction."
-msgstr ""
+msgstr "Целый идентификатор (N) fsubd специализированной инструкции."
 
 #: config/nios2/nios2.opt:346
-#, fuzzy
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the faddd custom instruction."
-msgstr "Не использовать команды callt"
+msgstr "Не использовать faddd специализированную инструкцию."
 
 #: config/nios2/nios2.opt:350
 msgid "Integer id (N) of faddd custom instruction."
-msgstr ""
+msgstr "Целый идентификатор (N) faddd специализированной инструкции."
 
 #: config/nios2/nios2.opt:354
-#, fuzzy
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fcmpnes custom instruction."
-msgstr "Не использовать команды callt"
+msgstr "Не использовать fcmpnes специализированную инструкцию."
 
 #: config/nios2/nios2.opt:358
 msgid "Integer id (N) of fcmpnes custom instruction."
-msgstr ""
+msgstr "Целый идентификатор (N) fcmpnes специализированной инструкции."
 
 #: config/nios2/nios2.opt:362
-#, fuzzy
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fcmpeqs custom instruction."
-msgstr "Не использовать команды callt"
+msgstr "Не использовать fcmpeqs специализированную инструкцию."
 
 #: config/nios2/nios2.opt:366
 msgid "Integer id (N) of fcmpeqs custom instruction."
-msgstr ""
+msgstr "Целый идентификатор (N) fcmpeqs специализированной инструкции."
 
 #: config/nios2/nios2.opt:370
-#, fuzzy
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fcmpges custom instruction."
-msgstr "Не использовать команды callt"
+msgstr "Не использовать fcmpges специализированную инструкцию."
 
 #: config/nios2/nios2.opt:374
 msgid "Integer id (N) of fcmpges custom instruction."
-msgstr ""
+msgstr "Целый идентификатор (N) fcmpges специализированной инструкции."
 
 #: config/nios2/nios2.opt:378
-#, fuzzy
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fcmpgts custom instruction."
-msgstr "Не использовать команды callt"
+msgstr "Не использовать fcmpgts специализированную инструкцию."
 
 #: config/nios2/nios2.opt:382
 msgid "Integer id (N) of fcmpgts custom instruction."
-msgstr ""
+msgstr "Целый идентификатор (N) fcmpgts специализированной инструкции."
 
 #: config/nios2/nios2.opt:386
-#, fuzzy
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fcmples custom instruction."
-msgstr "Не использовать команды callt"
+msgstr "Не использовать fcmples специализированную инструкцию."
 
 #: config/nios2/nios2.opt:390
 msgid "Integer id (N) of fcmples custom instruction."
-msgstr ""
+msgstr "Целый идентификатор (N) fcmples специализированной инструкции."
 
 #: config/nios2/nios2.opt:394
-#, fuzzy
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fcmplts custom instruction."
-msgstr "Не использовать команды callt"
+msgstr "Не использовать fcmplts специализированную инструкцию."
 
 #: config/nios2/nios2.opt:398
 msgid "Integer id (N) of fcmplts custom instruction."
-msgstr ""
+msgstr "Целый идентификатор (N) fcmplts специализированной инструкции."
 
 #: config/nios2/nios2.opt:402
-#, fuzzy
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the flogs custom instruction."
-msgstr "Не использовать команды callt"
+msgstr "Не использовать flogs специализированную инструкцию."
 
 #: config/nios2/nios2.opt:406
 msgid "Integer id (N) of flogs custom instruction."
-msgstr ""
+msgstr "Целый идентификатор (N) flogs специализированной инструкции."
 
 #: config/nios2/nios2.opt:410
-#, fuzzy
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fexps custom instruction."
-msgstr "Не использовать команды callt"
+msgstr "Не использовать fexps специализированную инструкцию."
 
 #: config/nios2/nios2.opt:414
 msgid "Integer id (N) of fexps custom instruction."
-msgstr ""
+msgstr "Целый идентификатор (N) fexps специализированной инструкции."
 
 #: config/nios2/nios2.opt:418
-#, fuzzy
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fatans custom instruction."
-msgstr "Не использовать команды callt"
+msgstr "Не использовать fatans специализированную инструкцию."
 
 #: config/nios2/nios2.opt:422
 msgid "Integer id (N) of fatans custom instruction."
-msgstr ""
+msgstr "Целый идентификатор (N) fatans специализированной инструкции."
 
 #: config/nios2/nios2.opt:426
-#, fuzzy
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the ftans custom instruction."
-msgstr "Не использовать команды callt"
+msgstr "Не использовать ftans специализированную инструкцию."
 
 #: config/nios2/nios2.opt:430
 msgid "Integer id (N) of ftans custom instruction."
-msgstr ""
+msgstr "Целый идентификатор (N) ftans специализированной инструкции."
 
 #: config/nios2/nios2.opt:434
-#, fuzzy
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fsins custom instruction."
-msgstr "Не использовать команды callt"
+msgstr "Не использовать fsins специализированную инструкцию."
 
 #: config/nios2/nios2.opt:438
 msgid "Integer id (N) of fsins custom instruction."
-msgstr ""
+msgstr "Целый идентификатор (N) fsins специализированной инструкции."
 
 #: config/nios2/nios2.opt:442
-#, fuzzy
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fcoss custom instruction."
-msgstr "Не использовать команды callt"
+msgstr "Не использовать fcoss специализированную инструкцию."
 
 #: config/nios2/nios2.opt:446
 msgid "Integer id (N) of fcoss custom instruction."
-msgstr ""
+msgstr "Целый идентификатор (N) fcoss специализированной инструкции."
 
 #: config/nios2/nios2.opt:450
-#, fuzzy
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fsqrts custom instruction."
-msgstr "Не использовать команды callt"
+msgstr "Не использовать fsqrts специализированную инструкцию."
 
 #: config/nios2/nios2.opt:454
 msgid "Integer id (N) of fsqrts custom instruction."
-msgstr ""
+msgstr "Целый идентификатор (N) fsqrts специализированной инструкции."
 
 #: config/nios2/nios2.opt:458
-#, fuzzy
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fabss custom instr."
-msgstr "Не использовать команды callt"
+msgstr "Не использовать fabss специализированную инструкцию."
 
 #: config/nios2/nios2.opt:462
 msgid "Integer id (N) of fabss custom instruction."
-msgstr ""
+msgstr "Целый идентификатор (N) fabss специализированной инструкции."
 
 #: config/nios2/nios2.opt:466
-#, fuzzy
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fnegs custom instruction."
-msgstr "Не использовать команды callt"
+msgstr "Не использовать fnegs специализированную инструкцию."
 
 #: config/nios2/nios2.opt:470
 msgid "Integer id (N) of fnegs custom instruction."
-msgstr ""
+msgstr "Целый идентификатор (N) fnegs специализированной инструкции."
 
 #: config/nios2/nios2.opt:474
-#, fuzzy
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fmaxs custom instruction."
-msgstr "Не использовать команды callt"
+msgstr "Не использовать fmaxs специализированную инструкцию."
 
 #: config/nios2/nios2.opt:478
 msgid "Integer id (N) of fmaxs custom instruction."
-msgstr ""
+msgstr "Целый идентификатор (N) fmaxs специализированной инструкции."
 
 #: config/nios2/nios2.opt:482
-#, fuzzy
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fmins custom instruction."
-msgstr "Не использовать команды callt"
+msgstr "Не использовать fmins специализированную инструкцию."
 
 #: config/nios2/nios2.opt:486
 msgid "Integer id (N) of fmins custom instruction."
-msgstr ""
+msgstr "Целый идентификатор (N) fmins специализированной инструкции."
 
 #: config/nios2/nios2.opt:490
-#, fuzzy
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fdivs custom instruction."
-msgstr "Не использовать команды callt"
+msgstr "Не использовать fdivs специализированную инструкцию."
 
 #: config/nios2/nios2.opt:494
 msgid "Integer id (N) of fdivs custom instruction."
-msgstr ""
+msgstr "Целый идентификатор (N) fdivs специализированной инструкции."
 
 #: config/nios2/nios2.opt:498
-#, fuzzy
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fmuls custom instruction."
-msgstr "Не использовать команды callt"
+msgstr "Не использовать fmuls специализированную инструкцию."
 
 #: config/nios2/nios2.opt:502
 msgid "Integer id (N) of fmuls custom instruction."
-msgstr ""
+msgstr "Целый идентификатор (N) fmuls специализированной инструкции."
 
 #: config/nios2/nios2.opt:506
-#, fuzzy
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fsubs custom instruction."
-msgstr "Не использовать команды callt"
+msgstr "Не использовать fsubs специализированную инструкцию."
 
 #: config/nios2/nios2.opt:510
 msgid "Integer id (N) of fsubs custom instruction."
-msgstr ""
+msgstr "Целый идентификатор (N) fsubs специализированной инструкции."
 
 #: config/nios2/nios2.opt:514
-#, fuzzy
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fadds custom instruction."
-msgstr "Не использовать команды callt"
+msgstr "Не использовать fadds специализированную инструкцию."
 
 #: config/nios2/nios2.opt:518
 msgid "Integer id (N) of fadds custom instruction."
-msgstr ""
+msgstr "Целый идентификатор (N) fadds специализированной инструкции."
 
 #: config/nios2/nios2.opt:522
-#, fuzzy
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the frdy custom instruction."
-msgstr "Не использовать команды callt"
+msgstr "Не использовать frdy специализированную инструкцию."
 
 #: config/nios2/nios2.opt:526
 msgid "Integer id (N) of frdy custom instruction."
-msgstr ""
+msgstr "Целый идентификатор (N) frdy специализированной инструкции."
 
 #: config/nios2/nios2.opt:530
-#, fuzzy
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the frdxhi custom instruction."
-msgstr "Не использовать команды callt"
+msgstr "Не использовать frdxhi специализированную инструкцию."
 
 #: config/nios2/nios2.opt:534
 msgid "Integer id (N) of frdxhi custom instruction."
-msgstr ""
+msgstr "Целый идентификатор (N) frdxhi специализированной инструкции."
 
 #: config/nios2/nios2.opt:538
-#, fuzzy
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the frdxlo custom instruction."
-msgstr "Не использовать команды callt"
+msgstr "Не использовать frdxlo специализированную инструкцию."
 
 #: config/nios2/nios2.opt:542
 msgid "Integer id (N) of frdxlo custom instruction."
-msgstr ""
+msgstr "Целый идентификатор (N) frdxlo специализированной инструкции."
 
 #: config/nios2/nios2.opt:546
-#, fuzzy
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fwry custom instruction."
-msgstr "Не использовать команды callt"
+msgstr "Не использовать fwry специализированную инструкцию."
 
 #: config/nios2/nios2.opt:550
 msgid "Integer id (N) of fwry custom instruction."
-msgstr ""
+msgstr "Целый идентификатор (N) fwry специализированной инструкции."
 
 #: config/nios2/nios2.opt:554
-#, fuzzy
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the fwrx custom instruction."
-msgstr "Не использовать команды callt"
+msgstr "Не использовать fwrx специализированную инструкцию."
 
 #: config/nios2/nios2.opt:558
 msgid "Integer id (N) of fwrx custom instruction."
-msgstr ""
+msgstr "Целый идентификатор (N) fwrx специализированной инструкции."
 
 #: config/nios2/nios2.opt:562
-#, fuzzy
-#| msgid "Do not use the callt instruction"
 msgid "Do not use the round custom instruction."
-msgstr "Не использовать команды callt"
+msgstr "Не использовать round специализированную инструкцию."
 
 #: config/nios2/nios2.opt:566
 msgid "Integer id (N) of round custom instruction."
-msgstr ""
+msgstr "Целый идентификатор (N) round специализированной инструкции."
 
 #: config/nios2/nios2.opt:574
 msgid "Valid Nios II ISA levels (for -march):"
-msgstr ""
+msgstr "Допустимые Nios II ISA уровни (для -march):"
 
 #: config/nios2/nios2.opt:584
-#, fuzzy
-#| msgid "Enable saturation instructions"
 msgid "Enable generation of R2 BMX instructions."
-msgstr "Включить инструкции насыщения"
+msgstr "Включить генерацию R2 BMX инструкций."
 
 #: config/nios2/nios2.opt:588
-#, fuzzy
-#| msgid "Enable saturation instructions"
 msgid "Enable generation of R2 CDX instructions."
-msgstr "Включить инструкции насыщения"
+msgstr "Включить генерацию R2 CDX инструкций."
 
 #: config/nios2/nios2.opt:592
 msgid "Regular expression matching additional GP-addressible section names."
@@ -14921,7 +12207,7 @@
 
 #: config/rx/rx.opt:33
 msgid "Stores doubles in 32 bits.  This is the default."
-msgstr "Хранить doubles в 32 битах.  Это умолчание."
+msgstr "Stores doubles in 32 bits.  Используется по умолчанию."
 
 #: config/rx/rx.opt:37
 msgid "Disable the use of RX FPU instructions.  "
@@ -14929,7 +12215,7 @@
 
 #: config/rx/rx.opt:44
 msgid "Enable the use of RX FPU instructions.  This is the default."
-msgstr "Включить использование RX FPU инструкций.  Это умолчание."
+msgstr "Enable the use of RX FPU instructions.  Используется по умолчанию."
 
 #: config/rx/rx.opt:50
 msgid "Specify the target RX cpu type."
@@ -14941,17 +12227,15 @@
 
 #: config/rx/rx.opt:75
 msgid "Data is stored in little-endian format.  (Default)."
-msgstr "Данные сохраняются в little-endian формате (с обратным порядком байт).  (Умолчание)."
+msgstr ""
 
 #: config/rx/rx.opt:81
 msgid "Maximum size of global and static variables which can be placed into the small data area."
-msgstr "Максимальный размер глобальных и статических переменных которые могут быть помещены в small data область."
+msgstr "Максимальный размер глобальных и статических переменных, которые могут быть помещены в small data область."
 
 #: config/rx/rx.opt:93
-#, fuzzy
-#| msgid "Generate assembler output that is compatible with the Renesas AS100 assembler.  This may restrict some of the compiler's capabilities.  The default is to generate GAS compatable syntax."
 msgid "Generate assembler output that is compatible with the Renesas AS100 assembler.  This may restrict some of the compiler's capabilities.  The default is to generate GAS compatible syntax."
-msgstr "Генерировать ассемблерный вывод совместимый с Renesas AS100 ассемблером.  Это может ограничить некоторые из возможностей компилятора.  По умолчанию генерируется GAS совместимый синтаксис."
+msgstr ""
 
 #: config/rx/rx.opt:99
 msgid "Enable linker relaxation."
@@ -14975,21 +12259,19 @@
 
 #: config/rx/rx.opt:129
 msgid "Warn when multiple, different, fast interrupt handlers are in the compilation unit."
-msgstr ""
+msgstr "Предупреждать, если в единице компиляции несколько разных, быстрых обработчиков прерываний."
 
 #: config/rx/rx.opt:135
 msgid "Enable the use of the old, broken, ABI where all stacked function arguments are aligned to 32-bits."
-msgstr ""
+msgstr "Включить использование старого, нарушенного ABI, если все помещенные в стек аргументы функции выровнены на границу 32 бит."
 
 #: config/rx/rx.opt:139
 msgid "Enable the use the standard RX ABI where all stacked function arguments are naturally aligned.  This is the default."
-msgstr ""
+msgstr "Enable the use the standard RX ABI where all stacked function arguments are naturally aligned.  Используется по умолчанию."
 
 #: config/rx/rx.opt:145
-#, fuzzy
-#| msgid "Enable the use of the short load instructions"
 msgid "Enable the use of the LRA register allocator."
-msgstr "Включить использование коротких команд загрузки"
+msgstr "Включить использование LRA распределения регистров."
 
 #: config/rx/rx.opt:151
 msgid "Enables or disables the use of the SMOVF, SMOVB, SMOVU, SUNTIL, SWHILE and RMPA instructions.  Enabled by default."
@@ -14996,46 +12278,32 @@
 msgstr ""
 
 #: config/rx/rx.opt:157
-#, fuzzy
-#| msgid "Always generate long calls"
 msgid "Always use JSR, never BSR, for calls."
-msgstr "Всегда генерировать дальние вызовы"
+msgstr "Всегда использовать для вызовов JSR, никогда BSR."
 
 #: config/visium/visium.opt:25
-#, fuzzy
-#| msgid "Link with libyk.a, libc.a and crt0.o"
 msgid "Link with libc.a and libdebug.a."
-msgstr "Компоновать с libyk.a, libc.a и crt0.o"
+msgstr "Компоновать с libc.a и libdebug.a."
 
 #: config/visium/visium.opt:29
-#, fuzzy
-#| msgid "Link with libsim.a, libc.a and sim-crt0.o"
 msgid "Link with libc.a and libsim.a."
-msgstr "Компоновать с libsim.a, libc.a и sim-crt0.o"
+msgstr "Компоновать с libc.a и libsim.a."
 
 #: config/visium/visium.opt:33
-#, fuzzy
-#| msgid "Use hardware FP"
 msgid "Use hardware FP (default)."
-msgstr "Использовать аппаратную вещественную арифметику"
+msgstr "Использовать аппаратную вещественную арифметику (умолчание)."
 
 #: config/visium/visium.opt:65
-#, fuzzy
-#| msgid "Generate code for CR16C+ architecture (Default)"
 msgid "Generate code for the supervisor mode (default)."
-msgstr "Генерировать код для CR16C+ архитектуры (По умолчанию)"
+msgstr "Генерировать код для режима супервизора (умолчание)."
 
 #: config/visium/visium.opt:69
-#, fuzzy
-#| msgid "Generate code for the Boehm GC"
 msgid "Generate code for the user mode."
-msgstr "Генерировать код для сборщика мусора Boehm"
+msgstr "Генерировать код для пользовательского режима."
 
 #: config/visium/visium.opt:73
-#, fuzzy
-#| msgid "Does nothing. Preserved for backward compatibility."
 msgid "Only retained for backward compatibility."
-msgstr "Игнорируется. Сохранен для обратной совместимости."
+msgstr "Сохранено только для обратной совместимости."
 
 #: config/fused-madd.opt:22
 msgid "%<-mfused-madd%> is deprecated; use %<-ffp-contract=%> instead"
@@ -15043,77 +12311,55 @@
 
 #: config/sol2.opt:32
 msgid "Clear hardware capabilities when linking."
-msgstr ""
+msgstr "Очистить аппаратные возможности при компоновке."
 
 #: config/sol2.opt:36
-#, fuzzy
-#| msgid "Pass -z text to linker"
 msgid "Pass -z text to linker."
-msgstr "Передать компоновщику ключ -z"
+msgstr "Передать компоновщику ключ -z."
 
 #: config/moxie/moxie.opt:31
-#, fuzzy
-#| msgid "Enable MPY||ADD and MPY||SUB instructions"
 msgid "Enable MUL.X and UMUL.X instructions."
-msgstr "Использовать команды MPY||ADD, MPY||SUB"
+msgstr "Включить MUL.X и UMUL.X инструкции."
 
 #: config/microblaze/microblaze.opt:40
-#, fuzzy
-#| msgid "Use software emulation for floating point (default)"
 msgid "Use software emulation for floating point (default)."
-msgstr "Использовать программную эмуляцию для плавающей арифметики (умолчание)"
+msgstr "Использовать программную эмуляцию для плавающей арифметики (умолчание)."
 
 #: config/microblaze/microblaze.opt:44
-#, fuzzy
-#| msgid "Use hardware floating point instructions"
 msgid "Use hardware floating point instructions."
-msgstr "Использовать аппаратные инструкции плавающей арифметики"
+msgstr "Использовать аппаратные инструкции плавающей арифметики."
 
 #: config/microblaze/microblaze.opt:48
-#, fuzzy
-#| msgid "Use table lookup optimization for small signed integer divisions"
 msgid "Use table lookup optimization for small signed integer divisions."
-msgstr "Использовать оптимизацию просмотра таблиц для деления небольших целых со знаком"
+msgstr "Использовать оптимизацию просмотра таблиц для деления небольших целых со знаком."
 
 #: config/microblaze/microblaze.opt:52
-#, fuzzy
-#| msgid "-mcpu=PROCESSOR\t\tUse features of and schedule code for given CPU"
 msgid "-mcpu=PROCESSOR\t\tUse features of and schedule code for given CPU."
-msgstr "-mcpu=PROCESSOR\t\tИспользовать возможности и планировать код для заданного CPU"
+msgstr "-mcpu=PROCESSOR\t\tИспользовать возможности и планировать код для заданного CPU."
 
 #: config/microblaze/microblaze.opt:56
-#, fuzzy
-#| msgid "Don't optimize block moves, use memcpy"
 msgid "Don't optimize block moves, use memcpy."
-msgstr "Не оптимизировать блочные пересылки, использовать memcpy"
+msgstr "Не оптимизировать блочные пересылки, использовать memcpy."
 
 #: config/microblaze/microblaze.opt:68
-#, fuzzy
-#| msgid "Use the soft multiply emulation (default)"
 msgid "Use the soft multiply emulation (default)."
-msgstr "Использовать программную эмуляцию умножения (умолчание)"
+msgstr "Использовать программную эмуляцию умножения (умолчание)."
 
 #: config/microblaze/microblaze.opt:72
 msgid "Use reorder instructions (swap and byte reversed load/store) (default)."
-msgstr ""
+msgstr "Использовать инструкции переупорядочения (swap и load/store с обращением порядка байт) (умолчание)."
 
 #: config/microblaze/microblaze.opt:76
-#, fuzzy
-#| msgid "Use the software emulation for divides (default)"
 msgid "Use the software emulation for divides (default)."
-msgstr "Использовать программную эмуляцию для делений (умолчание)"
+msgstr "Использовать программную эмуляцию для делений (умолчание)."
 
 #: config/microblaze/microblaze.opt:80
-#, fuzzy
-#| msgid "Use the hardware barrel shifter instead of emulation"
 msgid "Use the hardware barrel shifter instead of emulation."
-msgstr "Использовать аппаратное устройство циклического сдвига вместо эмуляции"
+msgstr "Использовать аппаратное устройство циклического сдвига вместо эмуляции."
 
 #: config/microblaze/microblaze.opt:84
-#, fuzzy
-#| msgid "Use pattern compare instructions"
 msgid "Use pattern compare instructions."
-msgstr "Использовать инструкции сравнения шаблонов"
+msgstr "Использовать инструкции сравнения шаблонов."
 
 #: config/microblaze/microblaze.opt:87
 #, c-format
@@ -15121,16 +12367,12 @@
 msgstr "%qs устарело; используйте -fstack-check"
 
 #: config/microblaze/microblaze.opt:88
-#, fuzzy
-#| msgid "Check for stack overflow at runtime"
 msgid "Check for stack overflow at runtime."
-msgstr "Проверить переполнение стека во время выполнения"
+msgstr "Проверить переполнение стека во время выполнения."
 
 #: config/microblaze/microblaze.opt:92 config/iq2000/iq2000.opt:65
-#, fuzzy
-#| msgid "Use GP relative sdata/sbss sections"
 msgid "Use GP relative sdata/sbss sections."
-msgstr "Использовать секции sdata/sbss, адресуемые относительно регистра GP"
+msgstr "Использовать секции sdata/sbss, адресуемые относительно регистра GP."
 
 #: config/microblaze/microblaze.opt:95
 #, c-format
@@ -15138,154 +12380,104 @@
 msgstr "%qs устарело; используйте -fno-zero-initialized-in-bss"
 
 #: config/microblaze/microblaze.opt:96
-#, fuzzy
-#| msgid "Clear the BSS to zero and place zero initialized in BSS"
 msgid "Clear the BSS to zero and place zero initialized in BSS."
-msgstr "Зачистить BSS нулями и поместить инициализированные нулями в BSS"
+msgstr "Зачистить BSS нулями и поместить инициализированные нулями в BSS."
 
 #: config/microblaze/microblaze.opt:100
-#, fuzzy
-#| msgid "Use multiply high instructions for high part of 32x32 multiply"
 msgid "Use multiply high instructions for high part of 32x32 multiply."
-msgstr "Использовать multiply high инструкции для high части 32x32 умножения"
+msgstr "Использовать multiply high инструкции для high части 32x32 умножения."
 
 #: config/microblaze/microblaze.opt:104
-#, fuzzy
-#| msgid "Use hardware floating point conversion instructions"
 msgid "Use hardware floating point conversion instructions."
-msgstr "Использовать аппаратные инструкции преобразования чисел с плавающей точкой"
+msgstr "Использовать аппаратные инструкции преобразования чисел с плавающей точкой."
 
 #: config/microblaze/microblaze.opt:108
-#, fuzzy
-#| msgid "Use hardware floating point square root instruction"
 msgid "Use hardware floating point square root instruction."
-msgstr "Использовать команду плавающей арифметики извлечения квадратного корня"
+msgstr "Использовать команду плавающей арифметики извлечения квадратного корня."
 
 #: config/microblaze/microblaze.opt:112
-#, fuzzy
-#| msgid "Description for mxl-mode-executable"
 msgid "Description for mxl-mode-executable."
-msgstr "Описание для mxl-mode-executable"
+msgstr "Описание для mxl-mode-executable."
 
 #: config/microblaze/microblaze.opt:116
-#, fuzzy
-#| msgid "Description for mxl-mode-xmdstub"
 msgid "Description for mxl-mode-xmdstub."
-msgstr "Описание для mxl-mode-xmdstub"
+msgstr "Описание для mxl-mode-xmdstub."
 
 #: config/microblaze/microblaze.opt:120
-#, fuzzy
-#| msgid "Description for mxl-mode-bootstrap"
 msgid "Description for mxl-mode-bootstrap."
-msgstr "Описание для mxl-mode-bootstrap"
+msgstr "Описание для mxl-mode-bootstrap."
 
 #: config/microblaze/microblaze.opt:124
-#, fuzzy
-#| msgid "Description for mxl-mode-novectors"
 msgid "Description for mxl-mode-novectors."
-msgstr "Описание для mxl-mode-novectors"
+msgstr "Описание для mxl-mode-novectors."
 
 #: config/microblaze/microblaze.opt:128
-#, fuzzy
-#| msgid "Use hardware quad FP instructions"
 msgid "Use hardware prefetch instruction"
-msgstr "Использовать аппаратные средства quad-плавающей арифметики"
+msgstr "Использовать аппаратную инструкцию предвыборки"
 
 #: config/vax/vax.opt:23 config/vax/vax.opt:27
-#, fuzzy
-#| msgid "Target DFLOAT double precision code"
 msgid "Target DFLOAT double precision code."
-msgstr "Генерировать код двойной плавающей точности DFLOAT"
+msgstr "Генерировать код двойной плавающей точности DFLOAT."
 
 #: config/vax/vax.opt:31 config/vax/vax.opt:35
-#, fuzzy
-#| msgid "Generate GFLOAT double precision code"
 msgid "Generate GFLOAT double precision code."
-msgstr "Генерировать код двойной плавающей точности GFLOAT"
+msgstr "Генерировать код двойной плавающей точности GFLOAT."
 
 #: config/vax/vax.opt:39
-#, fuzzy
-#| msgid "Generate code for GNU assembler (gas)"
 msgid "Generate code for GNU assembler (gas)."
-msgstr "Генерировать код для GNU-ассемблера (gas)"
+msgstr "Генерировать код для GNU-ассемблера (gas)."
 
 #: config/vax/vax.opt:43
-#, fuzzy
-#| msgid "Generate code for UNIX assembler"
 msgid "Generate code for UNIX assembler."
-msgstr "Генерировать код для UNIX-ассемблера"
+msgstr "Генерировать код для UNIX-ассемблера."
 
 #: config/vax/vax.opt:47
-#, fuzzy
-#| msgid "Use VAXC structure conventions"
 msgid "Use VAXC structure conventions."
-msgstr "Использовать соглашения о структурах VAXC"
+msgstr "Использовать соглашения о структурах VAXC."
 
 #: config/vax/vax.opt:51
-#, fuzzy
-#| msgid "Use new adddi3/subdi3 patterns"
 msgid "Use new adddi3/subdi3 patterns."
-msgstr "Использовать новые шаблоны adddi3/subdi3"
+msgstr "Использовать новые шаблоны adddi3/subdi3."
 
 #: config/frv/frv.opt:30
-#, fuzzy
-#| msgid "Use 4 media accumulators"
 msgid "Use 4 media accumulators."
-msgstr "Использовать 4 аккумулятора данных"
+msgstr "Использовать 4 media-аккумулятора."
 
 #: config/frv/frv.opt:34
-#, fuzzy
-#| msgid "Use 8 media accumulators"
 msgid "Use 8 media accumulators."
-msgstr "Использовать 8 аккумуляторов данных"
+msgstr "Использовать 8 media-аккумуляторов."
 
 #: config/frv/frv.opt:38
-#, fuzzy
-#| msgid "Enable label alignment optimizations"
 msgid "Enable label alignment optimizations."
-msgstr "Включить оптимизации выравнивания меток"
+msgstr "Включить оптимизации выравнивания меток."
 
 #: config/frv/frv.opt:42
-#, fuzzy
-#| msgid "Dynamically allocate cc registers"
 msgid "Dynamically allocate cc registers."
-msgstr "Не использовать регистр BK при распределении регистров"
+msgstr "Не использовать регистр BK при распределении регистров."
 
 #: config/frv/frv.opt:49
-#, fuzzy
-#| msgid "Set the cost of branches"
 msgid "Set the cost of branches."
-msgstr "Установить цену переходов"
+msgstr "Установить цену переходов."
 
 #: config/frv/frv.opt:53
-#, fuzzy
-#| msgid "Enable conditional execution other than moves/scc"
 msgid "Enable conditional execution other than moves/scc."
-msgstr "Использовать условное выполнение и других инструкций кроме moves/scc"
+msgstr "Использовать условное выполнение и других инструкций кроме moves/scc."
 
 #: config/frv/frv.opt:57
-#, fuzzy
-#| msgid "Change the maximum length of conditionally-executed sequences"
 msgid "Change the maximum length of conditionally-executed sequences."
-msgstr "Изменить максимальную длину условно выполняемого пути"
+msgstr "Изменить максимальную длину условно выполняемого пути."
 
 #: config/frv/frv.opt:61
-#, fuzzy
-#| msgid "Change the number of temporary registers that are available to conditionally-executed sequences"
 msgid "Change the number of temporary registers that are available to conditionally-executed sequences."
-msgstr "Задать число временных регистров для условно выполняемого пути"
+msgstr "Задать число временных регистров для условно выполняемого пути."
 
 #: config/frv/frv.opt:65
-#, fuzzy
-#| msgid "Enable conditional moves"
 msgid "Enable conditional moves."
-msgstr "Использовать условные команды move"
+msgstr "Использовать условные команды move."
 
 #: config/frv/frv.opt:69
-#, fuzzy
-#| msgid "Set the target CPU type"
 msgid "Set the target CPU type."
-msgstr "Имя целевого процессора"
+msgstr "Имя целевого процессора."
 
 #: config/frv/frv.opt:73
 msgid "Known FR-V CPUs (for use with the -mcpu= option):"
@@ -15292,214 +12484,144 @@
 msgstr "Имена процессоров FR-V (могут использоваться как аргументы ключа -mcpu= ):"
 
 #: config/frv/frv.opt:122
-#, fuzzy
-#| msgid "Use fp double instructions"
 msgid "Use fp double instructions."
-msgstr "Использовать инструкции двойной точности плавающих вычислений"
+msgstr "Использовать инструкции двойной точности плавающих вычислений."
 
 #: config/frv/frv.opt:126
-#, fuzzy
-#| msgid "Change the ABI to allow double word insns"
 msgid "Change the ABI to allow double word insns."
-msgstr "Изменить ABI для работы с инструкциями двойных слов"
+msgstr "Изменить ABI для работы с двухсловными инструкциями."
 
 #: config/frv/frv.opt:134
-#, fuzzy
-#| msgid "Just use icc0/fcc0"
 msgid "Just use icc0/fcc0."
-msgstr "Использовать только icc0/fcc0"
+msgstr "Использовать только icc0/fcc0."
 
 #: config/frv/frv.opt:138
-#, fuzzy
-#| msgid "Only use 32 FPRs"
 msgid "Only use 32 FPRs."
-msgstr "Использовать только 32 плавающих регистра"
+msgstr "Использовать только 32 плавающих регистра."
 
 #: config/frv/frv.opt:142
-#, fuzzy
-#| msgid "Use 64 FPRs"
 msgid "Use 64 FPRs."
-msgstr "Использовать 64 плавающих регистра"
+msgstr "Использовать 64 плавающих регистра."
 
 #: config/frv/frv.opt:146
-#, fuzzy
-#| msgid "Only use 32 GPRs"
 msgid "Only use 32 GPRs."
-msgstr "Использовать 32 регистра общего назначения"
+msgstr "Использовать 32 регистра общего назначения."
 
 #: config/frv/frv.opt:150
-#, fuzzy
-#| msgid "Use 64 GPRs"
 msgid "Use 64 GPRs."
-msgstr "Использовать 64 регистра общего назначения"
+msgstr "Использовать 64 регистра общего назначения."
 
 #: config/frv/frv.opt:154
-#, fuzzy
-#| msgid "Enable use of GPREL for read-only data in FDPIC"
 msgid "Enable use of GPREL for read-only data in FDPIC."
-msgstr "Использовать GPREL для данных только на чтение в режиме FDPIC"
+msgstr "Использовать GPREL для данных только на чтение в режиме FDPIC."
 
 #: config/frv/frv.opt:166
-#, fuzzy
-#| msgid "Enable PIC support for building libraries"
 msgid "Enable PIC support for building libraries."
-msgstr "Включить поддержку PIC при сборке библиотек"
+msgstr "Включить поддержку PIC при сборке библиотек."
 
 #: config/frv/frv.opt:170
-#, fuzzy
-#| msgid "Follow the EABI linkage requirements"
 msgid "Follow the EABI linkage requirements."
-msgstr "Следовать требованиям компоновки EABI"
+msgstr "Следовать требованиям компоновки EABI."
 
 #: config/frv/frv.opt:174
-#, fuzzy
-#| msgid "Disallow direct calls to global functions"
 msgid "Disallow direct calls to global functions."
-msgstr "Запретить прямые вызовы глобальных функций"
+msgstr "Запретить прямые вызовы глобальных функций."
 
 #: config/frv/frv.opt:178
-#, fuzzy
-#| msgid "Use media instructions"
 msgid "Use media instructions."
-msgstr "Использовать команды манипулирования медиаданными"
+msgstr "Использовать media-инструкции."
 
 #: config/frv/frv.opt:182
-#, fuzzy
-#| msgid "Use multiply add/subtract instructions"
 msgid "Use multiply add/subtract instructions."
-msgstr "Использовать команды плавающего умножения со сложением/вычитанием"
+msgstr "Использовать команды умножения со сложением/вычитанием."
 
 #: config/frv/frv.opt:186
-#, fuzzy
-#| msgid "Enable optimizing &&/|| in conditional execution"
 msgid "Enable optimizing &&/|| in conditional execution."
-msgstr "Включить оптимизацию &&/|| в условно выполняемых путях"
+msgstr "Включить оптимизацию &&/|| в условном выполнении."
 
 #: config/frv/frv.opt:190
-#, fuzzy
-#| msgid "Enable nested conditional execution optimizations"
 msgid "Enable nested conditional execution optimizations."
-msgstr "Включить оптимизацию вложенных условно выполняемых путей"
+msgstr "Включить оптимизацию вложенного условного выполнения."
 
 #: config/frv/frv.opt:195
-#, fuzzy
-#| msgid "Do not mark ABI switches in e_flags"
 msgid "Do not mark ABI switches in e_flags."
-msgstr "не отмечать переключение ABI в e_flags"
+msgstr "Не отмечать переключение ABI в e_flags."
 
 #: config/frv/frv.opt:199
-#, fuzzy
-#| msgid "Remove redundant membars"
 msgid "Remove redundant membars."
-msgstr "Удалять лишние куски памяти"
+msgstr "Удалять лишние куски памяти."
 
 #: config/frv/frv.opt:203
-#, fuzzy
-#| msgid "Pack VLIW instructions"
 msgid "Pack VLIW instructions."
-msgstr "Упаковывать команды во VLIW"
+msgstr "Упаковывать VLIW-инструкции."
 
 #: config/frv/frv.opt:207
-#, fuzzy
-#| msgid "Enable setting GPRs to the result of comparisons"
 msgid "Enable setting GPRs to the result of comparisons."
-msgstr "Присваивать результат сравнения к регистру общего назначения"
+msgstr "Включить установку регистров общего назначения в результат сравнения."
 
 #: config/frv/frv.opt:211
-#, fuzzy
-#| msgid "Change the amount of scheduler lookahead"
 msgid "Change the amount of scheduler lookahead."
-msgstr "Изменить дальность просмотра вперёд в планировщике"
+msgstr "Изменить дальность просмотра вперёд в планировщике."
 
 #: config/frv/frv.opt:219
-#, fuzzy
-#| msgid "Assume a large TLS segment"
 msgid "Assume a large TLS segment."
-msgstr "Использовать большой сегмент TLS"
+msgstr "Использовать большой сегмент TLS."
 
 #: config/frv/frv.opt:223
-#, fuzzy
-#| msgid "Do not assume a large TLS segment"
 msgid "Do not assume a large TLS segment."
-msgstr "Не использовать большой сегмент TLS"
+msgstr "Не использовать большой сегмент TLS."
 
 #: config/frv/frv.opt:228
-#, fuzzy
-#| msgid "Cause gas to print tomcat statistics"
 msgid "Cause gas to print tomcat statistics."
-msgstr "Заставлять gas печатать статистику tomcat"
+msgstr "Заставлять gas печатать статистику tomcat."
 
 #: config/frv/frv.opt:233
-#, fuzzy
-#| msgid "Link with the library-pic libraries"
 msgid "Link with the library-pic libraries."
-msgstr "Компоновать с библиотеками pic"
+msgstr "Компоновать с библиотеками pic."
 
 #: config/frv/frv.opt:237
-#, fuzzy
-#| msgid "Allow branches to be packed with other instructions"
 msgid "Allow branches to be packed with other instructions."
-msgstr "Комбинировать условные переходы с другими инструкциями"
+msgstr "Комбинировать условные переходы с другими инструкциями."
 
 #: config/mn10300/mn10300.opt:30
-#, fuzzy
-#| msgid "Target the AM33 processor"
 msgid "Target the AM33 processor."
-msgstr "Генерировать код для процессора AM33"
+msgstr "Генерировать код для процессора AM33."
 
 #: config/mn10300/mn10300.opt:34
-#, fuzzy
-#| msgid "Target the AM33/2.0 processor"
 msgid "Target the AM33/2.0 processor."
-msgstr "Генерировать код для процессора AM33/2.0"
+msgstr "Генерировать код для процессора AM33/2.0."
 
 #: config/mn10300/mn10300.opt:38
-#, fuzzy
-#| msgid "Target the AM34 processor"
 msgid "Target the AM34 processor."
-msgstr "Генерировать код для процессора AM34"
+msgstr "Генерировать код для процессора AM34."
 
 #: config/mn10300/mn10300.opt:46
-#, fuzzy
-#| msgid "Work around hardware multiply bug"
 msgid "Work around hardware multiply bug."
-msgstr "Обходить аппаратную ошибку умножения"
+msgstr "Обходить аппаратную ошибку умножения."
 
 #: config/mn10300/mn10300.opt:55
-#, fuzzy
-#| msgid "Enable linker relaxations"
 msgid "Enable linker relaxations."
-msgstr "Включить ключ -relax при компоновке"
+msgstr "Включить ослабления компоновщика."
 
 #: config/mn10300/mn10300.opt:59
-#, fuzzy
-#| msgid "Return pointers in both a0 and d0"
 msgid "Return pointers in both a0 and d0."
-msgstr "Возвращать указатели и на a0 и на d0"
+msgstr "Возвращать указатели и на a0 и на d0."
 
 #: config/mn10300/mn10300.opt:63
-#, fuzzy
-#| msgid "Allow gcc to generate LIW instructions"
 msgid "Allow gcc to generate LIW instructions."
-msgstr "Разрешить использование команд LIW"
+msgstr "Позволить gcc генерировать LIW инструкции."
 
 #: config/mn10300/mn10300.opt:67
-#, fuzzy
-#| msgid "Allow gcc to generate the SETLB and Lcc instructions"
 msgid "Allow gcc to generate the SETLB and Lcc instructions."
-msgstr "Разрешить использование команд SETLB и Lcc"
+msgstr "Позволить gcc генерировать SETLB и Lcc инструкции."
 
 #: config/nds32/nds32.opt:29 config/nds32/nds32.opt:82
-#, fuzzy
-#| msgid "Generate code in big endian mode"
 msgid "Generate code in big-endian mode."
-msgstr "Генерировать код для прямого (big endian) порядка байт"
+msgstr "Генерировать код для прямого (big endian) порядка байт."
 
 #: config/nds32/nds32.opt:33 config/nds32/nds32.opt:86
-#, fuzzy
-#| msgid "Generate code in little endian mode"
 msgid "Generate code in little-endian mode."
-msgstr "Генерировать код для обратного (little endian) порядка байт"
+msgstr "Генерировать код для обратного (little endian) порядка байт."
 
 #: config/nds32/nds32.opt:40
 msgid "Specify which ABI type to generate code for: 2, 2fp+."
@@ -15514,62 +12636,44 @@
 msgstr ""
 
 #: config/nds32/nds32.opt:64
-#, fuzzy
-#| msgid "Reschedule instructions before register allocation"
 msgid "Use reduced-set registers for register allocation."
-msgstr "Планировать код перед распределением регистров"
+msgstr "Использовать урезанный набор регистров для распределения регистров."
 
 #: config/nds32/nds32.opt:68
-#, fuzzy
-#| msgid "Reschedule instructions before register allocation"
 msgid "Use full-set registers for register allocation."
-msgstr "Планировать код перед распределением регистров"
+msgstr "Использовать полный набор регистров для распределения регистров."
 
 #: config/nds32/nds32.opt:74
 msgid "Always align function entry, jump target and return address."
-msgstr ""
+msgstr "Always align function entry, jump target and return address."
 
 #: config/nds32/nds32.opt:78
-#, fuzzy
-#| msgid "Align code and data to 32 bits"
 msgid "Align function entry to 4 byte."
-msgstr "Выравнивать код и данные по границе 32 бит"
+msgstr "Выравнивать вход в функцию по границе 4 байта"
 
 #: config/nds32/nds32.opt:91
-#, fuzzy
-#| msgid "enable conditional move instruction usage."
 msgid "Generate conditional move instructions."
-msgstr "включить использование инструкции условного перемещения."
+msgstr "Генерировать условные move-инструкции."
 
 #: config/nds32/nds32.opt:95
-#, fuzzy
-#| msgid "Generate bit instructions"
 msgid "Generate performance extension instructions."
-msgstr "Генерировать битовые инструкции"
+msgstr "Генерировать инструкции расширения производительности."
 
 #: config/nds32/nds32.opt:99
-#, fuzzy
-#| msgid "Generate bit instructions"
 msgid "Generate performance extension version 2 instructions."
-msgstr "Генерировать битовые инструкции"
+msgstr "Генерировать инструкции расширения производительности 2-й версии."
 
 #: config/nds32/nds32.opt:103
-#, fuzzy
-#| msgid "Generate bit instructions"
 msgid "Generate string extension instructions."
-msgstr "Генерировать битовые инструкции"
+msgstr "Генерировать инструкции расширения строк."
 
 #: config/nds32/nds32.opt:107
-#, fuzzy
-#| msgid "Generate isel instructions"
 msgid "Generate v3 push25/pop25 instructions."
-msgstr "Генерировать команды isel"
+msgstr "Генерировать v3 push25/pop25 инструкции."
 
 #: config/nds32/nds32.opt:111
-#, fuzzy
-#| msgid "Generate bit instructions"
 msgid "Generate 16-bit instructions."
-msgstr "Генерировать битовые инструкции"
+msgstr "Генерировать 16-битные инструкции."
 
 #: config/nds32/nds32.opt:115
 msgid "Insert relax hint for linker to do relaxation."
@@ -15576,46 +12680,36 @@
 msgstr ""
 
 #: config/nds32/nds32.opt:119
-#, fuzzy
-#| msgid "Enable multicore support"
 msgid "Enable Virtual Hosting support."
-msgstr "Включить поддержку многоядерности"
+msgstr ""
 
 #: config/nds32/nds32.opt:123
 msgid "Specify the size of each interrupt vector, which must be 4 or 16."
-msgstr ""
+msgstr "Задать размер каждого вектора прерывания, который должен быть 4 или 16."
 
 #: config/nds32/nds32.opt:127
 msgid "Specify the size of each cache block, which must be a power of 2 between 4 and 512."
-msgstr ""
+msgstr "Задать размер каждого блока кэша, который должен быть степенью 2 между 4 и 512."
 
 #: config/nds32/nds32.opt:135
-#, fuzzy
-#| msgid "Known ARM architectures (for use with the -march= option):"
 msgid "Known arch types (for use with the -march= option):"
-msgstr "Известные ARM архитектуры (для использования с -march= опцией):"
+msgstr "Известные arch типы (для использования с -march= опцией):"
 
 #: config/nds32/nds32.opt:154
 msgid "Specify the address generation strategy for code model."
-msgstr ""
+msgstr "Задать стратегию генерации адресов для модели кода."
 
 #: config/nds32/nds32.opt:158
-#, fuzzy
-#| msgid "Known code models (for use with the -mcmodel= option):"
 msgid "Known cmodel types (for use with the -mcmodel= option):"
-msgstr "Известные модели кода (значения ключа -mcmodel= ):"
+msgstr "Известные cmodel типы (для использования -mcmodel= опцией):"
 
 #: config/nds32/nds32.opt:171
-#, fuzzy
-#| msgid "Select code model"
 msgid "Specify the cpu for pipeline model."
-msgstr "Выбрать модель кода"
+msgstr ""
 
 #: config/nds32/nds32.opt:175
-#, fuzzy
-#| msgid "Known ARM architectures (for use with the -march= option):"
 msgid "Known cpu types (for use with the -mcpu= option):"
-msgstr "Известные ARM архитектуры (для использования с -march= опцией):"
+msgstr ""
 
 #: config/nds32/nds32.opt:242
 msgid "Specify a fpu configuration value from 0 to 7; 0-3 is as FPU spec says, and 4-7 is corresponding to 0-3."
@@ -15622,10 +12716,8 @@
 msgstr ""
 
 #: config/nds32/nds32.opt:246
-#, fuzzy
-#| msgid "Known floating-point ABIs (for use with the -mfloat-abi= option):"
 msgid "Known floating-point number of registers (for use with the -mconfig-fpu= option):"
-msgstr "Известные плавающие ABIs (для использования с -mfloat-abi= опцией):"
+msgstr ""
 
 #: config/nds32/nds32.opt:274
 msgid "Specify configuration of instruction mul: fast1, fast2 or slow. The default is fast1."
@@ -15636,34 +12728,24 @@
 msgstr ""
 
 #: config/nds32/nds32.opt:306
-#, fuzzy
-#| msgid "Warn when all constructors and destructors are private"
 msgid "Enable constructor/destructor feature."
-msgstr "Предупреждать о классах, в которых все конструкторы и деструкторы private"
+msgstr "Включить конструктор/деструктор возможность."
 
 #: config/nds32/nds32.opt:310
-#, fuzzy
-#| msgid "Generate isel instructions"
 msgid "Guide linker to relax instructions."
-msgstr "Генерировать команды isel"
+msgstr "Направить компоновщик на ослабление инструкций."
 
 #: config/nds32/nds32.opt:314
-#, fuzzy
-#| msgid "Generate floating point mathematics using given instruction set"
 msgid "Generate floating-point multiply-accumulation instructions."
-msgstr "Генерировать код для плавающей арифметики используя заданный набор команд"
+msgstr ""
 
 #: config/nds32/nds32.opt:318
-#, fuzzy
-#| msgid "Use paired-single floating-point instructions"
 msgid "Generate single-precision floating-point instructions."
-msgstr "Использовать команды плавающей арифметики формата paired-single (над парами значений одинарной точности)"
+msgstr ""
 
 #: config/nds32/nds32.opt:322
-#, fuzzy
-#| msgid "Generate code that uses 68881 floating-point instructions"
 msgid "Generate double-precision floating-point instructions."
-msgstr "Генерировать код с использованием плавающих инструкций 68881"
+msgstr ""
 
 #: config/nds32/nds32.opt:326
 msgid "Always save $lp in the stack."
@@ -15670,16 +12752,12 @@
 msgstr ""
 
 #: config/iq2000/iq2000.opt:31
-#, fuzzy
-#| msgid "Specify CPU for code generation purposes"
 msgid "Specify CPU for code generation purposes."
-msgstr "Процессор, для которого осуществляется генерацию кода"
+msgstr "Процессор, для которого осуществляется генерацию кода."
 
 #: config/iq2000/iq2000.opt:47
-#, fuzzy
-#| msgid "Specify CPU for scheduling purposes"
 msgid "Specify CPU for scheduling purposes."
-msgstr "Процессор, для которого осуществляется планирование команд"
+msgstr "Процессор, для которого осуществляется планирование команд."
 
 #: config/iq2000/iq2000.opt:51
 msgid "Known IQ2000 CPUs (for use with the -mcpu= option):"
@@ -15686,22 +12764,16 @@
 msgstr "Известные IQ2000 CPUs (для использования с -mcpu= опцией):"
 
 #: config/iq2000/iq2000.opt:61 config/mips/mips.opt:142
-#, fuzzy
-#| msgid "Use ROM instead of RAM"
 msgid "Use ROM instead of RAM."
-msgstr "Использовать ROM вместо RAM"
+msgstr "Использовать ROM вместо RAM."
 
 #: config/iq2000/iq2000.opt:70
-#, fuzzy
-#| msgid "No default crt0.o"
 msgid "No default crt0.o."
-msgstr "отсутствует стандартный файл crt0.o"
+msgstr "отсутствует стандартный файл crt0.o."
 
 #: config/iq2000/iq2000.opt:74 config/mips/mips.opt:405
-#, fuzzy
-#| msgid "Put uninitialized constants in ROM (needs -membedded-data)"
 msgid "Put uninitialized constants in ROM (needs -membedded-data)."
-msgstr "Размещать неинициализированные константы в ROM (требуется -membedded-data)"
+msgstr "Размещать неинициализированные константы в ROM (требуется -membedded-data)."
 
 #: config/c6x/c6x-tables.opt:24
 msgid "Known C6X ISAs (for use with the -march= option):"
@@ -15708,124 +12780,84 @@
 msgstr "Известные C6X ISAs (для использования с -march= опцией):"
 
 #: config/c6x/c6x.opt:46
-#, fuzzy
-#| msgid "Valid arguments for the -msdata= option"
 msgid "Valid arguments for the -msdata= option."
-msgstr "Корректные аргументы для -msdata= опции"
+msgstr "Корректные аргументы для -msdata= опции."
 
 #: config/c6x/c6x.opt:59
-#, fuzzy
-#| msgid "Compile for the DSBT shared library ABI"
 msgid "Compile for the DSBT shared library ABI."
-msgstr "Компилировать для ABI DSBT разделяемых библиотек"
+msgstr "Компилировать для ABI DSBT разделяемых библиотек."
 
 #: config/cris/linux.opt:27
-#, fuzzy
-#| msgid "Together with -fpic and -fPIC, do not use GOTPLT references"
 msgid "Together with -fpic and -fPIC, do not use GOTPLT references."
-msgstr "Не использовать GOTPLT-ссылки с -fpic и -fPIC"
+msgstr "Не использовать GOTPLT-ссылки с -fpic и -fPIC."
 
 #: config/cris/cris.opt:45
-#, fuzzy
-#| msgid "Work around bug in multiplication instruction"
 msgid "Work around bug in multiplication instruction."
-msgstr "Обойти ошибку в команде умножения"
+msgstr "Обойти ошибку в команде умножения."
 
 #: config/cris/cris.opt:51
-#, fuzzy
-#| msgid "Compile for ETRAX 4 (CRIS v3)"
 msgid "Compile for ETRAX 4 (CRIS v3)."
-msgstr "Компилировать для ETRAX 4 (CRIS v3)"
+msgstr "Компилировать для ETRAX 4 (CRIS v3)."
 
 #: config/cris/cris.opt:56
-#, fuzzy
-#| msgid "Compile for ETRAX 100 (CRIS v8)"
 msgid "Compile for ETRAX 100 (CRIS v8)."
-msgstr "Компилировать для ETRAX 100 (CRIS v8)"
+msgstr "Компилировать для ETRAX 100 (CRIS v8)."
 
 #: config/cris/cris.opt:64
-#, fuzzy
-#| msgid "Emit verbose debug information in assembly code"
 msgid "Emit verbose debug information in assembly code."
-msgstr "Выводить в ассемблерный код подробную отладочную информацию"
+msgstr "Выводить в ассемблерный код подробную отладочную информацию."
 
 #: config/cris/cris.opt:71
-#, fuzzy
-#| msgid "Do not use condition codes from normal instructions"
 msgid "Do not use condition codes from normal instructions."
-msgstr "В обычных командах не использовать коды условий"
+msgstr "В обычных командах не использовать коды условий."
 
 #: config/cris/cris.opt:80
-#, fuzzy
-#| msgid "Do not emit addressing modes with side-effect assignment"
 msgid "Do not emit addressing modes with side-effect assignment."
-msgstr "Не использовать режимов адресации с побочными эффектами"
+msgstr "Не использовать режимов адресации с побочными эффектами."
 
 #: config/cris/cris.opt:89
-#, fuzzy
-#| msgid "Do not tune stack alignment"
 msgid "Do not tune stack alignment."
-msgstr "Не выравнивать данные в стеке"
+msgstr "Не выравнивать данные в стеке."
 
 #: config/cris/cris.opt:98
-#, fuzzy
-#| msgid "Do not tune writable data alignment"
 msgid "Do not tune writable data alignment."
-msgstr "Не выравнивать данные, доступные на запись"
+msgstr "Не выравнивать данные, доступные на запись."
 
 #: config/cris/cris.opt:107
-#, fuzzy
-#| msgid "Do not tune code and read-only data alignment"
 msgid "Do not tune code and read-only data alignment."
-msgstr "Не выравнивать код и данные, доступные только на чтение"
+msgstr "Не выравнивать код и данные, доступные только на чтение."
 
 #: config/cris/cris.opt:116
-#, fuzzy
-#| msgid "Align code and data to 32 bits"
 msgid "Align code and data to 32 bits."
-msgstr "Выравнивать код и данные по границе 32 бит"
+msgstr "Выравнивать код и данные по границе 32 бит."
 
 #: config/cris/cris.opt:133
-#, fuzzy
-#| msgid "Don't align items in code or data"
 msgid "Don't align items in code or data."
-msgstr "Не выравнивать элементы кода или данных"
+msgstr "Не выравнивать элементы кода или данных."
 
 #: config/cris/cris.opt:142
-#, fuzzy
-#| msgid "Do not emit function prologue or epilogue"
 msgid "Do not emit function prologue or epilogue."
-msgstr "Не генерировать прологи и эпилоги функций"
+msgstr "Не генерировать прологи и эпилоги функций."
 
 #: config/cris/cris.opt:149
-#, fuzzy
-#| msgid "Use the most feature-enabling options allowed by other options"
 msgid "Use the most feature-enabling options allowed by other options."
-msgstr "Использовать максимум возможностей, не противоречащих другим ключам"
+msgstr "Использовать максимум возможностей, не противоречащих другим ключам."
 
 #: config/cris/cris.opt:158
-#, fuzzy
-#| msgid "Override -mbest-lib-options"
 msgid "Override -mbest-lib-options."
-msgstr "Отменить -mbest-lib-options"
+msgstr "Отменить -mbest-lib-options."
 
 #: config/cris/cris.opt:165
-#, fuzzy
-#| msgid "-march=ARCH\tGenerate code for the specified chip or CPU version"
 msgid "-march=ARCH\tGenerate code for the specified chip or CPU version."
-msgstr "-march=ARCH\tГенерировать код для указанной микросхемы или версии CPU"
+msgstr "-march=ARCH\tГенерировать код для указанной микросхемы или версии CPU."
 
 #: config/cris/cris.opt:169
-#, fuzzy
-#| msgid "-mtune=ARCH\tTune alignment for the specified chip or CPU version"
 msgid "-mtune=ARCH\tTune alignment for the specified chip or CPU version."
-msgstr "-mtune=ARCH\tНастроить выравнивание для указанной микросхемы или версии CPU"
+msgstr "-mtune=ARCH\tНастроить выравнивание для указанной микросхемы или версии CPU."
 
 #: config/cris/cris.opt:173
-#, fuzzy
-#| msgid "-mmax-stackframe=SIZE\tWarn when a stackframe is larger than the specified size"
 msgid "-mmax-stackframe=SIZE\tWarn when a stackframe is larger than the specified size."
-msgstr "-mmax-stackframe=SIZE\tПредупреждать если кадр стека превышает указанный размер"
+msgstr "-mmax-stackframe=SIZE\tПредупреждать, если кадр стека превышает указанный размер."
 
 #: config/cris/cris.opt:180
 msgid "Emit traps as \"break 8\", default for CRIS v3 and up.  If disabled, calls to abort() are used."
@@ -15833,7 +12865,7 @@
 
 #: config/cris/cris.opt:184
 msgid "Emit checks causing \"break 8\" instructions to execute when applying atomic builtins on misaligned memory."
-msgstr ""
+msgstr "Порождать проверки вызывающие выполнение инструкций \"break 8\" при применении атомарных встроенных функций к неверно выровненной памяти."
 
 #: config/cris/cris.opt:188
 msgid "Handle atomic builtins that may be applied to unaligned data by calling library functions. Overrides -mtrap-unaligned-atomic."
@@ -15848,118 +12880,80 @@
 msgstr "Имя времени выполнения."
 
 #: config/sh/sh.opt:42
-#, fuzzy
-#| msgid "Generate SH1 code"
 msgid "Generate SH1 code."
-msgstr "Генерировать код SH1"
+msgstr "Генерировать код SH1."
 
 #: config/sh/sh.opt:46
-#, fuzzy
-#| msgid "Generate SH2 code"
 msgid "Generate SH2 code."
-msgstr "Генерировать код SH2"
+msgstr "Генерировать код SH2."
 
 #: config/sh/sh.opt:50
-#, fuzzy
-#| msgid "Generate default double-precision SH2a-FPU code"
 msgid "Generate default double-precision SH2a-FPU code."
-msgstr "Генерировать подразумеваемый код двойной точности SH2a-FPU"
+msgstr "Генерировать подразумеваемый код двойной точности SH2a-FPU."
 
 #: config/sh/sh.opt:54
-#, fuzzy
-#| msgid "Generate SH2a FPU-less code"
 msgid "Generate SH2a FPU-less code."
-msgstr "Генерировать код для SH2a без FPU"
+msgstr "Генерировать код для SH2a без FPU."
 
 #: config/sh/sh.opt:58
-#, fuzzy
-#| msgid "Generate default single-precision SH2a-FPU code"
 msgid "Generate default single-precision SH2a-FPU code."
-msgstr "Генерировать подразумеваемый код одинарной точности SH2a-FPU"
+msgstr "Генерировать подразумеваемый код одинарной точности SH2a-FPU."
 
 #: config/sh/sh.opt:62
-#, fuzzy
-#| msgid "Generate only single-precision SH2a-FPU code"
 msgid "Generate only single-precision SH2a-FPU code."
-msgstr "Генерировать только код одинарной точности SH2a-FPU"
+msgstr "Генерировать только код одинарной точности SH2a-FPU."
 
 #: config/sh/sh.opt:66
-#, fuzzy
-#| msgid "Generate SH2e code"
 msgid "Generate SH2e code."
-msgstr "Генерировать код SH2e"
+msgstr "Генерировать код SH2e."
 
 #: config/sh/sh.opt:70
-#, fuzzy
-#| msgid "Generate SH3 code"
 msgid "Generate SH3 code."
-msgstr "Генерировать код SH3"
+msgstr "Генерировать код SH3."
 
 #: config/sh/sh.opt:74
-#, fuzzy
-#| msgid "Generate SH3e code"
 msgid "Generate SH3e code."
-msgstr "Генерировать код SH3e"
+msgstr "Генерировать код SH3e."
 
 #: config/sh/sh.opt:78
-#, fuzzy
-#| msgid "Generate SH4 code"
 msgid "Generate SH4 code."
-msgstr "Генерировать код SH4"
+msgstr "Генерировать код SH4."
 
 #: config/sh/sh.opt:82
-#, fuzzy
-#| msgid "Generate SH4-100 code"
 msgid "Generate SH4-100 code."
-msgstr "Генерировать код SH4-100"
+msgstr "Генерировать код SH4-100."
 
 #: config/sh/sh.opt:86
-#, fuzzy
-#| msgid "Generate SH4-200 code"
 msgid "Generate SH4-200 code."
-msgstr "Генерировать код SH4-200"
+msgstr "Генерировать код SH4-200."
 
 #: config/sh/sh.opt:92
-#, fuzzy
-#| msgid "Generate SH4-300 code"
 msgid "Generate SH4-300 code."
-msgstr "Генерировать код SH4-300"
+msgstr "Генерировать код SH4-300."
 
 #: config/sh/sh.opt:96
-#, fuzzy
-#| msgid "Generate SH4 FPU-less code"
 msgid "Generate SH4 FPU-less code."
-msgstr "Генерировать код для SH4 без FPU"
+msgstr "Генерировать код для SH4 без FPU."
 
 #: config/sh/sh.opt:100
-#, fuzzy
-#| msgid "Generate SH4-100 FPU-less code"
 msgid "Generate SH4-100 FPU-less code."
-msgstr "Генерировать код для SH4-100 без FPU"
+msgstr "Генерировать код для SH4-100 без FPU."
 
 #: config/sh/sh.opt:104
-#, fuzzy
-#| msgid "Generate SH4-200 FPU-less code"
 msgid "Generate SH4-200 FPU-less code."
-msgstr "Генерировать код для SH4-200 без FPU"
+msgstr "Генерировать код для SH4-200 без FPU."
 
 #: config/sh/sh.opt:108
-#, fuzzy
-#| msgid "Generate SH4-300 FPU-less code"
 msgid "Generate SH4-300 FPU-less code."
-msgstr "Генерировать код для SH4-300 без FPU"
+msgstr "Генерировать код для SH4-300 без FPU."
 
 #: config/sh/sh.opt:112
-#, fuzzy
-#| msgid "Generate code for SH4 340 series (MMU/FPU-less)"
 msgid "Generate code for SH4 340 series (MMU/FPU-less)."
-msgstr "Генерировать код для SH4 340 серии (без MMU/FPU)"
+msgstr "Генерировать код для SH4 340 серии (без MMU/FPU)."
 
 #: config/sh/sh.opt:117
-#, fuzzy
-#| msgid "Generate code for SH4 400 series (MMU/FPU-less)"
 msgid "Generate code for SH4 400 series (MMU/FPU-less)."
-msgstr "Генерировать код для SH4 400 серии (без MMU/FPU)"
+msgstr "Генерировать код для SH4 400 серии (без MMU/FPU)."
 
 #: config/sh/sh.opt:122
 msgid "Generate code for SH4 500 series (FPU-less)."
@@ -15966,240 +12960,172 @@
 msgstr "Генерировать код для SH4 500 серии (без FPU)."
 
 #: config/sh/sh.opt:127
-#, fuzzy
-#| msgid "Generate default single-precision SH4 code"
 msgid "Generate default single-precision SH4 code."
-msgstr "Генерировать код SH4 с одинарной точностью по умолчанию"
+msgstr "Генерировать код SH4 с одинарной точностью по умолчанию."
 
 #: config/sh/sh.opt:131
-#, fuzzy
-#| msgid "Generate default single-precision SH4-100 code"
 msgid "Generate default single-precision SH4-100 code."
-msgstr "Генерировать подразумеваемый код SH4-100 с одинарной точностью"
+msgstr "Генерировать подразумеваемый код SH4-100 с одинарной точностью."
 
 #: config/sh/sh.opt:135
-#, fuzzy
-#| msgid "Generate default single-precision SH4-200 code"
 msgid "Generate default single-precision SH4-200 code."
-msgstr "Генерировать подразумеваемый код SH4-200 с одинарной точностью"
+msgstr "Генерировать подразумеваемый код SH4-200 с одинарной точностью."
 
 #: config/sh/sh.opt:139
-#, fuzzy
-#| msgid "Generate default single-precision SH4-300 code"
 msgid "Generate default single-precision SH4-300 code."
-msgstr "Генерировать подразумеваемый код SH4-300 с одинарной точностью"
+msgstr "Генерировать подразумеваемый код SH4-300 с одинарной точностью."
 
 #: config/sh/sh.opt:143
-#, fuzzy
-#| msgid "Generate only single-precision SH4 code"
 msgid "Generate only single-precision SH4 code."
-msgstr "Генерировать только код SH4 с одинарной точностью"
+msgstr "Генерировать только код SH4 с одинарной точностью."
 
 #: config/sh/sh.opt:147
-#, fuzzy
-#| msgid "Generate only single-precision SH4-100 code"
 msgid "Generate only single-precision SH4-100 code."
-msgstr "Генерировать только код SH4-100 с одинарной точностью"
+msgstr "Генерировать только код SH4-100 с одинарной точностью."
 
 #: config/sh/sh.opt:151
-#, fuzzy
-#| msgid "Generate only single-precision SH4-200 code"
 msgid "Generate only single-precision SH4-200 code."
-msgstr "Генерировать только код SH4-200 с одинарной точностью"
+msgstr "Генерировать только код SH4-200 с одинарной точностью."
 
 #: config/sh/sh.opt:155
-#, fuzzy
-#| msgid "Generate only single-precision SH4-300 code"
 msgid "Generate only single-precision SH4-300 code."
-msgstr "Генерировать только код SH4-300 с одинарной точностью"
+msgstr "Генерировать только код SH4-300 с одинарной точностью."
 
 #: config/sh/sh.opt:159
-#, fuzzy
-#| msgid "Generate SH4a code"
 msgid "Generate SH4a code."
-msgstr "Генерировать код SH4a"
+msgstr "Генерировать код SH4a."
 
 #: config/sh/sh.opt:163
-#, fuzzy
-#| msgid "Generate SH4a FPU-less code"
 msgid "Generate SH4a FPU-less code."
-msgstr "Генерировать код для SH4a без FPU"
+msgstr "Генерировать код для SH4a без FPU."
 
 #: config/sh/sh.opt:167
-#, fuzzy
-#| msgid "Generate default single-precision SH4a code"
 msgid "Generate default single-precision SH4a code."
-msgstr "Генерировать по умолчанию код SH4a одинарной точности"
+msgstr "Генерировать по умолчанию код SH4a одинарной точности."
 
 #: config/sh/sh.opt:171
-#, fuzzy
-#| msgid "Generate only single-precision SH4a code"
 msgid "Generate only single-precision SH4a code."
-msgstr "Генерировать только код SH4a одинарной точности"
+msgstr "Генерировать только код SH4a одинарной точности."
 
 #: config/sh/sh.opt:175
-#, fuzzy
-#| msgid "Generate SH4al-dsp code"
 msgid "Generate SH4al-dsp code."
-msgstr "Генерировать SH4al-dsp код"
+msgstr "Генерировать SH4al-dsp код."
 
 #: config/sh/sh.opt:183
-#, fuzzy
-#| msgid "Generate code in big endian mode"
 msgid "Generate code in big endian mode."
-msgstr "Генерировать код для прямого (big endian) порядка байт"
+msgstr "Генерировать код для прямого (big endian) порядка байт."
 
 #: config/sh/sh.opt:187
-#, fuzzy
-#| msgid "Generate 32-bit offsets in switch tables"
 msgid "Generate 32-bit offsets in switch tables."
-msgstr "Генерировать 32-битные смещения в таблицах переключателей"
+msgstr "Генерировать 32-битные смещения в таблицах переключателей."
 
 #: config/sh/sh.opt:191
-#, fuzzy
-#| msgid "Generate bit instructions"
 msgid "Generate bit instructions."
-msgstr "Генерировать битовые инструкции"
+msgstr "Генерировать битовые инструкции."
 
 #: config/sh/sh.opt:199
 msgid "Assume that zero displacement conditional branches are fast."
-msgstr ""
+msgstr "Предполагать, что условные переходы с нулевым смещением быстры."
 
 #: config/sh/sh.opt:203
 msgid "Force the usage of delay slots for conditional branches."
-msgstr ""
+msgstr "Использовать слоты задержки для условных переходов."
 
 #: config/sh/sh.opt:207
-#, fuzzy
-#| msgid "Align doubles at 64-bit boundaries"
 msgid "Align doubles at 64-bit boundaries."
-msgstr "Выравнивать двойные по 64-битным границам"
+msgstr "Выравнивать двойные по 64-битным границам."
 
 #: config/sh/sh.opt:211
 msgid "Division strategy, one of: call-div1, call-fp, call-table."
-msgstr ""
+msgstr "Стратегия деления, одна из: call-div1, call-fp, call-table."
 
 #: config/sh/sh.opt:215
-#, fuzzy
-#| msgid "Specify name for 32 bit signed division function"
 msgid "Specify name for 32 bit signed division function."
-msgstr "Задать имя для функции деления 32-битных чисел со знаком"
+msgstr "Задать имя для функции деления 32-битных чисел со знаком."
 
 #: config/sh/sh.opt:219
-#, fuzzy
-#| msgid "Generate LP64 code"
 msgid "Generate ELF FDPIC code."
-msgstr "Генерировать код для LP64"
+msgstr "Генерировать ELF FDPIC код."
 
 #: config/sh/sh.opt:223
 msgid "Enable the use of 64-bit floating point registers in fmov instructions.  See -mdalign if 64-bit alignment is required."
-msgstr "Включить использование 64-битных плавающих регистров в fmov инструкциях.  См. -mdalign если 64-битное выравнивание требуется."
+msgstr ""
 
 #: config/sh/sh.opt:231 config/sh/sh.opt:269
-#, fuzzy
-#| msgid "Follow Renesas (formerly Hitachi) / SuperH calling conventions"
 msgid "Follow Renesas (formerly Hitachi) / SuperH calling conventions."
-msgstr "Следовать соглашениям о вызовах Renesas (бывшая Hitachi) для SuperH"
+msgstr "Следовать соглашениям о вызовах Renesas (бывшая Hitachi) для SuperH."
 
 #: config/sh/sh.opt:235
-#, fuzzy
-#| msgid "Increase the IEEE compliance for floating-point comparisons"
 msgid "Increase the IEEE compliance for floating-point comparisons."
-msgstr "Увеличить IEEE соответствие для сравнений с плавающей точкой"
+msgstr "Увеличить IEEE соответствие для сравнений с плавающей точкой."
 
 #: config/sh/sh.opt:239
-#, fuzzy
-#| msgid "inline code to invalidate instruction cache entries after setting up nested function trampolines"
 msgid "inline code to invalidate instruction cache entries after setting up nested function trampolines."
-msgstr "вставлять код для инвалидации элементов кэша команд после установки трамплинов вложенных функций"
+msgstr "вставлять код для инвалидации элементов кэша команд после установки трамплинов вложенных функций."
 
 #: config/sh/sh.opt:243 config/arc/arc.opt:246
-#, fuzzy
-#| msgid "Annotate assembler instructions with estimated addresses"
 msgid "Annotate assembler instructions with estimated addresses."
-msgstr "Аннотировать ассемблерные инструкции с оцененным адресом"
+msgstr "Аннотировать ассемблерные инструкции с оцененным адресом."
 
 #: config/sh/sh.opt:247
-#, fuzzy
-#| msgid "Generate code in little endian mode"
 msgid "Generate code in little endian mode."
-msgstr "Генерировать код для обратного (little endian) порядка байт"
+msgstr "Генерировать код для обратного (little endian) порядка байт."
 
 #: config/sh/sh.opt:251
-#, fuzzy
-#| msgid "Mark MAC register as call-clobbered"
 msgid "Mark MAC register as call-clobbered."
-msgstr "Регистр MAC портится при вызовах"
+msgstr "Регистр MAC портится при вызовах."
 
 #: config/sh/sh.opt:257
-#, fuzzy
-#| msgid "Make structs a multiple of 4 bytes (warning: ABI altered)"
 msgid "Make structs a multiple of 4 bytes (warning: ABI altered)."
-msgstr "Размер структуры кратен 4 байтам (предупреждение: при этом изменяется ABI)"
+msgstr "Размер структуры кратен 4 байтам (предупреждение: при этом изменяется ABI)."
 
 #: config/sh/sh.opt:261
-#, fuzzy
-#| msgid "Emit function-calls using global offset table when generating PIC"
 msgid "Emit function-calls using global offset table when generating PIC."
-msgstr "Вызывать функции с использованием глобальной таблицы смещений при генерации PIC кода"
+msgstr "Вызывать функции с использованием глобальной таблицы смещений при генерации PIC кода."
 
 #: config/sh/sh.opt:265
-#, fuzzy
-#| msgid "Shorten address references during linking"
 msgid "Shorten address references during linking."
-msgstr "Укорачивать ссылки по адресу во время компоновки"
+msgstr "Укорачивать ссылки по адресу во время компоновки."
 
 #: config/sh/sh.opt:273
-#, fuzzy
-#| msgid "Generate code for built-in atomic operations"
 msgid "Specify the model for atomic operations."
-msgstr "Генерировать код для встроенных атомарных операций"
+msgstr "Задать модель для atomic операций."
 
 #: config/sh/sh.opt:277
 msgid "Use tas.b instruction for __atomic_test_and_set."
-msgstr ""
+msgstr "Использовать tas.b инструкцию для __atomic_test_and_set."
 
 #: config/sh/sh.opt:281
-#, fuzzy
-#| msgid "Cost to assume for a multiply insn"
 msgid "Cost to assume for a multiply insn."
-msgstr "Цена за команду умножения"
+msgstr "Цена за команду умножения."
 
 #: config/sh/sh.opt:285
 msgid "Don't generate privileged-mode only code; implies -mno-inline-ic_invalidate if the inline code would not work in user mode."
-msgstr "Не генерировать только привилегированный код; влечет -mno-inline-ic_invalidate если inline код не будет работать в пользовательском режиме."
+msgstr "Не генерировать только привилегированный код; влечет -mno-inline-ic_invalidate, если inline код не будет работать в пользовательском режиме."
 
 #: config/sh/sh.opt:291
 msgid "Pretend a branch-around-a-move is a conditional move."
-msgstr "Делать вид что branch-around-a-move есть условный move."
+msgstr "Делать вид, что branch-around-a-move есть условный move."
 
 #: config/sh/sh.opt:295
-#, fuzzy
-#| msgid "Enable the use of the short load instructions"
 msgid "Enable the use of the fsca instruction."
-msgstr "Включить использование коротких команд загрузки"
+msgstr "Включить использование fsca инструкции."
 
 #: config/sh/sh.opt:299
-#, fuzzy
-#| msgid "Enable the use of the short load instructions"
 msgid "Enable the use of the fsrra instruction."
-msgstr "Включить использование коротких команд загрузки"
+msgstr "Включить использование fsrra инструкции."
 
 #: config/sh/sh.opt:303
 msgid "Use LRA instead of reload (transitional)."
-msgstr ""
+msgstr "Использовать LRA вместо reload (transitional)."
 
 #: config/fr30/fr30.opt:23
-#, fuzzy
-#| msgid "Assume small address space"
 msgid "Assume small address space."
-msgstr "Предполагать малое адресное пространство"
+msgstr "Предполагать малое адресное пространство."
 
 #: config/mips/mips.opt:32
-#, fuzzy
-#| msgid "-mabi=ABI\tGenerate code that conforms to the given ABI"
 msgid "-mabi=ABI\tGenerate code that conforms to the given ABI."
-msgstr "-mabi=ABI\tГенерировать код в соответствии с заданным ABI"
+msgstr "-mabi=ABI\tГенерировать код в соответствии с заданным ABI."
 
 #: config/mips/mips.opt:36
 msgid "Known MIPS ABIs (for use with the -mabi= option):"
@@ -16206,58 +13132,40 @@
 msgstr "MIPS ABI (возможные аргументы ключа -mabi=):"
 
 #: config/mips/mips.opt:55
-#, fuzzy
-#| msgid "Generate code that can be used in SVR4-style dynamic objects"
 msgid "Generate code that can be used in SVR4-style dynamic objects."
-msgstr "Генерировать код, который может использоваться в динамических объектах SVR4"
+msgstr "Генерировать код, который может использоваться в динамических объектах SVR4."
 
 #: config/mips/mips.opt:59
-#, fuzzy
-#| msgid "Use PMC-style 'mad' instructions"
 msgid "Use PMC-style 'mad' instructions."
-msgstr "Использовать команды 'mad' в стиле PMC"
+msgstr "Использовать команды 'mad' в стиле PMC."
 
 #: config/mips/mips.opt:63
-#, fuzzy
-#| msgid "Use multiply add/subtract instructions"
 msgid "Use integer madd/msub instructions."
-msgstr "Использовать команды плавающего умножения со сложением/вычитанием"
+msgstr "Использовать целочисленные madd/msub инструкции."
 
 #: config/mips/mips.opt:67
-#, fuzzy
-#| msgid "-march=ISA\tGenerate code for the given ISA"
 msgid "-march=ISA\tGenerate code for the given ISA."
-msgstr "-march=ISA\tГенерировать код для указанной системы команд (ISA)"
+msgstr "-march=ISA\tГенерировать код для указанной системы команд (ISA)."
 
 #: config/mips/mips.opt:71
-#, fuzzy
-#| msgid "-mbranch-cost=COST\tSet the cost of branches to roughly COST instructions"
 msgid "-mbranch-cost=COST\tSet the cost of branches to roughly COST instructions."
-msgstr "-mbranch-cost=COST\tУстановить цену переходов равной примерно COST команд"
+msgstr "-mbranch-cost=COST\tУстановить цену переходов равной примерно COST команд."
 
 #: config/mips/mips.opt:75
-#, fuzzy
-#| msgid "Use Branch Likely instructions, overriding the architecture default"
 msgid "Use Branch Likely instructions, overriding the architecture default."
-msgstr "Использовать команды Branch Likely, вопреки умолчанию для указанной архитектуры"
+msgstr "Использовать команды Branch Likely, вопреки умолчанию для указанной архитектуры."
 
 #: config/mips/mips.opt:79
-#, fuzzy
-#| msgid "Switch on/off MIPS16 ASE on alternating functions for compiler testing"
 msgid "Switch on/off MIPS16 ASE on alternating functions for compiler testing."
-msgstr "Включить/выключить MIPS16 ASE на альтернативных функциях для тестирования компилятора"
+msgstr "Включить/выключить MIPS16 ASE на альтернативных функциях для тестирования компилятора."
 
 #: config/mips/mips.opt:83
-#, fuzzy
-#| msgid "Trap on integer divide by zero"
 msgid "Trap on integer divide by zero."
-msgstr "Выдавать прерывание по целочисленному делению на ноль"
+msgstr "Выдавать прерывание по целочисленному делению на ноль."
 
 #: config/mips/mips.opt:87
-#, fuzzy
-#| msgid "-mcode-readable=SETTING\tSpecify when instructions are allowed to access code"
 msgid "-mcode-readable=SETTING\tSpecify when instructions are allowed to access code."
-msgstr "-mcode-readable=SETTING\tЗадать, когда команды имеют доступ к коду"
+msgstr "-mcode-readable=SETTING\tЗадать, когда команды имеют доступ к коду."
 
 #: config/mips/mips.opt:91
 msgid "Valid arguments to -mcode-readable=:"
@@ -16264,322 +13172,220 @@
 msgstr "Допустимые аргументы ключа -mcode-readable=:"
 
 #: config/mips/mips.opt:104
-#, fuzzy
-#| msgid "Use branch-and-break sequences to check for integer divide by zero"
 msgid "Use branch-and-break sequences to check for integer divide by zero."
-msgstr "Проверка целочисленного деления на ноль при помощи ветвлений и команд break"
+msgstr "Проверка целочисленного деления на ноль при помощи ветвлений и команд break."
 
 #: config/mips/mips.opt:108
-#, fuzzy
-#| msgid "Use trap instructions to check for integer divide by zero"
 msgid "Use trap instructions to check for integer divide by zero."
-msgstr "Проверка целочисленного деления на ноль при помощи условных trap"
+msgstr "Проверка целочисленного деления на ноль при помощи условных trap."
 
 #: config/mips/mips.opt:112
-#, fuzzy
-#| msgid "Allow the use of MDMX instructions"
 msgid "Allow the use of MDMX instructions."
-msgstr "Разрешить использование команд MDMX"
+msgstr "Разрешить использование команд MDMX."
 
 #: config/mips/mips.opt:116
-#, fuzzy
-#| msgid "Allow hardware floating-point instructions to cover both 32-bit and 64-bit operations"
 msgid "Allow hardware floating-point instructions to cover both 32-bit and 64-bit operations."
-msgstr "Полагать, что сопроцессор плавающей арифметики поддерживает 32- и 64-битные операции"
+msgstr "Полагать, что сопроцессор плавающей арифметики поддерживает 32- и 64-битные операции."
 
 #: config/mips/mips.opt:120
-#, fuzzy
-#| msgid "Use MIPS-DSP instructions"
 msgid "Use MIPS-DSP instructions."
-msgstr "Использовать команды MIPS-DSP"
+msgstr "Использовать команды MIPS-DSP."
 
 #: config/mips/mips.opt:124
-#, fuzzy
-#| msgid "Use MIPS-DSP REV 2 instructions"
 msgid "Use MIPS-DSP REV 2 instructions."
-msgstr "Использовать команды MIPS-DSP версии 2"
+msgstr "Использовать команды MIPS-DSP версии 2."
 
 #: config/mips/mips.opt:146
-#, fuzzy
-#| msgid "Use the bit-field instructions"
 msgid "Use Enhanced Virtual Addressing instructions."
-msgstr "Использовать команды работы с битовыми полями"
+msgstr "Использовать Enhanced Virtual Addressing инструкции."
 
 #: config/mips/mips.opt:150
-#, fuzzy
-#| msgid "Use NewABI-style %reloc() assembly operators"
 msgid "Use NewABI-style %reloc() assembly operators."
-msgstr "Использовать ассемблерные команды %reloc()"
+msgstr "Использовать ассемблерные команды %reloc()."
 
 #: config/mips/mips.opt:154
-#, fuzzy
-#| msgid "Use -G for data that is not defined by the current object"
 msgid "Use -G for data that is not defined by the current object."
-msgstr "Использовать -G для данных, которые не определены текущим объектом"
+msgstr "Использовать -G для данных, которые не определены текущим объектом."
 
 #: config/mips/mips.opt:158
-#, fuzzy
-#| msgid "Work around certain 24K errata"
 msgid "Work around certain 24K errata."
-msgstr "Обходить некоторые ошибки процессора 24K"
+msgstr "Обходить некоторые ошибки процессора 24K."
 
 #: config/mips/mips.opt:162
-#, fuzzy
-#| msgid "Work around certain R4000 errata"
 msgid "Work around certain R4000 errata."
-msgstr "Обходить некоторые ошибки процессора R4000"
+msgstr "Обходить некоторые ошибки процессора R4000."
 
 #: config/mips/mips.opt:166
-#, fuzzy
-#| msgid "Work around certain R4400 errata"
 msgid "Work around certain R4400 errata."
-msgstr "Обходить некоторые ошибки процессора R4400"
+msgstr "Обходить некоторые ошибки процессора R4400."
 
 #: config/mips/mips.opt:170
-#, fuzzy
-#| msgid "Work around certain R4000 errata"
 msgid "Work around certain RM7000 errata."
-msgstr "Обходить некоторые ошибки процессора R4000"
+msgstr "Обходить некоторые ошибки процессора RM7000."
 
 #: config/mips/mips.opt:174
-#, fuzzy
-#| msgid "Work around certain R10000 errata"
 msgid "Work around certain R10000 errata."
-msgstr "Обходить некоторые ошибки процессора R10000"
+msgstr "Обходить некоторые ошибки процессора R10000."
 
 #: config/mips/mips.opt:178
-#, fuzzy
-#| msgid "Work around errata for early SB-1 revision 2 cores"
 msgid "Work around errata for early SB-1 revision 2 cores."
-msgstr "Обходить старую аппаратную ошибку SB-1 версии 2"
+msgstr "Обходить старую аппаратную ошибку SB-1 версии 2."
 
 #: config/mips/mips.opt:182
-#, fuzzy
-#| msgid "Work around certain VR4120 errata"
 msgid "Work around certain VR4120 errata."
-msgstr "Обходить некоторые ошибки VR4120"
+msgstr "Обходить некоторые ошибки VR4120."
 
 #: config/mips/mips.opt:186
-#, fuzzy
-#| msgid "Work around VR4130 mflo/mfhi errata"
 msgid "Work around VR4130 mflo/mfhi errata."
-msgstr "Обходить ошибки mflo/mfhi процессора VR4130"
+msgstr "Обходить ошибки mflo/mfhi процессора VR4130."
 
 #: config/mips/mips.opt:190
-#, fuzzy
-#| msgid "Work around an early 4300 hardware bug"
 msgid "Work around an early 4300 hardware bug."
-msgstr "Обходить старую аппаратную ошибку 4300"
+msgstr "Обходить старую аппаратную ошибку 4300."
 
 #: config/mips/mips.opt:194
-#, fuzzy
-#| msgid "FP exceptions are enabled"
 msgid "FP exceptions are enabled."
-msgstr "включены прерывания сопроцессора плавающей арифметики"
+msgstr "Включены прерывания сопроцессора плавающей арифметики."
 
 #: config/mips/mips.opt:198
-#, fuzzy
-#| msgid "Use 32-bit floating-point registers"
 msgid "Use 32-bit floating-point registers."
-msgstr "Использовать 32-битные регистры сопроцессора плавающей арифметики"
+msgstr "Использовать 32-битные регистры сопроцессора плавающей арифметики."
 
 #: config/mips/mips.opt:202
 msgid "Conform to the o32 FPXX ABI."
-msgstr ""
+msgstr "Соответствовать o32 FPXX ABI."
 
 #: config/mips/mips.opt:206
-#, fuzzy
-#| msgid "Use 64-bit floating-point registers"
 msgid "Use 64-bit floating-point registers."
-msgstr "Использовать 64-битные регистры сопроцессора плавающей арифметики"
+msgstr "Использовать 64-битные регистры сопроцессора плавающей арифметики."
 
 #: config/mips/mips.opt:210
-#, fuzzy
-#| msgid "-mflush-func=FUNC\tUse FUNC to flush the cache before calling stack trampolines"
 msgid "-mflush-func=FUNC\tUse FUNC to flush the cache before calling stack trampolines."
-msgstr "-mflush-func=ФУНКЦИЯ\tИспользовать указанную ФУНКЦИЮ для сброса кэша перед вызовом стековых трамплинов"
+msgstr "-mflush-func=ФУНКЦИЯ\tИспользовать указанную ФУНКЦИЮ для сброса кэша перед вызовом стековых трамплинов."
 
 #: config/mips/mips.opt:214
 msgid "-mabs=MODE\tSelect the IEEE 754 ABS/NEG instruction execution mode."
-msgstr ""
+msgstr "-mabs=MODE\tВыбирает IEEE 754 ABS/NEG режим выполнения инструкций."
 
 #: config/mips/mips.opt:218
 msgid "-mnan=ENCODING\tSelect the IEEE 754 NaN data encoding."
-msgstr ""
+msgstr "-mnan=ENCODING\tВыбирает IEEE 754 NaN кодирование данных."
 
 #: config/mips/mips.opt:222
-#, fuzzy
-#| msgid "Known MIPS CPUs (for use with the -march= and -mtune= options):"
 msgid "Known MIPS IEEE 754 settings (for use with the -mabs= and -mnan= options):"
-msgstr "Известные процессоры MIPS (могут быть заданы как аргументы -march= и -mtune=)"
+msgstr "Известные MIPS IEEE 754 установки (для использования с -mabs= и -mnan= опциями):"
 
 #: config/mips/mips.opt:232
-#, fuzzy
-#| msgid "Use 32-bit general registers"
 msgid "Use 32-bit general registers."
-msgstr "Использовать 32-битные регистры общего назначения"
+msgstr "Использовать 32-битные регистры общего назначения."
 
 #: config/mips/mips.opt:236
-#, fuzzy
-#| msgid "Use 64-bit general registers"
 msgid "Use 64-bit general registers."
-msgstr "Использовать 64-битные регистры общего назначения"
+msgstr "Использовать 64-битные регистры общего назначения."
 
 #: config/mips/mips.opt:240
-#, fuzzy
-#| msgid "Use GP-relative addressing to access small data"
 msgid "Use GP-relative addressing to access small data."
-msgstr "Использовать адресацию относительно GP для доступа к данным малого размера"
+msgstr "Использовать адресацию относительно GP для доступа к данным малого размера."
 
 #: config/mips/mips.opt:244
-#, fuzzy
-#| msgid "When generating -mabicalls code, allow executables to use PLTs and copy relocations"
 msgid "When generating -mabicalls code, allow executables to use PLTs and copy relocations."
-msgstr "При генерации кода -mabicalls разрешить выполняемому модулю использование PLT и копирование перемещений"
+msgstr "При генерации кода -mabicalls разрешить выполняемому модулю использование PLT и копирование перемещений."
 
 #: config/mips/mips.opt:248
-#, fuzzy
-#| msgid "Allow the use of hardware floating-point ABI and instructions"
 msgid "Allow the use of hardware floating-point ABI and instructions."
-msgstr "Разрешить использование аппаратных команд и ABI для операций с плавающей точкой"
+msgstr "Разрешить использование аппаратных команд и ABI для операций с плавающей точкой."
 
 #: config/mips/mips.opt:252
-#, fuzzy
-#| msgid "Generate code that can be safely linked with MIPS16 code."
 msgid "Generate code that is link-compatible with MIPS16 and microMIPS code."
-msgstr "Генерировать код, который может быть скомпонован с кодом MIPS16."
+msgstr "Генерировать код, который может быть скомпонован с кодом MIPS16 и microMIPS."
 
 #: config/mips/mips.opt:256
-#, fuzzy
-#| msgid "Does nothing. Preserved for backward compatibility."
 msgid "An alias for minterlink-compressed provided for backward-compatibility."
-msgstr "Игнорируется. Сохранен для обратной совместимости."
+msgstr "Синоним для minterlink-compressed предоставлен для обратной совместимости."
 
 #: config/mips/mips.opt:260
-#, fuzzy
-#| msgid "-mipsN\tGenerate code for ISA level N"
 msgid "-mipsN\tGenerate code for ISA level N."
-msgstr "-mipsN\tГенерировать код для ассемблера ISA уровня N"
+msgstr "-mipsN\tГенерировать код для ISA уровня N."
 
 #: config/mips/mips.opt:264
-#, fuzzy
-#| msgid "Generate MIPS16 code"
 msgid "Generate MIPS16 code."
-msgstr "Генерировать код MIPS16"
+msgstr "Генерировать код MIPS16."
 
 #: config/mips/mips.opt:268
-#, fuzzy
-#| msgid "Use MIPS-3D instructions"
 msgid "Use MIPS-3D instructions."
-msgstr "Использовать команды MIPS-3D"
+msgstr "Использовать команды MIPS-3D."
 
 #: config/mips/mips.opt:272
-#, fuzzy
-#| msgid "Use ll, sc and sync instructions"
 msgid "Use ll, sc and sync instructions."
-msgstr "Использовать команды ll, sc и sync"
+msgstr "Использовать команды ll, sc и sync."
 
 #: config/mips/mips.opt:276
-#, fuzzy
-#| msgid "Use -G for object-local data"
 msgid "Use -G for object-local data."
-msgstr "Использовать -G для доступа к локальным данным модуля"
+msgstr "Использовать -G для доступа к локальным данным модуля."
 
 #: config/mips/mips.opt:280
-#, fuzzy
-#| msgid "Use indirect calls"
 msgid "Use indirect calls."
-msgstr "Использовать косвенные вызовы"
+msgstr "Использовать косвенные вызовы."
 
 #: config/mips/mips.opt:284
-#, fuzzy
-#| msgid "Use a 32-bit long type"
 msgid "Use a 32-bit long type."
-msgstr "Использовать 32-битное представление для типа long"
+msgstr "Использовать 32-битное представление для типа long."
 
 #: config/mips/mips.opt:288
-#, fuzzy
-#| msgid "Use a 64-bit long type"
 msgid "Use a 64-bit long type."
-msgstr "Использовать 64-битное представление для типа long"
+msgstr "Использовать 64-битное представление для типа long."
 
 #: config/mips/mips.opt:292
-#, fuzzy
-#| msgid "Pass the address of the ra save location to _mcount in $12"
 msgid "Pass the address of the ra save location to _mcount in $12."
-msgstr "Передать адрес, где сохранен ra функции _mcount в $12"
+msgstr "Передать адрес, где сохранен ra функции _mcount в $12."
 
 #: config/mips/mips.opt:296
-#, fuzzy
-#| msgid "Don't optimize block moves"
 msgid "Don't optimize block moves."
-msgstr "Не оптимизировать блочные пересылки"
+msgstr "Не оптимизировать блочные пересылки."
 
 #: config/mips/mips.opt:300
-#, fuzzy
-#| msgid "Use SmartMIPS instructions"
 msgid "Use microMIPS instructions."
-msgstr "Использовать команды SmartMIPS"
+msgstr "Использовать microMIPS инструкции."
 
 #: config/mips/mips.opt:304
-#, fuzzy
-#| msgid "Use MIPS-DSP instructions"
 msgid "Use MIPS MSA Extension instructions."
-msgstr "Использовать команды MIPS-DSP"
+msgstr "Использовать MIPS MSA Extension инструкции."
 
 #: config/mips/mips.opt:308
-#, fuzzy
-#| msgid "Allow the use of MT instructions"
 msgid "Allow the use of MT instructions."
-msgstr "Использовать команды MT"
+msgstr "Использовать команды MT."
 
 #: config/mips/mips.opt:312
-#, fuzzy
-#| msgid "Prevent the use of all floating-point operations"
 msgid "Prevent the use of all floating-point operations."
-msgstr "Не использовать аппаратную реализацию плавающих операций"
+msgstr "Не использовать аппаратную реализацию плавающих операций."
 
 #: config/mips/mips.opt:316
-#, fuzzy
-#| msgid "Use MIPS-3D instructions"
 msgid "Use MCU instructions."
-msgstr "Использовать команды MIPS-3D"
+msgstr "Использовать MCU инструкции."
 
 #: config/mips/mips.opt:320
-#, fuzzy
-#| msgid "Do not use a cache-flushing function before calling stack trampolines"
 msgid "Do not use a cache-flushing function before calling stack trampolines."
-msgstr "Не использовать функцию сброса кэша перед вызовом стекового трамплина"
+msgstr "Не использовать функцию сброса кэша перед вызовом стекового трамплина."
 
 #: config/mips/mips.opt:324
-#, fuzzy
-#| msgid "Do not use MDMX instructions"
 msgid "Do not use MDMX instructions."
-msgstr "Не использовать команды MDMX"
+msgstr "Не использовать команды MDMX."
 
 #: config/mips/mips.opt:328
-#, fuzzy
-#| msgid "Generate normal-mode code"
 msgid "Generate normal-mode code."
-msgstr "Генерировать обычный код"
+msgstr "Генерировать обычный код."
 
 #: config/mips/mips.opt:332
-#, fuzzy
-#| msgid "Do not use MIPS-3D instructions"
 msgid "Do not use MIPS-3D instructions."
-msgstr "Не использовать команды MIPS-3D"
+msgstr "Не использовать команды MIPS-3D."
 
 #: config/mips/mips.opt:336
-#, fuzzy
-#| msgid "Use paired-single floating-point instructions"
 msgid "Use paired-single floating-point instructions."
-msgstr "Использовать команды плавающей арифметики формата paired-single (над парами значений одинарной точности)"
+msgstr "Использовать команды плавающей арифметики формата paired-single (над парами значений одинарной точности)."
 
 #: config/mips/mips.opt:340
-#, fuzzy
-#| msgid "-mr10k-cache-barrier=SETTING\tSpecify when r10k cache barriers should be inserted"
 msgid "-mr10k-cache-barrier=SETTING\tSpecify when r10k cache barriers should be inserted."
-msgstr "-mr10k-cache-barrier=SETTING\tУказать, когда должны вставляться барьеры кэша r10k"
+msgstr "-mr10k-cache-barrier=SETTING\tУказать, когда должны вставляться барьеры кэша r10k."
 
 #: config/mips/mips.opt:344
 msgid "Valid arguments to -mr10k-cache-barrier=:"
@@ -16586,110 +13392,80 @@
 msgstr "Возможные аргументы ключа -mr10k-cache-barrier=:"
 
 #: config/mips/mips.opt:357
-#, fuzzy
-#| msgid "Try to allow the linker to turn PIC calls into direct calls"
 msgid "Try to allow the linker to turn PIC calls into direct calls."
-msgstr "Позволить компоновщику преобразовывать PIC-вызовы в прямые вызовы"
+msgstr "Позволить компоновщику преобразовывать PIC-вызовы в прямые вызовы."
 
 #: config/mips/mips.opt:361
-#, fuzzy
-#| msgid "When generating -mabicalls code, make the code suitable for use in shared libraries"
 msgid "When generating -mabicalls code, make the code suitable for use in shared libraries."
-msgstr "При генерации кода -mabicalls генерировать код, подходящий для использования в разделяемых библиотеках"
+msgstr "При генерации кода -mabicalls генерировать код, подходящий для использования в разделяемых библиотеках."
 
 #: config/mips/mips.opt:365
-#, fuzzy
-#| msgid "Restrict the use of hardware floating-point instructions to 32-bit operations"
 msgid "Restrict the use of hardware floating-point instructions to 32-bit operations."
-msgstr "Ограничить использование плавающей арифметики операциями над 32-битными значениями"
+msgstr "Ограничить использование плавающей арифметики операциями над 32-битными значениями."
 
 #: config/mips/mips.opt:369
-#, fuzzy
-#| msgid "Use SmartMIPS instructions"
 msgid "Use SmartMIPS instructions."
-msgstr "Использовать команды SmartMIPS"
+msgstr "Использовать команды SmartMIPS."
 
 #: config/mips/mips.opt:373
-#, fuzzy
-#| msgid "Prevent the use of all hardware floating-point instructions"
 msgid "Prevent the use of all hardware floating-point instructions."
-msgstr "Не использовать аппаратную реализацию плавающих операций"
+msgstr "Не использовать аппаратную реализацию плавающих операций."
 
 #: config/mips/mips.opt:377
-#, fuzzy
-#| msgid "Optimize lui/addiu address loads"
 msgid "Optimize lui/addiu address loads."
-msgstr "Оптимизировать команды lui/addiu при загрузке адресов"
+msgstr "Оптимизировать команды lui/addiu при загрузке адресов."
 
 #: config/mips/mips.opt:381
-#, fuzzy
-#| msgid "Assume all symbols have 32-bit values"
 msgid "Assume all symbols have 32-bit values."
-msgstr "Предполагать, что все символы имеют 32-битные значения"
+msgstr "Предполагать, что все символы имеют 32-битные значения."
 
 #: config/mips/mips.opt:385
-#, fuzzy
-#| msgid "Use synci instruction to invalidate i-cache"
 msgid "Use synci instruction to invalidate i-cache."
-msgstr "Использовать команды synci для инвалидации кэша инструкций"
+msgstr "Использовать команды synci для инвалидации кэша инструкций."
 
 #: config/mips/mips.opt:393
 msgid "Use lwxc1/swxc1/ldxc1/sdxc1 instructions where applicable."
-msgstr ""
+msgstr "Использовать lwxc1/swxc1/ldxc1/sdxc1 инструкции где возможно."
 
 #: config/mips/mips.opt:397
 msgid "Use 4-operand madd.s/madd.d and related instructions where applicable."
-msgstr ""
+msgstr "Использовать 4-операндные madd.s/madd.d и связанные с ними инструкции где возможно."
 
 #: config/mips/mips.opt:409
-#, fuzzy
-#| msgid "Use decimal floating point instructions"
 msgid "Use Virtualization (VZ) instructions."
-msgstr "Использовать инструкции десятичных плавающих"
+msgstr "Использовать Virtualization (VZ) инструкции."
 
 #: config/mips/mips.opt:413
-#, fuzzy
-#| msgid "Use vector/scalar (VSX) instructions"
 msgid "Use eXtended Physical Address (XPA) instructions."
-msgstr "Использовать vector/scalar (VSX) инструкции"
+msgstr "Использовать eXtended Physical Address (XPA) инструкции."
 
 #: config/mips/mips.opt:417
-#, fuzzy
-#| msgid "Perform VR4130-specific alignment optimizations"
 msgid "Perform VR4130-specific alignment optimizations."
-msgstr "Выполнить специфические для VR4130 оптимизации выравнивания"
+msgstr "Выполнить специфические для VR4130 оптимизации выравнивания."
 
 #: config/mips/mips.opt:421
-#, fuzzy
-#| msgid "Lift restrictions on GOT size"
 msgid "Lift restrictions on GOT size."
-msgstr "Поднять ограничение на размер GOT"
+msgstr "Поднять ограничение на размер GOT."
 
 #: config/mips/mips.opt:425
-#, fuzzy
-#| msgid "Don't allocate floats and doubles in extended-precision registers"
 msgid "Enable use of odd-numbered single-precision registers."
-msgstr "Не выделять для значений типа float и double регистры повышенной точности"
+msgstr "Включить использование регистров одинарной точности с нечетными номерами."
 
 #: config/mips/mips.opt:429
-#, fuzzy
-#| msgid "Optimize for space rather than speed"
 msgid "Optimize frame header."
-msgstr "Оптимизировать размер, а не быстродействие"
+msgstr "Оптимизировать заголовок кадра."
 
 #: config/mips/mips.opt:436
-#, fuzzy
-#| msgid "Enable dead store elimination"
 msgid "Enable load/store bonding."
-msgstr "Выполнить оптимизацию удаления мертвых команд записи в память"
+msgstr "Включить load/store сцепление."
 
 #: config/mips/mips.opt:440
 msgid "Specify the compact branch usage policy."
-msgstr ""
+msgstr "Задать политику использования компактных ветвлений."
 
 #: config/mips/mips.opt:444
 msgid "Policies available for use with -mcompact-branches=:"
-msgstr ""
+msgstr "Политики доступные для использования с -mcompact-branches=:"
 
 #: config/mips/mips-tables.opt:24
 msgid "Known MIPS CPUs (for use with the -march= and -mtune= options):"
@@ -16712,56 +13488,44 @@
 msgstr "Компилировать с 64-битными длинными и указателями."
 
 #: config/tilegx/tilegx.opt:53
-#, fuzzy
-#| msgid "Use given x86-64 code model"
 msgid "Use given TILE-Gx code model."
-msgstr "Использовать указанную модель кода x86-64"
+msgstr "Использовать указанную модель кода TILE-Gx."
 
 #: config/arc/arc-tables.opt:25
-#, fuzzy
-#| msgid "Known FR-V CPUs (for use with the -mcpu= option):"
 msgid "Known ARC CPUs (for use with the -mcpu= option):"
-msgstr "Имена процессоров FR-V (могут использоваться как аргументы ключа -mcpu= ):"
+msgstr "Известные ARC CPUs (для использования с -mcpu= опцией):"
 
 #: config/arc/arc.opt:26
-#, fuzzy
-#| msgid "Generate code in big endian mode"
 msgid "Compile code for big endian mode."
-msgstr "Генерировать код для прямого (big endian) порядка байт"
+msgstr "Генерировать код для прямого (big endian) порядка байт."
 
 #: config/arc/arc.opt:30
-#, fuzzy
-#| msgid "Stores doubles in 32 bits.  This is the default."
 msgid "Compile code for little endian mode.  This is the default."
-msgstr "Хранить doubles в 32 битах.  Это умолчание."
+msgstr "Compile code for little endian mode.  Используется по умолчанию."
 
 #: config/arc/arc.opt:34
 msgid "Disable ARCompact specific pass to generate conditional execution instructions."
-msgstr ""
+msgstr "Выключить ARCompact специфичный проход для генерации инструкций условного выполнения."
 
 #: config/arc/arc.opt:38
 msgid "Generate ARCompact 32-bit code for ARC600 processor."
-msgstr ""
+msgstr "Генерировать ARCompact 32-битный код для ARC600 процессора."
 
 #: config/arc/arc.opt:42
-#, fuzzy
-#| msgid "Same as -k128rio"
 msgid "Same as -mA6."
-msgstr "То же, что -k128rio"
+msgstr "То же, что -mA6."
 
 #: config/arc/arc.opt:46
 msgid "Generate ARCompact 32-bit code for ARC601 processor."
-msgstr ""
+msgstr "Генерировать ARCompact 32-битный код для ARC601 процессора."
 
 #: config/arc/arc.opt:50
 msgid "Generate ARCompact 32-bit code for ARC700 processor."
-msgstr ""
+msgstr "Генерировать ARCompact 32-битный код для ARC700 процессора."
 
 #: config/arc/arc.opt:54
-#, fuzzy
-#| msgid "Same as -k128rio"
 msgid "Same as -mA7."
-msgstr "То же, что -k128rio"
+msgstr "То же, что -mA7."
 
 #: config/arc/arc.opt:58
 msgid "Force all calls to be made via a jli instruction."
@@ -16769,63 +13533,47 @@
 
 #: config/arc/arc.opt:62
 msgid "-mmpy-option=MPY Compile ARCv2 code with a multiplier design option."
-msgstr ""
+msgstr "-mmpy-option=MPY Компилировать ARCv2 код с опцией проектирования умножителя."
 
 #: config/arc/arc.opt:132
-#, fuzzy
-#| msgid "Enable clip instructions"
 msgid "Enable DIV-REM instructions for ARCv2."
-msgstr "Включить clip инструкции"
+msgstr "Включить DIV-REM инструкции для ARCv2."
 
 #: config/arc/arc.opt:136
-#, fuzzy
-#| msgid "Enable barrel shift instructions"
 msgid "Enable code density instructions for ARCv2."
-msgstr "Включить инструкции циклического сдвига"
+msgstr "Включить инструкции уплотнения кода для ARCv2."
 
 #: config/arc/arc.opt:140
-#, fuzzy
-#| msgid "preferentially allocate registers that allow short instruction generation."
 msgid "Tweak register allocation to help 16-bit instruction generation."
-msgstr "Предпочтительно выделять регистры которые допускают генерацию коротких инструкций."
+msgstr "Настроить распределение регистров так, чтобы помочь генерации 16-битных инструкций."
 
 #: config/arc/arc.opt:150
 msgid "Use ordinarily cached memory accesses for volatile references."
-msgstr ""
+msgstr "Использовать обычно кэшируемые доступы к памяти для обращений к волатильной памяти."
 
 #: config/arc/arc.opt:154
 msgid "Enable cache bypass for volatile references."
-msgstr ""
+msgstr "Включить обход кэша для обращений к волатильной памяти."
 
 #: config/arc/arc.opt:158
-#, fuzzy
-#| msgid "Generate string instructions for block moves"
 msgid "Generate instructions supported by barrel shifter."
-msgstr "Генерировать строковые команды для блочных пересылок"
+msgstr "Генерировать инструкции поддержанные устройством циклического сдвига."
 
 #: config/arc/arc.opt:162
-#, fuzzy
-#| msgid "Generate bit instructions"
 msgid "Generate norm instruction."
-msgstr "Генерировать битовые инструкции"
+msgstr "Генерировать нормальные инструкции"
 
 #: config/arc/arc.opt:166
-#, fuzzy
-#| msgid "Generate isel instructions"
 msgid "Generate swap instruction."
-msgstr "Генерировать команды isel"
+msgstr "Генерировать swap инструкции."
 
 #: config/arc/arc.opt:170
-#, fuzzy
-#| msgid "Generate load/store multiple instructions"
 msgid "Generate mul64 and mulu64 instructions."
-msgstr "Генерировать команды множественного чтения/записи"
+msgstr "Генерировать mul64 и mulu64 инструкции."
 
 #: config/arc/arc.opt:174
-#, fuzzy
-#| msgid "Do not generate fused multiply/add instructions"
 msgid "Do not generate mpy instructions for ARC700."
-msgstr "Не генерировать команды умножения с накоплением"
+msgstr "Не генерировать mpy инструкции для ARC700."
 
 #: config/arc/arc.opt:178
 msgid "Generate Extended arithmetic instructions.  Currently only divaw, adds, subs and sat16 are supported."
@@ -16836,16 +13584,12 @@
 msgstr ""
 
 #: config/arc/arc.opt:186
-#, fuzzy
-#| msgid "Generate call insns as indirect calls"
 msgid "Generate call insns as register indirect calls."
-msgstr "Генерировать инструкции вызова как косвенные вызовы"
+msgstr "Генерировать инструкции вызова как регистровые косвенные вызовы"
 
 #: config/arc/arc.opt:190
-#, fuzzy
-#| msgid "Generate cld instruction in the function prologue."
 msgid "Do no generate BRcc instructions in arc_reorg."
-msgstr "Генерировать команду cld в прологе функции."
+msgstr "Генерировать BRcc инструкции в arc_reorg."
 
 #: config/arc/arc.opt:194
 msgid "Generate sdata references.  This is the default, unless you compile for PIC."
@@ -16853,269 +13597,209 @@
 
 #: config/arc/arc.opt:198
 msgid "Do not generate millicode thunks (needed only with -Os)."
-msgstr ""
+msgstr "Не генерировать millicode шлюзы (нужно только с -Os)."
 
 #: config/arc/arc.opt:202 config/arc/arc.opt:206
 msgid "FPX: Generate Single Precision FPX (compact) instructions."
-msgstr ""
+msgstr "FPX: Генерировать Single Precision FPX (compact) инструкции."
 
 #: config/arc/arc.opt:210
-#, fuzzy
-#| msgid "Generate bit instructions"
 msgid "FPX: Generate Single Precision FPX (fast) instructions."
-msgstr "Генерировать битовые инструкции"
+msgstr "FPX: Генерировать Single Precision FPX (fast) инструкции."
 
 #: config/arc/arc.opt:214
 msgid "FPX: Enable Argonaut ARC CPU Double Precision Floating Point extensions."
-msgstr ""
+msgstr "FPX: Включить Argonaut ARC CPU Double Precision Floating Point расширения."
 
 #: config/arc/arc.opt:218 config/arc/arc.opt:222
-#, fuzzy
-#| msgid "Generate bit instructions"
 msgid "FPX: Generate Double Precision FPX (compact) instructions."
-msgstr "Генерировать битовые инструкции"
+msgstr "FPX: Генерировать Double Precision FPX (compact) инструкции."
 
 #: config/arc/arc.opt:226
-#, fuzzy
-#| msgid "Generate bit instructions"
 msgid "FPX: Generate Double Precision FPX (fast) instructions."
-msgstr "Генерировать битовые инструкции"
+msgstr "FPX: Генерировать Double Precision FPX (fast) инструкции."
 
 #: config/arc/arc.opt:230
 msgid "Disable LR and SR instructions from using FPX extension aux registers."
-msgstr ""
+msgstr "Выключить использование LR и SR инструкциями aux регистров FPX расширения."
 
 #: config/arc/arc.opt:234
 msgid "Enable generation of ARC SIMD instructions via target-specific builtins."
-msgstr ""
+msgstr "Включить генерацию ARC SIMD инструкций в платформно-зависимых встроенных функциях."
 
 #
 #: config/arc/arc.opt:238
-#, fuzzy
-#| msgid "-mcpu=CPU\tCompile code for ARC variant CPU"
 msgid "-mcpu=CPU\tCompile code for ARC variant CPU."
-msgstr "-mcpu=CPU\tКомпилировать код для ARC варианта CPU"
+msgstr "-mcpu=CPU\tКомпилировать код для ARC варианта CPU."
 
 #: config/arc/arc.opt:242
 msgid "size optimization level: 0:none 1:opportunistic 2: regalloc 3:drop align, -Os."
-msgstr ""
+msgstr "уровень оптимизации размера: 0:ничего 1:по возможности 2: обычное размещение 3: не выравнивать, -Os."
 
 #: config/arc/arc.opt:250
-#, fuzzy
-#| msgid "Cost to assume for a multiply insn"
 msgid "Cost to assume for a multiply instruction, with 4 being equal to a normal insn."
-msgstr "Цена за команду умножения"
+msgstr "Предполагаемая цена для инструкции умножения, 4 равно нормальной инструкции."
 
 #
 #: config/arc/arc.opt:254
-#, fuzzy
-#| msgid "-mcpu=CPU\tCompile code for ARC variant CPU"
 msgid "-mcpu=TUNE Tune code for given ARC variant."
-msgstr "-mcpu=CPU\tКомпилировать код для ARC варианта CPU"
+msgstr ""
 
 #: config/arc/arc.opt:282
-#, fuzzy
-#| msgid "Enable the use of the short load instructions"
 msgid "Enable the use of indexed loads."
-msgstr "Включить использование коротких команд загрузки"
+msgstr "Включить использование индексированных загрузок."
 
 #: config/arc/arc.opt:286
 msgid "Enable the use of pre/post modify with register displacement."
-msgstr ""
+msgstr "Включить использование pre/post modify с регистром смещения."
 
 #: config/arc/arc.opt:290
-#, fuzzy
-#| msgid "Generate fused multiply/add instructions"
 msgid "Generate 32x16 multiply and mac instructions."
-msgstr "Использовать команды умножения с накоплением"
+msgstr "Генерировать 32x16 умножения и mac инструкции."
 
 #: config/arc/arc.opt:296
 msgid "Set probability threshold for unaligning branches."
-msgstr ""
+msgstr "Установить порог вероятности для невыровненных ветвлений."
 
 #: config/arc/arc.opt:300
 msgid "Don't use less than 25 bit addressing range for calls."
-msgstr ""
+msgstr "Не использовать диапазоны адресации менее 25 бит для вызовов."
 
 #: config/arc/arc.opt:304
 msgid "Explain what alignment considerations lead to the decision to make an insn short or long."
-msgstr ""
+msgstr "Объяснить, какие соображения выравнивания определили решение, сделать ли инструкцию короткой или длинной."
 
 #: config/arc/arc.opt:308
-#, fuzzy
-#| msgid "Avoid all range limits on call instructions"
 msgid "Do alignment optimizations for call instructions."
-msgstr "Не устанавливать предельные диапазоны для команд вызова"
+msgstr "Выполнять оптимизации выравнивания для инструкций вызова."
 
 #: config/arc/arc.opt:312
 msgid "Enable Rcq constraint handling - most short code generation depends on this."
-msgstr ""
+msgstr "Включить обработку Rcq ограничения - генерация короткого кода существенно зависит от этого."
 
 #: config/arc/arc.opt:316
 msgid "Enable Rcw constraint handling - ccfsm condexec mostly depends on this."
-msgstr ""
+msgstr "Включить обработку Rcw ограничения - ccfsm condexec существенно зависит от этого."
 
 #: config/arc/arc.opt:320
-#, fuzzy
-#| msgid "Enable cbranchdi4 pattern"
 msgid "Enable pre-reload use of cbranchsi pattern."
-msgstr "Включить cbranchdi4 шаблон"
+msgstr "Включить pre-reload использование cbranchsi шаблона."
 
 #: config/arc/arc.opt:324
 msgid "Enable bbit peephole2."
-msgstr ""
+msgstr "Включить bbit peephole2."
 
 #: config/arc/arc.opt:328
 msgid "Use pc-relative switch case tables - this enables case table shortening."
-msgstr ""
+msgstr "Использовать switch case таблицы относительно pc - это укорачивает case таблицы."
 
 #: config/arc/arc.opt:332
-#, fuzzy
-#| msgid "Enable cbranchdi4 pattern"
 msgid "Enable compact casesi pattern."
-msgstr "Включить cbranchdi4 шаблон"
+msgstr "Включить compact casesi шаблон."
 
 #: config/arc/arc.opt:336
-#, fuzzy
-#| msgid "Enable clip instructions"
 msgid "Enable 'q' instruction alternatives."
-msgstr "Включить clip инструкции"
+msgstr "Включить альтернативы 'q' инструкции."
 
 #: config/arc/arc.opt:340
 msgid "Expand adddi3 and subdi3 at rtl generation time into add.f / adc etc."
-msgstr ""
+msgstr "Расширять adddi3 и subdi3 при генерации rtl в add.f / adc и т.д."
 
 #: config/arc/arc.opt:347
 msgid "Enable variable polynomial CRC extension."
-msgstr ""
+msgstr "Включить переменное полиномиальное CRC расширение."
 
 #: config/arc/arc.opt:351
-#, fuzzy
-#| msgid "Enable Plan 9 language extensions"
 msgid "Enable DSP 3.1 Pack A extensions."
-msgstr "Включить расширения языка Plan 9"
+msgstr "Включить DSP 3.1 Pack A расширения."
 
 #: config/arc/arc.opt:355
-#, fuzzy
-#| msgid "Enable linker relaxation."
 msgid "Enable dual viterbi butterfly extension."
-msgstr "Включить ослабления компоновщиком."
+msgstr "Включить dual viterbi butterfly расширение."
 
 #: config/arc/arc.opt:365
-#, fuzzy
-#| msgid "Enable leading zero instructions"
 msgid "Enable Dual and Single Operand Instructions for Telephony."
-msgstr "Включить инструкции с ведущим нулем"
+msgstr "Включить Dual and Single Operand Instructions for Telephony."
 
 #: config/arc/arc.opt:369
 msgid "Enable XY Memory extension (DSP version 3)."
-msgstr ""
+msgstr "Включить XY Memory расширение (DSP version 3)."
 
 #: config/arc/arc.opt:374
-#, fuzzy
-#| msgid "Enable hoisting loads from conditional pointers."
 msgid "Enable Locked Load/Store Conditional extension."
-msgstr "Выполнять поднятие загрузок по условным указателям"
+msgstr "Включить Locked Load/Store Conditional расширение."
 
 #: config/arc/arc.opt:378
-#, fuzzy
-#| msgid "Enable sign extend instructions"
 msgid "Enable swap byte ordering extension instruction."
-msgstr "Включить инструкции размножения знака"
+msgstr "Включить swap byte ordering инструкцию расширения."
 
 #: config/arc/arc.opt:382
-#, fuzzy
-#| msgid "Enable bit manipulation instructions"
 msgid "Enable 64-bit Time-Stamp Counter extension instruction."
-msgstr "Включить инструкции манипуляций с битами"
+msgstr "Включить 64-битную Time-Stamp Counter инструкцию расширения."
 
 #: config/arc/arc.opt:386
-#, fuzzy
-#| msgid "Pass -z text to linker"
 msgid "Pass -EB option through to linker."
-msgstr "Передать компоновщику ключ -z"
+msgstr "Передать -EB опцию далее компоновщику."
 
 #: config/arc/arc.opt:390
-#, fuzzy
-#| msgid "Pass -z text to linker"
 msgid "Pass -EL option through to linker."
-msgstr "Передать компоновщику ключ -z"
+msgstr "Передать -EL опцию далее компоновщику."
 
 #: config/arc/arc.opt:394
-#, fuzzy
-#| msgid "Pass -z text to linker"
 msgid "Pass -marclinux option through to linker."
-msgstr "Передать компоновщику ключ -z"
+msgstr "Передать -marclinux опцию далее компоновщику."
 
 #: config/arc/arc.opt:398
 msgid "Pass -marclinux_prof option through to linker."
-msgstr ""
+msgstr "Передать -marclinux_prof ключ компоновщику."
 
 #: config/arc/arc.opt:406
-#, fuzzy
-#| msgid "Enable linker relaxation."
 msgid "Enable lra."
-msgstr "Включить ослабления компоновщиком."
+msgstr "Включить lra."
 
 #: config/arc/arc.opt:410
 msgid "Don't indicate any priority with TARGET_REGISTER_PRIORITY."
-msgstr ""
+msgstr "Не указывать приоритет с TARGET_REGISTER_PRIORITY."
 
 #: config/arc/arc.opt:414
 msgid "Indicate priority for r0..r3 / r12..r15 with TARGET_REGISTER_PRIORITY."
-msgstr ""
+msgstr "Указать приоритет для r0..r3 / r12..r15 с TARGET_REGISTER_PRIORITY."
 
 #: config/arc/arc.opt:418
 msgid "Reduce priority for r0..r3 / r12..r15 with TARGET_REGISTER_PRIORITY."
-msgstr ""
+msgstr "Понизить приоритет для r0..r3 / r12..r15 с TARGET_REGISTER_PRIORITY."
 
 #: config/arc/arc.opt:430
-#, fuzzy
-#| msgid "Enable clip instructions"
 msgid "Enable atomic instructions."
-msgstr "Включить clip инструкции"
+msgstr "Включить atomic инструкции."
 
 #: config/arc/arc.opt:434
-#, fuzzy
-#| msgid "Enable unaligned load/store instruction"
 msgid "Enable double load/store instructions for ARC HS."
-msgstr "Включить инструкции невыровненной загрузки/сохранения"
+msgstr "Включить инструкции загрузки/сохранения double для ARC HS."
 
 #: config/arc/arc.opt:438
-#, fuzzy
-#| msgid "Specify the name of the target floating point hardware/format"
 msgid "Specify the name of the target floating point configuration."
-msgstr "Задать целевую аппаратуру для плавающей точки и формат вычислений"
+msgstr "Задать имя целевой конфигурации для плавающей точки."
 
 #: config/arc/arc.opt:481
-#, fuzzy
-#| msgid "Specify thread local storage scheme"
 msgid "Specify thread pointer register number."
-msgstr "Задать схему thread local памяти"
+msgstr "Задать номер регистра указателя потока."
 
 #: config/arc/arc.opt:488
-#, fuzzy
-#| msgid "Enable use of RTPS instruction"
 msgid "Enable use of NPS400 bit operations."
-msgstr "Использовать команды RTPS"
+msgstr "Включить использование NPS400 битовых операций."
 
 #: config/arc/arc.opt:492
-#, fuzzy
-#| msgid "Enable use of RTPS instruction"
 msgid "Enable use of NPS400 xld/xst extension."
-msgstr "Использовать команды RTPS"
+msgstr "Включить использование NPS400 xld/xst расширения."
 
 #: config/arc/arc.opt:500
-#, fuzzy
-#| msgid "Specifies the number of registers to reserve for interrupt handlers."
 msgid "Specifies the registers that the processor saves on an interrupt entry and exit."
-msgstr "Задает число регистров резервируемых для обработчиков прерываний."
+msgstr ""
 
 #: config/arc/arc.opt:504
-#, fuzzy
-#| msgid "Specifies the number of registers to reserve for interrupt handlers."
 msgid "Specifies the number of registers replicated in second register bank on entry to fast interrupt."
-msgstr "Задает число регистров резервируемых для обработчиков прерываний."
+msgstr ""
 
 #: config/arc/arc.opt:508
 msgid "Sets LP_COUNT register width.  Possible values are 8, 16, 20, 24, 28, and 32."
@@ -17126,14 +13810,13 @@
 msgstr ""
 
 #: lto/lang.opt:28
-#, fuzzy, c-format
-#| msgid "unknown machine mode %qE"
+#, c-format
 msgid "unknown linker output %qs"
-msgstr "неизвестная машинный режим %qE"
+msgstr "неизвестный вывод компоновщика %qs"
 
 #: lto/lang.opt:47
 msgid "Set linker output type (used internally during LTO optimization)"
-msgstr ""
+msgstr "Установить тип вывода компоновщика (используется внутренне при LTO оптимизации)"
 
 #: lto/lang.opt:52
 msgid "Run the link-time optimizer in local transformation (LTRANS) mode."
@@ -17149,89 +13832,63 @@
 
 #: lto/lang.opt:64
 msgid "Whole program analysis (WPA) mode with number of parallel jobs specified."
-msgstr ""
+msgstr "Режим анализа всей программы (WPA) с заданным числом параллельных работ."
 
 #: lto/lang.opt:68
-#, fuzzy
-#| msgid "The resolution file"
 msgid "The resolution file."
-msgstr "Файл резолюции"
+msgstr "Файл резолюции."
 
 #: common.opt:304
-#, fuzzy
-#| msgid "Display this information"
 msgid "Display this information."
-msgstr "Выдать эту информацию"
+msgstr "Выдать эту информацию."
 
 #: common.opt:308
-#, fuzzy
-#| msgid "--help=<class>\tDisplay descriptions of a specific class of options.  <class> is one or more of optimizers, target, warnings, undocumented, params"
 msgid "--help=<class>\tDisplay descriptions of a specific class of options.  <class> is one or more of optimizers, target, warnings, undocumented, params."
-msgstr "--help=<класс>\tВыдать описание указанного класса ключей. <класс> задает одно или более из следующих слов: optimizers, target, warnings, undocumented, params"
+msgstr ""
 
 #: common.opt:429
-#, fuzzy
-#| msgid "Alias for --help=target"
 msgid "Alias for --help=target."
-msgstr "Синоним --help=target"
+msgstr "Синоним --help=target."
 
 #: common.opt:454
-#, fuzzy
-#| msgid "--param <param>=<value>\tSet parameter <param> to value.  See below for a complete list of parameters"
 msgid "--param <param>=<value>\tSet parameter <param> to value.  See below for a complete list of parameters."
-msgstr "--param <param>=<value>\tЗадать значение параметра <param> равным <value>. См. далее полный список параметров"
+msgstr ""
 
 #: common.opt:482
-#, fuzzy
-#| msgid "-O<number>\tSet optimization level to <number>"
 msgid "-O<number>\tSet optimization level to <number>."
-msgstr "-O<уровень>\tЗадать <уровень> оптимизации"
+msgstr "-O<уровень>\tЗадать <уровень> оптимизации."
 
 #: common.opt:486
-#, fuzzy
-#| msgid "Optimize for space rather than speed"
 msgid "Optimize for space rather than speed."
-msgstr "Оптимизировать размер, а не быстродействие"
+msgstr "Оптимизировать размер, а не быстродействие."
 
 #: common.opt:490
-#, fuzzy
-#| msgid "Optimize for speed disregarding exact standards compliance"
 msgid "Optimize for speed disregarding exact standards compliance."
-msgstr "Оптимизировать по скорости выполнения, пренебрегая некоторыми требованиями стандарта"
+msgstr "Оптимизировать по скорости выполнения, пренебрегая некоторыми требованиями стандарта."
 
 #: common.opt:494
-#, fuzzy
-#| msgid "Optimize for space rather than speed"
 msgid "Optimize for debugging experience rather than speed or size."
-msgstr "Оптимизировать размер, а не быстродействие"
+msgstr "Оптимизировать опыт отладки, а не быстродействие или размер."
 
 #: common.opt:534
-#, fuzzy
-#| msgid "This switch is deprecated; use -Wextra instead"
 msgid "This switch is deprecated; use -Wextra instead."
-msgstr "Этот ключ устарел; используйте -Wextra."
+msgstr "Этот ключ устарел; используйте -Wextra взамен."
 
 #: common.opt:547
-#, fuzzy
-#| msgid "Warn about returning structures, unions or arrays"
 msgid "Warn about returning structures, unions or arrays."
-msgstr "Предупреждать о возвращении функциями структур, объединений, массивов"
+msgstr "Предупреждать о возвращении функциями структур, объединений, массивов."
 
 #: common.opt:551
 msgid "Warn if a loop with constant number of iterations triggers undefined behavior."
-msgstr ""
+msgstr "Предупреждать, если цикл с константным числом итераций проявляет неопределенное поведение."
 
 #: common.opt:555 common.opt:559
-#, fuzzy
-#| msgid "Warn if an array is accessed out of bounds"
 msgid "Warn if an array is accessed out of bounds."
-msgstr "Предупреждать о выходе за границы массива"
+msgstr "Предупреждать о выходе за границы массива."
 
 #: common.opt:563
-#, fuzzy
-#| msgid "Warn about inappropriate attribute usage"
 msgid "Warn about inappropriate attribute usage."
-msgstr "Предупреждать о неадекватном использовании атрибутов"
+msgstr "Предупреждать о неадекватном использовании атрибутов."
 
 #: common.opt:567
 msgid "Warn about type safety and similar errors in attribute alias and related."
@@ -17238,80 +13895,56 @@
 msgstr ""
 
 #: common.opt:571 common.opt:575
-#, fuzzy
-#| msgid "Warn about pointer casts which increase alignment"
 msgid "Warn about pointer casts which increase alignment."
-msgstr "Предупреждать о приведении указательных типов с увеличением выравнивания"
+msgstr "Предупреждать о приведении указательных типов с увеличением выравнивания."
 
 #: common.opt:579
-#, fuzzy
-#| msgid "Warn when a #warning directive is encountered"
 msgid "Warn when a #warning directive is encountered."
-msgstr "Выдавать предупреждения в соответствии с директивами #warning"
+msgstr "Выдавать предупреждения в соответствии с директивами #warning."
 
 #: common.opt:583
-#, fuzzy
-#| msgid "Warn about uses of __attribute__((deprecated)) declarations"
 msgid "Warn about uses of __attribute__((deprecated)) declarations."
-msgstr "Предупреждать об использовании имён, декларированных с атрибутом deprecated"
+msgstr "Предупреждать об использовании имён, декларированных с атрибутом deprecated."
 
 #: common.opt:587
-#, fuzzy
-#| msgid "Warn when an optimization pass is disabled"
 msgid "Warn when an optimization pass is disabled."
-msgstr "Предупреждать о невыполнении заказанных оптимизаций"
+msgstr "Предупреждать о невыполнении заказанных оптимизаций."
 
 #: common.opt:591
-#, fuzzy
-#| msgid "Treat all warnings as errors"
 msgid "Treat all warnings as errors."
-msgstr "Все предупреждения считать ошибками"
+msgstr "Все предупреждения считать ошибками."
 
 #: common.opt:595
-#, fuzzy
-#| msgid "Treat specified warning as error"
 msgid "Treat specified warning as error."
-msgstr "Трактовать указанное предупреждение как ошибку"
+msgstr "Трактовать указанное предупреждение как ошибку."
 
 #: common.opt:599
-#, fuzzy
-#| msgid "Print extra (possibly unwanted) warnings"
 msgid "Print extra (possibly unwanted) warnings."
-msgstr "Печатать дополнительные (возможно, нежелательные) предупреждения"
+msgstr "Печатать дополнительные (возможно, нежелательные) предупреждения."
 
 #: common.opt:603
-#, fuzzy
-#| msgid "Exit on the first error occurred"
 msgid "Exit on the first error occurred."
-msgstr "Закончить работу при первой обнаруженной ошибке"
+msgstr "Закончить работу при первой обнаруженной ошибке."
 
 #: common.opt:607
-#, fuzzy
-#| msgid "-Wframe-larger-than=<number>\tWarn if a function's stack frame requires more than <number> bytes"
 msgid "-Wframe-larger-than=<number>\tWarn if a function's stack frame requires more than <number> bytes."
-msgstr "-Wframe-larger-than=<number>\tПредупреждать, если размер стека функции превышает <number> байт"
+msgstr "-Wframe-larger-than=<number>\tПредупреждать, если размер стека функции превышает <number> байт."
 
 #: common.opt:611
-#, fuzzy
-#| msgid "Warn when attempting to free a non-heap object"
 msgid "Warn when attempting to free a non-heap object."
-msgstr "Предупреждать о попытках освобождения объектов, размещенных не в динамической памяти"
+msgstr "Предупреждать о попытках освобождения объектов, размещенных не в динамической памяти."
 
 #: common.opt:615
-#, fuzzy
-#| msgid "Warn when an inlined function cannot be inlined"
 msgid "Warn when a function cannot be expanded to HSAIL."
-msgstr "Предупреждать об inline-функциях, подстановка которых невозможна"
+msgstr "Предупреждать, если функция не может быть расширена в HSAIL."
 
 #: common.opt:622
 msgid "Warn when a switch case falls through."
-msgstr ""
+msgstr "Предупреждать, если switch case проваливается дальше."
 
 #: common.opt:626
-#, fuzzy
-#| msgid "Warn when an inlined function cannot be inlined"
 msgid "Warn when an inlined function cannot be inlined."
-msgstr "Предупреждать об inline-функциях, подстановка которых невозможна"
+msgstr "Предупреждать об inline-функциях, подстановка которых невозможна."
 
 #: common.opt:630
 msgid "Warn when an atomic memory model parameter is known to be outside the valid range."
@@ -17318,2569 +13951,1855 @@
 msgstr "Предупреждать, если параметр атомарной модели памяти находится заведомо вне корректного диапазона"
 
 #: common.opt:637
-#, fuzzy
-#| msgid "-Wlarger-than=<number>\tWarn if an object is larger than <number> bytes"
 msgid "-Wlarger-than=<number>\tWarn if an object is larger than <number> bytes."
-msgstr "-Wlarger-than=<число>\tПредупреждать об объектах, размер которых превышает <число> байт"
+msgstr "-Wlarger-than=<число>\tПредупреждать об объектах, размер которых превышает <число> байт."
 
 #: common.opt:641
 msgid "Warn if comparing pointer parameter with nonnull attribute with NULL."
-msgstr ""
+msgstr "Предупреждать, если параметр-указатель с nonnull атрибутом сравнивается с NULL."
 
 #: common.opt:645
 msgid "Warn if dereferencing a NULL pointer may lead to erroneous or undefined behavior."
-msgstr ""
+msgstr "Предупреждать, если переход по пустому указателю может привести к ошибочному или неопределенному поведению."
 
-#: common.opt:649
-msgid "Warn if the loop cannot be optimized due to nontrivial assumptions."
-msgstr "Предупреждать, если оптимизация цикла невозможна из-за нетривиальных предположений"
-
 #: common.opt:656
 msgid "Warn about some C++ One Definition Rule violations during link time optimization."
-msgstr ""
+msgstr "Предупреждать о некоторых нарушениях C++ правила одного определения при оптимизации во время компоновки."
 
 #: common.opt:660
-#, fuzzy
-#| msgid "Warn about overflow in arithmetic expressions"
 msgid "Warn about overflow in arithmetic expressions."
-msgstr "Предупреждать о переполнениях в арифметических выражениях"
+msgstr "Предупреждать о переполнениях в арифметических выражениях."
 
 #: common.opt:664
 msgid "During link time optimization warn about mismatched types of global declarations."
-msgstr ""
+msgstr "При оптимизации во время компоновки предупреждать о несоответствии типов глобальных деклараций."
 
 #: common.opt:668
-#, fuzzy
-#| msgid "Warn when the packed attribute has no effect on struct layout"
 msgid "Warn when the packed attribute has no effect on struct layout."
-msgstr "Предупреждать о случаях, когда атрибут packed не влияет на "
+msgstr "Предупреждать, если атрибут packed не влияет на расположение структуры."
 
 #: common.opt:672
-#, fuzzy
-#| msgid "Warn when padding is required to align structure members"
 msgid "Warn when padding is required to align structure members."
-msgstr "Предупреждать о дырах в результате выравнивания элементов структур"
+msgstr "Предупреждать о дырах в результате выравнивания элементов структур."
 
 #: common.opt:676
-#, fuzzy
-#| msgid "Issue warnings needed for strict compliance to the standard"
 msgid "Issue warnings needed for strict compliance to the standard."
-msgstr "Выдавать предупреждения, требуемые для соответствия стандарту"
+msgstr "Выдавать предупреждения, требуемые для соответствия стандарту."
 
 #: common.opt:680
-#, fuzzy
-#| msgid "returning reference to temporary"
 msgid "Warn about returning a pointer/reference to a local or temporary variable."
-msgstr "возврат ссылки на временную переменную"
+msgstr "Предупреждать о возврате указателя/ссылки на локальную или временную переменную."
 
 #: common.opt:684
-#, fuzzy
-#| msgid "Warn when one local variable shadows another"
 msgid "Warn when one variable shadows another.  Same as -Wshadow=global."
-msgstr "Предупреждать когда одна локальная переменная перекрывает другую"
+msgstr ""
 
 #: common.opt:688
-#, fuzzy
-#| msgid "Warn when one local variable shadows another"
 msgid "Warn when one variable shadows another (globally)."
-msgstr "Предупреждать когда одна локальная переменная перекрывает другую"
+msgstr "Предупреждать, когда одна переменная перекрывает другую (глобально)."
 
 #: common.opt:692
-#, fuzzy
-#| msgid "Warn when one local variable shadows another"
 msgid "Warn when one local variable shadows another local variable or parameter."
-msgstr "Предупреждать когда одна локальная переменная перекрывает другую"
+msgstr "Предупреждать, когда одна локальная переменная перекрывает другую локальную переменную или параметр."
 
 #: common.opt:699
-#, fuzzy
-#| msgid "Warn when one local variable shadows another"
 msgid "Warn when one local variable shadows another local variable or parameter of compatible type."
-msgstr "Предупреждать когда одна локальная переменная перекрывает другую"
+msgstr "Предупреждать, когда одна локальная переменная перекрывает другую локальную переменную или параметр совместимого типа."
 
 #: common.opt:706
-#, fuzzy
-#| msgid "Warn when not issuing stack smashing protection for some reason"
 msgid "Warn when not issuing stack smashing protection for some reason."
-msgstr "Предупреждать, если защита от разрушения стека по каким-то причинам не сгенерирована"
+msgstr "Предупреждать, если защита от разрушения стека по каким-то причинам не сгенерирована."
 
 #: common.opt:710
-#, fuzzy
-#| msgid "Warn if stack usage might be larger than specified amount"
 msgid "-Wstack-usage=<number>\tWarn if stack usage might be larger than specified amount."
-msgstr "Предупреждать, если используемый размер стека может превышать указанную величину"
+msgstr "-Wstack-usage=<number>\tПредупреждать, если используемый размер стека может превышать указанную величину."
 
 #: common.opt:714 common.opt:718
-#, fuzzy
-#| msgid "Warn about code which might break strict aliasing rules"
 msgid "Warn about code which might break strict aliasing rules."
-msgstr "Предупреждать о возможных нарушениях правил перекрытия данных в памяти"
+msgstr "Предупреждать о возможных нарушениях правил перекрытия данных в памяти."
 
 #: common.opt:722 common.opt:726
-#, fuzzy
-#| msgid "Warn about optimizations that assume that signed overflow is undefined"
 msgid "Warn about optimizations that assume that signed overflow is undefined."
-msgstr "Предупреждать об оптимизациях, основанных на том, что при знаковом переполнении поведение не определено"
+msgstr "Предупреждать об оптимизациях, основанных на том, что при знаковом переполнении поведение не определено."
 
 #: common.opt:730
-#, fuzzy
-#| msgid "Warn about functions which might be candidates for __attribute__((const))"
 msgid "Warn about functions which might be candidates for __attribute__((cold))."
-msgstr "Предупреждать о функциях, которым можно назначить __attribute__((const))"
+msgstr ""
 
 #: common.opt:734
-#, fuzzy
-#| msgid "Warn about functions which might be candidates for __attribute__((const))"
 msgid "Warn about functions which might be candidates for __attribute__((const))."
-msgstr "Предупреждать о функциях, которым можно назначить __attribute__((const))"
+msgstr "Предупреждать о функциях, которым можно назначить __attribute__((const))."
 
 #: common.opt:738
-#, fuzzy
-#| msgid "Warn about functions which might be candidates for __attribute__((pure))"
 msgid "Warn about functions which might be candidates for __attribute__((pure))."
-msgstr "Предупреждать о функциях, которым можно назначить __attribute__((pure))"
+msgstr "Предупреждать о функциях, которым можно назначить __attribute__((pure))."
 
 #: common.opt:742
-#, fuzzy
-#| msgid "Warn about functions which might be candidates for __attribute__((noreturn))"
 msgid "Warn about functions which might be candidates for __attribute__((noreturn))."
-msgstr "Предупреждать о функциях, которым можно назначить атрибут noreturn"
+msgstr "Предупреждать о функциях, которым можно назначить атрибут noreturn."
 
 #: common.opt:746
-#, fuzzy
-#| msgid "Warn about functions which might be candidates for __attribute__((const))"
 msgid "Warn about functions which might be candidates for __attribute__((malloc))."
-msgstr "Предупреждать о функциях, которым можно назначить __attribute__((const))"
+msgstr ""
 
 #: common.opt:750
 msgid "Warn about C++ polymorphic types where adding final keyword would improve code quality."
-msgstr ""
+msgstr "Предупреждать о полиморфных типах C++, если добавление ключевого слова final повысит качество кода."
 
 #: common.opt:754
 msgid "Warn about C++ virtual methods where adding final keyword would improve code quality."
-msgstr ""
+msgstr "Предупреждать о виртуальных методах C++, если добавление ключевого слова final повысит качество кода."
 
 #: common.opt:758
-#, fuzzy
-#| msgid "Warn about truncated character expressions"
 msgid "Warn about statements between switch's controlling expression and the first case."
-msgstr "Предупреждать об усеченных строковых выражениях"
+msgstr "Предупреждать об операторах между управляющим выражением в switch и первым case."
 
 #: common.opt:763
-#, fuzzy
-#| msgid "Do not suppress warnings from system headers"
 msgid "Do not suppress warnings from system headers."
-msgstr "Не подавлять предупреждения от системных заголовков"
+msgstr "Не подавлять предупреждения от системных заголовков."
 
 #: common.opt:767
-#, fuzzy
-#| msgid "Warn whenever a trampoline is generated"
 msgid "Warn whenever a trampoline is generated."
-msgstr "Предупреждать о генерации \"трамплинов\" для вложенных функций"
+msgstr "Предупреждать о генерации \"трамплинов\" для вложенных функций."
 
 #: common.opt:771
-#, fuzzy
-#| msgid "Warn if a comparison is always true or always false due to the limited range of the data type"
 msgid "Warn if a comparison is always true or always false due to the limited range of the data type."
-msgstr "Предупреждать, если из-за ограниченности диапазона типа данных, результат сравнения всегда ложь или всегда истина"
+msgstr "Предупреждать, если из-за ограниченности диапазона типа данных, результат сравнения всегда ложь или всегда истина."
 
 #: common.opt:775
-#, fuzzy
-#| msgid "Warn about uninitialized automatic variables"
 msgid "Warn about uninitialized automatic variables."
-msgstr "Предупреждать о неинициализированных автоматических переменных"
+msgstr "Предупреждать о неинициализированных автоматических переменных."
 
 #: common.opt:779
-#, fuzzy
-#| msgid "Warn about maybe uninitialized automatic variables"
 msgid "Warn about maybe uninitialized automatic variables."
-msgstr "Предупреждать о, возможно, неинициализированных автоматических переменных"
+msgstr "Предупреждать о, возможно, неинициализированных автоматических переменных."
 
 #: common.opt:787
-#, fuzzy
-#| msgid "Enable all -Wunused- warnings"
 msgid "Enable all -Wunused- warnings."
-msgstr "Включить все предупреждения -Wunused-"
+msgstr "Включить все предупреждения -Wunused-."
 
 #: common.opt:791
-#, fuzzy
-#| msgid "Warn when a function parameter is only set, otherwise unused"
 msgid "Warn when a function parameter is only set, otherwise unused."
-msgstr "Предупреждать, если параметр функции не используется иначе чем для присваивания ему значений"
+msgstr "Предупреждать, если параметр функции не используется иначе чем для присваивания ему значений."
 
 #: common.opt:795
-#, fuzzy
-#| msgid "Warn when a variable is only set, otherwise unused"
 msgid "Warn when a variable is only set, otherwise unused."
-msgstr "Предупреждать о переменных, которые используются только как левая часть присваиваний"
+msgstr "Предупреждать о переменных, которые используются только как левая часть присваиваний."
 
 #: common.opt:799
-#, fuzzy
-#| msgid "Warn when a function is unused"
 msgid "Warn when a function is unused."
-msgstr "Предупреждать о неиспользуемых функциях"
+msgstr "Предупреждать о неиспользуемых функциях."
 
 #: common.opt:803
-#, fuzzy
-#| msgid "Warn when a label is unused"
 msgid "Warn when a label is unused."
-msgstr "Предупреждать о неиспользуемых метках"
+msgstr "Предупреждать о неиспользуемых метках."
 
 #: common.opt:807
-#, fuzzy
-#| msgid "Warn when a function parameter is unused"
 msgid "Warn when a function parameter is unused."
-msgstr "Предупреждать о неиспользуемых параметрах функций"
+msgstr "Предупреждать о неиспользуемых параметрах функций."
 
 #: common.opt:811
-#, fuzzy
-#| msgid "Warn when an expression value is unused"
 msgid "Warn when an expression value is unused."
-msgstr "Предупреждать о неиспользованных результатах выражений"
+msgstr "Предупреждать о неиспользованных результатах выражений."
 
 #: common.opt:815
-#, fuzzy
-#| msgid "Warn when a variable is unused"
 msgid "Warn when a variable is unused."
-msgstr "Предупреждать о неиспользуемых переменных"
+msgstr "Предупреждать о неиспользуемых переменных."
 
 #: common.opt:819
-#, fuzzy
-#| msgid "Warn in case profiles in -fprofile-use do not match"
 msgid "Warn in case profiles in -fprofile-use do not match."
-msgstr "Предупреждать о несоответствии данных профилирования, заданных ключом -fprofile-use"
+msgstr "Предупреждать о несоответствии данных профилирования, заданных ключом -fprofile-use."
 
 #: common.opt:823
-#, fuzzy
-#| msgid "Warn when a vector operation is compiled outside the SIMD"
 msgid "Warn when a vector operation is compiled outside the SIMD."
-msgstr "Предупреждать о векторных операциях, скомпилированных не при помощи SIMD-команд"
+msgstr "Предупреждать о векторных операциях, скомпилированных не при помощи SIMD-команд."
 
 #: common.opt:839
-#, fuzzy
-#| msgid "-aux-info <file>\tEmit declaration information into <file>"
 msgid "-aux-info <file>\tEmit declaration information into <file>."
-msgstr "-aux-info <файл>\tВыдать информацию о декларациях в <файл>"
+msgstr "-aux-info <файл>\tВыдать информацию о декларациях в <файл>."
 
 #: common.opt:858
-#, fuzzy
-#| msgid "-d<letters>\tEnable dumps from specific passes of the compiler"
 msgid "-d<letters>\tEnable dumps from specific passes of the compiler."
-msgstr "-d<letters>\tВыдать дампы от различных проходов компиляции"
+msgstr "-d<letters>\tВыдать дампы от различных проходов компиляции."
 
 #: common.opt:862
-#, fuzzy
-#| msgid "-dumpbase <file>\tSet the file basename to be used for dumps"
 msgid "-dumpbase <file>\tSet the file basename to be used for dumps."
-msgstr "-dumpbase <file>\tБазовое имя файла для дампов"
+msgstr "-dumpbase <file>\tБазовое имя файла для дампов."
 
 #: common.opt:866
-#, fuzzy
-#| msgid "-dumpdir <dir>\tSet the directory name to be used for dumps"
 msgid "-dumpdir <dir>\tSet the directory name to be used for dumps."
-msgstr "-dumpdir <каталог>\tУказать <каталог> для выдачи дампов"
+msgstr "-dumpdir <каталог>\tУказать <каталог> для выдачи дампов."
 
-#: common.opt:946
+#: common.opt:950
 msgid "The version of the C++ ABI in use."
-msgstr ""
+msgstr "Используемая версия C++ ABI."
 
-#: common.opt:950
+#: common.opt:954
 msgid "Aggressively optimize loops using language constraints."
-msgstr ""
+msgstr "Агрессивно оптимизировать циклы используя ограничения языка."
 
-#: common.opt:954
-#, fuzzy
-#| msgid "Align the start of functions"
+#: common.opt:958
 msgid "Align the start of functions."
-msgstr "Выравнивать начало функций"
+msgstr "Выравнивать начало функций."
 
-#: common.opt:964
-#, fuzzy
-#| msgid "Align labels which are only reached by jumping"
+#: common.opt:968
 msgid "Align labels which are only reached by jumping."
-msgstr "Выравнивать метки, доступные только по командам переходов"
+msgstr "Выравнивать метки, доступные только по командам переходов."
 
-#: common.opt:971
-#, fuzzy
-#| msgid "Align all labels"
+#: common.opt:975
 msgid "Align all labels."
-msgstr "Выравнивать все метки"
+msgstr "Выравнивать все метки."
 
-#: common.opt:978
-#, fuzzy
-#| msgid "Align the start of loops"
+#: common.opt:982
 msgid "Align the start of loops."
-msgstr "Выравнивать начало циклов"
+msgstr "Выравнивать начало циклов."
 
-#: common.opt:1001
-#, fuzzy
-#| msgid "Select the runtime"
+#: common.opt:1005
 msgid "Select what to sanitize."
-msgstr "Выбрать runtime-поддержку"
+msgstr "Выбрать, что санировать."
 
-#: common.opt:1005
-#, fuzzy
-#| msgid "Select the runtime"
+#: common.opt:1009
 msgid "Select type of coverage sanitization."
-msgstr "Выбрать runtime-поддержку"
+msgstr ""
 
-#: common.opt:1009
+#: common.opt:1013
 msgid "-fasan-shadow-offset=<number>\tUse custom shadow memory offset."
-msgstr ""
+msgstr "-fasan-shadow-offset=<number>\tИспользовать специальное смещение теневой памяти."
 
-#: common.opt:1013
+#: common.opt:1017
 msgid "-fsanitize-sections=<sec1,sec2,...>\tSanitize global variables in user-defined sections."
-msgstr ""
+msgstr "-fsanitize-sections=<sec1,sec2,...>\tСанировать глобальные переменные в определенных пользователем секциях."
 
-#: common.opt:1018
+#: common.opt:1022
 msgid "After diagnosing undefined behavior attempt to continue execution."
-msgstr ""
+msgstr "После диагностирования неопределенного поведения пытаться продолжить выполнение."
 
-#: common.opt:1022
-#, fuzzy
-#| msgid "This switch is deprecated; use -Wextra instead"
+#: common.opt:1026
 msgid "This switch is deprecated; use -fsanitize-recover= instead."
-msgstr "Этот ключ устарел; используйте -Wextra."
+msgstr "Этот ключ устарел; используйте -fsanitize-recover= взамен."
 
-#: common.opt:1029
+#: common.opt:1033
 msgid "Use trap instead of a library function for undefined behavior sanitization."
-msgstr ""
+msgstr "Использовать trap вместо библиотечной функции для санирования неопределенного поведения."
 
-#: common.opt:1033
-#, fuzzy
-#| msgid "Generate unwind tables that are exact at each instruction boundary"
+#: common.opt:1037
 msgid "Generate unwind tables that are exact at each instruction boundary."
-msgstr "Генерировать unwind-таблицы, корректные на начало каждой команды"
+msgstr "Генерировать unwind-таблицы, корректные на начало каждой команды."
 
-#: common.opt:1037
-#, fuzzy
-#| msgid "Generate auto-inc/dec instructions"
+#: common.opt:1041
 msgid "Generate auto-inc/dec instructions."
-msgstr "Генерировать команды автоинкрементации/автодекрементации"
+msgstr "Генерировать команды автоинкрементации/автодекрементации."
 
-#: common.opt:1041
-#, fuzzy
-#| msgid "Use profiling information for branch probabilities"
+#: common.opt:1045
 msgid "Use sample profile information for call graph node weights. The default profile file is fbdata.afdo in 'pwd'."
-msgstr "Оценивать вероятность переходов на основе данных профилирования"
+msgstr ""
 
-#: common.opt:1046
-#, fuzzy
-#| msgid "Use profiling information for branch probabilities"
+#: common.opt:1050
 msgid "Use sample profile information for call graph node weights. The profile file is specified in the argument."
-msgstr "Оценивать вероятность переходов на основе данных профилирования"
+msgstr ""
 
-#: common.opt:1055
-#, fuzzy
-#| msgid "Generate code to check bounds before indexing arrays"
+#: common.opt:1059
 msgid "Generate code to check bounds before indexing arrays."
-msgstr "Генерировать код для проверки выхода за границы массивов"
+msgstr "Генерировать код для проверки выхода за границы массивов."
 
-#: common.opt:1059
-#, fuzzy
-#| msgid "Replace add, compare, branch with branch on count register"
+#: common.opt:1063
 msgid "Replace add, compare, branch with branch on count register."
-msgstr "Генерировать для циклов переход по счётчику вместо команд продвижения счётчика, сравнения и перехода"
+msgstr "Заменить сложение, сравнение, ветвление на ветвление по регистру счетчика."
 
-#: common.opt:1063
-#, fuzzy
-#| msgid "Use profiling information for branch probabilities"
+#: common.opt:1067
 msgid "Use profiling information for branch probabilities."
-msgstr "Оценивать вероятность переходов на основе данных профилирования"
+msgstr "Оценивать вероятность переходов на основе данных профилирования."
 
-#: common.opt:1067
-#, fuzzy
-#| msgid "Perform branch target load optimization before prologue / epilogue threading"
+#: common.opt:1071
 msgid "Perform branch target load optimization before prologue / epilogue threading."
-msgstr "Оптимизировать чтение из памяти в точках, куда передается управление, до генерации прологов и эпилогов"
+msgstr "Оптимизировать чтение из памяти в точках, куда передается управление, до генерации прологов и эпилогов."
 
-#: common.opt:1071
-#, fuzzy
-#| msgid "Perform branch target load optimization after prologue / epilogue threading"
+#: common.opt:1075
 msgid "Perform branch target load optimization after prologue / epilogue threading."
-msgstr "Оптимизировать чтение из памяти в точках, куда передается управление, после генерации прологов и эпилогов"
+msgstr "Оптимизировать чтение из памяти в точках, куда передается управление, после генерации прологов и эпилогов."
 
-#: common.opt:1075
-#, fuzzy
-#| msgid "Restrict target load migration not to re-use registers in any basic block"
+#: common.opt:1079
 msgid "Restrict target load migration not to re-use registers in any basic block."
-msgstr "Ограничить миграцию регистров, в которые помещаются целевые адреса переходов, чтобы не переиспользовать эти регистры ни в каких блоках"
+msgstr "Ограничить миграцию регистров, в которые помещаются целевые адреса переходов, чтобы не переиспользовать эти регистры ни в каких блоках."
 
-#: common.opt:1079
-#, fuzzy
-#| msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions"
+#: common.opt:1083
 msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions."
-msgstr "-fcall-saved-<регистр>\tСчитать, что <регистр> сохраняется при вызовах функций"
+msgstr "-fcall-saved-<регистр>\tСчитать, что <регистр> сохраняется при вызовах функций."
 
-#: common.opt:1083
-#, fuzzy
-#| msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls"
+#: common.opt:1087
 msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls."
-msgstr "-fcall-used-<регистр>\tСчитать, что <регистр> портится при вызовах функций"
+msgstr "-fcall-used-<регистр>\tСчитать, что <регистр> портится при вызовах функций."
 
-#: common.opt:1090
-#, fuzzy
-#| msgid "Save registers around function calls"
+#: common.opt:1094
 msgid "Save registers around function calls."
-msgstr "Сохранять/восстанавливать регистры до/после вызовов функций"
+msgstr "Сохранять/восстанавливать регистры до/после вызовов функций."
 
-#: common.opt:1094
-#, fuzzy
-#| msgid "This switch is deprecated; use -Wextra instead"
+#: common.opt:1098
 msgid "This switch is deprecated; do not use."
-msgstr "Этот ключ устарел; используйте -Wextra."
+msgstr "Этот ключ устарел; не используйте."
 
-#: common.opt:1098
-#, fuzzy
-#| msgid "Check the return value of new"
+#: common.opt:1102
 msgid "Check the return value of new in C++."
-msgstr "Проверять результат new"
+msgstr "Проверять результат new в C++."
 
-#: common.opt:1102 common.opt:1106
-#, fuzzy
-#| msgid "internal consistency failure"
+#: common.opt:1106 common.opt:1110
 msgid "Perform internal consistency checkings."
-msgstr "обнаружена несогласованность внутреннего представления gcc"
+msgstr "Произвести проверки внутренней непротиворечивости."
 
-#: common.opt:1110
-#, fuzzy
-#| msgid "Enable dead store elimination"
+#: common.opt:1114
 msgid "Enable code hoisting."
-msgstr "Выполнить оптимизацию удаления мертвых команд записи в память"
+msgstr "Включить поднятие кода."
 
-#: common.opt:1114
+#: common.opt:1118
 msgid "Looks for opportunities to reduce stack adjustments and stack references."
 msgstr "По возможности сокращать число операций со стеком и обращений к стеку"
 
-#: common.opt:1118
-#, fuzzy
-#| msgid "Do not put uninitialized globals in the common section"
+#: common.opt:1122
 msgid "Do not put uninitialized globals in the common section."
-msgstr "Не размещать неинициализированные глобальные данные в общих блоках"
+msgstr "Не размещать неинициализированные глобальные данные в общих блоках."
 
-#: common.opt:1126
-#, fuzzy
-#| msgid "-fcompare-debug[=<opts>]\tCompile with and without e.g. -gtoggle, and compare the final-insns dump"
+#: common.opt:1130
 msgid "-fcompare-debug[=<opts>]\tCompile with and without e.g. -gtoggle, and compare the final-insns dump."
-msgstr "-fcompare-debug[=<opts>]\tКомпилировать с ключом, например, -gtoggle, и сравнивать финальные дампы инструкций"
+msgstr "-fcompare-debug[=<opts>]\tКомпилировать с ключом, например, -gtoggle, и сравнивать финальные дампы инструкций."
 
-#: common.opt:1130
-#, fuzzy
-#| msgid "Run only the second compilation of -fcompare-debug"
+#: common.opt:1134
 msgid "Run only the second compilation of -fcompare-debug."
-msgstr "Выполнять только вторую компиляцию по -fcompare-debug"
+msgstr "Выполнять только вторую компиляцию по -fcompare-debug."
 
-#: common.opt:1134
-#, fuzzy
-#| msgid "Perform comparison elimination after register allocation has finished"
+#: common.opt:1138
 msgid "Perform comparison elimination after register allocation has finished."
-msgstr "Выполнить исключение лишних сравнений после распределения регистров"
+msgstr "Выполнить исключение лишних сравнений после распределения регистров."
 
-#: common.opt:1138
-#, fuzzy
-#| msgid "Do not perform optimizations increasing noticeably stack usage"
+#: common.opt:1142
 msgid "Do not perform optimizations increasing noticeably stack usage."
-msgstr "Не выполнять оптимизации, существенно увеличивающие использование стека"
+msgstr "Не выполнять оптимизации, существенно увеличивающие использование стека."
 
-#: common.opt:1142
-#, fuzzy
-#| msgid "Perform a register copy-propagation optimization pass"
+#: common.opt:1146
 msgid "Perform a register copy-propagation optimization pass."
-msgstr "Выполнить оптимизацию распространения копий регистров"
+msgstr "Выполнить оптимизацию распространения копий регистров."
 
-#: common.opt:1146
-#, fuzzy
-#| msgid "Perform cross-jumping optimization"
+#: common.opt:1150
 msgid "Perform cross-jumping optimization."
-msgstr "Выполнить оптимизацию кода вокруг команд передачи управления"
+msgstr "Выполнить оптимизацию кода вокруг команд передачи управления."
 
-#: common.opt:1150
-#, fuzzy
-#| msgid "When running CSE, follow jumps to their targets"
+#: common.opt:1154
 msgid "When running CSE, follow jumps to their targets."
-msgstr "При экономии общих подвыражений прослеживать код, доступный по переходам"
+msgstr "При экономии общих подвыражений прослеживать код, доступный по переходам."
 
-#: common.opt:1158
-#, fuzzy
-#| msgid "Omit range reduction step when performing complex division"
+#: common.opt:1162
 msgid "Omit range reduction step when performing complex division."
-msgstr "Отбрасывать шаг редукции отрезка при выполнении комплексного деления"
+msgstr "Отбрасывать шаг редукции отрезка при выполнении комплексного деления."
 
-#: common.opt:1162
-#, fuzzy
-#| msgid "Complex multiplication and division follow Fortran rules"
+#: common.opt:1166
 msgid "Complex multiplication and division follow Fortran rules."
-msgstr "Использовать правила Фортрана для комплексного умножения и деления"
+msgstr "Использовать правила Фортрана для комплексного умножения и деления."
 
-#: common.opt:1166
-#, fuzzy
-#| msgid "Place data items into their own section"
+#: common.opt:1170
 msgid "Place data items into their own section."
-msgstr "Размещать элементы данных в отдельных секциях"
+msgstr "Размещать элементы данных в отдельных секциях."
 
-#: common.opt:1170
+#: common.opt:1174
 msgid "List all available debugging counters with their limits and counts."
-msgstr "Перечислить все отладочные счетчики с их границами и значениями"
+msgstr "Перечислить все отладочные счетчики с их границами и значениями."
 
-#: common.opt:1174
-#, fuzzy
-#| msgid "-fdbg-cnt=<counter>:<limit>[,<counter>:<limit>,...]\tSet the debug counter limit.   "
+#: common.opt:1178
 msgid "-fdbg-cnt=<counter>:<limit>[,<counter>:<limit>,...]\tSet the debug counter limit."
-msgstr "-fdbg-cnt=<counter>:<limit>[,<counter>:<limit>,...]\tЗадать список отладочных счетчиков.   "
+msgstr "-fdbg-cnt=<counter>:<limit>[,<counter>:<limit>,...]\tЗадать лимит отладочных счетчиков."
 
-#: common.opt:1178
-#, fuzzy
-#| msgid "Map one directory name to another in debug information"
+#: common.opt:1182
 msgid "-fdebug-prefix-map=<old>=<new> Map one directory name to another in debug information."
-msgstr "Отобразить имя каталога на другое имя в отладочной информации"
+msgstr ""
 
-#: common.opt:1182
-#, fuzzy
-#| msgid "Map one directory name to another in debug information"
+#: common.opt:1186
 msgid "-ffile-prefix-map=<old>=<new> Map one directory name to another in compilation result."
-msgstr "Отобразить имя каталога на другое имя в отладочной информации"
+msgstr ""
 
-#: common.opt:1186
+#: common.opt:1190
 msgid "Output .debug_types section when using DWARF v4 debuginfo."
-msgstr "Выдать секцию .debug_types если используется формат DWARF v4"
+msgstr "Выдать секцию .debug_types, если используется формат DWARF v4"
 
-#: common.opt:1192
-#, fuzzy
-#| msgid "Defer popping functions args from stack until later"
+#: common.opt:1196
 msgid "Defer popping functions args from stack until later."
-msgstr "Откладывать \"на потом\" выталкивание аргументов из стека после вызовов функций"
+msgstr "Откладывать \"на потом\" выталкивание аргументов из стека после вызовов функций."
 
-#: common.opt:1196
-#, fuzzy
-#| msgid "Attempt to fill delay slots of branch instructions"
+#: common.opt:1200
 msgid "Attempt to fill delay slots of branch instructions."
-msgstr "Заполнять гнезда задержки команд перехода"
+msgstr "Заполнять гнезда задержки команд перехода."
 
-#: common.opt:1200
+#: common.opt:1204
 msgid "Delete dead instructions that may throw exceptions."
-msgstr ""
+msgstr "Удалять мертвые вычисления, которые могут вызвать исключительные ситуации."
 
-#: common.opt:1204
-#, fuzzy
-#| msgid "Delete useless null pointer checks"
+#: common.opt:1208
 msgid "Delete useless null pointer checks."
-msgstr "Удалять ненужные сравнения указателей с нулем"
+msgstr "Удалять ненужные сравнения указателей с нулем."
 
-#: common.opt:1208
+#: common.opt:1212
 msgid "Stream extra data to support more aggressive devirtualization in LTO local transformation mode."
-msgstr ""
+msgstr "Подать дополнительные данные для поддержки более агрессивной девиртуализации LTO режиме локального преобразования."
 
-#: common.opt:1212
-#, fuzzy
-#| msgid "Perform superblock formation via tail duplication"
+#: common.opt:1216
 msgid "Perform speculative devirtualization."
-msgstr "Формировать суперблоки методом дублирования хвостов"
+msgstr "Производить спекулятивную девиртуализацию."
 
-#: common.opt:1216
+#: common.opt:1220
 msgid "Try to convert virtual calls to direct ones."
 msgstr "Пытаться преобразовать виртуальные классы в обычные"
 
-#: common.opt:1220
-#, fuzzy
-#| msgid "-fdiagnostics-show-location=[once|every-line]\tHow often to emit source location at the beginning of line-wrapped diagnostics"
+#: common.opt:1224
 msgid "-fdiagnostics-show-location=[once|every-line]\tHow often to emit source location at the beginning of line-wrapped diagnostics."
-msgstr "-fdiagnostics-show-location=[once|every-line]\tВыдавать местоположение источника сообщения один раз или для каждой строки многострочных сообщений"
+msgstr "-fdiagnostics-show-location=[once|every-line]\tВыдавать местоположение источника сообщения один раз или для каждой строки многострочных сообщений."
 
-#: common.opt:1237
+#: common.opt:1241
 msgid "Show the source line with a caret indicating the column."
-msgstr ""
+msgstr "Показывать исходную строку с указателем позиции."
 
-#: common.opt:1245
+#: common.opt:1249
 msgid "-fdiagnostics-color=[never|always|auto]\tColorize diagnostics."
-msgstr ""
+msgstr "-fdiagnostics-color=[never|always|auto]\tПодкрашивать диагностику."
 
-#: common.opt:1265
+#: common.opt:1269
 msgid "Print fix-it hints in machine-readable form."
 msgstr ""
 
-#: common.opt:1269
+#: common.opt:1273
 msgid "Print fix-it hints to stderr in unified diff format."
-msgstr ""
+msgstr "Печатать исправляющие подсказки в стандартный протокол в унифицированном diff формате."
 
-#: common.opt:1273
-#, fuzzy
-#| msgid "Amend appropriate diagnostic messages with the command line option that controls them"
+#: common.opt:1277
 msgid "Amend appropriate diagnostic messages with the command line option that controls them."
-msgstr "Дополнять диагностические сообщения ключом, который контролирует это сообщение"
+msgstr "Дополнять диагностические сообщения ключом, который контролирует это сообщение."
 
-#: common.opt:1277
-#, fuzzy
-#| msgid "-fdisable-[tree|rtl|ipa]-<pass>=range1+range2 disables an optimization pass"
+#: common.opt:1281
 msgid "-fdisable-[tree|rtl|ipa]-<pass>=range1+range2 disables an optimization pass."
-msgstr "-fdisable-[tree|rtl|ipa]-<pass>=range1+range2 отменяет проход оптимизации"
+msgstr "-fdisable-[tree|rtl|ipa]-<pass>=range1+range2 отменяет проход оптимизации."
 
-#: common.opt:1281
-#, fuzzy
-#| msgid "-fenable-[tree|rtl|ipa]-<pass>=range1+range2 enables an optimization pass"
+#: common.opt:1285
 msgid "-fenable-[tree|rtl|ipa]-<pass>=range1+range2 enables an optimization pass."
-msgstr "-fenable-[tree|rtl|ipa]-<pass>=range1+range2 включает проход оптимизации"
+msgstr "-fenable-[tree|rtl|ipa]-<pass>=range1+range2 включает проход оптимизации."
 
-#: common.opt:1285
-#, fuzzy
-#| msgid "-fdump-<type>\tDump various compiler internals to a file"
+#: common.opt:1289
 msgid "-fdump-<type>\tDump various compiler internals to a file."
-msgstr "-fdump-<type>\tВыдать внутреннюю информацию о компиляции в файл"
+msgstr "-fdump-<type>\tВыдать внутреннюю информацию о компиляции в файл."
 
-#: common.opt:1292
-#, fuzzy
-#| msgid "-fdump-final-insns=filename\tDump to filename the insns at the end of translation"
+#: common.opt:1296
 msgid "-fdump-final-insns=filename\tDump to filename the insns at the end of translation."
-msgstr "-fdump-final-insns=файл\tВывести в файл дамп инструкций в конце компиляции"
+msgstr "-fdump-final-insns=файл\tВывести в файл дамп инструкций в конце компиляции."
 
-#: common.opt:1296
-#, fuzzy
-#| msgid "-fdump-go-spec=filename\tWrite all declarations to file as Go code"
+#: common.opt:1300
 msgid "-fdump-go-spec=filename\tWrite all declarations to file as Go code."
-msgstr "-fdump-go-spec=файл\tЗаписать в файл все декларации в виде кода Go"
+msgstr "-fdump-go-spec=файл\tЗаписать в файл все декларации в виде кода Go."
 
-#: common.opt:1300
-#, fuzzy
-#| msgid "Suppress output of addresses in debugging dumps"
+#: common.opt:1304
 msgid "Suppress output of addresses in debugging dumps."
-msgstr "Подавлять вывод адресов в отладочных дампах"
+msgstr "Подавлять вывод адресов в отладочных дампах."
 
-#: common.opt:1304
+#: common.opt:1308
 msgid "Collect and dump debug information into temporary file if ICE in C/C++ compiler occurred."
-msgstr ""
+msgstr "Собрать и выдать отладочную информацию во временный файл, если произошла внутренняя ошибка в C/C++ компиляторе."
 
-#: common.opt:1309
+#: common.opt:1313
 msgid "Dump detailed information on GCC's internal representation of source code locations."
-msgstr ""
+msgstr "Выдать детальную информацию о внутреннем представлении GCC мест исходного кода."
 
-#: common.opt:1313
-#, fuzzy
-#| msgid "Dump optimization passes"
+#: common.opt:1317
 msgid "Dump optimization passes."
-msgstr "Выдать дампы проходов оптимизации"
+msgstr "Выдать дампы проходов оптимизации."
 
-#: common.opt:1317
-#, fuzzy
-#| msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps"
+#: common.opt:1321
 msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps."
-msgstr "Подавлять вывод номеров инструкций и номеров строк и адресов в отладочных дампах"
+msgstr "Подавлять вывод номеров инструкций и номеров строк и адресов в отладочных дампах."
 
-#: common.opt:1321
-#, fuzzy
-#| msgid "Suppress output of previous and next insn numbers in debugging dumps"
+#: common.opt:1325
 msgid "Suppress output of previous and next insn numbers in debugging dumps."
-msgstr "Подавлять вывод номеров предыдущей и следующей инструкций в отладочных дампах"
+msgstr "Подавлять вывод номеров предыдущей и следующей инструкций в отладочных дампах."
 
-#: common.opt:1325
+#: common.opt:1329
 msgid "Enable CFI tables via GAS assembler directives."
 msgstr "Выдавать таблицы DWARF CFI в виде ассемблерных директив .cfi_*"
 
-#: common.opt:1329
-#, fuzzy
-#| msgid "Perform early inlining"
+#: common.opt:1333
 msgid "Perform early inlining."
-msgstr "Выполнить inline-подстановки на ранних проходах оптимизации"
+msgstr "Выполнять ранние inline-подстановки."
 
-#: common.opt:1337
-#, fuzzy
-#| msgid "Perform interprocedural reduction of aggregates"
+#: common.opt:1341
 msgid "Perform interprocedural reduction of aggregates."
-msgstr "Выполнить межпроцедурную редукцию агрегатных данных"
+msgstr "Выполнить межпроцедурную редукцию агрегатных данных."
 
-#: common.opt:1341
-#, fuzzy
-#| msgid "Perform unused type elimination in debug info"
+#: common.opt:1345
 msgid "Perform unused symbol elimination in debug info."
-msgstr "Исключить отладочную информацию о неиспользуемых типах"
+msgstr "Исключить отладочную информацию о неиспользуемых типах."
 
-#: common.opt:1345
-#, fuzzy
-#| msgid "Perform unused type elimination in debug info"
+#: common.opt:1349
 msgid "Perform unused type elimination in debug info."
-msgstr "Исключить отладочную информацию о неиспользуемых типах"
+msgstr "Исключить отладочную информацию о неиспользуемых типах."
 
-#: common.opt:1349
+#: common.opt:1353
 msgid "Do not suppress C++ class debug information."
 msgstr "Не подавлять отладочную информацию о классах C++"
 
-#: common.opt:1353
-#, fuzzy
-#| msgid "Enable exception handling"
+#: common.opt:1357
 msgid "Enable exception handling."
-msgstr "Активировать обработку исключительных ситуаций"
+msgstr "Активировать обработку исключительных ситуаций."
 
-#: common.opt:1357
-#, fuzzy
-#| msgid "Perform a number of minor, expensive optimizations"
+#: common.opt:1361
 msgid "Perform a number of minor, expensive optimizations."
-msgstr "Выполнить некоторые дополнительные дорогостоящие оптимизации"
+msgstr "Выполнить некоторые дополнительные дорогостоящие оптимизации."
 
-#: common.opt:1361
-#, fuzzy
-#| msgid "-fexcess-precision=[fast|standard]\tSpecify handling of excess floating-point precision"
+#: common.opt:1365
 msgid "-fexcess-precision=[fast|standard]\tSpecify handling of excess floating-point precision."
-msgstr "-fexcess-precision=[fast|standard]\tЗадать способ обработки данных с плавающей точкой повышенной точности"
+msgstr "-fexcess-precision=[fast|standard]\tЗадать способ обработки данных с плавающей точкой повышенной точности."
 
-#: common.opt:1364
+#: common.opt:1368
 #, c-format
 msgid "unknown excess precision style %qs"
 msgstr "неизвестный стиль способ обработки данных повышенной точности %qs"
 
-#: common.opt:1376
+#: common.opt:1380
 msgid "-fpermitted-flt-eval-methods=[c11|ts-18661]\tSpecify which values of FLT_EVAL_METHOD are permitted."
-msgstr ""
+msgstr "-fpermitted-flt-eval-methods=[c11|ts-18661]\tЗадать, какие значения FLT_EVAL_METHOD допустимы."
 
-#: common.opt:1379
+#: common.opt:1383
 #, c-format
 msgid "unknown specification for the set of FLT_EVAL_METHOD values to permit %qs"
-msgstr ""
+msgstr "неизвестная спецификация для множества FLT_EVAL_METHOD значений, чтобы разрешить %qs"
 
-#: common.opt:1392
+#: common.opt:1396
 msgid "Output lto objects containing both the intermediate language and binary output."
 msgstr "Выводить в объектные файлы lto и промежуточное, и бинарное представление"
 
-#: common.opt:1396
-#, fuzzy
-#| msgid "Assume no NaNs or infinities are generated"
+#: common.opt:1400
 msgid "Assume no NaNs or infinities are generated."
-msgstr "Предполагать что результаты вычислений конечны и не NaN"
+msgstr "Предполагать, что результаты вычислений конечны и не NaN."
 
-#: common.opt:1400
-#, fuzzy
-#| msgid "-ffixed-<register>\tMark <register> as being unavailable to the compiler"
+#: common.opt:1404
 msgid "-ffixed-<register>\tMark <register> as being unavailable to the compiler."
-msgstr "-ffixed-<register>\tНе использовать <регистр> при генерации кода"
+msgstr "-ffixed-<register>\tНе использовать <регистр> при генерации кода."
 
-#: common.opt:1404
-#, fuzzy
-#| msgid "Don't allocate floats and doubles in extended-precision registers"
+#: common.opt:1408
 msgid "Don't allocate floats and doubles in extended-precision registers."
-msgstr "Не выделять для значений типа float и double регистры повышенной точности"
+msgstr "Не выделять для значений типа float и double регистры повышенной точности."
 
-#: common.opt:1412
-#, fuzzy
-#| msgid "Perform a forward propagation pass on RTL"
+#: common.opt:1416
 msgid "Perform a forward propagation pass on RTL."
-msgstr "Выполнить оптимизацию распространения на представлении RTL"
+msgstr "Выполнить оптимизацию распространения на представлении RTL."
 
-#: common.opt:1416
-#, fuzzy
-#| msgid "-ffp-contract=[off|on|fast] Perform floating-point expression contraction."
+#: common.opt:1420
 msgid "-ffp-contract=[off|on|fast]\tPerform floating-point expression contraction."
-msgstr "-ffp-contract=[off|on|fast] Выполнить сокращение выражений с плавающей точкой."
+msgstr "-ffp-contract=[off|on|fast]\tВыполнить сокращение выражений с плавающей точкой."
 
-#: common.opt:1419
+#: common.opt:1423
 #, c-format
 msgid "unknown floating point contraction style %qs"
 msgstr "некорректный аргумент %qs ключа -ffp-contract"
 
-#: common.opt:1433
+#: common.opt:1437
 msgid "Allow built-in functions ceil, floor, round, trunc to raise \"inexact\" exceptions."
-msgstr ""
+msgstr "Разрешить встроенным функциям ceil, floor, round, trunc возбуждать \"inexact\" исключительные ситуации."
 
-#: common.opt:1440
-#, fuzzy
-#| msgid "Allow function addresses to be held in registers"
+#: common.opt:1444
 msgid "Allow function addresses to be held in registers."
-msgstr "Разрешить хранение адресов функций на регистрах"
+msgstr "Разрешить хранение адресов функций на регистрах."
 
-#: common.opt:1444
-#, fuzzy
-#| msgid "Place each function into its own section"
+#: common.opt:1448
 msgid "Place each function into its own section."
-msgstr "Помещать каждую функцию в отдельную секцию"
+msgstr "Помещать каждую функцию в отдельную секцию."
 
-#: common.opt:1448
-#, fuzzy
-#| msgid "Perform global common subexpression elimination"
+#: common.opt:1452
 msgid "Perform global common subexpression elimination."
-msgstr "Выполнить глобальную экономию общих подвыражений"
+msgstr "Выполнить глобальную экономию общих подвыражений."
 
-#: common.opt:1452
-#, fuzzy
-#| msgid "Perform enhanced load motion during global common subexpression elimination"
+#: common.opt:1456
 msgid "Perform enhanced load motion during global common subexpression elimination."
-msgstr "В рамках глобальной экономии общих подвыражений выполнить расширенный перенос чтений из памяти между блоками"
+msgstr "В рамках глобальной экономии общих подвыражений выполнить расширенный перенос чтений из памяти между блоками."
 
-#: common.opt:1456
-#, fuzzy
-#| msgid "Perform store motion after global common subexpression elimination"
+#: common.opt:1460
 msgid "Perform store motion after global common subexpression elimination."
-msgstr "В рамках глобальной экономии общих подвыражений выполнить перенос записей в память между блоками"
+msgstr "В рамках глобальной экономии общих подвыражений выполнить перенос записей в память между блоками."
 
-#: common.opt:1460
-#, fuzzy
-#| msgid "Perform redundant load after store elimination in global common subexpression elimination"
+#: common.opt:1464
 msgid "Perform redundant load after store elimination in global common subexpression elimination."
-msgstr "В рамках глобальной экономии общих подвыражений исключать лишние чтения из памяти после записей по тем же адресам"
+msgstr "В рамках глобальной экономии общих подвыражений исключать лишние чтения из памяти после записей по тем же адресам."
 
-#: common.opt:1465
-#, fuzzy
-#| msgid "Perform global common subexpression elimination after register allocation has finished"
+#: common.opt:1469
 msgid "Perform global common subexpression elimination after register allocation has finished."
-msgstr "Выполнить глобальную экономию общих подвыражений после распределения регистров"
+msgstr "Выполнить глобальную экономию общих подвыражений после распределения регистров."
 
-#: common.opt:1482
+#: common.opt:1486
 msgid "-fgnat-encodings=[all|gdb|minimal]\tSelect the balance between GNAT encodings and standard DWARF emitted in the debug information"
-msgstr ""
+msgstr "-fgnat-encodings=[all|gdb|minimal]\tВыбрать баланс между GNAT кодированием и стандартным DWARF порождаемым в отладочной информации."
 
-#: common.opt:1487
-#, fuzzy
-#| msgid "Enable in and out of Graphite representation"
+#: common.opt:1491
 msgid "Enable in and out of Graphite representation."
-msgstr "Разрешить ввод и вывод представления Graphite"
+msgstr "Разрешить ввод и вывод представления Graphite."
 
-#: common.opt:1491
-#, fuzzy
-#| msgid "Enable Graphite Identity transformation"
+#: common.opt:1495
 msgid "Enable Graphite Identity transformation."
-msgstr "Разрешить трансформации Graphite"
+msgstr "Разрешить трансформации Graphite."
 
-#: common.opt:1495
-#, fuzzy
-#| msgid "Enable hoisting loads from conditional pointers."
+#: common.opt:1499
 msgid "Enable hoisting adjacent loads to encourage generating conditional move instructions."
-msgstr "Выполнять поднятие загрузок по условным указателям"
+msgstr "Выполнять поднятие соседних загрузок для поддержки генерации условных move инструкций."
 
-#: common.opt:1504
-#, fuzzy
-#| msgid "Mark all loops as parallel"
+#: common.opt:1508
 msgid "Mark all loops as parallel."
-msgstr "Пометить все циклы как параллельные"
+msgstr "Пометить все циклы как параллельные."
 
-#: common.opt:1508 common.opt:1516 common.opt:2587
-#, fuzzy
-#| msgid "Enable loop interchange transforms.  Same as -floop-interchange"
+#: common.opt:1512 common.opt:1520 common.opt:2591
 msgid "Enable loop nest transforms.  Same as -floop-nest-optimize."
-msgstr "Включить трансформации обмена циклов. То же, что -floop-interchange"
+msgstr ""
 
-#: common.opt:1512
-#, fuzzy
-#| msgid "Enable loop header copying on trees"
+#: common.opt:1516
 msgid "Enable loop interchange on trees."
-msgstr "Включить копирование заголовков циклов в древовидном представлении"
+msgstr ""
 
-#: common.opt:1520
-#, fuzzy
-#| msgid "Perform loop unrolling for all loops"
+#: common.opt:1524
 msgid "Perform unroll-and-jam on loops."
-msgstr "Выполнить развертку всех циклов"
+msgstr ""
 
-#: common.opt:1524
-#, fuzzy
-#| msgid "Enable support for GNU transactional memory"
+#: common.opt:1528
 msgid "Enable support for GNU transactional memory."
-msgstr "Включить поддержку транзакционной памяти GNU"
+msgstr "Включить поддержку транзакционной памяти GNU."
 
-#: common.opt:1528
+#: common.opt:1532
 msgid "Use STB_GNU_UNIQUE if supported by the assembler."
-msgstr ""
+msgstr "Использовать STB_GNU_UNIQUE, если поддерживается ассемблером."
 
-#: common.opt:1536
-#, fuzzy
-#| msgid "Run the loop optimizer twice"
+#: common.opt:1540
 msgid "Enable the loop nest optimizer."
-msgstr "Выполнить оптимизацию циклов дважды"
+msgstr "Включить оптимизатор гнезд циклов."
 
-#: common.opt:1540
-#, fuzzy
-#| msgid "Force bitfield accesses to match their type width"
+#: common.opt:1544
 msgid "Force bitfield accesses to match their type width."
-msgstr "Генерировать доступ к битовым полям в соответствии с шириной их типа"
+msgstr "Генерировать доступ к битовым полям в соответствии с шириной их типа."
 
-#: common.opt:1544
+#: common.opt:1548
 msgid "Merge adjacent stores."
-msgstr ""
+msgstr "Сливать смежные сохранения."
 
-#: common.opt:1548
-#, fuzzy
-#| msgid "Enable guessing of branch probabilities"
+#: common.opt:1552
 msgid "Enable guessing of branch probabilities."
-msgstr "Оценивать вероятности переходов"
+msgstr "Оценивать вероятности переходов."
 
-#: common.opt:1556
-#, fuzzy
-#| msgid "Process #ident directives"
+#: common.opt:1560
 msgid "Process #ident directives."
-msgstr "Обрабатывать директивы #ident"
+msgstr "Обрабатывать директивы #ident."
 
-#: common.opt:1560
-#, fuzzy
-#| msgid "Perform conversion of conditional jumps to branchless equivalents"
+#: common.opt:1564
 msgid "Perform conversion of conditional jumps to branchless equivalents."
-msgstr "Преобразовывать условные переходы в эквивалентный код без переходов"
+msgstr "Преобразовывать условные переходы в эквивалентный код без переходов."
 
-#: common.opt:1564
-#, fuzzy
-#| msgid "Perform conversion of conditional jumps to conditional execution"
+#: common.opt:1568
 msgid "Perform conversion of conditional jumps to conditional execution."
-msgstr "Преобразовывать условные переходы в условно выполняемый код"
+msgstr "Преобразовывать условные переходы в условно выполняемый код."
 
-#: common.opt:1568
+#: common.opt:1572
 msgid "-fstack-reuse=[all|named_vars|none]\tSet stack reuse level for local variables."
-msgstr ""
+msgstr "-fstack-reuse=[all|named_vars|none]\tУстановить уровень переиспользования стека для локальных переменных."
 
-#: common.opt:1571
-#, fuzzy, c-format
-#| msgid "unknown TLS model %qs"
+#: common.opt:1575
+#, c-format
 msgid "unknown Stack Reuse Level %qs"
-msgstr "неизвестная модель генерации кода TLS %qs"
+msgstr "неизвестный Stack Reuse Level %qs"
 
-#: common.opt:1584
-#, fuzzy
-#| msgid "Convert conditional jumps in innermost loops to branchless equivalents"
+#: common.opt:1588
 msgid "Convert conditional jumps in innermost loops to branchless equivalents."
-msgstr "Преобразовывать условные переходы во внутренних циклах в эквивалентный код без переходов"
+msgstr "Преобразовывать условные переходы во внутренних циклах в эквивалентный код без переходов."
 
-#: common.opt:1596
-#, fuzzy
-#| msgid "Do not generate .size directives"
+#: common.opt:1600
 msgid "Do not generate .size directives."
-msgstr "Не генерировать директивы .size"
+msgstr "Не генерировать директивы .size."
 
-#: common.opt:1600
-#, fuzzy
-#| msgid "Perform indirect inlining"
+#: common.opt:1604
 msgid "Perform indirect inlining."
-msgstr "Выполнить inline-подстановки косвенных вызовов"
+msgstr "Выполнить inline-подстановки косвенных вызовов."
 
-#: common.opt:1606
-#, fuzzy
-#| msgid "Enable inlining of function declared \"inline\", disabling disables all inlining"
+#: common.opt:1610
 msgid "Enable inlining of function declared \"inline\", disabling disables all inlining."
-msgstr "Включить inline-подстановки функций со спецификатором \"inline\", отмена отключает все inline-подстановки"
+msgstr "Включить inline-подстановки функций со спецификатором \"inline\", отмена отключает все inline-подстановки."
 
-#: common.opt:1610
-#, fuzzy
-#| msgid "Integrate functions into their callers when code size is known not to grow"
+#: common.opt:1614
 msgid "Integrate functions into their callers when code size is known not to grow."
-msgstr "Подставлять тела функций в места вызовов, когда это не увеличивает размер кода"
+msgstr "Подставлять тела функций в места вызовов, когда это не увеличивает размер кода."
 
-#: common.opt:1614
-#, fuzzy
-#| msgid "Integrate functions not declared \"inline\" into their callers when profitable"
+#: common.opt:1618
 msgid "Integrate functions not declared \"inline\" into their callers when profitable."
-msgstr "Подставлять тела функций без спецификатора \"inline\" в места вызова, когда это выгодно"
+msgstr "Подставлять тела функций без спецификатора \"inline\" в места вызова, когда это выгодно."
 
-#: common.opt:1618
-#, fuzzy
-#| msgid "Integrate functions only required by their single caller"
+#: common.opt:1622
 msgid "Integrate functions only required by their single caller."
-msgstr "Подставлять в места вызовов тела функций, вызываемых только один раз"
+msgstr "Подставлять в места вызовов тела функций, вызываемых только один раз."
 
-#: common.opt:1625
-#, fuzzy
-#| msgid "-finline-limit=<number>\tLimit the size of inlined functions to <number>"
+#: common.opt:1629
 msgid "-finline-limit=<number>\tLimit the size of inlined functions to <number>."
-msgstr "-finline-limit=<размер>\tМаксимальный <размер> функций для inline-подстановки"
+msgstr "-finline-limit=<размер>\tМаксимальный <размер> функций для inline-подстановки."
 
-#: common.opt:1629
+#: common.opt:1633
 msgid "Inline __atomic operations when a lock free instruction sequence is available."
 msgstr "Делать подстановку операций __atomic, если имеется соответствующая неблокирующая последовательность инструкций"
 
-#: common.opt:1636
+#: common.opt:1640
 msgid "-fcf-protection=[full|branch|return|none]\tInstrument functions with checks to verify jump/call/return control-flow transfer instructions have valid targets."
 msgstr ""
 
-#: common.opt:1640
-#, fuzzy, c-format
-#| msgid "unknown TLS model %qs"
+#: common.opt:1644
+#, c-format
 msgid "unknown Control-Flow Protection Level %qs"
-msgstr "неизвестная модель генерации кода TLS %qs"
+msgstr ""
 
-#: common.opt:1656
-#, fuzzy
-#| msgid "Instrument function entry and exit with profiling calls"
+#: common.opt:1660
 msgid "Instrument function entry and exit with profiling calls."
-msgstr "При входе и выходе из функции генерировать вызовы профилирования"
+msgstr "При входе и выходе из функции генерировать вызовы профилирования."
 
-#: common.opt:1660
-#, fuzzy
-#| msgid "-finstrument-functions-exclude-function-list=name,...  Do not instrument listed functions"
+#: common.opt:1664
 msgid "-finstrument-functions-exclude-function-list=name,...  Do not instrument listed functions."
-msgstr "-finstrument-functions-exclude-function-list=name,...  Не инструментировать перечисленные функции"
+msgstr "-finstrument-functions-exclude-function-list=name,...  Не инструментировать перечисленные функции."
 
-#: common.opt:1664
-#, fuzzy
-#| msgid "-finstrument-functions-exclude-file-list=filename,...  Do not instrument functions listed in files"
+#: common.opt:1668
 msgid "-finstrument-functions-exclude-file-list=filename,...  Do not instrument functions listed in files."
-msgstr "-finstrument-functions-exclude-file-list=filename,...  Не инструментировать функции, перечисленные в указанных файлах"
+msgstr "-finstrument-functions-exclude-file-list=filename,...  Не инструментировать функции, перечисленные в указанных файлах."
 
-#: common.opt:1668
-#, fuzzy
-#| msgid "Perform Interprocedural constant propagation"
+#: common.opt:1672
 msgid "Perform interprocedural constant propagation."
-msgstr "Выполнить межпроцедурное распространение констант"
+msgstr "Выполнить межпроцедурное распространение констант."
 
-#: common.opt:1672
-#, fuzzy
-#| msgid "Perform cloning to make Interprocedural constant propagation stronger"
+#: common.opt:1676
 msgid "Perform cloning to make Interprocedural constant propagation stronger."
-msgstr "Выполнить клонирование для усиления межпроцедурного распространения констант"
+msgstr "Выполнить клонирование для усиления межпроцедурного распространения констант."
 
-#: common.opt:1680
-#, fuzzy
-#| msgid "Perform Interprocedural constant propagation"
+#: common.opt:1684
 msgid "Perform interprocedural bitwise constant propagation."
-msgstr "Выполнить межпроцедурное распространение констант"
+msgstr "Выполнить межпроцедурное побитное распространение констант."
 
-#: common.opt:1684
-#, fuzzy
-#| msgid "Perform interprocedural profile propagation"
+#: common.opt:1688
 msgid "Perform interprocedural profile propagation."
-msgstr "Выполнить межпроцедурное распространение профиля"
+msgstr "Выполнить межпроцедурное распространение профиля."
 
-#: common.opt:1688
-#, fuzzy
-#| msgid "Perform interprocedural points-to analysis"
+#: common.opt:1692
 msgid "Perform interprocedural points-to analysis."
-msgstr "Выполнить межпроцедурный анализ указателей"
+msgstr "Выполнить межпроцедурный анализ указателей."
 
-#: common.opt:1692
-#, fuzzy
-#| msgid "Discover pure and const functions"
+#: common.opt:1696
 msgid "Discover pure and const functions."
-msgstr "Выявлять pure и const функции"
+msgstr "Выявлять pure и const функции."
 
-#: common.opt:1696
+#: common.opt:1700
 msgid "Perform Identical Code Folding for functions and read-only variables."
-msgstr ""
+msgstr "Выполнять сжатие идентичного кода для функций и read-only переменных."
 
-#: common.opt:1700
+#: common.opt:1704
 msgid "Perform Identical Code Folding for functions."
-msgstr ""
+msgstr "Выполнять сжатие идентичного кода для функций."
 
-#: common.opt:1704
+#: common.opt:1708
 msgid "Perform Identical Code Folding for variables."
-msgstr ""
+msgstr "Выполнять сжатие идентичного кода для переменных."
 
-#: common.opt:1708
-#, fuzzy
-#| msgid "Discover readonly and non addressable static variables"
+#: common.opt:1712
 msgid "Discover readonly and non addressable static variables."
-msgstr "Выявлять неадресуемые статические переменные, доступные только для чтения"
+msgstr "Выявлять неадресуемые статические переменные, доступные только для чтения."
 
-#: common.opt:1720
-#, fuzzy
-#| msgid "Perform Value Range Propagation on trees"
+#: common.opt:1724
 msgid "Perform IPA Value Range Propagation."
-msgstr "Выполнить оптимизацию распространения диапазонов значений на древовидном представлении"
+msgstr "Выполнять IPA распространение диапазонов значений."
 
-#: common.opt:1724
-#, fuzzy
-#| msgid "-fira-algorithm=[CB|priority] Set the used IRA algorithm"
+#: common.opt:1728
 msgid "-fira-algorithm=[CB|priority]\tSet the used IRA algorithm."
-msgstr "-fira-algorithm=[CB|priority] Задать алгоритм раскраски для распределения регистров"
+msgstr "-fira-algorithm=[CB|priority] Задать алгоритм раскраски для распределения регистров."
 
-#: common.opt:1727
+#: common.opt:1731
 #, c-format
 msgid "unknown IRA algorithm %qs"
 msgstr "неизвестный алгоритм раскраски %qs"
 
-#: common.opt:1737
-#, fuzzy
-#| msgid "-fira-region=[one|all|mixed] Set regions for IRA"
+#: common.opt:1741
 msgid "-fira-region=[one|all|mixed]\tSet regions for IRA."
-msgstr "-fira-region=[one|all|mixed] Задать регионы для IRA"
+msgstr "-fira-region=[one|all|mixed] Задать регионы для IRA."
 
-#: common.opt:1740
+#: common.opt:1744
 #, c-format
 msgid "unknown IRA region %qs"
 msgstr "неизвестный регион %qs для распределения регистров"
 
-#: common.opt:1753
-#, fuzzy
-#| msgid "Use IRA based register pressure calculation in RTL loop optimizations."
+#: common.opt:1757
 msgid "Use IRA based register pressure calculation in RTL hoist optimizations."
-msgstr "Использовать IRA для оценки регистрового давления в RTL-оптимизациях циклов"
+msgstr "Использовать IRA для оценки регистрового давления в RTL-оптимизациях циклов."
 
-#: common.opt:1758
-#, fuzzy
-#| msgid "Use IRA based register pressure calculation in RTL loop optimizations."
+#: common.opt:1762
 msgid "Use IRA based register pressure calculation in RTL loop optimizations."
-msgstr "Использовать IRA для оценки регистрового давления в RTL-оптимизациях циклов"
+msgstr "Использовать IRA для оценки регистрового давления в RTL-оптимизациях циклов."
 
-#: common.opt:1763
+#: common.opt:1767
 msgid "Share slots for saving different hard registers."
 msgstr "Использовать общие слоты стека для сохранения разных аппаратных регистров"
 
-#: common.opt:1767
+#: common.opt:1771
 msgid "Share stack slots for spilled pseudo-registers."
 msgstr "Использовать общие слоты стека для сохранения вытолкнутых псевдорегистров"
 
-#: common.opt:1771
+#: common.opt:1775
 msgid "-fira-verbose=<number>\tControl IRA's level of diagnostic messages."
 msgstr "-fira-verbose=<уровень>\tЗадать <уровень> диагностики IRA."
 
-#: common.opt:1775
-#, fuzzy
-#| msgid "Optimize induction variables on trees"
+#: common.opt:1779
 msgid "Optimize induction variables on trees."
-msgstr "Оптимизировать индуктивные переменные в древовидном представлении"
+msgstr "Оптимизировать индуктивные переменные в древовидном представлении."
 
-#: common.opt:1779
-#, fuzzy
-#| msgid "Use jump tables for sufficiently large switch statements"
+#: common.opt:1783
 msgid "Use jump tables for sufficiently large switch statements."
-msgstr "Использовать таблицы переходов для достаточно больших операторов switch"
+msgstr "Использовать таблицы переходов для достаточно больших операторов switch."
 
-#: common.opt:1783
-#, fuzzy
-#| msgid "Generate code for functions even if they are fully inlined"
+#: common.opt:1787
 msgid "Generate code for functions even if they are fully inlined."
-msgstr "Генерировать код для функций даже при 100%% inline-подстановке"
+msgstr "Генерировать код для функций даже при 100%% inline-подстановке."
 
-#: common.opt:1787
-#, fuzzy
-#| msgid "Generate code for functions even if they are fully inlined"
+#: common.opt:1791
 msgid "Generate code for static functions even if they are never called."
-msgstr "Генерировать код для функций даже при 100%% inline-подстановке"
+msgstr "Генерировать код для статических функций, даже если они никогда не вызываются."
 
-#: common.opt:1791
-#, fuzzy
-#| msgid "Emit static const variables even if they are not used"
+#: common.opt:1795
 msgid "Emit static const variables even if they are not used."
-msgstr "Не удалять даже неиспользуемые статические константные переменные"
+msgstr "Не удалять даже неиспользуемые статические константные переменные."
 
-#: common.opt:1795
-#, fuzzy
-#| msgid "Give external symbols a leading underscore"
+#: common.opt:1799
 msgid "Give external symbols a leading underscore."
-msgstr "Добавлять в начало внешних символов подчеркивание"
+msgstr "Добавлять в начало внешних символов подчеркивание."
 
-#: common.opt:1803
+#: common.opt:1807
 msgid "Do CFG-sensitive rematerialization in LRA."
-msgstr ""
+msgstr "Выполнить CFG-зависимую рематериализацию в LRA."
 
-#: common.opt:1807
+#: common.opt:1811
 msgid "Enable link-time optimization."
 msgstr "Включить оптимизации времени компоновки."
 
-#: common.opt:1811
+#: common.opt:1815
 msgid "Link-time optimization with number of parallel jobs or jobserver."
 msgstr "Включить оптимизации времени компоновки с заданным числом параллельных задач или с использованием сервера задач"
 
-#: common.opt:1814
-#, fuzzy, c-format
-#| msgid "unknown TLS model %qs"
+#: common.opt:1818
+#, c-format
 msgid "unknown LTO partitioning model %qs"
-msgstr "неизвестная модель генерации кода TLS %qs"
+msgstr "неизвестная LTO модель разбиения %qs"
 
-#: common.opt:1833
+#: common.opt:1837
 msgid "Specify the algorithm to partition symbols and vars at linktime."
-msgstr ""
+msgstr "Задать алгоритм разделения символов и переменных при компоновке."
 
-#: common.opt:1838
-#, fuzzy
-#| msgid "-flto-compression-level=<number>\tUse zlib compression level <number> for IL"
+#: common.opt:1842
 msgid "-flto-compression-level=<number>\tUse zlib compression level <number> for IL."
-msgstr "-flto-compression-level=<уровень>\tИспользовать заданный <уровень> сжатия zlib для промежуточного представления."
+msgstr "-flto-compression-level=<number>\tИспользовать заданный уровень сжатия <number> zlib для IL."
 
-#: common.opt:1842
+#: common.opt:1846
 msgid "Merge C++ types using One Definition Rule."
-msgstr ""
+msgstr "Слить C++ типы используя правило одного определения."
 
-#: common.opt:1846
-#, fuzzy
-#| msgid "Report various link-time optimization statistics"
+#: common.opt:1850
 msgid "Report various link-time optimization statistics."
-msgstr "Выдать статистику оптимизации времени выполнения"
+msgstr "Выдать статистику оптимизации при компоновке."
 
-#: common.opt:1850
-#, fuzzy
-#| msgid "Report various link-time optimization statistics"
+#: common.opt:1854
 msgid "Report various link-time optimization statistics for WPA only."
-msgstr "Выдать статистику оптимизации времени выполнения"
+msgstr "Выдать статистику оптимизации при компоновке только для WPA."
 
-#: common.opt:1854
-#, fuzzy
-#| msgid "Set errno after built-in math functions"
+#: common.opt:1858
 msgid "Set errno after built-in math functions."
-msgstr "Устанавливать errno после вызовов встроенных мат. функций"
+msgstr "Устанавливать errno после вызовов встроенных мат. функций."
 
-#: common.opt:1858
-#, fuzzy
-#| msgid "-fmax-errors=<number>\tMaximum number of errors to report"
+#: common.opt:1862
 msgid "-fmax-errors=<number>\tMaximum number of errors to report."
-msgstr "-fmax-errors=<number>\tМаксимальное число сообщений об ошибках"
+msgstr "-fmax-errors=<number>\tМаксимальное число сообщений об ошибках."
 
-#: common.opt:1862
-#, fuzzy
-#| msgid "Report on permanent memory allocation"
+#: common.opt:1866
 msgid "Report on permanent memory allocation."
-msgstr "Вывести информацию о распределении памяти"
+msgstr "Выдать информацию о распределении постоянной памяти."
 
-#: common.opt:1866
-#, fuzzy
-#| msgid "Report on permanent memory allocation"
+#: common.opt:1870
 msgid "Report on permanent memory allocation in WPA only."
-msgstr "Вывести информацию о распределении памяти"
+msgstr "Выдать информацию о распределении постоянной памяти только для WPA."
 
-#: common.opt:1873
-#, fuzzy
-#| msgid "Attempt to merge identical constants and constant variables"
+#: common.opt:1877
 msgid "Attempt to merge identical constants and constant variables."
-msgstr "Слить идентичные константы и константные переменные"
+msgstr "Слить идентичные константы и константные переменные."
 
-#: common.opt:1877
-#, fuzzy
-#| msgid "Attempt to merge identical constants across compilation units"
+#: common.opt:1881
 msgid "Attempt to merge identical constants across compilation units."
-msgstr "Слить идентичные константы по всем единицам компиляции"
+msgstr "Слить идентичные константы по всем единицам компиляции."
 
-#: common.opt:1881
-#, fuzzy
-#| msgid "Attempt to merge identical debug strings across compilation units"
+#: common.opt:1885
 msgid "Attempt to merge identical debug strings across compilation units."
-msgstr "Попытаться слить одинаковые строки в отладочной информации для всех единиц компиляции"
+msgstr "Попытаться слить одинаковые строки в отладочной информации для всех единиц компиляции."
 
-#: common.opt:1885
-#, fuzzy
-#| msgid "-fmessage-length=<number>\tLimit diagnostics to <number> characters per line.  0 suppresses line-wrapping"
+#: common.opt:1889
 msgid "-fmessage-length=<number>\tLimit diagnostics to <number> characters per line.  0 suppresses line-wrapping."
-msgstr "-fmessage-length=<длина>\tУстановить <длину> строк диагностических сообщений в символах. 0 - подавить разбиение на строки"
+msgstr ""
 
-#: common.opt:1889
-#, fuzzy
-#| msgid "Perform SMS based modulo scheduling before the first scheduling pass"
+#: common.opt:1893
 msgid "Perform SMS based modulo scheduling before the first scheduling pass."
-msgstr "Выполнять планирование циклов по модулю методом SMS перед первым проходом планирования команд"
+msgstr "Выполнять планирование циклов по модулю методом SMS перед первым проходом планирования команд."
 
-#: common.opt:1893
-#, fuzzy
-#| msgid "Perform SMS based modulo scheduling with register moves allowed"
+#: common.opt:1897
 msgid "Perform SMS based modulo scheduling with register moves allowed."
-msgstr "Выполнять планирование циклов по модулю методом SMS перед первым проходом планирования команд"
+msgstr "Выполнять планирование циклов по модулю методом SMS перед первым проходом планирования команд."
 
-#: common.opt:1897
-#, fuzzy
-#| msgid "Move loop invariant computations out of loops"
+#: common.opt:1901
 msgid "Move loop invariant computations out of loops."
-msgstr "Выносить инвариантные вычисления за пределы циклов"
+msgstr "Выносить инвариантные вычисления за пределы циклов."
 
-#: common.opt:1901
-#, fuzzy
-#| msgid "Use the RTL dead code elimination pass"
+#: common.opt:1905
 msgid "Use the RTL dead code elimination pass."
-msgstr "Выполнить оптимизацию удаления мертвых команд в RTL-представлении"
+msgstr "Выполнить оптимизацию удаления мертвых команд в RTL-представлении."
 
-#: common.opt:1905
-#, fuzzy
-#| msgid "Use the RTL dead store elimination pass"
+#: common.opt:1909
 msgid "Use the RTL dead store elimination pass."
-msgstr "Выполнить оптимизацию удаления мертвых команд записи в память в RTL-представлении"
+msgstr "Выполнить оптимизацию удаления мертвых команд записи в память в RTL-представлении."
 
-#: common.opt:1909
-#, fuzzy
-#| msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling"
+#: common.opt:1913
 msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling."
-msgstr "Включить/отменить обычное планирование для конвейеризованных циклов"
+msgstr "Включить/отменить обычное планирование для конвейеризованных циклов."
 
-#: common.opt:1913
-#, fuzzy
-#| msgid "Support synchronous non-call exceptions"
+#: common.opt:1917
 msgid "Support synchronous non-call exceptions."
-msgstr "Поддерживать синхронные исключения вне вызовов"
+msgstr "Поддерживать синхронные исключения вне вызовов."
 
-#: common.opt:1916
-#, fuzzy, c-format
-#| msgid "assertion missing after %qs"
+#: common.opt:1920
+#, c-format
 msgid "options or targets missing after %qs"
-msgstr "не задано утверждение после %qs"
+msgstr "опции или цели отсутствуют после %qs"
 
-#: common.opt:1917
+#: common.opt:1921
 msgid "-foffload=<targets>=<options>  Specify offloading targets and options for them."
-msgstr ""
+msgstr "-foffload=<targets>=<options>  Задать разгружаемые цели и опции для них."
 
-#: common.opt:1921
+#: common.opt:1925
 msgid "-foffload-abi=[lp64|ilp32]     Set the ABI to use in an offload compiler."
-msgstr ""
+msgstr "-foffload-abi=[lp64|ilp32]     Установить ABI используемый в компиляторе разгрузки."
 
-#: common.opt:1924
-#, fuzzy, c-format
-#| msgid "unknown TLS model %qs"
+#: common.opt:1928
+#, c-format
 msgid "unknown offload ABI %qs"
-msgstr "неизвестная модель генерации кода TLS %qs"
+msgstr "неизвестный ABI выгрузки %qs"
 
-#: common.opt:1934
-#, fuzzy
-#| msgid "When possible do not generate stack frames"
+#: common.opt:1938
 msgid "When possible do not generate stack frames."
-msgstr "По возможности не создавать кадры стека"
+msgstr "По возможности не создавать кадры стека."
 
-#: common.opt:1938
-#, fuzzy
-#| msgid "Enable loop optimizations on tree level"
+#: common.opt:1942
 msgid "Enable all optimization info dumps on stderr."
-msgstr "Включить оптимизации циклов на древовидном представлении"
+msgstr "Включить вывод всей оптимизационной информации в stderr."
 
-#: common.opt:1942
+#: common.opt:1946
 msgid "-fopt-info[-<type>=filename]\tDump compiler optimization details."
-msgstr ""
+msgstr "-fopt-info[-<type>=filename]\tВыдать детали компиляторной оптимизации."
 
-#: common.opt:1950
-#, fuzzy
-#| msgid "Optimize sibling and tail recursive calls"
+#: common.opt:1954
 msgid "Optimize sibling and tail recursive calls."
-msgstr "Оптимизировать парные вызовы и хвостовую рекурсию"
+msgstr "Оптимизировать парные вызовы и хвостовую рекурсию."
 
-#: common.opt:1954
-#, fuzzy
-#| msgid "Perform partial inlining"
+#: common.opt:1958
 msgid "Perform partial inlining."
-msgstr "Выполнить частичные inline-подстановки"
+msgstr "Выполнить частичные inline-подстановки."
 
-#: common.opt:1958 common.opt:1962
-#, fuzzy
-#| msgid "Report on memory allocation before interprocedural optimization"
+#: common.opt:1962 common.opt:1966
 msgid "Report on memory allocation before interprocedural optimization."
-msgstr "Выдать отчет о распределении памяти перед межпроцедурными оптимизациями"
+msgstr "Выдать отчет о распределении памяти перед межпроцедурными оптимизациями."
 
-#: common.opt:1966
-#, fuzzy
-#| msgid "Pack structure members together without holes"
+#: common.opt:1970
 msgid "Pack structure members together without holes."
-msgstr "Паковать поля структур без дыр"
+msgstr "Паковать поля структур без дыр."
 
-#: common.opt:1970
-#, fuzzy
-#| msgid "-fpack-struct=<number>\tSet initial maximum structure member alignment"
+#: common.opt:1974
 msgid "-fpack-struct=<number>\tSet initial maximum structure member alignment."
-msgstr "-fpack-struct=<number>\tУстановить начальное максимальное выравнивание для элементов структур"
+msgstr "-fpack-struct=<number>\tУстановить начальное максимальное выравнивание для элементов структур."
 
-#: common.opt:1974
-#, fuzzy
-#| msgid "Return small aggregates in memory, not registers"
+#: common.opt:1978
 msgid "Return small aggregates in memory, not registers."
-msgstr "Возвращать короткие агрегатные значения в памяти, а не в регистрах"
+msgstr "Возвращать короткие агрегатные значения в памяти, а не в регистрах."
 
-#: common.opt:1978
-#, fuzzy
-#| msgid "Perform loop peeling"
+#: common.opt:1982
 msgid "Perform loop peeling."
-msgstr "Выполнить раскатку циклов"
+msgstr "Выполнить раскатку циклов."
 
-#: common.opt:1982
-#, fuzzy
-#| msgid "Enable machine specific peephole optimizations"
+#: common.opt:1986
 msgid "Enable machine specific peephole optimizations."
-msgstr "Выполнить машинно-зависимые оптимизации"
+msgstr "Выполнить машинно-зависимые оптимизации."
 
-#: common.opt:1986
-#, fuzzy
-#| msgid "Enable an RTL peephole pass before sched2"
+#: common.opt:1990
 msgid "Enable an RTL peephole pass before sched2."
-msgstr "Выполнить машинно-зависимые оптимизации перед вторым планированием"
+msgstr "Выполнить машинно-зависимые оптимизации перед вторым планированием."
 
-#: common.opt:1990
-#, fuzzy
-#| msgid "Generate position-independent code if possible (large mode)"
+#: common.opt:1994
 msgid "Generate position-independent code if possible (large mode)."
-msgstr "Генерировать позиционно-независимый код, если возможно (режим large)"
+msgstr "Генерировать позиционно-независимый код, если возможно (режим large)."
 
-#: common.opt:1994
-#, fuzzy
-#| msgid "Generate position-independent code for executables if possible (large mode)"
+#: common.opt:1998
 msgid "Generate position-independent code for executables if possible (large mode)."
-msgstr "Генерировать позиционно-независимый код для выполняемых модулей, если возможно (режим large)"
+msgstr "Генерировать позиционно-независимый код для выполняемых модулей, если возможно (режим large)."
 
-#: common.opt:1998
-#, fuzzy
-#| msgid "Generate position-independent code if possible (small mode)"
+#: common.opt:2002
 msgid "Generate position-independent code if possible (small mode)."
-msgstr "Генерировать позиционно-независимый код, если возможно (режим small)"
+msgstr "Генерировать позиционно-независимый код, если возможно (режим small)."
 
-#: common.opt:2002
-#, fuzzy
-#| msgid "Generate position-independent code for executables if possible (small mode)"
+#: common.opt:2006
 msgid "Generate position-independent code for executables if possible (small mode)."
-msgstr "Генерировать позиционно-независимый код для выполняемых модулей, если возможно (режим small)"
+msgstr "Генерировать позиционно-независимый код для выполняемых модулей, если возможно (режим small)."
 
-#: common.opt:2006
+#: common.opt:2010
 msgid "Use PLT for PIC calls (-fno-plt: load the address from GOT at call site)."
-msgstr ""
+msgstr "Использовать PLT для PIC вызовов (-fno-plt: загрузить адрес из GOT при вызове)."
 
-#: common.opt:2010
-#, fuzzy
-#| msgid "Specify a plugin to load"
+#: common.opt:2014
 msgid "Specify a plugin to load."
-msgstr "Задать подгружаемый модуль"
+msgstr "Задать подгружаемый модуль."
 
-#: common.opt:2014
-#, fuzzy
-#| msgid "-fplugin-arg-<name>-<key>[=<value>]\tSpecify argument <key>=<value> for plugin <name>"
+#: common.opt:2018
 msgid "-fplugin-arg-<name>-<key>[=<value>]\tSpecify argument <key>=<value> for plugin <name>."
-msgstr "-fplugin-arg-<name>-<key>[=<value>]\tЗадать аргумент <key>=<value> для подгружаемого модуля <name>"
+msgstr "-fplugin-arg-<name>-<key>[=<value>]\tЗадать аргумент <key>=<value> для подгружаемого модуля <name>."
 
-#: common.opt:2018
+#: common.opt:2022
 msgid "Run predictive commoning optimization."
 msgstr "Выполнить оптимизацию переиспользования вычислений"
 
-#: common.opt:2022
-#, fuzzy
-#| msgid "Generate prefetch instructions, if available, for arrays in loops"
+#: common.opt:2026
 msgid "Generate prefetch instructions, if available, for arrays in loops."
-msgstr "Генерировать команды предвыборки элементов массивов, если они поддерживаются"
+msgstr "Генерировать команды предвыборки элементов массивов, если они поддерживаются."
 
-#: common.opt:2026
-#, fuzzy
-#| msgid "Enable basic program profiling code"
+#: common.opt:2030
 msgid "Enable basic program profiling code."
-msgstr "Включить генерацию базового кода для профилирования"
+msgstr "Включить генерацию базового кода для профилирования."
 
-#: common.opt:2030
-#, fuzzy
-#| msgid "Generate call insns as indirect calls"
+#: common.opt:2034
 msgid "Generate absolute source path names for gcov."
-msgstr "Генерировать инструкции вызова как косвенные вызовы"
+msgstr ""
 
-#: common.opt:2034
-#, fuzzy
-#| msgid "Insert arc-based program profiling code"
+#: common.opt:2038
 msgid "Insert arc-based program profiling code."
-msgstr "Вставлять код для профилирования по дугам управляющего графа программы"
+msgstr "Вставлять код для профилирования по дугам управляющего графа программы."
 
-#: common.opt:2038
-#, fuzzy
-#| msgid "Set the top-level directory for storing the profile data. The default is 'pwd'."
+#: common.opt:2042
 msgid "Set the top-level directory for storing the profile data. The default is 'pwd'."
-msgstr "Указать каталог верхнего уровня для сохранения данных профилирования. По умолчанию 'pwd'."
+msgstr ""
 
-#: common.opt:2043
-#, fuzzy
-#| msgid "Enable correction of flow inconsistent profile data input"
+#: common.opt:2047
 msgid "Enable correction of flow inconsistent profile data input."
-msgstr "Включить коррекцию несовместимых с потоком управления данных профилирования"
+msgstr "Включить коррекцию несовместимых с потоком управления данных профилирования."
 
-#: common.opt:2047
+#: common.opt:2051
 msgid "-fprofile-update=[single|atomic|prefer-atomic]\tSet the profile update method."
-msgstr ""
+msgstr "-fprofile-update=[single|atomic|prefer-atomic]\tУстановить метод изменения профиля."
 
-#: common.opt:2050
-#, fuzzy, c-format
-#| msgid "unknown TLS model %qs"
+#: common.opt:2054
+#, c-format
 msgid "unknown profile update method %qs"
-msgstr "неизвестная модель генерации кода TLS %qs"
+msgstr "неизвестный метод изменения профиля %qs"
 
-#: common.opt:2063
-#, fuzzy
-#| msgid "Enable common options for generating profile info for profile feedback directed optimizations"
+#: common.opt:2067
 msgid "Enable common options for generating profile info for profile feedback directed optimizations."
-msgstr "Активировать ключи генерации данных профилирования для выполнения соответствующих оптимизаций"
+msgstr "Активировать ключи генерации данных профилирования для выполнения соответствующих оптимизаций."
 
-#: common.opt:2067
-#, fuzzy
-#| msgid "Enable common options for generating profile info for profile feedback directed optimizations, and set -fprofile-dir="
+#: common.opt:2071
 msgid "Enable common options for generating profile info for profile feedback directed optimizations, and set -fprofile-dir=."
-msgstr "Активировать ключи генерации данных профилирования для выполнения соответствующих оптимизаций и установить -fprofile-dir="
+msgstr "Активировать ключи генерации данных профилирования для выполнения соответствующих оптимизаций и установить -fprofile-dir=."
 
-#: common.opt:2071
-#, fuzzy
-#| msgid "Enable common options for performing profile feedback directed optimizations"
+#: common.opt:2075
 msgid "Enable common options for performing profile feedback directed optimizations."
-msgstr "Активировать ключи оптимизаций, основанных на данных профилирования"
+msgstr "Активировать ключи оптимизаций, основанных на данных профилирования."
 
-#: common.opt:2075
-#, fuzzy
-#| msgid "Enable common options for performing profile feedback directed optimizations, and set -fprofile-dir="
+#: common.opt:2079
 msgid "Enable common options for performing profile feedback directed optimizations, and set -fprofile-dir=."
-msgstr "Активировать ключи оптимизаций, основанных на данных профилирования и установить -fprofile-dir="
+msgstr "Активировать ключи оптимизаций, основанных на данных профилирования и установить -fprofile-dir=."
 
-#: common.opt:2079
-#, fuzzy
-#| msgid "Insert code to profile values of expressions"
+#: common.opt:2083
 msgid "Insert code to profile values of expressions."
-msgstr "Вставлять код для профилирования значений выражений"
+msgstr "Вставлять код для профилирования значений выражений."
 
-#: common.opt:2083
-#, fuzzy
-#| msgid "internal consistency failure"
+#: common.opt:2087
 msgid "Report on consistency of profile."
-msgstr "обнаружена несогласованность внутреннего представления gcc"
+msgstr "Выдавать отчет о непротиворечивости профиля."
 
-#: common.opt:2087
-#, fuzzy
-#| msgid "Reorder functions to improve code placement"
+#: common.opt:2091
 msgid "Enable function reordering that improves code placement."
-msgstr "Переупорядочить функции для улучшения размещения кода"
+msgstr "Включить переупорядочение функций улучшающее размещение кода."
 
-#: common.opt:2091
-#, fuzzy
-#| msgid "Generate cld instruction in the function prologue."
+#: common.opt:2095
 msgid "Insert NOP instructions at each function entry."
-msgstr "Генерировать команду cld в прологе функции."
+msgstr ""
 
-#: common.opt:2098
-#, fuzzy
-#| msgid "-frandom-seed=<string>\tMake compile reproducible using <string>"
+#: common.opt:2102
 msgid "-frandom-seed=<string>\tMake compile reproducible using <string>."
-msgstr "-frandom-seed=<строка>\tКомпилировать воспроизводимым образом, используя <строку> для генерации случайных чисел"
+msgstr "-frandom-seed=<строка>\tКомпилировать воспроизводимым образом, используя <строку> для генерации случайных чисел."
 
-#: common.opt:2108
+#: common.opt:2112
 msgid "Record gcc command line switches in the object file."
 msgstr "Записать ключи командной строки gcc в объектный файл"
 
-#: common.opt:2112
-#, fuzzy
-#| msgid "Return small aggregates in registers"
+#: common.opt:2116
 msgid "Return small aggregates in registers."
-msgstr "Возвращать короткие агрегатные значения в регистрах"
+msgstr "Возвращать короткие агрегатные значения в регистрах."
 
-#: common.opt:2120
+#: common.opt:2124
 msgid "Tell DSE that the storage for a C++ object is dead when the constructor starts and when the destructor finishes."
-msgstr ""
+msgstr "Сообщить DSE, что память для C++ объекта мертва, когда конструктор стартует и когда деструктор финиширует."
 
-#: common.opt:2128
-#, fuzzy
-#| msgid "Enable register pressure sensitive insn scheduling"
+#: common.opt:2132
 msgid "Relief of register pressure through live range shrinkage."
-msgstr "Использовать планирование команд с учетом регистрового давления"
+msgstr "Облегчение регистрового давления путем сокращения действующих интервалов."
 
-#: common.opt:2132
-#, fuzzy
-#| msgid "Perform a register renaming optimization pass"
+#: common.opt:2136
 msgid "Perform a register renaming optimization pass."
-msgstr "Выполнить оптимизацию переименования регистров"
+msgstr "Выполнить оптимизацию переименования регистров."
 
-#: common.opt:2136
-#, fuzzy
-#| msgid "Perform a register renaming optimization pass"
+#: common.opt:2140
 msgid "Perform a target dependent instruction fusion optimization pass."
-msgstr "Выполнить оптимизацию переименования регистров"
+msgstr "Выполнить оптимизационный проход слияния зависящих от цели инструкций."
 
-#: common.opt:2140
-#, fuzzy
-#| msgid "Reorder basic blocks to improve code placement"
+#: common.opt:2144
 msgid "Reorder basic blocks to improve code placement."
-msgstr "Переупорядочить блоки для улучшения размещения кода"
+msgstr "Переупорядочить блоки для улучшения размещения кода."
 
-#: common.opt:2144
+#: common.opt:2148
 msgid "-freorder-blocks-algorithm=[simple|stc]\tSet the used basic block reordering algorithm."
-msgstr ""
+msgstr "-freorder-blocks-algorithm=[simple|stc]\tУстановить используемый алгоритм переупорядочения базового блока."
 
-#: common.opt:2147
-#, fuzzy, c-format
-#| msgid "unknown IRA algorithm %qs"
+#: common.opt:2151
+#, c-format
 msgid "unknown basic block reordering algorithm %qs"
-msgstr "неизвестный алгоритм раскраски %qs"
+msgstr "неизвестный алгоритм переупорядочения базовых блоков %qs"
 
-#: common.opt:2157
-#, fuzzy
-#| msgid "Reorder basic blocks and partition into hot and cold sections"
+#: common.opt:2161
 msgid "Reorder basic blocks and partition into hot and cold sections."
-msgstr "Переупорядочить блоки и партиции в hot и cold разделы"
+msgstr "Переупорядочить блоки и партиции в hot и cold разделы."
 
-#: common.opt:2161
-#, fuzzy
-#| msgid "Reorder functions to improve code placement"
+#: common.opt:2165
 msgid "Reorder functions to improve code placement."
-msgstr "Переупорядочить функции для улучшения размещения кода"
+msgstr "Переупорядочить функции для улучшения размещения кода."
 
-#: common.opt:2165
-#, fuzzy
-#| msgid "Add a common subexpression elimination pass after loop optimizations"
+#: common.opt:2169
 msgid "Add a common subexpression elimination pass after loop optimizations."
-msgstr "Выполнить экономию общих подвыражений еще и после оптимизации циклов"
+msgstr "Выполнить экономию общих подвыражений еще и после оптимизации циклов."
 
-#: common.opt:2173
-#, fuzzy
-#| msgid "Disable optimizations that assume default FP rounding behavior"
+#: common.opt:2177
 msgid "Disable optimizations that assume default FP rounding behavior."
-msgstr "Отменить оптимизации, предполагающие стандартное округление вещественных значений"
+msgstr "Отменить оптимизации, предполагающие стандартное округление вещественных значений."
 
-#: common.opt:2177
-#, fuzzy
-#| msgid "Enable scheduling across basic blocks"
+#: common.opt:2181
 msgid "Enable scheduling across basic blocks."
-msgstr "Планировать команды в рамках нескольких блоков"
+msgstr "Планировать команды в рамках нескольких блоков."
 
-#: common.opt:2181
-#, fuzzy
-#| msgid "Enable register pressure sensitive insn scheduling"
+#: common.opt:2185
 msgid "Enable register pressure sensitive insn scheduling."
-msgstr "Использовать планирование команд с учетом регистрового давления"
+msgstr "Использовать планирование команд с учетом регистрового давления."
 
-#: common.opt:2185
-#, fuzzy
-#| msgid "Allow speculative motion of non-loads"
+#: common.opt:2189
 msgid "Allow speculative motion of non-loads."
-msgstr "Разрешить спекулятивный перенос команд, кроме чтения"
+msgstr "Разрешить спекулятивный перенос команд, кроме чтения."
 
-#: common.opt:2189
-#, fuzzy
-#| msgid "Allow speculative motion of some loads"
+#: common.opt:2193
 msgid "Allow speculative motion of some loads."
-msgstr "Разрешить спекулятивный перенос некоторых команд чтения"
+msgstr "Разрешить спекулятивный перенос некоторых команд чтения."
 
-#: common.opt:2193
-#, fuzzy
-#| msgid "Allow speculative motion of more loads"
+#: common.opt:2197
 msgid "Allow speculative motion of more loads."
-msgstr "Разрешить более активный спекулятивный перенос команд чтения"
+msgstr "Разрешить более активный спекулятивный перенос команд чтения."
 
-#: common.opt:2197
-#, fuzzy
-#| msgid "-fsched-verbose=<number>\tSet the verbosity level of the scheduler"
+#: common.opt:2201
 msgid "-fsched-verbose=<number>\tSet the verbosity level of the scheduler."
-msgstr "-fsched-verbose=<уровень>\tУстановить <уровень> подробности сообщений от планировщика"
+msgstr "-fsched-verbose=<уровень>\tУстановить <уровень> подробности сообщений от планировщика."
 
-#: common.opt:2201
-#, fuzzy
-#| msgid "If scheduling post reload, do superblock scheduling"
+#: common.opt:2205
 msgid "If scheduling post reload, do superblock scheduling."
-msgstr "При планировании после распределения регистров, использовать метод суперблоков"
+msgstr "При планировании после распределения регистров, использовать метод суперблоков."
 
-#: common.opt:2209
-#, fuzzy
-#| msgid "Reschedule instructions before register allocation"
+#: common.opt:2213
 msgid "Reschedule instructions before register allocation."
-msgstr "Планировать код перед распределением регистров"
+msgstr "Планировать код перед распределением регистров."
 
-#: common.opt:2213
-#, fuzzy
-#| msgid "Reschedule instructions after register allocation"
+#: common.opt:2217
 msgid "Reschedule instructions after register allocation."
-msgstr "Планировать код после распределения регистров"
+msgstr "Планировать код после распределения регистров."
 
-#: common.opt:2220
-#, fuzzy
-#| msgid "Schedule instructions using selective scheduling algorithm"
+#: common.opt:2224
 msgid "Schedule instructions using selective scheduling algorithm."
-msgstr "Использовать алгоритм селективного планирования команд"
+msgstr "Использовать алгоритм селективного планирования команд."
 
-#: common.opt:2224
-#, fuzzy
-#| msgid "Run selective scheduling after reload"
+#: common.opt:2228
 msgid "Run selective scheduling after reload."
-msgstr "Выполнить селективное планирование после прохода перегрузки регистров"
+msgstr "Выполнить селективное планирование после прохода перегрузки регистров."
 
-#: common.opt:2228
+#: common.opt:2232
 msgid "Run self-tests, using the given path to locate test files."
-msgstr ""
+msgstr "Запускать тесты самопроверки, используя заданный маршрут для нахождения тестовых файлов."
 
-#: common.opt:2232
-#, fuzzy
-#| msgid "Perform software pipelining of inner loops during selective scheduling"
+#: common.opt:2236
 msgid "Perform software pipelining of inner loops during selective scheduling."
-msgstr "Выполнить программную конвейеризацию внутренних циклов во время селективного планирования"
+msgstr "Выполнить программную конвейеризацию внутренних циклов во время селективного планирования."
 
-#: common.opt:2236
-#, fuzzy
-#| msgid "Perform software pipelining of outer loops during selective scheduling"
+#: common.opt:2240
 msgid "Perform software pipelining of outer loops during selective scheduling."
-msgstr "Выполнить программную конвейеризацию внешних циклов во время селективного планирования"
+msgstr "Выполнить программную конвейеризацию внешних циклов во время селективного планирования."
 
-#: common.opt:2240
-#, fuzzy
-#| msgid "Reschedule pipelined regions without pipelining"
+#: common.opt:2244
 msgid "Reschedule pipelined regions without pipelining."
-msgstr "Перепланировать конвейеризованные области без конвейеризации"
+msgstr "Перепланировать конвейеризованные области без конвейеризации."
 
-#: common.opt:2244
+#: common.opt:2248
 msgid "Allow interposing function (or variables) by ones with different semantics (or initializer) respectively by dynamic linker."
-msgstr ""
+msgstr "Разрешить динамическому компоновщике вставлять функцию (или переменные) с другой семантикой (или инициализатором) соответственно."
 
-#: common.opt:2250
-#, fuzzy
-#| msgid "Allow premature scheduling of queued insns"
+#: common.opt:2254
 msgid "Allow premature scheduling of queued insns."
-msgstr "Разрешить предварительное планирование отложенных команд"
+msgstr "Разрешить предварительное планирование отложенных команд."
 
-#: common.opt:2254
-#, fuzzy
-#| msgid "-fsched-stalled-insns=<number>\tSet number of queued insns that can be prematurely scheduled"
+#: common.opt:2258
 msgid "-fsched-stalled-insns=<number>\tSet number of queued insns that can be prematurely scheduled."
-msgstr "-fsched-stalled-insns=<число>\tЗадать <число> отложенных команд, подлежащих предварительному планированию"
+msgstr "-fsched-stalled-insns=<число>\tЗадать <число> отложенных команд, подлежащих предварительному планированию."
 
-#: common.opt:2262
-#, fuzzy
-#| msgid "Set dependence distance checking in premature scheduling of queued insns"
+#: common.opt:2266
 msgid "Set dependence distance checking in premature scheduling of queued insns."
-msgstr "Включить проверку дальности зависимостей при предварительном планировании отложенных команд"
+msgstr "Включить проверку дальности зависимостей при предварительном планировании отложенных команд."
 
-#: common.opt:2266
-#, fuzzy
-#| msgid "-fsched-stalled-insns-dep=<number>\tSet dependence distance checking in premature scheduling of queued insns"
+#: common.opt:2270
 msgid "-fsched-stalled-insns-dep=<number>\tSet dependence distance checking in premature scheduling of queued insns."
-msgstr "-fsched-stalled-insns-dep=<number>\tВключить проверку дистанции зависимостей при предварительном планировании отложенных команд"
+msgstr "-fsched-stalled-insns-dep=<number>\tВключить проверку дистанции зависимостей при предварительном планировании отложенных команд."
 
-#: common.opt:2270
-#, fuzzy
-#| msgid "Enable the group heuristic in the scheduler"
+#: common.opt:2274
 msgid "Enable the group heuristic in the scheduler."
-msgstr "Установить групповую эвристику для планировщика"
+msgstr "Установить групповую эвристику для планировщика."
 
-#: common.opt:2274
-#, fuzzy
-#| msgid "Enable the critical path heuristic in the scheduler"
+#: common.opt:2278
 msgid "Enable the critical path heuristic in the scheduler."
-msgstr "Установить эвристику критического пути для планировщика"
+msgstr "Установить эвристику критического пути для планировщика."
 
-#: common.opt:2278
-#, fuzzy
-#| msgid "Enable the speculative instruction heuristic in the scheduler"
+#: common.opt:2282
 msgid "Enable the speculative instruction heuristic in the scheduler."
-msgstr "Установить эвристику спекулятивного выполнения команд для планировщика"
+msgstr "Установить эвристику спекулятивного выполнения команд для планировщика."
 
-#: common.opt:2282
-#, fuzzy
-#| msgid "Enable the rank heuristic in the scheduler"
+#: common.opt:2286
 msgid "Enable the rank heuristic in the scheduler."
-msgstr "Установить эвристику ранжирования для планировщика"
+msgstr "Установить эвристику ранжирования для планировщика."
 
-#: common.opt:2286
-#, fuzzy
-#| msgid "Enable the last instruction heuristic in the scheduler"
+#: common.opt:2290
 msgid "Enable the last instruction heuristic in the scheduler."
-msgstr "Установить эвристику \"последней команды\" для планировщика"
+msgstr "Установить эвристику \"последней команды\" для планировщика."
 
-#: common.opt:2290
-#, fuzzy
-#| msgid "Enable the dependent count heuristic in the scheduler"
+#: common.opt:2294
 msgid "Enable the dependent count heuristic in the scheduler."
-msgstr "Установить эвристику по числу зависимых команд для планировщика"
+msgstr "Установить эвристику по числу зависимых команд для планировщика."
 
-#: common.opt:2294
-#, fuzzy
-#| msgid "Access data in the same section from shared anchor points"
+#: common.opt:2298
 msgid "Access data in the same section from shared anchor points."
-msgstr "Использовать доступ к данным из одной секции по общим опорным точкам"
+msgstr "Использовать доступ к данным из одной секции по общим опорным точкам."
 
-#: common.opt:2306
+#: common.opt:2310
 msgid "Turn on Redundant Extensions Elimination pass."
 msgstr "Включить проход исключения избыточных расширений данных"
 
-#: common.opt:2310
-#, fuzzy
-#| msgid "Show column numbers in diagnostics, when available.  Default on"
+#: common.opt:2314
 msgid "Show column numbers in diagnostics, when available.  Default on."
-msgstr "Показывать номера колонок в диагностических сообщениях, если возможно. По умолчанию включено"
+msgstr ""
 
-#: common.opt:2314
-#, fuzzy
-#| msgid "Emit function prologues only before parts of the function that need it, rather than at the top of the function."
+#: common.opt:2318
 msgid "Emit function prologues only before parts of the function that need it, rather than at the top of the function."
-msgstr "Выводить пролог функции только перед теми частями функции, которые используют его, а не в начале функции."
+msgstr "Порождать прологи функции только перед частями функции, которым они нужны, а не в начале функции."
 
-#: common.opt:2319
+#: common.opt:2323
 msgid "Shrink-wrap parts of the prologue and epilogue separately."
-msgstr ""
+msgstr "Упаковать части пролога и эпилога отдельно."
 
-#: common.opt:2323
-#, fuzzy
-#| msgid "Disable optimizations observable by IEEE signaling NaNs"
+#: common.opt:2327
 msgid "Disable optimizations observable by IEEE signaling NaNs."
-msgstr "Отменить оптимизации, влияющие на поведение сигнализирующих NaN по IEEE"
+msgstr "Отменить оптимизации, влияющие на поведение сигнализирующих NaN по IEEE."
 
-#: common.opt:2327
-#, fuzzy
-#| msgid "Disable floating point optimizations that ignore the IEEE signedness of zero"
+#: common.opt:2331
 msgid "Disable floating point optimizations that ignore the IEEE signedness of zero."
-msgstr "Отменить оптимизации вычислений с плавающей точкой и игнорировать знак нуля по IEEE"
+msgstr "Отменить оптимизации вычислений с плавающей точкой и игнорировать знак нуля по IEEE."
 
-#: common.opt:2331
-#, fuzzy
-#| msgid "Convert floating point constants to single precision constants"
+#: common.opt:2335
 msgid "Convert floating point constants to single precision constants."
-msgstr "Преобразовывать вещественные константы к значениям одинарной точности"
+msgstr "Преобразовывать вещественные константы к значениям одинарной точности."
 
-#: common.opt:2335
-#, fuzzy
-#| msgid "Split lifetimes of induction variables when loops are unrolled"
+#: common.opt:2339
 msgid "Split lifetimes of induction variables when loops are unrolled."
-msgstr "Разбивать диапазоны жизни индуктивных переменных при развертке циклов"
+msgstr "Разбивать диапазоны жизни индуктивных переменных при развертке циклов."
 
-#: common.opt:2339
-#, fuzzy
-#| msgid "Generate discontiguous stack frames"
+#: common.opt:2343
 msgid "Generate discontiguous stack frames."
-msgstr "Генерировать не непрерывные кадры стека"
+msgstr "Генерировать не непрерывные кадры стека."
 
-#: common.opt:2343
-#, fuzzy
-#| msgid "Split wide types into independent registers"
+#: common.opt:2347
 msgid "Split wide types into independent registers."
-msgstr "Использовать независимые регистры для широких типов"
+msgstr "Использовать независимые регистры для широких типов."
 
-#: common.opt:2347
-#, fuzzy
-#| msgid "Enable forward propagation on trees"
+#: common.opt:2351
 msgid "Enable backward propagation of use properties at the SSA level."
-msgstr "Выполнять распространение вперед в древовидном представлении"
+msgstr "Включить обратное распространение свойств использования на SSA уровне."
 
-#: common.opt:2351
+#: common.opt:2355
 msgid "Optimize conditional patterns using SSA PHI nodes."
-msgstr ""
+msgstr "Оптимизировать условные шаблона используя SSA PHI узлы."
 
-#: common.opt:2355
+#: common.opt:2359
 msgid "Optimize amount of stdarg registers saved to stack at start of function."
-msgstr ""
+msgstr "Оптимизировать количество stdarg регистров сохраняемых в стеке в начале функции."
 
-#: common.opt:2359
-#, fuzzy
-#| msgid "Apply variable expansion when loops are unrolled"
+#: common.opt:2363
 msgid "Apply variable expansion when loops are unrolled."
-msgstr "Выполнять расширение переменных при развертке циклов"
+msgstr "Выполнять расширение переменных при развертке циклов."
 
-#: common.opt:2363
-#, fuzzy
-#| msgid "-fstack-check=[no|generic|specific]\tInsert stack checking code into the program"
+#: common.opt:2367
 msgid "-fstack-check=[no|generic|specific]\tInsert stack checking code into the program."
-msgstr "-fstack-check=[no|generic|specific]\tГенерировать код для проверки стека"
+msgstr "-fstack-check=[no|generic|specific]\tГенерировать код для проверки стека."
 
-#: common.opt:2367
-#, fuzzy
-#| msgid "Insert stack checking code into the program.  Same as -fstack-check=specific"
+#: common.opt:2371
 msgid "Insert stack checking code into the program.  Same as -fstack-check=specific."
-msgstr "Генерировать код для проверки стека. То же, что -fstack-check=specific"
+msgstr ""
 
-#: common.opt:2371
+#: common.opt:2375
 msgid "Insert code to probe each page of stack space as it is allocated to protect from stack-clash style attacks."
 msgstr ""
 
-#: common.opt:2379
-#, fuzzy
-#| msgid "-fstack-limit-register=<register>\tTrap if the stack goes past <register>"
+#: common.opt:2383
 msgid "-fstack-limit-register=<register>\tTrap if the stack goes past <register>."
-msgstr "-fstack-limit-register=<регистр>\tПрерывание при переполнении стека, <регистр> задает границу стека"
+msgstr "-fstack-limit-register=<регистр>\tПрерывание при переполнении стека, <регистр> задает границу стека."
 
-#: common.opt:2383
-#, fuzzy
-#| msgid "-fstack-limit-symbol=<name>\tTrap if the stack goes past symbol <name>"
+#: common.opt:2387
 msgid "-fstack-limit-symbol=<name>\tTrap if the stack goes past symbol <name>."
-msgstr "-fstack-limit-symbol=<символ>\tПрерывание при переполнении стека, <символ> задает границу стека"
+msgstr "-fstack-limit-symbol=<символ>\tПрерывание при переполнении стека, <символ> задает границу стека."
 
-#: common.opt:2387
-#, fuzzy
-#| msgid "Use propolice as a stack protection method"
+#: common.opt:2391
 msgid "Use propolice as a stack protection method."
-msgstr "Использовать propolice как метод защиты стека"
+msgstr "Использовать propolice как метод защиты стека."
 
-#: common.opt:2391
-#, fuzzy
-#| msgid "Use a stack protection method for every function"
+#: common.opt:2395
 msgid "Use a stack protection method for every function."
-msgstr "Использовать защиту стека для каждой функции"
+msgstr "Использовать защиту стека для каждой функции."
 
-#: common.opt:2395
-#, fuzzy
-#| msgid "Use a stack protection method for every function"
+#: common.opt:2399
 msgid "Use a smart stack protection method for certain functions."
-msgstr "Использовать защиту стека для каждой функции"
+msgstr "Использовать интеллектуальный метод защиты стека для определенных функций."
 
-#: common.opt:2399
-#, fuzzy
-#| msgid "Use a stack protection method for every function"
+#: common.opt:2403
 msgid "Use stack protection method only for functions with the stack_protect attribute."
-msgstr "Использовать защиту стека для каждой функции"
+msgstr "Использовать метод защиты стека только для функций со stack_protect атрибутом."
 
-#: common.opt:2403
-#, fuzzy
-#| msgid "Output stack usage information on a per-function basis"
+#: common.opt:2407
 msgid "Output stack usage information on a per-function basis."
-msgstr "Выводить информацию об использовании стека для каждой функции"
+msgstr "Выводить информацию об использовании стека для каждой функции."
 
-#: common.opt:2415
-#, fuzzy
-#| msgid "Assume strict aliasing rules apply"
+#: common.opt:2419
 msgid "Assume strict aliasing rules apply."
-msgstr "Предполагать строгое соблюдение правил перекрытия данных в памяти"
+msgstr "Предполагать строгое соблюдение правил перекрытия данных в памяти."
 
-#: common.opt:2419
-#, fuzzy
-#| msgid "Treat signed overflow as undefined"
+#: common.opt:2423
 msgid "Treat signed overflow as undefined.  Negated as -fwrapv -fwrapv-pointer."
-msgstr "Трактовать знаковое переполнение как неопределенное поведение"
+msgstr "Трактовать знаковое переполнение как неопределенное поведение.  Negated as -fwrapv -fwrapv-pointer."
 
-#: common.opt:2423
+#: common.opt:2427
 msgid "Implement __atomic operations via libcalls to legacy __sync functions."
-msgstr ""
+msgstr "Реализовать __atomic операции посредством библиотечных вызовов унаследованных __sync функций."
 
-#: common.opt:2427
-#, fuzzy
-#| msgid "Check for syntax errors, then stop"
+#: common.opt:2431
 msgid "Check for syntax errors, then stop."
-msgstr "Проверить код на наличие синтаксических ошибок и завершить работу"
+msgstr "Проверить код на наличие синтаксических ошибок и завершить работу."
 
-#: common.opt:2431
-#, fuzzy
-#| msgid "Create data files needed by \"gcov\""
+#: common.opt:2435
 msgid "Create data files needed by \"gcov\"."
-msgstr "Создать файлы данных для \"gcov\""
+msgstr "Создать файлы данных для \"gcov\"."
 
-#: common.opt:2435
-#, fuzzy
-#| msgid "Perform jump threading optimizations"
+#: common.opt:2439
 msgid "Perform jump threading optimizations."
-msgstr "Выполнить протягивание переходов"
+msgstr "Выполнить протягивание переходов."
 
-#: common.opt:2439
-#, fuzzy
-#| msgid "Report the time taken by each compiler pass"
+#: common.opt:2443
 msgid "Report the time taken by each compiler pass."
-msgstr "Показать время, затраченное на каждый проход оптимизации"
+msgstr "Показать время, затраченное каждым проходом компилятора."
 
-#: common.opt:2443
+#: common.opt:2447
 msgid "Record times taken by sub-phases separately."
-msgstr ""
+msgstr "Показать время, затраченное подфазами, отдельно."
 
-#: common.opt:2447
-#, fuzzy
-#| msgid "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tSet the default thread-local storage code generation model"
+#: common.opt:2451
 msgid "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tSet the default thread-local storage code generation model."
-msgstr "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tМодель генерации кода для данных, локальных для потов, по умолчанию"
+msgstr "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tМодель генерации кода для данных, локальных для потов, по умолчанию."
 
-#: common.opt:2450
+#: common.opt:2454
 #, c-format
 msgid "unknown TLS model %qs"
 msgstr "неизвестная модель генерации кода TLS %qs"
 
-#: common.opt:2466
-#, fuzzy
-#| msgid "Reorder top level functions, variables, and asms"
+#: common.opt:2470
 msgid "Reorder top level functions, variables, and asms."
-msgstr "Переупорядочивать функции, переменные и операторы asm верхнего уровня"
+msgstr "Переупорядочивать функции, переменные и операторы asm верхнего уровня."
 
-#: common.opt:2470
-#, fuzzy
-#| msgid "Perform superblock formation via tail duplication"
+#: common.opt:2474
 msgid "Perform superblock formation via tail duplication."
-msgstr "Формировать суперблоки методом дублирования хвостов"
+msgstr "Формировать суперблоки методом дублирования хвостов."
 
-#: common.opt:2474
+#: common.opt:2478
 msgid "For targets that normally need trampolines for nested functions, always generate them instead of using descriptors."
-msgstr ""
+msgstr "Для целей, которые обычно нуждаются в трамолинах для вложенных функций, всегда генерировать их вместо использования дескрипторов."
 
-#: common.opt:2482
-#, fuzzy
-#| msgid "Assume floating-point operations can trap"
+#: common.opt:2486
 msgid "Assume floating-point operations can trap."
-msgstr "Предполагать возможность прерываний при плавающих операциях"
+msgstr "Предполагать возможность прерываний при плавающих операциях."
 
-#: common.opt:2486
-#, fuzzy
-#| msgid "Trap for signed overflow in addition, subtraction and multiplication"
+#: common.opt:2490
 msgid "Trap for signed overflow in addition, subtraction and multiplication."
-msgstr "Прерывания при знаковых операциях сложения, вычитания, умножения"
+msgstr "Прерывания при знаковых переполнениях в сложении, вычитании и умножении."
 
-#: common.opt:2490
-#, fuzzy
-#| msgid "Enable SSA-CCP optimization on trees"
+#: common.opt:2494
 msgid "Enable SSA-CCP optimization on trees."
-msgstr "Включить SSA-оптимизацию  распространения констант на древовидном представлении"
+msgstr "Включить SSA-оптимизацию  распространения констант на древовидном представлении."
 
-#: common.opt:2494
-#, fuzzy
-#| msgid "Enable SSA-BIT-CCP optimization on trees"
+#: common.opt:2498
 msgid "Enable SSA-BIT-CCP optimization on trees."
-msgstr "Включить SSA-BIT-CCP оптимизацию на древовидном представлении"
+msgstr "Включить SSA-BIT-CCP оптимизацию на древовидном представлении."
 
-#: common.opt:2502
-#, fuzzy
-#| msgid "Enable loop header copying on trees"
+#: common.opt:2506
 msgid "Enable loop header copying on trees."
-msgstr "Включить копирование заголовков циклов в древовидном представлении"
+msgstr "Включить копирование заголовков циклов в древовидном представлении."
 
-#: common.opt:2510
-#, fuzzy
-#| msgid "Enable SSA code sinking on trees"
+#: common.opt:2514
 msgid "Enable SSA coalescing of user variables."
-msgstr "Выполнить погружение SSA-кода на древовидном представлении"
+msgstr "Включить SSA соединение пользовательских переменных."
 
-#: common.opt:2518
-#, fuzzy
-#| msgid "Enable copy propagation on trees"
+#: common.opt:2522
 msgid "Enable copy propagation on trees."
-msgstr "Выполнять распространение копий в древовидном представлении"
+msgstr "Выполнять распространение копий в древовидном представлении."
 
-#: common.opt:2526
-#, fuzzy
-#| msgid "Transform condition stores into unconditional ones"
+#: common.opt:2530
 msgid "Transform condition stores into unconditional ones."
-msgstr "Преобразовывать условные записи в безусловные"
+msgstr "Преобразовывать условные записи в безусловные."
 
-#: common.opt:2530
+#: common.opt:2534
 msgid "Perform conversions of switch initializations."
 msgstr "Выполнять преобразования в инициализации переключателей."
 
-#: common.opt:2534
-#, fuzzy
-#| msgid "Enable SSA dead code elimination optimization on trees"
+#: common.opt:2538
 msgid "Enable SSA dead code elimination optimization on trees."
-msgstr "Выполнить удаление мертвого SSA-кода на древовидном представлении"
+msgstr "Выполнить удаление мертвого SSA-кода на древовидном представлении."
 
-#: common.opt:2538
-#, fuzzy
-#| msgid "Enable dominator optimizations"
+#: common.opt:2542
 msgid "Enable dominator optimizations."
-msgstr "Включить оптимизации доминаторов"
+msgstr "Включить оптимизации доминаторов."
 
-#: common.opt:2542
-#, fuzzy
-#| msgid "Enable tail merging on trees"
+#: common.opt:2546
 msgid "Enable tail merging on trees."
-msgstr "Включить слияние хвостов в древовидном представлении"
+msgstr "Включить слияние хвостов в древовидном представлении."
 
-#: common.opt:2546
-#, fuzzy
-#| msgid "Enable dead store elimination"
+#: common.opt:2550
 msgid "Enable dead store elimination."
-msgstr "Выполнить оптимизацию удаления мертвых команд записи в память"
+msgstr "Выполнить оптимизацию удаления мертвых команд записи в память."
 
-#: common.opt:2550
-#, fuzzy
-#| msgid "Enable forward propagation on trees"
+#: common.opt:2554
 msgid "Enable forward propagation on trees."
-msgstr "Выполнять распространение вперед в древовидном представлении"
+msgstr "Выполнять распространение вперед в древовидном представлении."
 
-#: common.opt:2554
-#, fuzzy
-#| msgid "Enable Full Redundancy Elimination (FRE) on trees"
+#: common.opt:2558
 msgid "Enable Full Redundancy Elimination (FRE) on trees."
-msgstr "Выполнить полный набор оптимизаций удаления избыточного кода на древовидном  представлении"
+msgstr "Выполнить полный набор оптимизаций удаления избыточного кода на древовидном  представлении."
 
-#: common.opt:2558
-#, fuzzy
-#| msgid "Enable string length optimizations on trees"
+#: common.opt:2562
 msgid "Enable string length optimizations on trees."
-msgstr "Включить оптимизацию вычисления длин строк на древовидном представлении"
+msgstr "Включить оптимизацию вычисления длин строк на древовидном представлении."
 
-#: common.opt:2562
+#: common.opt:2566
 msgid "Detect paths that trigger erroneous or undefined behavior due to dereferencing a null pointer.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
-#: common.opt:2568
+#: common.opt:2572
 msgid "Detect paths that trigger erroneous or undefined behavior due to a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
-#: common.opt:2575
-#, fuzzy
-#| msgid "Enable loop distribution on trees"
+#: common.opt:2579
 msgid "Enable loop distribution on trees."
-msgstr "Выполнить распределение циклов на древовидном представлении"
+msgstr "Выполнить распределение циклов на древовидном представлении."
 
-#: common.opt:2579
-#, fuzzy
-#| msgid "Enable loop distribution for patterns transformed into a library call"
+#: common.opt:2583
 msgid "Enable loop distribution for patterns transformed into a library call."
-msgstr "Выполнить распределение циклов для шаблонов, преобразованных в библиотечные вызовы"
+msgstr "Выполнить распределение циклов для шаблонов, преобразованных в библиотечные вызовы."
 
-#: common.opt:2583
-#, fuzzy
-#| msgid "Enable loop invariant motion on trees"
+#: common.opt:2587
 msgid "Enable loop invariant motion on trees."
-msgstr "Выполнить вынесение инвариантных вычислений за пределы циклов на древовидном представлении"
+msgstr "Выполнить вынесение инвариантных вычислений за пределы циклов на древовидном представлении."
 
-#: common.opt:2591
-#, fuzzy
-#| msgid "Create canonical induction variables in loops"
+#: common.opt:2595
 msgid "Create canonical induction variables in loops."
-msgstr "Создавать канонические индуктивные переменные в циклах"
+msgstr "Создавать канонические индуктивные переменные в циклах."
 
-#: common.opt:2595
-#, fuzzy
-#| msgid "Enable loop optimizations on tree level"
+#: common.opt:2599
 msgid "Enable loop optimizations on tree level."
-msgstr "Включить оптимизации циклов на древовидном представлении"
+msgstr "Включить оптимизации циклов на древовидном представлении."
 
-#: common.opt:2599
-#, fuzzy
-#| msgid "Enable automatic parallelization of loops"
+#: common.opt:2603
 msgid "-ftree-parallelize-loops=<number>\tEnable automatic parallelization of loops."
-msgstr "Включить автоматическое распараллеливание циклов"
+msgstr "-ftree-parallelize-loops=<число>\tВключить автоматическое распараллеливание циклов."
 
-#: common.opt:2603
+#: common.opt:2607
 msgid "Enable hoisting loads from conditional pointers."
 msgstr "Выполнять поднятие загрузок по условным указателям"
 
-#: common.opt:2607
-#, fuzzy
-#| msgid "Enable SSA-PRE optimization on trees"
+#: common.opt:2611
 msgid "Enable SSA-PRE optimization on trees."
-msgstr "Включить оптимизации SSA-PRE на древовидном представлении"
+msgstr "Включить оптимизации SSA-PRE на древовидном представлении."
 
-#: common.opt:2611
+#: common.opt:2615
 msgid "In SSA-PRE optimization on trees, enable partial-partial redundancy elimination."
-msgstr ""
+msgstr "В SSA-PRE оптимизации на древовидном представлении включить устранение избыточности часть-часть."
 
-#: common.opt:2615
+#: common.opt:2619
 msgid "Perform function-local points-to analysis on trees."
 msgstr "Выполнить анализ указателей внутри функций на древовидном представлении"
 
-#: common.opt:2619
-#, fuzzy
-#| msgid "Enable reassociation on tree level"
+#: common.opt:2623
 msgid "Enable reassociation on tree level."
-msgstr "Включить оптимизацию ассоциативных операций на древовидном представлении"
+msgstr "Включить оптимизацию ассоциативных операций на древовидном представлении."
 
-#: common.opt:2627
-#, fuzzy
-#| msgid "Enable SSA code sinking on trees"
+#: common.opt:2631
 msgid "Enable SSA code sinking on trees."
-msgstr "Выполнить погружение SSA-кода на древовидном представлении"
+msgstr "Выполнить погружение SSA-кода на древовидном представлении."
 
-#: common.opt:2631
+#: common.opt:2635
 msgid "Perform straight-line strength reduction."
-msgstr ""
+msgstr "Выполнить прямолинейное понижение силы операций."
 
-#: common.opt:2635
-#, fuzzy
-#| msgid "Perform scalar replacement of aggregates"
+#: common.opt:2639
 msgid "Perform scalar replacement of aggregates."
-msgstr "Выполнить замену скаляров для агрегатных значений"
+msgstr "Выполнить замену скаляров для агрегатных значений."
 
-#: common.opt:2639
-#, fuzzy
-#| msgid "Replace temporary expressions in the SSA->normal pass"
+#: common.opt:2643
 msgid "Replace temporary expressions in the SSA->normal pass."
-msgstr "Выполнить замену временных выражений на проходе SSA->normal"
+msgstr "Выполнить замену временных выражений на проходе SSA->normal."
 
-#: common.opt:2643
-#, fuzzy
-#| msgid "Perform live range splitting during the SSA->normal pass"
+#: common.opt:2647
 msgid "Perform live range splitting during the SSA->normal pass."
-msgstr "Выполнить разбиение диапазонов жизни значений на проходе SSA->normal"
+msgstr "Выполнить разбиение диапазонов жизни значений на проходе SSA->normal."
 
-#: common.opt:2647
-#, fuzzy
-#| msgid "Perform Value Range Propagation on trees"
+#: common.opt:2651
 msgid "Perform Value Range Propagation on trees."
-msgstr "Выполнить оптимизацию распространения диапазонов значений на древовидном представлении"
+msgstr "Выполнить распространение диапазонов значений на древовидном представлении."
 
-#: common.opt:2651
+#: common.opt:2655
 msgid "Split paths leading to loop backedges."
-msgstr ""
+msgstr "Расщепить маршруты ведущие к обратным ссылкам цикла."
 
-#: common.opt:2655
+#: common.opt:2659
 msgid "Assume common declarations may be overridden with ones with a larger trailing array."
-msgstr ""
+msgstr "Считать, что common декларации могут быть переопределены другими с большим хвостовым массивом."
 
-#: common.opt:2660
-#, fuzzy
-#| msgid "Compile whole compilation unit at a time"
+#: common.opt:2664
 msgid "Compile whole compilation unit at a time."
-msgstr "Компилировать весь модуль целиком (а не по функциям)"
+msgstr "Компилировать весь модуль за раз."
 
-#: common.opt:2664
-#, fuzzy
-#| msgid "Perform loop unrolling when iteration count is known"
+#: common.opt:2668
 msgid "Perform loop unrolling when iteration count is known."
-msgstr "Выполнить развертку циклов с известным числом итераций"
+msgstr "Выполнить развертку циклов с известным числом итераций."
 
-#: common.opt:2668
-#, fuzzy
-#| msgid "Perform loop unrolling for all loops"
+#: common.opt:2672
 msgid "Perform loop unrolling for all loops."
-msgstr "Выполнить развертку всех циклов"
+msgstr "Выполнить развертку всех циклов."
 
-#: common.opt:2679
-#, fuzzy
-#| msgid "Allow optimization for floating-point arithmetic which may change the result of the operation due to rounding."
+#: common.opt:2683
 msgid "Allow optimization for floating-point arithmetic which may change the result of the operation due to rounding."
 msgstr "Разрешить оптимизации плавающей арифметики, которые могут изменить результат операции из-за округления."
 
-#: common.opt:2684
+#: common.opt:2688
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr "То же, что -fassociative-math для выражений, включающих деление."
 
-#: common.opt:2692
-#, fuzzy
-#| msgid "Allow math optimizations that may violate IEEE or ISO standards"
+#: common.opt:2696
 msgid "Allow math optimizations that may violate IEEE or ISO standards."
-msgstr "Разрешить оптимизации плавающих вычислений, которые могут противоречить стандартам IEEE или ISO"
+msgstr "Разрешить оптимизации плавающих вычислений, которые могут противоречить стандартам IEEE или ISO."
 
-#: common.opt:2696
-#, fuzzy
-#| msgid "Perform loop unswitching"
+#: common.opt:2700
 msgid "Perform loop unswitching."
-msgstr "Выполнить декомпозицию циклов, содержащих условные ветвления"
+msgstr "Выполнить декомпозицию циклов, содержащих условные ветвления."
 
-#: common.opt:2700
-#, fuzzy
-#| msgid "Perform loop peeling"
+#: common.opt:2704
 msgid "Perform loop splitting."
-msgstr "Выполнить раскатку циклов"
+msgstr "Выполнить расщепление циклов"
 
-#: common.opt:2704
-#, fuzzy
-#| msgid "Just generate unwind tables for exception handling"
+#: common.opt:2708
 msgid "Just generate unwind tables for exception handling."
-msgstr "Генерировать unwind-таблицы только для обработки исключений"
+msgstr "Генерировать unwind-таблицы только для обработки исключений."
 
-#: common.opt:2708
-#, fuzzy
-#| msgid "Use the hardware barrel shifter instead of emulation"
+#: common.opt:2712
 msgid "Use the bfd linker instead of the default linker."
-msgstr "Использовать аппаратное устройство циклического сдвига вместо эмуляции"
+msgstr "Использовать bfd компоновщик вместо подразумеваемого."
 
-#: common.opt:2712
-#, fuzzy
-#| msgid "Use the hardware barrel shifter instead of emulation"
+#: common.opt:2716
 msgid "Use the gold linker instead of the default linker."
-msgstr "Использовать аппаратное устройство циклического сдвига вместо эмуляции"
+msgstr "Использовать gold компоновщик вместо подразумеваемого."
 
-#: common.opt:2724
-#, fuzzy
-#| msgid "Perform variable tracking"
+#: common.opt:2728
 msgid "Perform variable tracking."
-msgstr "Выполнить отслеживание переменных"
+msgstr "Выполнить отслеживание переменных."
 
-#: common.opt:2732
-#, fuzzy
-#| msgid "Perform variable tracking by annotating assignments"
+#: common.opt:2736
 msgid "Perform variable tracking by annotating assignments."
-msgstr "Выполнить отслеживание переменных путем аннотирования присваиваний"
+msgstr "Выполнить отслеживание переменных путем аннотирования присваиваний."
 
-#: common.opt:2738
-#, fuzzy
-#| msgid "Toggle -fvar-tracking-assignments"
+#: common.opt:2742
 msgid "Toggle -fvar-tracking-assignments."
-msgstr "Переключить -fvar-tracking-assignments"
+msgstr "Переключить -fvar-tracking-assignments."
 
-#: common.opt:2746
-#, fuzzy
-#| msgid "Perform variable tracking and also tag variables that are uninitialized"
+#: common.opt:2750
 msgid "Perform variable tracking and also tag variables that are uninitialized."
-msgstr "Выполнить отслеживание переменных и пометить неинициализированные переменные"
+msgstr "Выполнить отслеживание переменных и пометить неинициализированные переменные."
 
-#: common.opt:2751
-#, fuzzy
-#| msgid "Enable loop vectorization on trees"
+#: common.opt:2755
 msgid "Enable vectorization on trees."
-msgstr "Выполнить векторизацию циклов на древовидном представлении"
+msgstr "Выполнить векторизацию циклов на древовидном представлении."
 
-#: common.opt:2759
-#, fuzzy
-#| msgid "Enable loop vectorization on trees"
+#: common.opt:2763
 msgid "Enable loop vectorization on trees."
-msgstr "Выполнить векторизацию циклов на древовидном представлении"
+msgstr "Выполнить векторизацию циклов на древовидном представлении."
 
-#: common.opt:2763
-#, fuzzy
-#| msgid "Enable basic block vectorization (SLP) on trees"
+#: common.opt:2767
 msgid "Enable basic block vectorization (SLP) on trees."
-msgstr "Выполнить векторизацию базовых блоков (SLP) на древовидном представлении"
+msgstr "Выполнить векторизацию базовых блоков (SLP) на древовидном представлении."
 
-#: common.opt:2767
+#: common.opt:2771
 msgid "Specifies the cost model for vectorization. -fvect-cost-model=[unlimited|dynamic|cheap]\tSpecifies the cost model for vectorization."
-msgstr ""
+msgstr "Specifies the cost model for vectorization. -fvect-cost-model=[unlimited|dynamic|cheap]\tЗадает ценовую модель для векторизации."
 
-#: common.opt:2772
+#: common.opt:2776
 msgid "-fsimd-cost-model=[unlimited|dynamic|cheap]\tSpecifies the vectorization cost model for code marked with a simd directive."
-msgstr ""
+msgstr "-fsimd-cost-model=[unlimited|dynamic|cheap]\tЗадает ценовую модель для кода помеченного simd директивой."
 
-#: common.opt:2775
-#, fuzzy, c-format
-#| msgid "unknown TLS model %qs"
+#: common.opt:2779
+#, c-format
 msgid "unknown vectorizer cost model %qs"
-msgstr "неизвестная модель генерации кода TLS %qs"
+msgstr "неизвестная ценовая модель векторизатора %qs"
 
-#: common.opt:2788
-#, fuzzy
-#| msgid "Does nothing.  Preserved for backward compatibility."
+#: common.opt:2792
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
-msgstr "Игнорируется. Сохранен для обратной совместимости"
+msgstr "Enables the dynamic vectorizer cost model.  Сохранён для обратной совместимости."
 
-#: common.opt:2796
+#: common.opt:2800
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr "Выполнять распространение копий по информации об эволюции скалярных значений."
 
-#: common.opt:2806
-#, fuzzy
-#| msgid "Add extra commentary to assembler output"
+#: common.opt:2810
 msgid "Add extra commentary to assembler output."
-msgstr "Добавить комментарии к ассемблерному коду"
+msgstr "Добавить комментарии к ассемблерному коду."
 
-#: common.opt:2810
-#, fuzzy
-#| msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility"
+#: common.opt:2814
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility."
-msgstr "-fvisibility=[default|internal|hidden|protected]\tУстановить атрибут видимости символов по умолчанию"
+msgstr "-fvisibility=[default|internal|hidden|protected]\tУстановить атрибут видимости символов по умолчанию."
 
-#: common.opt:2813
+#: common.opt:2817
 #, c-format
 msgid "unrecognized visibility value %qs"
 msgstr "некорректный тип видимости %qs"
 
-#: common.opt:2829
+#: common.opt:2833
 msgid "Validate vtable pointers before using them."
-msgstr ""
+msgstr "Проверяйте vtable указатели до их использования."
 
-#: common.opt:2832
-#, fuzzy, c-format
-#| msgid "(near initialization for %qs)"
+#: common.opt:2836
+#, c-format
 msgid "unknown vtable verify initialization priority %qs"
-msgstr "(где-то рядом с инициализацией для %qs)"
+msgstr "неизвестный vtable verify приоритет инициализации %qs"
 
-#: common.opt:2845
+#: common.opt:2849
 msgid "Output vtable verification counters."
-msgstr ""
+msgstr "Выдать vtable верификационные счетчики."
 
-#: common.opt:2849
+#: common.opt:2853
 msgid "Output vtable verification pointer sets information."
-msgstr ""
+msgstr "Выдать информацию о множествах vtable верификационных указателей."
 
-#: common.opt:2853
-#, fuzzy
-#| msgid "Use expression value profiles in optimizations"
+#: common.opt:2857
 msgid "Use expression value profiles in optimizations."
-msgstr "Использовать данные профилирования значений при оптимизациях"
+msgstr "Использовать данные профилирования значений при оптимизациях."
 
-#: common.opt:2857
-#, fuzzy
-#| msgid "Construct webs and split unrelated uses of single variable"
+#: common.opt:2861
 msgid "Construct webs and split unrelated uses of single variable."
-msgstr "Снять зависимости между различными использованиями одной и той же переменной"
+msgstr "Снять зависимости между различными использованиями одной и той же переменной."
 
-#: common.opt:2861
-#, fuzzy
-#| msgid "Enable conditional dead code elimination for builtin calls"
+#: common.opt:2865
 msgid "Enable conditional dead code elimination for builtin calls."
-msgstr "Выполнить удаление условного мертвого кода для вызовов встроенных функций"
+msgstr "Выполнить удаление условного мертвого кода для вызовов встроенных функций."
 
-#: common.opt:2865
-#, fuzzy
-#| msgid "Perform whole program optimizations"
+#: common.opt:2869
 msgid "Perform whole program optimizations."
-msgstr "Выполнить оптимизации на уровне всей программы"
+msgstr "Выполнить оптимизации на уровне всей программы."
 
-#: common.opt:2869
-#, fuzzy
-#| msgid "Assume signed arithmetic overflow wraps around"
+#: common.opt:2873
 msgid "Assume pointer overflow wraps around."
-msgstr "Предполагать циклический перенос при арифметических переполнениях"
+msgstr ""
 
-#: common.opt:2873
-#, fuzzy
-#| msgid "Assume signed arithmetic overflow wraps around"
+#: common.opt:2877
 msgid "Assume signed arithmetic overflow wraps around."
-msgstr "Предполагать циклический перенос при арифметических переполнениях"
+msgstr "Предполагать циклический перенос при арифметических переполнениях."
 
-#: common.opt:2877
-#, fuzzy
-#| msgid "Put zero initialized data in the bss section"
+#: common.opt:2881
 msgid "Put zero initialized data in the bss section."
-msgstr "Помещать данные, инициализированные нулями, в секцию bss"
+msgstr "Помещать данные, инициализированные нулями, в секцию bss."
 
-#: common.opt:2881
-#, fuzzy
-#| msgid "Generate debug information in default format"
+#: common.opt:2885
 msgid "Generate debug information in default format."
-msgstr "Генерировать отладочную информацию в формате по умолчанию"
+msgstr "Генерировать отладочную информацию в формате по умолчанию."
 
-#: common.opt:2885
-#, fuzzy
-#| msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
+#: common.opt:2889
 msgid "Assume assembler support for (DWARF2+) .loc directives"
-msgstr "%<-fsplit-stack%> требует поддержку ассемблера для CFI директив"
+msgstr ""
 
-#: common.opt:2889
-#, fuzzy
-#| msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
+#: common.opt:2893
 msgid "Assume assembler support for view in (DWARF2+) .loc directives"
-msgstr "%<-fsplit-stack%> требует поддержку ассемблера для CFI директив"
+msgstr ""
 
-#: common.opt:2892 common.opt:2896 common.opt:2900 common.opt:2904
-#, fuzzy, c-format
-#| msgid "switch %qs is no longer supported"
+#: common.opt:2896 common.opt:2900 common.opt:2904 common.opt:2908
+#, c-format
 msgid "switch %qs no longer supported"
-msgstr "ключ %qs больше не поддерживается"
+msgstr ""
 
-#: common.opt:2909
+#: common.opt:2913
 msgid "Record DW_AT_decl_column and DW_AT_call_column in DWARF."
-msgstr ""
+msgstr "Записывать DW_AT_decl_column и DW_AT_call_column в DWARF."
 
-#: common.opt:2913
-#, fuzzy
-#| msgid "Generate debug information in default format"
+#: common.opt:2917
 msgid "Generate debug information in default version of DWARF format."
-msgstr "Генерировать отладочную информацию в формате по умолчанию"
+msgstr "Генерировать отладочную информацию в подразумеваемой версии DWARF формата."
 
-#: common.opt:2917
-#, fuzzy
-#| msgid "Generate debug information in DWARF v2 (or later) format"
+#: common.opt:2921
 msgid "Generate debug information in DWARF v2 (or later) format."
-msgstr "Генерировать отладочную информацию в формате DWARF версии 2 или более поздней"
+msgstr "Генерировать отладочную информацию в формате DWARF версии 2 (или более поздней)."
 
-#: common.opt:2921
-#, fuzzy
-#| msgid "Generate debug information in default extended format"
+#: common.opt:2925
 msgid "Generate debug information in default extended format."
-msgstr "Генерировать отладочную информацию в расширенном формате по умолчанию"
+msgstr "Генерировать отладочную информацию в расширенном формате по умолчанию."
 
-#: common.opt:2925
-#, fuzzy
-#| msgid "Generate a single exit point for each function"
+#: common.opt:2929
 msgid "Generate extended entry point information for inlined functions"
-msgstr "Генерировать одну выходную точку для каждой функции"
+msgstr ""
 
-#: common.opt:2929
+#: common.opt:2933
 msgid "Compute locview reset points based on insn length estimates"
 msgstr ""
 
-#: common.opt:2937
+#: common.opt:2941
 msgid "Don't generate DWARF pubnames and pubtypes sections."
-msgstr ""
+msgstr "Не генерировать DWARF pubnames и pubtypes секции."
 
-#: common.opt:2941
+#: common.opt:2945
 msgid "Generate DWARF pubnames and pubtypes sections."
-msgstr ""
+msgstr "Генерировать DWARF pubnames и pubtypes секции."
 
-#: common.opt:2945
+#: common.opt:2949
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
-msgstr ""
+msgstr "Генерировать DWARF pubnames и pubtypes секции с GNU расширениями."
 
-#: common.opt:2949
+#: common.opt:2953
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr "Записывать ключи командной строки gcc в DWARF DW_AT_producer."
 
-#: common.opt:2953
-#, fuzzy
-#| msgid "Generate debug information in default format"
+#: common.opt:2957
 msgid "Generate debug information in separate .dwo files."
-msgstr "Генерировать отладочную информацию в формате по умолчанию"
+msgstr "Генерировать отладочную информацию в отдельных .dwo файлах."
 
-#: common.opt:2957
-#, fuzzy
-#| msgid "Generate debug information in STABS format"
+#: common.opt:2961
 msgid "Generate debug information in STABS format."
-msgstr "Генерировать отладочную информацию в формате STABS"
+msgstr "Генерировать отладочную информацию в формате STABS."
 
-#: common.opt:2961
-#, fuzzy
-#| msgid "Generate debug information in extended STABS format"
+#: common.opt:2965
 msgid "Generate debug information in extended STABS format."
-msgstr "Генерировать отладочную информацию в расширенном формате STABS"
+msgstr "Генерировать отладочную информацию в расширенном формате STABS."
 
-#: common.opt:2965
+#: common.opt:2969
 msgid "Emit progressive recommended breakpoint locations."
 msgstr ""
 
-#: common.opt:2969
-#, fuzzy
-#| msgid "Don't emit DWARF additions beyond selected version"
+#: common.opt:2973
 msgid "Don't emit DWARF additions beyond selected version."
-msgstr "Не генерировать дополнения DWARF, не входящие в выбранную версию"
+msgstr "Не генерировать дополнения DWARF, не входящие в выбранную версию."
 
-#: common.opt:2973
-#, fuzzy
-#| msgid "Toggle debug information generation"
+#: common.opt:2977
 msgid "Toggle debug information generation."
-msgstr "Переключить генерацию отладочной информации"
+msgstr "Переключить генерацию отладочной информации."
 
-#: common.opt:2977
+#: common.opt:2981
 msgid "Augment variable location lists with progressive views."
 msgstr ""
 
-#: common.opt:2984
-#, fuzzy
-#| msgid "Generate debug information in VMS format"
+#: common.opt:2988
 msgid "Generate debug information in VMS format."
-msgstr "Генерировать отладочную информацию в формате VMS"
+msgstr "Генерировать отладочную информацию в формате VMS."
 
-#: common.opt:2988
-#, fuzzy
-#| msgid "Generate debug information in XCOFF format"
+#: common.opt:2992
 msgid "Generate debug information in XCOFF format."
-msgstr "Генерировать отладочную информацию в формате XCOFF"
+msgstr "Генерировать отладочную информацию в формате XCOFF."
 
-#: common.opt:2992
-#, fuzzy
-#| msgid "Generate debug information in extended XCOFF format"
+#: common.opt:2996
 msgid "Generate debug information in extended XCOFF format."
-msgstr "Генерировать отладочную информацию в расширенном формате XCOFF"
+msgstr "Генерировать отладочную информацию в расширенном формате XCOFF."
 
-#: common.opt:3010
-#, fuzzy
-#| msgid "Generate isel instructions"
+#: common.opt:3014
 msgid "Generate compressed debug sections."
-msgstr "Генерировать команды isel"
+msgstr "Генерировать сжатые debug секции."
 
-#: common.opt:3014
+#: common.opt:3018
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>."
-msgstr ""
+msgstr "-gz=<format>\tГенерировать сжатые отладочные секции в формате <format>."
 
-#: common.opt:3021
-#, fuzzy
-#| msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory"
+#: common.opt:3025
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory."
-msgstr "-iplugindir=<каталог>\tУстановить <каталог> подгружаемых модулей по умолчанию"
+msgstr "-iplugindir=<каталог>\tУстановить <каталог> подгружаемых модулей по умолчанию."
 
-#: common.opt:3025
-#, fuzzy
-#| msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory"
+#: common.opt:3029
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory."
-msgstr "-imultiarch <каталог>\tУстановить <каталог> заголовочных файлов для мультиархитектуры"
+msgstr "-imultiarch <каталог>\tУстановить <каталог> заголовочных файлов для мультиархитектуры."
 
-#: common.opt:3047
-#, fuzzy
-#| msgid "-o <file>\tPlace output into <file>"
+#: common.opt:3051
 msgid "-o <file>\tPlace output into <file>."
-msgstr "-o <файл>\tЗаписать результат в <файл>"
+msgstr "-o <файл>\tЗаписать результат в <файл>."
 
-#: common.opt:3051
-#, fuzzy
-#| msgid "Enable function profiling"
+#: common.opt:3055
 msgid "Enable function profiling."
-msgstr "Включить профилирование функций"
+msgstr "Включить профилирование функций."
 
-#: common.opt:3061
-#, fuzzy
-#| msgid "Like -pedantic but issue them as errors"
+#: common.opt:3065
 msgid "Like -pedantic but issue them as errors."
-msgstr "Как -pedantic, но выдавать ошибки, а не предупреждения"
+msgstr "Как -pedantic, но выдавать ошибки, а не предупреждения."
 
-#: common.opt:3101
-#, fuzzy
-#| msgid "Do not display functions compiled or elapsed time"
+#: common.opt:3105
 msgid "Do not display functions compiled or elapsed time."
-msgstr "Не отображать время компиляции функций"
+msgstr "Не отображать время компиляции функций."
 
-#: common.opt:3133
-#, fuzzy
-#| msgid "Enable verbose output"
+#: common.opt:3137
 msgid "Enable verbose output."
-msgstr "Включить подробную выдачу"
+msgstr "Включить подробную выдачу."
 
-#: common.opt:3137
-#, fuzzy
-#| msgid "Display the compiler's version"
+#: common.opt:3141
 msgid "Display the compiler's version."
-msgstr "Показать версию компилятора"
+msgstr "Показать версию компилятора."
 
-#: common.opt:3141
-#, fuzzy
-#| msgid "Suppress warnings"
+#: common.opt:3145
 msgid "Suppress warnings."
-msgstr "Подавить выдачу предупреждений"
+msgstr "Подавить выдачу предупреждений."
 
-#: common.opt:3151
-#, fuzzy
-#| msgid "Create a shared library"
+#: common.opt:3155
 msgid "Create a shared library."
-msgstr "Создать разделяемую библиотеку"
+msgstr "Создать разделяемую библиотеку."
 
-#: common.opt:3196
-#, fuzzy
-#| msgid "Create a position independent executable"
+#: common.opt:3200
 msgid "Don't create a dynamically linked position independent executable."
-msgstr "Генерировать позиционно-независимый код для выполняемого модуля"
+msgstr ""
 
-#: common.opt:3200
-#, fuzzy
-#| msgid "Create a position independent executable"
+#: common.opt:3204
 msgid "Create a dynamically linked position independent executable."
-msgstr "Генерировать позиционно-независимый код для выполняемого модуля"
+msgstr ""
 
-#: common.opt:3204
-#, fuzzy
-#| msgid "Create a position independent executable"
+#: common.opt:3208
 msgid "Create a static position independent executable."
-msgstr "Генерировать позиционно-независимый код для выполняемого модуля"
+msgstr ""
 
-#: common.opt:3211
+#: common.opt:3215
 msgid "Use caller save register across calls if possible."
-msgstr ""
+msgstr "Использовать сохранение регистров вызывающей стороной при всех возможных вызовах."
 
-#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:598 cp/cvt.c:1308
+#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:599 cp/cvt.c:1308
 #: cp/cvt.c:1561
 #, gcc-internal-format
 msgid "value computed is not used"
@@ -19907,17 +15826,14 @@
 msgstr "ожидался булевый тип"
 
 #: go/gofrontend/expressions.cc:4331 c/c-parser.c:13477 c/c-parser.c:13484
-#: cp/parser.c:33264 cp/parser.c:33271
-#, fuzzy, gcc-internal-format
-#| msgid "Expected integer"
+#: cp/parser.c:33261 cp/parser.c:33268
+#, gcc-internal-format
 msgid "expected integer"
-msgstr "Ожидалось целочисленное значение"
+msgstr "ожидалось целое"
 
 #: go/gofrontend/expressions.cc:5959
-#, fuzzy
-#| msgid "invalid comparison code in gimple cond"
 msgid "invalid comparison of nil with nil"
-msgstr "некорректный код сравнения в gimple условном выражении"
+msgstr "некорректное сравнение nil с nil"
 
 #: go/gofrontend/expressions.cc:5965 go/gofrontend/expressions.cc:5983
 msgid "incompatible types in binary expression"
@@ -19924,10 +15840,8 @@
 msgstr "несовместимые типы в бинарном выражении"
 
 #: go/gofrontend/expressions.cc:6003
-#, fuzzy
-#| msgid "division by zero"
 msgid "integer division by zero"
-msgstr "деление на ноль"
+msgstr "целое деление на ноль"
 
 #: go/gofrontend/expressions.cc:6011
 msgid "shift of non-integer operand"
@@ -19955,14 +15869,12 @@
 msgstr "некорректное использование %<...%> со встроенной функцией"
 
 #: go/gofrontend/expressions.cc:7276
-#, fuzzy
-#| msgid "invalid use of template-name %qE without an argument list"
 msgid "invalid use of method value as argument of Offsetof"
-msgstr "некорректное использование имени шаблона %qE без списка аргументов"
+msgstr "некорректное использование значения метода как аргумента Offsetof"
 
 #: go/gofrontend/expressions.cc:7290
 msgid "argument of Offsetof implies indirection of an embedded field"
-msgstr ""
+msgstr "аргумент Offsetof влечет косвенность встроенного поля"
 
 #: go/gofrontend/expressions.cc:7315 go/gofrontend/expressions.cc:7352
 #: go/gofrontend/expressions.cc:7494 go/gofrontend/expressions.cc:8598
@@ -19996,7 +15908,7 @@
 
 #: go/gofrontend/expressions.cc:7581
 msgid "len larger than cap"
-msgstr ""
+msgstr "длина больше чем вместимость"
 
 #: go/gofrontend/expressions.cc:7590
 msgid "too many arguments to make"
@@ -20060,10 +15972,8 @@
 msgstr "ожидалась функция"
 
 #: go/gofrontend/expressions.cc:9504
-#, fuzzy
-#| msgid "multiple value function call in single value context"
 msgid "multiple-value argument in single-value context"
-msgstr "вызов функции со множеством значений в контексте одного значения"
+msgstr "multiple-value аргумент в single-value контексте"
 
 #: go/gofrontend/expressions.cc:9713
 msgid "invalid use of %<...%> with non-slice"
@@ -20071,10 +15981,8 @@
 
 #
 #: go/gofrontend/expressions.cc:10092
-#, fuzzy
-#| msgid "Function return value not set"
 msgid "function result count mismatch"
-msgstr "Возвращаемое функцией значение не установлено"
+msgstr "несоответствие счетчика результатов функции"
 
 #: go/gofrontend/expressions.cc:10110
 msgid "incompatible type for receiver"
@@ -20097,14 +16005,12 @@
 msgstr "конец вырезки должен быть целым"
 
 #: go/gofrontend/expressions.cc:10796
-#, fuzzy
-#| msgid "slice end must be integer"
 msgid "slice capacity must be integer"
-msgstr "конец вырезки должен быть целым"
+msgstr "емкость вырезки должна быть целой"
 
 #: go/gofrontend/expressions.cc:10846 go/gofrontend/expressions.cc:11341
 msgid "inverted slice range"
-msgstr ""
+msgstr "инвертированный диапазон вырезки"
 
 #: go/gofrontend/expressions.cc:10889
 msgid "slice of unaddressable value"
@@ -20144,14 +16050,12 @@
 msgstr "некорректный receive или send-only канал"
 
 #: go/gofrontend/parse.cc:3114
-#, fuzzy
-#| msgid "parentheses required around this composite literalto avoid parsing ambiguity"
 msgid "parentheses required around this composite literal to avoid parsing ambiguity"
-msgstr "скобки требуются вокруг этого составного литерала чтобы избежать неоднозначности разбора"
+msgstr "скобки требуются вокруг этого составного литерала, чтобы избежать неоднозначности разбора"
 
 #: go/gofrontend/parse.cc:4672
 msgid "cannot fallthrough final case in switch"
-msgstr ""
+msgstr "невозможно провалиться из последнего case в switch"
 
 #: go/gofrontend/statements.cc:781
 msgid "invalid left hand side of assignment"
@@ -20159,7 +16063,7 @@
 
 #: go/gofrontend/statements.cc:792 go/gofrontend/statements.cc:1113
 msgid "use of untyped nil"
-msgstr ""
+msgstr "использовать бестиповый nil"
 
 #: go/gofrontend/statements.cc:1235
 msgid "expected map index on right hand side"
@@ -20195,11 +16099,11 @@
 
 #: go/gofrontend/statements.cc:5298
 msgid "too many variables for range clause with channel"
-msgstr "слишком много переменных для range клаузулы с каналом"
+msgstr "слишком много переменных для предложения диапазона с каналом"
 
 #: go/gofrontend/statements.cc:5305
 msgid "range clause must have array, slice, string, map, or channel type"
-msgstr "range клаузула должна иметь тип массива, вырезки, строки, отображения или канала"
+msgstr "предложение диапазона должно иметь тип массива, вырезки, строки, отображения или канала"
 
 #: go/gofrontend/types.cc:547
 msgid "invalid comparison of non-ordered type"
@@ -20227,10 +16131,8 @@
 msgstr "некорректное сравнение несравнимого типа"
 
 #: go/gofrontend/types.cc:609
-#, fuzzy
-#| msgid "invalid comparison of non-comparable struct"
 msgid "invalid comparison of generated struct"
-msgstr "некорректное сравнение несравнимой структуры"
+msgstr "некорректное сравнение сгенерированной структуры"
 
 #: go/gofrontend/types.cc:620
 msgid "invalid comparison of non-comparable struct"
@@ -20237,10 +16139,8 @@
 msgstr "некорректное сравнение несравнимой структуры"
 
 #: go/gofrontend/types.cc:630
-#, fuzzy
-#| msgid "invalid comparison of non-comparable array"
 msgid "invalid comparison of generated array"
-msgstr "некорректное сравнение несравнимого массива"
+msgstr "некорректное сравнение сгенерированного массива"
 
 #: go/gofrontend/types.cc:637
 msgid "invalid comparison of non-comparable array"
@@ -20247,10 +16147,8 @@
 msgstr "некорректное сравнение несравнимого массива"
 
 #: go/gofrontend/types.cc:665
-#, fuzzy
-#| msgid "multiple value function call in single value context"
 msgid "multiple-value function call in single-value context"
-msgstr "вызов функции со множеством значений в контексте одного значения"
+msgstr "multiple-value вызов функции в single-value контексте"
 
 #: go/gofrontend/types.cc:748
 msgid "need explicit conversion"
@@ -20262,10 +16160,8 @@
 msgstr "невозможно использовать тип %s как тип %s"
 
 #: go/gofrontend/types.cc:792
-#, fuzzy
-#| msgid "conversion to incomplete type"
 msgid "conversion from normal type to notinheap type"
-msgstr "преобразование к неполному типу"
+msgstr ""
 
 #: go/gofrontend/types.cc:4528
 msgid "different receiver types"
@@ -20327,16 +16223,14 @@
 msgstr "отсутствует метод %s%s%s"
 
 #: go/gofrontend/types.cc:9052
-#, fuzzy, c-format
-#| msgid "method %s%s%s requires a pointer"
+#, c-format
 msgid "method %s%s%s requires a pointer receiver"
-msgstr "метод %s%s%s требует указателя"
+msgstr "метод %s%s%s требует приемника указателя"
 
 #: go/gofrontend/types.cc:9070
-#, fuzzy, c-format
-#| msgid "method %s%s%s requires a pointer"
+#, c-format
 msgid "method %s%s%s is marked go:nointerface"
-msgstr "метод %s%s%s требует указателя"
+msgstr "метод %s%s%s помечен go:nointerface"
 
 #: attribs.c:437
 #, gcc-internal-format
@@ -20344,20 +16238,18 @@
 msgstr ""
 
 #: attribs.c:443
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute conflicts with attribute %s"
+#, gcc-internal-format
 msgid "ignoring attribute %qE because it conflicts with attribute %qs"
-msgstr "атрибут %qE конфликтует с атрибутом %s"
+msgstr ""
 
-#: attribs.c:449 c-family/c-attribs.c:1894 cp/decl.c:13690 cp/friend.c:302
-#: cp/tree.c:4559
-#, fuzzy, gcc-internal-format
-#| msgid "previous declaration %q+#D here"
+#: attribs.c:449 c-family/c-attribs.c:1905 cp/decl.c:13714 cp/friend.c:302
+#: cp/tree.c:4607
+#, gcc-internal-format
 msgid "previous declaration here"
-msgstr "предыдущей декларации %q+#D здесь"
+msgstr "предыдущая декларация здесь"
 
 #. Warn about and ignore all others for now, but store them.
-#: attribs.c:564 c-family/c-attribs.c:2717 objc/objc-act.c:4963
+#: attribs.c:564 c-family/c-attribs.c:2728 objc/objc-act.c:4963
 #: objc/objc-act.c:6932 objc/objc-act.c:8119 objc/objc-act.c:8170
 #, gcc-internal-format
 msgid "%qE attribute directive ignored"
@@ -20364,10 +16256,9 @@
 msgstr "директива описания атрибута %qE проигнорирована"
 
 #: attribs.c:568
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute directive ignored"
+#, gcc-internal-format
 msgid "%<%E::%E%> scoped attribute directive ignored"
-msgstr "директива описания атрибута %qE проигнорирована"
+msgstr "%<%E::%E%> scoped attribute директива проигнорирована"
 
 #: attribs.c:577
 #, gcc-internal-format
@@ -20377,18 +16268,17 @@
 #. This is a c++11 attribute that appertains to a
 #. type-specifier, outside of the definition of, a class
 #. type.  Ignore it.
-#: attribs.c:590 cp/decl.c:10999
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute ignored"
+#: attribs.c:590 cp/decl.c:11023
+#, gcc-internal-format
 msgid "attribute ignored"
-msgstr "атрибут %qE проигнорирован"
+msgstr "атрибут проигнорирован"
 
-#: attribs.c:592 cp/decl.c:11000
+#: attribs.c:592 cp/decl.c:11024
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
-msgstr ""
+msgstr "атрибут, относящийся к спецификатору типа, игнорируется"
 
-#: attribs.c:610 c-family/c-attribs.c:3219
+#: attribs.c:610 c-family/c-attribs.c:3230
 #, gcc-internal-format
 msgid "%qE attribute does not apply to types"
 msgstr "атрибут %qE недопустим в декларациях типов"
@@ -20404,56 +16294,54 @@
 msgstr "атрибуты типов игнорируются, если тип уже определен"
 
 #: attribs.c:691 attribs.c:1622 attribs.c:1632 attribs.c:1642
-#: c-family/c-attribs.c:540 c-family/c-attribs.c:559 c-family/c-attribs.c:577
-#: c-family/c-attribs.c:607 c-family/c-attribs.c:628 c-family/c-attribs.c:649
-#: c-family/c-attribs.c:690 c-family/c-attribs.c:717 c-family/c-attribs.c:733
-#: c-family/c-attribs.c:750 c-family/c-attribs.c:766 c-family/c-attribs.c:792
-#: c-family/c-attribs.c:807 c-family/c-attribs.c:835 c-family/c-attribs.c:852
-#: c-family/c-attribs.c:870 c-family/c-attribs.c:893 c-family/c-attribs.c:931
-#: c-family/c-attribs.c:954 c-family/c-attribs.c:971 c-family/c-attribs.c:1000
-#: c-family/c-attribs.c:1021 c-family/c-attribs.c:1042
-#: c-family/c-attribs.c:1069 c-family/c-attribs.c:1099
-#: c-family/c-attribs.c:1136 c-family/c-attribs.c:1189
-#: c-family/c-attribs.c:1255 c-family/c-attribs.c:1313
-#: c-family/c-attribs.c:1402 c-family/c-attribs.c:1432
-#: c-family/c-attribs.c:1483 c-family/c-attribs.c:1998
-#: c-family/c-attribs.c:2035 c-family/c-attribs.c:2096
-#: c-family/c-attribs.c:2152 c-family/c-attribs.c:2230
-#: c-family/c-attribs.c:2312 c-family/c-attribs.c:2371
-#: c-family/c-attribs.c:2390 c-family/c-attribs.c:2498
-#: c-family/c-attribs.c:2514 c-family/c-attribs.c:2530
-#: c-family/c-attribs.c:2551 c-family/c-attribs.c:2608
-#: c-family/c-attribs.c:2635 c-family/c-attribs.c:2690
-#: c-family/c-attribs.c:2870 c-family/c-attribs.c:2891
-#: c-family/c-attribs.c:3004 c-family/c-attribs.c:3031
-#: c-family/c-attribs.c:3221 c-family/c-attribs.c:3239
-#: c-family/c-attribs.c:3262 c-family/c-attribs.c:3301
-#: c-family/c-attribs.c:3383 c-family/c-attribs.c:3439
-#: c-family/c-attribs.c:3455 c-family/c-attribs.c:3549
-#: c-family/c-common.c:5600 config/darwin.c:2072 config/arm/arm.c:6868
+#: c-family/c-attribs.c:547 c-family/c-attribs.c:566 c-family/c-attribs.c:584
+#: c-family/c-attribs.c:614 c-family/c-attribs.c:635 c-family/c-attribs.c:656
+#: c-family/c-attribs.c:697 c-family/c-attribs.c:728 c-family/c-attribs.c:744
+#: c-family/c-attribs.c:761 c-family/c-attribs.c:777 c-family/c-attribs.c:803
+#: c-family/c-attribs.c:818 c-family/c-attribs.c:846 c-family/c-attribs.c:863
+#: c-family/c-attribs.c:881 c-family/c-attribs.c:904 c-family/c-attribs.c:942
+#: c-family/c-attribs.c:965 c-family/c-attribs.c:982 c-family/c-attribs.c:1011
+#: c-family/c-attribs.c:1032 c-family/c-attribs.c:1053
+#: c-family/c-attribs.c:1080 c-family/c-attribs.c:1110
+#: c-family/c-attribs.c:1147 c-family/c-attribs.c:1200
+#: c-family/c-attribs.c:1266 c-family/c-attribs.c:1324
+#: c-family/c-attribs.c:1413 c-family/c-attribs.c:1443
+#: c-family/c-attribs.c:1494 c-family/c-attribs.c:2009
+#: c-family/c-attribs.c:2046 c-family/c-attribs.c:2107
+#: c-family/c-attribs.c:2163 c-family/c-attribs.c:2241
+#: c-family/c-attribs.c:2323 c-family/c-attribs.c:2382
+#: c-family/c-attribs.c:2401 c-family/c-attribs.c:2509
+#: c-family/c-attribs.c:2525 c-family/c-attribs.c:2541
+#: c-family/c-attribs.c:2562 c-family/c-attribs.c:2619
+#: c-family/c-attribs.c:2646 c-family/c-attribs.c:2701
+#: c-family/c-attribs.c:2881 c-family/c-attribs.c:2902
+#: c-family/c-attribs.c:3015 c-family/c-attribs.c:3042
+#: c-family/c-attribs.c:3232 c-family/c-attribs.c:3250
+#: c-family/c-attribs.c:3273 c-family/c-attribs.c:3312
+#: c-family/c-attribs.c:3394 c-family/c-attribs.c:3450
+#: c-family/c-attribs.c:3466 c-family/c-attribs.c:3560
+#: c-family/c-common.c:5598 config/darwin.c:2072 config/arm/arm.c:6868
 #: config/arm/arm.c:6896 config/arm/arm.c:6913 config/avr/avr.c:9698
-#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6497
-#: config/i386/i386.c:41520 config/ia64/ia64.c:788
-#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33056
-#: config/spu/spu.c:3743 ada/gcc-interface/utils.c:6244
-#: ada/gcc-interface/utils.c:6261 ada/gcc-interface/utils.c:6277
-#: ada/gcc-interface/utils.c:6303 brig/brig-lang.c:476 lto/lto-lang.c:283
+#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6500
+#: config/i386/i386.c:41514 config/ia64/ia64.c:788
+#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33112
+#: config/spu/spu.c:3743 ada/gcc-interface/utils.c:6249
+#: ada/gcc-interface/utils.c:6266 ada/gcc-interface/utils.c:6282
+#: ada/gcc-interface/utils.c:6308 brig/brig-lang.c:476 lto/lto-lang.c:283
 #, gcc-internal-format
 msgid "%qE attribute ignored"
 msgstr "атрибут %qE проигнорирован"
 
 #: attribs.c:989
-#, fuzzy, gcc-internal-format
-#| msgid "missing %<=%> (after %<getter%> attribute) before %qE"
+#, gcc-internal-format
 msgid "missing %<target%> attribute for multi-versioned %qD"
-msgstr "отсутствует %<=%> (после атрибута %<getter%>) перед %qE"
+msgstr ""
 
 #: attribs.c:992 cp/decl.c:1216 cp/decl.c:2010 cp/decl.c:2020 cp/decl.c:2592
 #: cp/decl.c:3012
-#, fuzzy, gcc-internal-format
-#| msgid "previous declaration of %q+D"
+#, gcc-internal-format
 msgid "previous declaration of %qD"
-msgstr "предыдущая декларация %q+D"
+msgstr "предыдущая декларация %qD"
 
 #: attribs.c:1135
 #, gcc-internal-format
@@ -20503,47 +16391,42 @@
 #: auto-profile.c:348
 #, gcc-internal-format
 msgid "offset exceeds 16 bytes"
-msgstr ""
+msgstr "смещение превышает 16 байт"
 
 #: auto-profile.c:855
-#, fuzzy, gcc-internal-format
-#| msgid "expected %<.%>"
+#, gcc-internal-format
 msgid "Not expected TAG."
-msgstr "ожидалась %<.%>"
+msgstr "Не ожидался TAG."
 
 #: auto-profile.c:921
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Cannot open source file %s\n"
+#, gcc-internal-format, gfc-internal-format
 msgid "cannot open profile file %s"
-msgstr "Ошибка открытия исходного файла %s\n"
+msgstr "Ошибка открытия файла профиля %s"
 
 #: auto-profile.c:927
 #, gcc-internal-format
 msgid "AutoFDO profile magic number does not match"
-msgstr ""
+msgstr "AutoFDO магическое число профиля не соответствует"
 
 #: auto-profile.c:935
 #, gcc-internal-format, gfc-internal-format
 msgid "AutoFDO profile version %u does match %u"
-msgstr ""
+msgstr "AutoFDO версия профиля %u не соответствует %u"
 
 #: auto-profile.c:947
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "cannot read LTO decls from %s"
+#, gcc-internal-format, gfc-internal-format
 msgid "cannot read string table from %s"
-msgstr "ошибка чтения LTO деклараций из %s"
+msgstr "ошибка чтения таблицы цепочек из %s"
 
 #: auto-profile.c:955
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "cannot read LTO decls from %s"
+#, gcc-internal-format, gfc-internal-format
 msgid "cannot read function profile from %s"
-msgstr "ошибка чтения LTO деклараций из %s"
+msgstr "ошибка чтения профиля функции из %s"
 
 #: auto-profile.c:965
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "cannot read LTO decls from %s"
+#, gcc-internal-format, gfc-internal-format
 msgid "cannot read working set from %s"
-msgstr "ошибка чтения LTO деклараций из %s"
+msgstr "ошибка чтения рабочего множества из %s"
 
 #: bt-load.c:1562
 #, gcc-internal-format
@@ -20551,10 +16434,9 @@
 msgstr "оптимизация переноса загрузок в регистры в другие блоки не должна выполняться дважды"
 
 #: builtins.c:659
-#, fuzzy, gcc-internal-format
-#| msgid "offset outside bounds of constant string"
+#, gcc-internal-format
 msgid "offset %qwi outside bounds of constant string"
-msgstr "отступ за пределами константной строки"
+msgstr "смещение %qwi вне границ константной строки"
 
 #: builtins.c:1258
 #, gcc-internal-format
@@ -20653,16 +16535,14 @@
 msgstr "слишком мало аргументов в вызове функции %<va_start%>"
 
 #: builtins.c:4981
-#, fuzzy, gcc-internal-format
-#| msgid "invalid use of %qD"
+#, gcc-internal-format
 msgid "invalid argument to %qD"
-msgstr "некорректное использование %qD"
+msgstr "некорректный аргумент для %qD"
 
 #: builtins.c:4994
-#, fuzzy, gcc-internal-format
-#| msgid "unsupported argument type to builtin function"
+#, gcc-internal-format
 msgid "unsupported argument to %qD"
-msgstr "неподдерживаемый тип аргумента для внутренней функции"
+msgstr "неподдерживаемый аргумент для %qD"
 
 #. Warn since no effort is made to ensure that any frame
 #. beyond the current one exists or can be safely reached.
@@ -20669,7 +16549,7 @@
 #: builtins.c:5002
 #, gcc-internal-format
 msgid "calling %qD with a nonzero argument is unsafe"
-msgstr ""
+msgstr "вызов %qD с ненулевым аргументом небезопасен"
 
 #: builtins.c:5302
 #, gcc-internal-format
@@ -20689,7 +16569,7 @@
 #: builtins.c:5864
 #, gcc-internal-format
 msgid "unknown architecture specifier in memory model to builtin"
-msgstr ""
+msgstr "неизвестный спецификатор архитектуры в модели памяти встроенной функции"
 
 #: builtins.c:5872
 #, gcc-internal-format
@@ -20727,16 +16607,14 @@
 msgstr "нецелочисленный аргумент 1 в вызове __atomic_is_lock_free"
 
 #: builtins.c:6578
-#, fuzzy, gcc-internal-format
-#| msgid "__builtin_eh_return not supported on this target"
+#, gcc-internal-format
 msgid "__builtin_thread_pointer is not supported on this target"
-msgstr "__builtin_eh_return не поддерживается для этой платформы"
+msgstr "__builtin_thread_pointer не поддерживается для этой платформы"
 
 #: builtins.c:6598
-#, fuzzy, gcc-internal-format
-#| msgid "__builtin_eh_return not supported on this target"
+#, gcc-internal-format
 msgid "__builtin_set_thread_pointer is not supported on this target"
-msgstr "__builtin_eh_return не поддерживается для этой платформы"
+msgstr "__builtin_set_thread_pointer не поддерживается для этой платформы"
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
@@ -20760,10 +16638,9 @@
 #. Software implementation of Pointer Bounds Checker is NYI.
 #. Target support is required.
 #: builtins.c:7753
-#, fuzzy, gcc-internal-format
-#| msgid "target format does not support infinity"
+#, gcc-internal-format
 msgid "Your target platform does not support -fcheck-pointer-bounds"
-msgstr "целевой формат не поддерживает бесконечные значения"
+msgstr "Ваша целевая платформа не поддерживает -fcheck-pointer-bounds"
 
 #: builtins.c:8089
 #, gcc-internal-format
@@ -20796,22 +16673,19 @@
 msgstr "второй аргумент %<va_start%> не является последним явным аргументом"
 
 #: builtins.c:9785
-#, fuzzy, gcc-internal-format
-#| msgid "undefined behaviour when second parameter of %<va_start%> is declared with %<register%> storage"
+#, gcc-internal-format
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
-msgstr "неопределенное поведение, т.к. второй параметр %<va_start%> продекларирован с классом памяти %<register%>"
+msgstr "неопределенное поведение, если второй параметр %<va_start%> продекларирован с классом памяти %<register%>"
 
 #: builtins.c:9814
-#, fuzzy, gcc-internal-format
-#| msgid "%Kfirst argument of %D must be a pointer, second integer constant"
+#, gcc-internal-format
 msgid "%Kfirst argument of %qD must be a pointer, second integer constant"
-msgstr "%Kпервый аргумент %D должен быть указателем, второй - целой константой"
+msgstr ""
 
 #: builtins.c:9827
-#, fuzzy, gcc-internal-format
-#| msgid "%Klast argument of %D is not integer constant between 0 and 3"
+#, gcc-internal-format
 msgid "%Klast argument of %qD is not integer constant between 0 and 3"
-msgstr "%Kпоследний аргумент %D не является целой константой от 0 до 3"
+msgstr ""
 
 #: builtins.c:10103
 #, gcc-internal-format
@@ -20823,107 +16697,111 @@
 msgid "%Kattempt to free a non-heap object"
 msgstr "%Kпопытка освобождения объекта, не находящегося в динамической памяти"
 
-#: calls.c:1434
-#, fuzzy, gcc-internal-format
-#| msgid "Argument of %s function at %L is negative"
+#: calls.c:1291 file-prefix-map.c:50
+#, gcc-internal-format
+msgid "invalid argument %qs to %qs"
+msgstr ""
+
+#: calls.c:1452
+#, gcc-internal-format
 msgid "%Kargument %i value %qE is negative"
-msgstr "Аргумент %s функции в %L отрицателен"
+msgstr "%Kаргумент %i значение %qE отрицательное"
 
-#: calls.c:1452
-#, fuzzy, gcc-internal-format
-#| msgid "Second argument MOD at %L is zero"
+#: calls.c:1470
+#, gcc-internal-format
 msgid "%Kargument %i value is zero"
-msgstr "Второй аргумент MOD в %L нулевой"
+msgstr "%Kаргумент %i значение нулевое"
 
-#: calls.c:1469
+#: calls.c:1487
 #, gcc-internal-format
 msgid "%Kargument %i value %qE exceeds maximum object size %E"
-msgstr ""
+msgstr "%Kаргумент %i значение %qE превышает максимальный размер объекта %E"
 
-#: calls.c:1483
-#, fuzzy, gcc-internal-format
-#| msgid "Argument of %s function at %L is negative"
+#: calls.c:1501
+#, gcc-internal-format
 msgid "%Kargument %i range [%E, %E] is negative"
-msgstr "Аргумент %s функции в %L отрицателен"
+msgstr "%Kаргумент %i диапазон [%E, %E] отрицательный"
 
-#: calls.c:1490
+#: calls.c:1508
 #, gcc-internal-format
 msgid "%Kargument %i range [%E, %E] exceeds maximum object size %E"
-msgstr ""
+msgstr "%Kаргумент %i диапазон [%E, %E] превышает максимальный размер объекта %E"
 
-#: calls.c:1520
+#: calls.c:1538
 #, gcc-internal-format
 msgid "%Kproduct %<%E * %E%> of arguments %i and %i exceeds %<SIZE_MAX%>"
-msgstr ""
+msgstr "%Kпроизведение %<%E * %E%> аргументов %i и %i превышает %<SIZE_MAX%>"
 
-#: calls.c:1526
+#: calls.c:1544
 #, gcc-internal-format
 msgid "%Kproduct %<%E * %E%> of arguments %i and %i exceeds maximum object size %E"
-msgstr ""
+msgstr "%Kпроизведение %<%E * %E%> аргументов %i и %i превышает максимальный размер объекта %E"
 
-#: calls.c:1537 calls.c:1540
-#, fuzzy, gcc-internal-format
-#| msgid "argument %d of %qE must be in the range %d...%d"
+#: calls.c:1555 calls.c:1558
+#, gcc-internal-format
 msgid "argument %i in the range [%E, %E]"
-msgstr "аргумент %d от %qE должен быть в диапазоне %d...%d"
+msgstr "аргумент %i в диапазоне [%E, %E]"
 
-#: calls.c:1551
-#, fuzzy, gcc-internal-format
-#| msgid "call to non-function %qD"
+#: calls.c:1569
+#, gcc-internal-format
 msgid "in a call to built-in allocation function %qD"
-msgstr "вызов не функции %qD"
+msgstr "в вызове встроенной функции размещения %qD"
 
-#: calls.c:1554
-#, fuzzy, gcc-internal-format
-#| msgid "inline function %q+D declared weak"
+#: calls.c:1572
+#, gcc-internal-format
 msgid "in a call to allocation function %qD declared here"
-msgstr "inline функция %q+D объявлена weak"
+msgstr "в вызове встроенной функции размещения %qD декларированной здесь"
 
-#: calls.c:1711
+#: calls.c:1835
 #, gcc-internal-format
-msgid "%qD argument %i declared attribute %<nonstring%> is smaller than the specified bound %E"
+msgid "%qD argument %i declared attribute %<nonstring%> is smaller than the specified bound %wu"
 msgstr ""
 
-#: calls.c:1716
-#, fuzzy, gcc-internal-format
-#| msgid "%qD was not declared %<constexpr%>"
+#: calls.c:1841
+#, gcc-internal-format
+msgid "%qD argument %i declared attribute %<nonstring%> is smaller than the specified bound [%E, %E]"
+msgstr ""
+
+#: calls.c:1847
+#, gcc-internal-format
+msgid "%qD argument %i declared attribute %<nonstring%> may be smaller than the specified bound [%E, %E]"
+msgstr ""
+
+#: calls.c:1857
+#, gcc-internal-format
 msgid "%qD argument %i declared attribute %<nonstring%>"
-msgstr "%qD не была декларирована %<constexpr%>"
+msgstr ""
 
-#: calls.c:1721
-#, fuzzy, gcc-internal-format
-#| msgid "%qD declared here"
+#: calls.c:1862
+#, gcc-internal-format
 msgid "argument %qD declared here"
-msgstr "%qD объявлено здесь"
+msgstr ""
 
-#: calls.c:1735
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "[cannot find %s]"
+#: calls.c:1876
+#, gcc-internal-format, gfc-internal-format
 msgid "cannot tail-call: %s"
-msgstr "[не найдена программа %s]"
+msgstr "ошибка хвостового вызова: %s"
 
-#: calls.c:3365
+#: calls.c:3506
 #, gcc-internal-format
 msgid "function call has aggregate value"
 msgstr "функция возвращает агрегатное значение"
 
 #
-#: calls.c:4059
-#, fuzzy, gcc-internal-format
-#| msgid "passing %qT for argument %P to %qD"
+#: calls.c:4200
+#, gcc-internal-format
 msgid "passing too large argument on stack"
-msgstr "передача %qT для аргумента %P в %qD"
+msgstr "передача слишком большого аргумента на стек"
 
-#: cfgexpand.c:1665 function.c:1002 varasm.c:2231
+#: cfgexpand.c:1665 function.c:1002 varasm.c:2242
 #, gcc-internal-format
 msgid "size of variable %q+D is too large"
 msgstr "размер переменной %q+D слишком велик"
 
 #: cfgexpand.c:1677
-#, fuzzy, gcc-internal-format
-#| msgid "Global register variable %qD used in nested function."
+#, gcc-internal-format
 msgid "cannot allocate stack for variable %q+D, naked function."
-msgstr "Глобальная регистровая переменная %qD использована во вложенной функции."
+msgstr "Невозможно выделить стек для переменной %q+D, naked функция."
 
 #: cfgexpand.c:2781
 #, gcc-internal-format
@@ -21008,16 +16886,14 @@
 msgstr "verify_flow_info: У блока %i отсутствует loop_father"
 
 #: cfghooks.c:146
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "verify_flow_info: Wrong count of block %i %i"
+#, gcc-internal-format, gfc-internal-format
 msgid "verify_flow_info: Wrong count of block %i"
-msgstr "verify_flow_info: Неверный счётчик блоков %i %i"
+msgstr ""
 
 #: cfghooks.c:154
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "verify_flow_info: Wrong count of block %i %i"
+#, gcc-internal-format, gfc-internal-format
 msgid "verify_flow_info: Missing count of block %i"
-msgstr "verify_flow_info: Неверный счётчик блоков %i %i"
+msgstr ""
 
 #: cfghooks.c:162
 #, gcc-internal-format, gfc-internal-format
@@ -21025,16 +16901,14 @@
 msgstr "verify_flow_info: Повторное вхождение дуги %i->%i"
 
 #: cfghooks.c:171
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "verify_flow_info: Wrong probability of edge %i->%i %i"
+#, gcc-internal-format, gfc-internal-format
 msgid "Uninitialized probability of edge %i->%i"
-msgstr "verify_flow_info: Некорректная вероятность дуги %i->%i %i"
+msgstr ""
 
 #: cfghooks.c:177
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "verify_flow_info: Wrong probability of edge %i->%i %i"
+#, gcc-internal-format, gfc-internal-format
 msgid "verify_flow_info: Wrong probability of edge %i->%i"
-msgstr "verify_flow_info: Некорректная вероятность дуги %i->%i %i"
+msgstr ""
 
 #: cfghooks.c:189
 #, gcc-internal-format, gfc-internal-format
@@ -21067,10 +16941,9 @@
 msgstr "процедура verify_flow_info выявила ошибки"
 
 #: cfghooks.c:323
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "%s does not support duplicate_block"
+#, gcc-internal-format, gfc-internal-format
 msgid "%s does not support dump_bb_for_graph"
-msgstr "%s не поддерживает duplicate_block"
+msgstr "%s не поддерживает dump_bb_for_graph"
 
 #: cfghooks.c:366
 #, gcc-internal-format, gfc-internal-format
@@ -21170,33 +17043,32 @@
 #: cfgloop.c:1388
 #, gcc-internal-format
 msgid "loop verification on loop tree that needs fixup"
-msgstr ""
+msgstr "верификация цикла на древовидном представлении, нуждающаяся в исправлении"
 
 #: cfgloop.c:1404
 #, gcc-internal-format
 msgid "corrupt loop tree root"
-msgstr ""
+msgstr "испорчен корень древовидного представления цикла"
 
 #: cfgloop.c:1414
 #, gcc-internal-format, gfc-internal-format
 msgid "loop with header %d marked for removal"
-msgstr ""
+msgstr "цикл с заголовком %d помечен для удаления"
 
 #: cfgloop.c:1419
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Enable loop header copying on trees"
+#, gcc-internal-format, gfc-internal-format
 msgid "loop with header %d not in loop tree"
-msgstr "Включить копирование заголовков циклов в древовидном представлении"
+msgstr "цикл с заголовком %d не в дереве циклов"
 
 #: cfgloop.c:1425
 #, gcc-internal-format, gfc-internal-format
 msgid "non-loop with header %d not marked for removal"
-msgstr ""
+msgstr "не-цикл с заголовком %d не помечен для удаления"
 
 #: cfgloop.c:1439
 #, gcc-internal-format, gfc-internal-format
 msgid "removed loop %d in loop tree"
-msgstr ""
+msgstr "удаленный цикл %d в древовидном представлении цикла"
 
 #: cfgloop.c:1447
 #, gcc-internal-format, gfc-internal-format
@@ -21204,22 +17076,19 @@
 msgstr "размер цикла %d должен быть %d, а не %d"
 
 #: cfgloop.c:1458
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "bb %d do not belong to loop %d"
+#, gcc-internal-format, gfc-internal-format
 msgid "bb %d does not belong to loop %d"
-msgstr "блок %d не принадлежит циклу %d"
+msgstr "базовый блок %d не принадлежит циклу %d"
 
 #: cfgloop.c:1470
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "size of loop %d should be %d, not %d"
+#, gcc-internal-format, gfc-internal-format
 msgid "bb %d has father loop %d, should be loop %d"
-msgstr "размер цикла %d должен быть %d, а не %d"
+msgstr "базовый блок %d имеет родительский цикл %d, должен быть цикл %d"
 
 #: cfgloop.c:1486
-#, fuzzy, gcc-internal-format
-#| msgid "loop %d%'s header does not have exactly 2 entries"
+#, gcc-internal-format
 msgid "loop %d%'s header is not a loop header"
-msgstr "заголовок цикла %d не имеет в точности 2 входа"
+msgstr "заголовок цикла %d не является заголовком цикла"
 
 #: cfgloop.c:1492
 #, gcc-internal-format
@@ -21227,16 +17096,14 @@
 msgstr "заголовок цикла %d не имеет в точности 2 входа"
 
 #: cfgloop.c:1499
-#, fuzzy, gcc-internal-format
-#| msgid "loop %d%'s latch does not have header as successor"
+#, gcc-internal-format
 msgid "loop %d%'s latch does not have an edge to its header"
-msgstr "затвор (latch) цикла %d не содержит заголовок цикла среди преемников"
+msgstr "затвор цикла %d не имеет ребра к своему заголовку"
 
 #: cfgloop.c:1504
-#, fuzzy, gcc-internal-format
-#| msgid "loop %d%'s latch does not have header as successor"
+#, gcc-internal-format
 msgid "loop %d%'s latch is not dominated by its header"
-msgstr "затвор (latch) цикла %d не содержит заголовок цикла среди преемников"
+msgstr "затвор цикла %d не доминируется своим заголовком"
 
 #: cfgloop.c:1512
 #, gcc-internal-format
@@ -21296,7 +17163,7 @@
 #: cfgloop.c:1629
 #, gcc-internal-format, gfc-internal-format
 msgid "nonempty exits list of loop %d, but exits are not recorded"
-msgstr "список выходов цикла %d непуст, но выходы не записаны"
+msgstr "список выходов цикла %d не пуст, но выходы не записаны"
 
 #: cfgloop.c:1656
 #, gcc-internal-format, gfc-internal-format
@@ -21331,19 +17198,17 @@
 #: cfgrtl.c:2424
 #, gcc-internal-format
 msgid "partition found but function partition flag not set"
-msgstr ""
+msgstr "раздел найден, но флаг раздела функции не установлен"
 
 #: cfgrtl.c:2463
-#, fuzzy, gcc-internal-format
-#| msgid "verify_flow_info: REG_BR_PROB does not match cfg %wi %i"
+#, gcc-internal-format
 msgid "verify_flow_info: REG_BR_PROB is set but cfg probability is not"
-msgstr "verify_flow_info: REG_BR_PROB не соответствует CFG %wi %i"
+msgstr ""
 
 #: cfgrtl.c:2472
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "verify_flow_info: REG_BR_PROB does not match cfg %wi %i"
+#, gcc-internal-format, gfc-internal-format
 msgid "verify_flow_info: REG_BR_PROB does not match cfg %i %i"
-msgstr "verify_flow_info: REG_BR_PROB не соответствует CFG %wi %i"
+msgstr "verify_flow_info: REG_BR_PROB не соответствует cfg %i %i"
 
 #: cfgrtl.c:2494
 #, gcc-internal-format
@@ -21351,22 +17216,19 @@
 msgstr "EDGE_CROSSING некорректно установлена через одну и ту же секцию"
 
 #: cfgrtl.c:2499
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "fallthru edge crosses section boundary (bb %i)"
+#, gcc-internal-format, gfc-internal-format
 msgid "fallthru edge crosses section boundary in bb %i"
-msgstr "сквозная дуга пересекает границу секции (блок %i)"
+msgstr "сквозная дуга пересекает границу секции в базовом блоке %i"
 
 #: cfgrtl.c:2505
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "EH edge crosses section boundary (bb %i)"
+#, gcc-internal-format, gfc-internal-format
 msgid "EH edge crosses section boundary in bb %i"
-msgstr "EH дуга пересекает границу секции (блок %i)"
+msgstr "EH дуга пересекает границу секции в базовом блоке %i"
 
 #: cfgrtl.c:2511
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "EH edge crosses section boundary (bb %i)"
+#, gcc-internal-format, gfc-internal-format
 msgid "No region crossing jump at section boundary in bb %i"
-msgstr "EH дуга пересекает границу секции (блок %i)"
+msgstr "Отсутствует пересекающий область переход на границе секции в базовом блоке %i"
 
 #: cfgrtl.c:2518
 #, gcc-internal-format
@@ -21376,19 +17238,17 @@
 #: cfgrtl.c:2548
 #, gcc-internal-format, gfc-internal-format
 msgid "Region crossing jump across same section in bb %i"
-msgstr ""
+msgstr "Область, пересекающая jump, в той же секции в bb %i"
 
 #: cfgrtl.c:2555
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "missing REG_EH_REGION note in the end of bb %i"
+#, gcc-internal-format, gfc-internal-format
 msgid "missing REG_EH_REGION note at the end of bb %i"
-msgstr "отсутствует пометка REG_EH_REGION в конце блока %i"
+msgstr "отсутствует пометка REG_EH_REGION в конце базового блока %i"
 
 #: cfgrtl.c:2560
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "too many outgoing branch edges from bb %i"
+#, gcc-internal-format, gfc-internal-format
 msgid "too many exception handling edges in bb %i"
-msgstr "слишком много переходов, исходящих из блока %i"
+msgstr "слишком много ребер обработки исключительных ситуаций в базовом блоке %i"
 
 #: cfgrtl.c:2568
 #, gcc-internal-format, gfc-internal-format
@@ -21396,34 +17256,29 @@
 msgstr "слишком много переходов, исходящих из блока %i"
 
 #: cfgrtl.c:2573
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "fallthru edge after unconditional jump %i"
+#, gcc-internal-format, gfc-internal-format
 msgid "fallthru edge after unconditional jump in bb %i"
-msgstr "сквозная дуга после безусловного перехода %i"
+msgstr "сквозная дуга после безусловного перехода в базовом блоке %i"
 
 #: cfgrtl.c:2578
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "wrong number of branch edges after unconditional jump %i"
+#, gcc-internal-format, gfc-internal-format
 msgid "wrong number of branch edges after unconditional jump in bb %i"
-msgstr "некорректное число ветвлений после безусловного перехода %i"
+msgstr "некорректное число ветвлений после безусловного перехода в базовом блоке %i"
 
 #: cfgrtl.c:2585
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "wrong amount of branch edges after conditional jump %i"
+#, gcc-internal-format, gfc-internal-format
 msgid "wrong amount of branch edges after conditional jump in bb %i"
-msgstr "некорректное число ветвлений после условного перехода %i"
+msgstr "некорректное число ветвлений после условного перехода в базовом блоке %i"
 
 #: cfgrtl.c:2591
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "call edges for non-call insn in bb %i"
+#, gcc-internal-format, gfc-internal-format
 msgid "abnormal call edges for non-call insn in bb %i"
-msgstr "дуги вызова для не-call инструкции в блоке %i"
+msgstr "ненормальные дуги вызова для не-call инструкции в базовом блоке %i"
 
 #: cfgrtl.c:2596
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "call edges for non-call insn in bb %i"
+#, gcc-internal-format, gfc-internal-format
 msgid "sibcall edges for non-call insn in bb %i"
-msgstr "дуги вызова для не-call инструкции в блоке %i"
+msgstr "sibcall дуги для не-call инструкции в базовом блоке %i"
 
 #: cfgrtl.c:2606
 #, gcc-internal-format, gfc-internal-format
@@ -21510,253 +17365,237 @@
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr "число меток блоков в списке RTL-инструкций (%d) != n_basic_blocks (%d)"
 
-#: cgraph.c:3051
-#, fuzzy, gcc-internal-format
-#| msgid "caller edge count is negative"
+#: cgraph.c:3056
+#, gcc-internal-format
 msgid "caller edge count invalid"
-msgstr "отрицательный счётчик дуг, соответствующих вызовам"
+msgstr ""
 
-#: cgraph.c:3135
+#: cgraph.c:3140
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr "для дуги %s->%s установлено вспомогательное поле"
 
-#: cgraph.c:3142
+#: cgraph.c:3147
 #, gcc-internal-format
 msgid "cgraph count invalid"
 msgstr ""
 
-#: cgraph.c:3147
-#, fuzzy, gcc-internal-format
-#| msgid "node is alone in a comdat group"
+#: cgraph.c:3152
+#, gcc-internal-format
 msgid "inline clone in same comdat group list"
-msgstr "только один узел в comdat группе"
+msgstr "подставляемый клон в том же списке comdat группы"
 
-#: cgraph.c:3152
-#, fuzzy, gcc-internal-format
-#| msgid "Assume symbols might be invalid"
+#: cgraph.c:3157
+#, gcc-internal-format
 msgid "local symbols must be defined"
-msgstr "Предполагать, что символы могут быть неправильными"
+msgstr "локальные символы должны быть определены"
 
-#: cgraph.c:3157
+#: cgraph.c:3162
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr "видимый извне inline клон"
 
-#: cgraph.c:3162
+#: cgraph.c:3167
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr "взятие inline клона с адресом"
 
-#: cgraph.c:3167
-#, fuzzy, gcc-internal-format
-#| msgid "inline clone is needed"
+#: cgraph.c:3172
+#, gcc-internal-format
 msgid "inline clone is forced to output"
-msgstr "требуется inline клон"
+msgstr "inline клон принудительно выводится"
 
-#: cgraph.c:3174
+#: cgraph.c:3179
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for indirect edge from %s"
 msgstr "aux поле установлено для косвенной дуги из %s"
 
-#: cgraph.c:3181
+#: cgraph.c:3186
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr "Косвенная дуга из %s не помечена как косвенная или имеет ассоциированную indirect_info, соответствующий оператор есть: "
 
-#: cgraph.c:3196
+#: cgraph.c:3201
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
-msgstr ""
+msgstr "comdat-local функция вызвана из %s вне ее comdat"
 
-#: cgraph.c:3206
+#: cgraph.c:3211
 #, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr "некорректный указатель inlined_to"
 
-#: cgraph.c:3211
+#: cgraph.c:3216
 #, gcc-internal-format
 msgid "multiple inline callers"
 msgstr "множественные inline-вызовы"
 
-#: cgraph.c:3218
+#: cgraph.c:3223
 #, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr "указатель inlined_to установлен для не inline вызова"
 
-#: cgraph.c:3239
-#, fuzzy, gcc-internal-format
-#| msgid "caller edge frequency %i does not match BB frequency %i"
+#: cgraph.c:3244
+#, gcc-internal-format
 msgid "caller edge count does not match BB count"
-msgstr "счётчик дуг вызова %i не соответствует частоте базового блока %i"
+msgstr ""
 
-#: cgraph.c:3261
-#, fuzzy, gcc-internal-format
-#| msgid "caller edge frequency %i does not match BB frequency %i"
+#: cgraph.c:3266
+#, gcc-internal-format
 msgid "indirect call count does not match BB count"
-msgstr "счётчик дуг вызова %i не соответствует частоте базового блока %i"
+msgstr ""
 
-#: cgraph.c:3272
+#: cgraph.c:3277
 #, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr "указатель inlined_to установлен, но не найдено ни одного предшественника"
 
-#: cgraph.c:3277
+#: cgraph.c:3282
 #, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr "указатель inlined_to ссылается на себя"
 
-#: cgraph.c:3289
-#, fuzzy, gcc-internal-format
-#| msgid "node has wrong clone_of"
+#: cgraph.c:3294
+#, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
-msgstr "узел имеет некорректное значение clone_of"
+msgstr "cgraph_node имеет некорректный clone_of"
 
-#: cgraph.c:3301
-#, fuzzy, gcc-internal-format
-#| msgid "node has wrong clone list"
+#: cgraph.c:3306
+#, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
-msgstr "узел имеет некорректный список клонов"
+msgstr "cgraph_node имеет некорректный список клонов"
 
-#: cgraph.c:3307
-#, fuzzy, gcc-internal-format
-#| msgid "node is in clone list but it is not clone"
+#: cgraph.c:3312
+#, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
-msgstr "узел в списке клонов, но не является клоном"
+msgstr "cgraph_node в списке клонов, но он не клон"
 
-#: cgraph.c:3312
-#, fuzzy, gcc-internal-format
-#| msgid "node has wrong prev_clone pointer"
+#: cgraph.c:3317
+#, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
-msgstr "узел имеет некорректное значение prev_clone pointer"
+msgstr "cgraph_node имеет некорректный prev_clone указатель"
 
-#: cgraph.c:3317
+#: cgraph.c:3322
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr "испорчен двусвязный список клонов"
 
-#: cgraph.c:3329
+#: cgraph.c:3334
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr "Alias имеет дуги вызовов"
 
-#: cgraph.c:3337
+#: cgraph.c:3342
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr "Alias имеет не-alias ссылку"
 
-#: cgraph.c:3342
+#: cgraph.c:3347
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr "Alias имеет более одной alias ссылки"
 
-#: cgraph.c:3349
+#: cgraph.c:3354
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr "Проанализированный alias не имеет ссылки"
 
-#: cgraph.c:3358
+#: cgraph.c:3363
 #, gcc-internal-format
 msgid "Instrumentation clone does not reference original node"
-msgstr ""
+msgstr "Инструментальный клон не ссылается на исходный клон"
 
-#: cgraph.c:3365
-#, fuzzy, gcc-internal-format
-#| msgid "alignment of %qD is bigger than original declaration"
+#: cgraph.c:3370
+#, gcc-internal-format
 msgid "Not instrumented node has non-NULL original declaration"
-msgstr "выравнивание %qD больше чем в исходной декларации"
+msgstr "Неинструментированный узел имеет non-NULL исходную декларацию"
 
-#: cgraph.c:3375
-#, fuzzy, gcc-internal-format
-#| msgid "alignment of %qD is bigger than original declaration"
+#: cgraph.c:3380
+#, gcc-internal-format
 msgid "Instrumented node has wrong original declaration"
-msgstr "выравнивание %qD больше чем в исходной декларации"
+msgstr "Инструментированный узел имеет некорректную исходную декларацию"
 
-#: cgraph.c:3393
-#, fuzzy, gcc-internal-format
-#| msgid "Alias has more than one alias reference"
+#: cgraph.c:3398
+#, gcc-internal-format
 msgid "Node has more than one chkp reference"
-msgstr "Alias имеет более одной alias ссылки"
+msgstr "Узел имеет более одной chkp ссылки"
 
-#: cgraph.c:3398
-#, fuzzy, gcc-internal-format
-#| msgid "forming reference to reference type %qT"
+#: cgraph.c:3403
+#, gcc-internal-format
 msgid "Wrong node is referenced with chkp reference"
-msgstr "формирование ссылки на ссылочный тип %qT"
+msgstr "На некорректный узел ссылается chkp ссылка"
 
-#: cgraph.c:3406
-#, fuzzy, gcc-internal-format
-#| msgid "Analyzed alias has no reference"
+#: cgraph.c:3411
+#, gcc-internal-format
 msgid "Analyzed node has no reference to instrumented version"
-msgstr "Проанализированный alias не имеет ссылки"
+msgstr "Проанализированный узел не имеет ссылки на инструментированную версию"
 
-#: cgraph.c:3420
+#: cgraph.c:3425
 #, gcc-internal-format
 msgid "Alias chain for instrumented node is broken"
-msgstr ""
+msgstr "Цепочка синонимов для инструментированного узла разорвана"
 
-#: cgraph.c:3429
+#: cgraph.c:3434
 #, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr "Нет дуги из thunk-узла"
 
-#: cgraph.c:3434
+#: cgraph.c:3439
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr "Более одной дуги исходит из thunk-узла"
 
-#: cgraph.c:3439
+#: cgraph.c:3444
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr "Thunk не должен иметь тела"
 
-#: cgraph.c:3445
+#: cgraph.c:3450
 #, gcc-internal-format
 msgid "Instrumentation thunk has wrong edge callee"
-msgstr ""
+msgstr "Инструментальный шлюз содержит неверную дугу вызова"
 
-#: cgraph.c:3481
+#: cgraph.c:3486
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr "разделяемый call_stmt:"
 
-#: cgraph.c:3489
+#: cgraph.c:3494
 #, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr "дуга указывает на неверную декларацию:"
 
-#: cgraph.c:3498
+#: cgraph.c:3503
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
-msgstr "косвенная дуга с неизвестной вызываемой функцией, соответствующая call_stmt в известной декларации"
+msgstr "косвенная дуга с неизвестной вызываемой функцией, соответствующая call_stmt, в известной декларации"
 
-#: cgraph.c:3508
+#: cgraph.c:3513
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr "отсутствует дуга callgraph для инструкции вызова:"
 
-#: cgraph.c:3518
-#, fuzzy, gcc-internal-format
-#| msgid "expected statement"
+#: cgraph.c:3523
+#, gcc-internal-format
 msgid "reference to dead statement"
-msgstr "ожидался оператор"
+msgstr "ссылка на мертвый оператор"
 
-#: cgraph.c:3531
+#: cgraph.c:3536
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr "отсутствует call_stmt, соответствующий дуге %s->%s"
 
-#: cgraph.c:3543
+#: cgraph.c:3548
 #, gcc-internal-format, gfc-internal-format
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr "косвенная дуга из %s не имеет соответствующего call_stmt"
 
-#: cgraph.c:3554
+#: cgraph.c:3559
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr "процедура verify_cgraph_node выявила ошибки"
 
-#: cgraph.c:3661 varpool.c:306
+#: cgraph.c:3666 varpool.c:306
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: section %s is missing"
 msgstr "%s: секция %s отсутствует"
@@ -21787,51 +17626,45 @@
 msgstr "атрибут %<weakref%> игнорируется, поскольку переменная инициализирована"
 
 #. include_self=
-#: cgraphunit.c:981 c/c-decl.c:11282
+#: cgraphunit.c:981 c/c-decl.c:11302
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F используется, но нигде не определена"
 
-#: cgraphunit.c:983 c/c-decl.c:11291
+#: cgraphunit.c:983 c/c-decl.c:11311
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "%q+F объявлена %<static%>, но нигде не определена"
 
 #: cgraphunit.c:1027
-#, fuzzy, gcc-internal-format
-#| msgid "%q+D defined but not used"
+#, gcc-internal-format
 msgid "%qD defined but not used"
-msgstr "%q+D определена, но нигде не используется"
+msgstr "%qD определена, но не используется"
 
 #: cgraphunit.c:1350
-#, fuzzy, gcc-internal-format
-#| msgid "%<operator new%> must return type %qT"
+#, gcc-internal-format
 msgid "%<ifunc%> resolver for %qD must return %qT"
-msgstr "%<operator new%> должен возвращать тип %qT"
+msgstr ""
 
 #: cgraphunit.c:1353 cgraphunit.c:1375
-#, fuzzy, gcc-internal-format
-#| msgid "indirect function %q+D cannot be declared weakref"
+#, gcc-internal-format
 msgid "resolver indirect function declared here"
-msgstr "косвенная функции %q+D не может быть объявлена как weakref"
+msgstr ""
 
 #: cgraphunit.c:1372
-#, fuzzy, gcc-internal-format
-#| msgid "prefix %qD should return %qT"
+#, gcc-internal-format
 msgid "%<ifunc%> resolver for %qD should return %qT"
-msgstr "префиксный %qD должен возвращать %qT"
+msgstr ""
 
 #: cgraphunit.c:1379
-#, fuzzy, gcc-internal-format
-#| msgid "Warn about casting functions to incompatible types"
+#, gcc-internal-format
 msgid "%qD alias between functions of incompatible types %qT and %qT"
-msgstr "Предупреждать о приведений функций к несовместимым типам"
+msgstr ""
 
 #: cgraphunit.c:1382 cgraphunit.c:1461
-#, fuzzy, gcc-internal-format
-#| msgid "%q+D used prior to declaration"
+#, gcc-internal-format
 msgid "aliased declaration here"
-msgstr "%q+D использовано до декларации"
+msgstr ""
 
 #: cgraphunit.c:1419 c-family/c-pragma.c:337
 #, gcc-internal-format
@@ -21859,10 +17692,9 @@
 msgstr "не удалось запросить повторно ненужную функцию в той же comdat группе"
 
 #: cgraphunit.c:1799
-#, fuzzy, gcc-internal-format
-#| msgid "generic thunk code fails for method %q#D which uses %<...%>"
+#, gcc-internal-format
 msgid "generic thunk code fails for method %qD which uses %<...%>"
-msgstr "ошибка в обобщенном thunk-коде для метода %q#D, который использует %<...%>"
+msgstr "ошибка в обобщенном thunk-коде для метода %qD, который использует %<...%>"
 
 #: cgraphunit.c:2165
 #, gcc-internal-format
@@ -21914,12 +17746,12 @@
 msgid "cannot find '%s'"
 msgstr "не удалось найти '%s'"
 
-#: collect-utils.c:183 collect2.c:2361 collect2.c:2560 gcc.c:3080 gcc.c:6856
+#: collect-utils.c:183 collect2.c:2387 collect2.c:2586 gcc.c:3080 gcc.c:6856
 #, gcc-internal-format
 msgid "pex_init failed: %m"
 msgstr "ошибка в pex_init: %m"
 
-#: collect-utils.c:192 collect2.c:2370 collect2.c:2568 gcc.c:8498
+#: collect-utils.c:192 collect2.c:2396 collect2.c:2594 gcc.c:8498
 #, gcc-internal-format
 msgid "%s: %m"
 msgstr "%s: %m"
@@ -21929,93 +17761,93 @@
 msgid "COLLECT_LTO_WRAPPER must be set"
 msgstr "должна быть установлена COLLECT_LTO_WRAPPER"
 
-#: collect2.c:966 gcc.c:7382 lto-wrapper.c:1666
+#: collect2.c:969 gcc.c:7382 lto-wrapper.c:1692
 #: config/i386/intelmic-mkoffload.c:556 config/nvptx/mkoffload.c:405
 #, gcc-internal-format
 msgid "atexit failed"
 msgstr "ошибка в atexit"
 
-#: collect2.c:1064
+#: collect2.c:1067
 #, gcc-internal-format
 msgid "no arguments"
 msgstr "отсутствуют аргументы"
 
-#: collect2.c:1303 opts.c:904
+#: collect2.c:1311 opts.c:904
 #, gcc-internal-format
 msgid "LTO support has not been enabled in this configuration"
 msgstr "Поддержка LTO в данной конфигурации отсутствует"
 
-#: collect2.c:1344
+#: collect2.c:1352
 #, gcc-internal-format
 msgid "can't open %s: %m"
 msgstr "ошибка открытия %s: %m"
 
-#: collect2.c:1450
+#: collect2.c:1472
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown demangling style '%s'"
 msgstr "неизвестный стиль декодирования имён '%s'"
 
-#: collect2.c:1546 collect2.c:1729 collect2.c:1769
+#: collect2.c:1574 collect2.c:1757 collect2.c:1797
 #, gcc-internal-format
 msgid "fopen %s: %m"
 msgstr "fopen %s: %m"
 
-#: collect2.c:1549 collect2.c:1734 collect2.c:1772
+#: collect2.c:1577 collect2.c:1762 collect2.c:1800
 #, gcc-internal-format
 msgid "fclose %s: %m"
 msgstr "fclose %s: %m"
 
-#: collect2.c:2335
+#: collect2.c:2361
 #, gcc-internal-format
 msgid "cannot find 'nm'"
 msgstr "не удалось найти 'nm'"
 
-#: collect2.c:2383
+#: collect2.c:2409
 #, gcc-internal-format
 msgid "can't open nm output: %m"
 msgstr "не удалось открыть выходной файл nm: %m"
 
-#: collect2.c:2467
+#: collect2.c:2493
 #, gcc-internal-format, gfc-internal-format
 msgid "init function found in object %s"
 msgstr "в объекте %s найдена функция init"
 
-#: collect2.c:2478
+#: collect2.c:2504
 #, gcc-internal-format, gfc-internal-format
 msgid "fini function found in object %s"
 msgstr "в объекте %s найдена функция fini"
 
-#: collect2.c:2535
+#: collect2.c:2561
 #, gcc-internal-format
 msgid "cannot find 'ldd'"
 msgstr "не найдена программа `ldd'"
 
-#: collect2.c:2581
+#: collect2.c:2607
 #, gcc-internal-format
 msgid "can't open ldd output: %m"
 msgstr "не удалось открыть выходной файл ldd: %m"
 
-#: collect2.c:2599
+#: collect2.c:2625
 #, gcc-internal-format, gfc-internal-format
 msgid "dynamic dependency %s not found"
 msgstr "динамическая зависимость %s не найдена"
 
-#: collect2.c:2611
+#: collect2.c:2637
 #, gcc-internal-format, gfc-internal-format
 msgid "unable to open dynamic dependency '%s'"
 msgstr "не удалось открыть динамическую зависимость '%s'"
 
-#: collect2.c:2765
+#: collect2.c:2791
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: not a COFF file"
 msgstr "%s: не COFF-файл"
 
-#: collect2.c:2930
+#: collect2.c:2961
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: cannot open as COFF file"
 msgstr "%s: ошибка открытия COFF-файла"
 
-#: collect2.c:2989
+#: collect2.c:3020
 #, gcc-internal-format, gfc-internal-format
 msgid "library lib%s not found"
 msgstr "не найдена библиотека lib%s"
@@ -22041,10 +17873,9 @@
 msgstr "преобразование к неполному типу"
 
 #: convert.c:992
-#, fuzzy, gcc-internal-format
-#| msgid "can%'t convert between vector values of different size"
+#, gcc-internal-format
 msgid "can%'t convert a vector of type %qT to type %qT which has different size"
-msgstr "невозможно преобразовать векторное значение в векторное значение другого размера"
+msgstr "невозможно преобразовать вектор типа %qT в тип %qT, который имеет другой размер"
 
 #: convert.c:1000
 #, gcc-internal-format
@@ -22062,10 +17893,9 @@
 msgstr "агрегатное значение вместо ожидаемого комплексного"
 
 #: convert.c:1123
-#, fuzzy, gcc-internal-format
-#| msgid "can%'t convert between vector values of different size"
+#, gcc-internal-format
 msgid "can%'t convert a value of type %qT to vector type %qT which has different size"
-msgstr "невозможно преобразовать векторное значение в векторное значение другого размера"
+msgstr "невозможно преобразовать значение типа %qT в векторный тип %qT, который имеет другой размер"
 
 #: convert.c:1131
 #, gcc-internal-format
@@ -22124,16 +17954,14 @@
 msgstr "поток управления функции %qE не соответствует данным профилирования (счетчик %qs)"
 
 #: coverage.c:406
-#, fuzzy, gcc-internal-format
-#| msgid "execution counts estimated"
+#, gcc-internal-format
 msgid "execution counts estimated\n"
-msgstr "использованы оценки счётчиков числа выполнений"
+msgstr ""
 
 #: coverage.c:407
-#, fuzzy, gcc-internal-format
-#| msgid "execution counts assumed to be zero"
+#, gcc-internal-format
 msgid "execution counts assumed to be zero\n"
-msgstr "предполагается, что счётчики числа выполнений нулевые"
+msgstr ""
 
 #: coverage.c:419
 #, gcc-internal-format
@@ -22216,27 +18044,26 @@
 msgstr "проигнорирован неопознанная опция %q.*s в %<-fdump-%s%>"
 
 #: dumpfile.c:967
-#, fuzzy, gcc-internal-format
-#| msgid "ignoring unknown option %q.*s in %<-fdump-%s%>"
+#, gcc-internal-format
 msgid "unknown option %q.*s in %<-fopt-info-%s%>"
-msgstr "проигнорирован неопознанная опция %q.*s в %<-fdump-%s%>"
+msgstr "неизвестная опция %q.*s в %<-fopt-info-%s%>"
 
 #: dumpfile.c:999
 #, gcc-internal-format
 msgid "ignoring possibly conflicting option %<-fopt-info-%s%>"
-msgstr ""
+msgstr "игнорирование возможно конфликтующих опций %<-fopt-info-%s%>"
 
 #: dwarf2out.c:1117
 #, gcc-internal-format
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
-msgstr "множественные программы индивидуальности для EH поддерживаются только если ассемблер поддерживает директиву .cfi_personality"
+msgstr "множественные программы индивидуальности для EH поддерживаются, только если ассемблер поддерживает директиву .cfi_personality"
 
-#: dwarf2out.c:10901
+#: dwarf2out.c:10909
 #, gcc-internal-format
 msgid "-gdwarf-6 is output as version 5 with incompatibilities"
 msgstr ""
 
-#: dwarf2out.c:14415
+#: dwarf2out.c:14423
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr "non-delegitimized UNSPEC %s (%d) найден в расположении переменной"
@@ -22329,22 +18156,22 @@
 #: expmed.c:354
 #, gcc-internal-format
 msgid "reverse scalar storage order"
-msgstr ""
+msgstr "обратить порядок хранения скаляра"
 
 #: expmed.c:371
 #, gcc-internal-format
 msgid "reverse floating-point scalar storage order"
-msgstr ""
+msgstr "обратить порядок хранения вещественного скаляра"
 
 #: expmed.c:412
 #, gcc-internal-format, gfc-internal-format
 msgid "reverse storage order for %smode"
-msgstr ""
+msgstr "обратить порядок хранения для %smode"
 
 #: expmed.c:658
 #, gcc-internal-format
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
-msgstr ""
+msgstr "запись %wu-бит данных вне границ объекта-приемника, данные усечены до %wu-бит"
 
 #: expr.c:10979
 #, gcc-internal-format
@@ -22356,12 +18183,6 @@
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr "%Kвызов %qs, объявленной с атрибутом warning: %s"
 
-#: file-prefix-map.c:50
-#, fuzzy, gcc-internal-format
-#| msgid "invalid use of %qD"
-msgid "invalid argument %qs to %qs"
-msgstr "некорректное использование %qD"
-
 #: final.c:1868
 #, gcc-internal-format
 msgid "the frame size of %wd bytes is larger than %wd bytes"
@@ -22382,42 +18203,42 @@
 msgid "large fixed-point constant implicitly truncated to fixed-point type"
 msgstr "большая константа с фиксированной точкой неявно урезана к типу с фиксированной точкой"
 
-#: fold-const.c:4151 fold-const.c:4161
+#: fold-const.c:4157 fold-const.c:4167
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d due to width of bit-field"
 msgstr "при данной ширине битового поля результат сравнения - всегда %d"
 
-#: fold-const.c:5478 tree-ssa-reassoc.c:2374 tree-ssa-reassoc.c:3214
+#: fold-const.c:5484 tree-ssa-reassoc.c:2379 tree-ssa-reassoc.c:3219
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
-msgstr "предполагается что при упрощении проверки диапазона не произошло переполнение"
+msgstr "предполагается, что при упрощении проверки диапазона не произошло переполнение"
 
-#: fold-const.c:5928 fold-const.c:5942
+#: fold-const.c:5934 fold-const.c:5948
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr "результат сравнения - всегда %d"
 
-#: fold-const.c:6085
+#: fold-const.c:6091
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr "%<или%> от двух сравнений на неравенство с разными величинами - всегда 1"
 
-#: fold-const.c:6090
+#: fold-const.c:6096
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr "%<или%> от двух взаимно исключающих сравнений на равенство - всегда 0"
 
-#: fold-const.c:8310
+#: fold-const.c:8316
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
-msgstr "предполагается что при редукции константы в сравнении не произошло переполнение"
+msgstr "предполагается, что при редукции константы в сравнении не произошло переполнение"
 
-#: fold-const.c:8710
+#: fold-const.c:8716
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr "предполагается, что при комбинировании констант вокруг сравнения не произошло переполнение"
 
-#: fold-const.c:12063
+#: fold-const.c:12069
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr "проверка fold: исходное дерево изменено функцией fold"
@@ -22427,7 +18248,7 @@
 msgid "total size of local objects too large"
 msgstr "общий размер локальных объектов слишком велик"
 
-#: function.c:1776 gimplify.c:6270
+#: function.c:1776 gimplify.c:6273
 #, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr "некорректное ограничение в %<asm%>"
@@ -22504,10 +18325,9 @@
 
 #. The inferior failed to catch the signal.
 #: gcc.c:3151 gcc.c:3175
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Use alternate register names"
+#, gcc-internal-format, gfc-internal-format
 msgid "%s signal terminated program %s"
-msgstr "Использовать альтернативные имена регистров"
+msgstr ""
 
 #: gcc.c:3653 opts-common.c:1233 opts-common.c:1257 opts-global.c:139
 #, gcc-internal-format
@@ -22517,7 +18337,7 @@
 #: gcc.c:3718
 #, gcc-internal-format, gfc-internal-format
 msgid "GCC is not configured to support %s as offload target"
-msgstr ""
+msgstr "GCC не сконфигурирована для поддержки %s как цели разгрузки"
 
 #: gcc.c:4022
 #, gcc-internal-format
@@ -22525,16 +18345,14 @@
 msgstr "%qs - неопределенный ключ -save-temps"
 
 #: gcc.c:4497 toplev.c:875
-#, fuzzy, gcc-internal-format
-#| msgid "%qs is not a valid output file"
+#, gcc-internal-format
 msgid "input file %qs is the same as output file"
-msgstr "%qs не является корректным выходным файлом"
+msgstr "входной файл %qs совпадает с выходным файлом"
 
 #: gcc.c:4502
-#, fuzzy, gcc-internal-format
-#| msgid "no input file specified"
+#, gcc-internal-format
 msgid "output filename may not be empty"
-msgstr "не задано ни одного входного файла"
+msgstr "имя выходного файла не может быть пустым"
 
 #: gcc.c:4527
 #, gcc-internal-format
@@ -22636,10 +18454,9 @@
 msgstr "некорректные аргументы spec-функции"
 
 #: gcc.c:6330
-#, fuzzy, gcc-internal-format
-#| msgid "braced spec %qs is invalid at %qc"
+#, gcc-internal-format
 msgid "braced spec %qs ends in escape"
-msgstr "ошибка в спецификации %qs в скобках на символе %qc"
+msgstr ""
 
 #: gcc.c:6465
 #, gcc-internal-format
@@ -22682,16 +18499,14 @@
 msgstr "ошибка спецификации: задано более одного аргумента для SYSROOT_HEADERS_SUFFIX_SPEC"
 
 #: gcc.c:7881
-#, fuzzy, gcc-internal-format
-#| msgid "unrecognized command line option %<-fdump-%s%>"
+#, gcc-internal-format
 msgid "unrecognized command line option %<-%s%>; did you mean %<-%s%>?"
-msgstr "некорректный ключ %<-fdump-%s%>"
+msgstr "неопознанная опция командной строки %<-%s%>; имелось в виду %<-%s%>?"
 
 #: gcc.c:7885
-#, fuzzy, gcc-internal-format
-#| msgid "unrecognized command line option %<-fdump-%s%>"
+#, gcc-internal-format
 msgid "unrecognized command line option %<-%s%>"
-msgstr "некорректный ключ %<-fdump-%s%>"
+msgstr "неопознанная опция командной строки %<-%s%>"
 
 #: gcc.c:8011
 #, gcc-internal-format
@@ -22738,10 +18553,10 @@
 msgid "%s: linker input file unused because linking not done"
 msgstr "%s: входные файлы компоновки не использованы, поскольку компоновка не выполнялась"
 
-#: gcc.c:8420 c-family/c-opts.c:770
+#: gcc.c:8420 c-family/c-opts.c:768
 #, gcc-internal-format
 msgid "cannot use %<-%> as input filename for a precompiled header"
-msgstr ""
+msgstr "нельзя использовать %<-%> как входное имя файла для прекомпилированного заголовка"
 
 #: gcc.c:8426
 #, gcc-internal-format, gfc-internal-format
@@ -22759,10 +18574,9 @@
 msgstr "исключения %qs в мультибиблиотеке некорректны"
 
 #: gcc.c:8932
-#, fuzzy, gcc-internal-format
-#| msgid "multilib select %qs is invalid"
+#, gcc-internal-format
 msgid "multilib select %qs %qs is invalid"
-msgstr "выбор мультибиблиотеки %qs некорректен"
+msgstr "выбор мультибиблиотеки %qs %qs некорректен"
 
 #: gcc.c:9094
 #, gcc-internal-format
@@ -22825,59 +18639,51 @@
 msgstr "аргумент %%:compare-debug-auxbase-opt заканчивается не .gk"
 
 #: gcc.c:9903
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "too few arguments to function"
+#, gcc-internal-format, gfc-internal-format
 msgid "too few arguments to %%:replace-extension"
-msgstr "слишком мало аргументов функции"
+msgstr "слишком мало аргументов для %%:replace-extension"
 
 #: gcc.c:9956
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "wrong number of arguments to %<__builtin_complex%>"
+#, gcc-internal-format, gfc-internal-format
 msgid "wrong number of arguments to %%:debug-level-gt"
-msgstr "неверное число аргументов в вызове %<__builtin_complex%>"
+msgstr "неверное число аргументов для %%:debug-level-gt"
 
 #: gcov-tool.c:73
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "error writing %qs"
+#, gcc-internal-format, gfc-internal-format
 msgid "error in removing %s\n"
-msgstr "ошибка записи %qs"
+msgstr ""
 
 #
 #: gcov-tool.c:104
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "can't create directory %s: %m"
+#, gcc-internal-format, gfc-internal-format
 msgid "Cannot make directory %s"
-msgstr "ошибка создания каталога %s: %m"
+msgstr "ошибка создания каталога %s"
 
 #: gcov-tool.c:112
-#, fuzzy, gcc-internal-format
-#| msgid "%s: cannot get working directory: %s\n"
+#, gcc-internal-format
 msgid "Cannot get current directory name"
-msgstr "%s: ошибка доступа к рабочему каталогу: %s\n"
+msgstr "Невозможно получить имя текущего каталога"
 
 #
 #: gcov-tool.c:116 gcov-tool.c:130
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "can't create directory %s: %m"
+#, gcc-internal-format, gfc-internal-format
 msgid "Cannot change directory to %s"
-msgstr "ошибка создания каталога %s: %m"
+msgstr "Невозможно сменить каталог на %s"
 
 #: gcov-tool.c:123
 #, gcc-internal-format, gfc-internal-format
 msgid "output file %s already exists in folder %s"
-msgstr ""
+msgstr "выходной файл %s уже существует в папке %s"
 
 #: gcov-tool.c:223
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' at %L must be nonnegative"
+#, gcc-internal-format
 msgid "weights need to be non-negative\n"
-msgstr "'%s' в %L должен быть неотрицательным"
+msgstr ""
 
 #: gcov-tool.c:358
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' at %L must be nonnegative"
+#, gcc-internal-format
 msgid "scale needs to be non-negative\n"
-msgstr "'%s' в %L должен быть неотрицательным"
+msgstr ""
 
 #: gcse.c:3985
 #, gcc-internal-format, gfc-internal-format
@@ -22885,58 +18691,54 @@
 msgstr "%s: %d блоков и %d дуг на блок"
 
 #: gcse.c:3997
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "%s: %d basic blocks and %d registers"
+#, gcc-internal-format, gfc-internal-format
 msgid "%s: %d basic blocks and %d registers; increase --param max-gcse-memory above %d"
-msgstr "%s: %d блоков и %d регистров"
+msgstr "%s: %d базовых блоков и %d регистров; увеличьте --param max-gcse-memory выше %d"
 
 #: gencfn-macros.c:195
 #, gcc-internal-format, gfc-internal-format
 msgid "DEF_INTERNAL_FLT_FN (%s) has no associated built-in functions"
-msgstr ""
+msgstr "DEF_INTERNAL_FLT_FN (%s) не имеет ассоциированных встроенных функций"
 
 #: gencfn-macros.c:202
 #, gcc-internal-format, gfc-internal-format
 msgid "DEF_INTERNAL_INT_FN (%s) has no associated built-in functions"
-msgstr ""
+msgstr "DEF_INTERNAL_INT_FN (%s) не имеет ассоциированных встроенных функций"
 
 #: gentarget-def.c:126
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "invalid abstract type for %q+D"
+#, gcc-internal-format, gfc-internal-format
 msgid "invalid prototype for '%s'"
-msgstr "некорректный абстрактный тип для %q+D"
+msgstr "некорректный прототип для '%s'"
 
 #: gentarget-def.c:131
 #, gcc-internal-format, gfc-internal-format
 msgid "prototype for '%s' has required operands after optional operands"
-msgstr ""
+msgstr "прототип для '%s' имеет обязательные операнды после необязательных операндов"
 
 #: gentarget-def.c:148
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Actual argument to '%s' at %L must have the same declared type"
+#, gcc-internal-format, gfc-internal-format
 msgid "argument %d of '%s' did not have the expected name"
-msgstr "Фактический аргумент для '%s' в %L должен иметь тот же декларированный тип"
+msgstr "аргумент %d для '%s' не имеет ожидаемое имя"
 
 #: gentarget-def.c:168
 #, gcc-internal-format, gfc-internal-format
 msgid "'%s' must have %d operands (excluding match_dups)"
-msgstr ""
+msgstr "'%s' должно иметь %d операндов (исключая match_dups)"
 
 #: gentarget-def.c:172
 #, gcc-internal-format, gfc-internal-format
 msgid "'%s' must have at least %d operands (excluding match_dups)"
-msgstr ""
+msgstr "'%s' должно иметь не менее %d операндов (исключая match_dups)"
 
 #: gentarget-def.c:176
 #, gcc-internal-format, gfc-internal-format
 msgid "'%s' must have no more than %d operands (excluding match_dups)"
-msgstr ""
+msgstr "'%s' должно иметь не более %d операндов (исключая match_dups)"
 
 #: gentarget-def.c:276
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "deleted definition of %qD"
+#, gcc-internal-format, gfc-internal-format
 msgid "duplicate definition of '%s'"
-msgstr "удаленное определение %qD"
+msgstr "повторное определение '%s'"
 
 #: ggc-common.c:393 ggc-common.c:401 ggc-common.c:470 ggc-common.c:488
 #: ggc-page.c:2457 ggc-page.c:2488 ggc-page.c:2495
@@ -22976,10 +18778,9 @@
 msgstr "ошибка записи PCH файла"
 
 #: gimple-fold.c:1624 gimple-fold.c:2609
-#, fuzzy, gcc-internal-format
-#| msgid "cleanup argument not a function"
+#, gcc-internal-format
 msgid "%qD source argument is the same as destination"
-msgstr "аргумент атрибута cleanup - не функция"
+msgstr ""
 
 #: gimple-fold.c:1679
 msgid "%G%qD destination unchanged after copying no bytes from a string of length %E"
@@ -22989,7 +18790,7 @@
 msgid "%G%qD destination unchanged after copying no bytes"
 msgstr ""
 
-#: gimple-fold.c:2052 tree-ssa-strlen.c:2050
+#: gimple-fold.c:2052 tree-ssa-strlen.c:2074
 msgid "%G%qD specified bound %E equals destination size"
 msgstr ""
 
@@ -23002,23 +18803,21 @@
 msgstr ""
 
 #: gimple-ssa-isolate-paths.c:290
-#, fuzzy, gcc-internal-format
-#| msgid "target is not pointer or reference"
+#, gcc-internal-format
 msgid "potential null pointer dereference"
-msgstr "цель не есть указатель или ссылка"
+msgstr "потенциальный переход по пустому указателю"
 
 #: gimple-ssa-isolate-paths.c:330
-#, fuzzy, gcc-internal-format
-#| msgid "null pointer"
+#, gcc-internal-format
 msgid "null pointer dereference"
-msgstr "нулевой указатель"
+msgstr "переход по пустому указателю"
 
-#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12451
-#: tree.c:12488 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10147
-#: c/c-typeck.c:10164 c/gimple-parser.c:1616 c/gimple-parser.c:1624
+#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12455
+#: tree.c:12492 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10152
+#: c/c-typeck.c:10169 c/gimple-parser.c:1616 c/gimple-parser.c:1624
 #: cp/call.c:6493 cp/call.c:8098 cp/constexpr.c:820 cp/constexpr.c:2309
-#: cp/cvt.c:1015 cp/cvt.c:1042 cp/decl.c:7334 cp/decl2.c:5256 cp/pt.c:8334
-#: cp/semantics.c:1836 cp/semantics.c:4053 cp/typeck.c:1700 cp/typeck.c:1895
+#: cp/cvt.c:1015 cp/cvt.c:1042 cp/decl.c:7355 cp/decl2.c:5246 cp/pt.c:8348
+#: cp/semantics.c:1836 cp/semantics.c:4056 cp/typeck.c:1700 cp/typeck.c:1895
 #: cp/typeck.c:3837
 #, gcc-internal-format
 msgid "declared here"
@@ -23027,409 +18826,393 @@
 #: gimple-ssa-nonnull-compare.c:102
 #, gcc-internal-format
 msgid "nonnull argument %qD compared to NULL"
-msgstr ""
+msgstr "nonnull аргумент %qD сравнивается с NULL"
 
-#: gimple-ssa-sprintf.c:2517 gimple-ssa-sprintf.c:2637
+#: gimple-ssa-sprintf.c:2555 gimple-ssa-sprintf.c:2675
 #, gcc-internal-format
 msgid "%qE output may be truncated before the last format character"
-msgstr ""
+msgstr "%qE вывод может быть усечен ранее последнего символа формата"
 
-#: gimple-ssa-sprintf.c:2519 gimple-ssa-sprintf.c:2639
+#: gimple-ssa-sprintf.c:2557 gimple-ssa-sprintf.c:2677
 #, gcc-internal-format
 msgid "%qE output truncated before the last format character"
-msgstr ""
+msgstr "%qE вывод усечен ранее последнего символа формата"
 
-#: gimple-ssa-sprintf.c:2522 gimple-ssa-sprintf.c:2642
+#: gimple-ssa-sprintf.c:2560 gimple-ssa-sprintf.c:2680
 #, gcc-internal-format
 msgid "%qE may write a terminating nul past the end of the destination"
-msgstr ""
+msgstr "%qE может писать завершающий nul после конца приемника"
 
-#: gimple-ssa-sprintf.c:2524 gimple-ssa-sprintf.c:2644
+#: gimple-ssa-sprintf.c:2562 gimple-ssa-sprintf.c:2682
 #, gcc-internal-format
 msgid "%qE writing a terminating nul past the end of the destination"
-msgstr ""
+msgstr "%qE запись завершающего nul после конца приемника"
 
-#: gimple-ssa-sprintf.c:2534
+#: gimple-ssa-sprintf.c:2572
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size %wu"
-msgstr[0] ""
-msgstr[1] ""
-msgstr[2] ""
+msgstr[0] "%<%.*s%> директивная запись %wu байт в область размера %wu"
+msgstr[1] "%<%.*s%> директивная запись %wu байт в область размера %wu"
+msgstr[2] "%<%.*s%> директивная запись %wu байт в область размера %wu"
 
-#: gimple-ssa-sprintf.c:2541
+#: gimple-ssa-sprintf.c:2579
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size %wu"
-msgstr[0] ""
-msgstr[1] ""
-msgstr[2] ""
+msgstr[0] "%<%.*s%> директивный вывод может быть усечен записью %wu байт в область размера %wu"
+msgstr[1] "%<%.*s%> директивный вывод может быть усечен записью %wu байт в область размера %wu"
+msgstr[2] "%<%.*s%> директивный вывод может быть усечен записью %wu байт в область размера %wu"
 
-#: gimple-ssa-sprintf.c:2548
+#: gimple-ssa-sprintf.c:2586
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size %wu"
-msgstr[0] ""
-msgstr[1] ""
-msgstr[2] ""
+msgstr[0] "%<%.*s%> директивный вывод усечен записью %wu байт в область размера %wu"
+msgstr[1] "%<%.*s%> директивный вывод усечен записью %wu байт в область размера %wu"
+msgstr[2] "%<%.*s%> директивный вывод усечен записью %wu байт в область размера %wu"
 
-#: gimple-ssa-sprintf.c:2559
+#: gimple-ssa-sprintf.c:2597
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size %wu"
-msgstr ""
+msgstr "%<%.*s%> директивный вывод может быть усечен записью до %wu байт в область размера %wu"
 
-#: gimple-ssa-sprintf.c:2562
+#: gimple-ssa-sprintf.c:2600
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size %wu"
-msgstr ""
+msgstr "%<%.*s%> директивный вывод усечен записью до %wu байт в область размера %wu"
 
-#: gimple-ssa-sprintf.c:2564
+#: gimple-ssa-sprintf.c:2602
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size %wu"
-msgstr ""
+msgstr "%<%.*s%> директивная запись до %wu байт в область размера %wu"
 
-#: gimple-ssa-sprintf.c:2576
+#: gimple-ssa-sprintf.c:2614
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size %wu"
-msgstr ""
+msgstr "%<%.*s%> директивный вывод может быть усечен записью примерно %wu или более байт в область размера %wu"
 
-#: gimple-ssa-sprintf.c:2579
+#: gimple-ssa-sprintf.c:2617
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size %wu"
-msgstr ""
+msgstr "%<%.*s%> директивный вывод усечен записью примерно %wu или более байт в область размера %wu"
 
-#: gimple-ssa-sprintf.c:2582
+#: gimple-ssa-sprintf.c:2620
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size %wu"
-msgstr ""
+msgstr "%<%.*s%> директивная запись примерно %wu или более байт в область размера %wu"
 
-#: gimple-ssa-sprintf.c:2591
+#: gimple-ssa-sprintf.c:2629
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size %wu"
-msgstr ""
+msgstr "%<%.*s%> директивный вывод может быть усечен записью от %wu до %wu байт в область размера %wu"
 
-#: gimple-ssa-sprintf.c:2594
+#: gimple-ssa-sprintf.c:2632
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size %wu"
-msgstr ""
+msgstr "%<%.*s%> директивный вывод усечен записью от %wu до %wu байт в область размера %wu"
 
-#: gimple-ssa-sprintf.c:2597
+#: gimple-ssa-sprintf.c:2635
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size %wu"
-msgstr ""
+msgstr "%<%.*s%> директивная запись от %wu до %wu байт в область размера %wu"
 
-#: gimple-ssa-sprintf.c:2606
+#: gimple-ssa-sprintf.c:2644
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size %wu"
-msgstr ""
+msgstr "%<%.*s%> директивный вывод может быть усечен записью %wu или более байт в область размера %wu"
 
-#: gimple-ssa-sprintf.c:2609
+#: gimple-ssa-sprintf.c:2647
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size %wu"
-msgstr ""
+msgstr "%<%.*s%> директивный вывод усечен записью %wu или более байт в область размера %wu"
 
-#: gimple-ssa-sprintf.c:2611
+#: gimple-ssa-sprintf.c:2649
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size %wu"
-msgstr ""
+msgstr "%<%.*s%> директивная запись %wu или более байт в область размера %wu"
 
-#: gimple-ssa-sprintf.c:2653
+#: gimple-ssa-sprintf.c:2691
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size between %wu and %wu"
-msgstr[0] ""
-msgstr[1] ""
-msgstr[2] ""
+msgstr[0] "%<%.*s%> директивная запись %wu байт в область размера от %wu до %wu"
+msgstr[1] "%<%.*s%> директивная запись %wu байт в область размера от %wu до %wu"
+msgstr[2] "%<%.*s%> директивная запись %wu байт в область размера от %wu до %wu"
 
-#: gimple-ssa-sprintf.c:2660
+#: gimple-ssa-sprintf.c:2698
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size between %wu and %wu"
-msgstr[0] ""
-msgstr[1] ""
-msgstr[2] ""
+msgstr[0] "%<%.*s%> директивный вывод может быть усечен записью %wu байт в область размера от %wu до %wu"
+msgstr[1] "%<%.*s%> директивный вывод может быть усечен записью %wu байт в область размера от %wu до %wu"
+msgstr[2] "%<%.*s%> директивный вывод может быть усечен записью %wu байт в область размера от %wu до %wu"
 
-#: gimple-ssa-sprintf.c:2668
+#: gimple-ssa-sprintf.c:2706
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size between %wu and %wu"
-msgstr[0] ""
-msgstr[1] ""
-msgstr[2] ""
+msgstr[0] "%<%.*s%> директивный вывод усечен записью %wu байт в область размера от %wu до %wu"
+msgstr[1] "%<%.*s%> директивный вывод усечен записью %wu байт в область размера от %wu до %wu"
+msgstr[2] "%<%.*s%> директивный вывод усечен записью %wu байт в область размера от %wu до %wu"
 
-#: gimple-ssa-sprintf.c:2680
+#: gimple-ssa-sprintf.c:2718
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size between %wu and %wu"
-msgstr ""
+msgstr "%<%.*s%> директивный вывод может быть усечен записью до %wu байт в область размера от %wu до %wu"
 
-#: gimple-ssa-sprintf.c:2683
+#: gimple-ssa-sprintf.c:2721
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size between %wu and %wu"
-msgstr ""
+msgstr "%<%.*s%> директивный вывод усечен записью до %wu байт в область размера от %wu до %wu"
 
-#: gimple-ssa-sprintf.c:2686
+#: gimple-ssa-sprintf.c:2724
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size between %wu and %wu"
-msgstr ""
+msgstr "%<%.*s%> директивная запись до %wu байт в область размера от %wu до %wu"
 
-#: gimple-ssa-sprintf.c:2699
+#: gimple-ssa-sprintf.c:2737
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
-msgstr ""
+msgstr "%<%.*s%> директивный вывод может быть усечен записью примерно %wu или более байт в область размера от %wu до %wu"
 
-#: gimple-ssa-sprintf.c:2702
+#: gimple-ssa-sprintf.c:2740
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
-msgstr ""
+msgstr "%<%.*s%> директивный вывод усечен записью примерно %wu или более байт в область размера от %wu до %wu"
 
-#: gimple-ssa-sprintf.c:2705
+#: gimple-ssa-sprintf.c:2743
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size between %wu and %wu"
-msgstr ""
+msgstr "%<%.*s%> директивная запись примерно %wu или более байт в область размера от %wu до %wu"
 
-#: gimple-ssa-sprintf.c:2715
+#: gimple-ssa-sprintf.c:2753
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
-msgstr ""
+msgstr "%<%.*s%> директивный вывод может быть усечен записью от %wu до %wu байт в область размера от %wu до %wu"
 
-#: gimple-ssa-sprintf.c:2718
+#: gimple-ssa-sprintf.c:2756
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
-msgstr ""
+msgstr "%<%.*s%> директивный вывод усечен записью от %wu до %wu байт в область размера от %wu до %wu"
 
-#: gimple-ssa-sprintf.c:2721
+#: gimple-ssa-sprintf.c:2759
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size between %wu and %wu"
-msgstr ""
+msgstr "%<%.*s%> директивная запись от %wu до %wu байт в область размера от %wu до %wu"
 
-#: gimple-ssa-sprintf.c:2730
+#: gimple-ssa-sprintf.c:2768
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size between %wu and %wu"
-msgstr ""
+msgstr "%<%.*s%> директивный вывод может быть усечен записью %wu или более байт в область размера от %wu до %wu"
 
-#: gimple-ssa-sprintf.c:2733
+#: gimple-ssa-sprintf.c:2771
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size between %wu and %wu"
-msgstr ""
+msgstr "%<%.*s%> директивный вывод усечен записью %wu или более байт в область размера от %wu до %wu"
 
-#: gimple-ssa-sprintf.c:2736
+#: gimple-ssa-sprintf.c:2774
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size between %wu and %wu"
-msgstr ""
+msgstr "%<%.*s%> директивная запись %wu или более байт в область размера от %wu до %wu"
 
-#: gimple-ssa-sprintf.c:2825
-#, fuzzy, gcc-internal-format
-#| msgid "Extension: Negative argument N at %L"
+#: gimple-ssa-sprintf.c:2863
+#, gcc-internal-format
 msgid "%<%.*s%> directive argument is null"
-msgstr "Расширение: Отрицательный аргумент N в %L"
+msgstr ""
 
-#: gimple-ssa-sprintf.c:2890
+#: gimple-ssa-sprintf.c:2928
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes exceeds minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2897
+#: gimple-ssa-sprintf.c:2935
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may exceed minimum required size of 4095"
-msgstr ""
+msgstr "%<%.*s%> директивный вывод от %wu до %wu байт может превысить минимальный требуемый размер 4095"
 
-#: gimple-ssa-sprintf.c:2900
+#: gimple-ssa-sprintf.c:2938
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes exceeds minimum required size of 4095"
-msgstr ""
+msgstr "%<%.*s%> директивный вывод от %wu до %wu байт превышает минимальный требуемый размер 4095"
 
-#: gimple-ssa-sprintf.c:2929
+#: gimple-ssa-sprintf.c:2967
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2936
+#: gimple-ssa-sprintf.c:2974
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes causes result to exceed %<INT_MAX%>"
-msgstr ""
+msgstr "%<%.*s%> директивный вывод от %wu до %wu байт вызывает превышение результатом %<INT_MAX%>"
 
-#: gimple-ssa-sprintf.c:2939
+#: gimple-ssa-sprintf.c:2977
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may cause result to exceed %<INT_MAX%>"
-msgstr ""
+msgstr "%<%.*s%> директивный вывод от %wu до %wu байт может вызвать превышение результатом %<INT_MAX%>"
 
-#: gimple-ssa-sprintf.c:2949
+#: gimple-ssa-sprintf.c:2987
 #, gcc-internal-format
 msgid "assuming directive output of %wu byte"
 msgid_plural "assuming directive output of %wu bytes"
-msgstr[0] ""
-msgstr[1] ""
-msgstr[2] ""
+msgstr[0] "предполагать директивный вывод в %wu байт"
+msgstr[1] "предполагать директивный вывод в %wu байт"
+msgstr[2] "предполагать директивный вывод в %wu байт"
 
-#: gimple-ssa-sprintf.c:2956
-#, fuzzy, gcc-internal-format
-#| msgid "Extension: Negative argument N at %L"
+#: gimple-ssa-sprintf.c:2994
+#, gcc-internal-format
 msgid "directive argument %qE"
-msgstr "Расширение: Отрицательный аргумент N в %L"
+msgstr "аргумент директивы %qE"
 
-#: gimple-ssa-sprintf.c:2958
-#, fuzzy, gcc-internal-format
-#| msgid "disable pass %s for functions in the range of [%u, %u]"
+#: gimple-ssa-sprintf.c:2996
+#, gcc-internal-format
 msgid "directive argument in the range [%E, %E]"
-msgstr "отключить проход %s для функций в диапазоне [%u, %u]"
+msgstr "аргумент директивы в диапазоне [%E, %E]"
 
-#: gimple-ssa-sprintf.c:2962
+#: gimple-ssa-sprintf.c:3000
 #, gcc-internal-format
 msgid "using the range [%E, %E] for directive argument"
-msgstr ""
+msgstr "использование диапазона [%E, %E] для аргумента директивы"
 
-#: gimple-ssa-sprintf.c:2982
+#: gimple-ssa-sprintf.c:3020
 #, gcc-internal-format
 msgid "%qE output %wu byte into a destination of size %wu"
-msgstr ""
+msgstr "%qE вывод %wu байт в приемник размера %wu"
 
-#: gimple-ssa-sprintf.c:2983
+#: gimple-ssa-sprintf.c:3021
 #, gcc-internal-format
 msgid "%qE output %wu bytes into a destination of size %wu"
-msgstr ""
+msgstr "%qE вывод %wu байт в приемник размера %wu"
 
-#: gimple-ssa-sprintf.c:2987
+#: gimple-ssa-sprintf.c:3025
 #, gcc-internal-format
 msgid "%qE output between %wu and %wu bytes into a destination of size %wu"
-msgstr ""
+msgstr "%qE вывод от %wu до %wu байт в приемник размера %wu"
 
-#: gimple-ssa-sprintf.c:2992
+#: gimple-ssa-sprintf.c:3030
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes (assuming %wu) into a destination of size %wu"
-msgstr ""
+msgstr "%qE вывод %wu или более байт (предполагается %wu) в приемник размера %wu"
 
-#: gimple-ssa-sprintf.c:2997
+#: gimple-ssa-sprintf.c:3035
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes into a destination of size %wu"
-msgstr ""
+msgstr "%qE вывод %wu или более байт в приемник размера %wu"
 
-#: gimple-ssa-sprintf.c:3368
+#: gimple-ssa-sprintf.c:3406
 #, gcc-internal-format
 msgid "%<%.*s%> directive width out of range"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3402
+#: gimple-ssa-sprintf.c:3440
 #, gcc-internal-format
 msgid "%<%.*s%> directive precision out of range"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3893
+#: gimple-ssa-sprintf.c:3931
 #, gcc-internal-format
 msgid "specified bound %wu exceeds maximum object size %wu"
-msgstr ""
+msgstr "заданная граница %wu превышает максимальный размер объекта %wu"
 
-#: gimple-ssa-sprintf.c:3899
+#: gimple-ssa-sprintf.c:3937
 #, gcc-internal-format
 msgid "specified bound %wu exceeds %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3949
-#, fuzzy, gcc-internal-format
-#| msgid "null pointer"
+#: gimple-ssa-sprintf.c:3987
+#, gcc-internal-format
 msgid "null destination pointer"
-msgstr "нулевой указатель"
+msgstr "нулевой указатель приемника"
 
-#: gimple-ssa-sprintf.c:3966
+#: gimple-ssa-sprintf.c:4004
 #, gcc-internal-format
 msgid "specified bound %wu exceeds the size %wu of the destination object"
-msgstr ""
+msgstr "заданная граница %wu превышает размер %wu объекта приемника"
 
-#: gimple-ssa-sprintf.c:3978
-#, fuzzy, gcc-internal-format
-#| msgid "%s in format string at %L"
+#: gimple-ssa-sprintf.c:4016
+#, gcc-internal-format
 msgid "null format string"
-msgstr "%s в форматной строке в %L"
+msgstr "пустая форматная строка"
 
 #: gimple-ssa-warn-alloca.c:462
-#, fuzzy, gcc-internal-format
-#| msgid "invalid use of %<auto%>"
+#, gcc-internal-format
 msgid "use of %<alloca%>"
-msgstr "недопустимое использование %<auto%>"
+msgstr "использование %<alloca%>"
 
 #: gimple-ssa-warn-alloca.c:485
-#, fuzzy, gcc-internal-format
-#| msgid "Warn if a variable length array is used"
+#, gcc-internal-format
 msgid "argument to variable-length array may be too large"
-msgstr "Предупреждать об использовании массивов переменной длины"
+msgstr "аргумент для массива переменной длины может оказаться слишком большим"
 
 #: gimple-ssa-warn-alloca.c:487
-#, fuzzy, gcc-internal-format
-#| msgid "argument to %qE attribute larger than %d"
+#, gcc-internal-format
 msgid "argument to %<alloca%> may be too large"
-msgstr "аргумент для %qE атрибута больше чем %d"
+msgstr "аргумент для %<alloca%> может оказаться слишком большим"
 
 #: gimple-ssa-warn-alloca.c:491
 #, gcc-internal-format, gfc-internal-format
 msgid "limit is %u bytes, but argument may be as large as %s"
-msgstr ""
+msgstr "лимит %u байт, но аргумент может достигать размера %s"
 
 #: gimple-ssa-warn-alloca.c:498
-#, fuzzy, gcc-internal-format
-#| msgid "Warn if a variable length array is used"
+#, gcc-internal-format
 msgid "argument to variable-length array is too large"
-msgstr "Предупреждать об использовании массивов переменной длины"
+msgstr "аргумент для массива переменной длины слишком большой"
 
 #: gimple-ssa-warn-alloca.c:500
-#, fuzzy, gcc-internal-format
-#| msgid "argument to %qE attribute larger than %d"
+#, gcc-internal-format
 msgid "argument to %<alloca%> is too large"
-msgstr "аргумент для %qE атрибута больше чем %d"
+msgstr "аргумент для %<alloca%> слишком большой"
 
 #: gimple-ssa-warn-alloca.c:504
 #, gcc-internal-format, gfc-internal-format
 msgid "limit is %u bytes, but argument is %s"
-msgstr ""
+msgstr "лимит %u байт, но аргумент %s"
 
 #: gimple-ssa-warn-alloca.c:510
-#, fuzzy, gcc-internal-format
-#| msgid "variable length array is used"
+#, gcc-internal-format
 msgid "variable-length array bound is unknown"
-msgstr "используется массив переменного размера"
+msgstr "граница массив переменной длины неизвестна"
 
 #: gimple-ssa-warn-alloca.c:511
-#, fuzzy, gcc-internal-format
-#| msgid "type of %qE is unknown"
+#, gcc-internal-format
 msgid "%<alloca%> bound is unknown"
-msgstr "тип %qE неизвестен"
+msgstr "граница %<alloca%> неизвестна"
 
 #: gimple-ssa-warn-alloca.c:515
-#, fuzzy, gcc-internal-format
-#| msgid "ISO C90 forbids variable length array"
+#, gcc-internal-format
 msgid "unbounded use of variable-length array"
-msgstr "ISO C90 не поддерживает массив переменного размера"
+msgstr "неограниченное использование массива переменной длины"
 
 #: gimple-ssa-warn-alloca.c:516
-#, fuzzy, gcc-internal-format
-#| msgid "invalid use of %<auto%>"
+#, gcc-internal-format
 msgid "unbounded use of %<alloca%>"
-msgstr "недопустимое использование %<auto%>"
+msgstr "некорректное использование %<alloca%>"
 
 #: gimple-ssa-warn-alloca.c:520
 #, gcc-internal-format
 msgid "use of %<alloca%> within a loop"
-msgstr ""
+msgstr "использование %<alloca%> в цикле"
 
 #: gimple-ssa-warn-alloca.c:525
 #, gcc-internal-format
 msgid "argument to variable-length array may be too large due to conversion from %qT to %qT"
-msgstr ""
+msgstr "аргумент для массива переменной длины может быть слишком велик из-за преобразования из %qT в %qT"
 
 #: gimple-ssa-warn-alloca.c:528
 #, gcc-internal-format
 msgid "argument to %<alloca%> may be too large due to conversion from %qT to %qT"
-msgstr ""
+msgstr "аргумент для %<alloca%> может быть слишком велик из-за преобразования из %qT в %qT"
 
 #: gimple-ssa-warn-alloca.c:534
-#, fuzzy, gcc-internal-format
-#| msgid "Warn if a variable length array is used"
+#, gcc-internal-format
 msgid "argument to variable-length array is zero"
-msgstr "Предупреждать об использовании массивов переменной длины"
+msgstr "аргумент для массива переменной длины нулевой"
 
 #: gimple-ssa-warn-alloca.c:536
-#, fuzzy, gcc-internal-format
-#| msgid "Second argument of MOD at %L is zero"
+#, gcc-internal-format
 msgid "argument to %<alloca%> is zero"
-msgstr "Второй аргумент MOD в %L нулевой"
+msgstr "аргумент для %<alloca%> нулевой"
 
 #: gimple-ssa-warn-restrict.c:1402
 msgid "%G%qD accessing %wu byte at offsets %s and %s overlaps %wu byte at offset %s"
@@ -23545,10 +19328,9 @@
 msgstr ""
 
 #: gimple-ssa-warn-restrict.c:1635
-#, fuzzy, gcc-internal-format
-#| msgid "%qD declared here"
+#, gcc-internal-format
 msgid "array %qD declared here"
-msgstr "%qD объявлено здесь"
+msgstr ""
 
 #: gimple-ssa-warn-restrict.c:1638 gimple-ssa-warn-restrict.c:1644
 msgid "%G%qD pointer overflow between offset %s and size %s"
@@ -23567,16 +19349,14 @@
 msgstr ""
 
 #: gimple-ssa-warn-restrict.c:1673
-#, fuzzy
-#| msgid "array subscript is outside array bounds"
 msgid "%G%qD offset %s is out of the bounds of object %qD with type %qT"
-msgstr "индекс массива вне диапазона границ массива"
+msgstr ""
 
 #: gimple-ssa-warn-restrict.c:1678 c/c-decl.c:3603 c/c-decl.c:3874
-#: c/c-typeck.c:8345 cp/class.c:1346 cp/class.c:3098 cp/decl.c:3979
-#: cp/decl.c:10753 cp/decl.c:11151 cp/decl.c:11160 cp/friend.c:384
+#: c/c-typeck.c:8350 cp/class.c:1346 cp/class.c:3102 cp/decl.c:3979
+#: cp/decl.c:10777 cp/decl.c:11175 cp/decl.c:11184 cp/friend.c:384
 #: cp/friend.c:393 cp/parser.c:3275 cp/parser.c:3372 cp/parser.c:3422
-#: cp/parser.c:6327 cp/parser.c:21027
+#: cp/parser.c:6330 cp/parser.c:21024
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD объявлено здесь"
@@ -23590,16 +19370,12 @@
 msgstr ""
 
 #: gimple-ssa-warn-restrict.c:1690
-#, fuzzy
-#| msgid "DIM argument at %L is out of bounds"
 msgid "%G%qD forming offset %s is out of bounds"
-msgstr "DIM аргумент в %L вне границ"
+msgstr ""
 
 #: gimple-ssa-warn-restrict.c:1691
-#, fuzzy
-#| msgid "DIM argument at %L is out of bounds"
 msgid "%G%qD offset %s is out of bounds"
-msgstr "DIM аргумент в %L вне границ"
+msgstr ""
 
 #: gimple-ssa-warn-restrict.c:1702
 msgid "%G%qD offset %s from the object at %qE is out of the bounds of %qT"
@@ -23610,10 +19386,8 @@
 msgstr ""
 
 #: gimple-ssa-warn-restrict.c:1890
-#, fuzzy
-#| msgid "cleanup argument not a function"
 msgid "%G%qD source argument is the same as destination"
-msgstr "аргумент атрибута cleanup - не функция"
+msgstr ""
 
 #: gimple-streamer-in.c:210
 #, gcc-internal-format, gfc-internal-format
@@ -23626,25 +19400,24 @@
 msgstr "проверка gimple: ожидался %s(%s), обнаружен %s(%s) в %s, в %s:%d"
 
 #: gimplify.c:1854
-#, fuzzy, gcc-internal-format
-#| msgid "%Hwill never be executed"
+#, gcc-internal-format
 msgid "statement will never be executed"
-msgstr "%Hникогда не будет выполнена"
+msgstr "Оператор никогда не будет выполнен"
 
 #: gimplify.c:2183 gimplify.c:2191
 #, gcc-internal-format
 msgid "this statement may fall through"
-msgstr ""
+msgstr "этот оператор может провалиться"
 
 #: gimplify.c:2193
 #, gcc-internal-format
 msgid "here"
-msgstr ""
+msgstr "здесь"
 
 #: gimplify.c:2302
 #, gcc-internal-format
 msgid "attribute %<fallthrough%> not preceding a case label or default label"
-msgstr ""
+msgstr "атрибут %<fallthrough%> без предшествующей case метки или default метки"
 
 #: gimplify.c:3409
 #, gcc-internal-format
@@ -23651,234 +19424,218 @@
 msgid "using result of function returning %<void%>"
 msgstr "использование результат функции, возвращающей %<void%>"
 
-#: gimplify.c:6128
+#: gimplify.c:6131
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid lvalue in asm output %d"
 msgstr "неверное lvalue-выражение в выходном операторе %d оператора asm"
 
-#: gimplify.c:6271
+#: gimplify.c:6274
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr "входное значение %d должно быть в памяти"
 
-#: gimplify.c:6311 gimplify.c:6320
+#: gimplify.c:6314 gimplify.c:6323
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr "невозможна прямая адресация к входной позиции памяти %d"
 
-#: gimplify.c:6928
-#, fuzzy, gcc-internal-format
-#| msgid "threadprivate variable %qE used in untied task"
+#: gimplify.c:6931
+#, gcc-internal-format
 msgid "threadprivate variable %qE used in target region"
-msgstr "частная переменная потока %qE использована в безымянной задаче"
+msgstr "частная переменная потока %qE использована в целевой области"
 
-#: gimplify.c:6930
-#, fuzzy, gcc-internal-format
-#| msgid "enclosing task"
+#: gimplify.c:6933
+#, gcc-internal-format
 msgid "enclosing target region"
-msgstr "объемлющая задача"
+msgstr "объемлющая целевая область"
 
-#: gimplify.c:6942
+#: gimplify.c:6945
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in untied task"
 msgstr "частная переменная потока %qE использована в безымянной задаче"
 
-#: gimplify.c:6944
+#: gimplify.c:6947
 #, gcc-internal-format
 msgid "enclosing task"
 msgstr "объемлющая задача"
 
-#: gimplify.c:7016
-#, fuzzy, gcc-internal-format
-#| msgid "%qE not specified in enclosing parallel"
+#: gimplify.c:7019
+#, gcc-internal-format
 msgid "%qE not specified in enclosing %qs"
-msgstr "%qE не задано в объемлющей конструкции parallel"
+msgstr "%qE не задано в объемлющей %qs"
 
-#: gimplify.c:7018
-#, fuzzy, gcc-internal-format
-#| msgid "enclosing task"
+#: gimplify.c:7021
+#, gcc-internal-format
 msgid "enclosing %qs"
-msgstr "объемлющая задача"
+msgstr "объемлющая %qs"
 
-#: gimplify.c:7143
-#, fuzzy, gcc-internal-format
-#| msgid "%qE not specified in enclosing parallel"
+#: gimplify.c:7146
+#, gcc-internal-format
 msgid "%qE not specified in enclosing OpenACC %qs construct"
-msgstr "%qE не задано в объемлющей конструкции parallel"
+msgstr "%qE не задано в объемлющей OpenACC %qs конструкции"
 
-#: gimplify.c:7145
+#: gimplify.c:7148
 #, gcc-internal-format
 msgid "enclosing OpenACC %qs construct"
-msgstr ""
+msgstr "объемлющая OpenACC %qs конструкция"
 
-#: gimplify.c:7198
+#: gimplify.c:7201
 #, gcc-internal-format
 msgid "%qE with %<link%> clause used in %<routine%> function"
-msgstr ""
+msgstr "%qE с %<link%> предложением использовано в %<routine%> функции"
 
-#: gimplify.c:7206
-#, fuzzy, gcc-internal-format
-#| msgid "%qE undeclared (first use in this function)"
+#: gimplify.c:7209
+#, gcc-internal-format
 msgid "%qE requires a %<declare%> directive for use in a %<routine%> function"
-msgstr "%qE не описан (первое использование в этой функции)"
+msgstr "%qE требует %<declare%> директиву для использования в %<routine%> функции"
 
-#: gimplify.c:7272 gimplify.c:7872
-#, fuzzy, gcc-internal-format
-#| msgid "variable %q+D declared %<inline%>"
+#: gimplify.c:7275 gimplify.c:7875
+#, gcc-internal-format
 msgid "variable %qE declared in enclosing %<host_data%> region"
-msgstr "переменная %q+D декларирована со спецификатором %<inline%>"
+msgstr "переменная %qE декларирована в объемлющей %<host_data%> области"
 
-#: gimplify.c:7293
+#: gimplify.c:7296
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
-msgstr ""
+msgstr "%qD со ссылкой из целевой области не имеет отображаемый тип"
 
 #
-#: gimplify.c:7411 gimplify.c:7443
-#, fuzzy, gcc-internal-format
-#| msgid "%Hiteration variable %qE is unsigned"
+#: gimplify.c:7414 gimplify.c:7446
+#, gcc-internal-format
 msgid "iteration variable %qE is predetermined linear"
-msgstr "%Hитерационная переменная %qE есть unsigned"
+msgstr "итерационная переменная %qE предопределенно линейна"
 
-#: gimplify.c:7414
+#: gimplify.c:7417
 #, gcc-internal-format
 msgid "iteration variable %qE should be private"
 msgstr "итерационная переменная %qE должна быть private"
 
-#: gimplify.c:7428
+#: gimplify.c:7431
 #, gcc-internal-format
 msgid "iteration variable %qE should not be firstprivate"
 msgstr "итерационная переменная %qE не должна быть firstprivate"
 
-#: gimplify.c:7431
+#: gimplify.c:7434
 #, gcc-internal-format
 msgid "iteration variable %qE should not be reduction"
 msgstr "итерационная переменная %qE не должна быть редукцией"
 
-#: gimplify.c:7434
-#, fuzzy, gcc-internal-format
-#| msgid "iteration variable %qE should not be reduction"
+#: gimplify.c:7437
+#, gcc-internal-format
 msgid "iteration variable %qE should not be linear"
-msgstr "итерационная переменная %qE не должна быть редукцией"
+msgstr "итерационная переменная %qE не должна быть линейной"
 
-#: gimplify.c:7437
-#, fuzzy, gcc-internal-format
-#| msgid "iteration variable %qE should not be firstprivate"
+#: gimplify.c:7440
+#, gcc-internal-format
 msgid "iteration variable %qE should not be lastprivate"
-msgstr "итерационная переменная %qE не должна быть firstprivate"
+msgstr "итерационная переменная %qE не должна быть lastprivate"
 
-#: gimplify.c:7440
-#, fuzzy, gcc-internal-format
-#| msgid "iteration variable %qE should be private"
+#: gimplify.c:7443
+#, gcc-internal-format
 msgid "iteration variable %qE should not be private"
-msgstr "итерационная переменная %qE должна быть private"
+msgstr "итерационная переменная %qE не должна быть private"
 
-#: gimplify.c:7742
+#: gimplify.c:7745
 #, gcc-internal-format
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
-msgstr ""
+msgstr "%<linear%> клаузула для переменной отличной от итератора цикла заданного в конструкции, скомбинированной с %<distribute%>"
 
-#: gimplify.c:7949
+#: gimplify.c:7952
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
-msgstr ""
+msgstr "отображение поля %qE структуры переменной длины"
 
-#: gimplify.c:8160
-#, fuzzy, gcc-internal-format
-#| msgid "%qE appears more than once in data clauses"
+#: gimplify.c:8163
+#, gcc-internal-format
 msgid "%qE appears more than once in map clauses"
-msgstr "%qE встречается более одного раза в конструкции данных"
+msgstr "%qE встречается более одного раза в map клаузуле"
 
-#: gimplify.c:8464
-#, fuzzy, gcc-internal-format
-#| msgid "%s variable %qE is private in outer context"
+#: gimplify.c:8467
+#, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
-msgstr "%s переменная %qE является частной для внешнего контекста"
+msgstr "copyprivate переменная %qE не является threadprivate или private во внешнем контексте"
 
-#: gimplify.c:8484
+#: gimplify.c:8487
 #, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr "%s переменная %qE является частной для внешнего контекста"
 
-#: gimplify.c:8510
+#: gimplify.c:8513
 #, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
-msgstr ""
+msgstr "ожидался %qs %<if%> модификатор клаузулы а не %qs"
 
-#: gimplify.c:8775
+#: gimplify.c:8778
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
-msgstr ""
+msgstr "%<_Atomic%> %qD в неявной %<map%> клаузуле"
 
-#: gimplify.c:8808
+#: gimplify.c:8811
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
-msgstr ""
+msgstr "%<_Atomic%> %qD в неявной %<firstprivate%> клаузуле %<target%> конструкции"
 
-#: gimplify.c:9000
+#: gimplify.c:9003
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
-msgstr ""
+msgstr "%<_Atomic%> %qD в %<firstprivate%> клаузуле %<target%> конструкции"
 
-#: gimplify.c:9051
+#: gimplify.c:9054
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
-msgstr ""
+msgstr "та же переменная использована в %<firstprivate%> и %<lastprivate%> клаузулах %<distribute%> конструкции"
 
-#: gimplify.c:9133
+#: gimplify.c:9136
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to present_or_copy"
-msgstr ""
+msgstr "несовместимая клаузула данных с редукцией %qE; преобразовано в present_or_copy"
 
-#: gimplify.c:9278
-#, fuzzy, gcc-internal-format
-#| msgid "invalid template declaration of %qD"
+#: gimplify.c:9281
+#, gcc-internal-format
 msgid "invalid private reduction on %qE"
-msgstr "некорректная template-декларация %qD"
+msgstr "некорректная private редукция на %qE"
 
-#: gimplify.c:11103 omp-low.c:2791
-#, fuzzy, gcc-internal-format
-#| msgid "ordered region must be closely nested inside a loop region with an ordered clause"
+#: gimplify.c:11106 omp-low.c:2791
+#, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
-msgstr "ordered область должна быть тесно вложена внутри области цикла с ordered клаузулой"
+msgstr "%<ordered%> конструкция с %<depend%> клаузулой должна быть замкнуто вложена внутри цикла с %<ordered%> клаузулой с параметром"
 
-#: gimplify.c:11121
+#: gimplify.c:11124
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
-msgstr ""
+msgstr "переменная %qE не есть итерация самого внешнего цикла %d, ожидалось %qE"
 
-#: gimplify.c:11134
-#, fuzzy, gcc-internal-format
-#| msgid "number of results does not match number of values"
+#: gimplify.c:11137
+#, gcc-internal-format
 msgid "number of variables in %<depend(sink)%> clause does not match number of iteration variables"
-msgstr "число результатов не соответствует числу значений"
+msgstr "число переменных в %<depend(sink)%> клаузуле не соответствует числу итерационных переменных"
 
-#: gimplify.c:11147
+#: gimplify.c:11150
 #, gcc-internal-format
 msgid "more than one %<depend(source)%> clause on an %<ordered%> construct"
-msgstr ""
+msgstr "более одной %<depend(source)%> клаузулы %<ordered%> конструкции"
 
-#: gimplify.c:11158
+#: gimplify.c:11161
 #, gcc-internal-format
 msgid "%<depend(source)%> clause specified together with %<depend(sink:)%> clauses on the same construct"
-msgstr ""
+msgstr "%<depend(source)%> клаузула задана вместе с %<depend(sink:)%> клаузулами в той же конструкции"
 
-#: gimplify.c:12393
+#: gimplify.c:12396
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr "преобразование в gimple завершилось неуспешно"
 
-#: gimplify.c:12936
+#: gimplify.c:12939
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr "%qT преобразован к %qT при передаче через %<...%>"
 
-#: gimplify.c:12941
+#: gimplify.c:12944
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr "(поэтому %<va_arg%> нужно передать %qT, а не %qT)"
 
-#: gimplify.c:12948
+#: gimplify.c:12951
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr "при достижении этого кода выполнение программы завершится аварийно"
@@ -23899,344 +19656,322 @@
 msgstr "ошибка открытия %s: %m"
 
 #: graphite.c:463
-#, fuzzy, gcc-internal-format
-#| msgid "Graphite loop optimizations cannot be used"
+#, gcc-internal-format
 msgid "Graphite loop optimizations cannot be used (isl is not available)."
-msgstr "Graphite оптимизации циклов не могут быть использованы"
+msgstr "Graphite оптимизации циклов не могут быть использованы (isl отсутствует)."
 
 #: hsa-brig.c:909
 #, gcc-internal-format
 msgid "Support for HSA does not implement immediate 16 bit FPU operands"
-msgstr ""
+msgstr "Поддержка для HSA не реализует непосредственные 16-битные FPU операнды"
 
 #: hsa-common.c:243
-#, fuzzy, gcc-internal-format
-#| msgid "move insn not handled"
+#, gcc-internal-format
 msgid "HSA image ops not handled"
-msgstr "инструкция move не обработана"
+msgstr "HSA операция образа не обработана"
 
 #: hsa-gen.c:1230
 #, gcc-internal-format
 msgid "HSA SSA name defined by instruction that is supposed to be using it"
-msgstr ""
+msgstr "HSA SSA имя определено инструкцией, которая по идее должна использовать его"
 
 #: hsa-gen.c:1234 hsa-gen.c:1247
-#, fuzzy, gcc-internal-format
-#| msgid "verification failed: %s"
+#, gcc-internal-format
 msgid "HSA SSA verification failed"
-msgstr "ошибка проверки: %s"
+msgstr "неудача верификации HSA SSA"
 
 #: hsa-gen.c:1243
 #, gcc-internal-format
 msgid "HSA SSA name not among operands of instruction that is supposed to use it"
-msgstr ""
+msgstr "HSA SSA имя отсутствует среди операндов инструкции, которая по идее должна использовать его"
 
 #: hsa-gen.c:1503
 #, gcc-internal-format
 msgid "HSA instruction uses a register but is not among recorded register uses"
-msgstr ""
+msgstr "HSA инструкция использует регистр, но отсутствует среди записанных использований регистра"
 
 #: hsa-gen.c:1507
-#, fuzzy, gcc-internal-format
-#| msgid "verification failed: %s"
+#, gcc-internal-format
 msgid "HSA instruction verification failed"
-msgstr "ошибка проверки: %s"
+msgstr "неудача верификации HSA инструкции"
 
 #: input.c:1190
 #, gcc-internal-format, gfc-internal-format
 msgid "expansion point is location %i"
-msgstr ""
+msgstr "точка расширения есть расположение %i"
 
 #: input.c:1220
 #, gcc-internal-format, gfc-internal-format
 msgid "token %u has x-location == y-location == %u"
-msgstr ""
+msgstr "токен %u имеет x-location == y-location == %u"
 
 #: input.c:1228
 #, gcc-internal-format, gfc-internal-format
 msgid "token %u has x-location == %u"
-msgstr ""
+msgstr "токен %u имеет x-location == %u"
 
 #: input.c:1229
 #, gcc-internal-format, gfc-internal-format
 msgid "token %u has y-location == %u"
-msgstr ""
+msgstr "токен %u имеет y-location == %u"
 
 #: internal-fn.c:480
-#, fuzzy, gcc-internal-format
-#| msgid "invalid use of %<auto%>"
+#, gcc-internal-format
 msgid "invalid use of attribute %<fallthrough%>"
-msgstr "недопустимое использование %<auto%>"
+msgstr "недопустимое использование атрибута %<fallthrough%>"
 
 #: ipa-chkp.c:669
-#, fuzzy, gcc-internal-format
-#| msgid "%qs function cannot have arguments"
+#, gcc-internal-format
 msgid "function cannot be instrumented"
-msgstr "%qs функция не может иметь аргументы"
+msgstr "функция не может быть инструментирована"
 
 #: ipa-devirt.c:755 ipa-devirt.c:906
 #, gcc-internal-format
 msgid "virtual table of type %qD violates one definition rule"
-msgstr ""
+msgstr "виртуальная таблица типа %qD нарушает правило одного определения"
 
 #: ipa-devirt.c:758
 #, gcc-internal-format
 msgid "variable of same assembler name as the virtual table is defined in another translation unit"
-msgstr ""
+msgstr "переменная того же ассемблерного имени, что и виртуальная таблица, определена в другой единице трансляции"
 
 #: ipa-devirt.c:797
 #, gcc-internal-format
 msgid "virtual table of type %qD contains RTTI information"
-msgstr ""
+msgstr "виртуальная таблица типа %qD содержит RTTI информацию"
 
 #: ipa-devirt.c:803
 #, gcc-internal-format
 msgid "but is prevailed by one without from other translation unit"
-msgstr ""
+msgstr "но предназначена чем-то из другой единицы трансляции"
 
 #: ipa-devirt.c:807
 #, gcc-internal-format
 msgid "RTTI will not work on this type"
-msgstr ""
+msgstr "RTTI не будет работать с этим типом"
 
 #: ipa-devirt.c:837 ipa-devirt.c:865 ipa-devirt.c:936
 #, gcc-internal-format
 msgid "virtual table of type %qD violates one definition rule  "
-msgstr ""
+msgstr "виртуальная таблица типа %qD нарушает правило одного определения  "
 
 #: ipa-devirt.c:843
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit has virtual table of different size"
-msgstr ""
+msgstr "конфликтующий тип определенный в другой единице трансляции имеет виртуальную таблицу другого размера"
 
 #: ipa-devirt.c:871
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit with different RTTI information"
-msgstr ""
+msgstr "конфликтующий тип определенный в другой единице трансляции с другой RTTI информацией"
 
 #: ipa-devirt.c:914 ipa-devirt.c:944
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit"
-msgstr ""
+msgstr "конфликтующий тип определенный в другой единице трансляции"
 
 #: ipa-devirt.c:918
-#, fuzzy, gcc-internal-format
-#| msgid "initializer specified for non-virtual method %q+D"
+#, gcc-internal-format
 msgid "contains additional virtual method %qD"
-msgstr "инициализатор задан для невиртуального метода %q+D"
+msgstr "содержит дополнительный виртуальный метод %qD"
 
 #: ipa-devirt.c:925
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit has virtual table with more entries"
-msgstr ""
+msgstr "конфликтующий тип определенный в другой единице трансляции имеет виртуальную таблицу с большим числом элементов"
 
 #: ipa-devirt.c:950
-#, fuzzy, gcc-internal-format
-#| msgid "virtual function %q+D"
+#, gcc-internal-format
 msgid "virtual method %qD"
-msgstr "виртуальная функция %q+D"
+msgstr "виртуальный метод %qD"
 
 #: ipa-devirt.c:954
 #, gcc-internal-format
 msgid "ought to match virtual method %qD but does not"
-msgstr ""
+msgstr "должен соответствовать виртуальному методу %qD, но не соответствует"
 
 #: ipa-devirt.c:960
 #, gcc-internal-format
 msgid "the conflicting type defined in another translation unit has virtual table with different contents"
-msgstr ""
+msgstr "конфликтующий тип определенный в другой единице трансляции имеет виртуальную таблицу с другим содержимым"
 
 #: ipa-devirt.c:990
 #, gcc-internal-format
 msgid "type %qT violates the C++ One Definition Rule"
-msgstr ""
+msgstr "тип %qT нарушает C++ Правило Одного Определения"
 
 #: ipa-devirt.c:1001 ipa-devirt.c:1016 ipa-devirt.c:1266 ipa-devirt.c:1358
 #: ipa-devirt.c:1397 ipa-devirt.c:1415
-#, fuzzy, gcc-internal-format
-#| msgid "%q+D declared here, later in the translation unit"
+#, gcc-internal-format
 msgid "a different type is defined in another translation unit"
-msgstr "%q+D декларировано здесь, позднее в единице компиляции"
+msgstr "другой тип определен в другой единице трансляции"
 
 #: ipa-devirt.c:1008
 #, gcc-internal-format
 msgid "the first difference of corresponding definitions is field %qD"
-msgstr ""
+msgstr "первое отличие соответствующего определения есть поле %qD"
 
 #: ipa-devirt.c:1018
 #, gcc-internal-format
 msgid "the first difference of corresponding definitions is method %qD"
-msgstr ""
+msgstr "первое отличие соответствующего определения есть метод %qD"
 
 #: ipa-devirt.c:1112
 #, gcc-internal-format
 msgid "type %qT defined in anonymous namespace can not match type %qT across the translation unit boundary"
-msgstr ""
+msgstr "тип %qT определенный в анонимном пространстве имен не может соответствовать типу %qT в другой единице трансляции"
 
 #: ipa-devirt.c:1117
 #, gcc-internal-format
 msgid "type %qT defined in anonymous namespace can not match across the translation unit boundary"
-msgstr ""
+msgstr "тип %qT определенный в анонимном пространстве имен не может иметь соответствие в другой единице трансляции"
 
 #: ipa-devirt.c:1122
-#, fuzzy, gcc-internal-format
-#| msgid "incompatible types in binary expression"
+#, gcc-internal-format
 msgid "the incompatible type defined in another translation unit"
-msgstr "несовместимые типы в бинарном выражении"
+msgstr "несовместимый тип определен в другой единице трансляции"
 
 #: ipa-devirt.c:1145
-#, fuzzy, gcc-internal-format
-#| msgid "type %qT is not derived from type %qT"
+#, gcc-internal-format
 msgid "type name %qs should match type name %qs"
-msgstr "тип %qT не является производным от %qT"
+msgstr "имя типа %qs должно соответствовать имени типа %qs"
 
 #: ipa-devirt.c:1149 ipa-devirt.c:1241
-#, fuzzy, gcc-internal-format
-#| msgid "incompatible types in send"
+#, gcc-internal-format
 msgid "the incompatible type is defined here"
-msgstr "несовместимые типы в send"
+msgstr "несовместимый тип определен здесь"
 
 #: ipa-devirt.c:1177
-#, fuzzy, gcc-internal-format
-#| msgid "Array reference out of bounds"
+#, gcc-internal-format
 msgid "array types have different bounds"
-msgstr "Ссылка на массив выходит за границы"
+msgstr "типы массива имеют разные границы"
 
 #
 #: ipa-devirt.c:1192
-#, fuzzy, gcc-internal-format
-#| msgid "field initializer type mismatch"
+#, gcc-internal-format
 msgid "return value type mismatch"
-msgstr "несоответствие типа инициализатора поля"
+msgstr "несоответствие типа возвращаемого значения"
 
 #
 #: ipa-devirt.c:1207
-#, fuzzy, gcc-internal-format
-#| msgid "field initializer type mismatch"
+#, gcc-internal-format
 msgid "implicit this pointer type mismatch"
-msgstr "несоответствие типа инициализатора поля"
+msgstr "несоответствие типа неявного this указателя"
 
 #: ipa-devirt.c:1210
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "type mismatch in nontype parameter pack"
+#, gcc-internal-format, gfc-internal-format
 msgid "type mismatch in parameter %i"
-msgstr "несоответствие типов в нетиповом parameter pack"
+msgstr "несоответствие типов в параметре %i"
 
 #: ipa-devirt.c:1221
-#, fuzzy, gcc-internal-format
-#| msgid "different parameter types"
+#, gcc-internal-format
 msgid "types have different parameter counts"
-msgstr "разные типы параметров"
+msgstr "типы имеют разные счетчики параметров"
 
 #: ipa-devirt.c:1232
 #, gcc-internal-format
 msgid "type %qT itself violates the C++ One Definition Rule"
-msgstr ""
+msgstr "тип %qT сам по себе нарушает C++ Правило Одного Определения"
 
 #: ipa-devirt.c:1238
-#, fuzzy, gcc-internal-format
-#| msgid "type %qT is not derived from type %qT"
+#, gcc-internal-format
 msgid "type %qT should match type %qT"
-msgstr "тип %qT не является производным от %qT"
+msgstr "тип %qT должен соответствовать типу %qT"
 
 #: ipa-devirt.c:1273
 #, gcc-internal-format
 msgid "a type with different qualifiers is defined in another translation unit"
-msgstr ""
+msgstr "тип с другими квалификаторами определен в другой единице трансляции"
 
 #: ipa-devirt.c:1291
 #, gcc-internal-format
 msgid "a type with different attributes is defined in another translation unit"
-msgstr ""
+msgstr "тип с другими атрибутами определен в другой единице трансляции"
 
 #: ipa-devirt.c:1306
 #, gcc-internal-format
 msgid "an enum with different value name is defined in another translation unit"
-msgstr ""
+msgstr "перечисление с другим именем значения определено в другой единице трансляции"
 
 #: ipa-devirt.c:1315
 #, gcc-internal-format
 msgid "an enum with different values is defined in another translation unit"
-msgstr ""
+msgstr "перечисление с другими значениями определено в другой единице трансляции"
 
 #: ipa-devirt.c:1323
 #, gcc-internal-format
 msgid "an enum with mismatching number of values is defined in another translation unit"
-msgstr ""
+msgstr "перечисление с несоответствующим числом значений определено в другой единице трансляции"
 
 #: ipa-devirt.c:1341
 #, gcc-internal-format
 msgid "a type with different precision is defined in another translation unit"
-msgstr ""
+msgstr "тип с другой точностью определен в другой единице трансляции"
 
 #: ipa-devirt.c:1348
 #, gcc-internal-format
 msgid "a type with different signedness is defined in another translation unit"
-msgstr ""
+msgstr "тип с другой знаковостью определен в другой единице трансляции"
 
 #: ipa-devirt.c:1373
 #, gcc-internal-format
 msgid "it is defined as a pointer in different address space in another translation unit"
-msgstr ""
+msgstr "это определено как указатель в другом адресном пространстве в другой единице трансляции"
 
 #: ipa-devirt.c:1382
 #, gcc-internal-format
 msgid "it is defined as a pointer to different type in another translation unit"
-msgstr ""
+msgstr "это определено как указатель на другой тип в другой единице трансляции"
 
 #: ipa-devirt.c:1442
 #, gcc-internal-format
 msgid "an array of different size is defined in another translation unit"
-msgstr ""
+msgstr "массив другого размера определен в другой единице трансляции"
 
 #: ipa-devirt.c:1457
-#, fuzzy, gcc-internal-format
-#| msgid "%q+D declared here, later in the translation unit"
+#, gcc-internal-format
 msgid "has different return value in another translation unit"
-msgstr "%q+D декларировано здесь, позднее в единице компиляции"
+msgstr "имеет другое возвращаемое значение в другой единице трансляции"
 
 #: ipa-devirt.c:1480 ipa-devirt.c:1492
-#, fuzzy, gcc-internal-format
-#| msgid "%q+D declared here, later in the translation unit"
+#, gcc-internal-format
 msgid "has different parameters in another translation unit"
-msgstr "%q+D декларировано здесь, позднее в единице компиляции"
+msgstr "имеет другие параметры в другой единице трансляции"
 
 #: ipa-devirt.c:1515
 #, gcc-internal-format
 msgid "a type defined in another translation unit is not polymorphic"
-msgstr ""
+msgstr "тип определенный в другой единице трансляции не полиморфный"
 
 #: ipa-devirt.c:1519
 #, gcc-internal-format
 msgid "a type defined in another translation unit is polymorphic"
-msgstr ""
+msgstr "тип определенный в другой единице трансляции полиморфный"
 
 #: ipa-devirt.c:1537 ipa-devirt.c:1600
 #, gcc-internal-format
 msgid "a type with different virtual table pointers is defined in another translation unit"
-msgstr ""
+msgstr "тип с другими указателями виртуальной таблицы определен в другой единице трансляции"
 
 #: ipa-devirt.c:1544 ipa-devirt.c:1605
 #, gcc-internal-format
 msgid "a type with different bases is defined in another translation unit"
-msgstr ""
+msgstr "тип с другими базами определен в другой единице трансляции"
 
 #: ipa-devirt.c:1552
-#, fuzzy, gcc-internal-format
-#| msgid "%q+D declared here, later in the translation unit"
+#, gcc-internal-format
 msgid "a field with different name is defined in another translation unit"
-msgstr "%q+D декларировано здесь, позднее в единице компиляции"
+msgstr "поле с другим именем определено в другой единице трансляции"
 
 #: ipa-devirt.c:1566
 #, gcc-internal-format
 msgid "a field of same name but different type is defined in another translation unit"
-msgstr ""
+msgstr "поле с тем же именем, но другим типом определено в другой единице трансляции"
 
 #: ipa-devirt.c:1579
-#, fuzzy, gcc-internal-format
-#| msgid "%q+D declared here, later in the translation unit"
+#, gcc-internal-format
 msgid "fields have different layout in another translation unit"
-msgstr "%q+D декларировано здесь, позднее в единице компиляции"
+msgstr "поля имеют другое расположение в другой единице трансляции"
 
 #: ipa-devirt.c:1586
 #, gcc-internal-format
@@ -24246,71 +19981,70 @@
 #: ipa-devirt.c:1609
 #, gcc-internal-format
 msgid "a type with different number of fields is defined in another translation unit"
-msgstr ""
+msgstr "тип с другим числом полей определен в другой единице трансляции"
 
 #: ipa-devirt.c:1631
 #, gcc-internal-format
 msgid "a type with different size is defined in another translation unit"
-msgstr ""
+msgstr "тип с другим размером определен в другой единице трансляции"
 
 #: ipa-devirt.c:1639
 #, gcc-internal-format
 msgid "a type with different alignment is defined in another translation unit"
-msgstr ""
+msgstr "тип с другим выравниванием определен в другой единице трансляции"
 
 #: ipa-devirt.c:1762
-#, fuzzy, gcc-internal-format
-#| msgid "label %qD defined here"
+#, gcc-internal-format
 msgid "the extra base is defined here"
-msgstr "метка %qD определена здесь"
+msgstr "дополнительная база определена здесь"
 
 #: ipa-devirt.c:3798
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls"
-msgstr[0] ""
-msgstr[1] ""
-msgstr[2] ""
+msgstr[0] "Декларирование типа %qD final включит девиртуализацию %i вызова"
+msgstr[1] "Декларирование типа %qD final включит девиртуализацию %i вызовов"
+msgstr[2] "Декларирование типа %qD final включит девиртуализацию %i вызовов"
 
 #: ipa-devirt.c:3807
 #, gcc-internal-format
 msgid "Declaring type %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring type %qD final would enable devirtualization of %i calls executed %lli times"
-msgstr[0] ""
-msgstr[1] ""
-msgstr[2] ""
+msgstr[0] "Декларирование типа %qD final включит девиртуализацию %i вызова, выполненного %lli раз"
+msgstr[1] "Декларирование типа %qD final включит девиртуализацию %i вызова, выполненного %lli раза"
+msgstr[2] "Декларирование типа %qD final включит девиртуализацию %i вызова, выполненного %lli раза"
 
 #: ipa-devirt.c:3837
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls"
-msgstr[0] ""
-msgstr[1] ""
-msgstr[2] ""
+msgstr[0] "Декларирование виртуального деструктора %qD final включит девиртуализацию %i вызова"
+msgstr[1] "Декларирование виртуального деструктора %qD final включит девиртуализацию %i вызовов"
+msgstr[2] "Декларирование виртуального деструктора %qD final включит девиртуализацию %i вызовов"
 
 #: ipa-devirt.c:3845
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls"
-msgstr[0] ""
-msgstr[1] ""
-msgstr[2] ""
+msgstr[0] "Декларирование метода %qD final включит девиртуализацию %i вызова"
+msgstr[1] "Декларирование метода %qD final включит девиртуализацию %i вызовов"
+msgstr[2] "Декларирование метода %qD final включит девиртуализацию %i вызовов"
 
 #: ipa-devirt.c:3853
 #, gcc-internal-format
 msgid "Declaring virtual destructor of %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring virtual destructor of %qD final would enable devirtualization of %i calls executed %lli times"
-msgstr[0] ""
-msgstr[1] ""
-msgstr[2] ""
+msgstr[0] "Декларирование виртуального деструктора %qD final включит девиртуализацию %i вызова, выполненного %lli раз"
+msgstr[1] "Декларирование виртуального деструктора %qD final включит девиртуализацию %i вызова, выполненного %lli раз"
+msgstr[2] "Декларирование виртуального деструктора %qD final включит девиртуализацию %i вызова, выполненного %lli раз"
 
 #: ipa-devirt.c:3864
 #, gcc-internal-format
 msgid "Declaring method %qD final would enable devirtualization of %i call executed %lli times"
 msgid_plural "Declaring method %qD final would enable devirtualization of %i calls executed %lli times"
-msgstr[0] ""
-msgstr[1] ""
-msgstr[2] ""
+msgstr[0] "Декларирование метода %qD final включит девиртуализацию %i вызова, выполненного %lli раз"
+msgstr[1] "Декларирование метода %qD final включит девиртуализацию %i вызова, выполненного %lli раз"
+msgstr[2] "Декларирование метода %qD final включит девиртуализацию %i вызова, выполненного %lli раз"
 
 #: ipa-fnsummary.c:3371
 #, gcc-internal-format
@@ -24318,22 +20052,19 @@
 msgstr "во входном файле отсутствует информация о межпроцедурных inline-подстановках"
 
 #: ipa-hsa.c:57
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "%qE is neither function nor member function; cannot be declared friend"
+#, gcc-internal-format, gfc-internal-format
 msgid "could not emit HSAIL for function %s: function cannot be cloned"
-msgstr "%qE не является ни функцией, ни элементом-функцией; не может быть декларировано как friend"
+msgstr "невозможно породить HSAIL для функции %s: функция не может быть закрыта"
 
 #: ipa-pure-const.c:204
-#, fuzzy, gcc-internal-format
-#| msgid "function might be candidate for attribute %<%s%>"
+#, gcc-internal-format
 msgid "function might be candidate for attribute %qs"
-msgstr "функции, возможно, следует задать атрибут %<%s%>"
+msgstr "функции, возможно, следует задать атрибут %qs"
 
 #: ipa-pure-const.c:205
-#, fuzzy, gcc-internal-format
-#| msgid "function might be candidate for attribute %<%s%> if it is known to return normally"
+#, gcc-internal-format
 msgid "function might be candidate for attribute %qs if it is known to return normally"
-msgstr "функции, возможно, следует задать атрибут %<%s%>, если она нормально возвращает управление"
+msgstr "функции, возможно, следует задать атрибут %qs, если она нормально возвращает управление"
 
 #: ipa-reference.c:1174
 #, gcc-internal-format
@@ -24348,13 +20079,12 @@
 #: ira.c:5551
 #, gcc-internal-format
 msgid "frame pointer required, but reserved"
-msgstr ""
+msgstr "указатель кадра требуется, но зарезервирован"
 
 #: ira.c:5552
-#, fuzzy, gcc-internal-format
-#| msgid "as %qD"
+#, gcc-internal-format
 msgid "for %qD"
-msgstr "как %qD"
+msgstr "для %qD"
 
 #: ira.c:5566
 #, gcc-internal-format
@@ -24372,10 +20102,9 @@
 msgstr "для операнда %<asm%> заданы недопустимые ограничения"
 
 #: lra-assigns.c:1809
-#, fuzzy, gcc-internal-format
-#| msgid "unable to find a register to spill in class %qs"
+#, gcc-internal-format
 msgid "unable to find a register to spill"
-msgstr "не найден регистр класса %qs для выталкивания в память"
+msgstr "не найден регистр для выталкивания в память"
 
 #: lra-constraints.c:3913 reload.c:3815 reload.c:4070
 #, gcc-internal-format
@@ -24385,54 +20114,52 @@
 #: lra-constraints.c:4821
 #, gcc-internal-format, gfc-internal-format
 msgid "Max. number of generated reload insns per insn is achieved (%d)\n"
-msgstr ""
+msgstr "Макс. number of generated reload insns per insn is achieved (%d)\n"
 
-#: lto-cgraph.c:1294
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "bytecode stream: found multiple instances of cgraph node %d"
+#: lto-cgraph.c:1296
+#, gcc-internal-format, gfc-internal-format
 msgid "bytecode stream: found multiple instances of cgraph node with uid %d"
-msgstr "поток байткода: найдено несколько копий cgraph узла %d"
+msgstr "поток байткода: найдено несколько экземпляров cgraph узла с uid %d"
 
-#: lto-cgraph.c:1472
+#: lto-cgraph.c:1474
 #, gcc-internal-format
 msgid "bytecode stream: no caller found while reading edge"
 msgstr "поток байткода: не найден вызывающий при чтении дуги"
 
-#: lto-cgraph.c:1478
+#: lto-cgraph.c:1480
 #, gcc-internal-format
 msgid "bytecode stream: no callee found while reading edge"
 msgstr "поток байткода: не найден вызываемый при чтении дуги"
 
-#: lto-cgraph.c:1552
+#: lto-cgraph.c:1554
 #, gcc-internal-format
 msgid "bytecode stream: found empty cgraph node"
 msgstr "поток байткода: найден пустой cgraph узел"
 
-#: lto-cgraph.c:1730
+#: lto-cgraph.c:1732
 #, gcc-internal-format, gfc-internal-format
 msgid "At most %i profile runs is supported. Perhaps corrupted profile?"
-msgstr "Не более %i профильных запусков поддерживается. Возможно поврежден профиль?"
+msgstr ""
 
-#: lto-cgraph.c:1817
+#: lto-cgraph.c:1819
 #, gcc-internal-format, gfc-internal-format
 msgid "Profile information in %s corrupted"
 msgstr "Данные профилирование в %s испорчены"
 
-#: lto-cgraph.c:1855
+#: lto-cgraph.c:1857
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO cgraph in %s"
 msgstr "не найден граф вызовов LTO в %s"
 
-#: lto-cgraph.c:1865
+#: lto-cgraph.c:1867
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO section refs in %s"
 msgstr "невозможно найти ссылки на LTO секцию в %s"
 
-#: lto-cgraph.c:1946
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "invalid rotate insn"
+#: lto-cgraph.c:1948
+#, gcc-internal-format, gfc-internal-format
 msgid "invalid offload table in %s"
-msgstr "некорректная инструкция rotate"
+msgstr "некорректная таблица разгрузки в %s"
 
 #: lto-compress.c:193 lto-compress.c:201 lto-compress.c:222 lto-compress.c:285
 #: lto-compress.c:293 lto-compress.c:314
@@ -24456,39 +20183,34 @@
 msgstr "поток байткода: неожиданный тег %s"
 
 #: lto-streamer-in.c:900 lto-streamer-in.c:910
-#, fuzzy, gcc-internal-format
-#| msgid "machine independent builtin code out of range"
+#, gcc-internal-format
 msgid "Cgraph edge statement index out of range"
-msgstr "машинно независимый встроенный код вне диапазона"
+msgstr "Индекс оператора ребра C-графа вне диапазона"
 
 #: lto-streamer-in.c:904 lto-streamer-in.c:913
 #, gcc-internal-format
 msgid "Cgraph edge statement index not found"
-msgstr ""
+msgstr "Индекс оператора ребра C-графа не найден"
 
 #: lto-streamer-in.c:920
-#, fuzzy, gcc-internal-format
-#| msgid "operand number out of range"
+#, gcc-internal-format
 msgid "Reference statement index out of range"
-msgstr "номер операнда вне диапазона"
+msgstr "Индекс оператора ссылки вне диапазона"
 
 #: lto-streamer-in.c:923
-#, fuzzy, gcc-internal-format
-#| msgid "expected statement at end of input"
+#, gcc-internal-format
 msgid "Reference statement index not found"
-msgstr "ожидался оператор в конце входного потока"
+msgstr "Индекс оператора ссылки не найден"
 
 #: lto-streamer-in.c:1595
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "cannot read LTO decls from %s"
+#, gcc-internal-format, gfc-internal-format
 msgid "cannot read LTO mode table from %s"
-msgstr "ошибка чтения LTO деклараций из %s"
+msgstr "ошибка чтения LTO таблицы режимов из %s"
 
 #: lto-streamer-in.c:1694
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "support for mode %qs"
+#, gcc-internal-format, gfc-internal-format
 msgid "unsupported mode %s\n"
-msgstr "поддержка моды %qs"
+msgstr ""
 
 #: lto-streamer-out.c:442 lto-streamer-out.c:686
 #, gcc-internal-format
@@ -24498,450 +20220,418 @@
 #: lto-streamer.c:162
 #, gcc-internal-format, gfc-internal-format
 msgid "bytecode stream: unexpected LTO section %s"
-msgstr "байткод: некорректная секция %s"
+msgstr "поток байткода: неожиданная LTO секция %s"
 
 #: lto-streamer.c:291
-#, fuzzy, gcc-internal-format
-#| msgid "bytecode stream generated with LTO version %d.%d instead of the expected %d.%d"
+#, gcc-internal-format
 msgid "bytecode stream in file %qs generated with LTO version %d.%d instead of the expected %d.%d"
-msgstr "байткод сгенерирован LTO версии %d.%d вместо ожидаемой %d.%d"
+msgstr "поток байткода в файле %qs сгенерирован с LTO версии %d.%d вместо ожидаемой %d.%d"
 
-#: lto-wrapper.c:117
-#, fuzzy, gcc-internal-format
-#| msgid "deleting LTRANS file %s"
+#: lto-wrapper.c:118
+#, gcc-internal-format
 msgid "deleting LTRANS file %s: %m"
-msgstr "удаляется файл LTRANS %s"
+msgstr "удаляется LTRANS файл %s: %m"
 
-#: lto-wrapper.c:154
+#: lto-wrapper.c:155
 #, gcc-internal-format
 msgid "malformed COLLECT_GCC_OPTIONS"
 msgstr "неверно сформирован COLLECT_GCC_OPTIONS"
 
-#: lto-wrapper.c:308
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "created and used with different endianness"
+#: lto-wrapper.c:309
+#, gcc-internal-format, gfc-internal-format
 msgid "Option %s with different values"
-msgstr "создан с одним значением endianness, а используется с другим"
+msgstr "Опция %s с другими значениями"
 
-#: lto-wrapper.c:392
+#: lto-wrapper.c:393
 #, gcc-internal-format, gfc-internal-format
 msgid "Option %s not used consistently in all LTO input files"
-msgstr ""
+msgstr "Опция %s не использована согласовано во всех LTO входных файлах"
 
-#: lto-wrapper.c:832
+#: lto-wrapper.c:833
 #, gcc-internal-format, gfc-internal-format
 msgid "problem with building target image for %s\n"
 msgstr ""
 
-#: lto-wrapper.c:852
-#, fuzzy, gcc-internal-format
-#| msgid "no input files"
+#: lto-wrapper.c:853
+#, gcc-internal-format
 msgid "reading input file"
-msgstr "не заданы входные файлы"
+msgstr "чтение входного файла"
 
-#: lto-wrapper.c:857
-#, fuzzy, gcc-internal-format
-#| msgid "Error writing output file '%s'\n"
+#: lto-wrapper.c:858
+#, gcc-internal-format
 msgid "writing output file"
-msgstr "Ошибка записи в выходной файл '%s'\n"
+msgstr "запись выходного файла"
 
-#: lto-wrapper.c:889
+#: lto-wrapper.c:890
 #, gcc-internal-format
 msgid "installation error, can't find crtoffloadtable.o"
-msgstr ""
+msgstr "ошибка инсталляции, не удается найти crtoffloadtable.o"
 
-#: lto-wrapper.c:1000 lto-wrapper.c:1012
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "%s: %s"
+#: lto-wrapper.c:1001 lto-wrapper.c:1013
+#, gcc-internal-format, gfc-internal-format
 msgid "%s: %s\n"
-msgstr "%s: %s"
+msgstr "%s: %s\n"
 
-#: lto-wrapper.c:1056
+#: lto-wrapper.c:1064
 #, gcc-internal-format
 msgid "environment variable COLLECT_GCC must be set"
 msgstr "переменная окружения COLLECT_GCC должна быть определена"
 
-#: lto-wrapper.c:1060 config/nvptx/mkoffload.c:363
+#: lto-wrapper.c:1068 config/nvptx/mkoffload.c:363
 #, gcc-internal-format
 msgid "environment variable COLLECT_GCC_OPTIONS must be set"
 msgstr "переменная окружения COLLECT_GCC_OPTIONS должна быть определена"
 
-#: lto-wrapper.c:1229 lto-wrapper.c:1285
-#, fuzzy, gcc-internal-format
-#| msgid "can't open %s: %m"
+#: lto-wrapper.c:1237 lto-wrapper.c:1293
+#, gcc-internal-format
 msgid "cannot open %s: %m"
-msgstr "ошибка открытия %s: %m"
+msgstr "невозможно открыть %s: %m"
 
-#: lto-wrapper.c:1232 lto-wrapper.c:1291
-#, fuzzy, gcc-internal-format
-#| msgid "can%'t read %s: %m"
+#: lto-wrapper.c:1240 lto-wrapper.c:1299
+#, gcc-internal-format
 msgid "cannot read %s: %m"
-msgstr "ошибка чтения %s: %m"
+msgstr "невозможно прочитать %s: %m"
 
-#: lto-wrapper.c:1259
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "invalid operation (%s)"
+#: lto-wrapper.c:1267
+#, gcc-internal-format, gfc-internal-format
 msgid "invalid format of %s"
-msgstr "некорректная операция (%s)"
+msgstr "некорректный формат %s"
 
-#: lto-wrapper.c:1482
-#, fuzzy, gcc-internal-format
-#| msgid "fopen %s: %m"
+#: lto-wrapper.c:1491
+#, gcc-internal-format
 msgid "fopen: %s: %m"
-msgstr "fopen %s: %m"
+msgstr "fopen: %s: %m"
 
+#: lto-wrapper.c:1508
+#, gcc-internal-format, gfc-internal-format
+msgid "Corrupted ltrans output file %s"
+msgstr ""
+
 #: multiple_target.c:76
-#, fuzzy, gcc-internal-format
-#| msgid "nested functions not supported on this target"
+#, gcc-internal-format
 msgid "the call requires ifunc, which is not supported by this target"
-msgstr "вложенные функции не поддерживаются для этой платформы"
+msgstr "вызов требует ifunc, которая не поддерживается этой целью"
 
 #: multiple_target.c:83
-#, fuzzy, gcc-internal-format
-#| msgid "target CPU does not support unaligned accesses"
+#, gcc-internal-format
 msgid "target does not support function version dispatcher"
-msgstr "целевой процессор не поддерживает невыровненные доступы"
+msgstr "цель не поддерживает диспетчер версий функций"
 
 #: multiple_target.c:91
-#, fuzzy, gcc-internal-format
-#| msgid "version attribute is not a string"
+#, gcc-internal-format
 msgid "default %<target_clones%> attribute was not set"
-msgstr "атрибут версии не строка"
+msgstr ""
 
 #: multiple_target.c:343
-#, fuzzy, gcc-internal-format
-#| msgid "%qE incompatible attribute ignored"
+#, gcc-internal-format
 msgid "single %<target_clones%> attribute is ignored"
-msgstr "несовместимый атрибут %qE игнорируется"
+msgstr ""
 
 #: multiple_target.c:351
-#, fuzzy, gcc-internal-format
-#| msgid "version attribute is not a string"
+#, gcc-internal-format
 msgid "clones for %<target_clones%> attribute cannot be created"
-msgstr "атрибут версии не строка"
+msgstr ""
 
 #: multiple_target.c:354
-#, fuzzy, gcc-internal-format
-#| msgid "function %q+F can never be copied because it receives a non-local goto"
+#, gcc-internal-format
 msgid "function %q+F can never be copied because it has %<noclone%> attribute"
-msgstr "функция %q+F не может быть скопирована, поскольку имеют нелокальные переходы в эту функцию"
+msgstr ""
 
 #: multiple_target.c:371
-#, fuzzy, gcc-internal-format
-#| msgid "default argument %qE uses %qD"
+#, gcc-internal-format
 msgid "default target was not set"
-msgstr "аргумент по умолчанию %qE использует %qD"
+msgstr "подразумеваемая цель не была установлен"
 
 #: multiple_target.c:379
-#, fuzzy, gcc-internal-format
-#| msgid "missing %<=%> (after %<getter%> attribute)"
+#, gcc-internal-format
 msgid "an empty string cannot be in %<target_clones%> attribute"
-msgstr "отсутствует %<=%> (после атрибута %<getter%>)"
+msgstr ""
 
 #: omp-expand.c:2016
 #, gcc-internal-format
 msgid "%<depend(sink)%> clause waiting for lexically later iteration"
-msgstr ""
+msgstr "%<depend(sink)%> клаузула ждет лексически более поздней итерации"
 
 #: omp-expand.c:2153
 #, gcc-internal-format
 msgid "%<depend(sink)%> refers to iteration never in the iteration space"
-msgstr ""
+msgstr "%<depend(sink)%> ссылается на итерацию отсутствующую в пространстве итераций"
 
 #: omp-general.c:588
-#, fuzzy, gcc-internal-format
-#| msgid "storage class specified for typename"
+#, gcc-internal-format
 msgid "multiple loop axes specified for routine"
-msgstr "класс хранения задан для имени типа"
+msgstr "несколько осей циклов задано для программы"
 
 #: omp-low.c:2098 omp-offload.c:1145
 #, gcc-internal-format
 msgid "%<seq%> overrides other OpenACC loop specifiers"
-msgstr ""
+msgstr "%<seq%> переопределяет другие OpenACC спецификаторы циклов"
 
 #: omp-low.c:2101 omp-offload.c:1146
 #, gcc-internal-format
 msgid "%<auto%> conflicts with other OpenACC loop specifiers"
-msgstr ""
+msgstr "%<auto%> конфликтует с другими OpenACC спецификаторами циклов"
 
 #: omp-low.c:2105 omp-offload.c:1180
 #, gcc-internal-format
 msgid "inner loop uses same OpenACC parallelism as containing loop"
-msgstr ""
+msgstr "внутренний цикл использует тот же OpenACC параллелизм, что и объемлющий"
 
 #: omp-low.c:2152
 #, gcc-internal-format
 msgid "argument not permitted on %qs clause in OpenACC %<parallel%>"
-msgstr ""
+msgstr "аргумент недопустим в %qs клаузуле в OpenACC %<parallel%>"
 
 #: omp-low.c:2420
 #, gcc-internal-format
 msgid "non-OpenACC construct inside of OpenACC routine"
-msgstr ""
+msgstr "не-OpenACC конструкция внутри OpenACC подпрограммы"
 
 #: omp-low.c:2429
 #, gcc-internal-format
 msgid "non-OpenACC construct inside of OpenACC region"
-msgstr ""
+msgstr "не-OpenACC конструкция внутри OpenACC области"
 
 #: omp-low.c:2454
-#, fuzzy, gcc-internal-format
-#| msgid "ordered region may not be closely nested inside of critical or explicit task region"
+#, gcc-internal-format
 msgid "%<ordered simd threads%> must be closely nested inside of %<for simd%> region"
-msgstr "ordered область не может быть тесно вложена внутри critical, или explicit task области"
+msgstr "%<ordered simd threads%> должна быть замкнуто вложена внутри %<for simd%> области"
 
 #: omp-low.c:2462
 #, gcc-internal-format
 msgid "OpenMP constructs other than %<#pragma omp ordered simd%> may not be nested inside %<simd%> region"
-msgstr ""
+msgstr "OpenMP конструкция отличная от %<#pragma omp ordered simd%> не может быть вложена в %<simd%> области"
 
 #: omp-low.c:2474
 #, gcc-internal-format
 msgid "only %<distribute%> or %<parallel%> regions are allowed to be strictly nested inside %<teams%> region"
-msgstr ""
+msgstr "только %<distribute%> или %<parallel%> области могут быть строго вложены в %<teams%> области"
 
 #: omp-low.c:2491
 #, gcc-internal-format
 msgid "%<distribute%> region must be strictly nested inside %<teams%> construct"
-msgstr ""
+msgstr "%<distribute%> область должна быть строго вложена в %<teams%> конструкции"
 
 #: omp-low.c:2532
 #, gcc-internal-format
 msgid "OpenACC loop directive must be associated with an OpenACC compute region"
-msgstr ""
+msgstr "OpenACC директива цикла должна быть ассоциирована с OpenACC вычислительной областью"
 
 #: omp-low.c:2554
 #, gcc-internal-format
 msgid "orphaned %qs construct"
-msgstr ""
+msgstr "зависшая %qs конструкция"
 
 #: omp-low.c:2583
 #, gcc-internal-format
 msgid "%<#pragma omp cancel for%> inside %<nowait%> for construct"
-msgstr ""
+msgstr "%<#pragma omp cancel for%> внутри %<nowait%> для конструкции"
 
 #: omp-low.c:2588
 #, gcc-internal-format
 msgid "%<#pragma omp cancel for%> inside %<ordered%> for construct"
-msgstr ""
+msgstr "%<#pragma omp cancel for%> внутри %<ordered%> для конструкции"
 
 #: omp-low.c:2608 omp-low.c:2621
-#, fuzzy, gcc-internal-format
-#| msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
+#, gcc-internal-format
 msgid "%<#pragma omp cancel sections%> inside %<nowait%> sections construct"
-msgstr "%<#pragma omp section%> может использоваться только в конструкции %<#pragma omp sections%>"
+msgstr "%<#pragma omp cancel section%> внутри %<nowait%> sections конструкции"
 
 #: omp-low.c:2647
 #, gcc-internal-format
 msgid "%<%s taskgroup%> construct not closely nested inside of %<taskgroup%> region"
-msgstr ""
+msgstr "%<%s taskgroup%> конструкция не вложена замкнуто в %<taskgroup%> области"
 
 #: omp-low.c:2661
-#, fuzzy, gcc-internal-format
-#| msgid "invalid PHI argument"
+#, gcc-internal-format
 msgid "invalid arguments"
-msgstr "некорректный аргумент PHI"
+msgstr "некорректные аргументы"
 
 #: omp-low.c:2667
 #, gcc-internal-format
 msgid "%<%s %s%> construct not closely nested inside of %qs"
-msgstr ""
+msgstr "%<%s %s%> конструкция не вложена замкнуто в области %qs"
 
 #: omp-low.c:2695
-#, fuzzy, gcc-internal-format
-#| msgid "barrier region may not be closely nested inside of work-sharing, critical, ordered, master or explicit task region"
+#, gcc-internal-format
 msgid "barrier region may not be closely nested inside of work-sharing, %<critical%>, %<ordered%>, %<master%>, explicit %<task%> or %<taskloop%> region"
-msgstr "область барьера не может быть тесно вложена внутри work-sharing. critical, ordered, master или explicit task области"
+msgstr "область барьера не может быть замкнуто вложена внутри work-sharing. %<critical%>, %<ordered%>, %<master%>, explicit %<task%> или %<taskloop%> области"
 
 #: omp-low.c:2702
-#, fuzzy, gcc-internal-format
-#| msgid "work-sharing region may not be closely nested inside of work-sharing, critical, ordered, master or explicit task region"
+#, gcc-internal-format
 msgid "work-sharing region may not be closely nested inside of work-sharing, %<critical%>, %<ordered%>, %<master%>, explicit %<task%> or %<taskloop%> region"
-msgstr "work-sharing область не может быть тесно вложена внутри work-sharing, critical, ordered, master или explicit task области"
+msgstr "work-sharing область не может быть замкнуто вложена внутри work-sharing, %<critical%>, %<ordered%>, %<master%>, explicit %<task%> или %<taskloop%> области"
 
 #: omp-low.c:2731
-#, fuzzy, gcc-internal-format
-#| msgid "master region may not be closely nested inside of work-sharing or explicit task region"
+#, gcc-internal-format
 msgid "%<master%> region may not be closely nested inside of work-sharing, explicit %<task%> or %<taskloop%> region"
-msgstr "master область не может быть тесно вложена внутри work-sharing или explicit task области"
+msgstr "%<master%> область не может быть замкнуто вложена внутри work-sharing, explicit task или %<taskloop%> области"
 
 #: omp-low.c:2755 omp-low.c:2894
 #, gcc-internal-format
 msgid "%<depend(%s)%> is only allowed in %<omp ordered%>"
-msgstr ""
+msgstr "%<depend(%s)%> допускается только в %<omp ordered%>"
 
 #: omp-low.c:2783
-#, fuzzy, gcc-internal-format
-#| msgid "ordered region must be closely nested inside a loop region with an ordered clause"
+#, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside an %<ordered%> loop"
-msgstr "ordered область должна быть тесно вложена внутри области цикла с ordered клаузулой"
+msgstr "%<ordered%> конструкция с %<depend%> клаузулой должна быть замкнуто вложена внутри %<ordered%> цикла"
 
 #: omp-low.c:2800
-#, fuzzy, gcc-internal-format
-#| msgid "invalid schedule kind before %<decltype%>"
+#, gcc-internal-format
 msgid "invalid depend kind in omp %<ordered%> %<depend%>"
-msgstr "некорректный тип планирования перед %<decltype%>"
+msgstr "некорректный depend вид в omp %<ordered%> %<depend%>"
 
 #: omp-low.c:2815
-#, fuzzy, gcc-internal-format
-#| msgid "ordered region must be closely nested inside a loop region with an ordered clause"
+#, gcc-internal-format
 msgid "%<ordered%> %<simd%> must be closely nested inside %<simd%> region"
-msgstr "ordered область должна быть тесно вложена внутри области цикла с ordered клаузулой"
+msgstr "%<ordered%> %<simd%>  должно быть замкнуто вложена внутри %<simd%> области"
 
 #: omp-low.c:2828
-#, fuzzy, gcc-internal-format
-#| msgid "ordered region may not be closely nested inside of critical or explicit task region"
+#, gcc-internal-format
 msgid "%<ordered%> region may not be closely nested inside of %<critical%>, %<ordered%>, explicit %<task%> or %<taskloop%> region"
-msgstr "ordered область не может быть тесно вложена внутри critical, или explicit task области"
+msgstr "%<ordered%> область не может быть замкнуто вложена внутри %<critical%>, %<ordered%>, explicit %<task%> или %<taskloop%> области"
 
 #: omp-low.c:2839 omp-low.c:2852
-#, fuzzy, gcc-internal-format
-#| msgid "ordered region must be closely nested inside a loop region with an ordered clause"
+#, gcc-internal-format
 msgid "%<ordered%> region must be closely nested inside a loop region with an %<ordered%> clause"
-msgstr "ordered область должна быть тесно вложена внутри области цикла с ordered клаузулой"
+msgstr "%<ordered%> область должна быть замкнуто вложена внутри области цикла с %<ordered%> клаузулой"
 
 #: omp-low.c:2869
-#, fuzzy, gcc-internal-format
-#| msgid "critical region may not be nested inside a critical region with the same name"
+#, gcc-internal-format
 msgid "%<critical%> region may not be nested inside a %<critical%> region with the same name"
-msgstr "critical область не может быть вложена внутри critical области с тем же именем"
+msgstr "%<critical%> область не может быть вложена внутри %<critical%> области с тем же именем"
 
 #: omp-low.c:2881
 #, gcc-internal-format
 msgid "%<teams%> construct not closely nested inside of %<target%> construct"
-msgstr ""
+msgstr "%<teams%> конструкция не вложена замкнуто в %<target%> конструкции"
 
 #: omp-low.c:2902
 #, gcc-internal-format
 msgid "OpenACC region inside of OpenACC routine, nested parallelism not supported yet"
-msgstr ""
+msgstr "OpenACC область внутри OpenACC подпрограммы, вложенный параллелизм пока не поддерживается"
 
 #: omp-low.c:2915
 #, gcc-internal-format
 msgid "OpenACC construct inside of non-OpenACC region"
-msgstr ""
+msgstr "OpenACC конструкция внутри не-OpenACC области"
 
 #: omp-low.c:2960
 #, gcc-internal-format
 msgid "%s %qs construct inside of %s %qs region"
-msgstr ""
+msgstr "%s %qs конструкция внутри %s %qs области"
 
 #: omp-low.c:2973 omp-low.c:2980
 #, gcc-internal-format
 msgid "%qs construct inside of %qs region"
-msgstr ""
+msgstr "%qs конструкция внутри %qs области"
 
 #: omp-low.c:3092
 #, gcc-internal-format
 msgid "setjmp/longjmp inside simd construct"
-msgstr ""
+msgstr "setjmp/longjmp внутри simd конструкции"
 
 #: omp-low.c:6377
 #, gcc-internal-format
 msgid "ignoring sink clause with offset that is not a multiple of the loop step"
-msgstr ""
+msgstr "игнорирование sink клаузулу со смещением, не кратным шагу цикла"
 
 #: omp-low.c:6400
 #, gcc-internal-format
 msgid "first offset must be in opposite direction of loop iterations"
-msgstr ""
+msgstr "первое смещение должно быть в противоположном направлении от итераций цикла"
 
 #: omp-low.c:9133
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "invalid exit from OpenMP structured block"
+#, gcc-internal-format, gfc-internal-format
 msgid "invalid exit from %s structured block"
-msgstr "некорректный выход из OpenMP структурного блока"
+msgstr "некорректный выход из %s структурного блока"
 
 #: omp-low.c:9135 omp-low.c:9140
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "invalid entry to OpenMP structured block"
+#, gcc-internal-format, gfc-internal-format
 msgid "invalid entry to %s structured block"
-msgstr "некорректный вход в OpenMP структурный блок"
+msgstr "некорректный вход в %s структурный блок"
 
 #. Otherwise, be vague and lazy, but efficient.
 #: omp-low.c:9144
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "invalid branch to/from an OpenMP structured block"
+#, gcc-internal-format, gfc-internal-format
 msgid "invalid branch to/from %s structured block"
-msgstr "некорректная ветка в/из структурного блока OpenMP"
+msgstr "некорректное ветвление в/из %s структурного блока"
 
 #: omp-offload.c:628
 #, gcc-internal-format, gfc-internal-format
 msgid "-fopenacc-dim operand is malformed at '%s'"
-msgstr ""
+msgstr "-fopenacc-dim операнд искажен в '%s'"
 
 #: omp-offload.c:1178
 #, gcc-internal-format
 msgid "routine call uses same OpenACC parallelism as containing loop"
-msgstr ""
+msgstr "вызов подпрограммы использует тот же OpenACC параллелизм, что и объемлющий цикл"
 
 #: omp-offload.c:1182 omp-offload.c:1214
 #, gcc-internal-format
 msgid "containing loop here"
-msgstr ""
+msgstr "объемлющий цикл здесь"
 
 #: omp-offload.c:1187
 #, gcc-internal-format
 msgid "routine call uses OpenACC parallelism disallowed by containing routine"
-msgstr ""
+msgstr "вызов подпрограммы использует OpenACC параллелизм, запрещенный объемлющей подпрограммой"
 
 #: omp-offload.c:1189
 #, gcc-internal-format
 msgid "loop uses OpenACC parallelism disallowed by containing routine"
-msgstr ""
+msgstr "цикл использует OpenACC параллелизм, запрещенный объемлющей подпрограммой"
 
 #: omp-offload.c:1194
-#, fuzzy, gcc-internal-format
-#| msgid "%qD declared here"
+#, gcc-internal-format
 msgid "routine %qD declared here"
-msgstr "%qD объявлено здесь"
+msgstr "программа %qD декларирована здесь"
 
 #: omp-offload.c:1207
 #, gcc-internal-format
 msgid "incorrectly nested OpenACC loop parallelism"
-msgstr ""
+msgstr "некорректно вложенный OpenACC параллелизм циклов"
 
 #: omp-offload.c:1348
 #, gcc-internal-format
 msgid "insufficient partitioning available to parallelize element loop"
-msgstr ""
+msgstr "недостаточно разбиений для распараллеливания элементарного цикла"
 
 #: omp-offload.c:1356
 #, gcc-internal-format
 msgid "insufficient partitioning available to parallelize tile loop"
-msgstr ""
+msgstr "недостаточно разбиений для распараллеливания мозаичного цикла"
 
 #: omp-offload.c:1358
 #, gcc-internal-format
 msgid "insufficient partitioning available to parallelize loop"
-msgstr ""
+msgstr "недостаточно разбиений для распараллеливания цикла"
 
 #: omp-simd-clone.c:194
-#, fuzzy, gcc-internal-format
-#| msgid "ignoring duplicate directory \"%s\"\n"
+#, gcc-internal-format
 msgid "ignoring large linear step"
-msgstr "повторное задание каталога \"%s\" проигнорировано\n"
+msgstr "игнорирование большого линейного шага"
 
 #: omp-simd-clone.c:201
 #, gcc-internal-format
 msgid "ignoring zero linear step"
-msgstr ""
+msgstr "игнорирование нулевого линейного шага"
 
 #: omp-simd-clone.c:260
 #, gcc-internal-format
 msgid "ignoring %<#pragma omp declare simd%> on function with %<_Atomic%> qualified return type"
-msgstr ""
+msgstr "игнорирование %<#pragma omp declare simd%> в функции с %<_Atomic%> квалифицированным типом возврата"
 
 #: omp-simd-clone.c:271
 #, gcc-internal-format
 msgid "ignoring %<#pragma omp declare simd%> on function with %<_Atomic%> qualified non-%<uniform%> argument"
-msgstr ""
+msgstr "игнорирование %<#pragma omp declare simd%> в функции с %<_Atomic%> квалифицированным не-%<uniform%> аргументом"
 
 #: optabs.c:4246
-#, fuzzy, gcc-internal-format
-#| msgid "BYTE type used at %C is not available on the target machine"
+#, gcc-internal-format
 msgid "indirect jumps are not available on this target"
-msgstr "BYTE тип использованный в %C не доступен на целевой машине"
+msgstr "косвенные переходы отсутствуют на этой платформе"
 
 #: opts-common.c:1150
 #, gcc-internal-format
@@ -24959,10 +20649,9 @@
 msgstr "аргумент %qs должен быть неотрицательным целым числом"
 
 #: opts-common.c:1173
-#, fuzzy, gcc-internal-format
-#| msgid "-malign-functions=%d is not between 0 and %d"
+#, gcc-internal-format
 msgid "argument to %qs is not between %d and %d"
-msgstr "-malign-loops=%d не между 0 и %d"
+msgstr ""
 
 #: opts-common.c:1187
 #, gcc-internal-format
@@ -24969,13 +20658,12 @@
 msgid "unrecognized argument in option %qs"
 msgstr "некорректный аргумент ключа %qs"
 
-#: opts-common.c:1198 config/i386/i386.c:3206
-#, fuzzy, gcc-internal-format
-#| msgid "valid arguments to %qs are: %s"
+#: opts-common.c:1198 config/i386/i386.c:3209
+#, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
-msgstr "допустимые аргументы %qs: %s"
+msgstr "допустимые аргументы для %qs: %s; имелось в виду %qs?"
 
-#: opts-common.c:1201 config/i386/i386.c:3209
+#: opts-common.c:1201 config/i386/i386.c:3212
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "допустимые аргументы %qs: %s"
@@ -24997,10 +20685,9 @@
 msgstr "некорректный ключ %<-fdump-%s%>"
 
 #: opts-global.c:380
-#, fuzzy, gcc-internal-format
-#| msgid "unrecognized command line option %<-fdump-%s%>"
+#, gcc-internal-format
 msgid "unrecognized command line option %<-fopt-info-%s%>"
-msgstr "некорректный ключ %<-fdump-%s%>"
+msgstr "неопознанная опция командной строки %<-fopt-info-%s%>"
 
 #: opts-global.c:401 opts-global.c:409
 #, gcc-internal-format
@@ -25015,13 +20702,12 @@
 #: opts-global.c:451
 #, gcc-internal-format
 msgid "-fasan-shadow-offset should only be used with -fsanitize=kernel-address"
-msgstr ""
+msgstr "-fasan-shadow-offset следует использовать только с -fsanitize=kernel-address"
 
 #: opts-global.c:454
-#, fuzzy, gcc-internal-format
-#| msgid "unrecognized address"
+#, gcc-internal-format
 msgid "unrecognized shadow offset %qs"
-msgstr "некорректный адрес"
+msgstr "неопознанное теневое смещение %qs"
 
 #: opts.c:90
 #, gcc-internal-format
@@ -25039,10 +20725,9 @@
 msgstr "%<-femit-struct-debug-detailed=dir:...%> должно позволять не меньше чем %<-femit-struct-debug-detailed=ind:...%>"
 
 #: opts.c:589
-#, fuzzy, gcc-internal-format
-#| msgid "argument to %qs should be a non-negative integer"
+#, gcc-internal-format
 msgid "argument to %<-O%> should be a non-negative integer, %<g%>, %<s%> or %<fast%>"
-msgstr "аргумент %qs должен быть неотрицательным целым числом"
+msgstr "аргумент %<-O%> должен быть неотрицательным целым числом, %<g%>, %<s%> или %<fast%>"
 
 #: opts.c:752
 #, gcc-internal-format
@@ -25062,31 +20747,27 @@
 #: opts.c:785
 #, gcc-internal-format
 msgid "section anchors must be disabled when toplevel reorder is disabled"
-msgstr "опорные точки секций нельзя использовать если не включено переупорядочение на верхнем уровне"
+msgstr "опорные точки секций нельзя использовать, если не включено переупорядочение на верхнем уровне"
 
 #: opts.c:840
-#, fuzzy, gcc-internal-format
-#| msgid "-freorder-blocks-and-partition does not work with exceptions on this architecture"
+#, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> does not work with exceptions on this architecture"
-msgstr "-freorder-blocks-and-partition не работает с исключениями для заданной архитектуры"
+msgstr ""
 
 #: opts.c:856
-#, fuzzy, gcc-internal-format
-#| msgid "-freorder-blocks-and-partition does not support unwind info on this architecture"
+#, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> does not support unwind info on this architecture"
-msgstr "-freorder-blocks-and-partition не поддерживает данные раскрутки для заданной архитектуры"
+msgstr ""
 
 #: opts.c:874
-#, fuzzy, gcc-internal-format
-#| msgid "-freorder-blocks-and-partition does not work on this architecture"
+#, gcc-internal-format
 msgid "%<-freorder-blocks-and-partition%> does not work on this architecture"
-msgstr "-freorder-blocks-and-partition не работает для заданной архитектуры"
+msgstr ""
 
 #: opts.c:912
-#, fuzzy, gcc-internal-format
-#| msgid "-fno-fat-lto-objects are supported only with linker plugin."
+#, gcc-internal-format
 msgid "%<-fno-fat-lto-objects%> are supported only with linker plugin"
-msgstr "-fno-fat-lto-objects поддерживается только с linker plugin."
+msgstr ""
 
 #: opts.c:926
 #, gcc-internal-format
@@ -25094,10 +20775,9 @@
 msgstr "%<-fsplit-stack%> для этой конфигурации не поддерживается"
 
 #: opts.c:973
-#, fuzzy, gcc-internal-format
-#| msgid "-fdirectives-only is incompatible with -traditional"
+#, gcc-internal-format
 msgid "%<-fsanitize=pointer-compare%> must be combined with %<-fsanitize=address%> or %<-fsanitize=kernel-address%>"
-msgstr "-fdirectives-only несовместим с -traditional"
+msgstr ""
 
 #: opts.c:977
 #, gcc-internal-format
@@ -25105,28 +20785,24 @@
 msgstr ""
 
 #: opts.c:985
-#, fuzzy, gcc-internal-format
-#| msgid "-fdirectives-only is incompatible with -traditional"
+#, gcc-internal-format
 msgid "%<-fsanitize=address%> is incompatible with %<-fsanitize=kernel-address%>"
-msgstr "-fdirectives-only несовместим с -traditional"
+msgstr ""
 
 #: opts.c:992
-#, fuzzy, gcc-internal-format
-#| msgid "section attributes are not supported for this target"
+#, gcc-internal-format
 msgid "%<-fsanitize=address%> and %<-fsanitize=kernel-address%> are incompatible with %<-fsanitize=thread%>"
-msgstr "атрибут section для данной платформы не поддерживается"
+msgstr ""
 
 #: opts.c:998
-#, fuzzy, gcc-internal-format
-#| msgid "-fdirectives-only is incompatible with -traditional"
+#, gcc-internal-format
 msgid "%<-fsanitize=leak%> is incompatible with %<-fsanitize=thread%>"
-msgstr "-fdirectives-only несовместим с -traditional"
+msgstr ""
 
 #: opts.c:1004
-#, fuzzy, gcc-internal-format
-#| msgid "-fpic is not supported"
+#, gcc-internal-format
 msgid "%<-fsanitize-recover=%s%> is not supported"
-msgstr "ключ -fpic не поддерживается"
+msgstr ""
 
 #: opts.c:1030
 #, gcc-internal-format
@@ -25134,40 +20810,34 @@
 msgstr ""
 
 #: opts.c:1037
-#, fuzzy, gcc-internal-format
-#| msgid "transactional memory is not supported with non-call exceptions"
+#, gcc-internal-format
 msgid "transactional memory is not supported with %<-fsanitize=address%>"
-msgstr "транзакционная память не поддерживается с non-call исключениями"
+msgstr "транзакционная память не поддерживается с %<-fsanitize=address%>"
 
 #: opts.c:1040
-#, fuzzy, gcc-internal-format
-#| msgid "transactional memory is not supported with non-call exceptions"
+#, gcc-internal-format
 msgid "transactional memory is not supported with %<-fsanitize=kernel-address%>"
-msgstr "транзакционная память не поддерживается с non-call исключениями"
+msgstr "транзакционная память не поддерживается с %<-fsanitize=kernel-address%>"
 
 #: opts.c:1048
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "-malign-loops=%d is not between 0 and %d"
+#, gcc-internal-format, gfc-internal-format
 msgid "-falign-loops=%d is not between 0 and %d"
-msgstr "-malign-loops=%d не между 0 и %d"
+msgstr ""
 
 #: opts.c:1052
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "-malign-jumps=%d is not between 0 and %d"
+#, gcc-internal-format, gfc-internal-format
 msgid "-falign-jumps=%d is not between 0 and %d"
-msgstr "-malign-loops=%d не между 0 и %d"
+msgstr ""
 
 #: opts.c:1056
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "-malign-functions=%d is not between 0 and %d"
+#, gcc-internal-format, gfc-internal-format
 msgid "-falign-functions=%d is not between 0 and %d"
-msgstr "-malign-loops=%d не между 0 и %d"
+msgstr ""
 
 #: opts.c:1060
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "-malign-loops=%d is not between 0 and %d"
+#, gcc-internal-format, gfc-internal-format
 msgid "-falign-labels=%d is not between 0 and %d"
-msgstr "-malign-loops=%d не между 0 и %d"
+msgstr ""
 
 #: opts.c:1471
 #, gcc-internal-format
@@ -25180,22 +20850,19 @@
 msgstr ""
 
 #: opts.c:1733
-#, fuzzy, gcc-internal-format
-#| msgid "unrecognized argument to --help= option: %q.*s"
+#, gcc-internal-format
 msgid "unrecognized argument to -f%ssanitize%s= option: %q.*s; did you mean %qs?"
-msgstr "неизвестный аргумент ключа --help=: %q.*s"
+msgstr "неопознанный аргумент для -f%ssanitize%s= опции: %q.*s; имелось в виду %qs?"
 
 #: opts.c:1739
-#, fuzzy, gcc-internal-format
-#| msgid "unrecognized argument to --help= option: %q.*s"
+#, gcc-internal-format
 msgid "unrecognized argument to -f%ssanitize%s= option: %q.*s"
-msgstr "неизвестный аргумент ключа --help=: %q.*s"
+msgstr "неопознанный аргумент для -f%ssanitize%s= опции: %q.*s"
 
 #: opts.c:1774
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute directive ignored"
+#, gcc-internal-format
 msgid "%<%s%> attribute directive ignored"
-msgstr "директива описания атрибута %qE проигнорирована"
+msgstr ""
 
 #: opts.c:1951
 #, gcc-internal-format
@@ -25208,10 +20875,9 @@
 msgstr "неизвестный аргумент ключа --help=: %q.*s"
 
 #: opts.c:2214
-#, fuzzy, gcc-internal-format
-#| msgid "LTO support has not been enabled in this configuration"
+#, gcc-internal-format
 msgid "HSA has not been enabled during configuration"
-msgstr "Поддержка LTO в данной конфигурации отсутствует"
+msgstr "HSA не было включено при конфигурировании"
 
 #: opts.c:2226
 #, gcc-internal-format
@@ -25224,21 +20890,19 @@
 msgstr "выравнивание структуры должно быть небольшой степенью двойки, а не %d"
 
 #: opts.c:2320
-#, fuzzy, gcc-internal-format
-#| msgid "invalid argument to built-in function"
+#, gcc-internal-format
 msgid "invalid arguments for %<-fpatchable_function_entry%>"
-msgstr "некорректный аргумент встроенной функции"
+msgstr ""
 
 #: opts.c:2378
-#, fuzzy, gcc-internal-format
-#| msgid "unknown stack check parameter \"%s\""
+#, gcc-internal-format
 msgid "unknown stack check parameter %qs"
-msgstr "неизвестный параметр проверки стека \"%s\""
+msgstr "неизвестный параметр проверки стека %qs"
 
 #: opts.c:2406
 #, gcc-internal-format
 msgid "%<-gdwarf%s%> is ambiguous; use %<-gdwarf-%s%> for DWARF version or %<-gdwarf -g%s%> for debug level"
-msgstr ""
+msgstr "%<-gdwarf%s%> двусмысленна; используйте %<-gdwarf-%s%> для DWARF версии или %<-gdwarf -g%s%> для уровня отладки"
 
 #: opts.c:2417
 #, gcc-internal-format, gfc-internal-format
@@ -25251,16 +20915,14 @@
 msgstr "%s: аргументы --param должны иметь вид ИМЯ=ЗНАЧЕНИЕ"
 
 #: opts.c:2535
-#, fuzzy, gcc-internal-format
-#| msgid "invalid --param value %qs"
+#, gcc-internal-format
 msgid "invalid --param name %qs; did you mean %qs?"
-msgstr "некорректное значение ключа --param %qs"
+msgstr "некорректное --param имя %qs; имелось в виду %qs?"
 
 #: opts.c:2538
-#, fuzzy, gcc-internal-format
-#| msgid "invalid --param value %qs"
+#, gcc-internal-format
 msgid "invalid --param name %qs"
-msgstr "некорректное значение ключа --param %qs"
+msgstr "некорректное --param имя %qs"
 
 #: opts.c:2546
 #, gcc-internal-format
@@ -25273,22 +20935,19 @@
 msgstr "целевая платформа не поддерживает вывод отладочной информации"
 
 #: opts.c:2677
-#, fuzzy, gcc-internal-format
-#| msgid "debug format \"%s\" conflicts with prior selection"
+#, gcc-internal-format
 msgid "debug format %qs conflicts with prior selection"
-msgstr "отладочный формат \"%s\" противоречит предыдущему выбору"
+msgstr "отладочный формат %qs противоречит предыдущему выбору"
 
 #: opts.c:2695
-#, fuzzy, gcc-internal-format
-#| msgid "unrecognised debug output level \"%s\""
+#, gcc-internal-format
 msgid "unrecognized debug output level %qs"
-msgstr "некорректный уровень отладочной информации \"%s\""
+msgstr "неопознанный уровень вывода отладочной информации %qs"
 
 #: opts.c:2697
-#, fuzzy, gcc-internal-format
-#| msgid "debug output level %s is too high"
+#, gcc-internal-format
 msgid "debug output level %qs is too high"
-msgstr "уровень отладочной информации %s слишком высок"
+msgstr "уровень вывода отладочной информации %qs слишком высок"
 
 #: opts.c:2717
 #, gcc-internal-format
@@ -25313,7 +20972,7 @@
 #: opts.c:2793
 #, gcc-internal-format, gfc-internal-format
 msgid "-Werror=%s: -%s is not an option that controls warnings"
-msgstr ""
+msgstr "-Werror=%s: -%s не есть опция, управляющая предупреждениями"
 
 #. If we didn't find this parameter, issue an error message.
 #: params.c:198
@@ -25332,15 +20991,14 @@
 msgstr "максимальное значение параметра %qs равно %u"
 
 #: passes.c:84
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "%s does not support split_edge"
+#, gcc-internal-format, gfc-internal-format
 msgid "pass %s does not support cloning"
-msgstr "%s не поддерживает split_edge"
+msgstr "проход %s не поддерживает клонирование"
 
 #: passes.c:90
 #, gcc-internal-format, gfc-internal-format
 msgid "pass %s needs a set_pass_param implementation to handle the extra argument in NEXT_PASS"
-msgstr ""
+msgstr "проход %s нуждается в set_pass_param реализации, обрабатывающей дополнительный аргумент в NEXT_PASS"
 
 #: passes.c:1027
 #, gcc-internal-format
@@ -25441,7 +21099,7 @@
 #: plugin.c:375
 #, gcc-internal-format
 msgid "unable to register info for plugin %qs - plugin name not found"
-msgstr ""
+msgstr "невозможно регистрировать информацию для плагина %qs - имя плагина не найдено"
 
 #: plugin.c:471
 #, gcc-internal-format, gfc-internal-format
@@ -25491,10 +21149,9 @@
 msgstr "опция -iplugindir <dir> не была передана из драйвера gcc"
 
 #: predict.c:3309
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Missing argument list in function '%s' at %C"
+#, gcc-internal-format, gfc-internal-format
 msgid "Missing counts for called function %s"
-msgstr "Отсутствует список аргументов в функции '%s' в %C"
+msgstr ""
 
 #: profile.c:456
 #, gcc-internal-format, gfc-internal-format
@@ -25524,59 +21181,52 @@
 #: read-rtl-function.c:262
 #, gcc-internal-format, gfc-internal-format
 msgid "insn with UID %i not found for operand %i (`%s') of insn %i"
-msgstr ""
+msgstr "инструкция с UID %i не найдена для операнда %i (`%s') инструкции %i"
 
 #: read-rtl-function.c:266
 #, gcc-internal-format, gfc-internal-format
 msgid "insn with UID %i not found for operand %i of insn %i"
-msgstr ""
+msgstr "инструкция с UID %i не найдена для операнда %i инструкции %i"
 
 #: read-rtl-function.c:409
-#, fuzzy, gcc-internal-format
-#| msgid "function %qs cannot be declared %<mutable%>"
+#, gcc-internal-format
 msgid "%<__RTL%> function cannot be compiled with %<-flto%>"
-msgstr "недопустимая декларация функции %qs как %<mutable%>"
+msgstr "%<__RTL%> функция не может компилироваться с %<-flto%>"
 
 #: read-rtl-function.c:710
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "unrecognized register name %qs"
+#, gcc-internal-format, gfc-internal-format
 msgid "unrecognized edge flag: '%s'"
-msgstr "некорректное имя регистра %qs"
+msgstr "неопознанный флаг ребра '%s'"
 
 #: read-rtl-function.c:853
-#, fuzzy, gcc-internal-format
-#| msgid "Do not generate #line directives"
+#, gcc-internal-format
 msgid "more than one 'crtl' directive"
-msgstr "Не генерировать директивы #строка"
+msgstr "более одной 'crtl' директивы"
 
 #: read-rtl-function.c:981
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "unrecognized visibility value %qs"
+#, gcc-internal-format, gfc-internal-format
 msgid "unrecognized enum value: '%s'"
-msgstr "некорректный тип видимости %qs"
+msgstr "неопознанное enum значение: '%s'"
 
 #: read-rtl-function.c:1137 read-rtl-function.c:1196
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Expecting %s statement at %C"
+#, gcc-internal-format, gfc-internal-format
 msgid "was expecting `%s'"
-msgstr "Ожидается %s оператор в %C"
+msgstr "ожидалось `%s'"
 
 #: read-rtl-function.c:1575
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "deleted definition of %qD"
+#, gcc-internal-format, gfc-internal-format
 msgid "duplicate insn UID: %i"
-msgstr "удаленное определение %qD"
+msgstr "повторный UID инструкции: %i"
 
 #: read-rtl-function.c:1635
 #, gcc-internal-format
 msgid "start/end of RTL fragment are in different files"
-msgstr ""
+msgstr "начало/конец RTL фрагмента в разных файлах"
 
 #: read-rtl-function.c:1641
-#, fuzzy, gcc-internal-format
-#| msgid "stack size must not be greater than 64k"
+#, gcc-internal-format
 msgid "start of RTL fragment must be on an earlier line than end"
-msgstr "размер стека должен быть больше чем 64k"
+msgstr "начало RTL фрагмента должно быть на более ранней строке, чем конец"
 
 #: reg-stack.c:536
 #, gcc-internal-format, gfc-internal-format
@@ -25599,10 +21249,9 @@
 msgstr "неявно выталкиваемые регистры должны быть сгруппированы на вершине стека"
 
 #: reg-stack.c:626
-#, fuzzy, gcc-internal-format
-#| msgid "implicitly popped regs must be grouped at top of stack"
+#, gcc-internal-format
 msgid "explicitly used regs must be grouped at top of stack"
-msgstr "неявно выталкиваемые регистры должны быть сгруппированы на вершине стека"
+msgstr "явно использованные регистры должны быть сгруппированы на вершине стека"
 
 #: reg-stack.c:645
 #, gcc-internal-format
@@ -25609,22 +21258,22 @@
 msgid "output operand %d must use %<&%> constraint"
 msgstr "выходной операнд %d должен содержать ограничитель %<&%>"
 
-#: regcprop.c:1187
+#: regcprop.c:1193
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad next_regno for empty chain (%u)"
 msgstr "validate_value_data: [%u] Некорректный next_regno для пустого списка (%u)"
 
-#: regcprop.c:1199
+#: regcprop.c:1205
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: Loop in regno chain (%u)"
 msgstr "validate_value_data: цикл в списке номеров регистров (%u)"
 
-#: regcprop.c:1202
+#: regcprop.c:1208
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad oldest_regno (%u)"
 msgstr "validate_value_data: : [%u] Некорректный oldest_regno (%u)"
 
-#: regcprop.c:1214
+#: regcprop.c:1220
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Non-empty reg in chain (%s %u %i)"
 msgstr "validate_value_data: [%u] Непустой регистр в списке (%s %u %i)"
@@ -25668,7 +21317,7 @@
 msgstr "регистр %qD назначен для нескольких глобальных регистровых переменных"
 
 #: reginfo.c:789 config/powerpcspe/powerpcspe.c:32259
-#: config/rs6000/rs6000.c:29453
+#: config/rs6000/rs6000.c:29530
 #, gcc-internal-format
 msgid "conflicts with %qD"
 msgstr "конфликтует с %qD"
@@ -25749,10 +21398,9 @@
 msgstr "RTL: попытка трактовать не блочный символ как блочный в %s, в %s:%d"
 
 #: rtl.c:891
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "RTL check: access of elt %d of vector with last elt %d in %s, at %s:%d"
+#, gcc-internal-format, gfc-internal-format
 msgid "RTL check: access of hwi elt %d of vector with last elt %d in %s, at %s:%d"
-msgstr "RTL: доступ к эл-ту %d вектора с числом эл-тов %d; функция %s, в %s:%d"
+msgstr "RTL проверка: доступ к hwi эл-ту %d вектора с последним эл-том %d в %s, в %s:%d"
 
 #: rtl.c:901
 #, gcc-internal-format, gfc-internal-format
@@ -25835,10 +21483,9 @@
 msgstr "размер %q+D больше %wd байт"
 
 #: stor-layout.c:1153
-#, fuzzy, gcc-internal-format
-#| msgid "requested alignment is too large"
+#, gcc-internal-format
 msgid "alignment %u of %qT is less than %u"
-msgstr "выравнивание слишком велико"
+msgstr ""
 
 #: stor-layout.c:1160
 #, gcc-internal-format
@@ -25901,184 +21548,175 @@
 msgstr "выравнивание элементов массива превышает их размер"
 
 #: substring-locations.c:181
-#, fuzzy, gcc-internal-format
-#| msgid "originally defined here"
+#, gcc-internal-format
 msgid "format string is defined here"
-msgstr "исходное определение находится здесь"
+msgstr "форматная цепочка определена здесь"
 
 #: symtab.c:302
-#, fuzzy, gcc-internal-format
-#| msgid "%D renamed after being referenced in assembly"
+#, gcc-internal-format
 msgid "%qD renamed after being referenced in assembly"
-msgstr "переименование %D после ссылки в ассемблерном коде"
+msgstr ""
 
 #: symtab.c:998
-#, fuzzy, gcc-internal-format
-#| msgid "function returning a function"
+#, gcc-internal-format
 msgid "function symbol is not function"
-msgstr "функция возвращает функцию"
+msgstr "функциональный символ не есть функция"
 
+#: symtab.c:1005
+#, gcc-internal-format
+msgid "inconsistent `ifunc' attribute"
+msgstr ""
+
 #
-#: symtab.c:1006
-#, fuzzy, gcc-internal-format
-#| msgid "array is not addressable"
+#: symtab.c:1013
+#, gcc-internal-format
 msgid "variable symbol is not variable"
-msgstr "массив неадресуем"
+msgstr "символ переменной не есть переменная"
 
-#: symtab.c:1012
-#, fuzzy, gcc-internal-format
-#| msgid "node has wrong clone list"
+#: symtab.c:1019
+#, gcc-internal-format
 msgid "node has unknown type"
-msgstr "узел имеет некорректный список клонов"
+msgstr "узел имеет неизвестный тип"
 
-#: symtab.c:1021
+#: symtab.c:1028
 #, gcc-internal-format
 msgid "node not found node->decl->decl_with_vis.symtab_node"
-msgstr ""
+msgstr "узел не найден node->decl->decl_with_vis.symtab_node"
 
-#: symtab.c:1029
+#: symtab.c:1036
 #, gcc-internal-format
 msgid "node differs from node->decl->decl_with_vis.symtab_node"
-msgstr ""
+msgstr "узел отличается от node->decl->decl_with_vis.symtab_node"
 
-#: symtab.c:1038
+#: symtab.c:1045
 #, gcc-internal-format
 msgid "assembler name hash list corrupted"
-msgstr ""
+msgstr "хэш-список ассемблерного имени поврежден"
 
-#: symtab.c:1051
-#, fuzzy, gcc-internal-format
-#| msgid "node not found in cgraph_hash"
+#: symtab.c:1058
+#, gcc-internal-format
 msgid "node not found in symtab assembler name hash"
-msgstr "не найден узел в cgraph_hash"
+msgstr "не найден узел в symtab assembler name hash"
 
-#: symtab.c:1058
-#, fuzzy, gcc-internal-format
-#| msgid "double linked list of clones corrupted"
+#: symtab.c:1065
+#, gcc-internal-format
 msgid "double linked list of assembler names corrupted"
-msgstr "испорчен двусвязный список клонов"
+msgstr "испорчен двусвязный список ассемблерных имен"
 
-#: symtab.c:1063
-#, fuzzy, gcc-internal-format
-#| msgid "%qD used before its definition"
+#: symtab.c:1070
+#, gcc-internal-format
 msgid "node has body_removed but is definition"
-msgstr "%qD использована до своего определения"
+msgstr "узел имеет body_removed, но является определением"
 
-#: symtab.c:1068
-#, fuzzy, gcc-internal-format
-#| msgid "node is in clone list but it is not clone"
+#: symtab.c:1075
+#, gcc-internal-format
 msgid "node is analyzed but it is not a definition"
-msgstr "узел в списке клонов, но не является клоном"
+msgstr "узел проанализирован, но это не определение"
 
-#: symtab.c:1073
+#: symtab.c:1080
 #, gcc-internal-format
 msgid "node is alias but not implicit alias"
-msgstr ""
+msgstr "узел есть синоним, но не неявный синоним"
 
-#: symtab.c:1078
-#, fuzzy, gcc-internal-format
-#| msgid "node is in clone list but it is not clone"
+#: symtab.c:1085
+#, gcc-internal-format
 msgid "node is alias but not definition"
-msgstr "узел в списке клонов, но не является клоном"
+msgstr "узел является синонимом, но не определением"
 
-#: symtab.c:1083
+#: symtab.c:1090
 #, gcc-internal-format
 msgid "node is weakref but not an transparent_alias"
-msgstr ""
+msgstr "узел есть weakref, но не transparent_alias"
 
-#: symtab.c:1088
+#: symtab.c:1095
 #, gcc-internal-format
 msgid "node is transparent_alias but not an alias"
-msgstr ""
+msgstr "узел есть transparent_alias, но не синоним"
 
-#: symtab.c:1097
-#, fuzzy, gcc-internal-format
-#| msgid "node is in clone list but it is not clone"
+#: symtab.c:1104
+#, gcc-internal-format
 msgid "node is in same_comdat_group list but has no comdat_group"
-msgstr "узел в списке клонов, но не является клоном"
+msgstr "узел в списке same_comdat_group, но не имеет comdat_group"
 
-#: symtab.c:1102
-#, fuzzy, gcc-internal-format
-#| msgid "same_comdat_group is not a circular list"
+#: symtab.c:1109
+#, gcc-internal-format
 msgid "same_comdat_group list across different groups"
-msgstr "same_comdat_group не является циклическим списком"
+msgstr "same_comdat_group список через разные группы"
 
-#: symtab.c:1107
+#: symtab.c:1114
 #, gcc-internal-format
 msgid "mixing different types of symbol in same comdat groups is not supported"
-msgstr ""
+msgstr "смешение разных типов символа в одной comdat группе не поддерживается"
 
-#: symtab.c:1112
+#: symtab.c:1119
 #, gcc-internal-format
 msgid "node is alone in a comdat group"
 msgstr "только один узел в comdat группе"
 
-#: symtab.c:1119
+#: symtab.c:1126
 #, gcc-internal-format
 msgid "same_comdat_group is not a circular list"
 msgstr "same_comdat_group не является циклическим списком"
 
-#: symtab.c:1134
+#: symtab.c:1141
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local symbol referred to by %s outside its comdat"
-msgstr ""
+msgstr "на comdat-local символ ссылается %s извне его comdat"
 
-#: symtab.c:1144
+#: symtab.c:1151
 #, gcc-internal-format
 msgid "implicit_section flag is set but section isn't"
-msgstr ""
+msgstr "implicit_section флаг установлен, а секция нет"
 
-#: symtab.c:1151
-#, fuzzy, gcc-internal-format
-#| msgid "node is alone in a comdat group"
+#: symtab.c:1158
+#, gcc-internal-format
 msgid "Both section and comdat group is set"
-msgstr "только один узел в comdat группе"
+msgstr "Установлена и секция, и comdat группа"
 
-#: symtab.c:1163
+#: symtab.c:1170
 #, gcc-internal-format
 msgid "Alias and target's section differs"
-msgstr ""
+msgstr "синоним и секция цели различаются"
 
-#: symtab.c:1170
+#: symtab.c:1177
 #, gcc-internal-format
 msgid "Alias and target's comdat groups differs"
-msgstr ""
+msgstr "синоним и comdat группа цели различаются"
 
-#: symtab.c:1185
+#: symtab.c:1192
 #, gcc-internal-format
 msgid "Transparent alias and target's assembler names differs"
-msgstr ""
+msgstr "Прозрачный синоним и ассемблерные имена цели различаются"
 
-#: symtab.c:1193
+#: symtab.c:1200
 #, gcc-internal-format
 msgid "Chained transparent aliases"
-msgstr ""
+msgstr "Связанные в цепочку прозрачные синонимы"
 
-#: symtab.c:1216 symtab.c:1253
-#, fuzzy, gcc-internal-format
-#| msgid "verify_ssa failed"
+#: symtab.c:1223 symtab.c:1260
+#, gcc-internal-format
 msgid "symtab_node::verify failed"
-msgstr "процедура verify_ssa выявила ошибки"
+msgstr "ошибка symtab_node::verify"
 
-#: symtab.c:1249
+#: symtab.c:1256
 #, gcc-internal-format
 msgid "Two symbols with same comdat_group are not linked by the same_comdat_group list."
-msgstr ""
+msgstr "Два символа с одной comdat_group не связаны посредством same_comdat_group списка."
 
-#: symtab.c:1658
+#: symtab.c:1665
 #, gcc-internal-format
 msgid "function %q+D part of alias cycle"
 msgstr "функция %q+D является частью цикла алиасов"
 
-#: symtab.c:1660
+#: symtab.c:1667
 #, gcc-internal-format
 msgid "variable %q+D part of alias cycle"
 msgstr "переменная %q+D входит в цикл алиасов"
 
-#: symtab.c:1688
+#: symtab.c:1695
 #, gcc-internal-format
 msgid "section of alias %q+D must match section of its target"
-msgstr ""
+msgstr "секция синонима %q+D должна соответствовать его цели"
 
 #: targhooks.c:191
 #, gcc-internal-format
@@ -26118,7 +21756,7 @@
 #: tlink.c:493
 #, gcc-internal-format, gfc-internal-format
 msgid "repository file '%s' does not contain command-line arguments"
-msgstr "файл репозитария '%s' не содержит аргументы командной строки"
+msgstr "файл репозитория '%s' не содержит аргументы командной строки"
 
 #: tlink.c:619
 #, gcc-internal-format, gfc-internal-format
@@ -26131,10 +21769,9 @@
 msgstr "выполнение ld завершилось с кодом возврата %d"
 
 #: toplev.c:879
-#, fuzzy, gcc-internal-format
-#| msgid "can%'t open %s for writing: %m"
+#, gcc-internal-format
 msgid "can%'t open %qs for writing: %m"
-msgstr "ошибка открытия %s на запись: %m"
+msgstr "ошибка открытия %qs на запись: %m"
 
 #: toplev.c:901
 #, gcc-internal-format
@@ -26172,64 +21809,54 @@
 msgstr "для этой целевой платформы не поддерживается %qs"
 
 #: toplev.c:1286
-#, fuzzy, gcc-internal-format
-#| msgid "Graphite loop optimizations cannot be used (-fgraphite, -fgraphite-identity, -floop-block, -floop-flatten, -floop-interchange, -floop-strip-mine, -floop-parallelize-all, and -ftree-loop-linear)"
+#, gcc-internal-format
 msgid "Graphite loop optimizations cannot be used (isl is not available) (-fgraphite, -fgraphite-identity, -floop-nest-optimize, -floop-parallelize-all)"
-msgstr "Graphite-оптимизации циклов не могут быть использованы (-fgraphite, -fgraphite-identity, -floop-block, -floop-flatten, -floop-interchange, -floop-strip-mine, -floop-parallelize-all и -ftree-loop-linear)"
+msgstr "Graphite-оптимизации циклов не могут быть использованы (isl отсутствует) (-fgraphite, -fgraphite-identity, -floop-nest-optimize, -floop-parallelize-all)"
 
 #: toplev.c:1297
-#, fuzzy, gcc-internal-format
-#| msgid "-fstack-protector not supported for this target"
+#, gcc-internal-format
 msgid "%<-fcf-protection=full%> is not supported for this target"
-msgstr "-fstack-protector не поддерживается для этой целевой платформы"
+msgstr ""
 
 #: toplev.c:1304
-#, fuzzy, gcc-internal-format
-#| msgid "-fstack-protector not supported for this target"
+#, gcc-internal-format
 msgid "%<-fcf-protection=branch%> is not supported for this target"
-msgstr "-fstack-protector не поддерживается для этой целевой платформы"
+msgstr ""
 
 #: toplev.c:1311
-#, fuzzy, gcc-internal-format
-#| msgid "-fstack-protector not supported for this target"
+#, gcc-internal-format
 msgid "%<-fcf-protection=return%> is not supported for this target"
-msgstr "-fstack-protector не поддерживается для этой целевой платформы"
+msgstr ""
 
 #: toplev.c:1322
-#, fuzzy, gcc-internal-format
-#| msgid "fixed-point types not supported for this target"
+#, gcc-internal-format
 msgid "%<-fcheck-pointer-bounds%> is not supported for this target"
-msgstr "типы с фиксированной точкой не поддерживаются для этой целевой платформы"
+msgstr "%<-fcheck-pointer-bounds%> не поддерживается для этой целевой платформы"
 
 #: toplev.c:1330
-#, fuzzy, gcc-internal-format
-#| msgid "-fuse-linker-plugin is not supported in this configuration"
+#, gcc-internal-format
 msgid "%<-fcheck-pointer-bounds%> is not supported with %<-fsanitize=bounds-strict%>"
-msgstr "-fuse-linker-plugin в данной конфигурации не поддерживается"
+msgstr "%<-fcheck-pointer-bounds%> не поддерживается с %<-fsanitize=bounds-strict%>"
 
 #: toplev.c:1337
-#, fuzzy, gcc-internal-format
-#| msgid "-fuse-linker-plugin is not supported in this configuration"
+#, gcc-internal-format
 msgid "%<-fcheck-pointer-bounds%> is not supported with %<-fsanitize=bounds%>"
-msgstr "-fuse-linker-plugin в данной конфигурации не поддерживается"
+msgstr "%<-fcheck-pointer-bounds%> не поддерживается с %<-fsanitize=bounds%>"
 
 #: toplev.c:1345
-#, fuzzy, gcc-internal-format
-#| msgid "-fuse-linker-plugin is not supported in this configuration"
+#, gcc-internal-format
 msgid "%<-fcheck-pointer-bounds%> is not supported with Address Sanitizer"
-msgstr "-fuse-linker-plugin в данной конфигурации не поддерживается"
+msgstr "%<-fcheck-pointer-bounds%> не поддерживается с Address Sanitizer"
 
 #: toplev.c:1353
-#, fuzzy, gcc-internal-format
-#| msgid "-fuse-linker-plugin is not supported in this configuration"
+#, gcc-internal-format
 msgid "%<-fcheck-pointer-bounds%> is not supported with Thread Sanitizer"
-msgstr "-fuse-linker-plugin в данной конфигурации не поддерживается"
+msgstr "%<-fcheck-pointer-bounds%> не поддерживается с Thread Sanitizer"
 
 #: toplev.c:1369
-#, fuzzy, gcc-internal-format
-#| msgid "switch %qs is no longer supported"
+#, gcc-internal-format
 msgid "%<-fabi-version=1%> is no longer supported"
-msgstr "ключ %qs больше не поддерживается"
+msgstr "%<-fabi-version=1%> больше не поддерживается"
 
 #: toplev.c:1397
 #, gcc-internal-format
@@ -26252,10 +21879,9 @@
 msgstr "ошибка закрытия дамп-файла %qs: %m"
 
 #: toplev.c:1495
-#, fuzzy, gcc-internal-format
-#| msgid "target system does not support the \"%s\" debug format"
+#, gcc-internal-format
 msgid "target system does not support the %qs debug format"
-msgstr "отладочный формат \"%s\" не поддерживается для этой целевой машины"
+msgstr "целевая система не поддерживает %qs отладочный формат"
 
 #: toplev.c:1508
 #, gcc-internal-format
@@ -26333,16 +21959,14 @@
 msgstr "-fstack-protector не поддерживается для этой целевой платформы"
 
 #: toplev.c:1728
-#, fuzzy, gcc-internal-format
-#| msgid "section attributes are not supported for this target"
+#, gcc-internal-format
 msgid "-fsanitize=address and -fsanitize=kernel-address are not supported for this target"
-msgstr "атрибут section для данной платформы не поддерживается"
+msgstr "-fsanitize=address и -fsanitize=kernel-address не поддерживаются для этой целевой платформы"
 
 #: toplev.c:1737
-#, fuzzy, gcc-internal-format
-#| msgid "-fdata-sections not supported for this target"
+#, gcc-internal-format
 msgid "-fsanitize=address not supported for this target"
-msgstr "-fdata-sections не поддерживается для этой целевой машины"
+msgstr "-fsanitize=address не поддерживается для этой целевой платформы"
 
 #: toplev.c:2035
 #, gcc-internal-format
@@ -26355,27 +21979,24 @@
 msgstr "ошибка закрытия %s: %m"
 
 #: toplev.c:2186
-#, fuzzy, gcc-internal-format
-#| msgid "%qs is incompatible with %qs"
+#, gcc-internal-format
 msgid "self-tests incompatible with -E"
-msgstr "%qs несовместим с %qs"
+msgstr "тесты самопроверки несовместимы с -E"
 
 #: toplev.c:2201
 #, gcc-internal-format
 msgid "self-tests are not enabled in this build"
-msgstr ""
+msgstr "self-tests не включены в этой сборке"
 
 #: trans-mem.c:621
-#, fuzzy, gcc-internal-format
-#| msgid "invalid volatile use of %qD inside transaction"
+#, gcc-internal-format
 msgid "invalid use of volatile lvalue inside transaction"
-msgstr "некорректное использование volatile %qD внутри транзакции"
+msgstr "некорректное использование volatile lvalue внутри транзакции"
 
 #: trans-mem.c:624
-#, fuzzy, gcc-internal-format
-#| msgid "asm not allowed in %<transaction_safe%> function"
+#, gcc-internal-format
 msgid "invalid use of volatile lvalue inside %<transaction_safe%> function"
-msgstr "asm не допускается в %<transaction_safe%> функции"
+msgstr "некорректное использование volatile lvalue внутри %<transaction_safe%> функции"
 
 #: trans-mem.c:656
 #, gcc-internal-format
@@ -26455,7 +22076,7 @@
 #: tree-cfg.c:356
 #, gcc-internal-format
 msgid "ignoring loop annotation"
-msgstr ""
+msgstr "игнорирование аннотации цикла"
 
 #: tree-cfg.c:3004
 #, gcc-internal-format
@@ -26478,10 +22099,9 @@
 msgstr "имя SSA в списке свободных, но на него есть ссылки"
 
 #: tree-cfg.c:3064
-#, fuzzy, gcc-internal-format
-#| msgid "declaration of %qD as non-function"
+#, gcc-internal-format
 msgid "Local declaration from a different function"
-msgstr "декларация %qD как не-функции"
+msgstr "Локальная декларация из другой функции"
 
 #: tree-cfg.c:3071 tree-cfg.c:4635
 #, gcc-internal-format
@@ -26526,7 +22146,7 @@
 #: tree-cfg.c:3175
 #, gcc-internal-format
 msgid "non-scalar BIT_FIELD_REF, IMAGPART_EXPR or REALPART_EXPR"
-msgstr ""
+msgstr "не-скаляр BIT_FIELD_REF, IMAGPART_EXPR или REALPART_EXPR"
 
 #: tree-cfg.c:3190
 #, gcc-internal-format
@@ -26539,21 +22159,19 @@
 msgstr "точность целочисленного типа результата не соответствует размеру поля в BIT_FIELD_REF"
 
 #: tree-cfg.c:3205
-#, fuzzy, gcc-internal-format
-#| msgid "mode precision of non-integral result does not match field size of BIT_FIELD_REF"
+#, gcc-internal-format
 msgid "mode size of non-integral result does not match field size of BIT_FIELD_REF"
-msgstr "точность моды нецелочисленного результата не соответствует размеру поля в BIT_FIELD_REF"
+msgstr "размер режима нецелочисленного результата не соответствует размеру поля в BIT_FIELD_REF"
 
 #: tree-cfg.c:3213
-#, fuzzy, gcc-internal-format
-#| msgid "invalid position or size operand to BIT_FIELD_REF"
+#, gcc-internal-format
 msgid "position plus size exceeds size of referenced object in BIT_FIELD_REF"
-msgstr "некорректная позиция или размер для BIT_FIELD_REF"
+msgstr "позиция плюс размер превышает размер указуемого объекта в BIT_FIELD_REF"
 
 #: tree-cfg.c:3246
 #, gcc-internal-format
 msgid "non-top-level BIT_FIELD_REF, IMAGPART_EXPR or REALPART_EXPR"
-msgstr ""
+msgstr "не-верхний-уровень BIT_FIELD_REF, IMAGPART_EXPR или REALPART_EXPR"
 
 #: tree-cfg.c:3256
 #, gcc-internal-format
@@ -26566,16 +22184,14 @@
 msgstr "некорректный операнд для операции плюс/минус, указательный тип"
 
 #: tree-cfg.c:3279
-#, fuzzy, gcc-internal-format
-#| msgid "invalid operand to pointer plus, first operand is not a pointer"
+#, gcc-internal-format
 msgid "invalid operand to pointer diff, operand is not a pointer"
-msgstr "некорректный операнд для операции сложения с указателем, первый операнд не указатель"
+msgstr ""
 
 #: tree-cfg.c:3287
-#, fuzzy, gcc-internal-format
-#| msgid "invalid type for property"
+#, gcc-internal-format
 msgid "invalid type for pointer diff"
-msgstr "некорректный тип для property"
+msgstr ""
 
 #: tree-cfg.c:3298
 #, gcc-internal-format
@@ -26714,10 +22330,9 @@
 #. out a call cannot happen in a legal program.  In such cases,
 #. we must make sure arguments are stripped off.
 #: tree-cfg.c:3692
-#, fuzzy, gcc-internal-format
-#| msgid "%<__builtin_next_arg%> called without an argument"
+#, gcc-internal-format
 msgid "__builtin_unreachable or __builtin_trap call with arguments"
-msgstr "вызов %<__builtin_next_arg%> без аргумента"
+msgstr "вызов __builtin_unreachable или __builtin_trap с аргументами"
 
 #: tree-cfg.c:3715
 #, gcc-internal-format
@@ -26737,7 +22352,7 @@
 #: tree-cfg.c:3768
 #, gcc-internal-format
 msgid "unsupported operation or type for vector comparison returning a boolean"
-msgstr ""
+msgstr "неподдерживаемая операция или тип для векторного сравнения, возвращающего boolean"
 
 #: tree-cfg.c:3783
 #, gcc-internal-format
@@ -26840,40 +22455,34 @@
 msgstr "несоответствие типов в выражении сложения с указателем"
 
 #: tree-cfg.c:4140
-#, fuzzy, gcc-internal-format
-#| msgid "type mismatch in pointer plus expression"
+#, gcc-internal-format
 msgid "type mismatch in pointer diff expression"
-msgstr "несоответствие типов в выражении сложения с указателем"
+msgstr ""
 
 #: tree-cfg.c:4194
-#, fuzzy, gcc-internal-format
-#| msgid "type mismatch in widening vector shift expression"
+#, gcc-internal-format
 msgid "type mismatch in widening sum reduction"
-msgstr "несоответствие типов в расширяющем векторном выражении сдвига"
+msgstr ""
 
 #: tree-cfg.c:4214
-#, fuzzy, gcc-internal-format
-#| msgid "type mismatch in widening multiply-accumulate expression"
+#, gcc-internal-format
 msgid "type mismatch in vector widening multiplication"
-msgstr "несоответствие расширяющем выражении умножения с накоплением"
+msgstr ""
 
 #: tree-cfg.c:4248
-#, fuzzy, gcc-internal-format
-#| msgid "type mismatch in vector permute expression"
+#, gcc-internal-format
 msgid "type mismatch in vector pack expression"
-msgstr "несоответствие типов в векторном выражении перестановки"
+msgstr ""
 
 #: tree-cfg.c:4281
-#, fuzzy, gcc-internal-format
-#| msgid "type mismatch in address expression"
+#, gcc-internal-format
 msgid "type mismatch in series expression"
-msgstr "несоответствие типов в адресном выражении"
+msgstr ""
 
 #: tree-cfg.c:4289
-#, fuzzy, gcc-internal-format
-#| msgid "vector types expected in vector permute expression"
+#, gcc-internal-format
 msgid "vector type expected in series expression"
-msgstr "ожидались векторные типы в векторном выражении перестановки"
+msgstr ""
 
 #: tree-cfg.c:4302
 #, gcc-internal-format
@@ -26903,9 +22512,9 @@
 #: tree-cfg.c:4383
 #, gcc-internal-format
 msgid "the first argument of a VEC_COND_EXPR must be of a boolean vector type of the same number of elements as the result"
-msgstr ""
+msgstr "первый аргумент VEC_COND_EXPR должен быть boolean векторного типа с тем же числом элементов, что и результат"
 
-#: tree-cfg.c:4395 c/c-typeck.c:5212
+#: tree-cfg.c:4395 c/c-typeck.c:5217
 #, gcc-internal-format
 msgid "type mismatch in conditional expression"
 msgstr "несоответствие типов в условном выражении"
@@ -26931,48 +22540,44 @@
 msgstr "некорректный тип маски в выражении векторной перестановки"
 
 #: tree-cfg.c:4466
-#, fuzzy, gcc-internal-format
-#| msgid "type mismatch in address expression"
+#, gcc-internal-format
 msgid "type mismatch in sad expression"
-msgstr "несоответствие типов в адресном выражении"
+msgstr "несоответствие типов в sad выражении"
 
 #: tree-cfg.c:4478
-#, fuzzy, gcc-internal-format
-#| msgid "vector types expected in vector permute expression"
+#, gcc-internal-format
 msgid "vector types expected in sad expression"
-msgstr "ожидались векторные типы в векторном выражении перестановки"
+msgstr "ожидались векторные типы в sad выражении"
 
 #: tree-cfg.c:4491
 #, gcc-internal-format
 msgid "type mismatch in BIT_INSERT_EXPR"
-msgstr ""
+msgstr "несоответствие типов в BIT_INSERT_EXPR"
 
 #: tree-cfg.c:4501
 #, gcc-internal-format
 msgid "not allowed type combination in BIT_INSERT_EXPR"
-msgstr ""
+msgstr "недопустимая комбинация типов в BIT_INSERT_EXPR"
 
 #: tree-cfg.c:4510
-#, fuzzy, gcc-internal-format
-#| msgid "invalid position or size operand to BIT_FIELD_REF"
+#, gcc-internal-format
 msgid "invalid position or size in BIT_INSERT_EXPR"
-msgstr "некорректная позиция или размер для BIT_FIELD_REF"
+msgstr "некорректная позиция или размер в BIT_INSERT_EXPR"
 
 #: tree-cfg.c:4520
 #, gcc-internal-format
 msgid "insertion out of range in BIT_INSERT_EXPR"
-msgstr ""
+msgstr "вставка вне диапазона в BIT_INSERT_EXPR"
 
 #: tree-cfg.c:4530
 #, gcc-internal-format
 msgid "vector insertion not at element boundary"
-msgstr ""
+msgstr "векторная вставка не на границе элемента"
 
 #: tree-cfg.c:4549
-#, fuzzy, gcc-internal-format
-#| msgid "type mismatch in vector permute expression"
+#, gcc-internal-format
 msgid "type mismatch in dot product reduction"
-msgstr "несоответствие типов в векторном выражении перестановки"
+msgstr ""
 
 #: tree-cfg.c:4583
 #, gcc-internal-format
@@ -26982,7 +22587,7 @@
 #: tree-cfg.c:4592
 #, gcc-internal-format
 msgid "non-decl/MEM_REF LHS in clobber statement"
-msgstr ""
+msgstr "non-decl/MEM_REF LHS в затирающем операторе"
 
 #: tree-cfg.c:4610
 #, gcc-internal-format
@@ -27002,29 +22607,28 @@
 #: tree-cfg.c:4710 tree-cfg.c:4728 tree-cfg.c:4742
 #, gcc-internal-format
 msgid "incorrect type of vector CONSTRUCTOR elements"
-msgstr ""
+msgstr "некорректный тип элементов векторного CONSTRUCTOR"
 
 #: tree-cfg.c:4719 tree-cfg.c:4735
 #, gcc-internal-format
 msgid "incorrect number of vector CONSTRUCTOR elements"
-msgstr ""
+msgstr "некорректное число элементов векторного CONSTRUCTOR"
 
 #: tree-cfg.c:4751
 #, gcc-internal-format
 msgid "vector CONSTRUCTOR with non-NULL element index"
-msgstr ""
+msgstr "векторный CONSTRUCTOR с non-NULL индексом элемента"
 
 #
 #: tree-cfg.c:4757
-#, fuzzy, gcc-internal-format
-#| msgid "PHI argument is not a GIMPLE value"
+#, gcc-internal-format
 msgid "vector CONSTRUCTOR element is not a GIMPLE value"
-msgstr "PHI аргумент не есть GIMPLE-значение"
+msgstr "элемент векторного CONSTRUCTOR не есть GIMPLE-значение"
 
 #: tree-cfg.c:4765
 #, gcc-internal-format
 msgid "non-vector CONSTRUCTOR with elements"
-msgstr ""
+msgstr "non-vector CONSTRUCTOR с элементами"
 
 #: tree-cfg.c:4824
 #, gcc-internal-format
@@ -27047,51 +22651,44 @@
 msgstr "некорректный операнд для оператора switch"
 
 #: tree-cfg.c:4890
-#, fuzzy, gcc-internal-format
-#| msgid "invalid operand to switch statement"
+#, gcc-internal-format
 msgid "non-integral type switch statement"
-msgstr "некорректный операнд для оператора switch"
+msgstr "оператор switch с нецелочисленным типом"
 
 #: tree-cfg.c:4898
-#, fuzzy, gcc-internal-format
-#| msgid "%<default%> label not within a switch statement"
+#, gcc-internal-format
 msgid "invalid default case label in switch statement"
-msgstr "метка %<default%> вне оператора switch"
+msgstr "некорректная default case метка в операторе switch"
 
 #: tree-cfg.c:4910
-#, fuzzy, gcc-internal-format
-#| msgid "case label not within a switch statement"
+#, gcc-internal-format
 msgid "invalid case label in switch statement"
-msgstr "case-метка вне оператора switch"
+msgstr "некорректная case метка в операторе switch"
 
 #: tree-cfg.c:4917
-#, fuzzy, gcc-internal-format
-#| msgid "invalid operand to switch statement"
+#, gcc-internal-format
 msgid "invalid case range in switch statement"
-msgstr "некорректный операнд для оператора switch"
+msgstr "некорректный case диапазон в операторе switch"
 
 #: tree-cfg.c:4927
-#, fuzzy, gcc-internal-format
-#| msgid "case label not within a switch statement"
+#, gcc-internal-format
 msgid "type mismatch for case label in switch statement"
-msgstr "case-метка вне оператора switch"
+msgstr "несоответствие типов для case метки в операторе switch"
 
 #: tree-cfg.c:4937
-#, fuzzy, gcc-internal-format
-#| msgid "case label not within a switch statement"
+#, gcc-internal-format
 msgid "type precision mismatch in switch statement"
-msgstr "case-метка вне оператора switch"
+msgstr "несоответствие точности типов в операторе switch"
 
 #: tree-cfg.c:4946
-#, fuzzy, gcc-internal-format
-#| msgid "case label not within a switch statement"
+#, gcc-internal-format
 msgid "case labels not sorted in switch statement"
-msgstr "case-метка вне оператора switch"
+msgstr "case метки не отсортированы в операторе switch"
 
 #: tree-cfg.c:4989
 #, gcc-internal-format
 msgid "label's context is not the current function decl"
-msgstr ""
+msgstr "контекст метки не есть декларация текущей функции"
 
 #: tree-cfg.c:4998
 #, gcc-internal-format
@@ -27146,7 +22743,7 @@
 #: tree-cfg.c:5329
 #, gcc-internal-format
 msgid "location references block not in block tree"
-msgstr ""
+msgstr "расположения блока ссылок не в дереве блоков"
 
 #: tree-cfg.c:5451
 #, gcc-internal-format
@@ -27154,10 +22751,9 @@
 msgstr "gimple_bb (phi) указывает не на тот блок"
 
 #: tree-cfg.c:5460
-#, fuzzy, gcc-internal-format
-#| msgid "from this location"
+#, gcc-internal-format
 msgid "PHI node with location"
-msgstr "в этом месте"
+msgstr "PHI узел с расположением"
 
 #: tree-cfg.c:5471 tree-cfg.c:5520
 #, gcc-internal-format
@@ -27167,7 +22763,7 @@
 #: tree-cfg.c:5479
 #, gcc-internal-format
 msgid "virtual PHI with argument locations"
-msgstr ""
+msgstr "виртуальный PHI с расположениями аргументов"
 
 #: tree-cfg.c:5508
 #, gcc-internal-format
@@ -27207,7 +22803,7 @@
 #: tree-cfg.c:5645
 #, gcc-internal-format
 msgid "nonlocal label "
-msgstr "нелокальная метка"
+msgstr "нелокальная метка "
 
 #: tree-cfg.c:5654
 #, gcc-internal-format
@@ -27269,22 +22865,22 @@
 msgid "missing edge %i->%i"
 msgstr "отсутствует дуга %i->%i"
 
-#: tree-cfg.c:9379
+#: tree-cfg.c:9388
 #, gcc-internal-format
 msgid "%<noreturn%> function does return"
 msgstr "выход из функции с атрибутом %<noreturn%>"
 
-#: tree-cfg.c:9400 tree-cfg.c:9432
+#: tree-cfg.c:9409 tree-cfg.c:9441
 #, gcc-internal-format
 msgid "control reaches end of non-void function"
 msgstr "управление достигает конца не-void функции"
 
-#: tree-cfg.c:9498 cp/cvt.c:1039
+#: tree-cfg.c:9507 cp/cvt.c:1039
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgstr "результат %qD, декларированной с атрибутом warn_unused_result, игнорируется"
 
-#: tree-cfg.c:9503 cp/cvt.c:1046
+#: tree-cfg.c:9512 cp/cvt.c:1046
 #, gcc-internal-format
 msgid "ignoring return value of function declared with attribute warn_unused_result"
 msgstr "результат функции, декларированной с атрибутом warn_unused_result, игнорируется"
@@ -27292,60 +22888,57 @@
 #: tree-chkp-opt.c:720
 #, gcc-internal-format
 msgid "memory access check always fail"
-msgstr ""
+msgstr "проверка доступа к памяти всегда заканчивается неудачей"
 
 #: tree-chkp.c:2054
-#, fuzzy, gcc-internal-format
-#| msgid "fixed-point types not supported for this target"
+#, gcc-internal-format
 msgid "-fcheck-pointer-bounds requires %qs name for internal usage"
-msgstr "типы с фиксированной точкой не поддерживаются для этой целевой платформы"
+msgstr "-fcheck-pointer-bounds требует %qs имя для внутреннего использования"
 
 #: tree-chkp.c:2831
 #, gcc-internal-format, gfc-internal-format
 msgid "pointer bounds were lost due to unexpected expression %s"
-msgstr ""
+msgstr "границы указателя утеряны из-за неожиданного выражения %s"
 
 #: tree-chkp.c:2919
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_get_bounds_by_definition: Unexpected var of type %s"
-msgstr ""
+msgstr "chkp_get_bounds_by_definition: Неожиданная переменная типа %s"
 
 #: tree-chkp.c:2962
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_get_bounds_by_definition: Unexpected GIMPLE code %s"
-msgstr ""
+msgstr "chkp_get_bounds_by_definition: Неожиданный GIMPLE код %s"
 
 #: tree-chkp.c:3662
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_make_addressed_object_bounds: Unexpected tree code %s"
-msgstr ""
+msgstr "chkp_make_addressed_object_bounds: Неожиданный код в дереве %s"
 
 #: tree-chkp.c:3822
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_find_bounds: Unexpected tree code %s"
-msgstr ""
+msgstr "chkp_find_bounds: Неожиданный код в дереве %s"
 
 #: tree-chkp.c:3833
 #, gcc-internal-format
 msgid "chkp_find_bounds: Cannot find bounds for pointer"
-msgstr ""
+msgstr "chkp_find_bounds: Невозможно найти границы для указателя"
 
 #: tree-chkp.c:3949
 #, gcc-internal-format, gfc-internal-format
 msgid "chkp_walk_pointer_assignments: unexpected RHS type: %s"
-msgstr ""
+msgstr "chkp_walk_pointer_assignments: неожиданный RHS тип: %s"
 
 #: tree-diagnostic.c:202
-#, fuzzy, gcc-internal-format
-#| msgid "redefinition of %q+D"
+#, gcc-internal-format
 msgid "in definition of macro %qs"
-msgstr "переопределение %q+D"
+msgstr "в определении макроса %qs"
 
 #: tree-diagnostic.c:219
-#, fuzzy, gcc-internal-format
-#| msgid "%s:%d:   in constexpr expansion of %qs"
+#, gcc-internal-format
 msgid "in expansion of macro %qs"
-msgstr "%s:%d:   в раскрытии константного выражения %qs"
+msgstr "в расширении макроса %qs"
 
 #: tree-eh.c:4766
 #, gcc-internal-format, gfc-internal-format
@@ -27458,10 +23051,9 @@
 msgstr "которая вызвана здесь"
 
 #: tree-inline.c:4448 tree-inline.c:4468
-#, fuzzy, gcc-internal-format
-#| msgid "from this location"
+#, gcc-internal-format
 msgid "called from this function"
-msgstr "в этом месте"
+msgstr "вызвано из этой функции"
 
 #: tree-inline.c:4461
 #, gcc-internal-format
@@ -27471,12 +23063,12 @@
 #: tree-into-ssa.c:3293
 #, gcc-internal-format
 msgid "statement uses released SSA name:"
-msgstr ""
+msgstr "оператор использует освобожденное SSA имя:"
 
 #: tree-into-ssa.c:3305
 #, gcc-internal-format
 msgid "cannot update SSA form"
-msgstr ""
+msgstr "невозможно изменить SSA форму"
 
 #: tree-into-ssa.c:3396 tree-outof-ssa.c:824 tree-outof-ssa.c:883
 #: tree-ssa-coalesce.c:1012
@@ -27487,7 +23079,7 @@
 #: tree-profile.c:640
 #, gcc-internal-format
 msgid "target does not support atomic profile update, single mode is selected"
-msgstr ""
+msgstr "цель не поддерживает атомарное изменение профиля, выбран одиночный режим"
 
 #: tree-ssa-ccp.c:3461
 msgid "%Gargument %u null where non-null expected"
@@ -27494,32 +23086,29 @@
 msgstr ""
 
 #: tree-ssa-ccp.c:3466
-#, fuzzy, gcc-internal-format
-#| msgid "invalid argument to built-in function"
+#, gcc-internal-format
 msgid "in a call to built-in function %qD"
-msgstr "некорректный аргумент встроенной функции"
+msgstr "в вызове встроенной функции %qD"
 
 #: tree-ssa-ccp.c:3470
-#, fuzzy, gcc-internal-format
-#| msgid "inline function %q+D declared weak"
+#, gcc-internal-format
 msgid "in a call to function %qD declared here"
-msgstr "inline функция %q+D объявлена weak"
+msgstr "в вызове функции %qD определенной здесь"
 
 #: tree-ssa-loop-niter.c:3049
 #, gcc-internal-format, gfc-internal-format
 msgid "iteration %s invokes undefined behavior"
-msgstr ""
+msgstr "итерация %s включает неопределенное поведение"
 
 #: tree-ssa-loop-niter.c:3050
-#, fuzzy, gcc-internal-format
-#| msgid "within this context"
+#, gcc-internal-format
 msgid "within this loop"
-msgstr "в данном контексте"
+msgstr "внутри этого цикла"
 
 #: tree-ssa-loop-prefetch.c:2065
 #, gcc-internal-format
 msgid "%<l1-cache-size%> parameter is not a power of two %d"
-msgstr ""
+msgstr "%<l1-cache-size%> параметр не степень двойки %d"
 
 #: tree-ssa-operands.c:975
 #, gcc-internal-format
@@ -27556,7 +23145,7 @@
 msgid "stmt volatile flag not up-to-date"
 msgstr "флаг volatile в операторе не соответствует текущему состоянию"
 
-#: tree-ssa-strlen.c:1975
+#: tree-ssa-strlen.c:1999
 msgid "%G%qD output truncated before terminating nul copying %E byte from a string of the same length"
 msgid_plural "%G%qD output truncated before terminating nul copying %E bytes from a string of the same length"
 msgstr[0] ""
@@ -27563,7 +23152,7 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: tree-ssa-strlen.c:1989
+#: tree-ssa-strlen.c:2013
 msgid "%G%qD output truncated copying %E byte from a string of length %wu"
 msgid_plural "%G%qD output truncated copying %E bytes from a string of length %wu"
 msgstr[0] ""
@@ -27570,11 +23159,11 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: tree-ssa-strlen.c:1996
+#: tree-ssa-strlen.c:2020
 msgid "%G%qD output truncated copying between %wu and %wu bytes from a string of length %wu"
 msgstr ""
 
-#: tree-ssa-strlen.c:2008
+#: tree-ssa-strlen.c:2032
 msgid "%G%qD output may be truncated copying %E byte from a string of length %wu"
 msgid_plural "%G%qD output may be truncated copying %E bytes from a string of length %wu"
 msgstr[0] ""
@@ -27581,25 +23170,24 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: tree-ssa-strlen.c:2015 tree-ssa-strlen.c:2029
+#: tree-ssa-strlen.c:2039 tree-ssa-strlen.c:2053
 msgid "%G%qD output may be truncated copying between %wu and %wu bytes from a string of length %wu"
 msgstr ""
 
-#: tree-ssa-strlen.c:2150
+#: tree-ssa-strlen.c:2174
 msgid "%G%qD output truncated before terminating nul copying as many bytes from a string as its length"
 msgstr ""
 
-#: tree-ssa-strlen.c:2156
+#: tree-ssa-strlen.c:2180
 msgid "%G%qD specified bound depends on the length of the source argument"
 msgstr ""
 
-#: tree-ssa-strlen.c:2163
-#, fuzzy, gcc-internal-format
-#| msgid "length modifier"
+#: tree-ssa-strlen.c:2187
+#, gcc-internal-format
 msgid "length computed here"
-msgstr "модификатор размера"
+msgstr ""
 
-#: tree-ssa-uninit.c:191 varasm.c:331
+#: tree-ssa-uninit.c:191 varasm.c:342
 #, gcc-internal-format
 msgid "%qD was declared here"
 msgstr "%qD было объявлено здесь"
@@ -27627,23 +23215,22 @@
 #: tree-ssa.c:647
 #, gcc-internal-format, gfc-internal-format
 msgid "multiple virtual PHI nodes in BB %d"
-msgstr ""
+msgstr "множественные виртуальные PHI узлы в BB %d"
 
 #: tree-ssa.c:661 tree-ssa.c:690
-#, fuzzy, gcc-internal-format
-#| msgid "virtual definition of statement not up-to-date"
+#, gcc-internal-format
 msgid "virtual definition is not an SSA name"
-msgstr "виртуальное определение оператора не соответствует текущему состоянию"
+msgstr "виртуальное определение не есть SSA имя"
 
 #: tree-ssa.c:677
 #, gcc-internal-format
 msgid "stmt with wrong VUSE"
-msgstr ""
+msgstr "оператор в неверным VUSE"
 
 #: tree-ssa.c:707
 #, gcc-internal-format, gfc-internal-format
 msgid "PHI node with wrong VUSE on edge from BB %d"
-msgstr ""
+msgstr "PHI узел с неверным VUSE на ребре из BB %d"
 
 #: tree-ssa.c:733
 #, gcc-internal-format
@@ -27683,7 +23270,7 @@
 #: tree-ssa.c:801
 #, gcc-internal-format
 msgid "RESULT_DECL should be read only when DECL_BY_REFERENCE is set"
-msgstr "RESULT_DECL должно читаться только когда установлено DECL_BY_REFERENCE"
+msgstr "RESULT_DECL должно читаться, только когда установлено DECL_BY_REFERENCE"
 
 #: tree-ssa.c:807
 #, gcc-internal-format, gfc-internal-format
@@ -27748,7 +23335,7 @@
 #: tree-ssa.c:1069
 #, gcc-internal-format
 msgid "shared SSA name info"
-msgstr ""
+msgstr "информация о разделяемом SSA имени"
 
 #: tree-ssa.c:1096
 #, gcc-internal-format, gfc-internal-format
@@ -27775,28 +23362,27 @@
 msgid "target specific builtin not available"
 msgstr "специфическая для целевой платформы встроенная функция недоступна"
 
-#: tree-vect-generic.c:287
+#: tree-vect-generic.c:283
 #, gcc-internal-format
 msgid "vector operation will be expanded piecewise"
 msgstr "векторная операция будет выполнена по частям"
 
-#: tree-vect-generic.c:290
+#: tree-vect-generic.c:286
 #, gcc-internal-format
 msgid "vector operation will be expanded in parallel"
 msgstr "векторная операция будет выполнена параллельно"
 
-#: tree-vect-generic.c:341
+#: tree-vect-generic.c:337
 #, gcc-internal-format
 msgid "vector operation will be expanded with a single scalar operation"
 msgstr "векторная операция будет выполнена при помощи одной скалярной операции"
 
-#: tree-vect-generic.c:941
-#, fuzzy, gcc-internal-format
-#| msgid "vector operation will be expanded piecewise"
+#: tree-vect-generic.c:937
+#, gcc-internal-format
 msgid "vector condition will be expanded piecewise"
-msgstr "векторная операция будет выполнена по частям"
+msgstr "векторное условие будет расширено по частям"
 
-#: tree-vect-generic.c:1373
+#: tree-vect-generic.c:1369
 #, gcc-internal-format
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr "векторная операция перемешивания будет выполнена по частям"
@@ -27804,137 +23390,129 @@
 #: tree-vect-loop.c:4038
 #, gcc-internal-format
 msgid "vectorization did not happen for a simd loop"
-msgstr ""
+msgstr "векторизация не получилась для simd цикла"
 
-#: tree-vrp.c:4930 tree-vrp.c:4974
-#, fuzzy, gcc-internal-format
-#| msgid "array subscript is above array bounds"
+#: tree-vrp.c:4931 tree-vrp.c:4975
+#, gcc-internal-format
 msgid "array subscript %E is above array bounds of %qT"
-msgstr "индекс массива превышает верхнее граничное значение"
+msgstr ""
 
-#: tree-vrp.c:4956
-#, fuzzy, gcc-internal-format
-#| msgid "array subscript is outside array bounds"
+#: tree-vrp.c:4957
+#, gcc-internal-format
 msgid "array subscript [%E, %E] is outside array bounds of %qT"
-msgstr "индекс массива вне диапазона границ массива"
+msgstr ""
 
-#: tree-vrp.c:4988
-#, fuzzy, gcc-internal-format
-#| msgid "array subscript is below array bounds"
+#: tree-vrp.c:4989
+#, gcc-internal-format
 msgid "array subscript %E is below array bounds of %qT"
-msgstr "индекс массива меньше нижнего граничного значения"
+msgstr ""
 
-#: tree-vrp.c:5046
-#, fuzzy, gcc-internal-format
-#| msgid "array subscript is below array bounds"
+#: tree-vrp.c:5047
+#, gcc-internal-format
 msgid "array subscript %wi is below array bounds of %qT"
-msgstr "индекс массива меньше нижнего граничного значения"
+msgstr ""
 
-#: tree-vrp.c:5060
-#, fuzzy, gcc-internal-format
-#| msgid "array subscript is above array bounds"
+#: tree-vrp.c:5061
+#, gcc-internal-format
 msgid "array subscript %wu is above array bounds of %qT"
-msgstr "индекс массива превышает верхнее граничное значение"
+msgstr ""
 
 #: tree.c:1987
 #, gcc-internal-format
 msgid "non-constant element in constant CONSTRUCTOR"
-msgstr ""
+msgstr "неконстантный элемент в константном CONSTRUCTOR"
 
 #: tree.c:1989
 #, gcc-internal-format
 msgid "side-effects element in no-side-effects CONSTRUCTOR"
-msgstr ""
+msgstr "элемент с побочными эффектами в no-side-effects CONSTRUCTOR"
 
-#: tree.c:7852
+#: tree.c:7856
 #, gcc-internal-format
 msgid "arrays of functions are not meaningful"
 msgstr "массивы функций не имеют осмысленной интерпретации"
 
-#: tree.c:8019
+#: tree.c:8023
 #, gcc-internal-format
 msgid "function return type cannot be function"
 msgstr "результат функции не может иметь тип функции"
 
-#: tree.c:9327 tree.c:9412 tree.c:9473
+#: tree.c:9331 tree.c:9416 tree.c:9477
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: %s, have %s in %s, at %s:%d"
 msgstr "дерево: %s, имеется %s в %s, на %s:%d"
 
-#: tree.c:9364
+#: tree.c:9368
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected none of %s, have %s in %s, at %s:%d"
 msgstr "дерево: не ожидалось ничего из %s, обнаружено %s в %s, на %s:%d"
 
-#: tree.c:9377
+#: tree.c:9381
 #, gcc-internal-format
 msgid "tree check: expected class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "дерево: ожидался класс %qs, обнаружен %qs (%s) в %s, на %s:%d"
 
-#: tree.c:9426
+#: tree.c:9430
 #, gcc-internal-format
 msgid "tree check: did not expect class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "дерево: не ожидался класс %qs, обнаружен %qs (%s) в %s, на %s:%d"
 
-#: tree.c:9439
+#: tree.c:9443
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected omp_clause %s, have %s in %s, at %s:%d"
 msgstr "дерево: ожидалось omp_clause %s, обнаружено %s в %s, на %s:%d"
 
-#: tree.c:9499
+#: tree.c:9503
 #, gcc-internal-format
 msgid "tree check: expected tree that contains %qs structure, have %qs in %s, at %s:%d"
 msgstr "дерево: ожидалось дерево, содержащее структуру %qs, обнаружено %qs в %s, на %s:%d"
 
-#: tree.c:9513
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "tree check: accessed elt %d of tree_vec with %d elts in %s, at %s:%d"
+#: tree.c:9517
+#, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_int_cst with %d elts in %s, at %s:%d"
-msgstr "дерево: доступ к элементу %d вектора tree_vec с %d элементами в %s, на %s:%d"
+msgstr "проверка дерева: доступ к элементу %d tree_int_cst с %d элементами в %s, на %s:%d"
 
-#: tree.c:9525
+#: tree.c:9529
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_vec with %d elts in %s, at %s:%d"
 msgstr "дерево: доступ к элементу %d вектора tree_vec с %d элементами в %s, на %s:%d"
 
-#: tree.c:9538
+#: tree.c:9542
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of %s with %d operands in %s, at %s:%d"
 msgstr "дерево: доступ к операнду %d функции %s с %d операндами в %s, в %s:%d"
 
-#: tree.c:9551
+#: tree.c:9555
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of omp_clause %s with %d operands in %s, at %s:%d"
 msgstr "дерево: доступ к операнду %d функции omp_clause %s с %d операндами в %s, в %s:%d"
 
-#: tree.c:12446
-#, fuzzy, gcc-internal-format
-#| msgid "%qE is deprecated: %s"
+#: tree.c:12450
+#, gcc-internal-format
 msgid "%qD is deprecated: %s"
-msgstr "%qE устаревшее: %s"
+msgstr "%qD устарело: %s"
 
-#: tree.c:12449
-#, fuzzy, gcc-internal-format
-#| msgid "%qE is deprecated"
+#: tree.c:12453
+#, gcc-internal-format
 msgid "%qD is deprecated"
-msgstr "имя %qE будет исключено в будущих версиях"
+msgstr "%qD устарело"
 
-#: tree.c:12473 tree.c:12495
+#: tree.c:12477 tree.c:12499
 #, gcc-internal-format
 msgid "%qE is deprecated: %s"
 msgstr "%qE устаревшее: %s"
 
-#: tree.c:12476 tree.c:12498
+#: tree.c:12480 tree.c:12502
 #, gcc-internal-format
 msgid "%qE is deprecated"
 msgstr "имя %qE будет исключено в будущих версиях"
 
-#: tree.c:12482 tree.c:12503
+#: tree.c:12486 tree.c:12507
 #, gcc-internal-format, gfc-internal-format
 msgid "type is deprecated: %s"
 msgstr "поддержка данного типа будет исключена в будущих версиях: %s"
 
-#: tree.c:12485 tree.c:12506
+#: tree.c:12489 tree.c:12510
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr "поддержка данного типа будет исключена в будущих версиях"
@@ -27959,250 +23537,245 @@
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.c:13043
+#: tree.c:13047
 #, gcc-internal-format, gfc-internal-format
 msgid "type variant differs by %s"
 msgstr ""
 
-#: tree.c:13084
+#: tree.c:13088
 #, gcc-internal-format
 msgid "type variant has different TYPE_SIZE_UNIT"
-msgstr ""
+msgstr "вариант типа имеет другой TYPE_SIZE_UNIT"
 
-#: tree.c:13086
+#: tree.c:13090
 #, gcc-internal-format
 msgid "type variant's TYPE_SIZE_UNIT"
-msgstr ""
+msgstr "TYPE_SIZE_UNIT варианта типа"
 
-#: tree.c:13088
+#: tree.c:13092
 #, gcc-internal-format
 msgid "type's TYPE_SIZE_UNIT"
-msgstr ""
+msgstr "TYPE_SIZE_UNIT типа"
 
-#: tree.c:13108
+#: tree.c:13112
 #, gcc-internal-format
 msgid "type variant with TYPE_ALIAS_SET_KNOWN_P"
-msgstr ""
+msgstr "вариант типа с TYPE_ALIAS_SET_KNOWN_P"
 
-#: tree.c:13121
+#: tree.c:13125
 #, gcc-internal-format
 msgid "type variant has different TYPE_VFIELD"
-msgstr ""
+msgstr "вариант типа имеет другой TYPE_VFIELD"
 
-#: tree.c:13157
+#: tree.c:13161
 #, gcc-internal-format
 msgid "type variant has different TYPE_BINFO"
-msgstr ""
+msgstr "вариант типа имеет другой TYPE_BINFO"
 
-#: tree.c:13159
+#: tree.c:13163
 #, gcc-internal-format
 msgid "type variant's TYPE_BINFO"
-msgstr ""
+msgstr "TYPE_BINFO варианта типа"
 
-#: tree.c:13161
+#: tree.c:13165
 #, gcc-internal-format
 msgid "type's TYPE_BINFO"
-msgstr ""
+msgstr "TYPE_BINFO типа"
 
-#: tree.c:13199
+#: tree.c:13203
 #, gcc-internal-format
 msgid "type variant has different TYPE_FIELDS"
-msgstr ""
+msgstr "вариант типа имеет другой TYPE_FIELDS"
 
-#: tree.c:13201
+#: tree.c:13205
 #, gcc-internal-format
 msgid "first mismatch is field"
-msgstr ""
+msgstr "первое несоответствие является полем"
 
-#: tree.c:13203
+#: tree.c:13207
 #, gcc-internal-format
 msgid "and field"
-msgstr ""
+msgstr "и поле"
 
-#: tree.c:13220
+#: tree.c:13224
 #, gcc-internal-format
 msgid "type variant has different TREE_TYPE"
-msgstr ""
+msgstr "вариант типа имеет другой TREE_TYPE"
 
-#: tree.c:13222 tree.c:13233
+#: tree.c:13226 tree.c:13237
 #, gcc-internal-format
 msgid "type variant's TREE_TYPE"
-msgstr ""
+msgstr "TREE_TYPE варианта типа"
 
-#: tree.c:13224 tree.c:13235
+#: tree.c:13228 tree.c:13239
 #, gcc-internal-format
 msgid "type's TREE_TYPE"
-msgstr ""
+msgstr "TREE_TYPE типа"
 
-#: tree.c:13231
-#, fuzzy, gcc-internal-format
-#| msgid "%qD is not compatible with %qD"
+#: tree.c:13235
+#, gcc-internal-format
 msgid "type is not compatible with its variant"
-msgstr "%qD не совместим с %qD"
+msgstr "тип не совместим со своим вариантом"
 
-#: tree.c:13534
-#, fuzzy, gcc-internal-format
-#| msgid "environment variable %qs not defined"
+#: tree.c:13538
+#, gcc-internal-format
 msgid "Main variant is not defined"
-msgstr "переменная окружения %qs не определена"
+msgstr "Главный вариант не определен"
 
-#: tree.c:13539
+#: tree.c:13543
 #, gcc-internal-format
 msgid "TYPE_MAIN_VARIANT has different TYPE_MAIN_VARIANT"
-msgstr ""
+msgstr "TYPE_MAIN_VARIANT имеет другой TYPE_MAIN_VARIANT"
 
-#: tree.c:13551
+#: tree.c:13555
 #, gcc-internal-format
 msgid "TYPE_CANONICAL has different TYPE_CANONICAL"
-msgstr ""
+msgstr "TYPE_CANONICAL имеет другой TYPE_CANONICAL"
 
-#: tree.c:13569
+#: tree.c:13573
 #, gcc-internal-format
 msgid "TYPE_CANONICAL is not compatible"
-msgstr ""
+msgstr "TYPE_CANONICAL несовместим"
 
-#: tree.c:13577
+#: tree.c:13581
 #, gcc-internal-format
 msgid "TYPE_MODE of TYPE_CANONICAL is not compatible"
-msgstr ""
+msgstr "TYPE_MODE от TYPE_CANONICAL несовместим"
 
-#: tree.c:13583
+#: tree.c:13587
 #, gcc-internal-format
 msgid "TYPE_CANONICAL of main variant is not main variant"
-msgstr ""
+msgstr "TYPE_CANONICAL от главного варианта не есть главный вариант"
 
-#: tree.c:13599
+#: tree.c:13603
 #, gcc-internal-format
 msgid "TYPE_VFIELD is not FIELD_DECL nor TREE_LIST"
-msgstr ""
+msgstr "TYPE_VFIELD не есть ни FIELD_DECL ни TREE_LIST"
 
-#: tree.c:13609
+#: tree.c:13613
 #, gcc-internal-format
 msgid "TYPE_NEXT_PTR_TO is not POINTER_TYPE"
-msgstr ""
+msgstr "TYPE_NEXT_PTR_TO не есть POINTER_TYPE"
 
-#: tree.c:13619
+#: tree.c:13623
 #, gcc-internal-format
 msgid "TYPE_NEXT_REF_TO is not REFERENCE_TYPE"
-msgstr ""
+msgstr "TYPE_NEXT_REF_TO не есть REFERENCE_TYPE"
 
-#: tree.c:13640
+#: tree.c:13644
 #, gcc-internal-format
 msgid "TYPE_BINFO is not TREE_BINFO"
-msgstr ""
+msgstr "TYPE_BINFO не есть TREE_BINFO"
 
-#: tree.c:13646
+#: tree.c:13650
 #, gcc-internal-format
 msgid "TYPE_BINFO type is not TYPE_MAIN_VARIANT"
-msgstr ""
+msgstr "TYPE_BINFO тип не есть TYPE_MAIN_VARIANT"
 
-#: tree.c:13657
+#: tree.c:13661
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not record nor union"
-msgstr ""
+msgstr "TYPE_METHOD_BASETYPE не есть ни record ни union"
 
-#: tree.c:13668
+#: tree.c:13672
 #, gcc-internal-format
 msgid "TYPE_OFFSET_BASETYPE is not record nor union"
-msgstr ""
+msgstr "TYPE_OFFSET_BASETYPE не есть ни record ни union"
 
-#: tree.c:13686
+#: tree.c:13690
 #, gcc-internal-format
 msgid "TYPE_ARRAY_MAX_SIZE not INTEGER_CST"
-msgstr ""
+msgstr "TYPE_ARRAY_MAX_SIZE не INTEGER_CST"
 
-#: tree.c:13693
+#: tree.c:13697
 #, gcc-internal-format
 msgid "TYPE_MAX_VALUE_RAW non-NULL"
 msgstr ""
 
-#: tree.c:13700
+#: tree.c:13704
 #, gcc-internal-format
 msgid "TYPE_LANG_SLOT_1 (binfo) field is non-NULL"
-msgstr ""
+msgstr "TYPE_LANG_SLOT_1 (binfo) поле не-NULL"
 
-#: tree.c:13716
+#: tree.c:13720
 #, gcc-internal-format
 msgid "Enum value is not CONST_DECL or INTEGER_CST"
-msgstr ""
+msgstr "Enum значение не есть CONST_DECL или INTEGER_CST"
 
-#: tree.c:13724
+#: tree.c:13728
 #, gcc-internal-format
 msgid "Enum value type is not INTEGER_TYPE nor convertible to the enum"
-msgstr ""
+msgstr "Тип enum значения не есть ни INTEGER_TYPE ни преобразуемый в enum"
 
-#: tree.c:13731
+#: tree.c:13735
 #, gcc-internal-format
 msgid "Enum value name is not IDENTIFIER_NODE"
-msgstr ""
+msgstr "Имя enum значения не есть IDENTIFIER_NODE"
 
-#: tree.c:13741
-#, fuzzy, gcc-internal-format
-#| msgid "size of array %qE has non-integer type"
+#: tree.c:13745
+#, gcc-internal-format
 msgid "Array TYPE_DOMAIN is not integer type"
-msgstr "размер массива %qE имеет не целочисленный тип"
+msgstr "Массивный TYPE_DOMAIN не есть целочисленный тип"
 
-#: tree.c:13750
-#, fuzzy, gcc-internal-format
-#| msgid "field %qE has incomplete type"
+#: tree.c:13754
+#, gcc-internal-format
 msgid "TYPE_FIELDS defined in incomplete type"
-msgstr "поле %qE имеет неполный тип"
+msgstr "TYPE_FIELDS определено в неполном типе"
 
-#: tree.c:13772
+#: tree.c:13776
 #, gcc-internal-format
 msgid "Wrong tree in TYPE_FIELDS list"
-msgstr ""
+msgstr "Неверное дерево в TYPE_FIELDS списке"
 
-#: tree.c:13787
+#: tree.c:13791
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is %i while TYPE_CACHED_VALUES is %p"
-msgstr ""
+msgstr "TYPE_CACHED_VALUES_P есть %i, в то время как TYPE_CACHED_VALUES есть %p"
 
-#: tree.c:13793
+#: tree.c:13797
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES is not TREE_VEC"
-msgstr ""
+msgstr "TYPE_CACHED_VALUES не есть TREE_VEC"
 
-#: tree.c:13806
+#: tree.c:13810
 #, gcc-internal-format
 msgid "wrong TYPE_CACHED_VALUES entry"
-msgstr ""
+msgstr "неверный TYPE_CACHED_VALUES элемент"
 
-#: tree.c:13819
+#: tree.c:13823
 #, gcc-internal-format
 msgid "TREE_PURPOSE is non-NULL in TYPE_ARG_TYPES list"
-msgstr ""
+msgstr "TREE_PURPOSE не-NULL в TYPE_ARG_TYPES списке"
 
-#: tree.c:13825
+#: tree.c:13829
 #, gcc-internal-format
 msgid "Wrong entry in TYPE_ARG_TYPES list"
-msgstr ""
+msgstr "Неверный элемент в TYPE_ARG_TYPES списке"
 
-#: tree.c:13832
+#: tree.c:13836
 #, gcc-internal-format
 msgid "TYPE_VALUES_RAW field is non-NULL"
-msgstr ""
+msgstr "TYPE_VALUES_RAW поле не-NULL"
 
-#: tree.c:13844
+#: tree.c:13848
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is set while it should not"
-msgstr ""
+msgstr "TYPE_CACHED_VALUES_P установлен хотя не должен"
 
-#: tree.c:13850
+#: tree.c:13854
 #, gcc-internal-format
 msgid "TYPE_STRING_FLAG is set on wrong type code"
-msgstr ""
+msgstr "TYPE_STRING_FLAG установлен у кода неверного типа"
 
-#: tree.c:13860
+#: tree.c:13864
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not main variant"
-msgstr ""
+msgstr "TYPE_METHOD_BASETYPE не есть главный вариант"
 
-#: tree.c:13867
-#, fuzzy, gcc-internal-format
-#| msgid "verify_gimple failed"
+#: tree.c:13871
+#, gcc-internal-format
 msgid "verify_type failed"
-msgstr "процедура verify_gimple выявила ошибки"
+msgstr "ошибка verify_type"
 
 #: value-prof.c:510
 #, gcc-internal-format
@@ -28224,191 +23797,182 @@
 msgid "corrupted value profile: %s profile counter (%d out of %d) inconsistent with basic-block count (%d)"
 msgstr "Испорчен профиль значений: общий счётчик профиля %s (%d из %d) не соответствует счетчику блока (%d)"
 
-#: var-tracking.c:7166
+#: var-tracking.c:7184
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded with -fvar-tracking-assignments, retrying without"
 msgstr "лимит памяти для отслеживания переменных превышен с -fvar-tracking-assignments, повторная попытка без этого ключа"
 
-#: var-tracking.c:7170
+#: var-tracking.c:7188
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded"
 msgstr "лимит памяти для отслеживания переменных превышен"
 
-#: varasm.c:326
-#, fuzzy, gcc-internal-format
-#| msgid "%+D causes a section type conflict with %D"
+#: varasm.c:337
+#, gcc-internal-format
 msgid "%+qD causes a section type conflict with %qD"
-msgstr "%+D создает конфликт типов секций с %D"
+msgstr ""
 
-#: varasm.c:329
-#, fuzzy, gcc-internal-format
-#| msgid "%+D causes a section type conflict with %D"
+#: varasm.c:340
+#, gcc-internal-format
 msgid "section type conflict with %qD"
-msgstr "%+D создает конфликт типов секций с %D"
+msgstr ""
 
-#: varasm.c:334
-#, fuzzy, gcc-internal-format
-#| msgid "%+D causes a section type conflict"
+#: varasm.c:345
+#, gcc-internal-format
 msgid "%+qD causes a section type conflict"
-msgstr "%+D создает конфликт типов секций"
+msgstr ""
 
-#: varasm.c:336
-#, fuzzy, gcc-internal-format
-#| msgid "%+D causes a section type conflict"
+#: varasm.c:347
+#, gcc-internal-format
 msgid "section type conflict"
-msgstr "%+D создает конфликт типов секций"
+msgstr "конфликт типа секции"
 
-#: varasm.c:1019
-#, fuzzy, gcc-internal-format
-#| msgid "alignment of %q+D is greater than maximum object file alignment.  Using %d"
+#: varasm.c:1030
+#, gcc-internal-format
 msgid "alignment of %q+D is greater than maximum object file alignment %d"
-msgstr "выравнивание %q+D превышает максимальное выравнивание в объектном файле. Используется %d"
+msgstr "выравнивание %qD превышает максимальное выравнивание в объектном файле %d"
 
-#: varasm.c:1172
-#, fuzzy, gcc-internal-format
-#| msgid "only uninitialized variables can be placed in a .bss section"
+#: varasm.c:1183
+#, gcc-internal-format
 msgid "only zero initializers are allowed in section %qs"
-msgstr "в секции .bss размещаются только неинициализированные данные"
+msgstr "только нулевые инициализаторы допускаются в секции %qs"
 
-#: varasm.c:1378 varasm.c:1387
+#: varasm.c:1389 varasm.c:1398
 #, gcc-internal-format
 msgid "register name not specified for %q+D"
 msgstr "не задано имя регистра для %q+D"
 
-#: varasm.c:1389
+#: varasm.c:1400
 #, gcc-internal-format
 msgid "invalid register name for %q+D"
 msgstr "некорректное имя регистра для %q+D"
 
-#: varasm.c:1391
+#: varasm.c:1402
 #, gcc-internal-format
 msgid "data type of %q+D isn%'t suitable for a register"
 msgstr "данные типа %q+D нельзя поместить на регистр"
 
-#: varasm.c:1394
+#: varasm.c:1405
 #, gcc-internal-format
 msgid "the register specified for %q+D cannot be accessed by the current target"
 msgstr "регистр, заданный для %q+D, не доступен для заданной целевой платформы"
 
-#: varasm.c:1397
+#: varasm.c:1408
 #, gcc-internal-format
 msgid "the register specified for %q+D is not general enough to be used as a register variable"
 msgstr "регистр, заданный для %q+D, не достаточно общий для использования в качестве регистровой переменной"
 
-#: varasm.c:1400
+#: varasm.c:1411
 #, gcc-internal-format
 msgid "register specified for %q+D isn%'t suitable for data type"
 msgstr "регистр, заданный для %q+D, не годится для этого типа данных"
 
-#: varasm.c:1410
+#: varasm.c:1421
 #, gcc-internal-format
 msgid "global register variable has initial value"
 msgstr "глобальная регистровая переменная имеет начальное значение"
 
-#: varasm.c:1414
+#: varasm.c:1425
 #, gcc-internal-format
 msgid "optimization may eliminate reads and/or writes to register variables"
 msgstr "оптимизация может удалить чтения или записи регистровых переменных"
 
-#: varasm.c:1460
+#: varasm.c:1471
 #, gcc-internal-format
 msgid "register name given for non-register variable %q+D"
 msgstr "имя регистра задано для нерегистровой переменной %q+D"
 
-#: varasm.c:1870
+#: varasm.c:1881
 #, gcc-internal-format
 msgid "Patchable function entry > size"
 msgstr ""
 
-#: varasm.c:2069
+#: varasm.c:2080
 #, gcc-internal-format
 msgid "thread-local COMMON data not implemented"
 msgstr "поддержка локально-поточных COMMON-данных не реализована"
 
-#: varasm.c:2102
+#: varasm.c:2113
 #, gcc-internal-format
 msgid "requested alignment for %q+D is greater than implemented alignment of %wu"
 msgstr "запрошенное выравнивание для %q+D превышает поддерживаемое выравнивание для %wu"
 
-#: varasm.c:2205 c/c-decl.c:5027 c/c-parser.c:1534
+#: varasm.c:2216 c/c-decl.c:5027 c/c-parser.c:1534
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t known"
 msgstr "размер %q+D в памяти неизвестен"
 
-#: varasm.c:4910
+#: varasm.c:4921
 #, gcc-internal-format
 msgid "initializer for integer/fixed-point value is too complicated"
 msgstr "слишком сложное инициализирующее выражение для целого или значения с фиксированной точкой"
 
-#: varasm.c:4915
+#: varasm.c:4926
 #, gcc-internal-format
 msgid "initializer for floating value is not a floating constant"
 msgstr "инициализирующее выражение для плавающего не является плавающей константой"
 
-#: varasm.c:5227
+#: varasm.c:5238
 #, gcc-internal-format
 msgid "invalid initial value for member %qE"
 msgstr "некорректное начальное значение для элемента %qE"
 
-#: varasm.c:5487
-#, fuzzy, gcc-internal-format
-#| msgid "%q+D declared inline after being called"
+#: varasm.c:5498
+#, gcc-internal-format
 msgid "%+qD declared weak after being used"
-msgstr "%q+D: inline-декларация после вызова"
+msgstr ""
 
-#: varasm.c:5539
-#, fuzzy, gcc-internal-format
-#| msgid "weak declaration of %q+D must precede definition"
+#: varasm.c:5550
+#, gcc-internal-format
 msgid "weak declaration of %q+D being applied to a already existing, static definition"
-msgstr "weak декларация %q+D должна предшествовать определению"
+msgstr "weak декларация %q+D применяется к уже существующему static определению"
 
-#: varasm.c:5575
+#: varasm.c:5586
 #, gcc-internal-format
 msgid "weak declaration of %q+D must be public"
 msgstr "weak декларация %q+D должна быть public"
 
-#: varasm.c:5579
+#: varasm.c:5590
 #, gcc-internal-format
 msgid "weak declaration of %q+D not supported"
 msgstr "weak декларация %q+D не поддерживается"
 
-#: varasm.c:5608 varasm.c:5912
+#: varasm.c:5619 varasm.c:5926
 #, gcc-internal-format
 msgid "only weak aliases are supported in this configuration"
 msgstr "в данной конфигурации поддерживаются только слабые алиасы"
 
-#: varasm.c:5802
+#: varasm.c:5813
 #, gcc-internal-format
 msgid "weakref is not supported in this configuration"
 msgstr "weakref в данной конфигурации не поддерживается"
 
-#: varasm.c:5834
-#, fuzzy, gcc-internal-format
-#| msgid "nested functions not supported on this target"
+#: varasm.c:5846
+#, gcc-internal-format
 msgid "ifunc is not supported on this target"
-msgstr "вложенные функции не поддерживаются для этой платформы"
+msgstr "ifunc не поддерживается на этой платформе"
 
-#: varasm.c:5892
+#: varasm.c:5904
 #, gcc-internal-format
 msgid "weakref %q+D ultimately targets itself"
 msgstr "слабая ссылка %q+D в конечном счёте направлена на себя"
 
-#: varasm.c:5894
+#: varasm.c:5906
 #, gcc-internal-format
 msgid "weakref %q+D must have static linkage"
 msgstr "слабая ссылка %q+D должна иметь статическое связывание"
 
-#: varasm.c:5901
+#: varasm.c:5913
 #, gcc-internal-format
 msgid "alias definitions not supported in this configuration"
 msgstr "в данной конфигурации определения алиасов не поддерживаются"
 
-#: varasm.c:5909
+#: varasm.c:5923
 #, gcc-internal-format
 msgid "ifunc is not supported in this configuration"
 msgstr "ifunc в данной конфигурации не поддерживается"
 
-#: varasm.c:6127 config/sol2.c:159 config/i386/winnt.c:265
+#: varasm.c:6141 config/sol2.c:159 config/i386/winnt.c:265
 #, gcc-internal-format
 msgid "visibility attribute not supported in this configuration; ignored"
 msgstr "атрибут видимости не поддерживается в данной конфигурации; определение игнорируется"
@@ -28436,12 +24000,12 @@
 #: vr-values.c:2396
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying conditional to constant"
-msgstr "предполагается что не произойдет знакового переполнения при сведении условной операции к константе"
+msgstr "предполагается, что не произойдет знакового переполнения при сведении условной операции к константе"
 
 #: vr-values.c:2402
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying conditional"
-msgstr "предполагается что не произойдет знакового переполнения при упрощении условной операции"
+msgstr "предполагается, что не произойдет знакового переполнения при упрощении условной операции"
 
 #: vr-values.c:2446
 #, gcc-internal-format
@@ -28456,18 +24020,17 @@
 #: vr-values.c:3127
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying %</%> or %<%%%> to %<>>%> or %<&%>"
-msgstr "предполагается что не произойдет знакового переполнения при упрощении %</%> или %<%%%> до %<>>%> или %<&%>"
+msgstr "предполагается, что не произойдет знакового переполнения при упрощении %</%> или %<%%%> до %<>>%> или %<&%>"
 
 #: vr-values.c:3194
-#, fuzzy, gcc-internal-format
-#| msgid "assuming signed overflow does not occur when simplifying %<abs (X)%> to %<X%> or %<-X%>"
+#, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying %<min/max (X,Y)%> to %<X%> or %<Y%>"
-msgstr "предполагается что не произойдет знакового переполнения при упрощении %<abs (X)%> до %<X%> или %<-X%>"
+msgstr "предполагается, что не произойдет знакового переполнения при упрощении %<min/max (X,Y)%> в %<X%> или %<Y%>"
 
 #: vr-values.c:3245
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying %<abs (X)%> to %<X%> or %<-X%>"
-msgstr "предполагается что не произойдет знакового переполнения при упрощении %<abs (X)%> до %<X%> или %<-X%>"
+msgstr "предполагается, что не произойдет знакового переполнения при упрощении %<abs (X)%> до %<X%> или %<-X%>"
 
 #. Print an error message for unrecognized stab codes.
 #: xcoffout.c:194
@@ -28485,492 +24048,474 @@
 msgid "bytecode stream: tag %s is not in the expected range [%s, %s]"
 msgstr "поток байткода: тег %s вне ожидаемого диапазона [%s, %s]"
 
-#: c-family/c-attribs.c:529
+#: c-family/c-attribs.c:524
 #, gcc-internal-format
+msgid "%qE attribute ignored for type %qT"
+msgstr ""
+
+#: c-family/c-attribs.c:536
+#, gcc-internal-format
 msgid "%qE attribute ignored for field of type %qT"
 msgstr "атрибут %qE для поля типа %qT проигнорирован"
 
-#: c-family/c-attribs.c:696
-#, fuzzy, gcc-internal-format
-#| msgid "alias argument not a string"
+#: c-family/c-attribs.c:706
+#, gcc-internal-format
 msgid "no_sanitize argument not a string"
-msgstr "аргумент атрибута alias должен быть текстовой строкой"
+msgstr ""
 
-#: c-family/c-attribs.c:826 ada/gcc-interface/utils.c:6235
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute conflicts with attribute %s"
+#: c-family/c-attribs.c:837 ada/gcc-interface/utils.c:6240
+#, gcc-internal-format
 msgid "%qE attribute ignored due to conflict with attribute %qs"
-msgstr "атрибут %qE конфликтует с атрибутом %s"
+msgstr "атрибут %qE проигнорирован из-за конфликта с атрибутом %qs"
 
-#: c-family/c-attribs.c:875
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute conflicts with attribute %s"
+#: c-family/c-attribs.c:886
+#, gcc-internal-format
 msgid "%qE attribute ignored. Use -fcf-protection option to enable it"
-msgstr "атрибут %qE конфликтует с атрибутом %s"
+msgstr ""
 
-#: c-family/c-attribs.c:914 c-family/c-attribs.c:920 c-family/c-attribs.c:3388
-#: c-family/c-attribs.c:3423 c-family/c-attribs.c:3429
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute conflicts with attribute %s"
+#: c-family/c-attribs.c:925 c-family/c-attribs.c:931 c-family/c-attribs.c:3399
+#: c-family/c-attribs.c:3434 c-family/c-attribs.c:3440
+#, gcc-internal-format
 msgid "%qE attribute ignored due to conflict with %qs attribute"
-msgstr "атрибут %qE конфликтует с атрибутом %s"
+msgstr "атрибут %qE проигнорирован из-за конфликта с %qs атрибутом"
 
-#: c-family/c-attribs.c:976 brig/brig-lang.c:482 lto/lto-lang.c:288
+#: c-family/c-attribs.c:987 brig/brig-lang.c:482 lto/lto-lang.c:288
 #, gcc-internal-format
 msgid "%qE attribute has no effect on unit local functions"
 msgstr "атрибут %qE не действует для локальных функций"
 
-#: c-family/c-attribs.c:1130
+#: c-family/c-attribs.c:1141
 #, gcc-internal-format
 msgid "%qE attribute have effect only on public objects"
 msgstr "%qE атрибут действует только в public-объектах"
 
-#: c-family/c-attribs.c:1159
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute only applies to variables"
+#: c-family/c-attribs.c:1170
+#, gcc-internal-format
 msgid "%qE attribute only affects top level objects"
-msgstr "%qE атрибут применим только к переменным"
+msgstr "%qE атрибут воздействует только на объекты верхнего уровня"
 
-#: c-family/c-attribs.c:1198 c-family/c-attribs.c:2682
-#, fuzzy, gcc-internal-format
-#| msgid "using result of function returning %<void%>"
+#: c-family/c-attribs.c:1209 c-family/c-attribs.c:2693
+#, gcc-internal-format
 msgid "%qE attribute on function returning %<void%>"
-msgstr "использование результат функции, возвращающей %<void%>"
+msgstr ""
 
-#: c-family/c-attribs.c:1221 c-family/c-pragma.c:419
+#: c-family/c-attribs.c:1232 c-family/c-pragma.c:419
 #, gcc-internal-format
 msgid "scalar_storage_order is not supported because endianness is not uniform"
-msgstr ""
+msgstr "scalar_storage_order не поддерживается, так как порядок байт не однороден"
 
-#: c-family/c-attribs.c:1238
+#: c-family/c-attribs.c:1249
 #, gcc-internal-format
 msgid "scalar_storage_order argument must be one of \"big-endian\" or \"little-endian\""
-msgstr ""
+msgstr "scalar_storage_order аргумент должен быть одним из \"big-endian\" или \"little-endian\""
 
-#: c-family/c-attribs.c:1334
+#: c-family/c-attribs.c:1345
 #, gcc-internal-format
 msgid "destructor priorities are not supported"
 msgstr "приоритеты деструкторов не поддерживаются"
 
-#: c-family/c-attribs.c:1336
+#: c-family/c-attribs.c:1347
 #, gcc-internal-format
 msgid "constructor priorities are not supported"
 msgstr "приоритеты конструкторов не поддерживаются"
 
-#: c-family/c-attribs.c:1358
+#: c-family/c-attribs.c:1369
 #, gcc-internal-format, gfc-internal-format
 msgid "destructor priorities from 0 to %d are reserved for the implementation"
 msgstr "приоритеты деструкторов от 0 до %d зарезервированы для реализации"
 
-#: c-family/c-attribs.c:1363
+#: c-family/c-attribs.c:1374
 #, gcc-internal-format, gfc-internal-format
 msgid "constructor priorities from 0 to %d are reserved for the implementation"
 msgstr "приоритеты конструкторов от 0 до %d зарезервированы для реализации"
 
-#: c-family/c-attribs.c:1371
+#: c-family/c-attribs.c:1382
 #, gcc-internal-format, gfc-internal-format
 msgid "destructor priorities must be integers from 0 to %d inclusive"
 msgstr "приоритеты деструкторов должны быть целыми от 0 до %d включительно"
 
-#: c-family/c-attribs.c:1374
+#: c-family/c-attribs.c:1385
 #, gcc-internal-format, gfc-internal-format
 msgid "constructor priorities must be integers from 0 to %d inclusive"
 msgstr "приоритеты конструкторов должны быть целыми от 0 до %d включительно"
 
-#: c-family/c-attribs.c:1527
+#: c-family/c-attribs.c:1538
 #, gcc-internal-format
 msgid "unknown machine mode %qE"
 msgstr "неизвестная машинный режим %qE"
 
-#: c-family/c-attribs.c:1557
+#: c-family/c-attribs.c:1568
 #, gcc-internal-format
 msgid "specifying vector types with __attribute__ ((mode)) is deprecated"
 msgstr "задание векторного типа с __attribute__ ((mode)) не будет поддерживаться в будущих версиях"
 
-#: c-family/c-attribs.c:1560
+#: c-family/c-attribs.c:1571
 #, gcc-internal-format
 msgid "use __attribute__ ((vector_size)) instead"
 msgstr "используйте вместо него __attribute__ ((vector_size))"
 
-#: c-family/c-attribs.c:1569
+#: c-family/c-attribs.c:1580
 #, gcc-internal-format
 msgid "unable to emulate %qs"
 msgstr "эмуляция %qs невозможна"
 
-#: c-family/c-attribs.c:1582
+#: c-family/c-attribs.c:1593
 #, gcc-internal-format
 msgid "invalid pointer mode %qs"
 msgstr "неизвестная машинный режим %qs для указателя"
 
-#: c-family/c-attribs.c:1599
+#: c-family/c-attribs.c:1610
 #, gcc-internal-format
 msgid "signedness of type and machine mode %qs don%'t match"
 msgstr "знаковость типа и машинной моды %qs не соответствуют друг другу"
 
-#: c-family/c-attribs.c:1610
+#: c-family/c-attribs.c:1621
 #, gcc-internal-format
 msgid "no data type for mode %qs"
 msgstr "тип данных, соответствующий режиму %qs, не существует"
 
-#: c-family/c-attribs.c:1620
+#: c-family/c-attribs.c:1631
 #, gcc-internal-format
 msgid "cannot use mode %qs for enumeral types"
 msgstr "использование режима %qs для перечислимых типов недопустимо"
 
-#: c-family/c-attribs.c:1647
+#: c-family/c-attribs.c:1658
 #, gcc-internal-format
 msgid "mode %qs applied to inappropriate type"
 msgstr "режим %qs применен к неподходящему типу"
 
-#: c-family/c-attribs.c:1669
+#: c-family/c-attribs.c:1680
 #, gcc-internal-format
 msgid "section attributes are not supported for this target"
 msgstr "атрибут section для данной платформы не поддерживается"
 
-#: c-family/c-attribs.c:1675
+#: c-family/c-attribs.c:1686
 #, gcc-internal-format
 msgid "section attribute not allowed for %q+D"
 msgstr "атрибут section для %q+D недопустим"
 
-#: c-family/c-attribs.c:1681
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute argument not a string constant"
+#: c-family/c-attribs.c:1692
+#, gcc-internal-format
 msgid "section attribute argument not a string constant"
-msgstr "аргумент атрибута %qE не строковая константа"
+msgstr "аргумент атрибута секции не строковая константа"
 
-#: c-family/c-attribs.c:1690
+#: c-family/c-attribs.c:1701
 #, gcc-internal-format
 msgid "section attribute cannot be specified for local variables"
 msgstr "атрибут section недопустим для локальных переменных"
 
-#: c-family/c-attribs.c:1700 config/bfin/bfin.c:4806 config/bfin/bfin.c:4857
+#: c-family/c-attribs.c:1711 config/bfin/bfin.c:4806 config/bfin/bfin.c:4857
 #: config/bfin/bfin.c:4883 config/bfin/bfin.c:4896
 #, gcc-internal-format
 msgid "section of %q+D conflicts with previous declaration"
 msgstr "атрибут section, заданный для %q+D, противоречит предшествующей декларации"
 
-#: c-family/c-attribs.c:1708
+#: c-family/c-attribs.c:1719
 #, gcc-internal-format
 msgid "section of %q+D cannot be overridden"
 msgstr "секция %q+D не может быть переопределена"
 
-#: c-family/c-attribs.c:1773
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "requested alignment is too large"
+#: c-family/c-attribs.c:1784
+#, gcc-internal-format, gfc-internal-format
 msgid "requested alignment %d is larger than %d"
-msgstr "выравнивание слишком велико"
+msgstr "запрошенное выравнивание %d больше чем %d"
 
-#: c-family/c-attribs.c:1866
+#: c-family/c-attribs.c:1877
 #, gcc-internal-format
 msgid "alignment may not be specified for %q+D"
 msgstr "нельзя задавать выравнивание для %q+D"
 
-#: c-family/c-attribs.c:1886
-#, fuzzy, gcc-internal-format
-#| msgid "%s attribute of '%s' conflicts with %s attribute at %L"
+#: c-family/c-attribs.c:1897
+#, gcc-internal-format
 msgid "ignoring attribute %<%E (%u)%> because it conflicts with attribute %<%E (%u)%>"
-msgstr "%s атрибут '%s' конфликтует с %s атрибутом в %L"
+msgstr ""
 
 #. Do not error out for attribute warn_if_not_aligned.
-#: c-family/c-attribs.c:1891 c-family/c-attribs.c:1920
+#: c-family/c-attribs.c:1902 c-family/c-attribs.c:1931
 #, gcc-internal-format
 msgid "alignment for %q+D must be at least %d"
 msgstr "выравнивание для %q+D должно быть не менее %d"
 
-#: c-family/c-attribs.c:1916
+#: c-family/c-attribs.c:1927
 #, gcc-internal-format
 msgid "alignment for %q+D was previously specified as %d and may not be decreased"
 msgstr "выравнивание для %q+D ранее было определено как %d и не может быть уменьшено"
 
-#: c-family/c-attribs.c:1943
-#, fuzzy, gcc-internal-format
-#| msgid "alignment may not be specified for %q+D"
+#: c-family/c-attribs.c:1954
+#, gcc-internal-format
 msgid "%<warn_if_not_aligned%> may not be specified for %q+D"
-msgstr "нельзя задавать выравнивание для %q+D"
+msgstr ""
 
-#: c-family/c-attribs.c:1986
+#: c-family/c-attribs.c:1997
 #, gcc-internal-format
 msgid "inline function %q+D declared weak"
 msgstr "inline функция %q+D объявлена weak"
 
-#: c-family/c-attribs.c:1991
+#: c-family/c-attribs.c:2002
 #, gcc-internal-format
 msgid "indirect function %q+D cannot be declared weak"
 msgstr "косвенная функция %q+D не может быть объявлена weak"
 
-#: c-family/c-attribs.c:2015
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute only applies to functions"
+#: c-family/c-attribs.c:2026
+#, gcc-internal-format
 msgid "%qE attribute is only applicable on functions"
 msgstr "%qE атрибут применим только к функциям"
 
-#: c-family/c-attribs.c:2046
+#: c-family/c-attribs.c:2057
 #, gcc-internal-format
 msgid "%q+D defined both normally and as %qE attribute"
 msgstr "%q+D определено обычным образом и как атрибут %qE"
 
-#: c-family/c-attribs.c:2054
+#: c-family/c-attribs.c:2065
 #, gcc-internal-format
 msgid "weak %q+D cannot be defined %qE"
 msgstr "weak %q+D не может быть определено %qE"
 
-#: c-family/c-attribs.c:2071 c-family/c-attribs.c:2582
+#: c-family/c-attribs.c:2082 c-family/c-attribs.c:2593
 #, gcc-internal-format
 msgid "attribute %qE argument not a string"
 msgstr "аргумент атрибута %qE не является строковой константой"
 
-#: c-family/c-attribs.c:2106
-#, fuzzy, gcc-internal-format
-#| msgid "%q+D declared inline after being called"
+#: c-family/c-attribs.c:2117
+#, gcc-internal-format
 msgid "%+qD declared alias after being used"
-msgstr "%q+D: inline-декларация после вызова"
+msgstr ""
 
-#: c-family/c-attribs.c:2108
-#, fuzzy, gcc-internal-format
-#| msgid "%q+D declared inline after being called"
+#: c-family/c-attribs.c:2119
+#, gcc-internal-format
 msgid "%+qD declared ifunc after being used"
-msgstr "%q+D: inline-декларация после вызова"
+msgstr ""
 
-#: c-family/c-attribs.c:2159
+#: c-family/c-attribs.c:2170
 #, gcc-internal-format
 msgid "indirect function %q+D cannot be declared weakref"
 msgstr "косвенная функции %q+D не может быть объявлена как weakref"
 
-#: c-family/c-attribs.c:2181
+#: c-family/c-attribs.c:2192
 #, gcc-internal-format
 msgid "weakref attribute must appear before alias attribute"
 msgstr "атрибут weakref должен задаваться до атрибута alias"
 
-#: c-family/c-attribs.c:2193
-#, fuzzy, gcc-internal-format
-#| msgid "%q+D declared inline after being called"
+#: c-family/c-attribs.c:2204
+#, gcc-internal-format
 msgid "%+qD declared weakref after being used"
-msgstr "%q+D: inline-декларация после вызова"
+msgstr ""
 
-#: c-family/c-attribs.c:2217
+#: c-family/c-attribs.c:2228
 #, gcc-internal-format
 msgid "%qE attribute ignored on non-class types"
 msgstr "атрибут %qE для не классовых типов игнорируется"
 
-#: c-family/c-attribs.c:2223
+#: c-family/c-attribs.c:2234
 #, gcc-internal-format
 msgid "%qE attribute ignored because %qT is already defined"
 msgstr "атрибут %qE игнорируется, поскольку %qT уже определен"
 
-#: c-family/c-attribs.c:2236
+#: c-family/c-attribs.c:2247
 #, gcc-internal-format
 msgid "visibility argument not a string"
 msgstr "аргумент атрибута visibility не является текстовой строкой"
 
-#: c-family/c-attribs.c:2248
+#: c-family/c-attribs.c:2259
 #, gcc-internal-format
 msgid "%qE attribute ignored on types"
 msgstr "атрибут %qE для типов игнорируется"
 
-#: c-family/c-attribs.c:2264
+#: c-family/c-attribs.c:2275
 #, gcc-internal-format
 msgid "visibility argument must be one of \"default\", \"hidden\", \"protected\" or \"internal\""
 msgstr "аргумент атрибута visibility должен быть \"default\", \"hidden\", \"protected\" или \"internal\""
 
-#: c-family/c-attribs.c:2275
+#: c-family/c-attribs.c:2286
 #, gcc-internal-format
 msgid "%qD redeclared with different visibility"
 msgstr "%qD повторно декларирован с другим атрибутом видимости"
 
-#: c-family/c-attribs.c:2278 c-family/c-attribs.c:2282
+#: c-family/c-attribs.c:2289 c-family/c-attribs.c:2293
 #, gcc-internal-format
 msgid "%qD was declared %qs which implies default visibility"
 msgstr "%qD был объявлен %qs, что подразумевает значение видимости по умолчанию"
 
-#: c-family/c-attribs.c:2320
+#: c-family/c-attribs.c:2331
 #, gcc-internal-format
 msgid "tls_model argument not a string"
 msgstr "аргумент атрибута tls_model не является текстовой строкой"
 
-#: c-family/c-attribs.c:2333
+#: c-family/c-attribs.c:2344
 #, gcc-internal-format
 msgid "tls_model argument must be one of \"local-exec\", \"initial-exec\", \"local-dynamic\" or \"global-dynamic\""
 msgstr "аргумент атрибута tls_model должен быть \"local-exec\", \"initial-exec\", \"local-dynamic\" или \"global-dynamic\""
 
-#: c-family/c-attribs.c:2353 c-family/c-attribs.c:2656
-#: c-family/c-attribs.c:3497 config/m32c/m32c.c:2944
+#: c-family/c-attribs.c:2364 c-family/c-attribs.c:2667
+#: c-family/c-attribs.c:3508 config/m32c/m32c.c:2944
 #, gcc-internal-format
 msgid "%qE attribute applies only to functions"
 msgstr "%qE: атрибут допустим только для функций"
 
-#: c-family/c-attribs.c:2417
+#: c-family/c-attribs.c:2428
 #, gcc-internal-format
 msgid "alloc_size parameter outside range"
 msgstr "параметр alloc_size вне диапазона"
 
-#: c-family/c-attribs.c:2443
-#, fuzzy, gcc-internal-format
-#| msgid "alloc_size parameter outside range"
+#: c-family/c-attribs.c:2454
+#, gcc-internal-format
 msgid "alloc_align parameter outside range"
-msgstr "параметр alloc_size вне диапазона"
+msgstr "параметр alloc_align вне диапазона"
 
-#: c-family/c-attribs.c:2467
-#, fuzzy, gcc-internal-format
-#| msgid "requested alignment is not an integer constant"
+#: c-family/c-attribs.c:2478
+#, gcc-internal-format
 msgid "assume_aligned parameter not integer constant"
-msgstr "запрошенное выравнивание не является целочисленной константой"
+msgstr "параметр assume_aligned не целочисленная константа"
 
-#: c-family/c-attribs.c:2595
+#: c-family/c-attribs.c:2606
 #, gcc-internal-format
 msgid "only %<inbranch%> and %<notinbranch%> flags are allowed for %<__simd__%> attribute"
-msgstr ""
+msgstr "только %<inbranch%> и %<notinbranch%> допустимы для %<__simd__%> атрибута"
 
-#: c-family/c-attribs.c:2662 c-family/c-attribs.c:3503
+#: c-family/c-attribs.c:2673 c-family/c-attribs.c:3514
 #, gcc-internal-format
 msgid "can%'t set %qE attribute after definition"
 msgstr "атрибут %qE нельзя установить после определения объекта"
 
-#: c-family/c-attribs.c:2727
+#: c-family/c-attribs.c:2738
 #, gcc-internal-format
 msgid "%qE attribute duplicated"
 msgstr "атрибут %qE продублирован"
 
-#: c-family/c-attribs.c:2729
+#: c-family/c-attribs.c:2740
 #, gcc-internal-format
 msgid "%qE attribute follows %qE"
 msgstr "атрибут %qE следует после %qE"
 
-#: c-family/c-attribs.c:2828
+#: c-family/c-attribs.c:2839
 #, gcc-internal-format
 msgid "type was previously declared %qE"
 msgstr "тип был ранее декларирован как %qE"
 
-#: c-family/c-attribs.c:2841 cp/class.c:4397
-#, fuzzy, gcc-internal-format
-#| msgid "%qs can only be specified for functions"
+#: c-family/c-attribs.c:2852 cp/class.c:4401
+#, gcc-internal-format
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
-msgstr "%qs допустим только для функций"
+msgstr "%<transaction_safe_dynamic%> может задаваться только для виртуальной функции"
 
-#: c-family/c-attribs.c:2899
+#: c-family/c-attribs.c:2910
 #, gcc-internal-format
 msgid "%qE argument not an identifier"
 msgstr "аргумент %qE - не идентификатор"
 
-#: c-family/c-attribs.c:2910
+#: c-family/c-attribs.c:2921
 #, gcc-internal-format
 msgid "%qD is not compatible with %qD"
 msgstr "%qD не совместим с %qD"
 
-#: c-family/c-attribs.c:2913
-#, fuzzy, gcc-internal-format
-#| msgid "cleanup argument not a function"
+#: c-family/c-attribs.c:2924
+#, gcc-internal-format
 msgid "%qE argument is not a function"
-msgstr "аргумент атрибута cleanup - не функция"
+msgstr "аргумент %qE не функция"
 
-#: c-family/c-attribs.c:2961
+#: c-family/c-attribs.c:2972
 #, gcc-internal-format
 msgid "deprecated message is not a string"
 msgstr "сообщение для атрибута deprecated не является строковой константой"
 
-#: c-family/c-attribs.c:3002
+#: c-family/c-attribs.c:3013
 #, gcc-internal-format
 msgid "%qE attribute ignored for %qE"
 msgstr "атрибут %qE для %qE проигнорирован"
 
-#: c-family/c-attribs.c:3065
+#: c-family/c-attribs.c:3076
 #, gcc-internal-format
 msgid "invalid vector type for attribute %qE"
 msgstr "неверно задан векторный тип для атрибута %qE"
 
-#: c-family/c-attribs.c:3071 ada/gcc-interface/utils.c:3896
+#: c-family/c-attribs.c:3082 ada/gcc-interface/utils.c:3899
 #, gcc-internal-format
 msgid "vector size not an integral multiple of component size"
 msgstr "размер вектора не кратен размеру компонент"
 
-#: c-family/c-attribs.c:3077 ada/gcc-interface/utils.c:3903
+#: c-family/c-attribs.c:3088 ada/gcc-interface/utils.c:3906
 #, gcc-internal-format
 msgid "zero vector size"
 msgstr "нулевой размер вектора"
 
-#: c-family/c-attribs.c:3085
+#: c-family/c-attribs.c:3096
 #, gcc-internal-format
 msgid "number of components of the vector not a power of two"
 msgstr "число компонент вектора не является степенью двойки"
 
-#: c-family/c-attribs.c:3118 ada/gcc-interface/utils.c:6092
+#: c-family/c-attribs.c:3129 ada/gcc-interface/utils.c:6098
 #, gcc-internal-format
 msgid "nonnull attribute without arguments on a non-prototype"
 msgstr "непустой атрибут без аргументов допустим только в прототипах"
 
-#: c-family/c-attribs.c:3137 ada/gcc-interface/utils.c:6106
+#: c-family/c-attribs.c:3148 ada/gcc-interface/utils.c:6112
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument has invalid operand number (argument %lu)"
 msgstr "в непустом аргументе задан неверный номер операнда (аргумент %lu)"
 
-#: c-family/c-attribs.c:3159 ada/gcc-interface/utils.c:6128
+#: c-family/c-attribs.c:3170 ada/gcc-interface/utils.c:6134
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument with out-of-range operand number (argument %lu, operand %lu)"
 msgstr "непустой аргумент содержит номер операнда вне диапазона (аргумент %lu, операнд %lu)"
 
-#: c-family/c-attribs.c:3168 ada/gcc-interface/utils.c:6137
+#: c-family/c-attribs.c:3179 ada/gcc-interface/utils.c:6143
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument references non-pointer operand (argument %lu, operand %lu)"
 msgstr "непустой аргумент ссылается на операнд, не являющийся указателем (аргумент %lu, операнд %lu)"
 
-#: c-family/c-attribs.c:3208
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute ignored for field of type %qT"
+#: c-family/c-attribs.c:3219
+#, gcc-internal-format
 msgid "%qE attribute ignored on objects of type %qT"
-msgstr "атрибут %qE для поля типа %qT проигнорирован"
+msgstr ""
 
-#: c-family/c-attribs.c:3216
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute only applies to functions"
+#: c-family/c-attribs.c:3227
+#, gcc-internal-format
 msgid "%qE attribute does not apply to functions"
-msgstr "%qE атрибут применим только к функциям"
+msgstr ""
 
-#: c-family/c-attribs.c:3273
+#: c-family/c-attribs.c:3284
 #, gcc-internal-format
 msgid "cleanup argument not an identifier"
 msgstr "аргумент атрибута cleanup - не идентификатор"
 
-#: c-family/c-attribs.c:3280
+#: c-family/c-attribs.c:3291
 #, gcc-internal-format
 msgid "cleanup argument not a function"
 msgstr "аргумент атрибута cleanup - не функция"
 
-#: c-family/c-attribs.c:3317
+#: c-family/c-attribs.c:3328
 #, gcc-internal-format
 msgid "%qE attribute requires prototypes with named arguments"
 msgstr "в атрибуте %qE требуется прототип с именованными аргументами"
 
-#: c-family/c-attribs.c:3325
+#: c-family/c-attribs.c:3336
 #, gcc-internal-format
 msgid "%qE attribute only applies to variadic functions"
 msgstr "атрибут %qE допустим только для функций с переменным числом аргументом"
 
-#: c-family/c-attribs.c:3341 ada/gcc-interface/utils.c:6179
+#: c-family/c-attribs.c:3352 ada/gcc-interface/utils.c:6185
 #, gcc-internal-format
 msgid "requested position is not an integer constant"
 msgstr "заданная позиция не является целой константой"
 
-#: c-family/c-attribs.c:3349 ada/gcc-interface/utils.c:6186
+#: c-family/c-attribs.c:3360 ada/gcc-interface/utils.c:6192
 #, gcc-internal-format
 msgid "requested position is less than zero"
 msgstr "заданная позиция меньше нуля"
 
-#: c-family/c-attribs.c:3404
-#, fuzzy, gcc-internal-format
-#| msgid "%<__int128%> is not supported by this target"
+#: c-family/c-attribs.c:3415
+#, gcc-internal-format
 msgid "empty string in attribute %<target%>"
-msgstr "%<__int128%> не поддерживается этой целевой платформой"
+msgstr ""
 
-#: c-family/c-attribs.c:3520
-#, fuzzy, gcc-internal-format
-#| msgid "return with value in function with no return type"
+#: c-family/c-attribs.c:3531
+#, gcc-internal-format
 msgid "returns_nonnull attribute on a function not returning a pointer"
-msgstr "return со значением в функции без типа возврата"
+msgstr "returns_nonnull атрибут для функции не возвращающей указатель"
 
-#: c-family/c-attribs.c:3535
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute only applies to function types"
+#: c-family/c-attribs.c:3546
+#, gcc-internal-format
 msgid "%qE attribute is only valid on %<struct%> type"
-msgstr "атрибут %qE допустим только для функций"
+msgstr "атрибут %qE допустим только для %<struct%> типа"
 
 #: c-family/c-common.c:725
 #, gcc-internal-format
@@ -29012,29 +24557,25 @@
 msgid "__builtin_shuffle argument vector(s) inner type must have the same size as inner type of the mask"
 msgstr "внутренний тип векторных аргументов __builtin_shuffle должен иметь тот же размер, что и внутренний размер маски"
 
-#: c-family/c-common.c:1262 c-family/c-warn.c:1194
-#, fuzzy, gcc-internal-format
-#| msgid "conversion from %qT to %qT discards qualifiers"
+#: c-family/c-common.c:1262 c-family/c-warn.c:1202
+#, gcc-internal-format
 msgid "unsigned conversion from %qT to %qT changes value from %qE to %qE"
-msgstr "преобразование из %qT в %qT отменяет квалификаторы"
+msgstr ""
 
-#: c-family/c-common.c:1267 c-family/c-warn.c:1202
-#, fuzzy, gcc-internal-format
-#| msgid "conversion from %qT to %qT is ambiguous"
+#: c-family/c-common.c:1267 c-family/c-warn.c:1210
+#, gcc-internal-format
 msgid "unsigned conversion from %qT to %qT changes the value of %qE"
-msgstr "преобразование из %qT в %qT неоднозначно"
+msgstr ""
 
 #: c-family/c-common.c:1276
-#, fuzzy, gcc-internal-format
-#| msgid "conversion from %qT to %qT discards qualifiers"
+#, gcc-internal-format
 msgid "signed conversion from %qT to %qT changes value from %qE to %qE"
-msgstr "преобразование из %qT в %qT отменяет квалификаторы"
+msgstr ""
 
 #: c-family/c-common.c:1281
-#, fuzzy, gcc-internal-format
-#| msgid "conversion from %qT to %qT is ambiguous"
+#, gcc-internal-format
 msgid "signed conversion from %qT to %qT changes the value of %qE"
-msgstr "преобразование из %qT в %qT неоднозначно"
+msgstr ""
 
 #: c-family/c-common.c:1434 c-family/c-common.c:1496
 #, gcc-internal-format
@@ -29112,10 +24653,9 @@
 msgstr "в арифметическом выражении использован указатель на функцию"
 
 #: c-family/c-common.c:3268
-#, fuzzy, gcc-internal-format
-#| msgid "enum constant defined here"
+#, gcc-internal-format
 msgid "enum constant in boolean context"
-msgstr "константа перечислимого типа определена здесь"
+msgstr "enum константа в boolean контексте"
 
 #: c-family/c-common.c:3295
 #, gcc-internal-format
@@ -29125,29 +24665,27 @@
 #: c-family/c-common.c:3338
 #, gcc-internal-format
 msgid "%<*%> in boolean context, suggest %<&&%> instead"
-msgstr ""
+msgstr "%<*%> в булевом контексте, предлагается %<&&%> взамен"
 
 #: c-family/c-common.c:3350
 #, gcc-internal-format
 msgid "%<<<%> in boolean context, did you mean %<<%> ?"
-msgstr ""
+msgstr "%<<<%> в булевом контексте, имелось в виду %<<%> ?"
 
 #: c-family/c-common.c:3366
-#, fuzzy, gcc-internal-format
-#| msgid "the address of %qD will always evaluate as %<true%>"
+#, gcc-internal-format
 msgid "?: using integer constants in boolean context, the expression will always evaluate to %<true%>"
-msgstr "адрес %qD всегда будет иметь значение %<истина%>"
+msgstr "?: использование integer констант в boolean контексте, выражение всегда будет давать значение %<true%>"
 
 #: c-family/c-common.c:3375
 #, gcc-internal-format
 msgid "?: using integer constants in boolean context"
-msgstr ""
+msgstr "?: использование целых констант в булевом контексте"
 
 #: c-family/c-common.c:3411
-#, fuzzy, gcc-internal-format
-#| msgid "the address of %qD will always evaluate as %<true%>"
+#, gcc-internal-format
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
-msgstr "адрес %qD всегда будет иметь значение %<истина%>"
+msgstr "компилятор может предполагать, что адрес %qD всегда будет давать значение %<true%>"
 
 #: c-family/c-common.c:3438 cp/semantics.c:662 cp/typeck.c:8916
 #, gcc-internal-format
@@ -29154,7 +24692,7 @@
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "присваивание, используемое как логическое выражение, рекомендуется "
 
-#: c-family/c-common.c:3518 c/c-decl.c:4325 c/c-decl.c:6430 c/c-typeck.c:14177
+#: c-family/c-common.c:3518 c/c-decl.c:4325 c/c-decl.c:6450 c/c-typeck.c:14182
 #, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr "неверное употребление спецификатора %<restrict%>"
@@ -29234,7 +24772,7 @@
 msgid "duplicate case value"
 msgstr "повтор case-значения,"
 
-#: c-family/c-common.c:4867 c-family/c-warn.c:2216
+#: c-family/c-common.c:4867 c-family/c-warn.c:2225
 #, gcc-internal-format
 msgid "previously used here"
 msgstr "которое ранее использовано здесь"
@@ -29260,10 +24798,9 @@
 msgstr "запрошенное выравнивание не является целочисленной константой"
 
 #: c-family/c-common.c:5143
-#, fuzzy, gcc-internal-format
-#| msgid "requested alignment is not a power of 2"
+#, gcc-internal-format
 msgid "requested alignment is not a positive power of 2"
-msgstr "выравнивание не является степенью числа 2"
+msgstr "запрошенное выравнивание не является положительной степенью 2"
 
 #: c-family/c-common.c:5148
 #, gcc-internal-format
@@ -29280,233 +24817,218 @@
 msgid "missing sentinel in function call"
 msgstr "отсутствует sentinel в вызове функции"
 
-#: c-family/c-common.c:5411
+#: c-family/c-common.c:5409
 #, gcc-internal-format, gfc-internal-format
 msgid "null argument where non-null required (argument %lu)"
 msgstr "пустой аргумент в позиции, где требуется непустой (аргумент %lu)"
 
-#: c-family/c-common.c:5506 c-family/c-common.c:5553
-#, fuzzy, gcc-internal-format
-#| msgid "bad option %s to pragma attribute"
+#: c-family/c-common.c:5504 c-family/c-common.c:5551
+#, gcc-internal-format
 msgid "bad option %qs to attribute %<optimize%>"
-msgstr "некорректная опция %s для атрибута pragma"
+msgstr "некорректная опция %qs для атрибута %<optimize%>"
 
-#: c-family/c-common.c:5509 c-family/c-common.c:5557
-#, fuzzy, gcc-internal-format
-#| msgid "bad option %s to pragma attribute"
+#: c-family/c-common.c:5507 c-family/c-common.c:5555
+#, gcc-internal-format
 msgid "bad option %qs to pragma %<optimize%>"
-msgstr "некорректная опция %s для атрибута pragma"
+msgstr "некорректная опция %qs для pragma %<optimize%>"
 
-#: c-family/c-common.c:5589
+#: c-family/c-common.c:5587
 #, gcc-internal-format
 msgid "%<fallthrough%> attribute specified multiple times"
-msgstr ""
+msgstr "%<fallthrough%> атрибут задан несколько раз"
 
-#: c-family/c-common.c:5593
-#, fuzzy, gcc-internal-format
-#| msgid "default argument specified for lambda parameter"
+#: c-family/c-common.c:5591
+#, gcc-internal-format
 msgid "%<fallthrough%> attribute specified with a parameter"
-msgstr "задан аргумент по умолчанию для lambda-параметра"
+msgstr "%<fallthrough%> атрибут задан с параметром"
 
-#: c-family/c-common.c:5733 c-family/c-common.c:6485 c-family/c-common.c:6558
+#: c-family/c-common.c:5731 c-family/c-common.c:6477 c-family/c-common.c:6550
 #: c/c-typeck.c:3555
 #, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr "слишком мало аргументов в вызове функции %qE"
 
-#: c-family/c-common.c:5738 c-family/c-common.c:6584 c/c-typeck.c:3284
+#: c-family/c-common.c:5736 c-family/c-common.c:6576 c/c-typeck.c:3284
 #, gcc-internal-format
 msgid "too many arguments to function %qE"
 msgstr "слишком много аргументов в вызове функции %qE"
 
-#: c-family/c-common.c:5769
-#, fuzzy, gcc-internal-format
-#| msgid "third argument to %<__builtin_prefetch%> must be a constant"
+#: c-family/c-common.c:5767
+#, gcc-internal-format
 msgid "third argument to function %qE must be a constant integer"
-msgstr "третий аргумент %<__builtin_prefetch%> должен быть константой"
+msgstr ""
 
-#: c-family/c-common.c:5794
+#: c-family/c-common.c:5792
 #, gcc-internal-format
 msgid "second argument to function %qE must be a constant integer power of 2 between %qi and %qu bits"
-msgstr ""
+msgstr "второй аргумент функции %qE должен быть целой константной степенью 2 от %qi до %qu бит"
 
-#: c-family/c-common.c:5815 c-family/c-common.c:5859
+#: c-family/c-common.c:5813 c-family/c-common.c:5857
 #, gcc-internal-format
 msgid "non-floating-point argument in call to function %qE"
 msgstr "не плавающий аргумент в вызове функции %qE"
 
-#: c-family/c-common.c:5838
+#: c-family/c-common.c:5836
 #, gcc-internal-format
 msgid "non-floating-point arguments in call to function %qE"
 msgstr "не плавающие аргументы в вызове функции %qE"
 
-#: c-family/c-common.c:5852
+#: c-family/c-common.c:5850
 #, gcc-internal-format
 msgid "non-const integer argument %u in call to function %qE"
 msgstr "аргумент %u в вызове функции %qE не является целочисленной константой"
 
-#: c-family/c-common.c:5872
+#: c-family/c-common.c:5870
 #, gcc-internal-format
 msgid "non-integer argument 3 in call to function %qE"
 msgstr "аргумент 3 в вызове функции %qE не является целочисленным"
 
-#: c-family/c-common.c:5889 c-family/c-common.c:5925
-#, fuzzy, gcc-internal-format
-#| msgid "argument %d of %qE must be a pointer type"
+#: c-family/c-common.c:5887 c-family/c-common.c:5923
+#, gcc-internal-format
 msgid "argument %u in call to function %qE does not have integral type"
-msgstr "аргумент %d для %qE должен быть указателем"
+msgstr "аргумент %u в вызове функции %qE не имеет целочисленный тип"
 
-#: c-family/c-common.c:5896
-#, fuzzy, gcc-internal-format
-#| msgid "argument 1 of %qE must be a pointer to a constant size type"
+#: c-family/c-common.c:5894
+#, gcc-internal-format
 msgid "argument 3 in call to function %qE does not have pointer to integral type"
-msgstr "аргумент 1 для %qE должен быть типом с константным размером"
+msgstr "аргумент 3 в вызове функции %qE не имеет тип указателя на целочисленное"
 
-#: c-family/c-common.c:5902
-#, fuzzy, gcc-internal-format
-#| msgid "argument 1 of %qE must be a pointer to a constant size type"
+#: c-family/c-common.c:5900
+#, gcc-internal-format
 msgid "argument 3 in call to function %qE has pointer to enumerated type"
-msgstr "аргумент 1 для %qE должен быть типом с константным размером"
+msgstr "аргумент 3 в вызове функции %qE имеет тип указателя на перечислимое"
 
-#: c-family/c-common.c:5908
-#, fuzzy, gcc-internal-format
-#| msgid "argument 1 of %qE must be a pointer to a constant size type"
+#: c-family/c-common.c:5906
+#, gcc-internal-format
 msgid "argument 3 in call to function %qE has pointer to boolean type"
-msgstr "аргумент 1 для %qE должен быть типом с константным размером"
+msgstr "аргумент 3 в вызове функции %qE имеет тип указателя на boolean"
 
-#: c-family/c-common.c:5931
-#, fuzzy, gcc-internal-format
-#| msgid "argument %d of %qE must be a pointer type"
+#: c-family/c-common.c:5929
+#, gcc-internal-format
 msgid "argument 3 in call to function %qE has enumerated type"
-msgstr "аргумент %d для %qE должен быть указателем"
+msgstr "аргумент 3 в вызове функции %qE имеет тип перечисления"
 
-#: c-family/c-common.c:5937
-#, fuzzy, gcc-internal-format
-#| msgid "argument %d of %qE must be a pointer type"
+#: c-family/c-common.c:5935
+#, gcc-internal-format
 msgid "argument 3 in call to function %qE has boolean type"
-msgstr "аргумент %d для %qE должен быть указателем"
+msgstr "аргумент 3 в вызове функции %qE имеет тип boolean"
 
-#: c-family/c-common.c:6184
+#: c-family/c-common.c:6183
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to static data member %qD"
 msgstr "недопустимое применение %<offsetof%> к статическому элементу данных %qD"
 
-#: c-family/c-common.c:6189
+#: c-family/c-common.c:6188
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> when %<operator[]%> is overloaded"
 msgstr "невозможно применит %<offsetof%> к перегруженной операции %<operator[]%>"
 
-#: c-family/c-common.c:6196
+#: c-family/c-common.c:6195
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to a non constant address"
 msgstr "невозможно применит %<offsetof%> к неконстантному адресу"
 
-#: c-family/c-common.c:6209
+#: c-family/c-common.c:6208
 #, gcc-internal-format
 msgid "attempt to take address of bit-field structure member %qD"
 msgstr "взятие адреса от битового поля структуры %qD"
 
-#: c-family/c-common.c:6261
+#: c-family/c-common.c:6260
 #, gcc-internal-format
 msgid "index %E denotes an offset greater than size of %qT"
 msgstr "индекс %E обозначает смещение, превышающее размер %qT"
 
-#: c-family/c-common.c:6427 cp/init.c:3004 cp/init.c:3023
+#: c-family/c-common.c:6419 cp/init.c:3020 cp/init.c:3039
 #, gcc-internal-format
 msgid "size of array is too large"
 msgstr "размер массива слишком велик"
 
-#: c-family/c-common.c:6517
-#, fuzzy, gcc-internal-format
-#| msgid "incompatible type for argument %d of %qE"
+#: c-family/c-common.c:6509
+#, gcc-internal-format
 msgid "operand type %qT is incompatible with argument %d of %qE"
-msgstr "несовместимый тип аргумента %d функции %qE"
+msgstr "тип операнда %qT несовместим с аргументом %d для %qE"
 
-#: c-family/c-common.c:6651
+#: c-family/c-common.c:6643
 #, gcc-internal-format
 msgid "incorrect number of arguments to function %qE"
 msgstr "неправильное число аргументов в вызове функции %qE"
 
-#: c-family/c-common.c:6665
+#: c-family/c-common.c:6657
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a non-void pointer type"
 msgstr "аргумент 1 для %qE должен быть не-void указателем"
 
-#: c-family/c-common.c:6674
+#: c-family/c-common.c:6666
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a constant size type"
 msgstr "аргумент 1 для %qE должен быть типом с константным размером"
 
-#: c-family/c-common.c:6685
+#: c-family/c-common.c:6677
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a nonzero size object"
 msgstr "аргумент 1 для %qE должен быть указателем на объект ненулевого размера"
 
-#: c-family/c-common.c:6706
+#: c-family/c-common.c:6698
 #, gcc-internal-format
 msgid "argument %d of %qE must be a pointer type"
 msgstr "аргумент %d для %qE должен быть указателем"
 
-#: c-family/c-common.c:6714
-#, fuzzy, gcc-internal-format
-#| msgid "argument 1 of %qE must be a pointer to a constant size type"
+#: c-family/c-common.c:6706
+#, gcc-internal-format
 msgid "argument %d of %qE must be a pointer to a constant size type"
-msgstr "аргумент 1 для %qE должен быть типом с константным размером"
+msgstr "аргумент %d для %qE должен быть указателем на тип константного размера"
 
-#: c-family/c-common.c:6720
-#, fuzzy, gcc-internal-format
-#| msgid "argument %d of %qE must be a pointer type"
+#: c-family/c-common.c:6712
+#, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a function"
-msgstr "аргумент %d для %qE должен быть указателем"
+msgstr "аргумент %d для %qE не должен быть указателем на функцию"
 
-#: c-family/c-common.c:6728
+#: c-family/c-common.c:6720
 #, gcc-internal-format
 msgid "size mismatch in argument %d of %qE"
 msgstr "несоответствие размера в аргументе %d для %qE"
 
-#: c-family/c-common.c:6740
+#: c-family/c-common.c:6732
 #, gcc-internal-format
 msgid "non-integer memory model argument %d of %qE"
 msgstr "нецелочисленный аргумент %d модели памяти для %qE"
 
-#: c-family/c-common.c:6753
+#: c-family/c-common.c:6745
 #, gcc-internal-format
 msgid "invalid memory model argument %d of %qE"
 msgstr "некорректный аргумент %d модели памяти для %qE"
 
-#: c-family/c-common.c:7672
+#: c-family/c-common.c:7664
 #, gcc-internal-format
 msgid "index value is out of bound"
 msgstr "значение индекса вне диапазона"
 
-#: c-family/c-common.c:7714 c-family/c-common.c:7763 c-family/c-common.c:7779
-#, fuzzy, gcc-internal-format
-#| msgid "conversion of scalar to vector involves truncation"
+#: c-family/c-common.c:7706 c-family/c-common.c:7755 c-family/c-common.c:7771
+#, gcc-internal-format
 msgid "conversion of scalar %qT to vector %qT involves truncation"
-msgstr "преобразование скаляра в вектор приводит к усечению значения"
+msgstr "преобразование скаляра %qT в вектор %qT включает усечение"
 
 #. Reject arguments that are built-in functions with
 #. no library fallback.
-#: c-family/c-common.c:7867
-#, fuzzy, gcc-internal-format
-#| msgid "built-in function %qD takes one argument only"
+#: c-family/c-common.c:7859
+#, gcc-internal-format
 msgid "built-in function %qE must be directly called"
-msgstr "внутренняя функция %qD принимает только один аргумент"
+msgstr "внутренняя функция %qE должна вызываться напрямую"
 
-#: c-family/c-common.c:7889 c/c-decl.c:6177
+#: c-family/c-common.c:7881 c/c-decl.c:6197
 #, gcc-internal-format
 msgid "size of array %qE is too large"
 msgstr "размер массива %qE слишком велик"
 
-#: c-family/c-common.c:7891 c/c-decl.c:6180
+#: c-family/c-common.c:7883 c/c-decl.c:6200
 #, gcc-internal-format
 msgid "size of unnamed array is too large"
 msgstr "размер безымянного массива слишком велик"
 
-#: c-family/c-common.c:7921
+#: c-family/c-common.c:7913
 #, gcc-internal-format
 msgid "environment variable SOURCE_DATE_EPOCH must expand to a non-negative integer less than or equal to %wd"
-msgstr ""
+msgstr "переменная окружения SOURCE_DATE_EPOCH должна расширяться в неотрицательное целое не более %wd"
 
 #: c-family/c-format.c:140 c-family/c-format.c:327
 #, gcc-internal-format
@@ -29524,27 +25046,24 @@
 msgstr "аргумент, задающий формат, имеет не строковый тип"
 
 #: c-family/c-format.c:216
-#, fuzzy, gcc-internal-format
-#| msgid "found a %<%s%> reference but the format argument should be a string"
+#, gcc-internal-format
 msgid "found a %qs reference but the format argument should be a string"
-msgstr "найдена ссылка %<%s%>, но аргумент, задающий формат, должен быть строкой"
+msgstr "найдена ссылка %qs, но форматный аргумент должен быть строкой"
 
 #: c-family/c-format.c:219
 #, gcc-internal-format
 msgid "found a %qT but the format argument should be a string"
-msgstr "найден %qT, но аргумент, задающий формат, должен быть строкой"
+msgstr "найден %qT, но форматный аргумент должен быть строкой"
 
 #: c-family/c-format.c:229
-#, fuzzy, gcc-internal-format
-#| msgid "format argument should be a %<%s%> reference but a string was found"
+#, gcc-internal-format
 msgid "format argument should be a %qs reference but a string was found"
-msgstr "аргумент, задающий формат, должен быть ссылкой %<%s%>, но найдена строка"
+msgstr "форматный аргумент должен быть %qs ссылкой, но была найдена строка"
 
 #: c-family/c-format.c:251
-#, fuzzy, gcc-internal-format
-#| msgid "format argument should be a %<%s%> reference"
+#, gcc-internal-format
 msgid "format argument should be a %qs reference"
-msgstr "аргумент, задающий формат, должен быть ссылкой %<%s%>"
+msgstr "форматный аргумент должен быть %qs ссылкой"
 
 #: c-family/c-format.c:295
 #, gcc-internal-format
@@ -29572,10 +25091,9 @@
 msgstr "аргумент с форматной строкой после аргументов, подлежащих форматированию"
 
 #: c-family/c-format.c:1148
-#, fuzzy, gcc-internal-format
-#| msgid "function might be possible candidate for %qs format attribute"
+#, gcc-internal-format
 msgid "function %qD might be a candidate for %qs format attribute"
-msgstr "этой функции, вероятно, можно задать атрибут форматирования %s"
+msgstr "функция %qD может быть кандидатом на %qs форматный атрибут"
 
 #: c-family/c-format.c:1239 c-family/c-format.c:1260 c-family/c-format.c:2678
 #, gcc-internal-format
@@ -29748,10 +25266,9 @@
 msgstr "отсутствует %<]%> для формата %<%%[%>"
 
 #: c-family/c-format.c:2595
-#, fuzzy, gcc-internal-format
-#| msgid "use of %qs length modifier with %qc type character"
+#, gcc-internal-format
 msgid "use of %qs length modifier with %qc type character has either no effect or undefined behavior"
-msgstr "модификатор длины %qs указан с типом %qc"
+msgstr "использование %qs модификатора длины с %qc символом типа или не имеет эффекта или дает неопределенное поведение"
 
 #: c-family/c-format.c:2617
 #, gcc-internal-format
@@ -29779,10 +25296,9 @@
 msgstr "в преобразовании в конце формата не указан тип"
 
 #: c-family/c-format.c:2893
-#, fuzzy, gcc-internal-format
-#| msgid "Process #ident directives"
+#, gcc-internal-format
 msgid "nested quoting directive"
-msgstr "Обрабатывать директивы #ident"
+msgstr ""
 
 #: c-family/c-format.c:2904
 #, gcc-internal-format
@@ -29810,16 +25326,14 @@
 msgstr "символ %<\\0%> в форматной строке"
 
 #: c-family/c-format.c:2990
-#, fuzzy, gcc-internal-format
-#| msgid "unterminated format string"
+#, gcc-internal-format
 msgid "unterminated quoting directive"
-msgstr "не терминирована строка формата"
+msgstr ""
 
 #: c-family/c-format.c:2994
-#, fuzzy, gcc-internal-format
-#| msgid "unterminated assembly dialect alternative"
+#, gcc-internal-format
 msgid "unterminated color directive"
-msgstr "незавершённая альтернатива диалекта ассемблера"
+msgstr ""
 
 #: c-family/c-format.c:3116
 #, gcc-internal-format, gfc-internal-format
@@ -29892,10 +25406,9 @@
 msgstr "имя %<tree%> не определено как указательный тип"
 
 #: c-family/c-format.c:3878
-#, fuzzy, gcc-internal-format
-#| msgid "%<locus%> is not defined as a type"
+#, gcc-internal-format
 msgid "%<gcall%> is not defined as a type"
-msgstr "имя %<locus%> не определено как тип"
+msgstr ""
 
 #: c-family/c-format.c:4089
 #, gcc-internal-format
@@ -29910,17 +25423,17 @@
 #: c-family/c-indentation.c:66
 #, gcc-internal-format
 msgid "-Wmisleading-indentation is disabled from this point onwards, since column-tracking was disabled due to the size of the code/headers"
-msgstr ""
+msgstr "-Wmisleading-indentation выключено с этого места вперед, так как отслеживание колонок было выключено из-за размера кода/заголовков"
 
 #: c-family/c-indentation.c:609
 #, gcc-internal-format
 msgid "this %qs clause does not guard..."
-msgstr ""
+msgstr "эта %qs клаузула не защищает..."
 
 #: c-family/c-indentation.c:612
 #, gcc-internal-format
 msgid "...this statement, but the latter is misleadingly indented as if it were guarded by the %qs"
-msgstr ""
+msgstr "...этот оператор, но последний ошибочно полагается на защиту %qs"
 
 #: c-family/c-lex.c:228
 #, gcc-internal-format
@@ -30019,10 +25532,9 @@
 msgstr "некорректный тип выражения для %<#pragma omp atomic%>"
 
 #: c-family/c-omp.c:209
-#, fuzzy, gcc-internal-format
-#| msgid "invalid expression type for %<#pragma omp atomic%>"
+#, gcc-internal-format
 msgid "%<_Atomic%> expression in %<#pragma omp atomic%>"
-msgstr "некорректный тип выражения для %<#pragma omp atomic%>"
+msgstr "%<_Atomic%> выражение в %<#pragma omp atomic%>"
 
 #: c-family/c-omp.c:329
 #, gcc-internal-format
@@ -30034,16 +25546,15 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr "в %<#pragma omp atomic capture%> используются две различные переменные для памяти"
 
-#: c-family/c-omp.c:557 cp/semantics.c:8186
+#: c-family/c-omp.c:557 cp/semantics.c:8189
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "некорректный тип итерационной переменной %qE"
 
 #: c-family/c-omp.c:562
-#, fuzzy, gcc-internal-format
-#| msgid "invalid type for iteration variable %qE"
+#, gcc-internal-format
 msgid "%<_Atomic%> iteration variable %qE"
-msgstr "некорректный тип итерационной переменной %qE"
+msgstr "%<_Atomic%> итерационная переменная %qE"
 
 #: c-family/c-omp.c:578
 #, gcc-internal-format
@@ -30050,56 +25561,51 @@
 msgid "%qE is not initialized"
 msgstr "%qE не инициализирован"
 
-#: c-family/c-omp.c:599 cp/semantics.c:8076
+#: c-family/c-omp.c:599 cp/semantics.c:8079
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "отсутствует управляющий предикат"
 
-#: c-family/c-omp.c:704 cp/semantics.c:7732
+#: c-family/c-omp.c:704 cp/semantics.c:7735
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "некорректный управляющий предикат"
 
-#: c-family/c-omp.c:711 cp/semantics.c:8082
+#: c-family/c-omp.c:711 cp/semantics.c:8085
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "отсутствует инкрементальное выражение"
 
-#: c-family/c-omp.c:775 cp/semantics.c:7847
+#: c-family/c-omp.c:775 cp/semantics.c:7850
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "некорректное инкрементальное выражение"
 
 #: c-family/c-omp.c:838
-#, fuzzy, gcc-internal-format
-#| msgid "invalid type for iteration variable %qE"
+#, gcc-internal-format
 msgid "initializer expression refers to iteration variable %qD"
-msgstr "некорректный тип итерационной переменной %qE"
+msgstr "выражение инициализатора ссылается на итерационную переменную %qD"
 
 #: c-family/c-omp.c:842
-#, fuzzy, gcc-internal-format
-#| msgid "invalid type for iteration variable %qE"
+#, gcc-internal-format
 msgid "condition expression refers to iteration variable %qD"
-msgstr "некорректный тип итерационной переменной %qE"
+msgstr "выражение условия ссылается на итерационную переменную %qD"
 
 #: c-family/c-omp.c:846
-#, fuzzy, gcc-internal-format
-#| msgid "increment of read-only variable %qD"
+#, gcc-internal-format
 msgid "increment expression refers to iteration variable %qD"
-msgstr "инкрементация переменной %qD, доступной только на чтение"
+msgstr "выражение инкремента ссылается на итерационную переменную %qD"
 
 #: c-family/c-omp.c:1422
-#, fuzzy, gcc-internal-format
-#| msgid "expected %<none%> or %<shared%> before end of line"
+#, gcc-internal-format
 msgid "expected %<parallel%> or %<target%> %<if%> clause modifier"
-msgstr "ожидалось %<none%> или %<shared%> перед концом строки"
+msgstr "ожидался %<parallel%> или %<target%> модификатор %<if%> клаузулы"
 
 #
 #: c-family/c-omp.c:1532 c-family/c-omp.c:1547
-#, fuzzy, gcc-internal-format
-#| msgid "%qE is not a function name"
+#, gcc-internal-format
 msgid "%qD is not an function argument"
-msgstr "%qE не является именем функции"
+msgstr "%qD не является аргументом функции"
 
 #: c-family/c-opts.c:325
 #, gcc-internal-format
@@ -30114,127 +25620,139 @@
 #: c-family/c-opts.c:386
 #, gcc-internal-format
 msgid "-Walloca-larger-than=0 is meaningless"
-msgstr ""
+msgstr "-Walloca-larger-than=0 бессмысленно"
 
 #: c-family/c-opts.c:391
 #, gcc-internal-format
 msgid "-Wvla-larger-than=0 is meaningless"
-msgstr ""
+msgstr "-Wvla-larger-than=0 бессмысленно"
 
 #: c-family/c-opts.c:416
-#, fuzzy, gcc-internal-format
-#| msgid "%<__int128%> is not supported by this target"
+#, gcc-internal-format
 msgid "%<-Wabi=1%> is not supported, using =2"
-msgstr "%<__int128%> не поддерживается этой целевой платформой"
+msgstr "%<-Wabi=1%> не поддерживается, используется =2"
 
-#: c-family/c-opts.c:612 fortran/cpp.c:350
+#: c-family/c-opts.c:610 fortran/cpp.c:350
 #, gcc-internal-format
 msgid "output filename specified twice"
 msgstr "дважды задано имя выходного файла"
 
-#: c-family/c-opts.c:799
+#: c-family/c-opts.c:797
 #, gcc-internal-format
 msgid "-fexcess-precision=standard for C++"
 msgstr "-fexcess-precision=standard для C++"
 
-#: c-family/c-opts.c:834
+#: c-family/c-opts.c:832
 #, gcc-internal-format
 msgid "-fno-gnu89-inline is only supported in GNU99 or C99 mode"
 msgstr "-fno-gnu89-inline поддерживается только в режиме GNU99 или C99"
 
-#: c-family/c-opts.c:880
+#: c-family/c-opts.c:878
 #, gcc-internal-format
 msgid "-Wformat-y2k ignored without -Wformat"
 msgstr "ключ -Wformat-y2k без -Wformat игнорируется"
 
-#: c-family/c-opts.c:882
+#: c-family/c-opts.c:880
 #, gcc-internal-format
 msgid "-Wformat-extra-args ignored without -Wformat"
 msgstr "ключ -Wformat-extra-args без -Wformat игнорируется"
 
-#: c-family/c-opts.c:884
+#: c-family/c-opts.c:882
 #, gcc-internal-format
 msgid "-Wformat-zero-length ignored without -Wformat"
 msgstr "ключ -Wformat-zero-length без -Wformat игнорируется"
 
-#: c-family/c-opts.c:886
+#: c-family/c-opts.c:884
 #, gcc-internal-format
 msgid "-Wformat-nonliteral ignored without -Wformat"
 msgstr "ключ -Wformat-nonliteral без -Wformat игнорируется"
 
-#: c-family/c-opts.c:888
+#: c-family/c-opts.c:886
 #, gcc-internal-format
 msgid "-Wformat-contains-nul ignored without -Wformat"
 msgstr "ключ -Wformat-contains-nul без -Wformat игнорируется"
 
-#: c-family/c-opts.c:890
+#: c-family/c-opts.c:888
 #, gcc-internal-format
 msgid "-Wformat-security ignored without -Wformat"
 msgstr "ключ -Wformat-security без -Wformat игнорируется"
 
-#: c-family/c-opts.c:928
-#, fuzzy, gcc-internal-format
-#| msgid "-falign-loops=%d is not supported"
+#: c-family/c-opts.c:918
+#, gcc-internal-format
 msgid "%<-fabi-compat-version=1%> is not supported, using =2"
-msgstr "-falign-loops=%d не поддерживается"
+msgstr "%<-fabi-compat-version=1%> не поддерживается, используется =2"
 
-#: c-family/c-opts.c:988
-#, fuzzy, gcc-internal-format
-#| msgid "nested functions not supported on this target"
+#: c-family/c-opts.c:944
+#, gcc-internal-format
+msgid "-Wabi won't warn about anything"
+msgstr ""
+
+#: c-family/c-opts.c:946
+#, gcc-internal-format
+msgid "-Wabi warns about differences from the most up-to-date ABI, which is also used by default"
+msgstr ""
+
+#: c-family/c-opts.c:949
+#, gcc-internal-format
+msgid "use e.g. -Wabi=11 to warn about changes from GCC 7"
+msgstr ""
+
+#: c-family/c-opts.c:1003
+#, gcc-internal-format
 msgid "external TLS initialization functions not supported on this target"
-msgstr "вложенные функции не поддерживаются для этой платформы"
+msgstr "внешние функции TLS инициализации не поддерживаются для этой платформы"
 
-#: c-family/c-opts.c:1001
+#: c-family/c-opts.c:1016
 #, gcc-internal-format, gfc-internal-format
 msgid "too many filenames given.  Type %s --help for usage"
-msgstr "задано слишком много имен файлов. Введите %s --help для получения справочной информации"
+msgstr ""
 
-#: c-family/c-opts.c:1016
+#: c-family/c-opts.c:1031
 #, gcc-internal-format
 msgid "opening output file %s: %m"
 msgstr "при открытии выходного файла %s: %m"
 
-#: c-family/c-opts.c:1036
+#: c-family/c-opts.c:1051
 #, gcc-internal-format, gfc-internal-format
 msgid "the \"%s\" debug format cannot be used with pre-compiled headers"
-msgstr ""
+msgstr "\"%s\" отладочный формат не может быть использован с прекомпилированными заголовками"
 
-#: c-family/c-opts.c:1190
+#: c-family/c-opts.c:1205
 #, gcc-internal-format
 msgid "opening dependency file %s: %m"
 msgstr "при открытии файла зависимостей %s: %m"
 
-#: c-family/c-opts.c:1201
+#: c-family/c-opts.c:1216
 #, gcc-internal-format
 msgid "closing dependency file %s: %m"
 msgstr "при закрытии файла зависимостей %s: %m"
 
-#: c-family/c-opts.c:1204
+#: c-family/c-opts.c:1219
 #, gcc-internal-format
 msgid "when writing output to %s: %m"
 msgstr "при записи вывода в %s: %m"
 
-#: c-family/c-opts.c:1284
+#: c-family/c-opts.c:1299
 #, gcc-internal-format
 msgid "to generate dependencies you must specify either -M or -MM"
 msgstr "для вывода зависимостей нужно задать -M или -MM"
 
-#: c-family/c-opts.c:1307
+#: c-family/c-opts.c:1322
 #, gcc-internal-format
 msgid "-MG may only be used with -M or -MM"
 msgstr "-MG может использоваться только с -M или -MM"
 
-#: c-family/c-opts.c:1340
+#: c-family/c-opts.c:1355
 #, gcc-internal-format
 msgid "-fdirectives-only is incompatible with -Wunused_macros"
 msgstr "-fdirectives-only несовместим с -Wunused_macros"
 
-#: c-family/c-opts.c:1342
+#: c-family/c-opts.c:1357
 #, gcc-internal-format
 msgid "-fdirectives-only is incompatible with -traditional"
 msgstr "-fdirectives-only несовместим с -traditional"
 
-#: c-family/c-opts.c:1534
+#: c-family/c-opts.c:1549
 #, gcc-internal-format
 msgid "too late for # directive to set debug directory"
 msgstr "слишком поздно установлено имя каталога для отладки в директиве #"
@@ -30355,26 +25873,24 @@
 msgstr "мусор в конце директивы %<#pragma weak%>"
 
 #: c-family/c-pragma.c:371
-#, fuzzy, gcc-internal-format
-#| msgid "weak declaration of %q+D not supported"
+#, gcc-internal-format
 msgid "%<#pragma weak%> declaration of %q+D not allowed, ignored"
-msgstr "weak декларация %q+D не поддерживается"
+msgstr "%<#pragma weak%> декларация для %q+D не допускается, проигнорирована"
 
 #: c-family/c-pragma.c:428
-#, fuzzy, gcc-internal-format
-#| msgid "trampolines not supported"
+#, gcc-internal-format
 msgid "%<#pragma scalar_storage_order%> is not supported for C++"
-msgstr "\"трамплины\" не поддерживаются"
+msgstr ""
 
 #: c-family/c-pragma.c:434
 #, gcc-internal-format
 msgid "missing [big-endian|little-endian|default] after %<#pragma scalar_storage_order%>"
-msgstr ""
+msgstr "отсутствует [big-endian|little-endian|default] после %<#pragma scalar_storage_order%>"
 
 #: c-family/c-pragma.c:443
 #, gcc-internal-format
 msgid "expected [big-endian|little-endian|default] after %<#pragma scalar_storage_order%>"
-msgstr ""
+msgstr "ожидалось [big-endian|little-endian|default] после %<#pragma scalar_storage_order%>"
 
 #: c-family/c-pragma.c:497 c-family/c-pragma.c:499
 #, gcc-internal-format
@@ -30437,10 +25953,9 @@
 msgstr "мусор в конце %<#pragma GCC visibility%>"
 
 #: c-family/c-pragma.c:762
-#, fuzzy, gcc-internal-format
-#| msgid "missing [error|warning|ignored] after %<#pragma GCC diagnostic%>"
+#, gcc-internal-format
 msgid "missing [error|warning|ignored|push|pop] after %<#pragma GCC diagnostic%>"
-msgstr "отсутствует [error|warning|ignored] после %<#pragma GCC diagnostic%>"
+msgstr "отсутствует [error|warning|ignored|push|pop] после %<#pragma GCC diagnostic%>"
 
 #: c-family/c-pragma.c:788
 #, gcc-internal-format
@@ -30458,16 +25973,14 @@
 msgstr "неизвестная опция после %<#pragma GCC diagnostic%> kind"
 
 #: c-family/c-pragma.c:814
-#, fuzzy, gcc-internal-format
-#| msgid "%qs is not a valid option to the preprocessor"
+#, gcc-internal-format
 msgid "%qs is not an option that controls warnings"
-msgstr "неверный ключ препроцессора %qs"
+msgstr "%qs не является опцией управляющей предупреждениями"
 
 #: c-family/c-pragma.c:822
-#, fuzzy, gcc-internal-format
-#| msgid "command line option %qs is valid for %s but not for %s"
+#, gcc-internal-format
 msgid "option %qs is valid for %s but not for %s"
-msgstr "ключ %qs годится для %s, но не для %s"
+msgstr "опция %qs годится для %s, но не для %s"
 
 #: c-family/c-pragma.c:854
 #, gcc-internal-format
@@ -30624,762 +26137,726 @@
 msgid "wrong type argument to %s"
 msgstr "неверный аргумент типа для %s"
 
-#: c-family/c-warn.c:53 c-family/c-warn.c:66 cp/constexpr.c:1847
+#: c-family/c-warn.c:54 c-family/c-warn.c:67 cp/constexpr.c:1847
 #: cp/constexpr.c:4099
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "переполнение при вычислении константного выражения"
 
-#: c-family/c-warn.c:93
-#, fuzzy, gcc-internal-format
-#| msgid "integer overflow in expression"
+#: c-family/c-warn.c:94
+#, gcc-internal-format
 msgid "integer overflow in expression %qE of type %qT results in %qE"
-msgstr "переполнение при вычислении целочисленного выражения"
+msgstr ""
 
-#: c-family/c-warn.c:95
-#, fuzzy, gcc-internal-format
-#| msgid "integer overflow in expression"
+#: c-family/c-warn.c:96
+#, gcc-internal-format
 msgid "integer overflow in expression of type %qT results in %qE"
-msgstr "переполнение при вычислении целочисленного выражения"
+msgstr ""
 
-#: c-family/c-warn.c:101
-#, fuzzy, gcc-internal-format
-#| msgid "floating point overflow in expression"
+#: c-family/c-warn.c:102
+#, gcc-internal-format
 msgid "floating point overflow in expression %qE of type %qT results in %qE"
-msgstr "переполнение при вычислении выражения с плавающей точкой"
+msgstr ""
 
-#: c-family/c-warn.c:103
-#, fuzzy, gcc-internal-format
-#| msgid "floating point overflow in expression"
+#: c-family/c-warn.c:104
+#, gcc-internal-format
 msgid "floating point overflow in expression of type %qT results in %qE"
-msgstr "переполнение при вычислении выражения с плавающей точкой"
+msgstr ""
 
-#: c-family/c-warn.c:109
-#, fuzzy, gcc-internal-format
-#| msgid "fixed-point overflow in expression"
+#: c-family/c-warn.c:110
+#, gcc-internal-format
 msgid "fixed-point overflow in expression %qE of type %qT results in %qE"
-msgstr "переполнение при вычислении выражения с фиксированной точкой"
+msgstr ""
 
-#: c-family/c-warn.c:111
-#, fuzzy, gcc-internal-format
-#| msgid "fixed-point overflow in expression"
+#: c-family/c-warn.c:112
+#, gcc-internal-format
 msgid "fixed-point overflow in expression of type %qT results in %qE"
-msgstr "переполнение при вычислении выражения с фиксированной точкой"
+msgstr ""
 
-#: c-family/c-warn.c:117
-#, fuzzy, gcc-internal-format
-#| msgid "vector overflow in expression"
+#: c-family/c-warn.c:118
+#, gcc-internal-format
 msgid "vector overflow in expression %qE of type %qT results in %qE"
-msgstr "переполнение при вычислении векторного выражения"
+msgstr ""
 
-#: c-family/c-warn.c:119
-#, fuzzy, gcc-internal-format
-#| msgid "vector overflow in expression"
+#: c-family/c-warn.c:120
+#, gcc-internal-format
 msgid "vector overflow in expression of type %qT results in %qE"
-msgstr "переполнение при вычислении векторного выражения"
+msgstr ""
 
-#: c-family/c-warn.c:126
-#, fuzzy, gcc-internal-format
-#| msgid "complex integer overflow in expression"
+#: c-family/c-warn.c:127
+#, gcc-internal-format
 msgid "complex integer overflow in expression %qE of type %qT results in %qE"
-msgstr "переполнение при вычислении комплексного целочисленного выражения"
+msgstr ""
 
-#: c-family/c-warn.c:128
-#, fuzzy, gcc-internal-format
-#| msgid "complex integer overflow in expression"
+#: c-family/c-warn.c:129
+#, gcc-internal-format
 msgid "complex integer overflow in expression of type %qT results in %qE"
-msgstr "переполнение при вычислении комплексного целочисленного выражения"
+msgstr ""
 
-#: c-family/c-warn.c:132
-#, fuzzy, gcc-internal-format
-#| msgid "complex floating point overflow in expression"
+#: c-family/c-warn.c:133
+#, gcc-internal-format
 msgid "complex floating point overflow in expression %qE of type %qT results in %qE"
-msgstr "переполнение при вычислении комплексного выражения с плавающей точкой"
+msgstr ""
 
-#: c-family/c-warn.c:134
-#, fuzzy, gcc-internal-format
-#| msgid "complex floating point overflow in expression"
+#: c-family/c-warn.c:135
+#, gcc-internal-format
 msgid "complex floating point overflow in expression of type %qT results in %qE"
-msgstr "переполнение при вычислении комплексного выражения с плавающей точкой"
+msgstr ""
 
-#: c-family/c-warn.c:216
+#: c-family/c-warn.c:217
 #, gcc-internal-format
 msgid "logical %<or%> applied to non-boolean constant"
 msgstr "логическое %<или%> применено к не булевой константе"
 
-#: c-family/c-warn.c:219
+#: c-family/c-warn.c:220
 #, gcc-internal-format
 msgid "logical %<and%> applied to non-boolean constant"
 msgstr "логическое %<и%> применено к не булевой константе"
 
-#: c-family/c-warn.c:289
+#: c-family/c-warn.c:290
 #, gcc-internal-format
 msgid "logical %<or%> of collectively exhaustive tests is always true"
 msgstr "логическое %<или%> от совокупности исчерпывающих сравнений - всегда истина"
 
-#: c-family/c-warn.c:293
+#: c-family/c-warn.c:294
 #, gcc-internal-format
 msgid "logical %<and%> of mutually exclusive tests is always false"
 msgstr "логическое %<и%> от взаимно исключающих сравнений - всегда ложь"
 
-#: c-family/c-warn.c:303
-#, fuzzy, gcc-internal-format
-#| msgid "invalid operand in unary expression"
+#: c-family/c-warn.c:304
+#, gcc-internal-format
 msgid "logical %<or%> of equal expressions"
-msgstr "неверный операнд в унарном выражении"
+msgstr "логическое %<or%> равных выражений"
 
-#: c-family/c-warn.c:306
-#, fuzzy, gcc-internal-format
-#| msgid "logical %<and%> of mutually exclusive tests is always false"
+#: c-family/c-warn.c:307
+#, gcc-internal-format
 msgid "logical %<and%> of equal expressions"
-msgstr "логическое %<и%> от взаимно исключающих сравнений - всегда ложь"
+msgstr "логическое %<and%> равных выражений"
 
-#: c-family/c-warn.c:384
-#, fuzzy, gcc-internal-format
-#| msgid "user-defined %qD always evaluates both arguments"
+#: c-family/c-warn.c:385
+#, gcc-internal-format
 msgid "bitwise comparison always evaluates to false"
-msgstr "пользовательский оператор %qD всегда вычисляет оба аргумента"
+msgstr ""
 
-#: c-family/c-warn.c:387
-#, fuzzy, gcc-internal-format
-#| msgid "user-defined %qD always evaluates both arguments"
+#: c-family/c-warn.c:388
+#, gcc-internal-format
 msgid "bitwise comparison always evaluates to true"
-msgstr "пользовательский оператор %qD всегда вычисляет оба аргумента"
+msgstr ""
 
-#: c-family/c-warn.c:441
-#, fuzzy, gcc-internal-format
-#| msgid "user-defined %qD always evaluates both arguments"
+#: c-family/c-warn.c:442
+#, gcc-internal-format
 msgid "self-comparison always evaluates to true"
-msgstr "пользовательский оператор %qD всегда вычисляет оба аргумента"
+msgstr "самосравнение всегда дает true"
 
-#: c-family/c-warn.c:444
-#, fuzzy, gcc-internal-format
-#| msgid "user-defined %qD always evaluates both arguments"
+#: c-family/c-warn.c:445
+#, gcc-internal-format
 msgid "self-comparison always evaluates to false"
-msgstr "пользовательский оператор %qD всегда вычисляет оба аргумента"
+msgstr "самосравнение всегда дает false"
 
-#: c-family/c-warn.c:494
+#: c-family/c-warn.c:495
 #, gcc-internal-format
 msgid "logical not is only applied to the left hand side of comparison"
-msgstr ""
+msgstr "логическое not применимо только к левой части сравнения"
 
-#: c-family/c-warn.c:502
+#: c-family/c-warn.c:503
 #, gcc-internal-format
 msgid "add parentheses around left hand side expression to silence this warning"
-msgstr ""
+msgstr "добавьте скобки вокруг выражения в левой части, чтобы устранить это предупреждение"
 
-#: c-family/c-warn.c:636
+#: c-family/c-warn.c:637
 #, gcc-internal-format
 msgid "type-punning to incomplete type might break strict-aliasing rules"
 msgstr "приведение к неполному типу может нарушить правила перекрытия объектов в памяти"
 
-#: c-family/c-warn.c:654
+#: c-family/c-warn.c:655
 #, gcc-internal-format
 msgid "dereferencing type-punned pointer will break strict-aliasing rules"
 msgstr "доступ по указателю с приведением типа нарушает правила перекрытия объектов в памяти"
 
-#: c-family/c-warn.c:662 c-family/c-warn.c:680
+#: c-family/c-warn.c:663 c-family/c-warn.c:681
 #, gcc-internal-format
 msgid "dereferencing type-punned pointer might break strict-aliasing rules"
 msgstr "доступ по указателю с приведением типа может нарушить правила перекрытия объектов в памяти"
 
-#: c-family/c-warn.c:803
+#: c-family/c-warn.c:811
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to use the size of the destination?"
 msgstr ""
 
-#: c-family/c-warn.c:834
+#: c-family/c-warn.c:842
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the destination; did you mean to remove the addressof?"
-msgstr ""
+msgstr "аргумент %<sizeof%> в %qD вызове есть то же выражение, что и приемник; имелось в виду устранить addressof?"
 
-#: c-family/c-warn.c:841
+#: c-family/c-warn.c:849
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the destination; did you mean to provide an explicit length?"
-msgstr ""
+msgstr "аргумент %<sizeof%> в %qD вызове есть то же выражение, что и приемник; имелось в виду задать явную длину?"
 
-#: c-family/c-warn.c:846
+#: c-family/c-warn.c:854
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the destination; did you mean to dereference it?"
-msgstr ""
+msgstr "аргумент %<sizeof%> в %qD вызове есть то же выражение, что и приемник; имелось в виду перейти по ссылке?"
 
-#: c-family/c-warn.c:858
+#: c-family/c-warn.c:866
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the destination; expected %qT or an explicit length"
-msgstr ""
+msgstr "аргумент %<sizeof%> в %qD вызове имеет тот же тип указателя %qT, что и приемник; ожидалось %qT или явная длина"
 
-#: c-family/c-warn.c:874
+#: c-family/c-warn.c:882
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to remove the addressof?"
-msgstr ""
+msgstr "аргумент %<sizeof%> в %qD вызове есть то же выражение, что и источник; имелось в виду устранить addressof?"
 
-#: c-family/c-warn.c:881
+#: c-family/c-warn.c:889
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to provide an explicit length?"
-msgstr ""
+msgstr "аргумент %<sizeof%> в %qD вызове есть то же выражение, что и источник; имелось в виду задать явную длину?"
 
-#: c-family/c-warn.c:886
+#: c-family/c-warn.c:894
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to dereference it?"
-msgstr ""
+msgstr "аргумент %<sizeof%> в %qD вызове есть то же выражение, что и источник; имелось в виду перейти по ссылке?"
 
-#: c-family/c-warn.c:898
+#: c-family/c-warn.c:906
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the source; expected %qT or an explicit length"
-msgstr ""
+msgstr "аргумент %<sizeof%> в %qD вызове имеет тот же тип указателя %qT, что и источник; ожидалось %qT или явная длина"
 
-#: c-family/c-warn.c:914
+#: c-family/c-warn.c:922
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the first source; did you mean to remove the addressof?"
-msgstr ""
+msgstr "аргумент %<sizeof%> в %qD вызове есть то же выражение, что и первый источник; имелось в виду устранить addressof?"
 
-#: c-family/c-warn.c:921
+#: c-family/c-warn.c:929
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the first source; did you mean to provide an explicit length?"
-msgstr ""
+msgstr "аргумент %<sizeof%> в %qD вызове есть то же выражение, что и первый источник; имелось в виду задать явную длину?"
 
-#: c-family/c-warn.c:926
+#: c-family/c-warn.c:934
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the first source; did you mean to dereference it?"
-msgstr ""
+msgstr "аргумент %<sizeof%> в %qD вызове есть то же выражение, что и первый источник; имелось в виду перейти по ссылке?"
 
-#: c-family/c-warn.c:938
+#: c-family/c-warn.c:946
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the first source; expected %qT or an explicit length"
-msgstr ""
+msgstr "аргумент %<sizeof%> в %qD вызове имеет тот же тип указателя %qT, что и первый источник; ожидалось %qT или явная длина"
 
-#: c-family/c-warn.c:954
+#: c-family/c-warn.c:962
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the second source; did you mean to remove the addressof?"
-msgstr ""
+msgstr "аргумент %<sizeof%> в %qD вызове есть то же выражение, что и второй источник; имелось в виду устранить addressof?"
 
-#: c-family/c-warn.c:961
+#: c-family/c-warn.c:969
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the second source; did you mean to provide an explicit length?"
-msgstr ""
+msgstr "аргумент %<sizeof%> в %qD вызове есть то же выражение, что и второй источник; имелось в виду задать явную длину?"
 
-#: c-family/c-warn.c:966
+#: c-family/c-warn.c:974
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the second source; did you mean to dereference it?"
-msgstr ""
+msgstr "аргумент %<sizeof%> в %qD вызове есть то же выражение, что и второй источник; имелось в виду перейти по ссылке?"
 
-#: c-family/c-warn.c:978
+#: c-family/c-warn.c:986
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the second source; expected %qT or an explicit length"
-msgstr ""
+msgstr "аргумент %<sizeof%> в %qD вызове имеет тот же тип указателя %qT, что и второй источник; ожидалось %qT или явная длина"
 
-#: c-family/c-warn.c:1007 c-family/c-warn.c:1014
-#, fuzzy, gcc-internal-format
-#| msgid "invalid parameter type %qT"
+#: c-family/c-warn.c:1015 c-family/c-warn.c:1022
+#, gcc-internal-format
 msgid "%<_Atomic%>-qualified parameter type %qT of %q+D"
-msgstr "некорректный тип параметра %qT"
+msgstr "%<_Atomic%>-квалифицированный параметр типа %qT для %q+D"
 
-#: c-family/c-warn.c:1024
+#: c-family/c-warn.c:1032
 #, gcc-internal-format
 msgid "first argument of %q+D should be %<int%>"
 msgstr "первый аргумент функции %q+D должен иметь тип %<int%>"
 
-#: c-family/c-warn.c:1033
+#: c-family/c-warn.c:1041
 #, gcc-internal-format
 msgid "second argument of %q+D should be %<char **%>"
 msgstr "второй аргумент функции %q+D должен иметь тип %<char **%>"
 
-#: c-family/c-warn.c:1042
+#: c-family/c-warn.c:1050
 #, gcc-internal-format
 msgid "third argument of %q+D should probably be %<char **%>"
 msgstr "третий аргумент функции %q+D должен, по-видимому, иметь тип %<char **%>"
 
-#: c-family/c-warn.c:1053
+#: c-family/c-warn.c:1061
 #, gcc-internal-format
 msgid "%q+D takes only zero or two arguments"
 msgstr "%q+D может быть функцией с двумя аргументами, либо функцией без аргументов"
 
-#: c-family/c-warn.c:1057
-#, fuzzy, gcc-internal-format
-#| msgid "field %qE declared as a function"
+#: c-family/c-warn.c:1065
+#, gcc-internal-format
 msgid "%q+D declared as variadic function"
-msgstr "поле %qE описано как функция"
+msgstr "%q+D декларирована как variadic функция"
 
-#: c-family/c-warn.c:1099
+#: c-family/c-warn.c:1107
 #, gcc-internal-format
 msgid "conversion to %qT from boolean expression"
 msgstr "преобразование в %qT из булева выражения"
 
-#: c-family/c-warn.c:1117 c-family/c-warn.c:1192
-#, fuzzy, gcc-internal-format
-#| msgid "conversion from %qT to %qT discards qualifiers"
+#: c-family/c-warn.c:1125 c-family/c-warn.c:1200
+#, gcc-internal-format
 msgid "conversion from %qT to %qT changes value from %qE to %qE"
-msgstr "преобразование из %qT в %qT отменяет квалификаторы"
+msgstr ""
 
-#: c-family/c-warn.c:1121 c-family/c-warn.c:1200
-#, fuzzy, gcc-internal-format
-#| msgid "conversion from %qT to %qT is ambiguous"
+#: c-family/c-warn.c:1129 c-family/c-warn.c:1208
+#, gcc-internal-format
 msgid "conversion from %qT to %qT changes the value of %qE"
-msgstr "преобразование из %qT в %qT неоднозначно"
+msgstr ""
 
-#: c-family/c-warn.c:1141
-#, fuzzy, gcc-internal-format
-#| msgid "conversion from %qT to %qT discards qualifiers"
+#: c-family/c-warn.c:1149
+#, gcc-internal-format
 msgid "conversion from %qT to %qT discards imaginary component"
-msgstr "преобразование из %qT в %qT отменяет квалификаторы"
+msgstr ""
 
-#: c-family/c-warn.c:1153
-#, fuzzy, gcc-internal-format
-#| msgid "conversion to %qT from %qT may alter its value"
+#: c-family/c-warn.c:1161
+#, gcc-internal-format
 msgid "conversion from %qT to %qT may change value"
-msgstr "преобразование в %qT из %qT может изменить значение"
+msgstr ""
 
-#: c-family/c-warn.c:1213 c-family/c-warn.c:1230 c-family/c-warn.c:1247
-#, fuzzy, gcc-internal-format
-#| msgid "implicit conversion from %qT to %qT when passing argument to function"
+#: c-family/c-warn.c:1221 c-family/c-warn.c:1238 c-family/c-warn.c:1255
+#, gcc-internal-format
 msgid "overflow in conversion from %qT to %qT changes value from %qE to %qE"
-msgstr "неявная конверсия из %qT в %qT при передаче аргумента функции"
+msgstr ""
 
-#: c-family/c-warn.c:1218 c-family/c-warn.c:1235 c-family/c-warn.c:1252
-#, fuzzy, gcc-internal-format
-#| msgid "narrowing conversion of %qE from %qT to %qT inside { }"
+#: c-family/c-warn.c:1226 c-family/c-warn.c:1243 c-family/c-warn.c:1260
+#, gcc-internal-format
 msgid "overflow in conversion from %qT to %qT changes the value of %qE"
-msgstr "сужающее преобразование %qE из %qT в %qT внутри { }"
+msgstr ""
 
-#: c-family/c-warn.c:1282
+#: c-family/c-warn.c:1290
 #, gcc-internal-format
 msgid "case value %qs not in enumerated type"
 msgstr "case-значение %qs не принадлежит к перечислимому типу"
 
-#: c-family/c-warn.c:1287
+#: c-family/c-warn.c:1295
 #, gcc-internal-format
 msgid "case value %qs not in enumerated type %qT"
 msgstr "case-значение %qs не принадлежит к перечислимому типу %qT"
 
-#: c-family/c-warn.c:1348
+#: c-family/c-warn.c:1356
 #, gcc-internal-format
 msgid "switch missing default case"
 msgstr "оператор switch без метки default"
 
-#: c-family/c-warn.c:1393
+#: c-family/c-warn.c:1401
 #, gcc-internal-format
 msgid "switch condition has boolean value"
-msgstr ""
+msgstr "switch условие имеет булево значение"
 
-#: c-family/c-warn.c:1466
+#: c-family/c-warn.c:1474
 #, gcc-internal-format
 msgid "enumeration value %qE not handled in switch"
 msgstr "в переключателе пропущено значение %qE перечислимого типа"
 
-#: c-family/c-warn.c:1494
+#: c-family/c-warn.c:1502
 #, gcc-internal-format
 msgid "the omitted middle operand in ?: will always be %<true%>, suggest explicit middle operand"
 msgstr "пропущенный средний операнд в ?: всегда %<true%>, предлагается явно задать средний операнд"
 
-#: c-family/c-warn.c:1515
+#: c-family/c-warn.c:1523
 #, gcc-internal-format
 msgid "assignment of member %qD in read-only object"
 msgstr "присваивание элементу %qD в объекте, доступном только на чтение"
 
-#: c-family/c-warn.c:1517
+#: c-family/c-warn.c:1525
 #, gcc-internal-format
 msgid "increment of member %qD in read-only object"
 msgstr "инкрементация элемента %qD в объекте, доступном только на чтение"
 
-#: c-family/c-warn.c:1519
+#: c-family/c-warn.c:1527
 #, gcc-internal-format
 msgid "decrement of member %qD in read-only object"
 msgstr "декрементация элемента %qD в объекте, доступном только на чтение"
 
-#: c-family/c-warn.c:1521
+#: c-family/c-warn.c:1529
 #, gcc-internal-format
 msgid "member %qD in read-only object used as %<asm%> output"
 msgstr "элемент %qD в объекте, доступном только на чтение, использован как выходной операнд %<asm%>"
 
-#: c-family/c-warn.c:1525
+#: c-family/c-warn.c:1533
 #, gcc-internal-format
 msgid "assignment of read-only member %qD"
 msgstr "присваивание элементу %qD, доступному только на чтение"
 
-#: c-family/c-warn.c:1526
+#: c-family/c-warn.c:1534
 #, gcc-internal-format
 msgid "increment of read-only member %qD"
 msgstr "инкрементация элемента %qD, доступного только на чтение"
 
-#: c-family/c-warn.c:1527
+#: c-family/c-warn.c:1535
 #, gcc-internal-format
 msgid "decrement of read-only member %qD"
 msgstr "декрементация элемента %qD, доступного только на чтение"
 
-#: c-family/c-warn.c:1528
+#: c-family/c-warn.c:1536
 #, gcc-internal-format
 msgid "read-only member %qD used as %<asm%> output"
 msgstr "доступный только на чтение элемент %qD использован как выходной операнд %<asm%>"
 
-#: c-family/c-warn.c:1532
+#: c-family/c-warn.c:1540
 #, gcc-internal-format
 msgid "assignment of read-only variable %qD"
 msgstr "присваивание переменной %qD, доступной только на чтение"
 
-#: c-family/c-warn.c:1533
+#: c-family/c-warn.c:1541
 #, gcc-internal-format
 msgid "increment of read-only variable %qD"
 msgstr "инкрементация переменной %qD, доступной только на чтение"
 
-#: c-family/c-warn.c:1534
+#: c-family/c-warn.c:1542
 #, gcc-internal-format
 msgid "decrement of read-only variable %qD"
 msgstr "декрементация переменной %qD, доступной только на чтение"
 
-#: c-family/c-warn.c:1535
+#: c-family/c-warn.c:1543
 #, gcc-internal-format
 msgid "read-only variable %qD used as %<asm%> output"
 msgstr "доступная только на чтение переменная %qD использована как выходной операнд %<asm%>"
 
-#: c-family/c-warn.c:1538
+#: c-family/c-warn.c:1546
 #, gcc-internal-format
 msgid "assignment of read-only parameter %qD"
 msgstr "присваивание параметру %qD, доступному только на чтение"
 
-#: c-family/c-warn.c:1539
+#: c-family/c-warn.c:1547
 #, gcc-internal-format
 msgid "increment of read-only parameter %qD"
 msgstr "инкрементация параметра %qD, доступного только на чтение"
 
-#: c-family/c-warn.c:1540
+#: c-family/c-warn.c:1548
 #, gcc-internal-format
 msgid "decrement of read-only parameter %qD"
 msgstr "декрементация параметра %qD, доступного только на чтение"
 
-#: c-family/c-warn.c:1541
+#: c-family/c-warn.c:1549
 #, gcc-internal-format
 msgid "read-only parameter %qD use as %<asm%> output"
 msgstr "доступный только на чтение параметр %qD использован как выходной операнд %<asm%>"
 
-#: c-family/c-warn.c:1546
+#: c-family/c-warn.c:1554
 #, gcc-internal-format
 msgid "assignment of read-only named return value %qD"
 msgstr "присваивание именованному возвращаемому значению %qD, доступному только на чтение"
 
-#: c-family/c-warn.c:1548
+#: c-family/c-warn.c:1556
 #, gcc-internal-format
 msgid "increment of read-only named return value %qD"
 msgstr "инкрементация именованного возвращаемого значения %qD, доступного только на чтение"
 
-#: c-family/c-warn.c:1550
+#: c-family/c-warn.c:1558
 #, gcc-internal-format
 msgid "decrement of read-only named return value %qD"
 msgstr "декрементация именованного возвращаемого значения %qD, доступного только на чтение"
 
-#: c-family/c-warn.c:1552
+#: c-family/c-warn.c:1560
 #, gcc-internal-format
 msgid "read-only named return value %qD used as %<asm%>output"
 msgstr "доступное только на чтение именованное возвращаемое значение %qD использовано как выходной операнд %<asm%>"
 
-#: c-family/c-warn.c:1557
+#: c-family/c-warn.c:1565
 #, gcc-internal-format
 msgid "assignment of function %qD"
 msgstr "присваивание функции %qD"
 
-#: c-family/c-warn.c:1558
+#: c-family/c-warn.c:1566
 #, gcc-internal-format
 msgid "increment of function %qD"
 msgstr "инкрементация функции %qD"
 
-#: c-family/c-warn.c:1559
+#: c-family/c-warn.c:1567
 #, gcc-internal-format
 msgid "decrement of function %qD"
 msgstr "декрементация функции %qD"
 
-#: c-family/c-warn.c:1560
+#: c-family/c-warn.c:1568
 #, gcc-internal-format
 msgid "function %qD used as %<asm%> output"
 msgstr "функция %qD использована как выходной операнд %<asm%>"
 
-#: c-family/c-warn.c:1563 c/c-typeck.c:4762
+#: c-family/c-warn.c:1571 c/c-typeck.c:4767
 #, gcc-internal-format
 msgid "assignment of read-only location %qE"
 msgstr "присваивание позиции в памяти %qE, доступной только на чтение"
 
-#: c-family/c-warn.c:1564 c/c-typeck.c:4765
+#: c-family/c-warn.c:1572 c/c-typeck.c:4770
 #, gcc-internal-format
 msgid "increment of read-only location %qE"
 msgstr "инкрементация позиции в памяти %qE, доступной только на чтение"
 
-#: c-family/c-warn.c:1565 c/c-typeck.c:4768
+#: c-family/c-warn.c:1573 c/c-typeck.c:4773
 #, gcc-internal-format
 msgid "decrement of read-only location %qE"
 msgstr "декрементация позиции в памяти %qE, доступной только на чтение"
 
-#: c-family/c-warn.c:1566
+#: c-family/c-warn.c:1574
 #, gcc-internal-format
 msgid "read-only location %qE used as %<asm%> output"
 msgstr "доступная только на чтение позиция памяти %qE использована как выходной операнд %<asm%>"
 
-#: c-family/c-warn.c:1580
+#: c-family/c-warn.c:1588
 #, gcc-internal-format
 msgid "lvalue required as left operand of assignment"
 msgstr "левая часть в присваивании должна быть lvalue-выражением"
 
-#: c-family/c-warn.c:1583
+#: c-family/c-warn.c:1591
 #, gcc-internal-format
 msgid "lvalue required as increment operand"
 msgstr "операнд инкрементации должен быть lvalue-выражением"
 
-#: c-family/c-warn.c:1586
+#: c-family/c-warn.c:1594
 #, gcc-internal-format
 msgid "lvalue required as decrement operand"
 msgstr "операнд декрементации должен быть lvalue-выражением"
 
-#: c-family/c-warn.c:1589
+#: c-family/c-warn.c:1597
 #, gcc-internal-format
 msgid "lvalue required as unary %<&%> operand"
 msgstr "операнд унарной операции %<&%> должен быть lvalue-выражением"
 
-#: c-family/c-warn.c:1592
+#: c-family/c-warn.c:1600
 #, gcc-internal-format
 msgid "lvalue required in asm statement"
 msgstr "в операторе asm требуется lvalue-выражение"
 
-#: c-family/c-warn.c:1609
+#: c-family/c-warn.c:1617
 #, gcc-internal-format
 msgid "invalid type argument (have %qT)"
-msgstr "неверный аргумент-тип (задан %qT)"
+msgstr "неверный тип аргумента (задан %qT)"
 
-#: c-family/c-warn.c:1613
+#: c-family/c-warn.c:1621
 #, gcc-internal-format
 msgid "invalid type argument of array indexing (have %qT)"
-msgstr "неверный аргумент-тип для индексации (задан %qT)"
+msgstr "неверный тип аргумента для индексации массива (задан %qT)"
 
-#: c-family/c-warn.c:1618
+#: c-family/c-warn.c:1626
 #, gcc-internal-format
 msgid "invalid type argument of unary %<*%> (have %qT)"
-msgstr "неверный аргумент-тип для унарной операции %<*%> (задан %qT)"
+msgstr "неверный тип аргумента для унарной %<*%> (задан %qT)"
 
-#: c-family/c-warn.c:1623
+#: c-family/c-warn.c:1631
 #, gcc-internal-format
 msgid "invalid type argument of %<->%> (have %qT)"
-msgstr "неверный аргумент-тип для операции %<->%> (задан %qT)"
+msgstr "неверный тип аргумента для операции %<->%> (задан %qT)"
 
-#: c-family/c-warn.c:1628
-#, fuzzy, gcc-internal-format
-#| msgid "invalid type argument of %<->%> (have %qT)"
+#: c-family/c-warn.c:1636
+#, gcc-internal-format
 msgid "invalid type argument of %<->*%> (have %qT)"
-msgstr "неверный аргумент-тип для операции %<->%> (задан %qT)"
+msgstr "неверный тип аргумента для %<->*%> (задан %qT)"
 
-#: c-family/c-warn.c:1633
+#: c-family/c-warn.c:1641
 #, gcc-internal-format
 msgid "invalid type argument of implicit conversion (have %qT)"
-msgstr "неверный аргумент-тип для неявного преобразования (задан %qT)"
+msgstr "неверный тип аргумента для неявного преобразования (задан %qT)"
 
-#: c-family/c-warn.c:1654
+#: c-family/c-warn.c:1662
 #, gcc-internal-format
 msgid "array subscript has type %<char%>"
 msgstr "индекс массива имеет тип %<char%>"
 
-#: c-family/c-warn.c:1689 c-family/c-warn.c:1692
+#: c-family/c-warn.c:1697 c-family/c-warn.c:1700
 #, gcc-internal-format
 msgid "suggest parentheses around %<+%> inside %<<<%>"
 msgstr "рекомендуется заключить в скобки %<+%> в операции %<<<%>"
 
-#: c-family/c-warn.c:1695 c-family/c-warn.c:1698
+#: c-family/c-warn.c:1703 c-family/c-warn.c:1706
 #, gcc-internal-format
 msgid "suggest parentheses around %<-%> inside %<<<%>"
 msgstr "рекомендуется заключить в скобки %<-%> в операции %<<<%>"
 
-#: c-family/c-warn.c:1704 c-family/c-warn.c:1707
+#: c-family/c-warn.c:1712 c-family/c-warn.c:1715
 #, gcc-internal-format
 msgid "suggest parentheses around %<+%> inside %<>>%>"
 msgstr "рекомендуется заключить в скобки %<+%> в операции %<>>%>"
 
-#: c-family/c-warn.c:1710 c-family/c-warn.c:1713
+#: c-family/c-warn.c:1718 c-family/c-warn.c:1721
 #, gcc-internal-format
 msgid "suggest parentheses around %<-%> inside %<>>%>"
 msgstr "рекомендуется заключить в скобки %<-%> в операции %<>>%>"
 
-#: c-family/c-warn.c:1719 c-family/c-warn.c:1722
+#: c-family/c-warn.c:1727 c-family/c-warn.c:1730
 #, gcc-internal-format
 msgid "suggest parentheses around %<&&%> within %<||%>"
 msgstr "рекомендуется заключить в скобки %<&&%> в операции %<||%>"
 
-#: c-family/c-warn.c:1729 c-family/c-warn.c:1733
+#: c-family/c-warn.c:1737 c-family/c-warn.c:1741
 #, gcc-internal-format
 msgid "suggest parentheses around arithmetic in operand of %<|%>"
 msgstr "рекомендуется заключить в скобки арифметические операции в операнде %<|%>"
 
-#: c-family/c-warn.c:1737 c-family/c-warn.c:1740
+#: c-family/c-warn.c:1745 c-family/c-warn.c:1748
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<|%>"
 msgstr "рекомендуется заключить в скобки сравнение в операнде %<|%>"
 
-#: c-family/c-warn.c:1745
+#: c-family/c-warn.c:1753
 #, gcc-internal-format
 msgid "suggest parentheses around operand of %<!%> or change %<|%> to %<||%> or %<!%> to %<~%>"
 msgstr "рекомендуется окружить скобками операнд %<!%>, либо заменить %<|%> на %<||%> или %<!%> на %<~%>"
 
-#: c-family/c-warn.c:1753 c-family/c-warn.c:1757
+#: c-family/c-warn.c:1761 c-family/c-warn.c:1765
 #, gcc-internal-format
 msgid "suggest parentheses around arithmetic in operand of %<^%>"
 msgstr "рекомендуется окружить скобками арифметические операции в операнде %<^%>"
 
-#: c-family/c-warn.c:1761 c-family/c-warn.c:1764
+#: c-family/c-warn.c:1769 c-family/c-warn.c:1772
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<^%>"
 msgstr "рекомендуется окружить скобками сравнение в операнде %<^%>"
 
-#: c-family/c-warn.c:1770 c-family/c-warn.c:1773
+#: c-family/c-warn.c:1778 c-family/c-warn.c:1781
 #, gcc-internal-format
 msgid "suggest parentheses around %<+%> in operand of %<&%>"
 msgstr "рекомендуется окружить скобками %<+%> в операнде %<&%>"
 
-#: c-family/c-warn.c:1776 c-family/c-warn.c:1779
+#: c-family/c-warn.c:1784 c-family/c-warn.c:1787
 #, gcc-internal-format
 msgid "suggest parentheses around %<-%> in operand of %<&%>"
 msgstr "рекомендуется окружить скобками %<-%> в операнде %<&%>"
 
-#: c-family/c-warn.c:1783 c-family/c-warn.c:1786
+#: c-family/c-warn.c:1791 c-family/c-warn.c:1794
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<&%>"
 msgstr "рекомендуется окружить скобками сравнение в операнде %<&%>"
 
-#: c-family/c-warn.c:1791
+#: c-family/c-warn.c:1799
 #, gcc-internal-format
 msgid "suggest parentheses around operand of %<!%> or change %<&%> to %<&&%> or %<!%> to %<~%>"
 msgstr "рекомендуется окружить скобками операнд %<!%>, либо заменить %<&%> на %<&&%> или %<!%> на %<~%>"
 
-#: c-family/c-warn.c:1798 c-family/c-warn.c:1801
+#: c-family/c-warn.c:1806 c-family/c-warn.c:1809
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<==%>"
 msgstr "рекомендуется окружить скобками сравнение, используемое в операнде %<==%>"
 
-#: c-family/c-warn.c:1806 c-family/c-warn.c:1809
+#: c-family/c-warn.c:1814 c-family/c-warn.c:1817
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<!=%>"
 msgstr "рекомендуется окружить скобками сравнение, используемое в операнде %<!=%>"
 
-#: c-family/c-warn.c:1819 c-family/c-warn.c:1825
+#: c-family/c-warn.c:1827 c-family/c-warn.c:1833
 #, gcc-internal-format
 msgid "comparisons like %<X<=Y<=Z%> do not have their mathematical meaning"
 msgstr "сравнения вида %<X<=Y<=Z%> трактуются в C не так, как в математике"
 
-#: c-family/c-warn.c:1841
+#: c-family/c-warn.c:1849
 #, gcc-internal-format
 msgid "label %q+D defined but not used"
 msgstr "метка %q+D определена, но не используется"
 
-#: c-family/c-warn.c:1843
+#: c-family/c-warn.c:1851
 #, gcc-internal-format
 msgid "label %q+D declared but not defined"
 msgstr "метка %q+D декларирована, но не определена"
 
-#: c-family/c-warn.c:1866
+#: c-family/c-warn.c:1874
 #, gcc-internal-format
 msgid "division by zero"
 msgstr "деление на ноль"
 
-#: c-family/c-warn.c:1886
+#: c-family/c-warn.c:1894
 #, gcc-internal-format
 msgid "%<memset%> used with constant zero length parameter; this could be due to transposed parameters"
-msgstr ""
+msgstr "%<memset%> использовано с константным нулевым параметром длины; возможно это следствие перестановки параметров"
 
-#: c-family/c-warn.c:1909
+#: c-family/c-warn.c:1918
 #, gcc-internal-format
 msgid "%<memset%> used with length equal to number of elements without multiplication by element size"
-msgstr ""
+msgstr "%<memset%> использовано с длиной равной числу элементов без умножения на размер элемента"
 
-#: c-family/c-warn.c:1948 c/c-typeck.c:11499 c/c-typeck.c:11667
+#: c-family/c-warn.c:1957 c/c-typeck.c:11504 c/c-typeck.c:11672
 #: cp/typeck.c:5048
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr "сравнение между типами %qT и %qT"
 
-#: c-family/c-warn.c:1998
+#: c-family/c-warn.c:2007
 #, gcc-internal-format
 msgid "comparison of integer expressions of different signedness: %qT and %qT"
 msgstr ""
 
-#: c-family/c-warn.c:2051
+#: c-family/c-warn.c:2060
 #, gcc-internal-format
 msgid "promoted ~unsigned is always non-zero"
 msgstr "расширенное значение ~unsigned всегда ненулевое"
 
-#: c-family/c-warn.c:2054
+#: c-family/c-warn.c:2063
 #, gcc-internal-format
 msgid "comparison of promoted ~unsigned with constant"
 msgstr "сравнение ~unsigned с константой"
 
-#: c-family/c-warn.c:2064
+#: c-family/c-warn.c:2073
 #, gcc-internal-format
 msgid "comparison of promoted ~unsigned with unsigned"
 msgstr "сравнение ~unsigned с unsigned"
 
-#: c-family/c-warn.c:2118
-#, fuzzy, gcc-internal-format
-#| msgid "unused parameter %q+D"
+#: c-family/c-warn.c:2127
+#, gcc-internal-format
 msgid "unused parameter %qD"
-msgstr "параметр %q+D не используется"
+msgstr "неиспользуемый параметр %qD"
 
-#: c-family/c-warn.c:2180
+#: c-family/c-warn.c:2189
 #, gcc-internal-format
 msgid "typedef %qD locally defined but not used"
 msgstr "typedef %qD определен локально, но нигде не используется"
 
-#: c-family/c-warn.c:2215
-#, fuzzy, gcc-internal-format
-#| msgid "duplicate %<const%>"
+#: c-family/c-warn.c:2224
+#, gcc-internal-format
 msgid "duplicated %<if%> condition"
-msgstr "повторное употребление %<const%>"
+msgstr "повторное %<if%> условие"
 
-#: c-family/c-warn.c:2244
-#, fuzzy, gcc-internal-format
-#| msgid "declaration of %q+D with attribute noinline follows inline declaration "
+#: c-family/c-warn.c:2253
+#, gcc-internal-format
 msgid "optimization attribute on %qD follows definition but the attribute doesn%'t match"
-msgstr "декларация %q+D с атрибутом noinline после inline-декларации"
+msgstr "оптимизационный атрибут %qD после определения, но атрибут не соответствует"
 
-#: c-family/c-warn.c:2254
-#, fuzzy, gcc-internal-format
-#| msgid "inline declaration of %qD follows declaration with attribute noinline"
+#: c-family/c-warn.c:2261
+#, gcc-internal-format
 msgid "inline declaration of %qD follows declaration with attribute %qs"
-msgstr "inline-декларация %qD после декларации с атрибутом noinline"
+msgstr ""
 
-#: c-family/c-warn.c:2259
-#, fuzzy, gcc-internal-format
-#| msgid "declaration of %q+D with attribute noinline follows inline declaration "
+#: c-family/c-warn.c:2266
+#, gcc-internal-format
 msgid "declaration of %q+D with attribute %qs follows inline declaration"
-msgstr "декларация %q+D с атрибутом noinline после inline-декларации"
+msgstr ""
 
-#: c-family/c-warn.c:2306
+#: c-family/c-warn.c:2313
 #, gcc-internal-format
 msgid "result of %qE requires %u bits to represent, but %qT only has %u bits"
-msgstr ""
+msgstr "результат %qE требует %u бит для представления, но %qT имеет только %u бит"
 
-#: c-family/c-warn.c:2344 c-family/c-warn.c:2368
-#, fuzzy, gcc-internal-format
-#| msgid "comparison of unsigned expression < 0 is always false"
+#: c-family/c-warn.c:2351 c-family/c-warn.c:2375
+#, gcc-internal-format
 msgid "comparison of constant %qE with boolean expression is always false"
-msgstr "результат сравнения `беззнаковое выражение < 0' всегда ложь"
+msgstr "сравнение константы %qE с булевым выражением всегда есть false"
 
-#: c-family/c-warn.c:2347 c-family/c-warn.c:2365
-#, fuzzy, gcc-internal-format
-#| msgid "comparison of unsigned expression >= 0 is always true"
+#: c-family/c-warn.c:2354 c-family/c-warn.c:2372
+#, gcc-internal-format
 msgid "comparison of constant %qE with boolean expression is always true"
-msgstr "результат сравнения `беззнаковое выражение >=0' всегда истина"
+msgstr "сравнение константы %qE с булевым выражением всегда есть true"
 
-#: c-family/c-warn.c:2415
-#, fuzzy
-#| msgid "passing argument %d of %qE discards %qv qualifier from pointer target type"
+#: c-family/c-warn.c:2422
 msgid "passing argument %i to restrict-qualified parameter aliases with argument %Z"
 msgid_plural "passing argument %i to restrict-qualified parameter aliases with arguments %Z"
-msgstr[0] "передача аргумента %d %qE отменяет квалификатор %qv указуемого типа"
-msgstr[1] "передача аргумента %d %qE отменяет квалификатор %qv указуемого типа"
-msgstr[2] "передача аргумента %d %qE отменяет квалификатор %qv указуемого типа"
+msgstr[0] "передача аргумента %i в restrict-квалифицированный параметр синонимично аргументам %Z"
+msgstr[1] ""
+msgstr[2] ""
 
-#: c-family/c-warn.c:2480 c/c-typeck.c:5288 cp/call.c:5365
+#: c-family/c-warn.c:2487 c/c-typeck.c:5293 cp/call.c:5365
 #, gcc-internal-format
 msgid "this condition has identical branches"
-msgstr ""
+msgstr "это условие имеет идентичные ветвления"
 
-#: c-family/c-warn.c:2586
+#: c-family/c-warn.c:2593
 #, gcc-internal-format
 msgid "macro expands to multiple statements"
 msgstr ""
 
-#: c-family/c-warn.c:2587
+#: c-family/c-warn.c:2594
 #, gcc-internal-format
 msgid "some parts of macro expansion are not guarded by this %qs clause"
 msgstr ""
@@ -31395,11 +26872,10 @@
 msgstr "слишком много входных файлов"
 
 #
-#: common/config/aarch64/aarch64-common.c:319 config/aarch64/aarch64.c:10686
-#, fuzzy, gcc-internal-format
-#| msgid "unknown value %s for -mfpu"
+#: common/config/aarch64/aarch64-common.c:319 config/aarch64/aarch64.c:10702
+#, gcc-internal-format
 msgid "unknown value %qs for -mcpu"
-msgstr "неизвестное значение %s для ключа -mfpu"
+msgstr "неизвестное значение %qs для -mcpu"
 
 #: common/config/alpha/alpha-common.c:75
 #, gcc-internal-format
@@ -31407,16 +26883,14 @@
 msgstr "некорректное значение %qs для ключа -mtls-size"
 
 #: common/config/arc/arc-common.c:81
-#, fuzzy, gcc-internal-format
-#| msgid "multiple function type attributes specified"
+#, gcc-internal-format
 msgid "multiple -mcpu= options specified."
-msgstr "задано несколько атрибутов типа функции"
+msgstr "задано несколько -mcpu= опций."
 
 #: common/config/arc/arc-common.c:87
-#, fuzzy, gcc-internal-format
-#| msgid "bad value %qs for -mtune switch"
+#, gcc-internal-format
 msgid "Unsupported value for mmpy-option"
-msgstr "некорректное значение %qs для ключа -mtune"
+msgstr "Неподдерживаемое значение для mmpy-опции"
 
 #: common/config/arm/arm-common.c:259
 #, gcc-internal-format, gfc-internal-format
@@ -31429,54 +26903,46 @@
 msgstr ""
 
 #: common/config/arm/arm-common.c:322 common/config/arm/arm-common.c:376
-#: common/config/arm/arm-common.c:423 config/aarch64/aarch64.c:10639
-#, fuzzy, gcc-internal-format
-#| msgid "valid arguments to %qs are: %s"
+#: common/config/arm/arm-common.c:423 config/aarch64/aarch64.c:10655
+#, gcc-internal-format
 msgid "valid arguments are: %s; did you mean %qs?"
-msgstr "допустимые аргументы %qs: %s"
+msgstr "допустимые аргументы: %s; имелось в виду %qs?"
 
 #: common/config/arm/arm-common.c:325 common/config/arm/arm-common.c:379
-#: common/config/arm/arm-common.c:426 config/aarch64/aarch64.c:10642
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "valid arguments to %qs are: %s"
+#: common/config/arm/arm-common.c:426 config/aarch64/aarch64.c:10658
+#, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s"
-msgstr "допустимые аргументы %qs: %s"
+msgstr ""
 
 #: common/config/arm/arm-common.c:352 common/config/arm/arm-common.c:406
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "unrecognized address"
+#, gcc-internal-format, gfc-internal-format
 msgid "unrecognized %s target: %s"
-msgstr "некорректный адрес"
+msgstr ""
 
 #: common/config/arm/arm-common.c:442
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "unrecognized address"
+#, gcc-internal-format, gfc-internal-format
 msgid "unrecognized -mfpu target: %s"
-msgstr "некорректный адрес"
+msgstr ""
 
 #: common/config/arm/arm-common.c:470
-#, fuzzy, gcc-internal-format
-#| msgid "%s does not support %s"
+#, gcc-internal-format
 msgid "%qs does not support feature %qs"
-msgstr "%s не поддерживает %s"
+msgstr ""
 
 #: common/config/arm/arm-common.c:481
-#, fuzzy, gcc-internal-format
-#| msgid "%qT has no member named %qE"
+#, gcc-internal-format
 msgid "valid feature names are: %s; did you mean %qs?"
-msgstr "%qT не содержит элемента с именем %qE"
+msgstr ""
 
 #: common/config/arm/arm-common.c:484
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "invalid memory model argument %d of %qE"
+#, gcc-internal-format, gfc-internal-format
 msgid "valid feature names are: %s"
-msgstr "некорректный аргумент %d модели памяти для %qE"
+msgstr ""
 
 #: common/config/arm/arm-common.c:502
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "%qD does not have integral or enumeration type"
+#, gcc-internal-format, gfc-internal-format
 msgid "%s does not take any feature options"
-msgstr "%qD не имеет целый или перечислимый тип"
+msgstr ""
 
 #: common/config/arm/arm-common.c:593
 #, gcc-internal-format, gfc-internal-format
@@ -31484,16 +26950,14 @@
 msgstr ""
 
 #: common/config/arm/arm-common.c:607
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "unrecognized option -fdisable"
+#, gcc-internal-format, gfc-internal-format
 msgid "unrecognized operand to %%:canon_for_mlib"
-msgstr "неопознанный ключ -fdisable"
+msgstr ""
 
 #: common/config/arm/arm-common.c:953
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "unrecognized command line option %qs"
+#, gcc-internal-format, gfc-internal-format
 msgid "unrecognized operand to %%:asm_auto_mfpu"
-msgstr "некорректный ключ %qs"
+msgstr ""
 
 #: common/config/bfin/bfin-common.c:304 common/config/m68k/m68k-common.c:60
 #, gcc-internal-format, gfc-internal-format
@@ -31562,20 +27026,19 @@
 
 #
 #: common/config/msp430/msp430-common.c:57
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "unrecognized argument to -mmcu= option: %qs"
+#, gcc-internal-format, gfc-internal-format
 msgid "unrecognized argument of -mcpu: %s"
-msgstr "неопознанный аргумент ключа -mmcu= option: %qs"
+msgstr "неопознанный аргумент для -mcpu: %s"
 
 #: common/config/nds32/nds32-common.c:49
 #, gcc-internal-format
 msgid "for the option -misr-vector-size=X, the valid X must be: 4 or 16"
-msgstr ""
+msgstr "для опции -misr-vector-size=X допустимый X должен быть: 4 или 16"
 
 #: common/config/nds32/nds32-common.c:60
 #, gcc-internal-format
 msgid "for the option -mcache-block-size=X, the valid X must be: 4, 8, 16, 32, 64, 128, 256, or 512"
-msgstr ""
+msgstr "для опции -mcache-block-size=X допустимый X должен быть: 4, 8, 16, 32, 64, 128, 256 или 512"
 
 #: common/config/powerpcspe/powerpcspe-common.c:173
 #: common/config/rs6000/rs6000-common.c:182 config/sparc/sparc.c:1734
@@ -31603,25 +27066,24 @@
 
 #: common/config/powerpcspe/powerpcspe-common.c:313
 #: common/config/rs6000/rs6000-common.c:313
-#, fuzzy, gcc-internal-format
-#| msgid "%<-fsplit-stack%> currently only supported on GNU/Linux"
+#, gcc-internal-format
 msgid "%<-fsplit-stack%> currently only supported on PowerPC64 GNU/Linux with glibc-2.18 or later"
-msgstr "%<-fsplit-stack%> в настоящее время поддерживается только на GNU/Linux"
+msgstr "%<-fsplit-stack%> в настоящее время поддерживается только на PowerPC64 GNU/Linux с glibc-2.18 или старше"
 
 #: common/config/riscv/riscv-common.c:43
 #, gcc-internal-format, gfc-internal-format
 msgid "-march=%s: ISA string must begin with rv32 or rv64"
-msgstr ""
+msgstr "-march=%s: ISA цепочка должна начинаться с rv32 или rv64"
 
 #: common/config/riscv/riscv-common.c:82
 #, gcc-internal-format, gfc-internal-format
 msgid "-march=%s: invalid ISA string"
-msgstr ""
+msgstr "-march=%s: некорректная ISA цепочка"
 
 #: common/config/riscv/riscv-common.c:92
 #, gcc-internal-format
 msgid "-march=%s: unsupported ISA substring %qs"
-msgstr ""
+msgstr "-march=%s: неподдерживаемая ISA подцепочка %qs"
 
 #: common/config/rx/rx-common.c:61
 #, gcc-internal-format
@@ -31629,10 +27091,9 @@
 msgstr "процессор RX200 не оборудован FPU"
 
 #: common/config/rx/rx-common.c:63
-#, fuzzy, gcc-internal-format
-#| msgid "the RX200 cpu does not have FPU hardware"
+#, gcc-internal-format
 msgid "the RX100 cpu does not have FPU hardware"
-msgstr "процессор RX200 не оборудован FPU"
+msgstr "процессор RX100 не оборудован FPU"
 
 #: common/config/s390/s390-common.c:96
 #, gcc-internal-format
@@ -31722,50 +27183,45 @@
 
 #. Arbitrary limit, number should be like xx.yy.zz
 #: config/darwin-driver.c:119
-#, fuzzy, gcc-internal-format
-#| msgid "couldn%'t understand kern.osversion %q.*s"
+#, gcc-internal-format
 msgid "couldn%'t understand version %s\n"
-msgstr "непонятно kern.osversion %q.*s"
+msgstr ""
 
 #: config/darwin-driver.c:172
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "this target does not support %qs"
+#, gcc-internal-format, gfc-internal-format
 msgid "this compiler does not support %s"
-msgstr "для этой целевой платформы не поддерживается %qs"
+msgstr "этот компилятор не поддерживает %s"
 
 #: config/darwin-driver.c:227
 #, gcc-internal-format
 msgid "this compiler does not support PowerPC (arch flags ignored)"
-msgstr ""
+msgstr "этот компилятор не поддерживает PowerPC (архитектурные флаги игнорируются)"
 
 #: config/darwin-driver.c:231
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "-mcpu=%s conflicts with -march=%s"
+#, gcc-internal-format, gfc-internal-format
 msgid "%s conflicts with i386 (arch flags ignored)"
-msgstr "-mcpu=%s конфликтует с -march=%s"
+msgstr "%s конфликтует с i386 (arch флаги проигнорированы)"
 
 #: config/darwin-driver.c:239
 #, gcc-internal-format, gfc-internal-format
 msgid "%s conflicts with x86_64 (arch flags ignored)"
-msgstr ""
+msgstr "%s конфликтует с x86_64 (arch флаги игнорируются)"
 
 #
 #: config/darwin-driver.c:246
-#, fuzzy, gcc-internal-format
-#| msgid "The C parser does not support -dy, option ignored"
+#, gcc-internal-format
 msgid "this compiler does not support X86 (arch flags ignored)"
-msgstr "C парсер не поддерживает -dy, опция игнорируется"
+msgstr "этот компилятор не поддерживает X86 (arch флаги проигнорированы)"
 
 #: config/darwin-driver.c:250
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "-mcpu=%s conflicts with -march=%s"
+#, gcc-internal-format, gfc-internal-format
 msgid "%s conflicts with ppc (arch flags ignored)"
-msgstr "-mcpu=%s конфликтует с -march=%s"
+msgstr "%s конфликтует с ppc (arch флаги проигнорированы)"
 
 #: config/darwin-driver.c:258
 #, gcc-internal-format, gfc-internal-format
 msgid "%s conflicts with ppc64 (arch flags ignored)"
-msgstr ""
+msgstr "%s конфликтует с ppc64 (arch флаги проигнорированы)"
 
 #: config/darwin.c:1694
 #, gcc-internal-format
@@ -31788,10 +27244,9 @@
 msgstr "атрибут %qE 2.95 vtable-совместимости применим только к классам C++"
 
 #: config/darwin.c:2768
-#, fuzzy, gcc-internal-format
-#| msgid "visibility attribute not supported in this configuration; ignored"
+#, gcc-internal-format
 msgid "protected visibility attribute not supported in this configuration; ignored"
-msgstr "атрибут видимости не поддерживается в данной конфигурации; определение игнорируется"
+msgstr "protected visibility атрибут не поддерживается в данной конфигурации; проигнорирован"
 
 #: config/darwin.c:2984
 #, gcc-internal-format, gfc-internal-format
@@ -31859,10 +27314,9 @@
 msgstr "некорректное выравнивание для %<#pragma align%>, директива проигнорирована"
 
 #: config/sol2-c.c:115
-#, fuzzy, gcc-internal-format
-#| msgid "%<#pragma align%> must appear before the declaration of %D, ignoring"
+#, gcc-internal-format
 msgid "%<#pragma align%> must appear before the declaration of %qD, ignoring"
-msgstr "%<#pragma align%> должна предшествовать декларации %D, игнорируется"
+msgstr ""
 
 #: config/sol2-c.c:127 config/sol2-c.c:139
 #, gcc-internal-format
@@ -31930,221 +27384,197 @@
 msgid "profiler support for VxWorks"
 msgstr "поддержка профилирования для VxWorks"
 
-#: config/aarch64/aarch64-builtins.c:1109 config/arm/arm-builtins.c:2262
-#, fuzzy, gcc-internal-format
-#| msgid "argument must be a constant"
+#: config/aarch64/aarch64-builtins.c:1109 config/arm/arm-builtins.c:2272
+#, gcc-internal-format
 msgid "%Kargument %d must be a constant immediate"
-msgstr "аргумент должен быть константой"
+msgstr "%Kаргумент %d должен быть непосредственной константой"
 
 #
-#: config/aarch64/aarch64-builtins.c:1180 config/arm/arm-builtins.c:2492
-#, fuzzy, gcc-internal-format
-#| msgid "index mask must be an immediate"
+#: config/aarch64/aarch64-builtins.c:1180 config/arm/arm-builtins.c:2502
+#, gcc-internal-format
 msgid "%Klane index must be a constant immediate"
-msgstr "маска индекса должна быть непосредственным значением"
+msgstr "%Kиндекс прохода должен быть непосредственной константой"
 
 #
 #: config/aarch64/aarch64-builtins.c:1183
-#, fuzzy, gcc-internal-format
-#| msgid "the second argument must be a 4-bit immediate"
+#, gcc-internal-format
 msgid "%Ktotal size and element size must be a non-zero constant immediate"
-msgstr "второй аргумент должен быть 4-битным непосредственным"
+msgstr "%Kобщий размер и размер элемента должны быть ненулевыми непосредственными константами"
 
-#: config/aarch64/aarch64.c:1053
-#, fuzzy, gcc-internal-format
-#| msgid "%qs is incompatible with %qs"
+#: config/aarch64/aarch64.c:1069
+#, gcc-internal-format
 msgid "%qs is incompatible with %s %s"
-msgstr "%qs несовместим с %qs"
+msgstr "%qs несовместим с %s %s"
 
-#: config/aarch64/aarch64.c:1055
-#, fuzzy, gcc-internal-format
-#| msgid "%qs is incompatible with %qs"
+#: config/aarch64/aarch64.c:1071
+#, gcc-internal-format
 msgid "%qs feature modifier is incompatible with %s %s"
-msgstr "%qs несовместим с %qs"
+msgstr "модификатор %qs возможности несовместим с %s %s"
 
-#: config/aarch64/aarch64.c:3772
+#: config/aarch64/aarch64.c:3788
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10287
+#: config/aarch64/aarch64.c:10303
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown flag passed in -moverride=%s (%s)"
-msgstr ""
+msgstr "неизвестный флаг переданный в -moverride=%s (%s)"
 
-#: config/aarch64/aarch64.c:10331
+#: config/aarch64/aarch64.c:10347
 #, gcc-internal-format, gfc-internal-format
 msgid "%s string ill-formed\n"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10388
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Invalid range %s in option %s"
+#: config/aarch64/aarch64.c:10404
+#, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
-msgstr "некорректный диапазон %s для ключа %s"
+msgstr "строка настройки отсутствует в опции (%s)"
 
-#: config/aarch64/aarch64.c:10406
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "unknown spec function %qs"
+#: config/aarch64/aarch64.c:10422
+#, gcc-internal-format, gfc-internal-format
 msgid "unknown tuning option (%s)"
-msgstr "неизвестная функция %qs в спецификации"
+msgstr "неизвестная опция настройки (%s)"
 
-#: config/aarch64/aarch64.c:10683
-#, fuzzy, gcc-internal-format
-#| msgid "missing path after %qs"
+#: config/aarch64/aarch64.c:10699
+#, gcc-internal-format
 msgid "missing cpu name in %<-mcpu=%s%>"
-msgstr "не задан маршрут после %qs"
+msgstr "отсутствует имя процессора в %<-mcpu=%s%>"
 
-#: config/aarch64/aarch64.c:10690
-#, fuzzy, gcc-internal-format
-#| msgid "invalid pointer mode %qs"
+#: config/aarch64/aarch64.c:10706
+#, gcc-internal-format
 msgid "invalid feature modifier in %<-mcpu=%s%>"
-msgstr "неизвестная машинный режим %qs для указателя"
+msgstr "некорректный модификатор возможности в %<-mcpu=%s%>"
 
-#: config/aarch64/aarch64.c:10717
-#, fuzzy, gcc-internal-format
-#| msgid "missing path after %qs"
+#: config/aarch64/aarch64.c:10733
+#, gcc-internal-format
 msgid "missing arch name in %<-march=%s%>"
-msgstr "не задан маршрут после %qs"
+msgstr "отсутствует имя архитектуры в %<-march=%s%>"
 
 #
-#: config/aarch64/aarch64.c:10720
-#, fuzzy, gcc-internal-format
-#| msgid "unknown value %s for -mfpu"
+#: config/aarch64/aarch64.c:10736
+#, gcc-internal-format
 msgid "unknown value %qs for -march"
-msgstr "неизвестное значение %s для ключа -mfpu"
+msgstr "неизвестное значение %qs для -march"
 
-#: config/aarch64/aarch64.c:10724
-#, fuzzy, gcc-internal-format
-#| msgid "invalid data model option -mdata-model=%s"
+#: config/aarch64/aarch64.c:10740
+#, gcc-internal-format
 msgid "invalid feature modifier in %<-march=%s%>"
-msgstr "некорректная опция модели данных -mdata-model=%s"
+msgstr "некорректный модификатор возможности в %<-march=%s%>"
 
-#: config/aarch64/aarch64.c:10750
-#, fuzzy, gcc-internal-format
-#| msgid "missing filename after %qs"
+#: config/aarch64/aarch64.c:10766
+#, gcc-internal-format
 msgid "missing cpu name in %<-mtune=%s%>"
-msgstr "не задано имя файла после %qs"
+msgstr "отсутствует имя процессора в %<-mtune=%s%>"
 
 #
-#: config/aarch64/aarch64.c:10753
-#, fuzzy, gcc-internal-format
-#| msgid "unknown value %s for -mfpu"
+#: config/aarch64/aarch64.c:10769
+#, gcc-internal-format
 msgid "unknown value %qs for -mtune"
-msgstr "неизвестное значение %s для ключа -mfpu"
+msgstr "неизвестное значение %qs для -mtune"
 
-#: config/aarch64/aarch64.c:10871 config/arm/arm.c:3173
+#: config/aarch64/aarch64.c:10887 config/arm/arm.c:3173
 #, gcc-internal-format, gfc-internal-format
 msgid "switch -mcpu=%s conflicts with -march=%s switch"
 msgstr "ключ -mcpu=%s несовместим с ключом -march=%s"
 
-#: config/aarch64/aarch64.c:10906
-#, fuzzy, gcc-internal-format
-#| msgid "does not support multilib"
+#: config/aarch64/aarch64.c:10922
+#, gcc-internal-format
 msgid "assembler does not support -mabi=ilp32"
-msgstr "не поддерживает мультибиблиотеку"
+msgstr ""
 
-#: config/aarch64/aarch64.c:10913
+#: config/aarch64/aarch64.c:10929
 #, gcc-internal-format
 msgid "return address signing is only supported for -mabi=lp64"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10975
+#: config/aarch64/aarch64.c:10991
 #, gcc-internal-format
 msgid "code model %qs with -f%s"
-msgstr ""
+msgstr "модель кода %qs с -f%s"
 
-#: config/aarch64/aarch64.c:11138
+#: config/aarch64/aarch64.c:11154
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11141
+#: config/aarch64/aarch64.c:11157
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11145 config/aarch64/aarch64.c:11184
-#: config/aarch64/aarch64.c:11257
-#, fuzzy, gcc-internal-format
-#| msgid "invalid argument of %qs attribute"
+#: config/aarch64/aarch64.c:11161 config/aarch64/aarch64.c:11200
+#: config/aarch64/aarch64.c:11273
+#, gcc-internal-format
 msgid "invalid value (\"%s\") in %<target()%> pragma or attribute"
-msgstr "некорректный аргумент атрибута %qs"
+msgstr ""
 
-#: config/aarch64/aarch64.c:11177
+#: config/aarch64/aarch64.c:11193
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11180
+#: config/aarch64/aarch64.c:11196
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11213
+#: config/aarch64/aarch64.c:11229
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"tune=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11253
-#, fuzzy, gcc-internal-format
-#| msgid "missing %<=%> (after %<getter%> attribute)"
+#: config/aarch64/aarch64.c:11269
+#, gcc-internal-format
 msgid "missing value in %<target()%> pragma or attribute"
-msgstr "отсутствует %<=%> (после атрибута %<getter%>)"
+msgstr ""
 
-#: config/aarch64/aarch64.c:11306 config/aarch64/aarch64.c:11483
-#, fuzzy, gcc-internal-format
-#| msgid "malformed #pragma call"
+#: config/aarch64/aarch64.c:11322 config/aarch64/aarch64.c:11499
+#, gcc-internal-format
 msgid "malformed %<target()%> pragma or attribute"
-msgstr "некорректный синтаксис #pragma call"
+msgstr ""
 
-#: config/aarch64/aarch64.c:11354
-#, fuzzy, gcc-internal-format
-#| msgid "%s only accepts 1 argument"
+#: config/aarch64/aarch64.c:11370
+#, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
-msgstr "%s принимает только 1 аргумент"
+msgstr ""
 
-#: config/aarch64/aarch64.c:11362
-#, fuzzy, gcc-internal-format
-#| msgid "matching constraint does not allow a register"
+#: config/aarch64/aarch64.c:11378
+#, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
-msgstr "ограничитель не допускает использование регистра"
+msgstr ""
 
-#: config/aarch64/aarch64.c:11416
-#, fuzzy, gcc-internal-format
-#| msgid "attribute(target(\"%s\")) is unknown"
+#: config/aarch64/aarch64.c:11432
+#, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
-msgstr "attribute(target(\"%s\")) неизвестен"
+msgstr ""
 
-#: config/aarch64/aarch64.c:11473 config/arm/arm.c:30742
-#: config/i386/i386.c:5440 config/powerpcspe/powerpcspe.c:39760
-#: config/rs6000/rs6000.c:36904 config/s390/s390.c:15746
-#, fuzzy, gcc-internal-format
-#| msgid "attribute %qE argument not a string"
+#: config/aarch64/aarch64.c:11489 config/arm/arm.c:30742
+#: config/i386/i386.c:5443 config/powerpcspe/powerpcspe.c:39760
+#: config/rs6000/rs6000.c:36960 config/s390/s390.c:15746
+#, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
-msgstr "аргумент атрибута %qE не является строковой константой"
+msgstr "аргумент атрибута %<target%> не строка"
 
-#: config/aarch64/aarch64.c:11500
-#, fuzzy, gcc-internal-format
-#| msgid "attribute(target(\"%s\")) is unknown"
+#: config/aarch64/aarch64.c:11516
+#, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
-msgstr "attribute(target(\"%s\")) неизвестен"
+msgstr ""
 
-#: config/aarch64/aarch64.c:11509
-#, fuzzy, gcc-internal-format
-#| msgid "malformed #pragma call"
+#: config/aarch64/aarch64.c:11525
+#, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
-msgstr "некорректный синтаксис #pragma call"
+msgstr ""
 
-#: config/aarch64/aarch64.c:13571
+#: config/aarch64/aarch64.c:13587
 #, gcc-internal-format
 msgid "%Klane %wd out of range %wd - %wd"
-msgstr ""
+msgstr "%Kпроход %wd вне диапазона %wd - %wd"
 
-#: config/aarch64/aarch64.c:13573
+#: config/aarch64/aarch64.c:13589
 #, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
-msgstr ""
+msgstr "проход %wd вне диапазона %wd - %wd"
 
 #: config/alpha/alpha.c:419
 #, gcc-internal-format
@@ -32201,8 +27631,8 @@
 msgid "bad value %qs for -mmemory-latency"
 msgstr "некорректное значение %qs для -mmemory-latency"
 
-#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6526
-#: config/arc/arc.c:6800 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
+#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6517
+#: config/arc/arc.c:6791 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
 #: config/tilepro/tilepro.c:3108
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -32211,29 +27641,27 @@
 #: config/arc/arc.c:878
 #, gcc-internal-format
 msgid "-mno-mpy supported only for ARC700 or ARCv2"
-msgstr ""
+msgstr "-mno-mpy поддерживается только для ARC700 или ARCv2"
 
 #: config/arc/arc.c:881
-#, fuzzy, gcc-internal-format
-#| msgid "-fno-fat-lto-objects are supported only with linker plugin."
+#, gcc-internal-format
 msgid "-mno-dpfp-lrsr supported only with -mdpfp"
-msgstr "-fno-fat-lto-objects поддерживается только с linker plugin."
+msgstr "-mno-dpfp-lrsr поддерживается только с -mdpfp"
 
 #: config/arc/arc.c:886
-#, fuzzy, gcc-internal-format
-#| msgid "-mcorea and -mcoreb can%'t be used together"
+#, gcc-internal-format
 msgid "FPX fast and compact options cannot be specified together"
-msgstr "-mcorea и -mcoreb не могут использоваться совместно"
+msgstr "FPX fast и compact опции не могут задаваться вместе"
 
 #: config/arc/arc.c:890
 #, gcc-internal-format
 msgid "-mspfp_fast not available on ARC600 or ARC601"
-msgstr ""
+msgstr "-mspfp_fast недоступно на ARC600 или ARC601"
 
 #: config/arc/arc.c:895
 #, gcc-internal-format
 msgid "No FPX/FPU mixing allowed"
-msgstr ""
+msgstr "FPX/FPU смешение не допускается"
 
 #: config/arc/arc.c:901
 #, gcc-internal-format, gfc-internal-format
@@ -32241,22 +27669,19 @@
 msgstr ""
 
 #: config/arc/arc.c:964
-#, fuzzy, gcc-internal-format
-#| msgid "value of -mfixed-range must have form REG1-REG2"
+#, gcc-internal-format
 msgid "value of -mirq-ctrl-saved must have form R0-REGx"
-msgstr "значение ключа -mfixed-range имеет вид РЕГ1-РЕГ2"
+msgstr ""
 
 #: config/arc/arc.c:976
-#, fuzzy, gcc-internal-format
-#| msgid "first argument must be []byte"
+#, gcc-internal-format
 msgid "first register must be R0"
-msgstr "первый аргумент должен быть []byte"
+msgstr ""
 
 #: config/arc/arc.c:995
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "operand 1 must be a hard register"
+#, gcc-internal-format, gfc-internal-format
 msgid "last register name %s must be an odd register"
-msgstr "первый операнд должен быть аппаратным регистром"
+msgstr ""
 
 #: config/arc/arc.c:1003 config/ia64/ia64.c:6054 config/pa/pa.c:483
 #: config/sh/sh.c:8292 config/spu/spu.c:4941
@@ -32282,21 +27707,19 @@
 #. Check options against architecture options.  Throw an error if
 #. option is not allowed.
 #: config/arc/arc.c:1186 config/arc/arc.c:1194
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "%qD is not a variable in clause %qs"
+#, gcc-internal-format, gfc-internal-format
 msgid "%s is not available for %s architecture"
-msgstr "%qD не есть переменная в клаузуле %qs"
+msgstr "%s отсутствует в %s архитектуре"
 
 #: config/arc/arc.c:1215
 #, gcc-internal-format
 msgid "compact-casesi is not applicable to ARCv2"
-msgstr ""
+msgstr "compact-casesi не применимо к ARCv2"
 
 #: config/arc/arc.c:1731
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "multiple function type attributes specified"
+#, gcc-internal-format, gfc-internal-format
 msgid "multiply option implies r%d is fixed"
-msgstr "задано несколько атрибутов типа функции"
+msgstr "исправлено, что опция умножения влечет r%d"
 
 #: config/arc/arc.c:2006 config/epiphany/epiphany.c:508
 #: config/epiphany/epiphany.c:548
@@ -32312,20 +27735,19 @@
 
 #
 #: config/arc/arc.c:2024
-#, fuzzy, gcc-internal-format
-#| msgid "argument of %qE attribute is not \"ilink1\" or \"ilink2\""
+#, gcc-internal-format
 msgid "argument of %qE attribute is not \"ilink\" or \"firq\""
-msgstr "аргумент атрибута %qE не есть \"ilink1\" или \"ilink2\""
+msgstr ""
 
 #: config/arc/arc.c:2038 config/arm/arm.c:6836 config/arm/arm.c:6854
 #: config/arm/arm.c:7029 config/avr/avr.c:9718 config/avr/avr.c:9734
 #: config/bfin/bfin.c:4705 config/bfin/bfin.c:4766 config/bfin/bfin.c:4795
 #: config/epiphany/epiphany.c:491 config/h8300/h8300.c:5459
-#: config/i386/i386.c:6452 config/i386/i386.c:12479 config/i386/i386.c:41424
-#: config/i386/i386.c:41474 config/i386/i386.c:41544 config/m68k/m68k.c:780
+#: config/i386/i386.c:6455 config/i386/i386.c:12482 config/i386/i386.c:41418
+#: config/i386/i386.c:41468 config/i386/i386.c:41538 config/m68k/m68k.c:780
 #: config/mcore/mcore.c:3070 config/nvptx/nvptx.c:4611
 #: config/powerpcspe/powerpcspe.c:35785 config/riscv/riscv.c:2698
-#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:32982
+#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:33038
 #: config/rx/rx.c:2719 config/rx/rx.c:2745 config/s390/s390.c:1056
 #: config/s390/s390.c:1143 config/sh/sh.c:8428 config/sh/sh.c:8446
 #: config/sh/sh.c:8470 config/sh/sh.c:8541 config/sh/sh.c:8564
@@ -32335,148 +27757,135 @@
 msgid "%qE attribute only applies to functions"
 msgstr "%qE атрибут применим только к функциям"
 
-#: config/arc/arc.c:6425
-#, fuzzy, gcc-internal-format
-#| msgid "%<__builtin_next_arg%> called without an argument"
+#: config/arc/arc.c:6416
+#, gcc-internal-format
 msgid "__builtin_arc_aligned with non-constant alignment"
-msgstr "вызов %<__builtin_next_arg%> без аргумента"
+msgstr "__builtin_arc_aligned с неконстантным выравниванием"
 
-#: config/arc/arc.c:6433
-#, fuzzy, gcc-internal-format
-#| msgid "invalid argument to %<__builtin_frame_address%>"
+#: config/arc/arc.c:6424
+#, gcc-internal-format
 msgid "invalid alignment value for __builtin_arc_aligned"
-msgstr "неверный аргумент для %<__builtin_frame_address%>"
+msgstr "некорректное значение выравнивания для __builtin_arc_aligned"
 
-#: config/arc/arc.c:6596
-#, fuzzy, gcc-internal-format
-#| msgid "-mcorea should be used with -mmulticore"
+#: config/arc/arc.c:6587
+#, gcc-internal-format
 msgid "operand 1 should be an unsigned 3-bit immediate"
-msgstr "-mcorea следует использовать с -mmulticore"
+msgstr "аргумент 1 должен быть непосредственным беззнаковым 3-битным"
 
-#: config/arc/arc.c:6637 config/arc/arc.c:6734
+#: config/arc/arc.c:6628 config/arc/arc.c:6725
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (I0-I7)"
-msgstr ""
+msgstr "операнд 2 должен быть беззнаковым 3-битным значением (I0-I7)"
 
-#: config/arc/arc.c:6670 config/arc/arc.c:6702
+#: config/arc/arc.c:6661 config/arc/arc.c:6693
 #, gcc-internal-format
 msgid "operand 1 should be an unsigned 3-bit value (I0-I7)"
-msgstr ""
+msgstr "операнд 1 должен быть беззнаковым 3-битным значением (I0-I7)"
 
-#: config/arc/arc.c:6674 config/arc/arc.c:6706
+#: config/arc/arc.c:6665 config/arc/arc.c:6697
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 8-bit value"
-msgstr ""
+msgstr "операнд 2 должен быть беззнаковым 8-битным значением"
 
-#: config/arc/arc.c:6738
+#: config/arc/arc.c:6729
 #, gcc-internal-format
 msgid "operand 3 should be an unsigned 8-bit value"
-msgstr ""
+msgstr "операнд 3 должен быть беззнаковым 8-битным значением"
 
-#: config/arc/arc.c:6771
+#: config/arc/arc.c:6762
 #, gcc-internal-format
 msgid "operand 4 should be an unsigned 8-bit value (0-255)"
-msgstr ""
+msgstr "операнд 4 должен быть беззнаковым 8-битным значением (0-255)"
 
-#: config/arc/arc.c:6775
+#: config/arc/arc.c:6766
 #, gcc-internal-format
 msgid "operand 3 should be an unsigned 3-bit value (I0-I7)"
-msgstr ""
+msgstr "операнд 3 должен быть беззнаковым 3-битным значением (I0-I7)"
 
-#: config/arc/arc.c:6782
+#: config/arc/arc.c:6773
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (subreg 0-7)"
-msgstr ""
+msgstr "операнд 2 должен быть беззнаковым 3-битным значением (подрегистр 0-7)"
 
-#: config/arc/arc.c:6785
+#: config/arc/arc.c:6776
 #, gcc-internal-format
 msgid "operand 2 should be an even 3-bit value (subreg 0,2,4,6)"
-msgstr ""
+msgstr "операнд 2 должен быть четным 3-битным значением (подрегистр 0,2,4,6)"
 
-#: config/arc/arc.c:6832
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "symbol used as immediate operand"
+#: config/arc/arc.c:6823
+#, gcc-internal-format, gfc-internal-format
 msgid "builtin requires an immediate for operand %d"
-msgstr "символ использован как непосредственный операнд"
+msgstr "внутренняя функция требует непосредственное значение для операнда %d"
 
-#: config/arc/arc.c:6837
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "argument 2 must be a 5-bit unsigned literal"
+#: config/arc/arc.c:6828
+#, gcc-internal-format, gfc-internal-format
 msgid "operand %d should be a 6 bit unsigned immediate"
-msgstr "аргумент 2 должен быть 5-битным беззнаковым литералом"
+msgstr "операнд %d должен быть 6-битным беззнаковым непосредственным"
 
-#: config/arc/arc.c:6841
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "argument 2 must be a 5-bit unsigned literal"
+#: config/arc/arc.c:6832
+#, gcc-internal-format, gfc-internal-format
 msgid "operand %d should be a 8 bit unsigned immediate"
-msgstr "аргумент 2 должен быть 5-битным беззнаковым литералом"
+msgstr "операнд %d должен быть 8-битным беззнаковым непосредственным"
 
-#: config/arc/arc.c:6845
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "argument 2 must be a 5-bit unsigned literal"
+#: config/arc/arc.c:6836
+#, gcc-internal-format, gfc-internal-format
 msgid "operand %d should be a 3 bit unsigned immediate"
-msgstr "аргумент 2 должен быть 5-битным беззнаковым литералом"
+msgstr "операнд %d должен быть 3-битным беззнаковым непосредственным"
 
-#: config/arc/arc.c:6848
+#: config/arc/arc.c:6839
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown builtin immediate operand type for operand %d"
-msgstr ""
+msgstr "неизвестный тип непосредственного операнда встроенной функции для операнда %d"
 
-#: config/arc/arc.c:6899
+#: config/arc/arc.c:6890
 #, gcc-internal-format
 msgid "register number must be a compile-time constant. Try giving higher optimization levels"
 msgstr ""
 
-#: config/arc/arc.c:7685
+#: config/arc/arc.c:7747
 #, gcc-internal-format
 msgid "Insn addresses not set after shorten_branches"
-msgstr ""
+msgstr "Адреса инструкций не установлены после shorten_branches"
 
-#: config/arc/arc.c:7894
-#, fuzzy, gcc-internal-format
-#| msgid "Bad address, not register:"
+#: config/arc/arc.c:7956
+#, gcc-internal-format
 msgid "insn addresses not freed"
-msgstr "некорректный адрес, не register:"
+msgstr "адреса инструкций не освобождены"
 
-#: config/arc/arc.c:10682
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute only available for 32-bit"
+#: config/arc/arc.c:10670
+#, gcc-internal-format
 msgid "%qE attribute only valid for ARCv2 architecture"
-msgstr "атрибут %qE допустим только для 32 бит"
+msgstr ""
 
 #
-#: config/arc/arc.c:10690 config/arc/arc.c:10729
-#, fuzzy, gcc-internal-format
-#| msgid "argument of %qE attribute is not \"ilink1\" or \"ilink2\""
+#: config/arc/arc.c:10678 config/arc/arc.c:10717
+#, gcc-internal-format
 msgid "argument of %qE attribute is missing"
-msgstr "аргумент атрибута %qE не есть \"ilink1\" или \"ilink2\""
+msgstr ""
 
-#: config/arc/arc.c:10701 config/arc/arc.c:10740 config/arc/arc.c:10842
+#: config/arc/arc.c:10689 config/arc/arc.c:10728 config/arc/arc.c:10830
 #: config/avr/avr.c:9790
 #, gcc-internal-format
 msgid "%qE attribute allows only an integer constant argument"
 msgstr "аргументом атрибута %qE должна быть целая константа"
 
-#: config/arc/arc.c:10721
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute only applies to function types"
+#: config/arc/arc.c:10709
+#, gcc-internal-format
 msgid "%qE attribute only valid for ARC EM architecture"
-msgstr "атрибут %qE допустим только для функций"
+msgstr ""
 
-#: config/arc/arc.c:10776
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute only applies to function types"
+#: config/arc/arc.c:10764
+#, gcc-internal-format
 msgid "%qE attribute only applies to types"
-msgstr "атрибут %qE допустим только для функций"
+msgstr ""
 
 #
-#: config/arc/arc.c:10782
-#, fuzzy, gcc-internal-format
-#| msgid "argument of %qE attribute is not \"ilink1\" or \"ilink2\""
+#: config/arc/arc.c:10770
+#, gcc-internal-format
 msgid "argument of %qE attribute ignored"
-msgstr "аргумент атрибута %qE не есть \"ilink1\" или \"ilink2\""
+msgstr ""
 
-#: config/arc/arc.c:10832 config/avr/avr.c:9777 config/bfin/bfin.c:4827
+#: config/arc/arc.c:10820 config/avr/avr.c:9777 config/bfin/bfin.c:4827
 #: config/i386/winnt.c:63 config/msp430/msp430.c:2018
 #: config/nvptx/nvptx.c:4634
 #, gcc-internal-format
@@ -32483,176 +27892,174 @@
 msgid "%qE attribute only applies to variables"
 msgstr "%qE атрибут применим только к переменным"
 
-#: config/arm/arm-builtins.c:2370
-#, fuzzy, gcc-internal-format
-#| msgid "nested functions not supported on this target"
+#: config/arm/arm-builtins.c:2380
+#, gcc-internal-format
 msgid "this builtin is not supported for this target"
-msgstr "вложенные функции не поддерживаются для этой платформы"
+msgstr "эта внутренняя функция не поддерживается для этой платформы"
 
-#: config/arm/arm-builtins.c:2475
+#: config/arm/arm-builtins.c:2485
 #, gcc-internal-format
 msgid "You must enable NEON instructions (e.g. -mfloat-abi=softfp -mfpu=neon) to use these intrinsics."
-msgstr ""
+msgstr "Вы должны включить NEON инструкции (например, -mfloat-abi=softfp -mfpu=neon) для использования этих встроенных функций."
 
-#: config/arm/arm-builtins.c:2513
+#: config/arm/arm-builtins.c:2523
 #, gcc-internal-format
 msgid "You must enable VFP instructions to use these intrinsics."
-msgstr ""
+msgstr "Вы должны включить NEON инструкции для использования этих встроенных функций."
 
-#: config/arm/arm-builtins.c:2573
+#: config/arm/arm-builtins.c:2583
 #, gcc-internal-format
 msgid "You must enable crypto instructions (e.g. include -mfloat-abi=softfp -mfpu=crypto-neon...) to use these intrinsics."
-msgstr ""
+msgstr "Вы должны включить крипто инструкции (например, включить -mfloat-abi=softfp -mfpu=neon...) для использования этих встроенных функций."
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:2633 config/arm/arm-builtins.c:2737
+#: config/arm/arm-builtins.c:2643 config/arm/arm-builtins.c:2747
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr "селектор должен быть непосредственным значением"
 
-#: config/arm/arm-builtins.c:2641 config/arm/arm-builtins.c:2686
-#: config/arm/arm-builtins.c:2744 config/arm/arm-builtins.c:2753
+#: config/arm/arm-builtins.c:2651 config/arm/arm-builtins.c:2696
+#: config/arm/arm-builtins.c:2754 config/arm/arm-builtins.c:2763
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
-msgstr ""
+msgstr "диапазон селектора должен быть от 0 до 7"
 
-#: config/arm/arm-builtins.c:2646 config/arm/arm-builtins.c:2755
+#: config/arm/arm-builtins.c:2656 config/arm/arm-builtins.c:2765
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
-msgstr ""
+msgstr "диапазон селектора должен быть от 0 до 3"
 
-#: config/arm/arm-builtins.c:2651 config/arm/arm-builtins.c:2757
+#: config/arm/arm-builtins.c:2661 config/arm/arm-builtins.c:2767
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
-msgstr ""
+msgstr "диапазон селектора должен быть от 0 до 1"
 
-#: config/arm/arm-builtins.c:2823
+#: config/arm/arm-builtins.c:2833
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr "маска должна быть непосредственным значением"
 
-#: config/arm/arm-builtins.c:2828
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute argument should be between 0 to 255"
+#: config/arm/arm-builtins.c:2838
+#, gcc-internal-format
 msgid "the range of mask should be in 0 to 255"
-msgstr "аргумент атрибута %qE должен быть между 0 и 255"
+msgstr "диапазон маски должен быть от 0 до 255"
 
-#: config/arm/arm-builtins.c:3016
+#: config/arm/arm-builtins.c:3026
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3018
+#: config/arm/arm-builtins.c:3028
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3020
+#: config/arm/arm-builtins.c:3030
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3022
+#: config/arm/arm-builtins.c:3032
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3028
+#: config/arm/arm-builtins.c:3038
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3030
+#: config/arm/arm-builtins.c:3040
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3035
+#: config/arm/arm-builtins.c:3045
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3037
+#: config/arm/arm-builtins.c:3047
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3039
+#: config/arm/arm-builtins.c:3049
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3041
+#: config/arm/arm-builtins.c:3051
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3043
+#: config/arm/arm-builtins.c:3053
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3045
+#: config/arm/arm-builtins.c:3055
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3047
+#: config/arm/arm-builtins.c:3057
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3049
+#: config/arm/arm-builtins.c:3059
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3051
+#: config/arm/arm-builtins.c:3061
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3053
+#: config/arm/arm-builtins.c:3063
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3055
+#: config/arm/arm-builtins.c:3065
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3057
+#: config/arm/arm-builtins.c:3067
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3059
+#: config/arm/arm-builtins.c:3069
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3061
+#: config/arm/arm-builtins.c:3071
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3063
+#: config/arm/arm-builtins.c:3073
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3065
+#: config/arm/arm-builtins.c:3075
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3067
+#: config/arm/arm-builtins.c:3077
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3069
+#: config/arm/arm-builtins.c:3079
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr ""
@@ -32659,10 +28066,9 @@
 
 #
 #: config/arm/arm.c:2863
-#, fuzzy, gcc-internal-format
-#| msgid "-fPIC and -G are incompatible"
+#, gcc-internal-format
 msgid "iWMMXt and NEON are incompatible"
-msgstr "ключи -fPIC и -G несовместимы"
+msgstr "iWMMXt и NEON несовместимы"
 
 #: config/arm/arm.c:2869
 #, gcc-internal-format
@@ -32687,7 +28093,7 @@
 #: config/arm/arm.c:2888
 #, gcc-internal-format
 msgid "iWMMXt unsupported under Thumb mode"
-msgstr ""
+msgstr "iWMMXt не поддерживается в Thumb режиме"
 
 #: config/arm/arm.c:2891
 #, gcc-internal-format
@@ -32727,7 +28133,7 @@
 #: config/arm/arm.c:3419
 #, gcc-internal-format
 msgid "APCS reentrant code not supported.  Ignored"
-msgstr "реентерабельный код APCS не поддерживается. Ключ игнорируется."
+msgstr ""
 
 #: config/arm/arm.c:3442
 #, gcc-internal-format
@@ -32765,10 +28171,9 @@
 msgstr "-freorder-blocks-and-partition не поддерживается на этой архитектуре"
 
 #: config/arm/arm.c:3672
-#, fuzzy, gcc-internal-format
-#| msgid "-mrelocatable and -msdata=%s are incompatible"
+#, gcc-internal-format
 msgid "selected fp16 options are incompatible"
-msgstr "ключи -mrelocatable и -msdata=%s несовместимы"
+msgstr "выбранные fp16 опции несовместимы"
 
 #: config/arm/arm.c:3709
 #, gcc-internal-format
@@ -32801,10 +28206,9 @@
 msgstr "__fp16 и нет ldrh"
 
 #: config/arm/arm.c:3744
-#, fuzzy, gcc-internal-format
-#| msgid "target CPU does not support THUMB instructions"
+#, gcc-internal-format
 msgid "target CPU does not support ARMv8-M Security Extensions"
-msgstr "целевой процессор не поддерживает команды THUMB"
+msgstr "целевой процессор не поддерживает ARMv8-M Security Extensions"
 
 #: config/arm/arm.c:3749
 #, gcc-internal-format
@@ -32812,10 +28216,9 @@
 msgstr ""
 
 #: config/arm/arm.c:3760
-#, fuzzy, gcc-internal-format
-#| msgid "-mfloat-abi=hard and VFP"
+#, gcc-internal-format
 msgid "-mfloat-abi=hard: selected processor lacks an FPU"
-msgstr "-mflat-abi=hard и VFP"
+msgstr "-mfloat-abi=hard: в выбранном процессоре нет FPU"
 
 #: config/arm/arm.c:3768
 #, gcc-internal-format
@@ -32846,58 +28249,52 @@
 #: config/arm/arm.c:26895
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
-msgstr ""
+msgstr "передача параметров для аргументов типа %qT изменилась в GCC 7.1"
 
 #: config/arm/arm.c:6978
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute only applies to functions, not %s"
+#, gcc-internal-format
 msgid "%qE attribute not available to functions with arguments passed on the stack"
-msgstr "атрибут %qE применим только к функциям, а не к %s"
+msgstr "атрибут %qE не доступен для функций с аргументами переданными на стеке"
 
 #: config/arm/arm.c:6990
-#, fuzzy, gcc-internal-format
-#| msgid "%qD must not have variable number of arguments"
+#, gcc-internal-format
 msgid "%qE attribute not available to functions with variable number of arguments"
-msgstr "%qD не может иметь переменное число аргументов"
+msgstr "атрибут %qE не доступен для функций с переменным числом аргументов"
 
 #: config/arm/arm.c:6999
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute only applies to functions, not %s"
+#, gcc-internal-format
 msgid "%qE attribute not available to functions that return value on the stack"
-msgstr "атрибут %qE применим только к функциям, а не к %s"
+msgstr "атрибут %qE не доступен для функций, которые возвращают значение на стеке"
 
 #: config/arm/arm.c:7021 config/arm/arm.c:7073
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute ignored on non-class types"
+#, gcc-internal-format
 msgid "%qE attribute ignored without -mcmse option."
-msgstr "атрибут %qE для не классовых типов игнорируется"
+msgstr "атрибут %qE игнорируется без -mcmse опции."
 
 #: config/arm/arm.c:7040
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute has no effect on unit local functions"
+#, gcc-internal-format
 msgid "%qE attribute has no effect on functions with static linkage"
-msgstr "атрибут %qE не действует для локальных функций"
+msgstr "атрибут %qE не действует на функции со статической компоновкой"
 
 #: config/arm/arm.c:7089
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute only applies to function types"
+#, gcc-internal-format
 msgid "%qE attribute only applies to base type of a function pointer"
-msgstr "атрибут %qE допустим только для функций"
+msgstr "атрибут %qE применим только к базовому типу указателя на функцию"
 
 #: config/arm/arm.c:8822
 #, gcc-internal-format
 msgid "accessing thread-local storage is not currently supported with -mpure-code or -mslow-flash-data"
-msgstr ""
+msgstr "доступ к локальной памяти потока в настоящее время не поддерживается с -mpure-code или -mslow-flash-data"
 
 #: config/arm/arm.c:12466
 #, gcc-internal-format
 msgid "%K%s %wd out of range %wd - %wd"
-msgstr ""
+msgstr "%K%s %wd вне диапазона %wd - %wd"
 
 #: config/arm/arm.c:12469
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
-msgstr ""
+msgstr "%s %wd вне диапазона %wd - %wd"
 
 #: config/arm/arm.c:23851
 #, gcc-internal-format
@@ -32905,10 +28302,9 @@
 msgstr "невозможно вычислить фактическое положение параметра в стеке"
 
 #: config/arm/arm.c:24507
-#, fuzzy, gcc-internal-format
-#| msgid "Unexpected end of module"
+#, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
-msgstr "Неожиданный конец модуля"
+msgstr "Неожиданный thumb1 далекий переход"
 
 #: config/arm/arm.c:24771
 #, gcc-internal-format
@@ -32923,13 +28319,12 @@
 #: config/arm/arm.c:25252
 #, gcc-internal-format
 msgid "-fstack-check=specific for Thumb-1"
-msgstr ""
+msgstr "-fstack-check=specific для Thumb-1"
 
 #: config/arm/arm.c:30766
-#, fuzzy, gcc-internal-format
-#| msgid "invalid vector type for attribute %qs"
+#, gcc-internal-format
 msgid "invalid fpu for target attribute or pragma %qs"
-msgstr "некорректный векторный тип для атрибута %qs"
+msgstr ""
 
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
@@ -32937,72 +28332,62 @@
 #: config/arm/arm.c:30774
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
-msgstr ""
+msgstr "auto fpu выбор в настоящее время здесь не допускается"
 
 #: config/arm/arm.c:30787
-#, fuzzy, gcc-internal-format
-#| msgid "invalid vector type for attribute %qE"
+#, gcc-internal-format
 msgid "invalid architecture for target attribute or pragma %qs"
-msgstr "неверно задан векторный тип для атрибута %qE"
+msgstr ""
 
 #: config/arm/arm.c:30801
-#, fuzzy, gcc-internal-format
-#| msgid "unknown property attribute before %<#pragma%>"
+#, gcc-internal-format
 msgid "unknown target attribute or pragma %qs"
-msgstr "неизвестный атрибут свойства перед %<#pragma%>"
+msgstr ""
 
 #: config/arm/freebsd.h:121
-#, fuzzy, gcc-internal-format
-#| msgid "target CPU does not support unaligned accesses"
+#, gcc-internal-format
 msgid "target OS does not support unaligned accesses"
-msgstr "целевой процессор не поддерживает невыровненные доступы"
+msgstr "целевая OS не поддерживает невыровненные доступы"
 
 #: config/avr/avr-c.c:65 config/avr/avr-c.c:190
-#, fuzzy, gcc-internal-format
-#| msgid "%qs expects a constant argument"
+#, gcc-internal-format
 msgid "%qs expects 1 argument but %d given"
-msgstr "для %qs требуется константный аргумент"
+msgstr "%qs ожидает 1 аргумент а дано %d"
 
 #: config/avr/avr-c.c:76
-#, fuzzy, gcc-internal-format
-#| msgid "%qs expects a constant argument"
+#, gcc-internal-format
 msgid "%qs expects a fixed-point value as argument"
-msgstr "для %qs требуется константный аргумент"
+msgstr "%qs ожидает значение с фиксированной точкой как аргумент"
 
 #: config/avr/avr-c.c:102
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute has no effect"
+#, gcc-internal-format
 msgid "using %qs with unsigned type has no effect"
-msgstr "атрибут %qE не действует"
+msgstr "использование %qs с беззнаковым типом не имеет эффекта"
 
 #: config/avr/avr-c.c:107 config/avr/avr-c.c:173 config/avr/avr-c.c:230
-#, fuzzy, gcc-internal-format
-#| msgid "no matching template for %qD found"
+#, gcc-internal-format
 msgid "no matching fixed-point overload found for %qs"
-msgstr "нет подходящего шаблона для %qD"
+msgstr "не найдено соответствующей перегрузки с фиксированной точкой для %qs"
 
 #: config/avr/avr-c.c:124
-#, fuzzy, gcc-internal-format
-#| msgid "%qs expects a constant argument"
+#, gcc-internal-format
 msgid "%qs expects 2 arguments but %d given"
-msgstr "для %qs требуется константный аргумент"
+msgstr "%qs ожидает 2 аргумента а дано %d"
 
 #: config/avr/avr-c.c:136 config/avr/avr-c.c:201
-#, fuzzy, gcc-internal-format
-#| msgid "%qs expects a constant argument"
+#, gcc-internal-format
 msgid "%qs expects a fixed-point value as first argument"
-msgstr "для %qs требуется константный аргумент"
+msgstr "%qs ожидает значение с фиксированной точкой как первый аргумент"
 
 #: config/avr/avr-c.c:144
-#, fuzzy, gcc-internal-format
-#| msgid "%qs expects a constant argument"
+#, gcc-internal-format
 msgid "%qs expects an integer value as second argument"
-msgstr "для %qs требуется константный аргумент"
+msgstr "%qs ожидает целочисленное значение как второй аргумент"
 
 #: config/avr/avr-devices.c:152
 #, gcc-internal-format, gfc-internal-format
 msgid "supported core architectures:%s"
-msgstr ""
+msgstr "поддерживаемые архитектуры ядра:%s"
 
 #. Reached the end of `avr_mcu_types'.  This should actually never
 #. happen as options are provided by device-specs.  It could be a
@@ -33009,10 +28394,9 @@
 #. typo in a device-specs or calling the compiler proper directly
 #. with -mmcu=<device>.
 #: config/avr/avr.c:707
-#, fuzzy, gcc-internal-format
-#| msgid "no class name specified with %qs"
+#, gcc-internal-format
 msgid "unknown core architecture %qs specified with %qs"
-msgstr "не задано имя класса для %qs"
+msgstr "неизвестная архитектура ядра %qs задана с %qs"
 
 #: config/avr/avr.c:765 config/visium/visium.c:417
 #, gcc-internal-format
@@ -33025,22 +28409,19 @@
 msgstr "ключ -fPIC не поддерживается"
 
 #: config/avr/avr.c:769
-#, fuzzy, gcc-internal-format
-#| msgid "-fpic is not supported"
+#, gcc-internal-format
 msgid "-fpie is not supported"
-msgstr "ключ -fpic не поддерживается"
+msgstr "-fpie не поддерживается"
 
 #: config/avr/avr.c:771
-#, fuzzy, gcc-internal-format
-#| msgid "-fPIC is not supported"
+#, gcc-internal-format
 msgid "-fPIE is not supported"
-msgstr "ключ -fPIC не поддерживается"
+msgstr "-fPIE не поддерживается"
 
 #: config/avr/avr.c:1047 config/avr/avr.c:1052
-#, fuzzy, gcc-internal-format
-#| msgid "function attributes %qs, %qs and %qs are mutually exclusive"
+#, gcc-internal-format
 msgid "function attributes %qs and %qs are mutually exclusive"
-msgstr "атрибуты функций %qs, %qs и %qs несовместимы"
+msgstr ""
 
 #: config/avr/avr.c:1073
 #, gcc-internal-format
@@ -33053,10 +28434,9 @@
 msgstr "%qs функция не может возвращать значение"
 
 #: config/avr/avr.c:1090
-#, fuzzy, gcc-internal-format
-#| msgid "%qs appears to be a misspelled %s handler"
+#, gcc-internal-format
 msgid "%qs appears to be a misspelled %qs handler, missing %<__vector%> prefix"
-msgstr "%qs возможно искаженный %s обработчик"
+msgstr "%qs похоже искаженный %qs обработчик, отсутствует %<__vector%> префикс"
 
 #: config/avr/avr.c:1103
 #, gcc-internal-format
@@ -33064,10 +28444,9 @@
 msgstr ""
 
 #: config/avr/avr.c:1336
-#, fuzzy, gcc-internal-format
-#| msgid "'builtin_return_address' contains only 2 bytes of address"
+#, gcc-internal-format
 msgid "%<builtin_return_address%> contains only 2 bytes of address"
-msgstr "'builtin_return_address' содержит только 2 байта адреса"
+msgstr "%<builtin_return_address%> содержит только 2 байта адреса"
 
 #: config/avr/avr.c:2759
 #, gcc-internal-format
@@ -33095,45 +28474,39 @@
 msgstr "запись в адресное пространство %qs не поддерживается"
 
 #: config/avr/avr.c:9753
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute only applies to variables and functions"
+#, gcc-internal-format
 msgid "%qE attribute only applies to variables in static storage"
-msgstr "атрибут %qE применим только к переменным и функциям"
+msgstr "атрибут %qE применим только к переменным в статической памяти"
 
 #: config/avr/avr.c:9760
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute is not supported for R8C target"
+#, gcc-internal-format
 msgid "%qE attribute only supported for reduced Tiny cores"
-msgstr "атрибут %qE не поддерживается для R8C платформы"
+msgstr "атрибут %qE поддерживается только для сокращенных Tiny ядер"
 
 #: config/avr/avr.c:9800
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute has no effect"
+#, gcc-internal-format
 msgid "%qE attribute address out of range"
-msgstr "атрибут %qE не действует"
+msgstr "адрес атрибута %qE вне диапазона"
 
 #: config/avr/avr.c:9814
 #, gcc-internal-format
 msgid "both %s and %qE attribute provide address"
-msgstr ""
+msgstr "и %s и %qE атрибут предоставляют адрес"
 
 #: config/avr/avr.c:9824
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute only applies to variables"
+#, gcc-internal-format
 msgid "%qE attribute on non-volatile variable"
-msgstr "%qE атрибут применим только к переменным"
+msgstr "%qE атрибут для non-volatile переменной"
 
 #: config/avr/avr.c:9896
-#, fuzzy, gcc-internal-format
-#| msgid "nested functions not supported on this target"
+#, gcc-internal-format
 msgid "address spaces are not supported for reduced Tiny devices"
-msgstr "вложенные функции не поддерживаются для этой платформы"
+msgstr "адресные пространства не поддерживаются для сокращенных Tiny устройств"
 
 #: config/avr/avr.c:9903
-#, fuzzy, gcc-internal-format
-#| msgid "code model %qs not supported in the %s bit mode"
+#, gcc-internal-format
 msgid "address space %qs not supported for devices with flash size up to %d KiB"
-msgstr "модель кодирования %s не поддерживается в %s-битном режиме"
+msgstr "адресное пространство %qs не поддерживается для устройств с флэш-памятью размером до %d KiB"
 
 #: config/avr/avr.c:10074
 #, gcc-internal-format
@@ -33148,19 +28521,17 @@
 #: config/avr/avr.c:10139
 #, gcc-internal-format
 msgid "variable %q+D must be const in order to be put into read-only section by means of %qs"
-msgstr "переменная %q+D должна быть const чтобы ее можно было поместить в доступную только на чтение секцию посредством %qs"
+msgstr "переменная %q+D должна быть const, чтобы ее можно было поместить в доступную только на чтение секцию посредством %qs"
 
 #: config/avr/avr.c:10178
-#, fuzzy, gcc-internal-format
-#| msgid "declaration of %q+D shadows a parameter"
+#, gcc-internal-format
 msgid "static IO declaration for %q+D needs an address"
-msgstr "декларация %q+D перекрывает параметр"
+msgstr "декларация статического IO для %q+D требует адрес"
 
 #: config/avr/avr.c:10210
-#, fuzzy, gcc-internal-format
-#| msgid "previous definition of %q+D was here"
+#, gcc-internal-format
 msgid "IO definition for %q+D needs an address"
-msgstr "здесь было предыдущее определение %q+D"
+msgstr "декларация IO для %q+D требует адрес"
 
 #: config/avr/avr.c:10328
 #, gcc-internal-format
@@ -33169,10 +28540,9 @@
 
 #. This might happen with C++ if stuff needs constructing.
 #: config/avr/avr.c:10404
-#, fuzzy, gcc-internal-format
-#| msgid "uninitialized variable %q+D put into program memory area"
+#, gcc-internal-format
 msgid "variable %q+D with dynamic initialization put into program memory area"
-msgstr "неинициализированная переменная %q+D помещена в область программной памяти"
+msgstr "переменная %q+D с динамической инициализацией помещена в область программной памяти"
 
 #: config/avr/avr.c:10415
 #, gcc-internal-format
@@ -33180,22 +28550,19 @@
 msgstr "неинициализированная переменная %q+D помещена в область программной памяти"
 
 #: config/avr/avr.c:10501
-#, fuzzy, gcc-internal-format
-#| msgid "%qE incompatible attribute ignored"
+#, gcc-internal-format
 msgid "%q+D has incompatible attributes %qs and %qs"
-msgstr "несовместимый атрибут %qE игнорируется"
+msgstr "%q+D имеет несовместимые атрибуты %qs и %qs"
 
 #: config/avr/avr.c:10564
-#, fuzzy, gcc-internal-format
-#| msgid "MCU %qs supported for assembler only"
+#, gcc-internal-format
 msgid "architecture %qs supported for assembler only"
-msgstr "MCU %qs поддерживается только для ассемблера"
+msgstr "архитектура %qs поддерживается только для ассемблера"
 
 #: config/avr/avr.c:13190
-#, fuzzy, gcc-internal-format
-#| msgid "Conversion from %s to %s at %L"
+#, gcc-internal-format
 msgid "conversion from address space %qs to address space %qs"
-msgstr "Преобразование из %s в %s в %L"
+msgstr "преобразование из адресного пространства %qs в адресное пространство %qs"
 
 #: config/avr/avr.c:14280 config/avr/avr.c:14293
 #, gcc-internal-format, gfc-internal-format
@@ -33210,30 +28577,27 @@
 #: config/avr/avr.c:14335
 #, gcc-internal-format, gfc-internal-format
 msgid "rounding to %d bits has no effect for fixed-point value with %d fractional bits"
-msgstr ""
+msgstr "округление до %d бит не влияет на величину с фиксированной точкой с %d битами в дробной части"
 
 #: config/avr/avr.c:14344
 #, gcc-internal-format
 msgid "rounding result will always be 0"
-msgstr ""
+msgstr "результат округления всегда будет 0"
 
 #: config/avr/driver-avr.c:58
-#, fuzzy, gcc-internal-format
-#| msgid "unknown spec function %qs"
+#, gcc-internal-format
 msgid "bad usage of spec function %qs"
-msgstr "неизвестная функция %qs в спецификации"
+msgstr "некорректное использование spec функции %qs"
 
 #: config/avr/driver-avr.c:86
-#, fuzzy, gcc-internal-format
-#| msgid "Array specification at %C has more than %d dimensions"
+#, gcc-internal-format
 msgid "specified option %qs more than once"
-msgstr "Спецификация массива в %C имеет больше чем %d измерений"
+msgstr "опция %qs задана более одного раза"
 
 #: config/avr/driver-avr.c:100
-#, fuzzy, gcc-internal-format
-#| msgid "specs file malformed after %ld characters"
+#, gcc-internal-format
 msgid "strange device name %qs after %qs: bad character %qc"
-msgstr "синтаксис файла спецификаций нарушен после %ld символов"
+msgstr "имя запоминающего устройства %qs после %qs: некорректный символ %qc"
 
 #: config/bfin/bfin.c:2382
 #, gcc-internal-format
@@ -33459,10 +28823,9 @@
 msgstr "нет FUNCTION_PROFILER для CRIS"
 
 #: config/epiphany/epiphany.c:499
-#, fuzzy, gcc-internal-format
-#| msgid "interrupt handlers cannot be MIPS16 functions"
+#, gcc-internal-format
 msgid "interrupt handlers cannot have arguments"
-msgstr "обработчики прерываний не могут быть функциями MIPS16"
+msgstr "обработчики прерываний не могут иметь аргументы"
 
 #: config/epiphany/epiphany.c:523
 #, gcc-internal-format
@@ -33540,28 +28903,24 @@
 msgstr "эта встроенная функция доступна только на fr450"
 
 #: config/ft32/ft32.c:181
-#, fuzzy, gcc-internal-format
-#| msgid "shift of non-integer operand"
+#, gcc-internal-format
 msgid "'h' applied to non-register operand"
-msgstr "сдвиг нецелого операнда"
+msgstr "'h' применено к нерегистровому операнду"
 
 #: config/ft32/ft32.c:206
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "array assignment"
+#, gcc-internal-format, gfc-internal-format
 msgid "bad alignment: %d"
-msgstr "присваивание массивов"
+msgstr "некорректное выравнивание: %d"
 
 #: config/ft32/ft32.c:502
-#, fuzzy, gcc-internal-format
-#| msgid "stack size must not be greater than 64k"
+#, gcc-internal-format
 msgid "stack frame must be smaller than 64K"
-msgstr "размер стека должен быть больше чем 64k"
+msgstr "кадр стека должен быть меньше чем 64k"
 
 #: config/h8300/h8300.c:329
-#, fuzzy, gcc-internal-format
-#| msgid "-f%s not supported: ignored"
+#, gcc-internal-format
 msgid "-msx is not supported in coff"
-msgstr "ключ -f%s не поддерживается; игнорируется"
+msgstr "-msx не поддерживается в coff"
 
 #: config/h8300/h8300.c:351
 #, gcc-internal-format
@@ -33569,39 +28928,34 @@
 msgstr "-ms2600 без -ms"
 
 #: config/h8300/h8300.c:357
-#, fuzzy, gcc-internal-format
-#| msgid "-mn is used without -mh or -ms"
+#, gcc-internal-format
 msgid "-mn is used without -mh or -ms or -msx"
-msgstr "-mn без -mh или -ms"
+msgstr "-mn использовано без -mh или -ms или -msx"
 
 #: config/h8300/h8300.c:363
-#, fuzzy, gcc-internal-format
-#| msgid "-ms2600 is used without -ms"
+#, gcc-internal-format
 msgid "-mexr is used without -ms"
-msgstr "-ms2600 без -ms"
+msgstr "-mexr использовано без -ms"
 
 #: config/h8300/h8300.c:369
-#, fuzzy, gcc-internal-format
-#| msgid "%<__int128%> is not supported for this target"
+#, gcc-internal-format
 msgid "-mint32 is not supported for H8300 and H8300L targets"
-msgstr "%<__int128%> не поддерживается для этой целевой машины"
+msgstr "-mint32 не поддерживается для H8300 и H8300L целей"
 
 #: config/h8300/h8300.c:375
-#, fuzzy, gcc-internal-format
-#| msgid "-mn is used without -mh or -ms"
+#, gcc-internal-format
 msgid "-mexr is used without -ms or -msx"
-msgstr "-mn без -mh или -ms"
+msgstr "-mexr использовано без -ms или -msx"
 
 #: config/h8300/h8300.c:381
 #, gcc-internal-format
 msgid "-mno-exr valid only with -ms or -msx                   - Option ignored!"
-msgstr ""
+msgstr "-mno-exr допускается только с -ms или -msx - Опция игнорируется!"
 
 #: config/h8300/h8300.c:388
-#, fuzzy, gcc-internal-format
-#| msgid "%<__int128%> is not supported for this target"
+#, gcc-internal-format
 msgid "-mn is not supported for linux targets"
-msgstr "%<__int128%> не поддерживается для этой целевой машины"
+msgstr "-mn не поддерживается для linux целей"
 
 #: config/i386/host-cygwin.c:64
 #, gcc-internal-format
@@ -33613,857 +28967,787 @@
 msgid "can%'t set position in PCH file: %m"
 msgstr "невозможно установить позицию в PCH файле: %m"
 
-#: config/i386/i386.c:3177
-#, fuzzy, gcc-internal-format
-#| msgid "-Werror=%s: no option -%s"
+#: config/i386/i386.c:3180
+#, gcc-internal-format
 msgid "wrong argument %qs to option %qs"
-msgstr "-Werror=%s: ключа -%s не существует"
+msgstr "некорректный аргумент %qs для опции %qs"
 
-#: config/i386/i386.c:3183
+#: config/i386/i386.c:3186
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
-msgstr ""
+msgstr "диапазоны размера в опции %qs следует увеличить"
 
-#: config/i386/i386.c:3193
-#, fuzzy, gcc-internal-format
-#| msgid "register name not specified for %q+D"
+#: config/i386/i386.c:3196
+#, gcc-internal-format
 msgid "wrong strategy name %qs specified for option %qs"
-msgstr "не задано имя регистра для %q+D"
+msgstr "некорректное имя стратегии %qs задано для опции %qs"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3219
-#, fuzzy, gcc-internal-format
-#| msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
+#: config/i386/i386.c:3222
+#, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
-msgstr "-mstringop-strategy=rep_8byte не поддерживается для 32-битного кода"
+msgstr "имя стратегии %qs заданное для опции %qs не поддерживается для 32-битного кода"
 
-#: config/i386/i386.c:3232
-#, fuzzy, gcc-internal-format
-#| msgid "alignment specified for function %qE"
+#: config/i386/i386.c:3235
+#, gcc-internal-format
 msgid "unknown alignment %qs specified for option %qs"
-msgstr "выравнивание задано для функции %qE"
+msgstr "неизвестное выравнивание %qs задано для опции %qs"
 
-#: config/i386/i386.c:3242
+#: config/i386/i386.c:3245
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
-msgstr ""
+msgstr "максимальное значение для диапазона последнего размера должно быть -1 для опции %qs"
 
-#: config/i386/i386.c:3249
-#, fuzzy, gcc-internal-format
-#| msgid "Invalid range %s in option %s"
+#: config/i386/i386.c:3252
+#, gcc-internal-format
 msgid "too many size ranges specified in option %qs"
-msgstr "некорректный диапазон %s для ключа %s"
+msgstr "слишком много диапазонов размера задано в опции %qs"
 
-#: config/i386/i386.c:3302
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Unknown argument list function at %L"
+#: config/i386/i386.c:3305
+#, gcc-internal-format, gfc-internal-format
 msgid "unknown parameter to option -mtune-ctrl: %s"
-msgstr "Неизвестная функция списка аргументов в %L"
+msgstr ""
 
-#: config/i386/i386.c:3726
-#, fuzzy, gcc-internal-format
-#| msgid "64-bit ABI not supported in ESA/390 mode"
+#: config/i386/i386.c:3729
+#, gcc-internal-format
 msgid "Intel MCU psABI isn%'t supported in %s mode"
-msgstr "64-битный ABI в режиме ESA/390 не поддерживается"
+msgstr "Intel MCU psABI не поддерживается в %s режиме"
 
-#: config/i386/i386.c:3775
-#, fuzzy, gcc-internal-format
-#| msgid "%stune=x86-64%s is deprecated; use %stune=k8%s or %stune=generic%s instead as appropriate"
+#: config/i386/i386.c:3778
+#, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
-msgstr "%stune=x86-64%s устарело; используйте вместо этого соответственно %stune=k8%s или %stune=generic%s"
+msgstr "%<-mtune=x86-64%> устарело; используйте вместо этого соответственно %<-mtune=k8%> или %<-mtune=generic%>"
 
-#: config/i386/i386.c:3777
-#, fuzzy, gcc-internal-format
-#| msgid "%stune=x86-64%s is deprecated; use %stune=k8%s or %stune=generic%s instead as appropriate"
+#: config/i386/i386.c:3780
+#, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
-msgstr "%stune=x86-64%s устарело; используйте вместо этого соответственно %stune=k8%s или %stune=generic%s"
+msgstr "%<target(\"tune=x86-64\")%> устарело; используйте вместо этого соответственно %<target(\"tune=k8\")%> или %<target(\"tune=generic\")%>"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3804
+#: config/i386/i386.c:3807
 #, gcc-internal-format
 msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgstr "-mstringop-strategy=rep_8byte не поддерживается для 32-битного кода"
 
-#: config/i386/i386.c:3821
-#, fuzzy, gcc-internal-format
-#| msgid "code model %qs not supported in the %s bit mode"
+#: config/i386/i386.c:3824
+#, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
-msgstr "модель кодирования %s не поддерживается в %s-битном режиме"
+msgstr "адресный режим %qs не поддерживается в %s-битном режиме"
 
-#: config/i386/i386.c:3833
-#, fuzzy, gcc-internal-format
-#| msgid "%<__int128%> is not supported by this target"
+#: config/i386/i386.c:3836
+#, gcc-internal-format
 msgid "-mabi=ms not supported with X32 ABI"
-msgstr "%<__int128%> не поддерживается этой целевой платформой"
+msgstr ""
 
-#: config/i386/i386.c:3851 config/i386/i386.c:3860 config/i386/i386.c:3872
-#: config/i386/i386.c:3883 config/i386/i386.c:3894
+#: config/i386/i386.c:3854 config/i386/i386.c:3863 config/i386/i386.c:3875
+#: config/i386/i386.c:3886 config/i386/i386.c:3897
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "модель кодирования %s не поддерживается в %s-битном режиме"
 
-#: config/i386/i386.c:3863 config/i386/i386.c:3875
+#: config/i386/i386.c:3866 config/i386/i386.c:3878
 #, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "модель кода %qs не поддерживается в режиме x32"
 
-#: config/i386/i386.c:3881 config/i386/i386.c:3890 config/i386/i386.c:5213
+#: config/i386/i386.c:3884 config/i386/i386.c:3893 config/i386/i386.c:5216
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "модель кода %s не поддерживает PIC режим"
 
-#: config/i386/i386.c:3918
+#: config/i386/i386.c:3921
 #, gcc-internal-format
 msgid "-masm=intel not supported in this configuration"
 msgstr "-masm=intel не поддерживается в этой конфигурации"
 
-#: config/i386/i386.c:3923
+#: config/i386/i386.c:3926
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "%i-битный режим не компилируется в"
 
-#: config/i386/i386.c:3932
-#, fuzzy, gcc-internal-format
-#| msgid "generic CPU can be used only for %stune=%s %s"
+#: config/i386/i386.c:3935
+#, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
-msgstr "обобщенный процессор может использоваться только для %stune=%s %s"
+msgstr "%<generic%> процессор может использоваться только для %<-mtune=%> ключа"
 
-#: config/i386/i386.c:3934
-#, fuzzy, gcc-internal-format
-#| msgid "generic CPU can be used only for %stune=%s %s"
+#: config/i386/i386.c:3937
+#, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
-msgstr "обобщенный процессор может использоваться только для %stune=%s %s"
+msgstr "%<generic%> процессор может использоваться только для %<target(\"tune=\")%> атрибута"
 
-#: config/i386/i386.c:3941
-#, fuzzy, gcc-internal-format
-#| msgid "generic CPU can be used only for %stune=%s %s"
+#: config/i386/i386.c:3944
+#, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
-msgstr "обобщенный процессор может использоваться только для %stune=%s %s"
+msgstr "%<intel%> процессор может использоваться только для %<-mtune=%> ключа"
 
-#: config/i386/i386.c:3943
-#, fuzzy, gcc-internal-format
-#| msgid "generic CPU can be used only for %stune=%s %s"
+#: config/i386/i386.c:3946
+#, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
-msgstr "обобщенный процессор может использоваться только для %stune=%s %s"
+msgstr "%<intel%> процессор может использоваться только для %<target(\"tune=\")%> атрибута"
 
-#: config/i386/i386.c:3951 config/i386/i386.c:4265
+#: config/i386/i386.c:3954 config/i386/i386.c:4268
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "заданный процессор не поддерживает набор команд x86-64"
 
-#: config/i386/i386.c:4197 config/i386/i386.c:4200
-#, fuzzy, gcc-internal-format
-#| msgid "%s does not support %s"
+#: config/i386/i386.c:4200 config/i386/i386.c:4203
+#, gcc-internal-format
 msgid "Intel MPX does not support x32"
-msgstr "%s не поддерживает %s"
+msgstr "Intel MPX не поддерживает x32"
 
-#: config/i386/i386.c:4205
-#, fuzzy, gcc-internal-format
-#| msgid "bad value (%s) for -march= switch"
+#: config/i386/i386.c:4208
+#, gcc-internal-format
 msgid "bad value (%qs) for %<-march=%> switch"
-msgstr "некорректное значение (%s) для ключа -march"
+msgstr "некорректное значение (%qs) для ключа %<-march=%>"
 
-#: config/i386/i386.c:4206
-#, fuzzy, gcc-internal-format
-#| msgid "bad value (%s) for %sarch=%s %s"
+#: config/i386/i386.c:4209
+#, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"arch=\")%> attribute"
-msgstr "некорректное значение (%s) для %sarch=%s %s"
+msgstr "некорректное значение (%qs) для %<target(\"arch=\")%> атрибута"
 
-#: config/i386/i386.c:4228
-#, fuzzy, gcc-internal-format
-#| msgid "valid arguments to %qs are: %s"
+#: config/i386/i386.c:4231
+#, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
-msgstr "допустимые аргументы %qs: %s"
+msgstr "допустимые аргументы для %<-march=%> ключа: %s; имелось в виду %qs?"
 
-#: config/i386/i386.c:4230
+#: config/i386/i386.c:4233
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
-msgstr ""
+msgstr "допустимые аргументы для %<target(\"arch=\")%> атрибута: %s; вы имели в виду %qs?"
 
-#: config/i386/i386.c:4235
-#, fuzzy, gcc-internal-format
-#| msgid "valid arguments to %qs are: %s"
+#: config/i386/i386.c:4238
+#, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
-msgstr "допустимые аргументы %qs: %s"
+msgstr "допустимые аргументы для %<-march=%> ключа: %s"
 
-#: config/i386/i386.c:4236
-#, fuzzy, gcc-internal-format
-#| msgid "valid arguments to %qs are: %s"
+#: config/i386/i386.c:4239
+#, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
-msgstr "допустимые аргументы %qs: %s"
+msgstr "допустимые аргументы для %<target(\"arch=\")%> атрибута: %s"
 
-#: config/i386/i386.c:4284
-#, fuzzy, gcc-internal-format
-#| msgid "bad value (%s) for -mtune= switch"
+#: config/i386/i386.c:4287
+#, gcc-internal-format
 msgid "bad value (%qs) for %<-mtune=%> switch"
-msgstr "некорректное значение (%s) для ключа -mtune="
+msgstr "некорректное значение (%qs) для ключа %<-mtune=%>"
 
-#: config/i386/i386.c:4285
-#, fuzzy, gcc-internal-format
-#| msgid "bad value (%s) for %stune=%s %s"
+#: config/i386/i386.c:4288
+#, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"tune=\")%> attribute"
-msgstr "некорректное значение (%s) для %stune=%s %s"
+msgstr "некорректное значение (%qs) для %<target(\"tune=\")%> атрибута"
 
-#: config/i386/i386.c:4305
-#, fuzzy, gcc-internal-format
-#| msgid "valid arguments to %qs are: %s"
+#: config/i386/i386.c:4308
+#, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
-msgstr "допустимые аргументы %qs: %s"
+msgstr "допустимые аргументы для %<-mtune=%> ключа: %s; имелось в виду %qs?"
 
-#: config/i386/i386.c:4307
+#: config/i386/i386.c:4310
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
-msgstr ""
+msgstr "допустимые аргументы для %<target(\"tune=\")%> атрибута: %s; вы имели в виду %qs?"
 
-#: config/i386/i386.c:4312
-#, fuzzy, gcc-internal-format
-#| msgid "valid arguments to %qs are: %s"
+#: config/i386/i386.c:4315
+#, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
-msgstr "допустимые аргументы %qs: %s"
+msgstr "допустимые аргументы для %<-mtune=%> ключа: %s"
 
-#: config/i386/i386.c:4313
-#, fuzzy, gcc-internal-format
-#| msgid "valid arguments to %qs are: %s"
+#: config/i386/i386.c:4316
+#, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
-msgstr "допустимые аргументы %qs: %s"
+msgstr "допустимые аргументы для %<target(\"tune=\")%> атрибута: %s"
 
-#: config/i386/i386.c:4379
+#: config/i386/i386.c:4382
 #, gcc-internal-format
 msgid "-mregparm is ignored in 64-bit mode"
 msgstr "-mregparm игнорируется в 64-битном режиме"
 
-#: config/i386/i386.c:4381
-#, fuzzy, gcc-internal-format
-#| msgid "-mregparm is ignored in 64-bit mode"
+#: config/i386/i386.c:4384
+#, gcc-internal-format
 msgid "-mregparm is ignored for Intel MCU psABI"
-msgstr "-mregparm игнорируется в 64-битном режиме"
+msgstr "-mregparm игнорируется для Intel MCU psABI"
 
-#: config/i386/i386.c:4384
+#: config/i386/i386.c:4387
 #, gcc-internal-format, gfc-internal-format
 msgid "-mregparm=%d is not between 0 and %d"
 msgstr "-mregparm=%d не между 0 и %d"
 
-#: config/i386/i386.c:4417
-#, fuzzy, gcc-internal-format
-#| msgid "%srtd%s is ignored in 64bit mode"
+#: config/i386/i386.c:4420
+#, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
-msgstr "%srtd%s игнорируется в 64-битном режиме"
+msgstr "%<-mrtd%> игнорируется в 64-битном режиме"
 
-#: config/i386/i386.c:4418
-#, fuzzy, gcc-internal-format
-#| msgid "%srtd%s is ignored in 64bit mode"
+#: config/i386/i386.c:4421
+#, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
-msgstr "%srtd%s игнорируется в 64-битном режиме"
+msgstr "%<target(\"rtd\")%> игнорируется в 64-битном режиме"
 
-#: config/i386/i386.c:4497
+#: config/i386/i386.c:4500
 #, gcc-internal-format
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "-mpreferred-stack-boundary не поддерживается для этой целевой платформы"
 
-#: config/i386/i386.c:4500
+#: config/i386/i386.c:4503
 #, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d не между %d и %d"
 
-#: config/i386/i386.c:4523
+#: config/i386/i386.c:4526
 #, gcc-internal-format, gfc-internal-format
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr "-mincoming-stack-boundary=%d не между %d и 12"
 
-#: config/i386/i386.c:4536
-#, fuzzy, gcc-internal-format
-#| msgid "-mno-fentry isn%'t compatible with SEH"
+#: config/i386/i386.c:4539
+#, gcc-internal-format
 msgid "-mnop-mcount is not compatible with this target"
-msgstr "-mno-fentry несовместимо с SEH"
+msgstr "-mnop-mcount несовместимо с этой целью"
 
-#: config/i386/i386.c:4539
-#, fuzzy, gcc-internal-format
-#| msgid "inter-module optimizations not implemented for C++"
+#: config/i386/i386.c:4542
+#, gcc-internal-format
 msgid "-mnop-mcount is not implemented for -fPIC"
-msgstr "межмодульные оптимизации не реализованы для C++"
+msgstr "-mnop-mcount не реализовано для -fPIC"
 
-#: config/i386/i386.c:4545
-#, fuzzy, gcc-internal-format
-#| msgid "%ssseregparm%s used without SSE enabled"
+#: config/i386/i386.c:4548
+#, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
-msgstr "%ssseregparm%s используется без SSE включения"
+msgstr "%<-msseregparm%> используется без SSE включения"
 
-#: config/i386/i386.c:4546
-#, fuzzy, gcc-internal-format
-#| msgid "%ssseregparm%s used without SSE enabled"
+#: config/i386/i386.c:4549
+#, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
-msgstr "%ssseregparm%s используется без SSE включения"
+msgstr "%<target(\"sseregparm\")%> используется без SSE включения"
 
-#: config/i386/i386.c:4556
+#: config/i386/i386.c:4559
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "набор команд SSE отменен, используется арифметика 387"
 
-#: config/i386/i386.c:4563
+#: config/i386/i386.c:4566
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "набор команд 387 отменен, используется арифметика SSE"
 
-#: config/i386/i386.c:4613
-#, fuzzy, gcc-internal-format
-#| msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
+#: config/i386/i386.c:4616
+#, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
-msgstr "опробование стека требует %saccumulate-outgoing-args%s для корректной работы"
+msgstr "опробование стека требует %<-maccumulate-outgoing-args%> для корректной работы"
 
-#: config/i386/i386.c:4615
-#, fuzzy, gcc-internal-format
-#| msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
+#: config/i386/i386.c:4618
+#, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
-msgstr "опробование стека требует %saccumulate-outgoing-args%s для корректной работы"
+msgstr "опробование стека требует %<target(\"accumulate-outgoing-args\")%> для корректной работы"
 
-#: config/i386/i386.c:4629
-#, fuzzy, gcc-internal-format
-#| msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
+#: config/i386/i386.c:4632
+#, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
-msgstr "опробование стека требует %saccumulate-outgoing-args%s для корректной работы"
+msgstr "фиксированный ebp регистр требует %<-maccumulate-outgoing-args%>"
 
-#: config/i386/i386.c:4631
-#, fuzzy, gcc-internal-format
-#| msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
+#: config/i386/i386.c:4634
+#, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
-msgstr "опробование стека требует %saccumulate-outgoing-args%s для корректной работы"
+msgstr "фиксированный ebp регистр требует %<target(\"accumulate-outgoing-args\")%>"
 
-#: config/i386/i386.c:4741
+#: config/i386/i386.c:4744
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr "-mfentry не поддерживается для 32 бит в комбинации с -fpic"
 
-#: config/i386/i386.c:4744
+#: config/i386/i386.c:4747
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr "-mno-fentry несовместимо с SEH"
 
-#: config/i386/i386.c:4748
+#: config/i386/i386.c:4751
 #, gcc-internal-format
 msgid "-mcall-ms2sysv-xlogues isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386.c:4813 config/powerpcspe/powerpcspe.c:5663
+#: config/i386/i386.c:4816 config/powerpcspe/powerpcspe.c:5663
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown option for -mrecip=%s"
 msgstr "неизвестная опция для -mrecip=%s"
 
-#: config/i386/i386.c:4870 config/powerpcspe/powerpcspe.c:5339
+#: config/i386/i386.c:4873 config/powerpcspe/powerpcspe.c:5339
 #, gcc-internal-format
 msgid "%qs is not a valid number in -mstack-protector-guard-offset="
-msgstr ""
+msgstr "%qs не есть допустимое число в -mstack-protector-guard-offset"
 
-#: config/i386/i386.c:4875 config/powerpcspe/powerpcspe.c:5344
-#, fuzzy, gcc-internal-format
-#| msgid "%qs is not a valid option to the preprocessor"
+#: config/i386/i386.c:4878 config/powerpcspe/powerpcspe.c:5344
+#, gcc-internal-format
 msgid "%qs is not a valid offset in -mstack-protector-guard-offset="
-msgstr "неверный ключ препроцессора %qs"
+msgstr "%qs не есть допустимое смещение в -mstack-protector-guard-offset="
 
-#: config/i386/i386.c:4907 config/powerpcspe/powerpcspe.c:5356
+#: config/i386/i386.c:4910 config/powerpcspe/powerpcspe.c:5356
 #, gcc-internal-format
 msgid "%qs is not a valid base register in -mstack-protector-guard-reg="
-msgstr ""
+msgstr "%qs не есть допустимый базовый регистр в -mstack-protector-guard-reg"
 
-#: config/i386/i386.c:5506 config/i386/i386.c:5553 config/s390/s390.c:15812
+#: config/i386/i386.c:5509 config/i386/i386.c:5556 config/s390/s390.c:15812
 #: config/s390/s390.c:15862 config/s390/s390.c:15879
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr "attribute(target(\"%s\")) неизвестен"
 
-#: config/i386/i386.c:5534
+#: config/i386/i386.c:5537
 #, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr "option(\"%s\") уже было задано"
 
-#: config/i386/i386.c:5837
-#, fuzzy, gcc-internal-format
-#| msgid "stdcall and cdecl attributes are not compatible"
+#: config/i386/i386.c:5840
+#, gcc-internal-format
 msgid "interrupt and naked attributes are not compatible"
-msgstr "атрибуты stdcall и cdecl несовместимы"
+msgstr ""
 
-#: config/i386/i386.c:5852
+#: config/i386/i386.c:5855
 #, gcc-internal-format
 msgid "Only DWARF debug format is supported for interrupt service routine."
-msgstr ""
+msgstr "Только отладочный формат DWARF поддерживается для программы обслуживания прерываний."
 
-#: config/i386/i386.c:5901
-#, fuzzy, gcc-internal-format
-#| msgid "-msdata=%s and -mcall-%s are incompatible"
+#: config/i386/i386.c:5904
+#, gcc-internal-format
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
-msgstr "ключи -msdata=%s и -mcall-%s несовместимы"
+msgstr ""
 
-#: config/i386/i386.c:5913
-#, fuzzy, gcc-internal-format
-#| msgid "-msdata=%s and -mcall-%s are incompatible"
+#: config/i386/i386.c:5916
+#, gcc-internal-format
 msgid "%<-mindirect-branch=thunk-extern%>, %<-fcf-protection=branch%> and %<-fcheck-pointer-bounds%> are not compatible"
-msgstr "ключи -msdata=%s и -mcall-%s несовместимы"
+msgstr ""
 
-#: config/i386/i386.c:5949
-#, fuzzy, gcc-internal-format
-#| msgid "-msdata=%s and -mcall-%s are incompatible"
+#: config/i386/i386.c:5952
+#, gcc-internal-format
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
-msgstr "ключи -msdata=%s и -mcall-%s несовместимы"
+msgstr ""
 
-#: config/i386/i386.c:6047
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "2 byte cop instructions are not allowed in 64-bit VLIW mode"
+#: config/i386/i386.c:6050
+#, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in %s service routine"
-msgstr "инструкции с 2-байтным кодом операции не допускаются в 64-битном VLIW режиме"
+msgstr "%s инструкции не допускаются в %s сервисной программе"
 
-#: config/i386/i386.c:6051
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Use a stack protection method for every function"
+#: config/i386/i386.c:6054
+#, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in function with no_caller_saved_registers attribute"
-msgstr "Использовать защиту стека для каждой функции"
+msgstr "%s инструкции не допускаются в функции с no_caller_saved_registers атрибутом"
 
-#: config/i386/i386.c:6465 config/i386/i386.c:6516
+#: config/i386/i386.c:6468 config/i386/i386.c:6519
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "атрибуты fastcall и regparm несовместимы"
 
-#: config/i386/i386.c:6470
+#: config/i386/i386.c:6473
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "атрибуты regparam и thiscall несовместимы"
 
-#: config/i386/i386.c:6477 config/i386/i386.c:41444
+#: config/i386/i386.c:6480 config/i386/i386.c:41438
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "%qE атрибут требует целый константный аргумент"
 
-#: config/i386/i386.c:6483
+#: config/i386/i386.c:6486
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "аргумент для %qE атрибута больше чем %d"
 
-#: config/i386/i386.c:6508 config/i386/i386.c:6551
+#: config/i386/i386.c:6511 config/i386/i386.c:6554
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "атрибуты fastcall и cdecl несовместимы"
 
-#: config/i386/i386.c:6512
+#: config/i386/i386.c:6515
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "атрибуты fastcall и stdcall несовместимы"
 
-#: config/i386/i386.c:6520 config/i386/i386.c:6569
+#: config/i386/i386.c:6523 config/i386/i386.c:6572
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "атрибуты fastcall и thiscall несовместимы"
 
-#: config/i386/i386.c:6530 config/i386/i386.c:6547
+#: config/i386/i386.c:6533 config/i386/i386.c:6550
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "атрибуты stdcall и cdecl несовместимы"
 
-#: config/i386/i386.c:6534
+#: config/i386/i386.c:6537
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "атрибуты stdcall и fastcall несовместимы"
 
-#: config/i386/i386.c:6538 config/i386/i386.c:6565
+#: config/i386/i386.c:6541 config/i386/i386.c:6568
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "атрибуты stdcall и thiscall несовместимы"
 
-#: config/i386/i386.c:6555 config/i386/i386.c:6573
+#: config/i386/i386.c:6558 config/i386/i386.c:6576
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "атрибуты cdecl и thiscall несовместимы"
 
-#: config/i386/i386.c:6561
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute is used for none class-method"
+#: config/i386/i386.c:6564
+#, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
-msgstr "атрибут %qE используется не для метода класса"
+msgstr "атрибут %qE используется для неклассового метода"
 
-#: config/i386/i386.c:6805
+#: config/i386/i386.c:6808
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "вызов %qD с атрибутом sseregparm без включения SSE/SSE2"
 
-#: config/i386/i386.c:6808
+#: config/i386/i386.c:6811
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "вызов %qT с атрибутом sseregparm без включения SSE/SSE2"
 
-#: config/i386/i386.c:7126
-#, fuzzy, gcc-internal-format
-#| msgid "does not support multilib"
+#: config/i386/i386.c:7129
+#, gcc-internal-format
 msgid "X32 does not support ms_abi attribute"
-msgstr "не поддерживает мультибиблиотеку"
+msgstr "X32 не поддерживает ms_abi атрибут"
 
-#: config/i386/i386.c:7160
+#: config/i386/i386.c:7163
 #, gcc-internal-format
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr "ms_hook_prologue несовместим с вложенной функцией"
 
-#: config/i386/i386.c:7502
-#, fuzzy, gcc-internal-format
-#| msgid "AVX vector argument without AVX enabled changes the ABI"
+#: config/i386/i386.c:7505
+#, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
-msgstr "векторный аргумент AVX без включения AVX изменяет ABI"
+msgstr "AVX512F векторный аргумент без включения AVX512F изменяет ABI"
 
-#: config/i386/i386.c:7508
-#, fuzzy, gcc-internal-format
-#| msgid "AVX vector argument without AVX enabled changes the ABI"
+#: config/i386/i386.c:7511
+#, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
-msgstr "векторный аргумент AVX без включения AVX изменяет ABI"
+msgstr "AVX512F векторный возврат без включения AVX512F изменяет ABI"
 
-#: config/i386/i386.c:7522
+#: config/i386/i386.c:7525
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr "векторный аргумент AVX без включения AVX изменяет ABI"
 
-#: config/i386/i386.c:7528
-#, fuzzy, gcc-internal-format
-#| msgid "AVX vector argument without AVX enabled changes the ABI"
+#: config/i386/i386.c:7531
+#, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
-msgstr "векторный аргумент AVX без включения AVX изменяет ABI"
+msgstr "AVX векторный возврат без включения AVX изменяет ABI"
 
-#: config/i386/i386.c:7544
+#: config/i386/i386.c:7547
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr "SSE векторный аргумент без включения SSE изменяет ABI"
 
-#: config/i386/i386.c:7550
+#: config/i386/i386.c:7553
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr "результат - вектор SSE без включения SSE изменяет ABI"
 
-#: config/i386/i386.c:7566
+#: config/i386/i386.c:7569
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr "аргумент - вектор MMX без включения MMX изменяет ABI"
 
-#: config/i386/i386.c:7572
+#: config/i386/i386.c:7575
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr "возврат вектора MMX без включения MMX изменяет ABI"
 
-#: config/i386/i386.c:7754
+#: config/i386/i386.c:7757
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr "ABI для передачи структуры с элементом flexible array изменен в GCC 4.4"
 
-#: config/i386/i386.c:7871
+#: config/i386/i386.c:7874
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr "ABI для передачи объединения с long double изменен в GCC 4.4"
 
-#: config/i386/i386.c:7989
+#: config/i386/i386.c:7992
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr "ABI для передачи структуры с элементом complex float изменен в GCC 4.4"
 
-#: config/i386/i386.c:8152
+#: config/i386/i386.c:8155
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr "SSE регистровый возврат с выключенным SSE"
 
-#: config/i386/i386.c:8158
+#: config/i386/i386.c:8161
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr "SSE регистровый аргумент с выключенным SSE"
 
-#: config/i386/i386.c:8174
+#: config/i386/i386.c:8177
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr "x87 регистровый возврат с выключенным x87"
 
-#: config/i386/i386.c:8471 config/i386/i386.c:8750 config/i386/i386.c:9276
-#, fuzzy, gcc-internal-format
-#| msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
+#: config/i386/i386.c:8474 config/i386/i386.c:8753 config/i386/i386.c:9279
+#, gcc-internal-format
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
-msgstr "вызов %qD с атрибутом sseregparm без включения SSE/SSE2"
+msgstr "вызов %qD с SSE соглашением о вызовах без включения SSE/SSE2"
 
-#: config/i386/i386.c:8473 config/i386/i386.c:8752 config/i386/i386.c:9278
+#: config/i386/i386.c:8476 config/i386/i386.c:8755 config/i386/i386.c:9281
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
-msgstr ""
+msgstr "это ошибка GCC, которую можно обойти добавлением атрибута used для вызываемой функции"
 
-#: config/i386/i386.c:9178
+#: config/i386/i386.c:9181
 #, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr "ABI для передачи параметров с %d-байтным выравниванием изменен в GCC 4.6"
 
-#: config/i386/i386.c:11601
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "assert: %s is assign compatible with %s"
+#: config/i386/i386.c:11604
+#, gcc-internal-format, gfc-internal-format
 msgid "-mcall-ms2sysv-xlogues is not compatible with %s"
-msgstr "assert: %s совместима по присваиванию с %s"
+msgstr ""
 
-#: config/i386/i386.c:13593
+#: config/i386/i386.c:13596
 #, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr "атрибут ms_hook_prologue несовместим с -mfentry для 32 бит"
 
-#: config/i386/i386.c:13683
+#: config/i386/i386.c:13686
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr ""
 
-#: config/i386/i386.c:14970
+#: config/i386/i386.c:14973
 #, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr "-fsplit-stack не поддерживает fastcall с вложенной функцией"
 
-#: config/i386/i386.c:14990
-#, fuzzy, gcc-internal-format
-#| msgid "-fsplit-stack does not support 2 register  parameters for a nested function"
+#: config/i386/i386.c:14993
+#, gcc-internal-format
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
 msgstr "-fsplit-stack не поддерживает 2-регистровые параметры для вложенной функции"
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:15001
+#: config/i386/i386.c:15004
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr "-fsplit-stack не поддерживает 3-регистровые параметры"
 
-#: config/i386/i386.c:17939
+#: config/i386/i386.c:17942
 #, gcc-internal-format
 msgid "'V' modifier on non-integer register"
 msgstr ""
 
-#: config/i386/i386.c:17950 config/i386/i386.c:17964
-#, fuzzy, gcc-internal-format
-#| msgid "unsupported operand size for extended register"
+#: config/i386/i386.c:17953 config/i386/i386.c:17967
+#, gcc-internal-format
 msgid "unsupported size for integer register"
-msgstr "некорректный размер операнда для расширенного регистра"
+msgstr "неподдерживаемый размер для целочисленного регистра"
 
-#: config/i386/i386.c:17996
+#: config/i386/i386.c:17999
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr "расширенные регистры не имеют верхних половин"
 
-#: config/i386/i386.c:18011
+#: config/i386/i386.c:18014
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr "некорректный размер операнда для расширенного регистра"
 
-#: config/i386/i386.c:18202
-#, fuzzy, gcc-internal-format
-#| msgid "non-integer operand used with operand code '%c'"
+#: config/i386/i386.c:18205
+#, gcc-internal-format
 msgid "non-integer operand used with operand code 'z'"
-msgstr "нецелый операнд использован с кодом операнда '%c'"
+msgstr "нецелый операнд использован с кодом операнда 'z'"
 
-#: config/i386/i386.c:28467
-#, fuzzy, gcc-internal-format
-#| msgid "interrupt Service Routines cannot be coded in Thumb mode"
+#: config/i386/i386.c:28470
+#, gcc-internal-format
 msgid "interrupt service routine can't be called directly"
-msgstr "подпрограммы Service Routines для прерываний не могут использоваться в режиме Thumb"
+msgstr "программа обслуживания прерываний не может вызываться напрямую"
 
-#: config/i386/i386.c:29995
+#: config/i386/i386.c:29998
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in -fabi-version=12 (GCC 8)"
 msgstr ""
 
-#: config/i386/i386.c:32435
+#: config/i386/i386.c:32438
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
-msgstr ""
+msgstr "диспетчер не найден для версионных атрибутов"
 
-#: config/i386/i386.c:32485
+#: config/i386/i386.c:32488
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for %s"
-msgstr ""
+msgstr "диспетчер не найден для %s"
 
-#: config/i386/i386.c:32495
+#: config/i386/i386.c:32498
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
-msgstr ""
+msgstr "диспетчер не найден для версионных атрибутов : %s"
 
-#: config/i386/i386.c:32657
+#: config/i386/i386.c:32660
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
-msgstr ""
+msgstr "Версии функции не могут быть помечены как gnu_inline, должны генерироваться тела"
 
 #
-#: config/i386/i386.c:32662 config/i386/i386.c:32938
-#: config/rs6000/rs6000.c:37850
-#, fuzzy, gcc-internal-format
-#| msgid "static linking is not supported"
+#: config/i386/i386.c:32665 config/i386/i386.c:32941
+#: config/rs6000/rs6000.c:37906
+#, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
-msgstr "статическая компоновка не поддерживается"
+msgstr "мультиверсионность виртуальной функции не поддерживается"
 
-#: config/i386/i386.c:32795 config/rs6000/rs6000.c:37607
-#, fuzzy, gcc-internal-format
-#| msgid "nested functions not supported on this target"
+#: config/i386/i386.c:32798 config/rs6000/rs6000.c:37663
+#, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
-msgstr "вложенные функции не поддерживаются для этой платформы"
+msgstr "мультиверсионность требует ifunc, что не поддерживается на этой платформе"
 
-#: config/i386/i386.c:33207
-#, fuzzy, gcc-internal-format
-#| msgid "argument to %qs must be a 2-bit unsigned literal"
+#: config/i386/i386.c:33210
+#, gcc-internal-format
 msgid "Parameter to builtin must be a string constant or literal"
-msgstr "аргумент %qs должен быть 2-битным беззнаковым литералом"
+msgstr "Параметр для внутренней функции должен быть строковой константой или литералом"
 
-#: config/i386/i386.c:33232 config/i386/i386.c:33282
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Argument to -ffpe-trap is not valid: %s"
+#: config/i386/i386.c:33235 config/i386/i386.c:33285
+#, gcc-internal-format, gfc-internal-format
 msgid "Parameter to builtin not valid: %s"
-msgstr "Аргумент для -ffpe-trap некорректен: %s"
+msgstr "Параметр для внутренней функции некорректен: %s"
 
-#: config/i386/i386.c:33975 config/i386/i386.c:35415
+#: config/i386/i386.c:33978 config/i386/i386.c:35418
 #, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "последний аргумент должен быть 2-битным непосредственным"
 
-#: config/i386/i386.c:34370
+#: config/i386/i386.c:34373
 #, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "пятый аргумент должен быть 8-битным непосредственным"
 
-#: config/i386/i386.c:34465
+#: config/i386/i386.c:34468
 #, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "третий аргумент должен быть 8-битным непосредственным"
 
-#: config/i386/i386.c:35346
+#: config/i386/i386.c:35349
 #, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "последний аргумент должен быть 1-битным непосредственным"
 
-#: config/i386/i386.c:35361
-#, fuzzy, gcc-internal-format
-#| msgid "the last argument must be a 32-bit immediate"
+#: config/i386/i386.c:35364
+#, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
-msgstr "последний аргумент должен быть 32-битным непосредственным"
+msgstr "последний аргумент должен быть 3-битным непосредственным"
 
-#: config/i386/i386.c:35394
+#: config/i386/i386.c:35397
 #, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "последний аргумент должен быть 4-битным непосредственным"
 
-#: config/i386/i386.c:35434
+#: config/i386/i386.c:35437
 #, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "последний аргумент должен быть 1-битным непосредственным"
 
-#: config/i386/i386.c:35447
+#: config/i386/i386.c:35450
 #, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "последний аргумент должен быть 5-битным непосредственным"
 
-#: config/i386/i386.c:35457
+#: config/i386/i386.c:35460
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "следующий за последним аргумент должен быть 8-битным непосредственным"
 
-#: config/i386/i386.c:35462 config/i386/i386.c:36249
+#: config/i386/i386.c:35465 config/i386/i386.c:36252
 #, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "последний аргумент должен быть 8-битным непосредственным"
 
-#: config/i386/i386.c:35596
-#, fuzzy, gcc-internal-format
-#| msgid "argument must be a constant"
+#: config/i386/i386.c:35599
+#, gcc-internal-format
 msgid "the third argument must be comparison constant"
-msgstr "аргумент должен быть константой"
+msgstr "третий аргумент должен быть константой сравнения"
 
-#: config/i386/i386.c:35601
-#, fuzzy, gcc-internal-format
-#| msgid "incorrect insn:"
+#: config/i386/i386.c:35604
+#, gcc-internal-format
 msgid "incorrect comparison mode"
-msgstr "некорректная инструкция:"
+msgstr "некорректный режим сравнения"
 
-#: config/i386/i386.c:35607 config/i386/i386.c:35814
-#, fuzzy, gcc-internal-format
-#| msgid "incorrect sharing of tree nodes"
+#: config/i386/i386.c:35610 config/i386/i386.c:35817
+#, gcc-internal-format
 msgid "incorrect rounding operand"
-msgstr "недопустимое разделение узлов дерева"
+msgstr "некорректный операнд округления"
 
-#: config/i386/i386.c:35796
-#, fuzzy, gcc-internal-format
-#| msgid "the last argument must be a 4-bit immediate"
+#: config/i386/i386.c:35799
+#, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
-msgstr "последний аргумент должен быть 4-битным непосредственным"
+msgstr "непосредственный аргумент должен быть 4-битным непосредственным"
 
-#: config/i386/i386.c:35802
-#, fuzzy, gcc-internal-format
-#| msgid "the last argument must be a 5-bit immediate"
+#: config/i386/i386.c:35805
+#, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
-msgstr "последний аргумент должен быть 5-битным непосредственным"
+msgstr "непосредственный аргумент должен быть 5-битным непосредственным"
 
-#: config/i386/i386.c:35805
-#, fuzzy, gcc-internal-format
-#| msgid "the last argument must be an 8-bit immediate"
+#: config/i386/i386.c:35808
+#, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
-msgstr "последний аргумент должен быть 8-битным непосредственным"
+msgstr "непосредственный аргумент должен быть 8-битным непосредственным"
 
-#: config/i386/i386.c:36247
+#: config/i386/i386.c:36250
 #, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "последний аргумент должен быть 32-битным непосредственным"
 
-#: config/i386/i386.c:36329 config/powerpcspe/powerpcspe.c:16219
-#: config/rs6000/rs6000.c:15304
+#: config/i386/i386.c:36332 config/powerpcspe/powerpcspe.c:16219
+#: config/rs6000/rs6000.c:15348
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr "селектор должен быть целой константой в диапазоне 0..%wi"
 
-#: config/i386/i386.c:36539
+#: config/i386/i386.c:36542
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr "%qE требует неизвестную isa опцию"
 
-#: config/i386/i386.c:36543
+#: config/i386/i386.c:36546
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "%qE требует isa опцию %s"
 
-#: config/i386/i386.c:37381
+#: config/i386/i386.c:37375
 #, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "последний аргумент должен быть непосредственным"
 
-#: config/i386/i386.c:38108 config/i386/i386.c:38290
-#, fuzzy, gcc-internal-format
-#| msgid "last argument must be scale 1, 2, 4, 8"
+#: config/i386/i386.c:38102 config/i386/i386.c:38284
+#, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
-msgstr "последний аргумент должен быть степенью 1, 2, 4, 8"
+msgstr "последний аргумент должен быть масштабом 1, 2, 4, 8"
 
-#: config/i386/i386.c:38343
-#, fuzzy, gcc-internal-format
-#| msgid "last argument must be scale 1, 2, 4, 8"
+#: config/i386/i386.c:38337
+#, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
-msgstr "последний аргумент должен быть степенью 1, 2, 4, 8"
+msgstr "четвертый аргумент должен быть масштабом 1, 2, 4, 8"
 
-#: config/i386/i386.c:38349
-#, fuzzy, gcc-internal-format
-#| msgid "incorrect insn:"
+#: config/i386/i386.c:38343
+#, gcc-internal-format
 msgid "incorrect hint operand"
-msgstr "некорректная инструкция:"
+msgstr "некорректный операнд подсказки"
 
-#: config/i386/i386.c:38368
-#, fuzzy, gcc-internal-format
-#| msgid "the last argument must be an 8-bit immediate"
+#: config/i386/i386.c:38362
+#, gcc-internal-format
 msgid "the xabort's argument must be an 8-bit immediate"
-msgstr "последний аргумент должен быть 8-битным непосредственным"
+msgstr "аргумент xabort должен быть 8-битным непосредственным"
 
-#: config/i386/i386.c:41431
+#: config/i386/i386.c:41425
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "атрибут %qE допустим только для 32 бит"
 
-#: config/i386/i386.c:41452
+#: config/i386/i386.c:41446
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "аргумент атрибута %qE не ноль и не один"
 
-#: config/i386/i386.c:41485 config/i386/i386.c:41494
+#: config/i386/i386.c:41479 config/i386/i386.c:41488
 #, gcc-internal-format
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr "атрибуты ms_abi и sysv_abi несовместимы"
 
-#: config/i386/i386.c:41530 config/powerpcspe/powerpcspe.c:35868
-#: config/rs6000/rs6000.c:33065
+#: config/i386/i386.c:41524 config/powerpcspe/powerpcspe.c:35868
+#: config/rs6000/rs6000.c:33121
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "несовместимый атрибут %qE игнорируется"
 
-#: config/i386/i386.c:41555 config/i386/i386.c:41577 config/ia64/ia64.c:815
+#: config/i386/i386.c:41549 config/i386/i386.c:41571 config/ia64/ia64.c:815
 #: config/s390/s390.c:1153
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
@@ -34470,126 +29754,111 @@
 msgstr "аргументом атрибута %qE должна быть строковая константа"
 
 #
-#: config/i386/i386.c:41565 config/i386/i386.c:41587 config/s390/s390.c:1182
-#, fuzzy, gcc-internal-format
-#| msgid "argument of %qE attribute is not \"ilink1\" or \"ilink2\""
+#: config/i386/i386.c:41559 config/i386/i386.c:41581 config/s390/s390.c:1182
+#, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
-msgstr "аргумент атрибута %qE не есть \"ilink1\" или \"ilink2\""
+msgstr ""
 
-#: config/i386/i386.c:41619
+#: config/i386/i386.c:41613
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
-msgstr ""
+msgstr "программа обслуживания прерываний должна иметь указатель первым аргументом"
 
-#: config/i386/i386.c:41626
+#: config/i386/i386.c:41620
 #, gcc-internal-format, gfc-internal-format
 msgid "interrupt service routine should have unsigned %sint as the second argument"
-msgstr ""
+msgstr "программа обслуживания прерываний должна иметь беззнаковый %sint вторым аргументом"
 
-#: config/i386/i386.c:41636
+#: config/i386/i386.c:41630
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
-msgstr ""
+msgstr "программа обслуживания прерываний может иметь только указательный аргумент и необязательный целочисленный аргумент"
 
-#: config/i386/i386.c:41639
-#, fuzzy, gcc-internal-format
-#| msgid "interrupt Service Routines cannot be coded in Thumb mode"
+#: config/i386/i386.c:41633
+#, gcc-internal-format
 msgid "interrupt service routine can't have non-void return value"
-msgstr "подпрограммы Service Routines для прерываний не могут использоваться в режиме Thumb"
+msgstr "программа обслуживания прерываний не может иметь не-void возвращаемое значение"
 
-#: config/i386/i386.c:44676
-#, fuzzy, gcc-internal-format
-#| msgid "By-value argument at %L is not allowed in this context"
+#: config/i386/i386.c:44670
+#, gcc-internal-format
 msgid "alternatives not allowed in asm flag output"
-msgstr "Аргумент по значению в %L не допускается в этом контексте"
+msgstr "альтернативы не допускается в выводе ассемблерного флага"
 
-#: config/i386/i386.c:44740
-#, fuzzy, gcc-internal-format
-#| msgid "unknown IRA algorithm %qs"
+#: config/i386/i386.c:44734
+#, gcc-internal-format
 msgid "unknown asm flag output %qs"
-msgstr "неизвестный алгоритм раскраски %qs"
+msgstr "неизвестный вывод ассемблерного флага %qs"
 
-#: config/i386/i386.c:44769
-#, fuzzy, gcc-internal-format
-#| msgid "invalid type for make function"
+#: config/i386/i386.c:44763
+#, gcc-internal-format
 msgid "invalid type for asm flag output"
-msgstr "некорректный тип для make функции"
+msgstr "некорректный тип для вывода ассемблерного флага"
 
-#: config/i386/i386.c:50634
-#, fuzzy, gcc-internal-format
-#| msgid "Unknown architecture '%s'"
+#: config/i386/i386.c:50628
+#, gcc-internal-format
 msgid "unknown architecture specific memory model"
-msgstr "неизвестная архитектура '%s'"
+msgstr ""
 
-#: config/i386/i386.c:50641
+#: config/i386/i386.c:50635
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
-msgstr ""
+msgstr "HLE_ACQUIRE не использовано с ACQUIRE или более сильной моделью памяти"
 
-#: config/i386/i386.c:50647
+#: config/i386/i386.c:50641
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
-msgstr ""
+msgstr "HLE_RELEASE не использовано с RELEASE или более сильной моделью памяти"
 
-#: config/i386/i386.c:50671 config/i386/i386.c:50787
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "unsupported combination: %s"
+#: config/i386/i386.c:50665 config/i386/i386.c:50781
+#, gcc-internal-format, gfc-internal-format
 msgid "unsupported simdlen %d"
-msgstr "неподдерживаемая комбинация: %s"
+msgstr "неподдерживаемая simdlen %d"
 
-#: config/i386/i386.c:50690
-#, fuzzy, gcc-internal-format
-#| msgid "unsupported argument type to builtin function"
+#: config/i386/i386.c:50684
+#, gcc-internal-format
 msgid "unsupported return type %qT for simd"
-msgstr "неподдерживаемый тип аргумента для внутренней функции"
+msgstr ""
 
-#: config/i386/i386.c:50712
-#, fuzzy, gcc-internal-format
-#| msgid "unsupported argument type to builtin function"
+#: config/i386/i386.c:50706
+#, gcc-internal-format
 msgid "unsupported argument type %qT for simd"
-msgstr "неподдерживаемый тип аргумента для внутренней функции"
+msgstr ""
 
-#: config/i386/i386.c:51033
+#: config/i386/i386.c:51027
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr ""
 
 #: config/i386/intelmic-mkoffload.c:73 config/nvptx/mkoffload.c:87
-#, fuzzy, gcc-internal-format
-#| msgid "deleting LTRANS file %s"
+#, gcc-internal-format
 msgid "deleting file %s: %m"
-msgstr "удаляется файл LTRANS %s"
+msgstr "удаляется файл %s: %m"
 
 #: config/i386/intelmic-mkoffload.c:255 config/i386/intelmic-mkoffload.c:319
 #: config/i386/intelmic-mkoffload.c:360 config/nvptx/mkoffload.c:526
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "cannot open %s"
+#, gcc-internal-format, gfc-internal-format
 msgid "cannot open '%s'"
-msgstr "ошибка открытия %s"
+msgstr "ошибка открытия '%s'"
 
 #: config/i386/intelmic-mkoffload.c:467
-#, fuzzy, gcc-internal-format
-#| msgid "no input file specified"
+#, gcc-internal-format
 msgid "output file not specified"
-msgstr "не задано ни одного входного файла"
+msgstr "выходной файл не задан"
 
 #: config/i386/intelmic-mkoffload.c:560
-#, fuzzy, gcc-internal-format
-#| msgid "COLLECT_LTO_WRAPPER must be set"
+#, gcc-internal-format
 msgid "COLLECT_GCC must be set"
-msgstr "должна быть установлена COLLECT_LTO_WRAPPER"
+msgstr "COLLECT_GCC должен быть установлен"
 
 #: config/i386/intelmic-mkoffload.c:565 config/nvptx/mkoffload.c:457
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "field %qs not found"
+#, gcc-internal-format, gfc-internal-format
 msgid "offload compiler %s not found"
-msgstr "нет поля %qs"
+msgstr "компилятор разгрузки %s не найден"
 
 #: config/i386/intelmic-mkoffload.c:584 config/nvptx/mkoffload.c:477
-#, fuzzy, gcc-internal-format
-#| msgid "unrecognized argument in option %qs"
+#, gcc-internal-format
 msgid "unrecognizable argument of option "
-msgstr "некорректный аргумент ключа %qs"
+msgstr ""
 
 #: config/i386/winnt.c:83
 #, gcc-internal-format
@@ -34761,10 +30030,9 @@
 msgstr "-falign-loops=%d не поддерживается"
 
 #: config/m68k/m68k.c:669
-#, fuzzy, gcc-internal-format
-#| msgid "stack limits not supported on this target"
+#, gcc-internal-format
 msgid "-fstack-limit- options are not supported on this cpu"
-msgstr "проверка выхода за границу стека не поддерживается для этой платформы"
+msgstr "-fstack-limit- опции не поддерживаются на этом процессоре"
 
 #: config/m68k/m68k.c:787
 #, gcc-internal-format
@@ -34777,7 +30045,7 @@
 msgstr "interrupt_thread доступен только на fido"
 
 #: config/m68k/m68k.c:1128 config/powerpcspe/powerpcspe.c:28512
-#: config/rs6000/rs6000.c:25791
+#: config/rs6000/rs6000.c:25868
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "выражение для границы стека не поддерживается"
@@ -34788,10 +30056,9 @@
 msgstr "инициализированная переменная %q+D помечена как dllimport"
 
 #: config/microblaze/microblaze.c:1689
-#, fuzzy, gcc-internal-format
-#| msgid "-fstack-protector not supported for this target"
+#, gcc-internal-format
 msgid "-fPIC/-fpic not supported for this target"
-msgstr "-fstack-protector не поддерживается для этой целевой платформы"
+msgstr "-fPIC/-fpic не поддерживается для этой целевой платформы"
 
 #: config/microblaze/microblaze.c:1701
 #, gcc-internal-format
@@ -34804,15 +30071,14 @@
 msgstr "-mxl-multiply-high может использоваться только с -mcpu=v6.00.a или выше"
 
 #: config/microblaze/microblaze.c:1766
-#, fuzzy, gcc-internal-format
-#| msgid "-mxl-multiply-high can be used only with -mcpu=v6.00.a or greater"
+#, gcc-internal-format
 msgid "-mxl-reorder can be used only with -mcpu=v8.30.a or greater"
-msgstr "-mxl-multiply-high может использоваться только с -mcpu=v6.00.a или выше"
+msgstr "-mxl-reorder может использоваться только с -mcpu=v8.30.a или выше"
 
 #: config/microblaze/microblaze.c:1772
 #, gcc-internal-format
 msgid "-mxl-reorder requires -mxl-pattern-compare for -mcpu=v8.30.a"
-msgstr ""
+msgstr "-mxl-reorder требует -mxl-pattern-compare для -mcpu=v8.30.a"
 
 #: config/microblaze/microblaze.c:1777
 #, gcc-internal-format
@@ -34825,10 +30091,9 @@
 msgstr "атрибут %qs допустим только для функций"
 
 #: config/mips/mips.c:1409 config/mips/mips.c:1415
-#, fuzzy, gcc-internal-format
-#| msgid "%qE cannot have both %<mips16%> and %<nomips16%> attributes"
+#, gcc-internal-format
 msgid "%qE cannot have both %qs and %qs attributes"
-msgstr "%qE не может иметь оба атрибута: %<mips16%> и %<nomips16%>"
+msgstr "%qE не может иметь оба атрибута: %qs и %qs"
 
 #: config/mips/mips.c:1444 config/mips/mips.c:1450 config/nios2/nios2.c:4444
 #, gcc-internal-format
@@ -34836,27 +30101,24 @@
 msgstr "повторная декларация %qE с конфликтующими атрибутами %qs"
 
 #: config/mips/mips.c:1482 config/mips/mips.c:1536
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute requires a string constant argument"
+#, gcc-internal-format
 msgid "%qE attribute requires a string argument"
-msgstr "аргументом атрибута %qE должна быть строковая константа"
+msgstr "%qE атрибут требует строковый аргумент"
 
 #: config/mips/mips.c:1490
-#, fuzzy, gcc-internal-format
-#| msgid "argument to %qE attribute is neither zero, nor one"
+#, gcc-internal-format
 msgid "argument to %qE attribute is neither eic, nor vector=<line>"
-msgstr "аргумент атрибута %qE не ноль и не один"
+msgstr "аргумент атрибута %qE не eic и не vector=<line>"
 
 #: config/mips/mips.c:1506
 #, gcc-internal-format
 msgid "interrupt vector to %qE attribute is not vector=(sw0|sw1|hw0|hw1|hw2|hw3|hw4|hw5)"
-msgstr ""
+msgstr "вектор прерывания для %qE атрибута не есть vector=(sw0|sw1|hw0|hw1|hw2|hw3|hw4|hw5)"
 
 #: config/mips/mips.c:1543
-#, fuzzy, gcc-internal-format
-#| msgid "argument of %qE attribute is not a string constant"
+#, gcc-internal-format
 msgid "argument to %qE attribute is not intstack"
-msgstr "аргумент %qE атрибута не строковая константа"
+msgstr "аргумент %qE атрибута не есть intstack"
 
 #: config/mips/mips.c:7697
 #, gcc-internal-format
@@ -34864,10 +30126,9 @@
 msgstr "ошибка при обработке некорректных вызовов %qs"
 
 #: config/mips/mips.c:10933
-#, fuzzy, gcc-internal-format
-#| msgid "the %<interrupt%> attribute requires a MIPS32r2 processor"
+#, gcc-internal-format
 msgid "the %<interrupt%> attribute requires a MIPS32r2 processor or greater"
-msgstr "атрибут %<interrupt%> допустим только для процессора MIPS32r2"
+msgstr "атрибут %<interrupt%> требует процессор MIPS32r2 или выше"
 
 #: config/mips/mips.c:10935
 #, gcc-internal-format
@@ -34877,13 +30138,12 @@
 #: config/mips/mips.c:11925
 #, gcc-internal-format
 msgid "-fstack-check=specific not implemented for MIPS16"
-msgstr ""
+msgstr "-fstack-check=specific не реализовано для MIPS16"
 
 #: config/mips/mips.c:16882
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "argument must be a constant"
+#, gcc-internal-format, gfc-internal-format
 msgid "argument %d to the built-in must be a constant in range %d to %d"
-msgstr "аргумент должен быть константой"
+msgstr "аргумент %d для внутренней функции должен быть константой в диапазоне от %d до %d"
 
 #: config/mips/mips.c:16888 config/nios2/nios2.c:3596
 #: config/riscv/riscv-builtins.c:219
@@ -34892,10 +30152,9 @@
 msgstr "некорректный аргумент встроенной функции"
 
 #: config/mips/mips.c:17002
-#, fuzzy, gcc-internal-format
-#| msgid "failed to reclaim unneeded function"
+#, gcc-internal-format
 msgid "failed to expand built-in function"
-msgstr "ошибка при возврате ненужной функции"
+msgstr "ошибка при расширении внутренней функции"
 
 #: config/mips/mips.c:17133
 #, gcc-internal-format
@@ -34923,10 +30182,9 @@
 msgstr "аппаратная реализация плавающей арифметики для MIPS16 и ABI, отличного от o32 и o64"
 
 #: config/mips/mips.c:19487
-#, fuzzy, gcc-internal-format
-#| msgid "Generate MIPS16 code"
+#, gcc-internal-format
 msgid "MSA MIPS16 code"
-msgstr "Генерировать код MIPS16"
+msgstr "MSA MIPS16 код"
 
 #: config/mips/mips.c:19662 config/mips/mips.c:19667 config/mips/mips.c:19749
 #: config/mips/mips.c:19751 config/mips/mips.c:19781 config/mips/mips.c:19791
@@ -34961,15 +30219,14 @@
 msgstr "ключ %<-mgp64%> задан для 32-битного ABI"
 
 #: config/mips/mips.c:19746
-#, fuzzy, gcc-internal-format
-#| msgid "the %qs architecture does not support the synci instruction"
+#, gcc-internal-format
 msgid "the %qs architecture does not support %<-mfp32%>"
-msgstr "архитектура %qs не поддерживает команду synci"
+msgstr "архитектура %qs не поддерживает %<-mfp32%>"
 
 #: config/mips/mips.c:19755
 #, gcc-internal-format
 msgid "%<-mgp32%> and %<-mfp64%> can only be combined if the target supports the mfhc1 and mthc1 instructions"
-msgstr "%<-mgp32%> и %<-mfp64%> могут сочетаться только если процессор поддерживает команды mfhc1 и mthc1"
+msgstr "%<-mgp32%> и %<-mfp64%> могут сочетаться, только если процессор поддерживает команды mfhc1 и mthc1"
 
 #: config/mips/mips.c:19758
 #, gcc-internal-format
@@ -34977,22 +30234,19 @@
 msgstr "%<-mgp32%> и %<-mfp64%> могут сочетаться только при использовании ABI o32"
 
 #: config/mips/mips.c:19779
-#, fuzzy, gcc-internal-format
-#| msgid "%<-mgp32%> and %<-mfp64%> can only be combined when using the o32 ABI"
+#, gcc-internal-format
 msgid "%<-mfpxx%> can only be used with the o32 ABI"
-msgstr "%<-mgp32%> и %<-mfp64%> могут сочетаться только при использовании ABI o32"
+msgstr "%<-mfpxx%> использоваться только с o32 ABI"
 
 #: config/mips/mips.c:19783
-#, fuzzy, gcc-internal-format
-#| msgid "%<-mips3d%> requires %<-mpaired-single%>"
+#, gcc-internal-format
 msgid "%<-march=%s%> requires %<-mfp32%>"
-msgstr "для %<-mips3d%> требуется %<-mpaired-single%>"
+msgstr "%<-march=%s%> требует %<-mfp32%>"
 
 #: config/mips/mips.c:19785
-#, fuzzy, gcc-internal-format
-#| msgid "%<-mips3d%> requires %<-mpaired-single%>"
+#, gcc-internal-format
 msgid "%<-mfpxx%> requires %<-mlra%>"
-msgstr "для %<-mips3d%> требуется %<-mpaired-single%>"
+msgstr "%<-mfpxx%> требует %<-mlra%>"
 
 #: config/mips/mips.c:19801 config/mips/mips.c:19803 config/mips/mips.c:19816
 #, gcc-internal-format
@@ -35015,40 +30269,34 @@
 msgstr "архитектура %qs не поддерживает команды branch-likely"
 
 #: config/mips/mips.c:19878
-#, fuzzy, gcc-internal-format
-#| msgid "the %qs architecture does not support the synci instruction"
+#, gcc-internal-format
 msgid "the %qs architecture does not support madd or msub instructions"
-msgstr "архитектура %qs не поддерживает команду synci"
+msgstr "архитектура %qs не поддерживает инструкции madd или msub"
 
 #: config/mips/mips.c:19892
-#, fuzzy, gcc-internal-format
-#| msgid "the %qs architecture does not support paired-single instructions"
+#, gcc-internal-format
 msgid "the %qs architecture does not support odd single-precision registers"
-msgstr "архитектура %qs не поддерживает команды формата PS"
+msgstr "архитектура %qs не поддерживает нечетные регистры одинарной точности"
 
 #: config/mips/mips.c:19905 config/mips/mips.c:19911
-#, fuzzy, gcc-internal-format
-#| msgid "unsupported combination: %s"
+#, gcc-internal-format
 msgid "unsupported combination: %qs%s %s"
-msgstr "неподдерживаемая комбинация: %s"
+msgstr "неподдерживаемая комбинация: %qs%s %s"
 
 #: config/mips/mips.c:19920
-#, fuzzy, gcc-internal-format
-#| msgid "unsupported combination: %s"
+#, gcc-internal-format
 msgid "unsupported combination: %qs %s"
-msgstr "неподдерживаемая комбинация: %s"
+msgstr "неподдерживаемая комбинация: %qs %s"
 
 #: config/mips/mips.c:19935
-#, fuzzy, gcc-internal-format
-#| msgid "Generate position-independent code if possible (large mode)"
+#, gcc-internal-format
 msgid "cannot generate position-independent code for %qs"
-msgstr "Генерировать позиционно-независимый код, если возможно (режим large)"
+msgstr "невозможно генерировать позиционно-независимый код для %qs"
 
 #: config/mips/mips.c:19938
-#, fuzzy, gcc-internal-format
-#| msgid "Disable position-independent code (PIC) for use in OS kernel code"
+#, gcc-internal-format
 msgid "position-independent code requires %qs"
-msgstr "Выключить позиционно-независимый код (PIC) для использования в коде ядра OS"
+msgstr "позиционно-независимый код требует %qs"
 
 #: config/mips/mips.c:19971
 #, gcc-internal-format
@@ -35061,16 +30309,14 @@
 msgstr "невозможно использовать метод доступа к малым объектам данных для %qs"
 
 #: config/mips/mips.c:19997
-#, fuzzy, gcc-internal-format
-#| msgid "the %qs architecture does not support paired-single instructions"
+#, gcc-internal-format
 msgid "the %qs architecture does not support %<-m%s=legacy%>"
-msgstr "архитектура %qs не поддерживает команды формата PS"
+msgstr "архитектура %qs не поддерживает %<-m%s=legacy%>"
 
 #: config/mips/mips.c:20004
-#, fuzzy, gcc-internal-format
-#| msgid "the %qs architecture does not support the synci instruction"
+#, gcc-internal-format
 msgid "the %qs architecture does not support %<-m%s=2008%>"
-msgstr "архитектура %qs не поддерживает команду synci"
+msgstr "архитектура %qs не поддерживает %<-m%s=2008%>"
 
 #: config/mips/mips.c:20022
 #, gcc-internal-format
@@ -35085,7 +30331,7 @@
 #: config/mips/mips.c:20042
 #, gcc-internal-format
 msgid "%<-mmsa%> must be used with %<-mfp64%> and %<-mhard-float%>"
-msgstr ""
+msgstr "%<-mmsa%> должно использоваться с %<-mfp64%> и %<-mhard-float%>"
 
 #: config/mips/mips.c:20049
 #, gcc-internal-format
@@ -35098,10 +30344,9 @@
 msgstr "%qs поддерживается только для процессоров, имеющих команду %qs"
 
 #: config/mips/mips.c:20069
-#, fuzzy, gcc-internal-format
-#| msgid "the %qs architecture does not support the synci instruction"
+#, gcc-internal-format
 msgid "the %qs architecture does not support DSP instructions"
-msgstr "архитектура %qs не поддерживает команду synci"
+msgstr "архитектура %qs не поддерживает DSP инструкции"
 
 #: config/mips/mips.c:20171
 #, gcc-internal-format
@@ -35177,47 +30422,47 @@
 #: config/msp430/driver-msp430.c:661
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected argument to msp430_select_hwmult_lib: %s"
-msgstr ""
+msgstr "неожиданный аргумент для msp430_select_hwmult_lib: %s"
 
 #: config/msp430/driver-msp430.c:702
 #, gcc-internal-format, gfc-internal-format
 msgid "unrecognized hwpy field in msp430_mcu_data[%d]: %d"
-msgstr ""
+msgstr "неопознанное hwpy поле в msp430_mcu_data[%d]: %d"
 
 #: config/msp430/driver-msp430.c:709
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected first argument to msp430_select_hwmult_lib: %s"
-msgstr ""
+msgstr "неожиданный первый аргумент для msp430_select_hwmult_lib: %s"
 
 #: config/msp430/driver-msp430.c:713
 #, gcc-internal-format
 msgid "msp430_select_hwmult_lib needs one or more arguments"
-msgstr ""
+msgstr "msp430_select_hwmult_lib требуется один или более аргументов"
 
 #: config/msp430/msp430.c:785
 #, gcc-internal-format, gfc-internal-format
 msgid "MCU '%s' supports %s ISA but -mcpu option is set to %s"
-msgstr ""
+msgstr "MCU '%s' поддерживает %s ISA, но -mcpu опция установлена в %s"
 
 #: config/msp430/msp430.c:791
 #, gcc-internal-format, gfc-internal-format
 msgid "MCU '%s' does not have hardware multiply support, but -mhwmult is set to %s"
-msgstr ""
+msgstr "MCU '%s' не поддерживает аппаратное умножение, но -mhwmult установлено в %s"
 
 #: config/msp430/msp430.c:798
 #, gcc-internal-format, gfc-internal-format
 msgid "MCU '%s' supports %s hardware multiply, but -mhwmult is set to 16-bit"
-msgstr ""
+msgstr "MCU '%s' поддерживает %s аппаратное умножение, но -mhwmult установлено в 16-бит"
 
 #: config/msp430/msp430.c:801
 #, gcc-internal-format, gfc-internal-format
 msgid "MCU '%s' supports %s hardware multiply, but -mhwmult is set to 32-bit"
-msgstr ""
+msgstr "MCU '%s' поддерживает %s аппаратное умножение, но -mhwmult установлено в 32-бит"
 
 #: config/msp430/msp430.c:804
 #, gcc-internal-format, gfc-internal-format
 msgid "MCU '%s' supports %s hardware multiply, but -mhwmult is set to f5series"
-msgstr ""
+msgstr "MCU '%s' поддерживает %s аппаратное умножение, но -mhwmult установлено в f5series"
 
 #: config/msp430/msp430.c:820
 #, gcc-internal-format, gfc-internal-format
@@ -35241,83 +30486,74 @@
 msgstr ""
 
 #: config/msp430/msp430.c:847
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "unrecognized register name %qs"
+#, gcc-internal-format, gfc-internal-format
 msgid "Unrecognized MCU name '%s'."
-msgstr "некорректное имя регистра %qs"
+msgstr "Неопознанное MCU имя '%s'."
 
 #: config/msp430/msp430.c:856
 #, gcc-internal-format
 msgid "-mlarge requires a 430X-compatible -mmcu="
-msgstr ""
+msgstr "-mlarge требует 430X-совместимое -mmcu="
 
 #: config/msp430/msp430.c:859
 #, gcc-internal-format
 msgid "-mcode-region=upper requires 430X-compatible cpu"
-msgstr ""
+msgstr "-mcode-region=upper требует 430X-совместимое cpu"
 
 #: config/msp430/msp430.c:861
 #, gcc-internal-format
 msgid "-mdata-region=upper requires 430X-compatible cpu"
-msgstr ""
+msgstr "-mdata-region=upper требует 430X-совместимое cpu"
 
 #: config/msp430/msp430.c:1886
-#, fuzzy, gcc-internal-format
-#| msgid "invalid argument of %qE attribute"
+#, gcc-internal-format
 msgid "unrecognized interrupt vector argument of %qE attribute"
-msgstr "некорректный аргумент атрибута %qE"
+msgstr "неопознанный аргумент вектор прерываний для %qE атрибута"
 
 #: config/msp430/msp430.c:1895
-#, fuzzy, gcc-internal-format
-#| msgid "argument %d of %qE must be in the range %d...%d"
+#, gcc-internal-format
 msgid "numeric argument of %qE attribute must be in range 0..63"
-msgstr "аргумент %d от %qE должен быть в диапазоне %d...%d"
+msgstr "числовой аргумент для %qE атрибута должен быть в диапазоне 0..63"
 
 #: config/msp430/msp430.c:1901
-#, fuzzy, gcc-internal-format
-#| msgid "argument of %qE attribute is not a string constant"
+#, gcc-internal-format
 msgid "argument of %qE attribute is not a string constant or number"
-msgstr "аргумент %qE атрибута не строковая константа"
+msgstr "аргумент %qE атрибута не строковая константа или число"
 
 #: config/msp430/msp430.c:2023
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute only applies to variables and functions"
+#, gcc-internal-format
 msgid "%qE attribute cannot be applied to variables with specific sections"
-msgstr "атрибут %qE применим только к переменным и функциям"
+msgstr ""
 
 #: config/msp430/msp430.c:2027
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute has no effect on unit local functions"
+#, gcc-internal-format
 msgid "%qE attribute has no effect on automatic variables"
-msgstr "атрибут %qE не действует для локальных функций"
+msgstr ""
 
 #: config/msp430/msp430.c:2174
-#, fuzzy, gcc-internal-format
-#| msgid "cannot set interrupt attribute: no current function"
+#, gcc-internal-format
 msgid "argument to interrupt attribute is unsupported for weak functions"
-msgstr "ошибка при установке атрибута interrupt: нет текущей функции"
+msgstr "аргумент для interrupt атрибута не поддерживается для weak функций"
 
 #: config/msp430/msp430.c:2550
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute allows only an integer constant argument"
+#, gcc-internal-format
 msgid "__delay_cycles() only takes constant arguments"
-msgstr "аргументом атрибута %qE должна быть целая константа"
+msgstr "__delay_cycles() принимает только константные аргументы"
 
 #: config/msp430/msp430.c:2560
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute allows only an integer constant argument"
+#, gcc-internal-format
 msgid "__delay_cycles only takes non-negative cycle counts"
-msgstr "аргументом атрибута %qE должна быть целая константа"
+msgstr "__delay_cycles принимает только неотрицательные счетчики циклов"
 
 #: config/msp430/msp430.c:2580
 #, gcc-internal-format
 msgid "__delay_cycles is limited to 32-bit loop counts"
-msgstr ""
+msgstr "__delay_cycles ограничено 32-битными счетчиками циклов"
 
 #: config/msp430/msp430.c:2650
 #, gcc-internal-format
 msgid "MSP430 builtin functions only work inside interrupt handlers"
-msgstr ""
+msgstr "MSP430 встроенные функции работают только внутри обработчиков прерываний"
 
 #: config/msp430/msp430.c:2662 config/rx/rx.c:2658 config/xtensa/xtensa.c:3465
 #: config/xtensa/xtensa.c:3491
@@ -35326,401 +30562,360 @@
 msgstr "некорректный встроенный code"
 
 #: config/nds32/nds32-intrinsic.c:126 config/nios2/nios2.c:3834
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "invalid argument to built-in function"
+#, gcc-internal-format, gfc-internal-format
 msgid "invalid argument to built-in function %s"
-msgstr "некорректный аргумент встроенной функции"
+msgstr "некорректный аргумент встроенной функции %s"
 
 #: config/nds32/nds32-intrinsic.c:131
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "constant argument out of range for %qs"
+#, gcc-internal-format, gfc-internal-format
 msgid "constant argument out of range for %s"
-msgstr "константный аргумент для %qs вне диапазона"
+msgstr ""
 
 #: config/nds32/nds32-intrinsic.c:690
-#, fuzzy, gcc-internal-format
-#| msgid "this builtin function is only available on the fr450"
+#, gcc-internal-format
 msgid "this builtin function is only available on the v3s or v3f toolchain"
-msgstr "эта встроенная функция доступна только на fr450"
+msgstr ""
 
 #: config/nds32/nds32-intrinsic.c:702
-#, fuzzy, gcc-internal-format
-#| msgid "this builtin function is only available on the fr450"
+#, gcc-internal-format
 msgid "this builtin function is only available on the v3f toolchain"
-msgstr "эта встроенная функция доступна только на fr450"
+msgstr ""
 
 #: config/nds32/nds32-intrinsic.c:717
-#, fuzzy, gcc-internal-format
-#| msgid "nested functions not supported on this target"
+#, gcc-internal-format
 msgid "this builtin function not support on the v3m toolchain"
-msgstr "вложенные функции не поддерживаются для этой платформы"
+msgstr ""
 
 #: config/nds32/nds32-intrinsic.c:736
-#, fuzzy, gcc-internal-format
-#| msgid "Generate bit instructions"
+#, gcc-internal-format
 msgid "don't support performance extension instructions"
-msgstr "Генерировать битовые инструкции"
+msgstr ""
 
 #: config/nds32/nds32-intrinsic.c:748
-#, fuzzy, gcc-internal-format
-#| msgid "Generate bit instructions"
+#, gcc-internal-format
 msgid "don't support performance extension version 2 instructions"
-msgstr "Генерировать битовые инструкции"
+msgstr ""
 
 #: config/nds32/nds32-intrinsic.c:760
-#, fuzzy, gcc-internal-format
-#| msgid "Generate bit instructions"
+#, gcc-internal-format
 msgid "don't support string extension instructions"
-msgstr "Генерировать битовые инструкции"
+msgstr ""
 
 #: config/nds32/nds32-isr.c:341
-#, fuzzy, gcc-internal-format
-#| msgid "too few arguments to function %q#D"
+#, gcc-internal-format
 msgid "multiple save reg attributes to function %qD"
-msgstr "слишком мало аргументов для функции %q#D"
+msgstr "несколько save reg атрибутов для функции %qD"
 
 #: config/nds32/nds32-isr.c:352
-#, fuzzy, gcc-internal-format
-#| msgid "multiple function type attributes specified"
+#, gcc-internal-format
 msgid "multiple nested types attributes to function %qD"
-msgstr "задано несколько атрибутов типа функции"
+msgstr "несколько nested types атрибутов для функции %qD"
 
 #: config/nds32/nds32-isr.c:364
-#, fuzzy, gcc-internal-format
-#| msgid "multiple interrupt attributes not allowed"
+#, gcc-internal-format
 msgid "multiple interrupt attributes to function %qD"
-msgstr "несколько атрибутов прерываний не допускаются"
+msgstr "несколько interrupt атрибутов для функции %qD"
 
 #. Trampoline is not supported on reduced-set registers yet.
 #: config/nds32/nds32.c:2327 config/nds32/nds32.c:2381
-#: config/nds32/nds32.c:3127 config/nds32/nds32.c:3201
-#: config/nds32/nds32.c:3216 config/nds32/nds32.c:3222
-#: config/nds32/nds32.c:3284 config/nds32/nds32.c:3290
-#: config/nds32/nds32.c:3322
-#, fuzzy, gcc-internal-format
-#| msgid "nested functions not supported on this target"
+#: config/nds32/nds32.c:3128 config/nds32/nds32.c:3202
+#: config/nds32/nds32.c:3217 config/nds32/nds32.c:3223
+#: config/nds32/nds32.c:3285 config/nds32/nds32.c:3291
+#: config/nds32/nds32.c:3323
+#, gcc-internal-format
 msgid "a nested function is not supported for reduced registers"
-msgstr "вложенные функции не поддерживаются для этой платформы"
+msgstr "вложенные функции не поддерживаются для сокращенных регистров"
 
 #. The enum index value for array size is out of range.
-#: config/nds32/nds32.c:3025
-#, fuzzy, gcc-internal-format
-#| msgid "invalid register in the instruction"
+#: config/nds32/nds32.c:3026
+#, gcc-internal-format
 msgid "intrinsic register index is out of range"
-msgstr "некорректный регистр в инструкции"
+msgstr "встроенный регистровый индекс вне диапазона"
 
-#: config/nds32/nds32.c:3041 config/nds32/nds32.c:3048
-#: config/nds32/nds32.c:3055 config/nds32/nds32.c:3062
-#: config/nds32/nds32.c:3069
-#, fuzzy, gcc-internal-format
-#| msgid "invalid register in the instruction"
+#: config/nds32/nds32.c:3042 config/nds32/nds32.c:3049
+#: config/nds32/nds32.c:3056 config/nds32/nds32.c:3063
+#: config/nds32/nds32.c:3070
+#, gcc-internal-format
 msgid "CCTL intrinsic function subtype out of range!"
-msgstr "некорректный регистр в инструкции"
+msgstr ""
 
-#: config/nds32/nds32.c:3508
-#, fuzzy, gcc-internal-format
-#| msgid "invalid type for iteration variable %qE"
+#: config/nds32/nds32.c:3509
+#, gcc-internal-format
 msgid "invalid id value for interrupt/exception attribute"
-msgstr "некорректный тип итерационной переменной %qE"
+msgstr "некорректное id значение для interrupt/exception атрибута"
 
-#: config/nds32/nds32.c:3536
-#, fuzzy, gcc-internal-format
-#| msgid "invalid argument of %qs attribute"
+#: config/nds32/nds32.c:3537
+#, gcc-internal-format
 msgid "invalid id value for reset attribute"
-msgstr "некорректный аргумент атрибута %qs"
+msgstr "некорректное id значение для reset атрибута"
 
-#: config/nds32/nds32.c:3552
-#, fuzzy, gcc-internal-format
-#| msgid "invalid argument of %qs attribute"
+#: config/nds32/nds32.c:3553
+#, gcc-internal-format
 msgid "invalid nmi function for reset attribute"
-msgstr "некорректный аргумент атрибута %qs"
+msgstr "некорректная nmi функция для reset атрибута"
 
-#: config/nds32/nds32.c:3565
-#, fuzzy, gcc-internal-format
-#| msgid "invalid argument of %qs attribute"
+#: config/nds32/nds32.c:3566
+#, gcc-internal-format
 msgid "invalid warm function for reset attribute"
-msgstr "некорректный аргумент атрибута %qs"
+msgstr "некорректная warm функция для reset атрибута"
 
-#: config/nds32/nds32.c:3638
+#: config/nds32/nds32.c:3639
 #, gcc-internal-format
 msgid "Disable FPU ISA, the ABI option must be enable '-mfloat-abi=soft'"
 msgstr ""
 
-#: config/nds32/nds32.c:3641
+#: config/nds32/nds32.c:3642
 #, gcc-internal-format
 msgid "'-mabi=2fp+' option only support when FPU available, must be enable '-mext-fpu-sp' or '-mext-fpu-dp'"
 msgstr ""
 
-#: config/nds32/nds32.c:3647
-#, fuzzy, gcc-internal-format
-#| msgid "Disable position-independent code (PIC) for use in OS kernel code"
+#: config/nds32/nds32.c:3648
+#, gcc-internal-format
 msgid "position-independent code not supported"
-msgstr "Выключить позиционно-независимый код (PIC) для использования в коде ядра OS"
+msgstr "позиционно-независимый код не поддерживается"
 
 #: config/nios2/nios2.c:573
 #, gcc-internal-format
 msgid "Unknown form for stack limit expression"
-msgstr ""
+msgstr "Неизвестная форма для выражения границы стека"
 
 #: config/nios2/nios2.c:1182
-#, fuzzy, gcc-internal-format
-#| msgid "target attribute or pragma changes double precision floating point"
+#, gcc-internal-format
 msgid "switch %<-mcustom-%s%> is required for double precision floating point"
-msgstr "target attribute или pragma изменяет плавающие двойной точности"
+msgstr "ключ %<-mcustom-%s%> требуется для плавающей точки двойной точности"
 
 #: config/nios2/nios2.c:1195
 #, gcc-internal-format
 msgid "switch %<-mcustom-%s%> has no effect unless -funsafe-math-optimizations is specified"
-msgstr ""
+msgstr "ключ %<-mcustom-%s%> не действует, если -funsafe-math-optimizations не задано"
 
 #: config/nios2/nios2.c:1204
 #, gcc-internal-format
 msgid "switch %<-mcustom-%s%> has no effect unless -ffinite-math-only is specified"
-msgstr ""
+msgstr "ключ %<-mcustom-%s%> не действует, если -ffinite-math-only не задано"
 
 #: config/nios2/nios2.c:1213
 #, gcc-internal-format
 msgid "switch %<-mcustom-%s%> has no effect unless -fno-math-errno is specified"
-msgstr ""
+msgstr "ключ %<-mcustom-%s%> не действует, если -fno-math-errno не задано"
 
 #: config/nios2/nios2.c:1218
 #, gcc-internal-format
 msgid "conflicting use of -mcustom switches, target attributes, and/or __builtin_custom_ functions"
-msgstr ""
+msgstr "противоречивое использование -mcustom ключей, атрибутов цели и/или __builtin_custom_ функций"
 
 #: config/nios2/nios2.c:1320
 #, gcc-internal-format
 msgid "ignoring unrecognized switch %<-mcustom-fpu-cfg%> value %<%s%>"
-msgstr ""
+msgstr "игнорирование неопознанного значения ключа %<-mcustom-fpu-cfg%> %<%s%>"
 
 #: config/nios2/nios2.c:1339
 #, gcc-internal-format
 msgid "switch %<-mcustom-%s%> value %d must be between 0 and 255"
-msgstr ""
+msgstr "значение ключа %<-mcustom-%s%> %d должно быть между 0 и 255"
 
 #: config/nios2/nios2.c:1362
-#, fuzzy, gcc-internal-format
-#| msgid "Disable position-independent code (PIC) for use in OS kernel code"
+#, gcc-internal-format
 msgid "position-independent code requires the Linux ABI"
-msgstr "Выключить позиционно-независимый код (PIC) для использования в коде ядра OS"
+msgstr "позиционно-независимый код требует Linux ABI"
 
 #: config/nios2/nios2.c:1365
 #, gcc-internal-format
 msgid "PIC support for -fstack-limit-symbol"
-msgstr ""
+msgstr "PIC поддержка для -fstack-limit-symbol"
 
 #: config/nios2/nios2.c:1387
-#, fuzzy, gcc-internal-format
-#| msgid "profiling not supported with -mg"
+#, gcc-internal-format
 msgid "-mgpopt not supported with PIC."
-msgstr "профилирование с -mg не поддерживается"
+msgstr ""
 
 #: config/nios2/nios2.c:1389
-#, fuzzy, gcc-internal-format
-#| msgid "profiling not supported with -mg"
+#, gcc-internal-format
 msgid "-mgprel-sec= not supported with PIC."
-msgstr "профилирование с -mg не поддерживается"
+msgstr ""
 
 #: config/nios2/nios2.c:1391
-#, fuzzy, gcc-internal-format
-#| msgid "profiling not supported with -mg"
+#, gcc-internal-format
 msgid "-mr0rel-sec= not supported with PIC."
-msgstr "профилирование с -mg не поддерживается"
+msgstr ""
 
 #
 #: config/nios2/nios2.c:1399
-#, fuzzy, gcc-internal-format
-#| msgid "object argument is not a potential constant expression"
+#, gcc-internal-format
 msgid "-mgprel-sec= argument is not a valid regular expression."
-msgstr "объектный аргумент не есть потенциальное константное выражение"
+msgstr ""
 
 #
 #: config/nios2/nios2.c:1405
-#, fuzzy, gcc-internal-format
-#| msgid "object argument is not a potential constant expression"
+#, gcc-internal-format
 msgid "-mr0rel-sec= argument is not a valid regular expression."
-msgstr "объектный аргумент не есть потенциальное константное выражение"
+msgstr ""
 
 #
 #: config/nios2/nios2.c:1416
-#, fuzzy, gcc-internal-format
-#| msgid "generation of Branch Likely instructions enabled, but not supported by architecture"
+#, gcc-internal-format
 msgid "BMX instructions are only supported with R2 architecture"
-msgstr "генерация инструкций Branch Likely включена, но не поддерживается архитектурой"
+msgstr "BMX инструкции поддерживаются только с R2 архитектурой"
 
 #: config/nios2/nios2.c:1418
-#, fuzzy, gcc-internal-format
-#| msgid "instruction scheduling not supported on this target machine"
+#, gcc-internal-format
 msgid "CDX instructions are only supported with R2 architecture"
-msgstr "планирование команд для этой платформы не поддерживается"
+msgstr "CDX инструкции поддерживаются только с R2 архитектурой"
 
 #: config/nios2/nios2.c:1423
-#, fuzzy, gcc-internal-format
-#| msgid "Generate code in little endian mode"
+#, gcc-internal-format
 msgid "R2 architecture is little-endian only"
-msgstr "Генерировать код для обратного (little endian) порядка байт"
+msgstr "R2 архитектура только little-endian"
 
 #: config/nios2/nios2.c:3580
 #, gcc-internal-format
 msgid "Cannot call %<__builtin_custom_%s%> without specifying switch %<-mcustom-%s%>"
-msgstr ""
+msgstr "Невозможно вызвать %<__builtin_custom_%s%> без задания ключа %<-mcustom-%s%>"
 
 #: config/nios2/nios2.c:3688
 #, gcc-internal-format, gfc-internal-format
 msgid "custom instruction opcode must be compile time constant in the range 0-255 for __builtin_custom_%s"
-msgstr ""
+msgstr "код операции специализированной инструкции должен быть константой времени компиляции в диапазоне 00-255 для __builtin_custom_%s"
 
 #: config/nios2/nios2.c:3893
 #, gcc-internal-format, gfc-internal-format
 msgid "Control register number must be in range 0-31 for %s"
-msgstr ""
+msgstr "Номер управляющего регистра должен быть в диапазоне 0-31 для %s"
 
 #: config/nios2/nios2.c:3921
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "number must be 0 or 1"
+#, gcc-internal-format, gfc-internal-format
 msgid "Register number must be in range 0-31 for %s"
-msgstr "число должно быть 0 или 1"
+msgstr "Номер регистра должен быть в диапазоне 0-31 для %s"
 
 #: config/nios2/nios2.c:3928
 #, gcc-internal-format, gfc-internal-format
 msgid "The immediate value must fit into a %d-bit integer for %s"
-msgstr ""
+msgstr "Непосредственное значение должно помещаться в %d-битное целое для %s"
 
 #: config/nios2/nios2.c:3978
 #, gcc-internal-format
 msgid "The ENI instruction operand must be either 0 or 1"
-msgstr ""
+msgstr "Операнд ENI инструкции должен быть 0 или 1"
 
 #: config/nios2/nios2.c:4006
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Builtin function %s requires the -mvsx option"
+#, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires Nios II R%d"
-msgstr "Встроенная функция %s требует опцию -mvsx"
+msgstr "Встроенная функция %s требует Nios II R%d"
 
 #: config/nios2/nios2.c:4086
-#, fuzzy, gcc-internal-format
-#| msgid "switch -mcpu=%s conflicts with -march=%s switch"
+#, gcc-internal-format
 msgid "switch %<-mcustom-%s%> conflicts with switch %<-mcustom-%s%>"
-msgstr "ключ -mcpu=%s несовместим с ключом -march=%s"
+msgstr "ключ %<-mcustom-%s%> конфликтует с ключом %<-mcustom-%s%>"
 
 #: config/nios2/nios2.c:4092 config/nios2/nios2.c:4102
 #, gcc-internal-format
 msgid "call to %<__builtin_custom_%s%> conflicts with switch %<-mcustom-%s%>"
-msgstr ""
+msgstr "вызов %<__builtin_custom_%s%> конфликтует с ключом %<-mcustom-%s%>"
 
 #: config/nios2/nios2.c:4208
 #, gcc-internal-format
 msgid "custom-fpu-cfg option does not support %<no-%>"
-msgstr ""
+msgstr "custom-fpu-cfg опция не поддерживает %<no-%>"
 
 #: config/nios2/nios2.c:4213
 #, gcc-internal-format
 msgid "custom-fpu-cfg option requires configuration argument"
-msgstr ""
+msgstr "custom-fpu-cfg опция требует конфигурационного аргумента"
 
 #: config/nios2/nios2.c:4242
-#, fuzzy, gcc-internal-format
-#| msgid "%s only accepts 2 arguments"
+#, gcc-internal-format
 msgid "%<no-custom-%s%> does not accept arguments"
-msgstr "%s принимает только 2 аргумента"
+msgstr "%<no-custom-%s%> не принимает аргументы"
 
 #: config/nios2/nios2.c:4257
 #, gcc-internal-format
 msgid "%<custom-%s=%> requires argument"
-msgstr ""
+msgstr "%<custom-%s=%> требует аргумента"
 
 #: config/nios2/nios2.c:4267
 #, gcc-internal-format, gfc-internal-format
 msgid "`custom-%s=' argument requires numeric digits"
-msgstr ""
+msgstr "`custom-%s=' аргумент требует числовых цифр"
 
 #: config/nios2/nios2.c:4279
 #, gcc-internal-format
 msgid "%<custom-%s=%> is not recognized as FPU instruction"
-msgstr ""
+msgstr "%<custom-%s=%> не опознано как FPU инструкция"
 
 #: config/nios2/nios2.c:4286
-#, fuzzy, gcc-internal-format
-#| msgid "type of %qE is unknown"
+#, gcc-internal-format
 msgid "%<%s%> is unknown"
-msgstr "тип %qE неизвестен"
+msgstr "%<%s%> неизвестен"
 
 #: config/nvptx/mkoffload.c:109
-#, fuzzy, gcc-internal-format
-#| msgid "malformed spec function name"
+#, gcc-internal-format
 msgid "malformed ptx file"
-msgstr "некорректное имя spec-функции"
+msgstr "некорректный синтаксис ptx файла"
 
 #: config/nvptx/mkoffload.c:409
-#, fuzzy, gcc-internal-format
-#| msgid "COLLECT_LTO_WRAPPER must be set"
+#, gcc-internal-format
 msgid "COLLECT_GCC must be set."
-msgstr "должна быть установлена COLLECT_LTO_WRAPPER"
+msgstr "COLLECT_GCC должен быть установлен."
 
 #: config/nvptx/mkoffload.c:490
 #, gcc-internal-format
 msgid "either -fopenacc or -fopenmp must be set"
-msgstr ""
+msgstr "или -fopenacc или -fopenmp должно быть установлено"
 
 #: config/nvptx/mkoffload.c:554
-#, fuzzy, gcc-internal-format
-#| msgid "%s:cannot open graph file\n"
+#, gcc-internal-format
 msgid "cannot open intermediate ptx file"
-msgstr "%s:ошибка открытия графического файла\n"
+msgstr "ошибка открытия промежуточного ptx файла"
 
 #: config/nvptx/nvptx.c:165
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Builtin function %s is not supported with the current options"
+#, gcc-internal-format, gfc-internal-format
 msgid "option %s is not supported together with -fopenacc"
-msgstr "Встроенная функция %s не поддерживается с текущими опциями"
+msgstr "опция %s не поддерживается вместе с -fopenacc"
 
 #: config/nvptx/nvptx.c:191
-#, fuzzy, gcc-internal-format
-#| msgid "writing to address space %qs not supported"
+#, gcc-internal-format
 msgid "not generating patch area, nops not supported"
-msgstr "запись в адресное пространство %qs не поддерживается"
+msgstr ""
 
 #: config/nvptx/nvptx.c:278
 #, gcc-internal-format
 msgid "static initialization of variable %q+D in %<.shared%> memory is not supported"
-msgstr ""
+msgstr "статическая инициализация переменной %q+D в %<.shared%> памяти не поддерживается"
 
 #: config/nvptx/nvptx.c:1970
 #, gcc-internal-format
 msgid "cannot emit unaligned pointers in ptx assembly"
-msgstr ""
+msgstr "невозможно породить невыровненные указатели в ptx ассемблере"
 
 #: config/nvptx/nvptx.c:2196
 #, gcc-internal-format
 msgid "PTX does not support weak declarations (only weak definitions)"
-msgstr ""
+msgstr "PTX не поддерживает weak декларации (только weak определения)"
 
 #: config/nvptx/nvptx.c:4616
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute ignored on types"
+#, gcc-internal-format
 msgid "%qE attribute requires a void return type"
-msgstr "атрибут %qE для типов игнорируется"
+msgstr "атрибут %qE требует возвращаемый тип void"
 
 #: config/nvptx/nvptx.c:4639
-#, fuzzy, gcc-internal-format
-#| msgid "__BELOW100__ attribute not allowed with auto storage class"
+#, gcc-internal-format
 msgid "%qE attribute not allowed with auto storage class"
-msgstr "атрибут __BELOW100__ не допускается для класса памяти auto"
+msgstr "%qE атрибут не допускается с классом памяти auto"
 
 #: config/nvptx/nvptx.c:5009
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring %d"
-msgstr ""
+msgstr "использование vector_length (%d), игнорирование %d"
 
 #: config/nvptx/nvptx.c:5010
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring runtime setting"
-msgstr ""
+msgstr "использование vector_length (%d), игнорирование установок времени выполнения"
 
 #: config/nvptx/nvptx.c:5020
 #, gcc-internal-format, gfc-internal-format
 msgid "using num_workers (%d), ignoring %d"
-msgstr ""
+msgstr "использование num_workers (%d), игнорирование %d"
 
 #: config/pa/pa.c:532
 #, gcc-internal-format
@@ -35750,7 +30945,7 @@
 #: config/pa/pa.c:8825
 #, gcc-internal-format, gfc-internal-format
 msgid "alignment (%u) for %s exceeds maximum alignment for global common data.  Using %u"
-msgstr "выравнивание (%u) для %s превышает максимальное выравнивание для глобальных общих данных. Используется %u"
+msgstr ""
 
 #: config/powerpcspe/host-darwin.c:61 config/rs6000/host-darwin.c:61
 #, gcc-internal-format
@@ -35811,39 +31006,35 @@
 msgid "junk at end of #pragma longcall"
 msgstr "мусор в конце #pragma longcall"
 
-#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6154
+#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6152
 #, gcc-internal-format
 msgid "vec_lvsl is deprecated for little endian; use assignment for unaligned loads and stores"
-msgstr ""
+msgstr "vec_lvsl устарело для little endian; используйте присваивание для невыровненных загрузок и сохранений"
 
-#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6158
+#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6156
 #, gcc-internal-format
 msgid "vec_lvsr is deprecated for little endian; use assignment for unaligned loads and stores"
-msgstr ""
+msgstr "vec_lvsr устарело для little endian; используйте присваивание для невыровненных загрузок и сохранений"
 
 #: config/powerpcspe/powerpcspe-c.c:5675
-#, fuzzy, gcc-internal-format
-#| msgid "vec_extract only accepts 2 arguments"
+#, gcc-internal-format
 msgid "vec_mul only accepts 2 arguments"
-msgstr "vec_extract принимает только 2 аргумента"
+msgstr "vec_mul принимает только 2 аргумента"
 
 #: config/powerpcspe/powerpcspe-c.c:5726
-#, fuzzy, gcc-internal-format
-#| msgid "vec_insert only accepts 3 arguments"
+#, gcc-internal-format
 msgid "vec_cmpne only accepts 2 arguments"
-msgstr "vec_insert принимает только 3 аргумента"
+msgstr "vec_cmpne принимает только 2 аргумента"
 
 #: config/powerpcspe/powerpcspe-c.c:5796
-#, fuzzy, gcc-internal-format
-#| msgid "vec_insert only accepts 3 arguments"
+#, gcc-internal-format
 msgid "vec_adde only accepts 3 arguments"
-msgstr "vec_insert принимает только 3 аргумента"
+msgstr "vec_adde принимает только 3 аргумента"
 
 #: config/powerpcspe/powerpcspe-c.c:5860
-#, fuzzy, gcc-internal-format
-#| msgid "vec_insert only accepts 3 arguments"
+#, gcc-internal-format
 msgid "vec_addec only accepts 3 arguments"
-msgstr "vec_insert принимает только 3 аргумента"
+msgstr "vec_addec принимает только 3 аргумента"
 
 #: config/powerpcspe/powerpcspe-c.c:5948
 #, gcc-internal-format, gfc-internal-format
@@ -35870,29 +31061,25 @@
 msgid "vec_insert only accepts 3 arguments"
 msgstr "vec_insert принимает только 3 аргумента"
 
-#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6868
-#, fuzzy, gcc-internal-format
-#| msgid "passing arg %d of %qE discards qualifiers frompointer target type"
+#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6866
+#, gcc-internal-format
 msgid "passing arg %d of %qE discards qualifiers from pointer target type"
-msgstr "передача arg %d от %qE отменяет квалификаторы frompointer указуемого типа"
+msgstr "передача аргумента %d от %qE отбрасывает квалификаторы типа цели указателя"
 
 #: config/powerpcspe/powerpcspe-c.c:6515
-#, fuzzy, gcc-internal-format
-#| msgid "%s only accepts 2 arguments"
+#, gcc-internal-format
 msgid "__builtin_cmpb only accepts 2 arguments"
-msgstr "%s принимает только 2 аргумента"
+msgstr ""
 
 #: config/powerpcspe/powerpcspe-c.c:6573
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "ifunc is not supported in this configuration"
+#, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s not supported in this compiler configuration"
-msgstr "ifunc в данной конфигурации не поддерживается"
+msgstr "внутренняя функция %s не поддерживается в данной конфигурации компилятора"
 
 #: config/powerpcspe/powerpcspe-c.c:6581
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "invalid parameter combination for AltiVec intrinsic"
+#, gcc-internal-format, gfc-internal-format
 msgid "invalid parameter combination for AltiVec intrinsic %s"
-msgstr "недопустимая комбинация параметров для AltiVec встроенной функции"
+msgstr "некорректная комбинация параметров для AltiVec встроенной функции %s"
 
 #: config/powerpcspe/powerpcspe.c:3829
 #, gcc-internal-format
@@ -35922,27 +31109,27 @@
 #: config/powerpcspe/powerpcspe.c:4209
 #, gcc-internal-format
 msgid "will not generate power9 instructions because assembler lacks power9 support"
-msgstr ""
+msgstr "не будут генерироваться power9 инструкции, так как в ассемблер не поддерживает power9"
 
 #: config/powerpcspe/powerpcspe.c:4218
 #, gcc-internal-format
 msgid "will not generate power8 instructions because assembler lacks power8 support"
-msgstr ""
+msgstr "не будут генерироваться power8 инструкции, так как в ассемблер не поддерживает power8"
 
 #: config/powerpcspe/powerpcspe.c:4227
 #, gcc-internal-format
 msgid "will not generate power7 instructions because assembler lacks power7 support"
-msgstr ""
+msgstr "не будут генерироваться power7 инструкции, так как в ассемблер не поддерживает power7"
 
 #: config/powerpcspe/powerpcspe.c:4236
 #, gcc-internal-format
 msgid "will not generate power6 instructions because assembler lacks power6 support"
-msgstr ""
+msgstr "не будут генерироваться power6 инструкции, так как в ассемблер не поддерживает power6"
 
 #: config/powerpcspe/powerpcspe.c:4245
 #, gcc-internal-format
 msgid "will not generate power5 instructions because assembler lacks power5 support"
-msgstr ""
+msgstr "не будут генерироваться power5 инструкции, так как в ассемблер не поддерживает power5"
 
 #: config/powerpcspe/powerpcspe.c:4333
 #, gcc-internal-format
@@ -35950,10 +31137,9 @@
 msgstr "не сконфигурировано для SPE ABI"
 
 #: config/powerpcspe/powerpcspe.c:4338
-#, fuzzy, gcc-internal-format
-#| msgid "Do not use PowerPC instruction set"
+#, gcc-internal-format
 msgid "not configured for SPE instruction set"
-msgstr "Не использовать систему команд PowerPC"
+msgstr "не сконфигурировано для SPE набора инструкций"
 
 #: config/powerpcspe/powerpcspe.c:4344
 #, gcc-internal-format
@@ -35960,7 +31146,7 @@
 msgid "target attribute or pragma changes SPE ABI"
 msgstr "target attribute или pragma изменяет SPE ABI"
 
-#: config/powerpcspe/powerpcspe.c:4351 config/rs6000/rs6000.c:4223
+#: config/powerpcspe/powerpcspe.c:4351 config/rs6000/rs6000.c:4243
 #, gcc-internal-format
 msgid "AltiVec not supported in this target"
 msgstr "AltiVec не поддерживается на этой целевой платформе"
@@ -35983,76 +31169,69 @@
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
 #: config/powerpcspe/powerpcspe.c:4489 config/powerpcspe/powerpcspe.c:4500
-#, fuzzy, gcc-internal-format
-#| msgid "-mcmodel incompatible with other toc options"
+#, gcc-internal-format
 msgid "-mpower9-minmax incompatible with explicitly disabled options"
-msgstr "ключ -mcmodel несовместим с другими опциями toc"
+msgstr "-mpower9-minmax несовместима с явно выключенными опциями"
 
 #: config/powerpcspe/powerpcspe.c:4492
 #, gcc-internal-format
 msgid "Power9 target option is incompatible with -mcpu=<xxx> for <xxx> less than power9"
-msgstr ""
+msgstr "Power9 опция цели несовместима с -mcpu=<xxx> для <xxx> меньше чем power9"
 
 #: config/powerpcspe/powerpcspe.c:4524
 #, gcc-internal-format
 msgid "-mcrypto requires -maltivec"
-msgstr ""
+msgstr "-mcrypto требует -maltivec"
 
 #: config/powerpcspe/powerpcspe.c:4531
-#, fuzzy, gcc-internal-format
-#| msgid "--resource requires -o"
+#, gcc-internal-format
 msgid "-mdirect-move requires -mvsx"
-msgstr "ключ --resource требует задания -o"
+msgstr "-mdirect-move требует -mvsx"
 
 #: config/powerpcspe/powerpcspe.c:4538
 #, gcc-internal-format
 msgid "-mpower8-vector requires -maltivec"
-msgstr ""
+msgstr "-mpower8-vector требует -maltivec"
 
 #: config/powerpcspe/powerpcspe.c:4546
-#, fuzzy, gcc-internal-format
-#| msgid "--resource requires -o"
+#, gcc-internal-format
 msgid "-mpower8-vector requires -mvsx"
-msgstr "ключ --resource требует задания -o"
+msgstr "-mpower8-vector требует -mvsx"
 
 #: config/powerpcspe/powerpcspe.c:4565
-#, fuzzy, gcc-internal-format
-#| msgid "--resource requires -o"
+#, gcc-internal-format
 msgid "-mvsx-timode requires -mvsx"
-msgstr "ключ --resource требует задания -o"
+msgstr "-mvsx-timode требует -mvsx"
 
 #: config/powerpcspe/powerpcspe.c:4572
-#, fuzzy, gcc-internal-format
-#| msgid "-msingle-float option equivalent to -mhard-float"
+#, gcc-internal-format
 msgid "-mhard-dfp requires -mhard-float"
-msgstr "опция -msingle-float эквивалентна -mhard-float"
+msgstr "-mhard-dfp требует -mhard-float"
 
 #: config/powerpcspe/powerpcspe.c:4625
-#, fuzzy, gcc-internal-format
-#| msgid "--resource requires -o"
+#, gcc-internal-format
 msgid "-mupper-regs-df requires -mvsx"
-msgstr "ключ --resource требует задания -o"
+msgstr "-mupper-regs-df требует -mvsx"
 
 #: config/powerpcspe/powerpcspe.c:4632
-#, fuzzy, gcc-internal-format
-#| msgid "--resource requires -o"
+#, gcc-internal-format
 msgid "-mupper-regs-di requires -mvsx"
-msgstr "ключ --resource требует задания -o"
+msgstr "-mupper-regs-di требует -mvsx"
 
 #: config/powerpcspe/powerpcspe.c:4639
 #, gcc-internal-format
 msgid "-mupper-regs-sf requires -mpower8-vector"
-msgstr ""
+msgstr "-mupper-regs-sf требует -mpower8-vector"
 
 #: config/powerpcspe/powerpcspe.c:4688
 #, gcc-internal-format
 msgid "-mpower8-fusion-sign requires -mpower8-fusion"
-msgstr ""
+msgstr "-mpower8-fusion-sign требует -mpower8-fusion"
 
 #: config/powerpcspe/powerpcspe.c:4691
 #, gcc-internal-format
 msgid "-mtoc-fusion requires -mpower8-fusion"
-msgstr ""
+msgstr "-mtoc-fusion требует -mpower8-fusion"
 
 #. We prefer to not mention undocumented options in
 #. error messages.  However, if users have managed to select
@@ -36061,60 +31240,59 @@
 #: config/powerpcspe/powerpcspe.c:4708
 #, gcc-internal-format
 msgid "-mpower9-fusion requires -mpower8-fusion"
-msgstr ""
+msgstr "-mpower9-fusion требует -mpower8-fusion"
 
 #: config/powerpcspe/powerpcspe.c:4761
 #, gcc-internal-format
 msgid "-mpower9-vector requires -mpower8-vector"
-msgstr ""
+msgstr "-mpower9-vector требует -mpower8-vector"
 
 #: config/powerpcspe/powerpcspe.c:4806
 #, gcc-internal-format
 msgid "-mpower9-dform requires -mpower9-vector"
-msgstr ""
+msgstr "-mpower9-dform требует -mpower9-vector"
 
 #: config/powerpcspe/powerpcspe.c:4835
 #, gcc-internal-format
 msgid "-mpower9-dform, -mpower9-dform-vector, -mpower9-dform-scalar require -mdirect-move"
-msgstr ""
+msgstr "-mpower9-dform, -mpower9-dform-vector, -mpower9-dform-scalar требуют -mdirect-move"
 
 #: config/powerpcspe/powerpcspe.c:4858
 #, gcc-internal-format
 msgid "-mpower9-dform requires -mupper-regs-df"
-msgstr ""
+msgstr "-mpower9-dform требует -mupper-regs-df"
 
 #: config/powerpcspe/powerpcspe.c:4865
 #, gcc-internal-format
 msgid "-mpower9-dform requires -mupper-regs-sf"
-msgstr ""
+msgstr "-mpower9-dform требует -mupper-regs-sf"
 
 #: config/powerpcspe/powerpcspe.c:4885
-#, fuzzy, gcc-internal-format
-#| msgid "--resource requires -o"
+#, gcc-internal-format
 msgid "-mvsx-timode might need -mlra"
-msgstr "ключ --resource требует задания -o"
+msgstr "-mvsx-timode возможно требует -mlra"
 
 #: config/powerpcspe/powerpcspe.c:4910
 #, gcc-internal-format
 msgid "-mallow-movmisalign requires -mvsx"
-msgstr ""
+msgstr "-mallow-movmisalign требует -mvsx"
 
 #: config/powerpcspe/powerpcspe.c:4925
 #, gcc-internal-format
 msgid "-mefficient-unaligned-vsx requires -mvsx"
-msgstr ""
+msgstr "-mefficient-unaligned-vsx требует -mvsx"
 
 #: config/powerpcspe/powerpcspe.c:4933
 #, gcc-internal-format
 msgid "-mefficient-unaligned-vsx requires -mallow-movmisalign"
-msgstr ""
+msgstr "-mefficient-unaligned-vsx требует -mallow-movmisalign"
 
 #: config/powerpcspe/powerpcspe.c:4947
 #, gcc-internal-format
 msgid "-mvsx-small-integer requires -mpower8-vector, -mupper-regs-di, and -mdirect-move"
-msgstr ""
+msgstr "-mvsx-small-integer требует -mpower8-vector, -mupper-regs-di и -mdirect-move"
 
-#: config/powerpcspe/powerpcspe.c:4959 config/rs6000/rs6000.c:4601
+#: config/powerpcspe/powerpcspe.c:4959 config/rs6000/rs6000.c:4628
 #, gcc-internal-format
 msgid "target attribute or pragma changes long double size"
 msgstr "target attribute или pragma изменяет размер long double"
@@ -36122,33 +31300,32 @@
 #: config/powerpcspe/powerpcspe.c:4985
 #, gcc-internal-format
 msgid "-mfloat128 requires VSX support"
-msgstr ""
+msgstr "-mfloat128 требует VSX поддержки"
 
 #: config/powerpcspe/powerpcspe.c:4995
 #, gcc-internal-format
 msgid "-mfloat128-type requires VSX support"
-msgstr ""
+msgstr "-mfloat128-type требует VSX поддержки"
 
 #: config/powerpcspe/powerpcspe.c:5011
 #, gcc-internal-format
 msgid "-mfloat128 requires -mfloat128-type"
-msgstr ""
+msgstr "-mfloat128 требует -mfloat128-type"
 
 #: config/powerpcspe/powerpcspe.c:5024
-#, fuzzy, gcc-internal-format
-#| msgid "-msingle-float option equivalent to -mhard-float"
+#, gcc-internal-format
 msgid "-mfloat128-hardware requires -mfloat128-type"
-msgstr "опция -msingle-float эквивалентна -mhard-float"
+msgstr "-mfloat128-hardware требует -mfloat128-type"
 
 #: config/powerpcspe/powerpcspe.c:5047
 #, gcc-internal-format
 msgid "-mfloat128-hardware requires full ISA 3.0 support"
-msgstr ""
+msgstr "-mfloat128-hardware требует полной ISA 3.0 поддержки"
 
 #: config/powerpcspe/powerpcspe.c:5055
 #, gcc-internal-format
 msgid "-mfloat128-hardware requires -m64"
-msgstr ""
+msgstr "-mfloat128-hardware требует -m64"
 
 #: config/powerpcspe/powerpcspe.c:5119
 #, gcc-internal-format, gfc-internal-format
@@ -36156,22 +31333,22 @@
 msgstr "неизвестный тип (%s) ABI библиотеки векторизации для ключа -mveclibabi="
 
 #: config/powerpcspe/powerpcspe.c:5140 config/powerpcspe/powerpcspe.c:5155
-#: config/rs6000/rs6000.c:4766 config/rs6000/rs6000.c:4781
+#: config/rs6000/rs6000.c:4791 config/rs6000/rs6000.c:4806
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr "target attribute или pragma изменяет AltiVec ABI"
 
-#: config/powerpcspe/powerpcspe.c:5168 config/rs6000/rs6000.c:4794
+#: config/powerpcspe/powerpcspe.c:5168 config/rs6000/rs6000.c:4819
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr "target attribute или pragma изменяет darwin64 ABI"
 
-#: config/powerpcspe/powerpcspe.c:5234 config/rs6000/rs6000.c:4828
+#: config/powerpcspe/powerpcspe.c:5234 config/rs6000/rs6000.c:4853
 #, gcc-internal-format
 msgid "target attribute or pragma changes single precision floating point"
 msgstr "target attribute или pragma изменяет плавающие одинарной точности"
 
-#: config/powerpcspe/powerpcspe.c:5237 config/rs6000/rs6000.c:4831
+#: config/powerpcspe/powerpcspe.c:5237 config/rs6000/rs6000.c:4856
 #, gcc-internal-format
 msgid "target attribute or pragma changes double precision floating point"
 msgstr "target attribute или pragma изменяет плавающие двойной точности"
@@ -36179,15 +31356,14 @@
 #: config/powerpcspe/powerpcspe.c:5364
 #, gcc-internal-format
 msgid "-mstack-protector-guard=tls needs a valid base register"
-msgstr ""
+msgstr "-mstack-protector-guard требует допустимый базовый регистр"
 
-#: config/powerpcspe/powerpcspe.c:8415 config/rs6000/rs6000.c:7925
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
+#: config/powerpcspe/powerpcspe.c:8415 config/rs6000/rs6000.c:7950
+#, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
-msgstr "ABI для передачи параметров с %d-байтным выравниванием изменен в GCC 4.6"
+msgstr "расположение агрегатов содержащих векторы с %d-байтным выравниванием изменилось в GCC 5"
 
-#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11237
+#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11269
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC вектор, возвращенный по ссылке: нестандартное расширение ABI без гарантий совместимости"
@@ -36197,11 +31373,10 @@
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "возврат значения в векторном регистре невозможен, поскольку инструкции altivec отключены, используйте -maltivec для их включения"
 
-#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11595
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
+#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11633
+#, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
-msgstr "ABI для передачи параметров с %d-байтным выравниванием изменен в GCC 4.6"
+msgstr "ABI для передачи агрегатов с %d-байтным выравниванием изменен в GCC 5"
 
 #: config/powerpcspe/powerpcspe.c:12460
 #, gcc-internal-format
@@ -36208,13 +31383,12 @@
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "передача аргумента в векторном регистре невозможна, поскольку инструкции altivec отключены, используйте -maltivec для их включения"
 
-#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12604
-#, fuzzy, gcc-internal-format
-#| msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
+#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12648
+#, gcc-internal-format
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
-msgstr "ABI для передачи структуры с элементом complex float изменен в GCC 4.4"
+msgstr "ABI для передачи однородных плавающих агрегатов изменен в GCC 5"
 
-#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12779
+#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12823
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC вектор, переданный по ссылке: нестандартное расширение ABI без гарантий совместимости"
@@ -36224,34 +31398,31 @@
 msgid "internal error: builtin function %s already processed"
 msgstr "внутренняя ошибка: встроенная функция %s уже обработана"
 
-#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:13971
-#, fuzzy, gcc-internal-format
-#| msgid "argument 1 must be a 5-bit signed literal"
+#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:14015
+#, gcc-internal-format
 msgid "argument 1 must be an 8-bit field value"
-msgstr "аргумент 1 должен быть 5-битным знаковым литералом"
+msgstr "аргумент 1 должен быть 8-битным значением поля"
 
-#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14015
+#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14059
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "аргумент 1 должен быть 5-битным знаковым литералом"
 
 #: config/powerpcspe/powerpcspe.c:14934 config/powerpcspe/powerpcspe.c:16803
-#: config/rs6000/rs6000.c:14101
+#: config/rs6000/rs6000.c:14145
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "аргумент 2 должен быть 5-битным беззнаковым литералом"
 
-#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14119
-#, fuzzy, gcc-internal-format
-#| msgid "argument 3 must be a 1-bit unsigned literal"
+#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14163
+#, gcc-internal-format
 msgid "argument 1 must be a 6-bit unsigned literal"
-msgstr "аргумент 3 должен быть 1-битным беззнаковым литералом"
+msgstr "аргумент 1 должен быть 6-битным беззнаковым литералом"
 
-#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14135
-#, fuzzy, gcc-internal-format
-#| msgid "argument 2 must be a 5-bit unsigned literal"
+#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14179
+#, gcc-internal-format
 msgid "argument 2 must be a 7-bit unsigned literal"
-msgstr "аргумент 2 должен быть 5-битным беззнаковым литералом"
+msgstr "аргумент 2 должен быть 7-битным беззнаковым литералом"
 
 #: config/powerpcspe/powerpcspe.c:15005
 #, gcc-internal-format
@@ -36264,95 +31435,84 @@
 msgstr "аргумент 1 __builtin_altivec_predicate вне диапазона"
 
 #: config/powerpcspe/powerpcspe.c:15550
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "%srtd%s is ignored in 64bit mode"
+#, gcc-internal-format, gfc-internal-format
 msgid "builtin %s is only valid in 64-bit mode"
-msgstr "%srtd%s игнорируется в 64-битном режиме"
+msgstr "внутренняя функция %s допустима только в 64-битном режиме"
 
-#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14791
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "argument 2 must be a 5-bit unsigned literal"
+#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14835
+#, gcc-internal-format, gfc-internal-format
 msgid "argument %d must be an unsigned literal"
-msgstr "аргумент 2 должен быть 5-битным беззнаковым литералом"
+msgstr "аргумент %d должен быть беззнаковым литералом"
 
-#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14793
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "argument 1 of __builtin_spe_predicate is out of range"
+#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14837
+#, gcc-internal-format, gfc-internal-format
 msgid "argument %d is an unsigned literal that is out of range"
-msgstr "аргумент 1 __builtin_spe_predicate вне диапазона"
+msgstr "аргумент %d есть беззнаковый литерал вне диапазона"
 
 #: config/powerpcspe/powerpcspe.c:15739
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "%s only accepts 1 argument"
+#, gcc-internal-format, gfc-internal-format
 msgid "builtin %s only accepts a string argument"
-msgstr "%s принимает только 1 аргумент"
+msgstr "внутренняя функция %s принимает только строковый аргумент"
 
 #. Invalid CPU argument.
 #: config/powerpcspe/powerpcspe.c:15758
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "%qs is an invalid argument to -mcpu="
+#, gcc-internal-format, gfc-internal-format
 msgid "cpu %s is an invalid argument to builtin %s"
-msgstr "%qs некорректный аргумент для -mcpu="
+msgstr "процессор %s есть некорректный аргумент для внутренней функции %s"
 
 #. Invalid HWCAP argument.
 #: config/powerpcspe/powerpcspe.c:15786
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "%qs is an invalid argument to -mcpu="
+#, gcc-internal-format, gfc-internal-format
 msgid "hwcap %s is an invalid argument to builtin %s"
-msgstr "%qs некорректный аргумент для -mcpu="
+msgstr "hwcap %s есть некорректный аргумент для внутренней функции %s"
 
-#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15065
+#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15109
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "аргумент 3 должен быть 4-битным беззнаковым литералом"
 
-#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15090
+#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15134
 #, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "аргумент 3 должен быть 2-битным беззнаковым литералом"
 
-#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15110
+#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15154
 #, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "аргумент 3 должен быть 1-битным беззнаковым литералом"
 
-#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15122
-#, fuzzy, gcc-internal-format
-#| msgid "argument 1 must be a map"
+#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15166
+#, gcc-internal-format
 msgid "argument 1 must be 0 or 2"
-msgstr "аргумент 1 должен быть отображением"
+msgstr "аргумент 1 должен быть 0 или 2"
 
-#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15134
-#, fuzzy, gcc-internal-format
-#| msgid "argument 3 must be a 1-bit unsigned literal"
+#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15178
+#, gcc-internal-format
 msgid "argument 1 must be a 1-bit unsigned literal"
-msgstr "аргумент 3 должен быть 1-битным беззнаковым литералом"
+msgstr "аргумент 1 должен быть 1-битным беззнаковым литералом"
 
-#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15148
-#, fuzzy, gcc-internal-format
-#| msgid "argument 2 must be a 5-bit unsigned literal"
+#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15192
+#, gcc-internal-format
 msgid "argument 2 must be a 6-bit unsigned literal"
-msgstr "аргумент 2 должен быть 5-битным беззнаковым литералом"
+msgstr "аргумент 2 должен быть 6-битным беззнаковым литералом"
 
-#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15160
-#, fuzzy, gcc-internal-format
-#| msgid "number must be 0 or 1"
+#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15204
+#, gcc-internal-format
 msgid "argument 2 must be 0 or 1"
-msgstr "число должно быть 0 или 1"
+msgstr "аргумент 2 должен быть 0 или 1"
 
-#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15168
-#, fuzzy, gcc-internal-format
-#| msgid "argument %d of %qE must be in the range %d...%d"
+#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15212
+#, gcc-internal-format
 msgid "argument 3 must be in the range 0..15"
-msgstr "аргумент %d от %qE должен быть в диапазоне %d...%d"
+msgstr "аргумент 3 должен быть в диапазоне 0..15"
 
-#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15237
-#: config/rs6000/rs6000.c:15569
+#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15281
+#: config/rs6000/rs6000.c:15613
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "аргумент %qs должен быть 2-битным беззнаковым литералом"
 
-#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15394
+#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15438
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr "неразрешенная перегрузка Altivec builtin %qF"
@@ -36364,16 +31524,14 @@
 
 #
 #: config/powerpcspe/powerpcspe.c:16531
-#, fuzzy, gcc-internal-format
-#| msgid "second argument to %<__builtin_expect%> must be a constant"
+#, gcc-internal-format
 msgid "second argument to vec_vextract4b must be 0..12"
-msgstr "второй аргумент %<__builtin_expect%> должен быть константой"
+msgstr "второй аргумент vec_vextract4b должен быть 0..12"
 
 #: config/powerpcspe/powerpcspe.c:16548
-#, fuzzy, gcc-internal-format
-#| msgid "third argument to %<__builtin_prefetch%> must be a constant"
+#, gcc-internal-format
 msgid "third argument to vec_vinsert4b must be 0..12"
-msgstr "третий аргумент %<__builtin_prefetch%> должен быть константой"
+msgstr "третий аргумент vec_vextract4b должен быть 0..12"
 
 #: config/powerpcspe/powerpcspe.c:16923
 #, gcc-internal-format
@@ -36406,10 +31564,9 @@
 msgstr "Встроенная функция %s требует опцию -mvsx"
 
 #: config/powerpcspe/powerpcspe.c:17153
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Builtin function %s requires the -mvsx option"
+#, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhtm option"
-msgstr "Встроенная функция %s требует опцию -mvsx"
+msgstr "Встроенная функция %s требует опцию -mhtm"
 
 #: config/powerpcspe/powerpcspe.c:17155
 #, gcc-internal-format, gfc-internal-format
@@ -36427,52 +31584,44 @@
 msgstr "Встроенная функция %s требует опцию -mspe"
 
 #: config/powerpcspe/powerpcspe.c:17162
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Builtin function %s requires the -mpaired option"
+#, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-dfp and -mpower8-vector options"
-msgstr "Встроенная функция %s требует опцию --mpaired"
+msgstr "Встроенная функция %s требует опции -mhard-dfp и -mpower8-vector"
 
 #: config/powerpcspe/powerpcspe.c:17165
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Builtin function %s requires the -mpaired option"
+#, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-dfp option"
-msgstr "Встроенная функция %s требует опцию --mpaired"
+msgstr "Встроенная функция %s требует опцию -mhard-dfp"
 
 #: config/powerpcspe/powerpcspe.c:17167
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Builtin function %s requires the -mspe option"
+#, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mpower8-vector option"
-msgstr "Встроенная функция %s требует опцию -mspe"
+msgstr "Встроенная функция %s требует опцию -mpower8-vector"
 
 #: config/powerpcspe/powerpcspe.c:17170 config/powerpcspe/powerpcspe.c:17176
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Builtin function %s requires the -mspe option"
+#, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mcpu=power9 and -m64 options"
-msgstr "Встроенная функция %s требует опцию -mspe"
+msgstr "Встроенная функция %s требует опции -mcpu=power9 и -m64"
 
 #: config/powerpcspe/powerpcspe.c:17173 config/powerpcspe/powerpcspe.c:17179
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Builtin function %s requires the -mspe option"
+#, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mcpu=power9 option"
-msgstr "Встроенная функция %s требует опцию -mspe"
+msgstr "Встроенная функция %s требует опцию -mcpu=power9"
 
 #: config/powerpcspe/powerpcspe.c:17182
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Builtin function %s requires the -maltivec option"
+#, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-float and -mlong-double-128 options"
-msgstr "Встроенная функция %s требует опцию --maltivec"
+msgstr "Встроенная функция %s требует опции -mhard-float и -mlong-double-128"
 
 #: config/powerpcspe/powerpcspe.c:17185
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Builtin function %s requires the -mpaired option"
+#, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-float option"
-msgstr "Встроенная функция %s требует опцию --mpaired"
+msgstr "Встроенная функция %s требует опцию -mhard-float"
 
 #: config/powerpcspe/powerpcspe.c:17187
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Builtin function %s requires the -mpaired option"
+#, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mfloat128 option"
-msgstr "Встроенная функция %s требует опцию --mpaired"
+msgstr "Встроенная функция %s требует опцию -mfloat128"
 
 #: config/powerpcspe/powerpcspe.c:17189
 #, gcc-internal-format, gfc-internal-format
@@ -36489,24 +31638,22 @@
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr "внутренняя ошибка: встроенная функция %s, аргумент %d имел неожиданный тип аргумента %s"
 
-#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25758
+#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25835
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr "кадр стека слишком велик"
 
 #: config/powerpcspe/powerpcspe.c:32257
-#, fuzzy, gcc-internal-format
-#| msgid "-fsplit-stack does not support 3 register parameters"
+#, gcc-internal-format
 msgid "-fsplit-stack uses register r29"
-msgstr "-fsplit-stack не поддерживает 3-регистровые параметры"
+msgstr "-fsplit-stack использует регистр r29"
 
-#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29459
-#, fuzzy, gcc-internal-format
-#| msgid "#pragma GCC target is not supported for this machine"
+#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29536
+#, gcc-internal-format
 msgid "Stack frame larger than 2G is not supported for -fsplit-stack"
-msgstr "#pragma GCC target для этой машины не поддерживается"
+msgstr "Кадр стека больше 2G не поддерживается для -fsplit-stack"
 
-#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30447
+#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30524
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "отсутствует профилирование 64-битного кода для этого ABI"
@@ -36516,22 +31663,22 @@
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr "Вы не можете брать адрес вложенной функции, если Вы используете опцию -mno-pointers-to-nested-functions."
 
-#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32830
+#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32907
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "использование %<long double%> в типах AltiVec некорректно"
 
-#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32832
+#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32909
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "использование типов boolean в типах AltiVec некорректно"
 
-#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32834
+#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32911
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "использование %<complex%> в типах AltiVec некорректно"
 
-#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32836
+#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32913
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr "использование типов decimal floating point в типах AltiVec некорректно"
@@ -36541,7 +31688,7 @@
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr "использование %<long%> в типах AltiVec некорректно для 64-битного кода без -mvsx"
 
-#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32845
+#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32922
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "использование %<long%> в типах AltiVec не рекомендуется; используйте %<int%>"
@@ -36584,12 +31731,12 @@
 #: config/powerpcspe/powerpcspe.c:40254
 #, gcc-internal-format, gfc-internal-format
 msgid "-mno-%s turns off -m%s"
-msgstr ""
+msgstr "-mno-%s выключает -m%s"
 
 #: config/powerpcspe/powerpcspe.c:40271
 #, gcc-internal-format
 msgid "-mno-power9-vector turns off -mpower9-dform"
-msgstr ""
+msgstr "-mno-power9-vector выключает -mpower9-dform"
 
 #. Definitions of target machine for GNU compiler,
 #. for IBM RS/6000 POWER running AIX version 4.3.
@@ -36916,22 +32063,19 @@
 msgstr "ключ -mcmodel несовместим с другими опциями toc"
 
 #: config/powerpcspe/e500.h:37
-#, fuzzy, gcc-internal-format
-#| msgid "AltiVec and E500 instructions cannot coexist"
+#, gcc-internal-format
 msgid "AltiVec and SPE instructions cannot coexist"
-msgstr "инструкции AltiVec и E500 несовместимы"
+msgstr "инструкции AltiVec и SPE несовместимы"
 
 #: config/powerpcspe/e500.h:39
-#, fuzzy, gcc-internal-format
-#| msgid "VSX and E500 instructions cannot coexist"
+#, gcc-internal-format
 msgid "VSX and SPE instructions cannot coexist"
-msgstr "инструкции VSX и E500 несовместимы"
+msgstr "инструкции VSX и SPE несовместимы"
 
 #: config/powerpcspe/e500.h:41
-#, fuzzy, gcc-internal-format
-#| msgid "64-bit E500 not supported"
+#, gcc-internal-format
 msgid "64-bit SPE not supported"
-msgstr "64-битный E500 не поддерживается"
+msgstr "64-битный SPE не поддерживается"
 
 #: config/powerpcspe/e500.h:43
 #, gcc-internal-format
@@ -36940,10 +32084,9 @@
 
 #: config/powerpcspe/freebsd64.h:98 config/powerpcspe/linux64.h:115
 #: config/rs6000/freebsd64.h:98 config/rs6000/linux64.h:115
-#, fuzzy, gcc-internal-format
-#| msgid "-mas100-syntax is incompatible with -gdwarf"
+#, gcc-internal-format
 msgid "-mcall-aixdesc incompatible with -mabi=elfv2"
-msgstr "ключ -mas100-syntax несовместим с -gdwarf"
+msgstr "-mcall-aixdesc несовместим с -mabi=elfv2"
 
 #: config/powerpcspe/freebsd64.h:113 config/powerpcspe/linux64.h:135
 #: config/rs6000/freebsd64.h:113 config/rs6000/linux64.h:135
@@ -37006,90 +32149,80 @@
 
 #
 #: config/riscv/riscv.c:310
-#, fuzzy, gcc-internal-format
-#| msgid "unknown value %s for -mfpu"
+#, gcc-internal-format
 msgid "unknown cpu %qs for -mtune"
-msgstr "неизвестное значение %s для ключа -mfpu"
+msgstr "неизвестный процессор %qs для -mtune"
 
 #: config/riscv/riscv.c:4097
 #, gcc-internal-format
 msgid "-mdiv requires -march to subsume the %<M%> extension"
-msgstr ""
+msgstr "-mdiv требует -march, чтобы понять %<M%> расширение"
 
 #: config/riscv/riscv.c:4137
 #, gcc-internal-format
 msgid "requested ABI requires -march to subsume the %qc extension"
-msgstr ""
+msgstr "запрошенный ABI требует -march, чтобы понять %qc расширение"
 
 #: config/riscv/riscv.c:4142
 #, gcc-internal-format, gfc-internal-format
 msgid "ABI requires -march=rv%d"
-msgstr ""
+msgstr "ABI требует -march=rv%d"
 
 #: config/riscv/riscv.c:4152
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
+#, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d must be between %d and %d"
-msgstr "-mpreferred-stack-boundary=%d не между %d и %d"
+msgstr ""
 
 #. Address spaces are currently only supported by C.
 #: config/rl78/rl78.c:374
-#, fuzzy, gcc-internal-format
-#| msgid "-mmulticore can only be used with BF561"
+#, gcc-internal-format
 msgid "-mes0 can only be used with C"
-msgstr "-mmulticore можно использовать только с BF561"
+msgstr "-mes0 можно использовать только с C"
 
 #: config/rl78/rl78.c:377
 #, gcc-internal-format
 msgid "mduc registers only saved for G13 target"
-msgstr ""
+msgstr "mduc регистры сохраняются только для G13 цели"
 
 #: config/rl78/rl78.c:392
-#, fuzzy, gcc-internal-format
-#| msgid "-mmulticore can only be used with BF561"
+#, gcc-internal-format
 msgid "-mmul=g13 cannot be used with -mcpu=g10"
-msgstr "-mmulticore можно использовать только с BF561"
+msgstr "-mmul=g13 не может использоваться с -mcpu=g10"
 
 #: config/rl78/rl78.c:393
-#, fuzzy, gcc-internal-format
-#| msgid "-mmulticore can only be used with BF561"
+#, gcc-internal-format
 msgid "-mmul=g14 cannot be used with -mcpu=g10"
-msgstr "-mmulticore можно использовать только с BF561"
+msgstr "-mmul=g14 не может использоваться с -mcpu=g10"
 
 #. The S2 core does not have mul/div instructions.
 #: config/rl78/rl78.c:404
-#, fuzzy, gcc-internal-format
-#| msgid "-mmulticore can only be used with BF561"
+#, gcc-internal-format
 msgid "-mmul=g14 cannot be used with -mcpu=g13"
-msgstr "-mmulticore можно использовать только с BF561"
+msgstr "-mmul=g14 не может использоваться с -mcpu=g13"
 
 #. The G14 core does not have the hardware multiply peripheral used by the
 #. G13 core, hence you cannot use G13 multipliy routines on G14 hardware.
 #: config/rl78/rl78.c:416
-#, fuzzy, gcc-internal-format
-#| msgid "-mmulticore can only be used with BF561"
+#, gcc-internal-format
 msgid "-mmul=g13 cannot be used with -mcpu=g14"
-msgstr "-mmulticore можно использовать только с BF561"
+msgstr "-mmul=g13 не может использоваться с -mcpu=g14"
 
 #: config/rl78/rl78.c:838
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute only applies to functions"
+#, gcc-internal-format
 msgid "naked attribute only applies to functions"
-msgstr "%qE атрибут применим только к функциям"
+msgstr "naked атрибут применим только к функциям"
 
 #: config/rl78/rl78.c:862
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute only applies to functions"
+#, gcc-internal-format
 msgid "%qE attribute doesn't apply to functions"
-msgstr "%qE атрибут применим только к функциям"
+msgstr "%qE атрибут не применим к функциям"
 
 #. This is unpredictable, as we're truncating off usable address
 #. bits.
 #: config/rl78/rl78.c:1228
-#, fuzzy, gcc-internal-format
-#| msgid "converting %<false%> to pointer type %qT"
+#, gcc-internal-format
 msgid "converting far pointer to near pointer"
-msgstr "преобразование %<false%> в указательный тип %qT"
+msgstr "преобразование далекого указателя в ближний указатель"
 
 #: config/rs6000/driver-rs6000.c:268
 #, gcc-internal-format, gfc-internal-format
@@ -37098,82 +32231,71 @@
 "Please use an explicit cpu name.  Valid cpu names are: %s"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6168 config/rs6000/rs6000-c.c:6219
-#: config/rs6000/rs6000-c.c:6489 config/rs6000/rs6000-c.c:6555
-#: config/rs6000/rs6000-c.c:6916 config/rs6000/rs6000-c.c:6963
-#, fuzzy, gcc-internal-format
-#| msgid "%s only accepts 1 argument"
+#: config/rs6000/rs6000-c.c:6166 config/rs6000/rs6000-c.c:6217
+#: config/rs6000/rs6000-c.c:6487 config/rs6000/rs6000-c.c:6553
+#: config/rs6000/rs6000-c.c:6914 config/rs6000/rs6000-c.c:6961
+#, gcc-internal-format
 msgid "builtin %qs only accepts 2 arguments"
-msgstr "%s принимает только 1 аргумент"
+msgstr ""
 
-#: config/rs6000/rs6000-c.c:6292 config/rs6000/rs6000-c.c:6375
-#: config/rs6000/rs6000-c.c:6736
-#, fuzzy, gcc-internal-format
-#| msgid "%s only accepts 1 argument"
+#: config/rs6000/rs6000-c.c:6290 config/rs6000/rs6000-c.c:6373
+#: config/rs6000/rs6000-c.c:6734
+#, gcc-internal-format
 msgid "builtin %qs only accepts 3 arguments"
-msgstr "%s принимает только 1 аргумент"
+msgstr ""
 
-#: config/rs6000/rs6000-c.c:6484
-#, fuzzy, gcc-internal-format
-#| msgid "%s only accepts 1 argument"
+#: config/rs6000/rs6000-c.c:6482
+#, gcc-internal-format
 msgid "builtin %qs only accepts 1 argument"
-msgstr "%s принимает только 1 аргумент"
+msgstr ""
 
-#: config/rs6000/rs6000-c.c:7054
-#, fuzzy, gcc-internal-format
-#| msgid "Builtin function %s requires the -mvsx option"
+#: config/rs6000/rs6000-c.c:7052
+#, gcc-internal-format
 msgid "builtin %qs requires builtin %qs"
-msgstr "Встроенная функция %s требует опцию -mvsx"
+msgstr ""
 
-#: config/rs6000/rs6000-c.c:7058
-#, fuzzy, gcc-internal-format
-#| msgid "ifunc is not supported in this configuration"
+#: config/rs6000/rs6000-c.c:7056
+#, gcc-internal-format
 msgid "builtin function %qs not supported in this compiler configuration"
-msgstr "ifunc в данной конфигурации не поддерживается"
+msgstr ""
 
-#: config/rs6000/rs6000-c.c:7068
-#, fuzzy, gcc-internal-format
-#| msgid "invalid parameter combination for AltiVec intrinsic"
+#: config/rs6000/rs6000-c.c:7066
+#, gcc-internal-format
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
-msgstr "недопустимая комбинация параметров для AltiVec встроенной функции"
+msgstr ""
 
-#: config/rs6000/rs6000.c:3754 config/rs6000/rs6000.c:3757
-#: config/rs6000/rs6000.c:3760
-#, fuzzy, gcc-internal-format
-#| msgid "%qE is predetermined %qs for %qs"
+#: config/rs6000/rs6000.c:3772 config/rs6000/rs6000.c:3775
+#: config/rs6000/rs6000.c:3778
+#, gcc-internal-format
 msgid "%qs requires %qs or %qs"
-msgstr "%qE является предопределенным %qs для %qs"
+msgstr ""
 
-#: config/rs6000/rs6000.c:3861
-#, fuzzy, gcc-internal-format
-#| msgid "-m64 requires PowerPC64 architecture, enabling"
+#: config/rs6000/rs6000.c:3879
+#, gcc-internal-format
 msgid "%qs requires PowerPC64 architecture, enabling"
-msgstr "ключ -m64 требует архитектуры PowerPC64, включается"
+msgstr ""
 
-#: config/rs6000/rs6000.c:4037
-#, fuzzy, gcc-internal-format
-#| msgid "%qE is deprecated"
+#: config/rs6000/rs6000.c:4057
+#, gcc-internal-format
 msgid "%qs command-line option is deprecated"
-msgstr "имя %qE будет исключено в будущих версиях"
+msgstr ""
 
-#: config/rs6000/rs6000.c:4048
-#, fuzzy, gcc-internal-format
-#| msgid "-malign-power is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
+#: config/rs6000/rs6000.c:4068
+#, gcc-internal-format
 msgid "%qs is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
-msgstr "ключ -malign-power не поддерживается для 64-битного Darwin; он несовместим с установленными библиотеками C и C++"
+msgstr ""
 
-#: config/rs6000/rs6000.c:4147
+#: config/rs6000/rs6000.c:4167
 #, gcc-internal-format
 msgid "will not generate %qs instructions because assembler lacks %qs support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4240
-#, fuzzy, gcc-internal-format
-#| msgid "-mstring is not supported on little endian systems"
+#: config/rs6000/rs6000.c:4260
+#, gcc-internal-format
 msgid "%qs is not supported on little endian systems"
-msgstr "ключ -mstring не поддерживается для систем little endian"
+msgstr ""
 
-#: config/rs6000/rs6000.c:4333
+#: config/rs6000/rs6000.c:4353
 #, gcc-internal-format
 msgid "power9 target option is incompatible with %<%s=<xxx>%> for <xxx> less than power9"
 msgstr ""
@@ -37180,291 +32302,250 @@
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:4341
-#, fuzzy, gcc-internal-format
-#| msgid "%qs is incompatible with %qs"
+#: config/rs6000/rs6000.c:4361
+#, gcc-internal-format
 msgid "%qs incompatible with explicitly disabled options"
-msgstr "%qs несовместим с %qs"
+msgstr ""
 
 #. We prefer to not mention undocumented options in
 #. error messages.  However, if users have managed to select
 #. power9-fusion without selecting power8-fusion, they
 #. already know about undocumented flags.
-#: config/rs6000/rs6000.c:4366 config/rs6000/rs6000.c:4373
-#: config/rs6000/rs6000.c:4380 config/rs6000/rs6000.c:4388
-#: config/rs6000/rs6000.c:4407 config/rs6000/rs6000.c:4464
-#: config/rs6000/rs6000.c:4468 config/rs6000/rs6000.c:4485
-#: config/rs6000/rs6000.c:4538 config/rs6000/rs6000.c:4565
-#: config/rs6000/rs6000.c:4580 config/rs6000/rs6000.c:4588
-#: config/rs6000/rs6000.c:4684
-#, fuzzy, gcc-internal-format
-#| msgid "%qT referred to as %qs"
+#: config/rs6000/rs6000.c:4386 config/rs6000/rs6000.c:4393
+#: config/rs6000/rs6000.c:4400 config/rs6000/rs6000.c:4408
+#: config/rs6000/rs6000.c:4427 config/rs6000/rs6000.c:4484
+#: config/rs6000/rs6000.c:4488 config/rs6000/rs6000.c:4505
+#: config/rs6000/rs6000.c:4558 config/rs6000/rs6000.c:4585
+#: config/rs6000/rs6000.c:4600 config/rs6000/rs6000.c:4608
+#: config/rs6000/rs6000.c:4709
+#, gcc-internal-format
 msgid "%qs requires %qs"
-msgstr "ссылка на %qT как на %qs"
+msgstr ""
 
-#: config/rs6000/rs6000.c:4625
-#, fuzzy, gcc-internal-format
-#| msgid "using IEEE extended precision long double"
+#: config/rs6000/rs6000.c:4650
+#, gcc-internal-format
 msgid "Using IEEE extended precision long double"
-msgstr "использование IEEE extended precision long double"
+msgstr ""
 
-#: config/rs6000/rs6000.c:4627
-#, fuzzy, gcc-internal-format
-#| msgid "using IBM extended precision long double"
+#: config/rs6000/rs6000.c:4652
+#, gcc-internal-format
 msgid "Using IBM extended precision long double"
-msgstr "использование IBM extended precision long double"
+msgstr ""
 
-#: config/rs6000/rs6000.c:4644
-#, fuzzy, gcc-internal-format
-#| msgid "%s does not support %s"
+#: config/rs6000/rs6000.c:4669
+#, gcc-internal-format
 msgid "%qs requires VSX support"
-msgstr "%s не поддерживает %s"
+msgstr ""
 
-#: config/rs6000/rs6000.c:4653
+#: config/rs6000/rs6000.c:4678
 #, gcc-internal-format
 msgid "The -mfloat128 option may not be fully supported"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4676
+#: config/rs6000/rs6000.c:4701
 #, gcc-internal-format
 msgid "%qs requires full ISA 3.0 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4743
-#, fuzzy, gcc-internal-format
-#| msgid "unknown vectorization library ABI type (%s) for -mveclibabi= switch"
+#: config/rs6000/rs6000.c:4768
+#, gcc-internal-format
 msgid "unknown vectorization library ABI type (%qs) for %qs switch"
-msgstr "неизвестный тип (%s) ABI библиотеки векторизации для ключа -mveclibabi="
+msgstr ""
 
-#: config/rs6000/rs6000.c:4930
-#, fuzzy, gcc-internal-format
-#| msgid "%qs is not valid for %qs"
+#: config/rs6000/rs6000.c:4955
+#, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
-msgstr "%qs не является корректным для %qs"
+msgstr ""
 
-#: config/rs6000/rs6000.c:4935
-#, fuzzy, gcc-internal-format
-#| msgid "%qs is not valid for %qs"
+#: config/rs6000/rs6000.c:4960
+#, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
-msgstr "%qs не является корректным для %qs"
+msgstr ""
 
-#: config/rs6000/rs6000.c:4947
-#, fuzzy, gcc-internal-format
-#| msgid "%qs is not a valid class name"
+#: config/rs6000/rs6000.c:4972
+#, gcc-internal-format
 msgid "%qs is not a valid base register in %qs"
-msgstr "%qs не является корректным именем класса"
+msgstr ""
 
-#: config/rs6000/rs6000.c:4955
-#, fuzzy, gcc-internal-format
-#| msgid "need a call-clobbered target register"
+#: config/rs6000/rs6000.c:4980
+#, gcc-internal-format
 msgid "%qs needs a valid base register"
-msgstr "нужен затираемый вызовом целевой регистр"
+msgstr ""
 
-#: config/rs6000/rs6000.c:5253
-#, fuzzy, gcc-internal-format
-#| msgid "unknown option for -mrecip=%s"
+#: config/rs6000/rs6000.c:5278
+#, gcc-internal-format
 msgid "unknown option for %<%s=%s%>"
-msgstr "неизвестная опция для -mrecip=%s"
+msgstr ""
 
-#: config/rs6000/rs6000.c:5290
-#, fuzzy, gcc-internal-format
-#| msgid "Deprecated.  This switch has no effect"
+#: config/rs6000/rs6000.c:5315
+#, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
-msgstr "Устаревший ключ. Игнорируется."
+msgstr ""
 
-#: config/rs6000/rs6000.c:11401
-#, fuzzy, gcc-internal-format
-#| msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
+#: config/rs6000/rs6000.c:11439
+#, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use %qs to enable them"
-msgstr "возврат значения в векторном регистре невозможен, поскольку инструкции altivec отключены, используйте -maltivec для их включения"
+msgstr ""
 
-#: config/rs6000/rs6000.c:11862
-#, fuzzy, gcc-internal-format
-#| msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
+#: config/rs6000/rs6000.c:11906
+#, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use %qs to enable them"
-msgstr "передача аргумента в векторном регистре невозможна, поскольку инструкции altivec отключены, используйте -maltivec для их включения"
+msgstr ""
 
-#: config/rs6000/rs6000.c:13572
-#, fuzzy, gcc-internal-format
-#| msgid "internal error: builtin function %s already processed"
+#: config/rs6000/rs6000.c:13616
+#, gcc-internal-format
 msgid "internal error: builtin function %qs already processed"
-msgstr "внутренняя ошибка: встроенная функция %s уже обработана"
+msgstr ""
 
-#: config/rs6000/rs6000.c:14150
-#, fuzzy, gcc-internal-format
-#| msgid "argument 2 must be a 5-bit unsigned literal"
+#: config/rs6000/rs6000.c:14194
+#, gcc-internal-format
 msgid "argument 2 must be a 1-bit unsigned literal"
-msgstr "аргумент 2 должен быть 5-битным беззнаковым литералом"
+msgstr ""
 
-#: config/rs6000/rs6000.c:14189
-#, fuzzy, gcc-internal-format
-#| msgid "argument %d of %qE must be a pointer type"
+#: config/rs6000/rs6000.c:14233
+#, gcc-internal-format
 msgid "argument 1 of %qs must be a constant"
-msgstr "аргумент %d для %qE должен быть указателем"
+msgstr ""
 
-#: config/rs6000/rs6000.c:14247 config/rs6000/rs6000.c:15898
-#, fuzzy, gcc-internal-format
-#| msgid "argument 1 of __builtin_spe_predicate is out of range"
+#: config/rs6000/rs6000.c:14291 config/rs6000/rs6000.c:15942
+#, gcc-internal-format
 msgid "argument 1 of %qs is out of range"
-msgstr "аргумент 1 __builtin_spe_predicate вне диапазона"
+msgstr ""
 
-#: config/rs6000/rs6000.c:14742
-#, fuzzy, gcc-internal-format
-#| msgid "%srtd%s is ignored in 64bit mode"
+#: config/rs6000/rs6000.c:14786
+#, gcc-internal-format
 msgid "builtin %qs is only valid in 64-bit mode"
-msgstr "%srtd%s игнорируется в 64-битном режиме"
+msgstr ""
 
-#: config/rs6000/rs6000.c:14939
-#, fuzzy, gcc-internal-format
-#| msgid "%s only accepts 1 argument"
+#: config/rs6000/rs6000.c:14983
+#, gcc-internal-format
 msgid "builtin %qs only accepts a string argument"
-msgstr "%s принимает только 1 аргумент"
+msgstr ""
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000.c:14958
-#, fuzzy, gcc-internal-format
-#| msgid "%qs is an invalid argument to -mcpu="
+#: config/rs6000/rs6000.c:15002
+#, gcc-internal-format
 msgid "cpu %qs is an invalid argument to builtin %qs"
-msgstr "%qs некорректный аргумент для -mcpu="
+msgstr ""
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000.c:14986
-#, fuzzy, gcc-internal-format
-#| msgid "%qs is an invalid argument to -mcpu="
+#: config/rs6000/rs6000.c:15030
+#, gcc-internal-format
 msgid "%s %qs is an invalid argument to builtin %qs"
-msgstr "%qs некорректный аргумент для -mcpu="
+msgstr ""
 
-#: config/rs6000/rs6000.c:15012
+#: config/rs6000/rs6000.c:15056
 #, gcc-internal-format
 msgid "builtin %qs needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15616
-#, fuzzy, gcc-internal-format
-#| msgid "argument 1 must be a map"
+#: config/rs6000/rs6000.c:15660
+#, gcc-internal-format
 msgid "second argument to %qs must be 0..12"
-msgstr "аргумент 1 должен быть отображением"
+msgstr ""
 
-#: config/rs6000/rs6000.c:15631
-#, fuzzy, gcc-internal-format
-#| msgid "argument 1 must be a map"
+#: config/rs6000/rs6000.c:15675
+#, gcc-internal-format
 msgid "third argument to %qs must be 0..12"
-msgstr "аргумент 1 должен быть отображением"
+msgstr ""
 
-#: config/rs6000/rs6000.c:15850
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "argument %d of %qE must be a pointer type"
+#: config/rs6000/rs6000.c:15894
+#, gcc-internal-format, gfc-internal-format
 msgid "argument 1 of %s must be a constant"
-msgstr "аргумент %d для %qE должен быть указателем"
+msgstr ""
 
-#: config/rs6000/rs6000.c:15932
-#, fuzzy, gcc-internal-format
-#| msgid "Builtin function %s is only valid for the cell processor"
+#: config/rs6000/rs6000.c:15976
+#, gcc-internal-format
 msgid "builtin function %qs is only valid for the cell processor"
-msgstr "Встроенная функция %s допустима только для процессора cell"
+msgstr ""
 
-#: config/rs6000/rs6000.c:15934 config/rs6000/rs6000.c:15936
-#: config/rs6000/rs6000.c:15938 config/rs6000/rs6000.c:15940
-#: config/rs6000/rs6000.c:15946 config/rs6000/rs6000.c:15948
-#: config/rs6000/rs6000.c:15955 config/rs6000/rs6000.c:15962
-#: config/rs6000/rs6000.c:15969 config/rs6000/rs6000.c:15975
-#, fuzzy, gcc-internal-format
-#| msgid "Builtin function %s requires the -mvsx option"
+#: config/rs6000/rs6000.c:15978 config/rs6000/rs6000.c:15980
+#: config/rs6000/rs6000.c:15982 config/rs6000/rs6000.c:15984
+#: config/rs6000/rs6000.c:15990 config/rs6000/rs6000.c:15992
+#: config/rs6000/rs6000.c:15999 config/rs6000/rs6000.c:16006
+#: config/rs6000/rs6000.c:16011 config/rs6000/rs6000.c:16014
+#: config/rs6000/rs6000.c:16018 config/rs6000/rs6000.c:16024
+#, gcc-internal-format
 msgid "builtin function %qs requires the %qs option"
-msgstr "Встроенная функция %s требует опцию -mvsx"
+msgstr ""
 
-#: config/rs6000/rs6000.c:15943 config/rs6000/rs6000.c:15952
-#: config/rs6000/rs6000.c:15959 config/rs6000/rs6000.c:15966
-#, fuzzy, gcc-internal-format
-#| msgid "Builtin function %s requires the -mvsx option"
+#: config/rs6000/rs6000.c:15987 config/rs6000/rs6000.c:15996
+#: config/rs6000/rs6000.c:16003
+#, gcc-internal-format
 msgid "builtin function %qs requires the %qs and %qs options"
-msgstr "Встроенная функция %s требует опцию -mvsx"
+msgstr ""
 
-#: config/rs6000/rs6000.c:15972
-#, fuzzy, gcc-internal-format
-#| msgid "Builtin function %s requires the -mvsx option"
+#: config/rs6000/rs6000.c:16021
+#, gcc-internal-format
 msgid "builtin function %qs requires ISA 3.0 IEEE 128-bit floating point"
-msgstr "Встроенная функция %s требует опцию -mvsx"
+msgstr ""
 
-#: config/rs6000/rs6000.c:15978
-#, fuzzy, gcc-internal-format
-#| msgid "Builtin function %s requires the -mvsx option"
+#: config/rs6000/rs6000.c:16027
+#, gcc-internal-format
 msgid "builtin function %qs requires the %qs (or newer), and %qs or %qs options"
-msgstr "Встроенная функция %s требует опцию -mvsx"
+msgstr ""
 
-#: config/rs6000/rs6000.c:15982
-#, fuzzy, gcc-internal-format
-#| msgid "Builtin function %s is not supported with the current options"
+#: config/rs6000/rs6000.c:16031
+#, gcc-internal-format
 msgid "builtin function %qs is not supported with the current options"
-msgstr "Встроенная функция %s не поддерживается с текущими опциями"
+msgstr ""
 
-#: config/rs6000/rs6000.c:18218
-#, fuzzy, gcc-internal-format
-#| msgid "internal error: builtin function %s had an unexpected return type %s"
+#: config/rs6000/rs6000.c:18290
+#, gcc-internal-format
 msgid "internal error: builtin function %qs had an unexpected return type %qs"
-msgstr "внутренняя ошибка: встроенная функция %s имела неожиданный тип результата %s"
+msgstr ""
 
-#: config/rs6000/rs6000.c:18235
-#, fuzzy, gcc-internal-format
-#| msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
+#: config/rs6000/rs6000.c:18307
+#, gcc-internal-format
 msgid "internal error: builtin function %qs, argument %d had unexpected argument type %qs"
-msgstr "внутренняя ошибка: встроенная функция %s, аргумент %d имел неожиданный тип аргумента %s"
+msgstr ""
 
-#: config/rs6000/rs6000.c:29451
-#, fuzzy, gcc-internal-format
-#| msgid "-fsplit-stack does not support 3 register parameters"
+#: config/rs6000/rs6000.c:29528
+#, gcc-internal-format
 msgid "%qs uses register r29"
-msgstr "-fsplit-stack не поддерживает 3-регистровые параметры"
+msgstr ""
 
-#: config/rs6000/rs6000.c:32748
-#, fuzzy, gcc-internal-format
-#| msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
+#: config/rs6000/rs6000.c:32825
+#, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
-msgstr "Вы не можете брать адрес вложенной функции, если Вы используете опцию -mno-pointers-to-nested-functions."
+msgstr ""
 
-#: config/rs6000/rs6000.c:32842
-#, fuzzy, gcc-internal-format
-#| msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
+#: config/rs6000/rs6000.c:32919
+#, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
-msgstr "использование %<long%> в типах AltiVec некорректно для 64-битного кода без -mvsx"
+msgstr ""
 
-#: config/rs6000/rs6000.c:32850
-#, fuzzy, gcc-internal-format
-#| msgid "use of %<long long%> in AltiVec types is invalid without -mvsx"
+#: config/rs6000/rs6000.c:32927
+#, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
-msgstr "использование %<long long%> в типах AltiVec некорректно без -mvsx"
+msgstr ""
 
-#: config/rs6000/rs6000.c:32853
-#, fuzzy, gcc-internal-format
-#| msgid "use of %<double%> in AltiVec types is invalid without -mvsx"
+#: config/rs6000/rs6000.c:32930
+#, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
-msgstr "использование %<double%> в типах AltiVec некорректно без -mvsx"
+msgstr ""
 
-#: config/rs6000/rs6000.c:36876
-#, fuzzy, gcc-internal-format
-#| msgid "invalid cpu \"%s\" for %s\"%s\"%s"
+#: config/rs6000/rs6000.c:36932
+#, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
-msgstr "некорректный процессор \"%s\" для %s\"%s\"%s"
+msgstr ""
 
-#: config/rs6000/rs6000.c:36879
-#, fuzzy, gcc-internal-format
-#| msgid "%s\"%s\"%s is not allowed"
+#: config/rs6000/rs6000.c:36935
+#, gcc-internal-format
 msgid "%s%qs%s is not allowed"
-msgstr "%s\"%s\"%s не допускается"
+msgstr ""
 
-#: config/rs6000/rs6000.c:36881
-#, fuzzy, gcc-internal-format
-#| msgid "%s\"%s\"%s is invalid"
+#: config/rs6000/rs6000.c:36937
+#, gcc-internal-format
 msgid "%s%qs%s is invalid"
-msgstr "%s\"%s\"%s некорректно"
+msgstr ""
 
-#: config/rs6000/rs6000.c:37416
-#, fuzzy, gcc-internal-format
-#| msgid "%<-mips3d%> requires %<-mpaired-single%>"
+#: config/rs6000/rs6000.c:37472
+#, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
-msgstr "для %<-mips3d%> требуется %<-mpaired-single%>"
+msgstr ""
 
-#: config/rs6000/rs6000.c:37575
+#: config/rs6000/rs6000.c:37631
 #, gcc-internal-format
 msgid "target_clones attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
@@ -37472,58 +32553,49 @@
 #. The macro SUBTARGET_OVERRIDE_OPTIONS is provided for subtargets, to
 #. get control in TARGET_OPTION_OVERRIDE.
 #: config/rs6000/sysv4.h:111
-#, fuzzy, gcc-internal-format
-#| msgid "bad value for -mcall-%s"
+#, gcc-internal-format
 msgid "bad value for %<%s-%s%>"
-msgstr "Некорректное значение ключа -mcall-%s"
+msgstr ""
 
 #: config/rs6000/sysv4.h:127
-#, fuzzy, gcc-internal-format
-#| msgid "bad value for -msdata=%s"
+#, gcc-internal-format
 msgid "bad value for %<%s=%s%>"
-msgstr "Некорректное значение ключа -msdata=%s"
+msgstr ""
 
 #: config/rs6000/sysv4.h:144
-#, fuzzy, gcc-internal-format
-#| msgid "-f%s and -msdata=%s are incompatible"
+#, gcc-internal-format
 msgid "%qs and %<%s=%s%> are incompatible"
-msgstr "ключи -f%s и -msdata=%s несовместимы"
+msgstr ""
 
 #: config/rs6000/sysv4.h:153
-#, fuzzy, gcc-internal-format
-#| msgid "-f%s and -msdata=%s are incompatible"
+#, gcc-internal-format
 msgid "%<-f%s%> and %<%s=%s%> are incompatible"
-msgstr "ключи -f%s и -msdata=%s несовместимы"
+msgstr ""
 
 #: config/rs6000/sysv4.h:162
-#, fuzzy, gcc-internal-format
-#| msgid "-msdata=%s and -mcall-%s are incompatible"
+#, gcc-internal-format
 msgid "%<%s=%s%> and %<%s-%s%> are incompatible"
-msgstr "ключи -msdata=%s и -mcall-%s несовместимы"
+msgstr ""
 
 #: config/rs6000/sysv4.h:171
-#, fuzzy, gcc-internal-format
-#| msgid "-f%s and -msdata=%s are incompatible"
+#, gcc-internal-format
 msgid "%qs and %qs are incompatible"
-msgstr "ключи -f%s и -msdata=%s несовместимы"
+msgstr ""
 
 #: config/rs6000/sysv4.h:178 config/rs6000/sysv4.h:185
-#, fuzzy, gcc-internal-format
-#| msgid "-f%s and -msdata=%s are incompatible"
+#, gcc-internal-format
 msgid "%qs and %<%s-%s%> are incompatible"
-msgstr "ключи -f%s и -msdata=%s несовместимы"
+msgstr ""
 
 #: config/rs6000/sysv4.h:191
-#, fuzzy, gcc-internal-format
-#| msgid "-msecure-plt not supported by your assembler"
+#, gcc-internal-format
 msgid "%qs not supported by your assembler"
-msgstr "ключ -msecure-plt не поддерживается вашим ассемблером"
+msgstr ""
 
 #: config/rs6000/sysv4.h:219
-#, fuzzy, gcc-internal-format
-#| msgid "-m%s not supported in this configuration"
+#, gcc-internal-format
 msgid "%<-m%s%> not supported in this configuration"
-msgstr "-m%s в данной конфигурации не поддерживается"
+msgstr ""
 
 #: config/rx/rx.c:651
 #, gcc-internal-format, gfc-internal-format
@@ -37531,10 +32603,9 @@
 msgstr "неопознанный номер управляющего регистра: %d - используется 'psw'"
 
 #: config/rx/rx.c:1389
-#, fuzzy, gcc-internal-format
-#| msgid "multiple interrupt attributes not allowed"
+#, gcc-internal-format
 msgid "multiple fast interrupt routines seen: %qE and %qE"
-msgstr "несколько атрибутов прерываний не допускаются"
+msgstr "выявлено несколько быстрых программ прерываний: %qE и %qE"
 
 #: config/rx/rx.c:2596
 #, gcc-internal-format, gfc-internal-format
@@ -37549,7 +32620,7 @@
 #: config/rx/rx.c:2645
 #, gcc-internal-format
 msgid "-mno-allow-string-insns forbids the generation of the RMPA instruction"
-msgstr ""
+msgstr "-mno-allow-string-insns запрещает генерацию RMPA инструкции"
 
 #: config/rx/rx.c:2792
 #, gcc-internal-format
@@ -37559,106 +32630,97 @@
 #: config/s390/s390-c.c:472
 #, gcc-internal-format
 msgid "builtin vec_step can only be used on vector types."
-msgstr ""
+msgstr "встроенная функция vec_step может использоваться только для векторных типов"
 
 #: config/s390/s390-c.c:687 config/s390/s390.c:887
 #, gcc-internal-format
 msgid "constant value required for builtin %qF argument %d"
-msgstr ""
+msgstr "константное значение требуется для встроенной функции %qF (аргумент %d)"
 
 #: config/s390/s390-c.c:702
 #, gcc-internal-format
 msgid "valid values for builtin %qF argument %d are 64, 128, 256, 512, 1024, 2048, and 4096"
-msgstr ""
+msgstr "допустимые значения для встроенной функции %qF (аргумент %d): 64, 128, 256, 512, 1024, 2048 и 4096"
 
 #: config/s390/s390-c.c:873
 #, gcc-internal-format
 msgid "builtin %qF is for GCC internal use only."
-msgstr ""
+msgstr "встроенная функция %qF предназначена только для внутреннего употребления в GCC"
 
 #: config/s390/s390-c.c:881
-#, fuzzy, gcc-internal-format
-#| msgid "%qE is deprecated"
+#, gcc-internal-format
 msgid "builtin %qF is deprecated."
-msgstr "имя %qE будет исключено в будущих версиях"
+msgstr "внутренняя функция %qF устарела."
 
 #: config/s390/s390-c.c:885
-#, fuzzy, gcc-internal-format
-#| msgid "--resource requires -o"
+#, gcc-internal-format
 msgid "%qF requires -mvx"
-msgstr "ключ --resource требует задания -o"
+msgstr "%qF требует -mvx"
 
 #: config/s390/s390-c.c:891
 #, gcc-internal-format
 msgid "%qF requires z14 or higher"
-msgstr ""
+msgstr "%qF требует z14 или выше"
 
 #: config/s390/s390-c.c:905
 #, gcc-internal-format
 msgid "mismatch in number of arguments for builtin %qF. Expected: %d got %d"
-msgstr ""
+msgstr "несоответствие в числе аргументов для встроенной функции %qF. Ожидалось %d, получено %d"
 
 #: config/s390/s390-c.c:954
-#, fuzzy, gcc-internal-format
-#| msgid "invalid parameter combination for AltiVec intrinsic"
+#, gcc-internal-format
 msgid "invalid parameter combination for intrinsic %qs"
-msgstr "недопустимая комбинация параметров для AltiVec встроенной функции"
+msgstr "недопустимая комбинация параметров для встроенной функции %qs"
 
 #: config/s390/s390-c.c:960
-#, fuzzy, gcc-internal-format
-#| msgid "ambiguous overload for %qs in %<%s %E%>"
+#, gcc-internal-format
 msgid "ambiguous overload for intrinsic %qs"
-msgstr "неоднозначная перегрузка для %qs в %<%s %E%>"
+msgstr "неоднозначная перегрузка для встроенной функции %qs"
 
 #: config/s390/s390-c.c:968
 #, gcc-internal-format
 msgid "%qs matching variant requires z14 or higher"
-msgstr ""
+msgstr "%qs соответствующий вариант требует z14 или выше"
 
 #: config/s390/s390-c.c:974
-#, fuzzy, gcc-internal-format
-#| msgid "%qE is deprecated"
+#, gcc-internal-format
 msgid "%qs matching variant is deprecated."
-msgstr "имя %qE будет исключено в будущих версиях"
+msgstr "%qs соответствующий вариант устарел."
 
 #: config/s390/s390-c.c:1014
-#, fuzzy, gcc-internal-format
-#| msgid "constant argument out of range for %qs"
+#, gcc-internal-format
 msgid "constant argument %d for builtin %qF is out of range for target type"
-msgstr "константный аргумент для %qs вне диапазона"
+msgstr "константный аргумент %d для внутренней функции %qF вне диапазона для целевого типа"
 
 #: config/s390/s390.c:743
-#, fuzzy, gcc-internal-format
-#| msgid "constant argument out of range for %qs"
+#, gcc-internal-format
 msgid "constant argument %d for builtin %qF is out of range (0.."
-msgstr "константный аргумент для %qs вне диапазона"
+msgstr "константный аргумент %d для внутренней функции %qF вне диапазона (0.."
 
 #: config/s390/s390.c:760
-#, fuzzy, gcc-internal-format
-#| msgid "constant argument out of range for %qs"
+#, gcc-internal-format
 msgid "constant argument %d for builtin %qF is out of range ("
-msgstr "константный аргумент для %qs вне диапазона"
+msgstr "константный аргумент %d для внутренней функции %qF вне диапазона ("
 
 #: config/s390/s390.c:811
 #, gcc-internal-format
 msgid "builtin %qF is not supported without -mhtm (default with -march=zEC12 and higher)."
-msgstr ""
+msgstr "встроенная функция %qF не поддерживается без -mhtm (по умолчанию с -march=zEC12 и выше)."
 
 #: config/s390/s390.c:817
 #, gcc-internal-format
 msgid "builtin %qF requires -mvx (default with -march=z13 and higher)."
-msgstr ""
+msgstr "встроенная функция %qF требует -mvx (по умолчанию с -march=z13 и выше)."
 
 #: config/s390/s390.c:824
 #, gcc-internal-format
 msgid "Builtin %qF requires z14 or higher."
-msgstr ""
+msgstr "Встроенная функция %qF требует z14 или выше."
 
 #: config/s390/s390.c:843
-#, fuzzy, gcc-internal-format
-#| msgid "<unresolved overloaded function type>"
+#, gcc-internal-format
 msgid "unresolved overloaded builtin"
-msgstr "<неразрешенный тип перегруженной функции>"
+msgstr "неразрешенная перегрузка внутренней функции"
 
 #: config/s390/s390.c:850 config/tilegx/tilegx.c:3547
 #: config/tilepro/tilepro.c:3111
@@ -37667,10 +32729,9 @@
 msgstr "некорректный встроенный icode"
 
 #: config/s390/s390.c:978
-#, fuzzy, gcc-internal-format
-#| msgid "invalid argument to built-in function"
+#, gcc-internal-format
 msgid "invalid argument %d for builtin %qF"
-msgstr "некорректный аргумент встроенной функции"
+msgstr "некорректный аргумент %d для встроенной функции %qF"
 
 #: config/s390/s390.c:1079
 #, gcc-internal-format
@@ -37679,10 +32740,9 @@
 
 #
 #: config/s390/s390.c:1169
-#, fuzzy, gcc-internal-format
-#| msgid "argument of %qE attribute is not \"ilink1\" or \"ilink2\""
+#, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-extern)"
-msgstr "аргумент атрибута %qE не есть \"ilink1\" или \"ilink2\""
+msgstr ""
 
 #: config/s390/s390.c:10171
 #, gcc-internal-format
@@ -37692,12 +32752,12 @@
 #: config/s390/s390.c:11539
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
-msgstr "размер кадра функции %qs равен %wd байт, что превышает предоставленный пользователем лимит стека в %d байт.  Добавлен безусловный trap."
+msgstr ""
 
 #: config/s390/s390.c:11555
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
-msgstr "размер кадра функции %qs равен %wd байт, что больше половины размера стека. Динамическая проверка не будет надежной. Для этой функции проверка не сгенерирована."
+msgstr ""
 
 #: config/s390/s390.c:11583
 #, gcc-internal-format
@@ -37712,19 +32772,17 @@
 #: config/s390/s390.c:11965
 #, gcc-internal-format
 msgid "CPUs older than z900 are not supported for -fsplit-stack"
-msgstr ""
+msgstr "CPUs старше чем z900 не поддерживаются для -fsplit-stack"
 
 #: config/s390/s390.c:15361
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "%<mwords-little-endian%> is deprecated and will be removed in a future release"
+#, gcc-internal-format, gfc-internal-format
 msgid "%sarch=%s%s is deprecated and will be removed in future releases; use at least %sarch=z900%s"
-msgstr "%<mwords-little-endian%> не рекомендуется и не будет поддерживаться в будущих версиях"
+msgstr "%sarch=%s%s устарело и будет удалено в будущих версиях; используйте по крайней мере %sarch=z900%s"
 
 #: config/s390/s390.c:15373
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "%<mwords-little-endian%> is deprecated and will be removed in a future release"
+#, gcc-internal-format, gfc-internal-format
 msgid "%stune=%s%s is deprecated and will be removed in future releases; use at least %stune=z900%s"
-msgstr "%<mwords-little-endian%> не рекомендуется и не будет поддерживаться в будущих версиях"
+msgstr "%stune=%s%s устарело и будет удалено в будущих версиях; используйте по крайней мере %stune=z900%s"
 
 #: config/s390/s390.c:15385
 #, gcc-internal-format, gfc-internal-format
@@ -37752,15 +32810,14 @@
 msgstr ""
 
 #: config/s390/s390.c:15441
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "hardware decimal floating point instructions not available on %s"
+#, gcc-internal-format, gfc-internal-format
 msgid "hardware vector support not available on %s"
-msgstr "аппаратные инструкции десятичной плавающей точки отсутствуют на %s"
+msgstr "аппаратная поддержка векторов отсутствует на %s"
 
 #: config/s390/s390.c:15444
 #, gcc-internal-format
 msgid "hardware vector support not available with -msoft-float"
-msgstr ""
+msgstr "аппаратная поддержка векторов недоступна с -msoft-float"
 
 #: config/s390/s390.c:15472
 #, gcc-internal-format, gfc-internal-format
@@ -37799,16 +32856,14 @@
 
 #. argument is not a plain number
 #: config/s390/s390.c:15600
-#, fuzzy, gcc-internal-format
-#| msgid "argument to %qs should be a non-negative integer"
+#, gcc-internal-format
 msgid "arguments to %qs should be non-negative integers"
-msgstr "аргумент %qs должен быть неотрицательным целым числом"
+msgstr "аргументы для %qs должны быть неотрицательными целыми числами"
 
 #: config/s390/s390.c:15607
-#, fuzzy, gcc-internal-format
-#| msgid "argument to %qE attribute larger than %d"
+#, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
-msgstr "аргумент для %qE атрибута больше чем %d"
+msgstr ""
 
 #: config/s390/s390.c:15637
 #, gcc-internal-format
@@ -37817,10 +32872,9 @@
 
 #. Value is not allowed for the target attribute.
 #: config/s390/s390.c:15818
-#, fuzzy, gcc-internal-format
-#| msgid "%<__int128%> is not supported by this target"
+#, gcc-internal-format
 msgid "value %qs is not supported by attribute %<target%>"
-msgstr "%<__int128%> не поддерживается этой целевой платформой"
+msgstr "значение %qs не поддерживается атрибутом %<target%>"
 
 #: config/sh/sh.c:935
 #, gcc-internal-format
@@ -37890,10 +32944,9 @@
 msgstr "некорректное значение (%s) для ключа -mcmodel"
 
 #: config/sparc/sparc.c:1793
-#, fuzzy, gcc-internal-format
-#| msgid "-mcmodel= is not supported on 32 bit systems"
+#, gcc-internal-format
 msgid "-mcmodel= is not supported on 32-bit systems"
-msgstr "ключ -mcmodel= на 32-битных системах не поддерживается"
+msgstr "-mcmodel= не поддерживается на 32-битных системах"
 
 #: config/sparc/sparc.c:1800
 #, gcc-internal-format
@@ -37943,7 +32996,7 @@
 #: config/spu/spu.c:6360
 #, gcc-internal-format
 msgid "%s expects an integer literal in the range [%d, %d]. (%wd)"
-msgstr "%s ожидает целый литерал в диапазоне [%d, %d]. (%wd)"
+msgstr ""
 
 #: config/spu/spu.c:6389
 #, gcc-internal-format, gfc-internal-format
@@ -38101,10 +33154,9 @@
 msgstr "готовится слишком большое пространство стека: %d"
 
 #: config/visium/visium.c:741
-#, fuzzy, gcc-internal-format
-#| msgid "attribute interrupt_handler is not compatible with -m5-compact"
+#, gcc-internal-format
 msgid "an interrupt handler cannot be compiled with -muser-mode"
-msgstr "атрибут interrupt_handler несовместим с -m5-compact"
+msgstr "обработчик прерываний не может компилироваться с -muser-mode"
 
 #: config/vms/vms-c.c:44
 #, gcc-internal-format
@@ -38172,16 +33224,14 @@
 msgstr "некорректный синтаксис директивы '#pragma __extern_prefix', игнорируется"
 
 #: config/vms/vms-c.c:312 config/vms/vms-c.c:332
-#, fuzzy, gcc-internal-format
-#| msgid "malformed %<#pragma %s%>, ignored"
+#, gcc-internal-format
 msgid "malformed %<#pragma %s%>, ignoring"
-msgstr "некорректный синтаксис %<#pragma %s%>, директива проигнорирована"
+msgstr "некорректный синтаксис %<#pragma %s%>, игнорируется"
 
 #: config/vms/vms-c.c:328
-#, fuzzy, gcc-internal-format
-#| msgid "invalid constant in %<#pragma pack%> - ignored"
+#, gcc-internal-format
 msgid "invalid constant in %<#pragma %s%>"
-msgstr "некорректная константа в %<#pragma pack%> - директива проигнорирована"
+msgstr "некорректная константа в %<#pragma %s%>"
 
 #: config/xtensa/xtensa.c:2221
 #, gcc-internal-format
@@ -38216,76 +33266,73 @@
 #: ada/gcc-interface/misc.c:278
 #, gcc-internal-format
 msgid "STABS debugging information for Ada is obsolete and not supported anymore"
-msgstr ""
+msgstr "STABS отладочная информация для Ada устарела и больше не поддерживается"
 
 #: ada/gcc-interface/trans.c:1535
 #, gcc-internal-format
 msgid "subprogram %q+F not marked Inline_Always"
-msgstr ""
+msgstr "подпрограмма %q+F не помечена Inline_Always"
 
 #: ada/gcc-interface/trans.c:1536 ada/gcc-interface/trans.c:1542
-#, fuzzy, gcc-internal-format
-#| msgid "template parameters cannot be friends"
+#, gcc-internal-format
 msgid "parent subprogram cannot be inlined"
-msgstr "параметры шаблона не могут быть friend"
+msgstr "подстановка родительской подпрограммы невозможна"
 
 #: ada/gcc-interface/trans.c:1540
 #, gcc-internal-format
 msgid "subprogram %q+F not marked Inline"
-msgstr ""
+msgstr "подпрограмма %q+F не помечена Inline"
 
-#: ada/gcc-interface/trans.c:6404
+#: ada/gcc-interface/trans.c:6401
 #, gcc-internal-format
 msgid "out-of-bounds access may be optimized away"
-msgstr ""
+msgstr "доступ вне границ может быть ликвидирован оптимизацией"
 
-#: ada/gcc-interface/trans.c:6406
+#: ada/gcc-interface/trans.c:6403
 #, gcc-internal-format
 msgid "containing loop"
-msgstr ""
+msgstr "вложенный цикл"
 
-#: ada/gcc-interface/utils.c:3887
+#: ada/gcc-interface/utils.c:3890
 #, gcc-internal-format
 msgid "invalid element type for attribute %qs"
 msgstr "некорректный тип элемента для атрибута %qs"
 
-#: ada/gcc-interface/utils.c:3911
-#, fuzzy, gcc-internal-format
-#| msgid "number of components of the vector not a power of two"
+#: ada/gcc-interface/utils.c:3914
+#, gcc-internal-format
 msgid "number of components of vector not a power of two"
-msgstr "число компонент вектора не является степенью двойки"
+msgstr "число компонент вектора не есть степень двух"
 
-#: ada/gcc-interface/utils.c:6037 ada/gcc-interface/utils.c:6215
-#: ada/gcc-interface/utils.c:6322
+#: ada/gcc-interface/utils.c:6043 ada/gcc-interface/utils.c:6220
+#: ada/gcc-interface/utils.c:6327
 #, gcc-internal-format
 msgid "%qs attribute ignored"
 msgstr "атрибут %qs проигнорирован"
 
-#: ada/gcc-interface/utils.c:6158
+#: ada/gcc-interface/utils.c:6164
 #, gcc-internal-format
 msgid "%qs attribute requires prototypes with named arguments"
 msgstr "атрибут %qs требует прототипы с именованными аргументами"
 
-#: ada/gcc-interface/utils.c:6167
+#: ada/gcc-interface/utils.c:6173
 #, gcc-internal-format
 msgid "%qs attribute only applies to variadic functions"
 msgstr "атрибут %qs применим только к вариантным функциям"
 
-#: ada/gcc-interface/utils.c:6282
+#: ada/gcc-interface/utils.c:6287
 #, gcc-internal-format
 msgid "%qE attribute has no effect"
 msgstr "атрибут %qE не действует"
 
-#: ada/gcc-interface/utils.c:6406
+#: ada/gcc-interface/utils.c:6411
 #, gcc-internal-format
 msgid "attribute %qs applies to array types only"
 msgstr "атрибут %qs применим только к массивным типам"
 
 #: brig/brig-lang.c:204
-#, fuzzy, gcc-internal-format
-#| msgid "could not write to response file %s"
+#, gcc-internal-format
 msgid "could not read the BRIG file"
-msgstr "не удалось записать файл отзыва %s"
+msgstr "не удалось прочитать BRIG файл"
 
 #. Except for passing an argument to an unprototyped function,
 #. this is a constraint violation.  When passing an argument to
@@ -38292,7 +33339,7 @@
 #. an unprototyped function, it is compile-time undefined;
 #. making it a constraint in that case was rejected in
 #. DR#252.
-#: c/c-convert.c:101 c/c-typeck.c:2175 c/c-typeck.c:6507 c/c-typeck.c:12138
+#: c/c-convert.c:101 c/c-typeck.c:2175 c/c-typeck.c:6512 c/c-typeck.c:12143
 #: cp/typeck.c:2027 cp/typeck.c:7977 cp/typeck.c:8742
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
@@ -38353,7 +33400,7 @@
 msgid "type of array %q+D completed incompatibly with implicit initialization"
 msgstr "тип массива %q+D завершен несовместимым с неявной инициализацией образом"
 
-#: c/c-decl.c:1567 c/c-decl.c:6701 c/c-decl.c:7574 c/c-decl.c:8381
+#: c/c-decl.c:1567 c/c-decl.c:6721 c/c-decl.c:7594 c/c-decl.c:8401
 #, gcc-internal-format
 msgid "originally defined here"
 msgstr "исходное определение находится здесь"
@@ -38541,10 +33588,9 @@
 msgstr "декларация %q+D перекрывает предшествующую декларацию не переменной"
 
 #: c/c-decl.c:2793
-#, fuzzy, gcc-internal-format
-#| msgid "declaration of %q+D shadows a parameter"
+#, gcc-internal-format
 msgid "declaration of %qD shadows a parameter"
-msgstr "декларация %q+D перекрывает параметр"
+msgstr "декларация %qD перекрывает параметр"
 
 #: c/c-decl.c:2806 cp/name-lookup.c:2806
 #, gcc-internal-format
@@ -38567,10 +33613,9 @@
 msgstr "вложенная extern-декларация %qD"
 
 #: c/c-decl.c:3126 c/c-decl.c:3140
-#, fuzzy, gcc-internal-format
-#| msgid "implicit declaration of function %qE"
+#, gcc-internal-format
 msgid "implicit declaration of function %qE; did you mean %qs?"
-msgstr "неявная декларация функции %qE"
+msgstr "неявная декларация функции %qE; имелось в виду %qs?"
 
 #: c/c-decl.c:3132 c/c-decl.c:3145
 #, gcc-internal-format
@@ -38583,10 +33628,9 @@
 msgstr "несовместимая неявная декларация внутренней функции %qD"
 
 #: c/c-decl.c:3417
-#, fuzzy, gcc-internal-format
-#| msgid "invalid redeclaration of %q+D"
+#, gcc-internal-format
 msgid "include %qs or provide a declaration of %qD"
-msgstr "некорректная декларация %q+D"
+msgstr "включите %qs или предоставьте декларацию для %qD"
 
 #: c/c-decl.c:3427
 #, gcc-internal-format
@@ -38594,10 +33638,9 @@
 msgstr "несовместимая неявная декларация функции %qD"
 
 #: c/c-decl.c:3487
-#, fuzzy, gcc-internal-format
-#| msgid "%qE undeclared here (not in a function)"
+#, gcc-internal-format
 msgid "%qE undeclared here (not in a function); did you mean %qs?"
-msgstr "%qE не описан здесь (не в функции)"
+msgstr "%qE не описан здесь (не в функции); имелось в виду %qs?"
 
 #: c/c-decl.c:3492
 #, gcc-internal-format
@@ -38605,10 +33648,9 @@
 msgstr "%qE не описан здесь (не в функции)"
 
 #: c/c-decl.c:3505
-#, fuzzy, gcc-internal-format
-#| msgid "%qE undeclared (first use in this function)"
+#, gcc-internal-format
 msgid "%qE undeclared (first use in this function); did you mean %qs?"
-msgstr "%qE не описан (первое использование в этой функции)"
+msgstr "%qE не описан (первое использование в этой функции); имелось в виду %qs?"
 
 #: c/c-decl.c:3510
 #, gcc-internal-format
@@ -38731,10 +33773,9 @@
 msgstr "бесполезный спецификатор класса хранения в пустой декларации"
 
 #: c/c-decl.c:4440
-#, fuzzy, gcc-internal-format
-#| msgid "useless %<_Alignas%> in empty declaration"
+#, gcc-internal-format
 msgid "useless %qs in empty declaration"
-msgstr "бесполезное %<_Alignas%> в пустой декларации"
+msgstr "бесполезное %qs в пустой декларации"
 
 #: c/c-decl.c:4453
 #, gcc-internal-format
@@ -38764,16 +33805,11 @@
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.c:4548 c/c-decl.c:7147
+#: c/c-decl.c:4548 c/c-decl.c:7167
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr "%<[*]%> не допускается нигде кроме прототипа функции"
 
-#: c/c-decl.c:4635 cp/decl2.c:1520
-#, gcc-internal-format
-msgid "%q+D in declare target directive does not have mappable type"
-msgstr ""
-
 #: c/c-decl.c:4693
 #, gcc-internal-format
 msgid "%q+D is usually a function"
@@ -38799,7 +33835,7 @@
 #. of VLAs themselves count as VLAs, it does not make
 #. sense to permit them to be initialized given that
 #. ordinary VLAs may not be initialized.
-#: c/c-decl.c:4732 c/c-decl.c:4747 c/c-typeck.c:7630
+#: c/c-decl.c:4732 c/c-decl.c:4747 c/c-typeck.c:7635
 #, gcc-internal-format
 msgid "variable-sized object may not be initialized"
 msgstr "объект переменного размера нельзя инициализировать"
@@ -38859,919 +33895,909 @@
 msgid "uninitialized const %qD is invalid in C++"
 msgstr "неинициализированная константа %qD не допускается в C++"
 
-#: c/c-decl.c:5268
+#: c/c-decl.c:5224 cp/decl.c:7318
 #, gcc-internal-format
+msgid "%q+D in declare target directive does not have mappable type"
+msgstr "%q+D в declare target директиве не имеет отображаемого типа"
+
+#: c/c-decl.c:5288
+#, gcc-internal-format
 msgid "ISO C forbids forward parameter declarations"
 msgstr "в ISO C упреждающие декларации параметров запрещены"
 
-#: c/c-decl.c:5371
+#: c/c-decl.c:5391
 #, gcc-internal-format
 msgid "defining a type in a compound literal is invalid in C++"
 msgstr "определение типа в составном литерале не допускается в C++"
 
-#: c/c-decl.c:5425 c/c-decl.c:5440
+#: c/c-decl.c:5445 c/c-decl.c:5460
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant"
 msgstr "размер битового поля %qs не является целочисленной константой"
 
-#: c/c-decl.c:5435
+#: c/c-decl.c:5455
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant expression"
 msgstr "размер битового поля %qs не является целочисленным константным выражением"
 
-#: c/c-decl.c:5446
+#: c/c-decl.c:5466
 #, gcc-internal-format
 msgid "negative width in bit-field %qs"
 msgstr "битовое поле %qs имеет отрицательный размер"
 
-#: c/c-decl.c:5451
+#: c/c-decl.c:5471
 #, gcc-internal-format
 msgid "zero width for bit-field %qs"
 msgstr "битовое поле %qs имеет нулевой размер"
 
-#: c/c-decl.c:5461
+#: c/c-decl.c:5481
 #, gcc-internal-format
 msgid "bit-field %qs has invalid type"
 msgstr "неверный тип битового поля %qs"
 
-#: c/c-decl.c:5467
-#, fuzzy, gcc-internal-format
-#| msgid "cannot declare bit-field %qD with function type"
+#: c/c-decl.c:5487
+#, gcc-internal-format
 msgid "cannot declare bit-field %qs with %<warn_if_not_aligned%> type"
-msgstr "недопустимая декларация битового поля %qD с типом функции"
+msgstr ""
 
-#: c/c-decl.c:5478
+#: c/c-decl.c:5498
 #, gcc-internal-format
 msgid "type of bit-field %qs is a GCC extension"
 msgstr "тип для битового поля %qs является расширением GCC"
 
-#: c/c-decl.c:5484
+#: c/c-decl.c:5504
 #, gcc-internal-format
 msgid "width of %qs exceeds its type"
 msgstr "размер поля %qs превышает размер указанного типа"
 
-#: c/c-decl.c:5497
+#: c/c-decl.c:5517
 #, gcc-internal-format
 msgid "%qs is narrower than values of its type"
 msgstr "ширина поля %qs не достаточна для значений указанного типа"
 
-#: c/c-decl.c:5512
+#: c/c-decl.c:5532
 #, gcc-internal-format
 msgid "ISO C90 forbids array %qE whose size can%'t be evaluated"
 msgstr "ISO C90 не поддерживает массив %qE, размер которого нельзя определить"
 
-#: c/c-decl.c:5515
+#: c/c-decl.c:5535
 #, gcc-internal-format
 msgid "ISO C90 forbids array whose size can%'t be evaluated"
 msgstr "ISO C90 не поддерживает массив, размер которого нельзя определить"
 
-#: c/c-decl.c:5522
+#: c/c-decl.c:5542
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array %qE"
 msgstr "ISO C90 не поддерживает массив %qE переменного размера"
 
-#: c/c-decl.c:5524
+#: c/c-decl.c:5544
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array"
 msgstr "ISO C90 не поддерживает массив переменного размера"
 
-#: c/c-decl.c:5733 c/c-decl.c:6107 c/c-decl.c:6117
+#: c/c-decl.c:5753 c/c-decl.c:6127 c/c-decl.c:6137
 #, gcc-internal-format
 msgid "variably modified %qE at file scope"
 msgstr "переменно модифицированный %qE на уровне файла"
 
-#: c/c-decl.c:5735
+#: c/c-decl.c:5755
 #, gcc-internal-format
 msgid "variably modified field at file scope"
 msgstr "переменно модифицированное поле на уровне файла"
 
-#: c/c-decl.c:5755
+#: c/c-decl.c:5775
 #, gcc-internal-format
 msgid "type defaults to %<int%> in declaration of %qE"
 msgstr "в декларации %qE по умолчанию установлен тип %<int%>"
 
-#: c/c-decl.c:5759
+#: c/c-decl.c:5779
 #, gcc-internal-format
 msgid "type defaults to %<int%> in type name"
 msgstr "в имени типа по умолчанию установлен тип %<int%>"
 
-#: c/c-decl.c:5791
+#: c/c-decl.c:5811
 #, gcc-internal-format
 msgid "duplicate %<const%>"
 msgstr "повторное употребление %<const%>"
 
-#: c/c-decl.c:5793
+#: c/c-decl.c:5813
 #, gcc-internal-format
 msgid "duplicate %<restrict%>"
 msgstr "повторное употребление %<restrict%>"
 
-#: c/c-decl.c:5795
+#: c/c-decl.c:5815
 #, gcc-internal-format
 msgid "duplicate %<volatile%>"
 msgstr "повторное употребление %<volatile%>"
 
-#: c/c-decl.c:5797
-#, fuzzy, gcc-internal-format
-#| msgid "duplicate %<restrict%>"
+#: c/c-decl.c:5817
+#, gcc-internal-format
 msgid "duplicate %<_Atomic%>"
-msgstr "повторное употребление %<restrict%>"
+msgstr "повторный %<_Atomic%>"
 
-#: c/c-decl.c:5800
+#: c/c-decl.c:5820
 #, gcc-internal-format, gfc-internal-format
 msgid "conflicting named address spaces (%s vs %s)"
 msgstr "конфликтующие именованные адресные пространства (%s и %s)"
 
-#: c/c-decl.c:5823 c/c-parser.c:2821
+#: c/c-decl.c:5843 c/c-parser.c:2821
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified array type"
-msgstr ""
+msgstr "%<_Atomic%>-квалифицированный массивный тип"
 
-#: c/c-decl.c:5837
+#: c/c-decl.c:5857
 #, gcc-internal-format
 msgid "function definition declared %<auto%>"
 msgstr "определение функции с классом хранения %<auto%>"
 
-#: c/c-decl.c:5839
+#: c/c-decl.c:5859
 #, gcc-internal-format
 msgid "function definition declared %<register%>"
 msgstr "определение функции с классом хранения %<register%>"
 
-#: c/c-decl.c:5841
+#: c/c-decl.c:5861
 #, gcc-internal-format
 msgid "function definition declared %<typedef%>"
 msgstr "определение функции с классом хранения %<typedef%>"
 
-#: c/c-decl.c:5843
-#, fuzzy, gcc-internal-format
-#| msgid "function definition declared %<auto%>"
+#: c/c-decl.c:5863
+#, gcc-internal-format
 msgid "function definition declared %qs"
-msgstr "определение функции с классом хранения %<auto%>"
+msgstr "определение функции декларировано %qs"
 
-#: c/c-decl.c:5861
+#: c/c-decl.c:5881
 #, gcc-internal-format
 msgid "storage class specified for structure field %qE"
 msgstr "класс хранения в декларации поля структуры %qE"
 
-#: c/c-decl.c:5864
+#: c/c-decl.c:5884
 #, gcc-internal-format
 msgid "storage class specified for structure field"
 msgstr "класс хранения в декларации поля структуры"
 
-#: c/c-decl.c:5868
+#: c/c-decl.c:5888
 #, gcc-internal-format
 msgid "storage class specified for parameter %qE"
 msgstr "класс хранения в декларации параметра %qE"
 
-#: c/c-decl.c:5871
+#: c/c-decl.c:5891
 #, gcc-internal-format
 msgid "storage class specified for unnamed parameter"
 msgstr "класс хранения задан для неименованного параметра"
 
-#: c/c-decl.c:5874 cp/decl.c:10935
+#: c/c-decl.c:5894 cp/decl.c:10959
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "класс хранения задан для имени типа"
 
-#: c/c-decl.c:5891
+#: c/c-decl.c:5911
 #, gcc-internal-format
 msgid "%qE initialized and declared %<extern%>"
 msgstr "%<extern%> декларация %qE с инициализацией"
 
-#: c/c-decl.c:5895
+#: c/c-decl.c:5915
 #, gcc-internal-format
 msgid "%qE has both %<extern%> and initializer"
 msgstr "для %qE задан спецификатор %<extern%> и инициализатор"
 
-#: c/c-decl.c:5900
+#: c/c-decl.c:5920
 #, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<auto%>"
 msgstr "в декларации %qE на уровне файла задан класс хранения %<auto%>"
 
-#: c/c-decl.c:5904
+#: c/c-decl.c:5924
 #, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<register%>"
 msgstr "в декларации %qE на уровне файла задан класс хранения %<register%>"
 
-#: c/c-decl.c:5909
+#: c/c-decl.c:5929
 #, gcc-internal-format
 msgid "nested function %qE declared %<extern%>"
 msgstr "вложенная функция %qE объявлена %<extern%>"
 
-#: c/c-decl.c:5912
-#, fuzzy, gcc-internal-format
-#| msgid "function-scope %qE implicitly auto and declared %<__thread%>"
+#: c/c-decl.c:5932
+#, gcc-internal-format
 msgid "function-scope %qE implicitly auto and declared %qs"
-msgstr "имя %qE на уровне функции неявно имеет класс auto и объявлено %<__thread%>"
+msgstr "%qE из контекста функции неявно auto и декларировано %qs"
 
 #. Only the innermost declarator (making a parameter be of
 #. array type which is converted to pointer type)
 #. may have static or type qualifiers.
-#: c/c-decl.c:5959 c/c-decl.c:6328
+#: c/c-decl.c:5979 c/c-decl.c:6348
 #, gcc-internal-format
 msgid "static or type qualifiers in non-parameter array declarator"
 msgstr "static или квалификаторы типа в деклараторе массива, не являющегося "
 
-#: c/c-decl.c:6007
+#: c/c-decl.c:6027
 #, gcc-internal-format
 msgid "declaration of %qE as array of voids"
 msgstr "имя %qE описано как массив элементов типа void"
 
-#: c/c-decl.c:6009
+#: c/c-decl.c:6029
 #, gcc-internal-format
 msgid "declaration of type name as array of voids"
 msgstr "имя типа описано как массив элементов типа void"
 
-#: c/c-decl.c:6016
+#: c/c-decl.c:6036
 #, gcc-internal-format
 msgid "declaration of %qE as array of functions"
 msgstr "имя %qE описано как массив функций"
 
-#: c/c-decl.c:6019
+#: c/c-decl.c:6039
 #, gcc-internal-format
 msgid "declaration of type name as array of functions"
 msgstr "имя типа описано как массив функций"
 
-#: c/c-decl.c:6027 c/c-decl.c:8085
+#: c/c-decl.c:6047 c/c-decl.c:8105
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr "неверное употребление структуры с регулируемым элементом-массивом"
 
-#: c/c-decl.c:6053
+#: c/c-decl.c:6073
 #, gcc-internal-format
 msgid "size of array %qE has non-integer type"
 msgstr "размер массива %qE имеет не целочисленный тип"
 
-#: c/c-decl.c:6057
+#: c/c-decl.c:6077
 #, gcc-internal-format
 msgid "size of unnamed array has non-integer type"
 msgstr "размер безымянного массива имеет не целочисленный тип"
 
-#: c/c-decl.c:6064
-#, fuzzy, gcc-internal-format
-#| msgid "size of array %qE has non-integer type"
+#: c/c-decl.c:6084
+#, gcc-internal-format
 msgid "size of array %qE has incomplete type"
-msgstr "размер массива %qE имеет не целочисленный тип"
+msgstr "размер массива %qE имеет неполный тип"
 
-#: c/c-decl.c:6067
-#, fuzzy, gcc-internal-format
-#| msgid "size of unnamed array has non-integer type"
+#: c/c-decl.c:6087
+#, gcc-internal-format
 msgid "size of unnamed array has incomplete type"
-msgstr "размер безымянного массива имеет не целочисленный тип"
+msgstr "размер безымянного массива имеет неполный тип"
 
-#: c/c-decl.c:6078
+#: c/c-decl.c:6098
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array %qE"
 msgstr "в ISO C массив %qE нулевой длины недопустим"
 
-#: c/c-decl.c:6081
+#: c/c-decl.c:6101
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array"
 msgstr "ISO C запрещает массивы нулевого размера"
 
-#: c/c-decl.c:6090
+#: c/c-decl.c:6110
 #, gcc-internal-format
 msgid "size of array %qE is negative"
 msgstr "размер массива %qE отрицательный"
 
-#: c/c-decl.c:6092
+#: c/c-decl.c:6112
 #, gcc-internal-format
 msgid "size of unnamed array is negative"
 msgstr "размер безымянного массива отрицательный"
 
-#: c/c-decl.c:6216 c/c-decl.c:6871
+#: c/c-decl.c:6236 c/c-decl.c:6891
 #, gcc-internal-format
 msgid "ISO C90 does not support flexible array members"
 msgstr "ISO C90 не поддерживает регулируемые элементы-массивы"
 
 #. C99 6.7.5.2p4
-#: c/c-decl.c:6238
+#: c/c-decl.c:6258
 #, gcc-internal-format
 msgid "%<[*]%> not in a declaration"
 msgstr "%<[*]%> не является декларацией"
 
-#: c/c-decl.c:6251
-#, fuzzy, gcc-internal-format
-#| msgid "array type has incomplete element type"
+#: c/c-decl.c:6271
+#, gcc-internal-format
 msgid "array type has incomplete element type %qT"
-msgstr "тип элементов массива неполный"
+msgstr "тип массива имеет неполный тип элементов %qT"
 
-#: c/c-decl.c:6257
-#, fuzzy, gcc-internal-format
-#| msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
+#: c/c-decl.c:6277
+#, gcc-internal-format
 msgid "declaration of %qE as multidimensional array must have bounds for all dimensions except the first"
-msgstr "декларация многомерного массива %qD должна определять границы для всех размерностей, кроме первой"
+msgstr "декларация %qE как многомерного массива должна иметь границы для всех размерностей, кроме первой"
 
-#: c/c-decl.c:6261
-#, fuzzy, gcc-internal-format
-#| msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
+#: c/c-decl.c:6281
+#, gcc-internal-format
 msgid "declaration of multidimensional array must have bounds for all dimensions except the first"
-msgstr "декларация многомерного массива %qD должна определять границы для всех размерностей, кроме первой"
+msgstr "декларация многомерного массива должна иметь границы для всех размерностей, кроме первой"
 
-#: c/c-decl.c:6364
+#: c/c-decl.c:6384
 #, gcc-internal-format
 msgid "%qE declared as function returning a function"
 msgstr "%qE объявлена как функция, возвращающая функцию"
 
-#: c/c-decl.c:6367
+#: c/c-decl.c:6387
 #, gcc-internal-format
 msgid "type name declared as function returning a function"
 msgstr "имя типа объявлено как функция, возвращающая функцию"
 
-#: c/c-decl.c:6374
+#: c/c-decl.c:6394
 #, gcc-internal-format
 msgid "%qE declared as function returning an array"
 msgstr "%qE объявлена как функция, возвращающая массив"
 
-#: c/c-decl.c:6377
+#: c/c-decl.c:6397
 #, gcc-internal-format
 msgid "type name declared as function returning an array"
 msgstr "имя типа объявлено как функция, возвращающая массив"
 
-#: c/c-decl.c:6418
+#: c/c-decl.c:6438
 #, gcc-internal-format
 msgid "function definition has qualified void return type"
 msgstr "в определении функции задан квалифицированный void-тип возвращаемого значения"
 
-#: c/c-decl.c:6421 cp/decl.c:11201
+#: c/c-decl.c:6441 cp/decl.c:11225
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "квалификаторы в описании типа возвращаемого значения функции "
 
-#: c/c-decl.c:6459 c/c-decl.c:6668 c/c-decl.c:6721 c/c-decl.c:6805
-#: c/c-decl.c:6926 c/c-parser.c:2823
-#, fuzzy, gcc-internal-format
-#| msgid "ISO C forbids qualified function types"
+#: c/c-decl.c:6479 c/c-decl.c:6688 c/c-decl.c:6741 c/c-decl.c:6825
+#: c/c-decl.c:6946 c/c-parser.c:2823
+#, gcc-internal-format
 msgid "%<_Atomic%>-qualified function type"
-msgstr "в ISO C употребление квалификаторов в описании типа функции запрещено"
+msgstr "%<_Atomic%>-квалифицированный тип функции"
 
-#: c/c-decl.c:6465 c/c-decl.c:6674 c/c-decl.c:6810 c/c-decl.c:6931
+#: c/c-decl.c:6485 c/c-decl.c:6694 c/c-decl.c:6830 c/c-decl.c:6951
 #, gcc-internal-format
 msgid "ISO C forbids qualified function types"
 msgstr "в ISO C употребление квалификаторов в описании типа функции запрещено"
 
-#: c/c-decl.c:6559
+#: c/c-decl.c:6579
 #, gcc-internal-format
 msgid "%qs combined with %<auto%> qualifier for %qE"
 msgstr "%qs в сочетании с квалификатором %<auto%> для %qE"
 
-#: c/c-decl.c:6563
+#: c/c-decl.c:6583
 #, gcc-internal-format
 msgid "%qs combined with %<register%> qualifier for %qE"
 msgstr "%qs в сочетании с квалификатором %<register%> для %qE"
 
-#: c/c-decl.c:6569
+#: c/c-decl.c:6589
 #, gcc-internal-format
 msgid "%qs specified for auto variable %qE"
 msgstr "%qs задано для автоматической переменной %qE"
 
-#: c/c-decl.c:6585
+#: c/c-decl.c:6605
 #, gcc-internal-format
 msgid "%qs specified for parameter %qE"
 msgstr "%qs задано для параметра %qE"
 
-#: c/c-decl.c:6588
+#: c/c-decl.c:6608
 #, gcc-internal-format
 msgid "%qs specified for unnamed parameter"
 msgstr "%qs задано для безымянного параметра"
 
-#: c/c-decl.c:6594
+#: c/c-decl.c:6614
 #, gcc-internal-format
 msgid "%qs specified for structure field %qE"
 msgstr "%qs задано для поля структуры %qE"
 
-#: c/c-decl.c:6597
+#: c/c-decl.c:6617
 #, gcc-internal-format
 msgid "%qs specified for structure field"
 msgstr "%qs задано для поля структуры"
 
-#: c/c-decl.c:6612
-#, fuzzy, gcc-internal-format
-#| msgid "bit-field %qs has invalid type"
+#: c/c-decl.c:6632
+#, gcc-internal-format
 msgid "bit-field %qE has atomic type"
-msgstr "неверный тип битового поля %qs"
+msgstr "битовое поле %qE имеет atomic тип"
 
-#: c/c-decl.c:6614
-#, fuzzy, gcc-internal-format
-#| msgid "bit-field %qs has invalid type"
+#: c/c-decl.c:6634
+#, gcc-internal-format
 msgid "bit-field has atomic type"
-msgstr "неверный тип битового поля %qs"
+msgstr "битовое поле имеет atomic тип"
 
-#: c/c-decl.c:6623
+#: c/c-decl.c:6643
 #, gcc-internal-format
 msgid "alignment specified for typedef %qE"
 msgstr "выравнивание задано в определении типа %qE"
 
-#: c/c-decl.c:6625
+#: c/c-decl.c:6645
 #, gcc-internal-format
 msgid "alignment specified for %<register%> object %qE"
 msgstr "выравнивание задано для объекта %<register%> %qE"
 
-#: c/c-decl.c:6630
+#: c/c-decl.c:6650
 #, gcc-internal-format
 msgid "alignment specified for parameter %qE"
 msgstr "выравнивание задано для параметра %qE"
 
-#: c/c-decl.c:6632
+#: c/c-decl.c:6652
 #, gcc-internal-format
 msgid "alignment specified for unnamed parameter"
 msgstr "выравнивание задано для безымянного параметра"
 
-#: c/c-decl.c:6637
+#: c/c-decl.c:6657
 #, gcc-internal-format
 msgid "alignment specified for bit-field %qE"
 msgstr "выравнивание задано для битового поля %qE"
 
-#: c/c-decl.c:6639
+#: c/c-decl.c:6659
 #, gcc-internal-format
 msgid "alignment specified for unnamed bit-field"
 msgstr "выравнивание задано для безымянного битового поля"
 
-#: c/c-decl.c:6642
+#: c/c-decl.c:6662
 #, gcc-internal-format
 msgid "alignment specified for function %qE"
 msgstr "выравнивание задано для функции %qE"
 
-#: c/c-decl.c:6649
+#: c/c-decl.c:6669
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of %qE"
 msgstr "спецификатор %<_Alignas%> не должен уменьшать выравнивание %qE"
 
-#: c/c-decl.c:6652
+#: c/c-decl.c:6672
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of unnamed field"
 msgstr "спецификатор %<_Alignas%> не должен уменьшать выравнивание безымянного поля"
 
-#: c/c-decl.c:6683
+#: c/c-decl.c:6703
 #, gcc-internal-format
 msgid "typedef %q+D declared %<inline%>"
 msgstr "typedef %q+D декларирован %<inline%>"
 
-#: c/c-decl.c:6685
+#: c/c-decl.c:6705
 #, gcc-internal-format
 msgid "typedef %q+D declared %<_Noreturn%>"
 msgstr "typedef %q+D декларирован как %<_Noreturn%>"
 
-#: c/c-decl.c:6727
+#: c/c-decl.c:6747
 #, gcc-internal-format
 msgid "ISO C forbids const or volatile function types"
 msgstr "в ISO C функции с квалификаторами const и volatile запрещены"
 
 #. C99 6.7.2.1p8
-#: c/c-decl.c:6738
+#: c/c-decl.c:6758
 #, gcc-internal-format
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "элемент структуры или объединения не может иметь переменно модифицируемый тип"
 
-#: c/c-decl.c:6755 cp/decl.c:9989
+#: c/c-decl.c:6775 cp/decl.c:10010
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "переменная или поле %qE объявлено void"
 
-#: c/c-decl.c:6795
+#: c/c-decl.c:6815
 #, gcc-internal-format
 msgid "attributes in parameter array declarator ignored"
 msgstr "атрибуты в деклараторе массива-параметра проигнорированы"
 
-#: c/c-decl.c:6837
+#: c/c-decl.c:6857
 #, gcc-internal-format
 msgid "parameter %q+D declared %<inline%>"
 msgstr "параметр %q+D объявлен %<inline%>"
 
-#: c/c-decl.c:6839
+#: c/c-decl.c:6859
 #, gcc-internal-format
 msgid "parameter %q+D declared %<_Noreturn%>"
 msgstr "параметр %q+D объявлен %<_Noreturn%>"
 
-#: c/c-decl.c:6852
+#: c/c-decl.c:6872
 #, gcc-internal-format
 msgid "field %qE declared as a function"
 msgstr "поле %qE описано как функция"
 
-#: c/c-decl.c:6859
+#: c/c-decl.c:6879
 #, gcc-internal-format
 msgid "field %qE has incomplete type"
 msgstr "поле %qE имеет неполный тип"
 
-#: c/c-decl.c:6861
+#: c/c-decl.c:6881
 #, gcc-internal-format
 msgid "unnamed field has incomplete type"
 msgstr "безымянное поле имеет неполный тип"
 
-#: c/c-decl.c:6897 c/c-decl.c:6908 c/c-decl.c:6911
+#: c/c-decl.c:6917 c/c-decl.c:6928 c/c-decl.c:6931
 #, gcc-internal-format
 msgid "invalid storage class for function %qE"
 msgstr "для функции %qE задан неверный класс хранения"
 
-#: c/c-decl.c:6968
+#: c/c-decl.c:6988
 #, gcc-internal-format
 msgid "cannot inline function %<main%>"
 msgstr "inline-подстановка функции %<main%> невозможна"
 
-#: c/c-decl.c:6970
+#: c/c-decl.c:6990
 #, gcc-internal-format
 msgid "%<main%> declared %<_Noreturn%>"
 msgstr "функция %<main%> декларирована как %<_Noreturn%>"
 
-#: c/c-decl.c:6981
+#: c/c-decl.c:7001
 #, gcc-internal-format
 msgid "ISO C99 does not support %<_Noreturn%>"
 msgstr "ISO C99 не поддерживает %<_Noreturn%>"
 
-#: c/c-decl.c:6984
+#: c/c-decl.c:7004
 #, gcc-internal-format
 msgid "ISO C90 does not support %<_Noreturn%>"
 msgstr "ISO C90 не поддерживает %<_Noreturn%>"
 
-#: c/c-decl.c:7013
+#: c/c-decl.c:7033
 #, gcc-internal-format
 msgid "variable previously declared %<static%> redeclared %<extern%>"
 msgstr "переменная декларирована сначала как %<static%>, а затем как %<extern%>"
 
-#: c/c-decl.c:7023
+#: c/c-decl.c:7043
 #, gcc-internal-format
 msgid "variable %q+D declared %<inline%>"
 msgstr "переменная %q+D декларирована со спецификатором %<inline%>"
 
-#: c/c-decl.c:7025
+#: c/c-decl.c:7045
 #, gcc-internal-format
 msgid "variable %q+D declared %<_Noreturn%>"
 msgstr "переменная %q+D декларирована со спецификатором %<_Noreturn%>"
 
-#: c/c-decl.c:7060
+#: c/c-decl.c:7080
 #, gcc-internal-format
 msgid "non-nested function with variably modified type"
 msgstr "не вложенная функция с переменно модифицируемым типом"
 
-#: c/c-decl.c:7062
+#: c/c-decl.c:7082
 #, gcc-internal-format
 msgid "object with variably modified type must have no linkage"
 msgstr "объект с переменно модифицируемым типом не должен иметь привязки"
 
-#: c/c-decl.c:7153 c/c-decl.c:8821
+#: c/c-decl.c:7173 c/c-decl.c:8841
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr "декларация функции не является прототипом"
 
-#: c/c-decl.c:7163
+#: c/c-decl.c:7183
 #, gcc-internal-format
 msgid "parameter names (without types) in function declaration"
 msgstr "в декларации функции указаны имена параметров без типов"
 
-#: c/c-decl.c:7201
+#: c/c-decl.c:7221
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has incomplete type"
 msgstr "параметр %u (%q+D) имеет неполный тип"
 
-#: c/c-decl.c:7205
+#: c/c-decl.c:7225
 #, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has incomplete type"
 msgstr "параметр %u имеет неполный тип"
 
-#: c/c-decl.c:7216
+#: c/c-decl.c:7236
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has void type"
 msgstr "параметр %u (%q+D) имеет тип void"
 
-#: c/c-decl.c:7220
+#: c/c-decl.c:7240
 #, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has void type"
 msgstr "параметр %u имеет тип void"
 
-#: c/c-decl.c:7294
+#: c/c-decl.c:7314
 #, gcc-internal-format
 msgid "%<void%> as only parameter may not be qualified"
 msgstr "%<void%>, как единственный параметры не может содержать квалификаторы"
 
-#: c/c-decl.c:7298 c/c-decl.c:7334
+#: c/c-decl.c:7318 c/c-decl.c:7354
 #, gcc-internal-format
 msgid "%<void%> must be the only parameter"
 msgstr "%<void%> должен быть единственным параметром"
 
-#: c/c-decl.c:7328
+#: c/c-decl.c:7348
 #, gcc-internal-format
 msgid "parameter %q+D has just a forward declaration"
 msgstr "для параметра %q+D есть только упреждающая декларация"
 
-#: c/c-decl.c:7374
+#: c/c-decl.c:7394
 #, gcc-internal-format
 msgid "%<%s %E%> declared inside parameter list will not be visible outside of this definition or declaration"
-msgstr ""
+msgstr "%<%s %E%> декларированное внутри списка параметров не будет видно вне этого определения или декларации"
 
-#: c/c-decl.c:7380
+#: c/c-decl.c:7400
 #, gcc-internal-format, gfc-internal-format
 msgid "anonymous %s declared inside parameter list will not be visible outside of this definition or declaration"
-msgstr ""
+msgstr "анонимное %s декларированное внутри списка параметров не будет видно вне этого определения или декларации"
 
-#: c/c-decl.c:7482
+#: c/c-decl.c:7502
 #, gcc-internal-format
 msgid "enum type defined here"
 msgstr "перечислимый тип определён здесь"
 
-#: c/c-decl.c:7488
+#: c/c-decl.c:7508
 #, gcc-internal-format
 msgid "struct defined here"
 msgstr "структура определена здесь"
 
-#: c/c-decl.c:7494
+#: c/c-decl.c:7514
 #, gcc-internal-format
 msgid "union defined here"
 msgstr "объединение определено здесь"
 
-#: c/c-decl.c:7570
+#: c/c-decl.c:7590
 #, gcc-internal-format
 msgid "redefinition of %<union %E%>"
 msgstr "повторное определение %<union %E%>"
 
-#: c/c-decl.c:7572
+#: c/c-decl.c:7592
 #, gcc-internal-format
 msgid "redefinition of %<struct %E%>"
 msgstr "повторное определение %<struct %E%>"
 
-#: c/c-decl.c:7581
+#: c/c-decl.c:7601
 #, gcc-internal-format
 msgid "nested redefinition of %<union %E%>"
 msgstr "вложенное переопределение %<union %E%>"
 
-#: c/c-decl.c:7583
+#: c/c-decl.c:7603
 #, gcc-internal-format
 msgid "nested redefinition of %<struct %E%>"
 msgstr "вложенное переопределение %<struct %E%>"
 
-#: c/c-decl.c:7613 c/c-decl.c:8400
+#: c/c-decl.c:7633 c/c-decl.c:8420
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr "определение типа в выражении %qs некорректно в C++"
 
-#: c/c-decl.c:7680 cp/decl.c:4802
+#: c/c-decl.c:7700 cp/decl.c:4802
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "декларация ничего не описывает"
 
-#: c/c-decl.c:7685
+#: c/c-decl.c:7705
 #, gcc-internal-format
 msgid "ISO C99 doesn%'t support unnamed structs/unions"
 msgstr "ISO C99 не поддерживает безымянные структуры и объединения"
 
-#: c/c-decl.c:7688
+#: c/c-decl.c:7708
 #, gcc-internal-format
 msgid "ISO C90 doesn%'t support unnamed structs/unions"
 msgstr "ISO C90 не поддерживает безымянные структуры и объединения"
 
-#: c/c-decl.c:7781 c/c-decl.c:7799 c/c-decl.c:7860
+#: c/c-decl.c:7801 c/c-decl.c:7819 c/c-decl.c:7880
 #, gcc-internal-format
 msgid "duplicate member %q+D"
 msgstr "повторное описание члена %q+D"
 
-#: c/c-decl.c:7886
+#: c/c-decl.c:7906
 #, gcc-internal-format
 msgid "empty struct has size 0 in C, size 1 in C++"
-msgstr ""
+msgstr "пустая структура имеет размер 0 в C, размер 1 в C++"
 
-#: c/c-decl.c:7889
+#: c/c-decl.c:7909
 #, gcc-internal-format
 msgid "empty union has size 0 in C, size 1 in C++"
-msgstr ""
+msgstr "пустое объединение имеет размер 0 в C, размер 1 в C++"
 
-#: c/c-decl.c:7994
+#: c/c-decl.c:8014
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr "объединение не содержит именованных элементов"
 
-#: c/c-decl.c:7996
+#: c/c-decl.c:8016
 #, gcc-internal-format
 msgid "union has no members"
 msgstr "объединение без элементов"
 
-#: c/c-decl.c:8001
+#: c/c-decl.c:8021
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr "структура не содержит именованных элементов"
 
-#: c/c-decl.c:8003
+#: c/c-decl.c:8023
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr "структура не содержит элементов"
 
-#: c/c-decl.c:8064 cp/decl.c:12069
+#: c/c-decl.c:8084 cp/decl.c:12093
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "регулируемый элемент-массив в объединении"
 
-#: c/c-decl.c:8070
+#: c/c-decl.c:8090
 #, gcc-internal-format
 msgid "flexible array member not at end of struct"
 msgstr "регулируемый элемент-массив - не последний элемент структуры"
 
-#: c/c-decl.c:8076
-#, fuzzy, gcc-internal-format
-#| msgid "flexible array member in union"
+#: c/c-decl.c:8096
+#, gcc-internal-format
 msgid "flexible array member in a struct with no named members"
-msgstr "регулируемый элемент-массив в объединении"
+msgstr "регулируемый элемент-массив в структуре без именованных элементов"
 
-#: c/c-decl.c:8107
-#, fuzzy, gcc-internal-format
-#| msgid "value passed in %qs is too large"
+#: c/c-decl.c:8127
+#, gcc-internal-format
 msgid "type %qT is too large"
-msgstr "значение, переданное в %qs слишком велико"
+msgstr "тип %qT слишком велик"
 
-#: c/c-decl.c:8230
+#: c/c-decl.c:8250
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr "трактовка данного объединения как прозрачного невозможна"
 
-#: c/c-decl.c:8372
+#: c/c-decl.c:8392
 #, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr "вложенное переопределение %<enum %E%>"
 
 #. This enum is a named one that has been declared already.
-#: c/c-decl.c:8379
+#: c/c-decl.c:8399
 #, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr "повторная декларация %<enum %E%>"
 
-#: c/c-decl.c:8458 cp/decl.c:14423
+#: c/c-decl.c:8478 cp/decl.c:14447
 #, gcc-internal-format
 msgid "specified mode too small for enumeral values"
 msgstr "заданный режим слишком мал для значений перечислимого типа"
 
-#: c/c-decl.c:8473
+#: c/c-decl.c:8493
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr "перечислимый тип превышает диапазон максимального целочисленного типа"
 
-#: c/c-decl.c:8587 c/c-decl.c:8603
+#: c/c-decl.c:8607 c/c-decl.c:8623
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr "значение перечислимого типа для %qE не является константой целого типа"
 
-#: c/c-decl.c:8598
+#: c/c-decl.c:8618
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr "значение перечислимого типа для %qE не является целочисленным константным выражением"
 
-#: c/c-decl.c:8622
+#: c/c-decl.c:8642
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr "переполнение значений перечислимого типа"
 
-#: c/c-decl.c:8630
+#: c/c-decl.c:8650
 #, gcc-internal-format
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "в ISO C значения перечислимого типа ограничены диапазоном типа %<int%>"
 
-#: c/c-decl.c:8715 cp/decl.c:5104 cp/decl.c:14955
+#: c/c-decl.c:8735 cp/decl.c:5104 cp/decl.c:14979
 #, gcc-internal-format
 msgid "inline function %qD given attribute noinline"
 msgstr "inline функция %qD с атрибутом noinline"
 
-#: c/c-decl.c:8733
+#: c/c-decl.c:8753
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr "тип возвращаемого значения не полный"
 
-#: c/c-decl.c:8744
+#: c/c-decl.c:8764
 #, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr "по умолчанию возвращаемый тип функции - %<int%>"
 
-#: c/c-decl.c:8771
-#, fuzzy, gcc-internal-format
-#| msgid "Warn about global functions without prototypes"
+#: c/c-decl.c:8791
+#, gcc-internal-format
 msgid "%q+D defined as variadic function without prototype"
-msgstr "Предупреждать о глобальных функциях без прототипов"
+msgstr "%q+D определена как variadic функциях без прототипа"
 
-#: c/c-decl.c:8830
+#: c/c-decl.c:8850
 #, gcc-internal-format
 msgid "no previous prototype for %qD"
 msgstr "прототип для %qD не был предварительно определен"
 
-#: c/c-decl.c:8839
+#: c/c-decl.c:8859
 #, gcc-internal-format
 msgid "%qD was used with no prototype before its definition"
 msgstr "%qD использована без прототипа, до её определению"
 
-#: c/c-decl.c:8847 cp/decl.c:15090
+#: c/c-decl.c:8867 cp/decl.c:15114
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "отсутствует предварительная декларация %qD"
 
-#: c/c-decl.c:8857
+#: c/c-decl.c:8877
 #, gcc-internal-format
 msgid "%qD was used with no declaration before its definition"
 msgstr "функция %qD использована до определения без предварительной декларации"
 
-#: c/c-decl.c:8876
+#: c/c-decl.c:8896
 #, gcc-internal-format
 msgid "return type of %qD is not %<int%>"
 msgstr "возвращаемое значение функции %qD - не %<int%>"
 
-#: c/c-decl.c:8878
+#: c/c-decl.c:8898
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
-msgstr ""
+msgstr "%<_Atomic%>-квалифицированный возвращаемый тип в %qD"
 
-#: c/c-decl.c:8885
+#: c/c-decl.c:8905
 #, gcc-internal-format
 msgid "%qD is normally a non-static function"
 msgstr "обычно %qD является нестатической функцией"
 
-#: c/c-decl.c:8922
+#: c/c-decl.c:8942
 #, gcc-internal-format
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr "старый стиль деклараций параметров в определении функции с прототипом"
 
-#: c/c-decl.c:8937
+#: c/c-decl.c:8957
 #, gcc-internal-format
 msgid "traditional C rejects ISO C style function definitions"
 msgstr "в традиционном С не поддерживаются определения функций в стиле ISO C"
 
-#: c/c-decl.c:8953
+#: c/c-decl.c:8973
 #, gcc-internal-format
 msgid "parameter name omitted"
 msgstr "опущено имя параметра"
 
-#: c/c-decl.c:8990
+#: c/c-decl.c:9010
 #, gcc-internal-format
 msgid "old-style function definition"
 msgstr "определение функции в старом стиле"
 
-#: c/c-decl.c:8999
+#: c/c-decl.c:9019
 #, gcc-internal-format
 msgid "parameter name missing from parameter list"
 msgstr "в списке параметров пропущено имя параметра"
 
-#: c/c-decl.c:9015
+#: c/c-decl.c:9035
 #, gcc-internal-format
 msgid "%qD declared as a non-parameter"
 msgstr "%qD декларирован как не параметр"
 
-#: c/c-decl.c:9023
+#: c/c-decl.c:9043
 #, gcc-internal-format
 msgid "multiple parameters named %qD"
 msgstr "более одного параметра с именем %qD"
 
-#: c/c-decl.c:9032
+#: c/c-decl.c:9052
 #, gcc-internal-format
 msgid "parameter %qD declared with void type"
 msgstr "параметр %qD объявлен с типом void"
 
-#: c/c-decl.c:9061 c/c-decl.c:9066
+#: c/c-decl.c:9081 c/c-decl.c:9086
 #, gcc-internal-format
 msgid "type of %qD defaults to %<int%>"
 msgstr "по умолчанию для %qD принят тип %<int%>"
 
-#: c/c-decl.c:9086
+#: c/c-decl.c:9106
 #, gcc-internal-format
 msgid "parameter %qD has incomplete type"
 msgstr "параметр %qD имеет неполный тип"
 
-#: c/c-decl.c:9093
+#: c/c-decl.c:9113
 #, gcc-internal-format
 msgid "declaration for parameter %qD but no such parameter"
 msgstr "декларация параметра %q+D, не заданного в списке параметров"
 
-#: c/c-decl.c:9146
+#: c/c-decl.c:9166
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr "число аргументов не соответствует встроенному прототипу"
 
-#: c/c-decl.c:9157
+#: c/c-decl.c:9177
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr "число аргументов не соответствует прототипу"
 
-#: c/c-decl.c:9160 c/c-decl.c:9207 c/c-decl.c:9221
+#: c/c-decl.c:9180 c/c-decl.c:9227 c/c-decl.c:9241
 #, gcc-internal-format
 msgid "prototype declaration"
 msgstr "декларация прототипа"
 
-#: c/c-decl.c:9199
+#: c/c-decl.c:9219
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr "аргумент %qD после приведения типа не соответствует встроенному прототипу"
 
-#: c/c-decl.c:9204
+#: c/c-decl.c:9224
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr "аргумент %qD после приведения типа не соответствует прототипу"
 
-#: c/c-decl.c:9214
+#: c/c-decl.c:9234
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr "аргумент %qD не соответствует встроенному прототипу"
 
-#: c/c-decl.c:9219
+#: c/c-decl.c:9239
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr "аргумент %qD не соответствует прототипу"
 
-#: c/c-decl.c:9470 cp/decl.c:15873
+#: c/c-decl.c:9490 cp/decl.c:15897
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "в функции, которая должна возвращать значение, отсутствует оператор return"
 
-#: c/c-decl.c:9490 cp/decl.c:15905
+#: c/c-decl.c:9510 cp/decl.c:15929
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "параметру %qD присвоено значение, но он не использован"
@@ -39779,265 +34805,250 @@
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:9586
-#, fuzzy, gcc-internal-format
-#| msgid "%<for%> loop initial declarations are only allowed in C99 mode"
+#: c/c-decl.c:9606
+#, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
-msgstr "декларация в заголовке %<for%>-цикла поддерживается только в стандарте C99"
+msgstr "декларации в заголовке %<for%>-цикла допускаются только в C99 или C11 режиме"
 
-#: c/c-decl.c:9591
-#, fuzzy, gcc-internal-format
-#| msgid "use option -std=c99 or -std=gnu99 to compile your code"
+#: c/c-decl.c:9611
+#, gcc-internal-format
 msgid "use option -std=c99, -std=gnu99, -std=c11 or -std=gnu11 to compile your code"
-msgstr "используйте -std=c99 или -std=gnu99 для компиляции вашей программы"
+msgstr "используйте опцию -std=c99, -std=gnu99,-std=c11 или -std=gnu11 для компиляции вашей программы"
 
-#: c/c-decl.c:9626
+#: c/c-decl.c:9646
 #, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "декларация статической переменной %qD в заголовке %<for%>-цикла"
 
-#: c/c-decl.c:9630
+#: c/c-decl.c:9650
 #, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "декларация %<extern%> переменной %qD в заголовке %<for%>-цикла"
 
-#: c/c-decl.c:9637
+#: c/c-decl.c:9657
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "декларация %<struct %E%> в заголовке %<for%>-цикла"
 
-#: c/c-decl.c:9642
+#: c/c-decl.c:9662
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "декларация %<union %E%> в заголовке %<for%>-цикла"
 
-#: c/c-decl.c:9646
+#: c/c-decl.c:9666
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "декларация %<enum %E%> в заголовке %<for%>-цикла"
 
-#: c/c-decl.c:9650
+#: c/c-decl.c:9670
 #, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "декларация %qD, не являющегося переменной, в заголовке %<for%>-цикла"
 
-#: c/c-decl.c:9900
+#: c/c-decl.c:9920
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr "несовместимые квалификаторы адресного пространства %qs и %qs"
 
-#: c/c-decl.c:9958 c/c-decl.c:9965
-#, fuzzy, gcc-internal-format
-#| msgid "expected declaration specifiers"
+#: c/c-decl.c:9978 c/c-decl.c:9985
+#, gcc-internal-format
 msgid "duplicate %qE declaration specifier"
-msgstr "ожидались спецификаторы декларации"
+msgstr "повторный %qE  спецификатор декларации"
 
-#: c/c-decl.c:9992 c/c-decl.c:10376 c/c-decl.c:10766
+#: c/c-decl.c:10012 c/c-decl.c:10396 c/c-decl.c:10786
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr "два или более типа в декларации"
 
-#: c/c-decl.c:10004 cp/parser.c:28261
+#: c/c-decl.c:10024 cp/parser.c:28258
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "GCC не поддерживает тип %<long long long%>"
 
-#: c/c-decl.c:10017
+#: c/c-decl.c:10037
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C90 не поддерживает тип %<long long%>"
 
-#: c/c-decl.c:10246 c/c-parser.c:8848
+#: c/c-decl.c:10266 c/c-parser.c:8848
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C90 не поддерживает комплексные типы"
 
-#: c/c-decl.c:10292
+#: c/c-decl.c:10312
 #, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr "ISO C не поддерживает типы с насыщением"
 
-#: c/c-decl.c:10363 c/c-decl.c:10923
+#: c/c-decl.c:10383 c/c-decl.c:10943
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "дублирование %qE"
 
-#: c/c-decl.c:10419
-#, fuzzy, gcc-internal-format
-#| msgid "ISO C does not support %<__int128%> type"
+#: c/c-decl.c:10439
+#, gcc-internal-format
 msgid "ISO C does not support %<__int%d%> types"
-msgstr "ISO C не поддерживает тип %<__int128%>"
+msgstr "ISO C не поддерживает типы %<__int%d%>"
 
-#: c/c-decl.c:10441
-#, fuzzy, gcc-internal-format
-#| msgid "%<__int128%> is not supported for this target"
+#: c/c-decl.c:10461
+#, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
-msgstr "%<__int128%> не поддерживается для этой целевой машины"
+msgstr "%<__int%d%> не поддерживается для этой целевой машины"
 
-#: c/c-decl.c:10484
-#, fuzzy, gcc-internal-format
-#| msgid "ISO C90 does not support complex types"
+#: c/c-decl.c:10504
+#, gcc-internal-format
 msgid "ISO C90 does not support boolean types"
-msgstr "ISO C90 не поддерживает комплексные типы"
+msgstr "ISO C90 не поддерживает булевы типы"
 
-#: c/c-decl.c:10603
-#, fuzzy, gcc-internal-format
-#| msgid "ISO C does not support %<__int128%> type"
+#: c/c-decl.c:10623
+#, gcc-internal-format
 msgid "ISO C does not support the %<_Float%d%s%> type"
-msgstr "ISO C не поддерживает тип %<__int128%>"
+msgstr "ISO C не поддерживает тип %<_Float%d%s%>"
 
-#: c/c-decl.c:10653
-#, fuzzy, gcc-internal-format
-#| msgid "%<__int128%> is not supported for this target"
+#: c/c-decl.c:10673
+#, gcc-internal-format
 msgid "%<_Float%d%s%> is not supported on this target"
-msgstr "%<__int128%> не поддерживается для этой целевой машины"
+msgstr "%<_Float%d%s%> не поддерживается для этой целевой машины"
 
-#: c/c-decl.c:10724
+#: c/c-decl.c:10744
 #, gcc-internal-format
 msgid "ISO C does not support decimal floating point"
 msgstr "ISO C не поддерживает десятичный тип с плавающей точкой"
 
-#: c/c-decl.c:10747 c/c-decl.c:11013 c/c-parser.c:7842
+#: c/c-decl.c:10767 c/c-decl.c:11033 c/c-parser.c:7842
 #, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "типы с фиксированной точкой не поддерживаются для этой целевой платформы"
 
-#: c/c-decl.c:10749
+#: c/c-decl.c:10769
 #, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C не поддерживает типы с фиксированной точкой"
 
-#: c/c-decl.c:10784
+#: c/c-decl.c:10804
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr "в C++ результатом поиска %qD будет поле, а не тип"
 
-#: c/c-decl.c:10797
+#: c/c-decl.c:10817
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr "%qE не является встроенным типом или typedef-типом"
 
-#: c/c-decl.c:10845
+#: c/c-decl.c:10865
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qE - не в начале декларации"
 
-#: c/c-decl.c:10866
-#, fuzzy, gcc-internal-format
-#| msgid "%<__thread%> used with %<auto%>"
+#: c/c-decl.c:10886
+#, gcc-internal-format
 msgid "%qE used with %<auto%>"
-msgstr "спецификатор %<__thread%> использован с %<auto%>"
+msgstr "%qE использован с %<auto%>"
 
-#: c/c-decl.c:10868
-#, fuzzy, gcc-internal-format
-#| msgid "%<__thread%> used with %<register%>"
+#: c/c-decl.c:10888
+#, gcc-internal-format
 msgid "%qE used with %<register%>"
-msgstr "спецификатор %<__thread%> использован с %<register%>"
+msgstr "%qE использован register %<auto%>"
 
-#: c/c-decl.c:10870
-#, fuzzy, gcc-internal-format
-#| msgid "%<__thread%> used with %<typedef%>"
+#: c/c-decl.c:10890
+#, gcc-internal-format
 msgid "%qE used with %<typedef%>"
-msgstr "спецификатор %<__thread%> использован с %<typedef%>"
+msgstr "%qE использован с %<typedef%>"
 
-#: c/c-decl.c:10884 c/c-parser.c:7360
+#: c/c-decl.c:10904 c/c-parser.c:7360
 #, gcc-internal-format
 msgid "ISO C99 does not support %qE"
 msgstr "ISO C99 не поддерживает %qE"
 
-#: c/c-decl.c:10887 c/c-parser.c:7363
+#: c/c-decl.c:10907 c/c-parser.c:7363
 #, gcc-internal-format
 msgid "ISO C90 does not support %qE"
 msgstr "ISO C90 не поддерживает %qE"
 
-#: c/c-decl.c:10899
+#: c/c-decl.c:10919
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<__thread%> перед %<extern%>"
 
-#: c/c-decl.c:10908
+#: c/c-decl.c:10928
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<__thread%> перед %<static%>"
 
-#: c/c-decl.c:10921
+#: c/c-decl.c:10941
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
-msgstr ""
+msgstr "повторение %<_Thread_local%> или %<__thread%>"
 
-#: c/c-decl.c:10929
+#: c/c-decl.c:10949
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr "в декларации задано более одного класса хранения"
 
-#: c/c-decl.c:10937
-#, fuzzy, gcc-internal-format
-#| msgid "%qs must be used with %qs"
+#: c/c-decl.c:10957
+#, gcc-internal-format
 msgid "%qs used with %qE"
-msgstr "%qs следует использовать вместе с %qs"
+msgstr "%qs использован с %qE"
 
-#: c/c-decl.c:11010
+#: c/c-decl.c:11030
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "%<_Sat%> использован без %<_Fract%> или %<_Accum%>"
 
-#: c/c-decl.c:11025
+#: c/c-decl.c:11045
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C не поддерживает %<complex%> как эквивалент %<double complex%>"
 
-#: c/c-decl.c:11076 c/c-decl.c:11092 c/c-decl.c:11118
+#: c/c-decl.c:11096 c/c-decl.c:11112 c/c-decl.c:11138
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C не поддерживает целочисленные комплексные типы"
 
-#: c/c-decl.c:11514 cp/semantics.c:5348
+#: c/c-decl.c:11534 cp/semantics.c:5351
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
-msgstr ""
+msgstr "%<#pragma omp declare reduction%> объединитель ссылается на переменную %qD, которая не %<omp_out%> и не %<omp_in%>"
 
-#: c/c-decl.c:11518 cp/semantics.c:5352
+#: c/c-decl.c:11538 cp/semantics.c:5355
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
-msgstr ""
+msgstr "%<#pragma omp declare reduction%> инициализатор ссылается на переменную %qD, которая не %<omp_priv%> и не %<omp_orig%>"
 
-#: c/c-fold.c:385 c/c-typeck.c:11426 cp/typeck.c:4680
-#, fuzzy, gcc-internal-format
-#| msgid "left shift count is negative"
+#: c/c-fold.c:385 c/c-typeck.c:11431 cp/typeck.c:4680
+#, gcc-internal-format
 msgid "left shift of negative value"
-msgstr "сдвиг влево на отрицательное число позиций"
+msgstr "сдвиг влево отрицательного значения"
 
-#: c/c-fold.c:395 c/c-typeck.c:11435 cp/typeck.c:4688
+#: c/c-fold.c:395 c/c-typeck.c:11440 cp/typeck.c:4688
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "сдвиг влево на отрицательное число позиций"
 
-#: c/c-fold.c:396 c/c-typeck.c:11365 cp/typeck.c:4633
+#: c/c-fold.c:396 c/c-typeck.c:11370 cp/typeck.c:4633
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "сдвиг вправо на отрицательное число позиций"
 
-#: c/c-fold.c:404 c/c-typeck.c:11454 cp/typeck.c:4696
+#: c/c-fold.c:404 c/c-typeck.c:11459 cp/typeck.c:4696
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "величина сдвига влево больше или равна ширине данного типа"
 
-#: c/c-fold.c:405 c/c-typeck.c:11389 cp/typeck.c:4641
+#: c/c-fold.c:405 c/c-typeck.c:11394 cp/typeck.c:4641
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "величина сдвига вправо больше или равна ширине данного типа"
 
-#: c/c-fold.c:412 c/c-typeck.c:11446
-#, fuzzy, gcc-internal-format
-#| msgid "left shift count >= width of type"
+#: c/c-fold.c:412 c/c-typeck.c:11451
+#, gcc-internal-format
 msgid "left shift count >= width of vector element"
-msgstr "величина сдвига влево больше или равна ширине данного типа"
+msgstr "счетчик сдвига влево >= ширине элемента вектора"
 
-#: c/c-fold.c:413 c/c-typeck.c:11376
-#, fuzzy, gcc-internal-format
-#| msgid "right shift count >= width of type"
+#: c/c-fold.c:413 c/c-typeck.c:11381
+#, gcc-internal-format
 msgid "right shift count >= width of vector element"
-msgstr "величина сдвига вправо больше или равна ширине данного типа"
+msgstr "счетчик сдвига вправо >= ширине элемента вектора"
 
 #: c/c-parser.c:274
 #, gcc-internal-format
@@ -40047,16 +35058,15 @@
 #: c/c-parser.c:884 cp/parser.c:2864
 #, gcc-internal-format
 msgid "version control conflict marker in file"
-msgstr ""
+msgstr "противоречивый маркер управления версиями в файле"
 
 #
 #: c/c-parser.c:1087 cp/parser.c:2905
-#, fuzzy, gcc-internal-format
-#| msgid "%J  other type here"
+#, gcc-internal-format
 msgid "to match this %qs"
-msgstr "%J  другой тип здесь"
+msgstr ""
 
-#: c/c-parser.c:1216 cp/parser.c:28484
+#: c/c-parser.c:1216 cp/parser.c:28481
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr "ожидался конец строки"
@@ -40074,23 +35084,22 @@
 #: c/c-parser.c:1795
 #, gcc-internal-format
 msgid "unknown type name %qE; use %<struct%> keyword to refer to the type"
-msgstr ""
+msgstr "неизвестное имя типа %qE; используйте ключевое слово %<struct%>, чтобы сослаться на этот тип"
 
 #: c/c-parser.c:1803
 #, gcc-internal-format
 msgid "unknown type name %qE; use %<union%> keyword to refer to the type"
-msgstr ""
+msgstr "неизвестное имя типа %qE; используйте ключевое слово %<union%>, чтобы сослаться на этот тип"
 
 #: c/c-parser.c:1811
 #, gcc-internal-format
 msgid "unknown type name %qE; use %<enum%> keyword to refer to the type"
-msgstr ""
+msgstr "неизвестное имя типа %qE; используйте ключевое слово %<enum%>, чтобы сослаться на этот тип"
 
 #: c/c-parser.c:1823 c/c-parser.c:4060
-#, fuzzy, gcc-internal-format
-#| msgid "%qT has no member named %qE"
+#, gcc-internal-format
 msgid "unknown type name %qE; did you mean %qs?"
-msgstr "%qT не содержит элемента с именем %qE"
+msgstr "неизвестное имя типа %qE; имелось в виду %qs?"
 
 #: c/c-parser.c:1827 c/c-parser.c:2650 c/c-parser.c:4064
 #, gcc-internal-format
@@ -40098,16 +35107,15 @@
 msgstr "неизвестное имя типа %qE"
 
 #: c/c-parser.c:1848 c/c-parser.c:11129 c/c-parser.c:16147 c/c-parser.c:16585
-#: c/c-parser.c:17061 cp/parser.c:36007 cp/parser.c:38993
+#: c/c-parser.c:17061 cp/parser.c:36004 cp/parser.c:38990
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "ожидались спецификаторы декларации"
 
 #: c/c-parser.c:1858
-#, fuzzy, gcc-internal-format
-#| msgid "%<_Noreturn%> in empty declaration"
+#, gcc-internal-format
 msgid "%<__auto_type%> in empty declaration"
-msgstr "%<_Noreturn%> в пустой декларации"
+msgstr "%<__auto_type%> в пустой декларации"
 
 #: c/c-parser.c:1888 c/c-parser.c:3343
 #, gcc-internal-format
@@ -40114,7 +35122,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "ожидалось %<;%>, идентификатор или %<(%>"
 
-#: c/c-parser.c:1906 cp/parser.c:30161 cp/parser.c:30235
+#: c/c-parser.c:1906 cp/parser.c:30158 cp/parser.c:30232
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "префиксные атрибуты для методов игнорируются"
@@ -40131,15 +35139,14 @@
 
 #: c/c-parser.c:1972 c/c-parser.c:5194 c/c-parser.c:5511 cp/parser.c:10952
 #: cp/parser.c:11151
-#, fuzzy, gcc-internal-format
-#| msgid "section attribute not allowed for %q+D"
+#, gcc-internal-format
 msgid "%<fallthrough%> attribute not followed by %<;%>"
-msgstr "атрибут section для %q+D недопустим"
+msgstr "за атрибутом %<fallthrough%> не следует %<;%>"
 
 #: c/c-parser.c:2004
 #, gcc-internal-format
 msgid "%<__auto_type%> requires a plain identifier as declarator"
-msgstr ""
+msgstr "%<__auto_type%> требует простого идентификатора в качестве декларатора"
 
 #: c/c-parser.c:2021
 #, gcc-internal-format
@@ -40150,30 +35157,26 @@
 #. the declarator in a function definition.  Provide
 #. some more information for the user.
 #: c/c-parser.c:2036
-#, fuzzy, gcc-internal-format
-#| msgid "attributes are not allowed on a function-definition"
+#, gcc-internal-format
 msgid "attributes should be specified before the declarator in a function definition"
-msgstr "атрибуты не допускаются при определении функции"
+msgstr "атрибуты должны задаваться до декларатора в определении функции"
 
 #: c/c-parser.c:2063
-#, fuzzy, gcc-internal-format
-#| msgid "%<typeof%> applied to a bit-field"
+#, gcc-internal-format
 msgid "%<__auto_type%> used with a bit-field initializer"
-msgstr "оператор %<typeof%> применен к битовому полю"
+msgstr "%<__auto_type%> использован с инициализатором битового поля"
 
 #: c/c-parser.c:2138 c/c-parser.c:2228
-#, fuzzy, gcc-internal-format
-#| msgid "%<auto%> in file-scope empty declaration"
+#, gcc-internal-format
 msgid "%<__auto_type%> requires an initialized data declaration"
-msgstr "%<auto%> в пустой декларации на уровне файла"
+msgstr "%<__auto_type%> требует инициализированной декларации данных"
 
 #: c/c-parser.c:2191
-#, fuzzy, gcc-internal-format
-#| msgid "%<auto%> can only be specified for variables or function declarations"
+#, gcc-internal-format
 msgid "%<__auto_type%> may only be used with a single declarator"
-msgstr "%<auto%> можно задавать только для переменных или деклараций функций"
+msgstr "%<__auto_type%> может использоваться только с одним декларатором"
 
-#: c/c-parser.c:2220 cp/parser.c:13002 cp/parser.c:13159
+#: c/c-parser.c:2220 cp/parser.c:12999 cp/parser.c:13156
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "ожидалось %<,%> или %<;%>"
@@ -40201,7 +35204,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C90 не поддерживает %<_Static_assert%>"
 
-#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38634
+#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38631
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr "ожидался строковый литерал"
@@ -40229,36 +35232,32 @@
 #: c/c-parser.c:2792
 #, gcc-internal-format
 msgid "%<_Atomic%> in Objective-C"
-msgstr ""
+msgstr "%<_Atomic%> в Objective-C"
 
 #: c/c-parser.c:2795
-#, fuzzy, gcc-internal-format
-#| msgid "ISO C99 does not support %<_Alignas%>"
+#, gcc-internal-format
 msgid "ISO C99 does not support the %<_Atomic%> qualifier"
-msgstr "ISO C99 не поддерживает %<_Alignas%>"
+msgstr "ISO C99 не поддерживает %<_Atomic%> квалификатор"
 
 #: c/c-parser.c:2798
-#, fuzzy, gcc-internal-format
-#| msgid "ISO C90 does not support %<_Alignas%>"
+#, gcc-internal-format
 msgid "ISO C90 does not support the %<_Atomic%> qualifier"
-msgstr "ISO C90 не поддерживает %<_Alignas%>"
+msgstr "ISO C90 не поддерживает %<_Atomic%> квалификатор"
 
 #: c/c-parser.c:2825
-#, fuzzy, gcc-internal-format
-#| msgid "%<typeof%> applied to a bit-field"
+#, gcc-internal-format
 msgid "%<_Atomic%> applied to a qualified type"
-msgstr "оператор %<typeof%> применен к битовому полю"
+msgstr "%<_Atomic%> применен к квалифицированному типу"
 
 #: c/c-parser.c:2855
 #, gcc-internal-format
 msgid "%<__GIMPLE%> only valid with -fgimple"
-msgstr ""
+msgstr "%<__GIMPLE%> допускается только с -fgimple"
 
 #: c/c-parser.c:2953
-#, fuzzy, gcc-internal-format
-#| msgid "template argument %d is invalid"
+#, gcc-internal-format
 msgid "empty enum is invalid"
-msgstr "некорректный аргумент шаблона %d"
+msgstr "пустое перечисление некорректно"
 
 #: c/c-parser.c:2957 c/c-parser.c:3891 c/c-parser.c:4656 c/c-parser.c:4951
 #: c/c-parser.c:6436 c/c-parser.c:6524 c/c-parser.c:7226 c/c-parser.c:7903
@@ -40269,13 +35268,13 @@
 #: c/c-parser.c:10745 c/c-parser.c:10798 c/c-parser.c:10814 c/c-parser.c:10860
 #: c/c-parser.c:11496 c/c-parser.c:11537 c/c-parser.c:13445 c/c-parser.c:13681
 #: c/c-parser.c:15544 c/c-parser.c:18218 c/gimple-parser.c:1058
-#: c/gimple-parser.c:1096 cp/parser.c:28487 cp/parser.c:31013
-#: cp/parser.c:31043 cp/parser.c:31113 cp/parser.c:33230 cp/parser.c:38350
+#: c/gimple-parser.c:1096 cp/parser.c:28484 cp/parser.c:31010
+#: cp/parser.c:31040 cp/parser.c:31110 cp/parser.c:33227 cp/parser.c:38347
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "ожидался идентификатор"
 
-#: c/c-parser.c:2995 cp/parser.c:18384
+#: c/c-parser.c:2995 cp/parser.c:18381
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "запятая в конце списка значений перечислимого типа"
@@ -40421,10 +35420,9 @@
 msgstr "ожидалось %<:%> или %<...%>"
 
 #: c/c-parser.c:5198 c/c-parser.c:5515
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute can only be applied to class definitions"
+#, gcc-internal-format
 msgid "only attribute %<fallthrough%> can be applied to a null statement"
-msgstr "%qE атрибут может применяться только к определениям классов"
+msgstr "только атрибут %<fallthrough%> может применяться к пустому оператору"
 
 #: c/c-parser.c:5204
 #, gcc-internal-format
@@ -40445,12 +35443,12 @@
 msgid "expected statement"
 msgstr "ожидался оператор"
 
-#: c/c-parser.c:5639 cp/parser.c:12516
+#: c/c-parser.c:5639 cp/parser.c:12513
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "рекомендуется заключать в фигурные скобки пустое тело в операторе %<if%>"
 
-#: c/c-parser.c:5681 cp/parser.c:12519
+#: c/c-parser.c:5681 cp/parser.c:12516
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "рекомендуется заключать в фигурные скобки пустое тело в операторе %<else%>"
@@ -40478,7 +35476,7 @@
 #: c/c-parser.c:6172 cp/parser.c:11708
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
-msgstr ""
+msgstr "отсутствует условие цикла в цикле с %<GCC ivdep%> pragma"
 
 #: c/c-parser.c:6178 cp/parser.c:11714
 #, gcc-internal-format
@@ -40513,16 +35511,14 @@
 msgstr ""
 
 #: c/c-parser.c:6873 cp/typeck.c:4478
-#, fuzzy, gcc-internal-format
-#| msgid "type of field declared here"
+#, gcc-internal-format
 msgid "first %<sizeof%> operand was declared here"
-msgstr "тип поля объявлен здесь"
+msgstr ""
 
 #: c/c-parser.c:7090
-#, fuzzy, gcc-internal-format
-#| msgid "alignment specified for typedef %qE"
+#, gcc-internal-format
 msgid "alignment specified for type name in cast"
-msgstr "выравнивание задано в определении типа %qE"
+msgstr ""
 
 #: c/c-parser.c:7189
 #, gcc-internal-format
@@ -40530,10 +35526,9 @@
 msgstr "в традиционном C унарный плюс не поддерживается"
 
 #: c/c-parser.c:7318
-#, fuzzy, gcc-internal-format
-#| msgid "alignment specified for typedef %qE"
+#, gcc-internal-format
 msgid "alignment specified for type name in %<sizeof%>"
-msgstr "выравнивание задано в определении типа %qE"
+msgstr ""
 
 #: c/c-parser.c:7334
 #, gcc-internal-format
@@ -40541,10 +35536,9 @@
 msgstr "оператор %<sizeof%> применен к битовому полю"
 
 #: c/c-parser.c:7403
-#, fuzzy, gcc-internal-format
-#| msgid "alignment specified for typedef %qE"
+#, gcc-internal-format
 msgid "alignment specified for type name in %qE"
-msgstr "выравнивание задано в определении типа %qE"
+msgstr ""
 
 #: c/c-parser.c:7426
 #, gcc-internal-format
@@ -40557,97 +35551,85 @@
 msgstr "некорректная попытка взять адрес %qs"
 
 #: c/c-parser.c:7540
-#, fuzzy, gcc-internal-format
-#| msgid "ISO C99 does not support %<_Noreturn%>"
+#, gcc-internal-format
 msgid "ISO C99 does not support %<_Generic%>"
-msgstr "ISO C99 не поддерживает %<_Noreturn%>"
+msgstr "ISO C99 не поддерживает %<_Generic%>"
 
 #: c/c-parser.c:7543
-#, fuzzy, gcc-internal-format
-#| msgid "ISO C90 does not support %<_Noreturn%>"
+#, gcc-internal-format
 msgid "ISO C90 does not support %<_Generic%>"
-msgstr "ISO C90 не поддерживает %<_Noreturn%>"
+msgstr "ISO C90 не поддерживает %<_Generic%>"
 
 #: c/c-parser.c:7611
-#, fuzzy, gcc-internal-format
-#| msgid "cast specifies function type"
+#, gcc-internal-format
 msgid "%<_Generic%> association has function type"
-msgstr "тип функции в операции приведения типов"
+msgstr "%<_Generic%> ассоциация имеет тип функции"
 
 #: c/c-parser.c:7614
-#, fuzzy, gcc-internal-format
-#| msgid "expression statement has incomplete type"
+#, gcc-internal-format
 msgid "%<_Generic%> association has incomplete type"
-msgstr "оператор-выражение имеет неполный тип"
+msgstr "%<_Generic%> ассоциация имеет неполный тип"
 
 #: c/c-parser.c:7618
 #, gcc-internal-format
 msgid "%<_Generic%> association has variable length type"
-msgstr ""
+msgstr "%<_Generic%> ассоциация имеет тип переменной длины"
 
 #: c/c-parser.c:7642
 #, gcc-internal-format
 msgid "duplicate %<default%> case in %<_Generic%>"
-msgstr ""
+msgstr "повторение %<default%> case в %<_Generic%>"
 
 #: c/c-parser.c:7643
-#, fuzzy, gcc-internal-format
-#| msgid "originally defined here"
+#, gcc-internal-format
 msgid "original %<default%> is here"
-msgstr "исходное определение находится здесь"
+msgstr "оригинал %<default%> здесь"
 
 #: c/c-parser.c:7651
 #, gcc-internal-format
 msgid "%<_Generic%> specifies two compatible types"
-msgstr ""
+msgstr "%<_Generic%> задает два совместимых типа"
 
 #: c/c-parser.c:7652
-#, fuzzy, gcc-internal-format
-#| msgid "incompatible types in send"
+#, gcc-internal-format
 msgid "compatible type is here"
-msgstr "несовместимые типы в send"
+msgstr "совместимый тип здесь"
 
 #: c/c-parser.c:7675
-#, fuzzy, gcc-internal-format
-#| msgid "Generate load/store multiple instructions"
+#, gcc-internal-format
 msgid "%<_Generic%> selector matches multiple associations"
-msgstr "Генерировать команды множественного чтения/записи"
+msgstr "%<_Generic%> селектор соответствует нескольким ассоциациям"
 
 #
 #: c/c-parser.c:7677
-#, fuzzy, gcc-internal-format
-#| msgid "%J  other type here"
+#, gcc-internal-format
 msgid "other match is here"
-msgstr "%J  другой тип здесь"
+msgstr "другое соответствие здесь"
 
 #: c/c-parser.c:7696
 #, gcc-internal-format
 msgid "%<_Generic%> selector of type %qT is not compatible with any association"
-msgstr ""
+msgstr "%<_Generic%> селектор типа %qT несовместим ни с какой ассоциацией"
 
 #: c/c-parser.c:7717
-#, fuzzy, gcc-internal-format
-#| msgid "argument of %<__builtin_args_info%> must be constant"
+#, gcc-internal-format
 msgid "argument %u of %<__builtin_tgmath%> is not a function pointer"
-msgstr "аргумент %<__builtin_args_info%> должен быть константой"
+msgstr ""
 
 #: c/c-parser.c:7725
-#, fuzzy, gcc-internal-format
-#| msgid "argument of %<__builtin_args_info%> out of range"
+#, gcc-internal-format
 msgid "argument %u of %<__builtin_tgmath%> is unprototyped"
-msgstr "аргумент %<__builtin_args_info%> вне допустимого диапазона"
+msgstr ""
 
 #: c/c-parser.c:7731
-#, fuzzy, gcc-internal-format
-#| msgid "argument of %<__builtin_args_info%> must be constant"
+#, gcc-internal-format
 msgid "argument %u of %<__builtin_tgmath%> has variable arguments"
-msgstr "аргумент %<__builtin_args_info%> должен быть константой"
+msgstr ""
 
 #: c/c-parser.c:7747
-#, fuzzy, gcc-internal-format
-#| msgid "argument of %<__builtin_args_info%> out of range"
+#, gcc-internal-format
 msgid "argument %u of %<__builtin_tgmath%> has no arguments"
-msgstr "аргумент %<__builtin_args_info%> вне допустимого диапазона"
+msgstr ""
 
 #: c/c-parser.c:7917 c/c-parser.c:8969 c/c-parser.c:8991 c/gimple-parser.c:978
 #: c/gimple-parser.c:984 c/gimple-parser.c:1468
@@ -40666,21 +35648,19 @@
 msgstr "ISO C не поддерживает использование групп операторов в фигурных скобках внутри выражений"
 
 #: c/c-parser.c:7976
-#, fuzzy, gcc-internal-format
-#| msgid "ISO C does not support %<__int128%> type"
+#, gcc-internal-format
 msgid "ISO C does not support %<__FUNCTION__%> predefined identifier"
-msgstr "ISO C не поддерживает тип %<__int128%>"
+msgstr "ISO C не поддерживает %<__FUNCTION__%> предопределенный идентификатор"
 
 #: c/c-parser.c:7985
 #, gcc-internal-format
 msgid "ISO C does not support %<__PRETTY_FUNCTION__%> predefined identifier"
-msgstr ""
+msgstr "ISO C не поддерживает %<__PRETTY_FUNCTION__%> предопределенный идентификатор"
 
 #: c/c-parser.c:7994
-#, fuzzy, gcc-internal-format
-#| msgid "ISO C does not support %<__int128%> type"
+#, gcc-internal-format
 msgid "ISO C90 does not support %<__func__%> predefined identifier"
-msgstr "ISO C не поддерживает тип %<__int128%>"
+msgstr "ISO C90 не поддерживает %<__func__%> предопределенный идентификатор"
 
 #: c/c-parser.c:8158
 #, gcc-internal-format
@@ -40693,16 +35673,14 @@
 msgstr "первый аргумент %<__builtin_choose_expr%> - не константа"
 
 #: c/c-parser.c:8244 c/c-parser.c:8261 c/c-parser.c:8268
-#, fuzzy, gcc-internal-format
-#| msgid "too few arguments to function %<va_start%>"
+#, gcc-internal-format
 msgid "too few arguments to %<__builtin_tgmath%>"
-msgstr "слишком мало аргументов в вызове функции %<va_start%>"
+msgstr ""
 
 #: c/c-parser.c:8289
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L has wrong number of elements (%d/%d)"
+#, gcc-internal-format
 msgid "argument %u of %<__builtin_tgmath%> has wrong number of arguments"
-msgstr "'%s' аргумент '%s' встроенной функции в %L имеет неверное число элементов (%d/%d)"
+msgstr ""
 
 #: c/c-parser.c:8333 c/c-parser.c:8343
 #, gcc-internal-format
@@ -40715,10 +35693,9 @@
 msgstr ""
 
 #: c/c-parser.c:8408
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' and '%s' arguments of '%s' intrinsic at %L must have the same type"
+#, gcc-internal-format
 msgid "function arguments of %<__builtin_tgmath%> all have the same type"
-msgstr "'%s' и '%s' аргументы '%s' встроенной функции в %L должны иметь одинаковый тип"
+msgstr ""
 
 #: c/c-parser.c:8427
 #, gcc-internal-format
@@ -40736,76 +35713,64 @@
 msgstr ""
 
 #: c/c-parser.c:8515
-#, fuzzy, gcc-internal-format
-#| msgid "wrong number of arguments to function %<__builtin_next_arg%>"
+#, gcc-internal-format
 msgid "bad type for argument %u of function argument %u of %<__builtin_tgmath%>"
-msgstr "неверное число аргументов в вызове функции %<__builtin_next_arg%>"
+msgstr ""
 
 #: c/c-parser.c:8553
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "invalid type for parameter %d of constexpr function %q+#D"
+#, gcc-internal-format, gfc-internal-format
 msgid "invalid type of argument %u of type-generic function"
-msgstr "некорректный тип для параметра %d constexpr функции %q+#D"
+msgstr ""
 
 #: c/c-parser.c:8564
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "non-floating-point argument in call to function %qE"
+#, gcc-internal-format, gfc-internal-format
 msgid "decimal floating-point argument %u to complex-only type-generic function"
-msgstr "не плавающий аргумент в вызове функции %qE"
+msgstr ""
 
 #: c/c-parser.c:8572
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "non-floating-point argument in call to function %qE"
+#, gcc-internal-format, gfc-internal-format
 msgid "decimal floating-point argument %u to binary-only type-generic function"
-msgstr "не плавающий аргумент в вызове функции %qE"
+msgstr ""
 
 #: c/c-parser.c:8580 c/c-parser.c:8610
-#, fuzzy, gcc-internal-format
-#| msgid "non-floating-point arguments in call to function %qE"
+#, gcc-internal-format
 msgid "both complex and decimal floating-point arguments to type-generic function"
-msgstr "не плавающие аргументы в вызове функции %qE"
+msgstr ""
 
 #: c/c-parser.c:8588 c/c-parser.c:8630
-#, fuzzy, gcc-internal-format
-#| msgid "non-floating-point arguments in call to function %qE"
+#, gcc-internal-format
 msgid "both binary and decimal floating-point arguments to type-generic function"
-msgstr "не плавающие аргументы в вызове функции %qE"
+msgstr ""
 
 #: c/c-parser.c:8602
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "complex arguments must have identical types"
+#, gcc-internal-format, gfc-internal-format
 msgid "complex argument %u to decimal-only type-generic function"
-msgstr "complex аргументы должны иметь идентичные типы"
+msgstr ""
 
 #: c/c-parser.c:8622
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "invalid argument to built-in function"
+#, gcc-internal-format, gfc-internal-format
 msgid "binary argument %u to decimal-only type-generic function"
-msgstr "некорректный аргумент встроенной функции"
+msgstr ""
 
 #: c/c-parser.c:8728
-#, fuzzy, gcc-internal-format
-#| msgid "no matching function for call to %<%D(%A)%>"
+#, gcc-internal-format
 msgid "no matching function for type-generic call"
-msgstr "нет соответствующей функции для вызова %<%D(%A)%>"
+msgstr ""
 
 #: c/c-parser.c:8769
-#, fuzzy, gcc-internal-format
-#| msgid "wrong number of arguments to %<__builtin_choose_expr%>"
+#, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_call_with_static_chain%>"
-msgstr "неверное число аргументов в вызове %<__builtin_choose_expr%>"
+msgstr "неверное число аргументов для %<__builtin_call_with_static_chain%>"
 
 #: c/c-parser.c:8782
-#, fuzzy, gcc-internal-format
-#| msgid "third argument to %<__builtin_prefetch%> must be a constant"
+#, gcc-internal-format
 msgid "first argument to %<__builtin_call_with_static_chain%> must be a call expression"
-msgstr "третий аргумент %<__builtin_prefetch%> должен быть константой"
+msgstr "первый аргумент %<__builtin_call_with_static_chain%> должен быть выражением вызова"
 
 #: c/c-parser.c:8786
-#, fuzzy, gcc-internal-format
-#| msgid "second argument to %<__builtin_prefetch%> must be a constant"
+#, gcc-internal-format
 msgid "second argument to %<__builtin_call_with_static_chain%> must be a pointer type"
-msgstr "второй аргумент %<__builtin_prefetch%> должен быть константой"
+msgstr "второй аргумент %<__builtin_call_with_static_chain%> должен быть типа указателя"
 
 #: c/c-parser.c:8812
 #, gcc-internal-format
@@ -40822,7 +35787,7 @@
 msgid "%<__builtin_complex%> operands of different types"
 msgstr "операнды %<__builtin_complex%> имеют разные типы"
 
-#: c/c-parser.c:8891 cp/parser.c:6918
+#: c/c-parser.c:8891 cp/parser.c:6921
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_shuffle%>"
 msgstr "неверное число аргументов в вызове аргументов в вызове %<__builtin_shuffle%>"
@@ -40843,10 +35808,9 @@
 msgstr "ISO C90 не поддерживает составные литеральные выражения"
 
 #: c/c-parser.c:9057
-#, fuzzy, gcc-internal-format
-#| msgid "%<_Alignas%> specifiers cannot reduce alignment of unnamed field"
+#, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of compound literal"
-msgstr "спецификатор %<_Alignas%> не должен уменьшать выравнивание безымянного поля"
+msgstr ""
 
 #: c/c-parser.c:9513
 #, gcc-internal-format
@@ -40883,89 +35847,84 @@
 msgid "no type or storage class may be specified here,"
 msgstr "в этом месте не может указываться ни тип, ни класс хранения,"
 
-#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31073
+#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31070
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "неизвестный атрибут свойства"
 
-#: c/c-parser.c:10682 cp/parser.c:31033
+#: c/c-parser.c:10682 cp/parser.c:31030
 #, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "отсутствует %<=%> (после атрибута %<getter%>)"
 
-#: c/c-parser.c:10685 cp/parser.c:31036
+#: c/c-parser.c:10685 cp/parser.c:31033
 #, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "отсутствует %<=%> (после атрибута %<setter%>)"
 
-#: c/c-parser.c:10699 cp/parser.c:31051
+#: c/c-parser.c:10699 cp/parser.c:31048
 #, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "атрибут %<setter%> может быть задан только один раз"
 
-#: c/c-parser.c:10704 cp/parser.c:31057
+#: c/c-parser.c:10704 cp/parser.c:31054
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr "имя setter должно заканчиваться %<:%>"
 
-#: c/c-parser.c:10711 cp/parser.c:31065
+#: c/c-parser.c:10711 cp/parser.c:31062
 #, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "атрибут %<getter%> может быть задан только один раз"
 
-#: c/c-parser.c:10905 cp/parser.c:38674
+#: c/c-parser.c:10905 cp/parser.c:38671
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
 #: c/c-parser.c:10949 c/c-parser.c:16582 c/c-parser.c:16840 c/c-parser.c:16899
-#: c/c-parser.c:16983 cp/parser.c:36004 cp/parser.c:36298 cp/parser.c:36386
-#: cp/parser.c:36457 cp/parser.c:38721 cp/parser.c:38736 cp/parser.c:38752
-#: cp/parser.c:38768 cp/parser.c:38784 cp/parser.c:38811 cp/parser.c:38824
-#: cp/parser.c:38847 cp/parser.c:38860
-#, fuzzy, gcc-internal-format
-#| msgid "%<#pragma omp flush%> may only be used in compound statements"
+#: c/c-parser.c:16983 cp/parser.c:36001 cp/parser.c:36295 cp/parser.c:36383
+#: cp/parser.c:36454 cp/parser.c:38718 cp/parser.c:38733 cp/parser.c:38749
+#: cp/parser.c:38765 cp/parser.c:38781 cp/parser.c:38808 cp/parser.c:38821
+#: cp/parser.c:38844 cp/parser.c:38857
+#, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
-msgstr "%<#pragma omp flush%> может использоваться только в составных операторах"
+msgstr "%<#pragma %s%> может использоваться только в составных операторах"
 
-#: c/c-parser.c:10972 cp/parser.c:38837
-#, fuzzy, gcc-internal-format
-#| msgid "%<#pragma GCC option%> is not a string"
+#: c/c-parser.c:10972 cp/parser.c:38834
+#, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
-msgstr "%<#pragma GCC option%> не является строковым литералом"
+msgstr "%<#pragma acc routine%> должна быть в контексте файла"
 
-#: c/c-parser.c:11050 cp/parser.c:38918
+#: c/c-parser.c:11050 cp/parser.c:38915
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<#pragma omp section%> может использоваться только в конструкции %<#pragma omp sections%>"
 
-#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38947 cp/parser.c:38980
-#, fuzzy, gcc-internal-format
-#| msgid "for statement expected"
+#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38944 cp/parser.c:38977
+#, gcc-internal-format
 msgid "for, while or do statement expected"
-msgstr "ожидался оператор for"
+msgstr "for, while или do оператор ожидался"
 
-#: c/c-parser.c:11111 cp/parser.c:38711
+#: c/c-parser.c:11111 cp/parser.c:38708
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%> должна быть первой"
 
-#: c/c-parser.c:11421 cp/parser.c:31457
+#: c/c-parser.c:11421 cp/parser.c:31454
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "слишком много конструкций %qs"
 
-#: c/c-parser.c:11443 cp/parser.c:31994
-#, fuzzy, gcc-internal-format
-#| msgid "expected integer expression before %s'%c'"
+#: c/c-parser.c:11443 cp/parser.c:31991
+#, gcc-internal-format
 msgid "expected integer expression before ')'"
-msgstr "ожидалось целочисленное выражение перед %s'%c'"
+msgstr "ожидалось целочисленное выражение перед ')'"
 
 #: c/c-parser.c:11458
-#, fuzzy, gcc-internal-format
-#| msgid "num_threads expression must be integral"
+#, gcc-internal-format
 msgid "expression must be integral"
-msgstr "num_threads выражение должно быть целочисленным"
+msgstr "выражение должно быть целочисленным"
 
 #: c/c-parser.c:11742 c/c-parser.c:18160
 #, gcc-internal-format
@@ -40972,62 +35931,56 @@
 msgid "%qD is not a variable"
 msgstr "%qD не переменная"
 
-#: c/c-parser.c:11746 cp/semantics.c:6808
-#, fuzzy, gcc-internal-format
-#| msgid "%qD is not a variable"
+#: c/c-parser.c:11746 cp/semantics.c:6811
+#, gcc-internal-format
 msgid "%qD is not a pointer variable"
-msgstr "%qD не переменная"
+msgstr "%qD не указательная переменная"
 
-#: c/c-parser.c:11788 cp/parser.c:32073
+#: c/c-parser.c:11788 cp/parser.c:32070
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr "collapse аргумент требует положительного константного целого выражения"
 
-#: c/c-parser.c:11865 cp/parser.c:32137
-#, fuzzy, gcc-internal-format
-#| msgid "expected %<none%> or %<shared%>"
+#: c/c-parser.c:11865 cp/parser.c:32134
+#, gcc-internal-format
 msgid "expected %<none%> or %<present%>"
-msgstr "ожидалось %<none%> или %<shared%>"
+msgstr ""
 
-#: c/c-parser.c:11867 cp/parser.c:32139
+#: c/c-parser.c:11867 cp/parser.c:32136
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "ожидалось %<none%> или %<shared%>"
 
-#: c/c-parser.c:11968 cp/parser.c:32242
-#, fuzzy, gcc-internal-format
-#| msgid "expected %<;%>, %<,%> or %<)%>"
+#: c/c-parser.c:11968 cp/parser.c:32239
+#, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
-msgstr "ожидалось %<;%>, %<,%> или %<)%>"
+msgstr "ожидалось %<data%>, %<update%>, %<enter%> или %<exit%>"
 
-#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32260
-#: cp/parser.c:36290 cp/parser.c:36378
-#, fuzzy, gcc-internal-format
-#| msgid "expected %<catch%>"
+#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32257
+#: cp/parser.c:36287 cp/parser.c:36375
+#, gcc-internal-format
 msgid "expected %<data%>"
-msgstr "ожидалось %<catch%>"
+msgstr "ожидалось %<data%>"
 
-#: c/c-parser.c:12035 cp/parser.c:32313
+#: c/c-parser.c:12035 cp/parser.c:32310
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
-msgstr ""
+msgstr "слишком много %<if%> клаузул с %qs модификатором"
 
-#: c/c-parser.c:12042 cp/parser.c:32320
-#, fuzzy, gcc-internal-format
-#| msgid "too many %qs clauses"
+#: c/c-parser.c:12042 cp/parser.c:32317
+#, gcc-internal-format
 msgid "too many %<if%> clauses"
-msgstr "слишком много конструкций %qs"
+msgstr "слишком много %<if%> клаузул"
 
-#: c/c-parser.c:12044 cp/parser.c:32322
-#, fuzzy, gcc-internal-format
-#| msgid "too many %qs clauses"
+#: c/c-parser.c:12044 cp/parser.c:32319
+#, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
-msgstr "слишком много конструкций %qs"
+msgstr "слишком много %<if%> клаузул без модификатора"
 
-#: c/c-parser.c:12050 cp/parser.c:32328
+#: c/c-parser.c:12050 cp/parser.c:32325
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
-msgstr ""
+msgstr "если какая-либо %<if%> клаузула имеет модификатор, то все %<if%> должны использовать модификатор"
 
 #: c/c-parser.c:12126 c/c-parser.c:12172 c/c-parser.c:12218 c/c-parser.c:12264
 #: c/c-parser.c:12311 c/c-parser.c:12551 c/c-parser.c:12632 c/c-parser.c:13043
@@ -41042,239 +35995,206 @@
 msgstr "значение %<num_threads%> должно быть положительным"
 
 #: c/c-parser.c:12183
-#, fuzzy, gcc-internal-format
-#| msgid "%<num_threads%> value must be positive"
+#, gcc-internal-format
 msgid "%<num_tasks%> value must be positive"
-msgstr "значение %<num_threads%> должно быть положительным"
+msgstr "значение %<num_tasks%> должно быть положительным"
 
-#: c/c-parser.c:12229 cp/semantics.c:6992
-#, fuzzy, gcc-internal-format
-#| msgid "%<num_threads%> value must be positive"
+#: c/c-parser.c:12229 cp/semantics.c:6995
+#, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
-msgstr "значение %<num_threads%> должно быть положительным"
+msgstr "значение %<grainsize%> должно быть положительным"
 
-#: c/c-parser.c:12276 cp/semantics.c:7021
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' at %L must be nonnegative"
+#: c/c-parser.c:12276 cp/semantics.c:7024
+#, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
-msgstr "'%s' в %L должен быть неотрицательным"
+msgstr "значение %<priority%> должен быть неотрицательным"
 
-#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32545 cp/parser.c:32552
-#, fuzzy, gcc-internal-format
-#| msgid "expected %<throw%>"
+#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32542 cp/parser.c:32549
+#, gcc-internal-format
 msgid "expected %<tofrom%>"
-msgstr "ожидалось %<throw%>"
+msgstr "ожидалось %<tofrom%>"
 
-#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32561 cp/parser.c:32568
-#, fuzzy, gcc-internal-format
-#| msgid "expected %<class%>"
+#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32558 cp/parser.c:32565
+#, gcc-internal-format
 msgid "expected %<scalar%>"
-msgstr "ожидалось %<class%>"
+msgstr "ожидалось %<scalar%>"
 
-#: c/c-parser.c:12425 cp/semantics.c:6299
-#, fuzzy, gcc-internal-format
-#| msgid "num_threads expression must be integral"
+#: c/c-parser.c:12425 cp/semantics.c:6302
+#, gcc-internal-format
 msgid "%qs expression must be integral"
-msgstr "num_threads выражение должно быть целочисленным"
+msgstr "%qs выражение должно быть целочисленным"
 
-#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6331
-#, fuzzy, gcc-internal-format
-#| msgid "%<num_threads%> value must be positive"
+#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6334
+#, gcc-internal-format
 msgid "%qs value must be positive"
-msgstr "значение %<num_threads%> должно быть положительным"
+msgstr "значение %qs должно быть положительным"
 
-#: c/c-parser.c:12499 cp/parser.c:31853
-#, fuzzy, gcc-internal-format
-#| msgid "too many arguments"
+#: c/c-parser.c:12499 cp/parser.c:31850
+#, gcc-internal-format
 msgid "too many %<static%> arguments"
-msgstr "слишком много аргументов"
+msgstr "слишком много %<static%> аргументов"
 
-#: c/c-parser.c:12533 cp/parser.c:31886
-#, fuzzy, gcc-internal-format
-#| msgid "unexpected attribute"
+#: c/c-parser.c:12533 cp/parser.c:31883
+#, gcc-internal-format
 msgid "unexpected argument"
-msgstr "неожиданный атрибут"
+msgstr "неожиданный аргумент"
 
-#: c/c-parser.c:12699 cp/semantics.c:7120
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute argument not an integer constant"
+#: c/c-parser.c:12699 cp/semantics.c:7123
+#, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
-msgstr "аргумент атрибута %qE не целая константа"
+msgstr "%<tile%> аргумент требует положительной целочисленной константы"
 
-#: c/c-parser.c:12765 cp/parser.c:32626
-#, fuzzy, gcc-internal-format
-#| msgid "collapse argument needs positive constant integer expression"
+#: c/c-parser.c:12765 cp/parser.c:32623
+#, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
-msgstr "collapse аргумент требует положительного константного целого выражения"
+msgstr "ordered аргумент требует положительного константного целого выражения"
 
-#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37643
-#, fuzzy, gcc-internal-format
-#| msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or %<max%>"
+#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37640
+#, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
-msgstr "ожидалось %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> или %<max%>"
+msgstr "ожидалось %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> или идентификатор"
 
-#: c/c-parser.c:12967 cp/parser.c:32840
-#, fuzzy, gcc-internal-format
-#| msgid "both %<long%> and %<void%> in declaration specifiers"
+#: c/c-parser.c:12967 cp/parser.c:32837
+#, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
-msgstr "в декларации заданы спецификаторы %<long%> и %<void%>"
+msgstr "заданы оба модификатора %<monotonic%> и %<nonmonotonic%>"
 
-#: c/c-parser.c:13021 cp/parser.c:32856
+#: c/c-parser.c:13021 cp/parser.c:32853
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "расписание %<runtime%> не имеет параметра %<chunk_size%>"
 
-#: c/c-parser.c:13025 cp/parser.c:32859
+#: c/c-parser.c:13025 cp/parser.c:32856
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "расписание %<auto%> не имеет параметра %<chunk_size%>"
 
-#: c/c-parser.c:13037 cp/semantics.c:6389
-#, fuzzy, gcc-internal-format
-#| msgid "%<num_threads%> value must be positive"
+#: c/c-parser.c:13037 cp/semantics.c:6392
+#, gcc-internal-format
 msgid "chunk size value must be positive"
-msgstr "значение %<num_threads%> должно быть положительным"
+msgstr "значение размера чанка должно быть положительным"
 
-#: c/c-parser.c:13060 cp/parser.c:32879
+#: c/c-parser.c:13060 cp/parser.c:32876
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "некорректный тип планирования"
 
 #: c/c-parser.c:13181
-#, fuzzy, gcc-internal-format
-#| msgid "%<num_threads%> value must be positive"
+#, gcc-internal-format
 msgid "%<num_teams%> value must be positive"
-msgstr "значение %<num_threads%> должно быть положительным"
+msgstr "значение %<num_teams%> должно быть положительным"
 
-#: c/c-parser.c:13226 cp/semantics.c:6479
-#, fuzzy, gcc-internal-format
-#| msgid "%<num_threads%> value must be positive"
+#: c/c-parser.c:13226 cp/semantics.c:6482
+#, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
-msgstr "значение %<num_threads%> должно быть положительным"
+msgstr "значение %<thread_limit%> должно быть положительным"
 
-#: c/c-parser.c:13271 cp/semantics.c:6589
-#, fuzzy, gcc-internal-format
-#| msgid "collapse argument needs positive constant integer expression"
+#: c/c-parser.c:13271 cp/semantics.c:6592
+#, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
-msgstr "collapse аргумент требует положительного константного целого выражения"
+msgstr "%<aligned%> клаузула выражения выравнивания должна быть положительным константным целочисленным выражением"
 
 #: c/c-parser.c:13334
-#, fuzzy, gcc-internal-format
-#| msgid "schedule chunk size expression must be integral"
+#, gcc-internal-format
 msgid "%<linear%> clause step expression must be integral"
-msgstr "schedule chunk size выражение должно быть целочисленным"
+msgstr "%<linear%> клаузула выражения шага должна быть целочисленным выражением"
 
 #: c/c-parser.c:13375
-#, fuzzy, gcc-internal-format
-#| msgid "collapse argument needs positive constant integer expression"
+#, gcc-internal-format
 msgid "%<safelen%> clause expression must be positive constant integer expression"
-msgstr "collapse аргумент требует положительного константного целого выражения"
+msgstr "%<safelen%> клаузула выражения должна быть положительным константным целочисленным выражением"
 
 #: c/c-parser.c:13414
-#, fuzzy, gcc-internal-format
-#| msgid "collapse argument needs positive constant integer expression"
+#, gcc-internal-format
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
-msgstr "collapse аргумент требует положительного константного целого выражения"
+msgstr "%<simdlen%> клаузула выражения должна быть положительным константным целочисленным выражением"
 
-#: c/c-parser.c:13584 cp/parser.c:33374 cp/parser.c:33599
-#, fuzzy, gcc-internal-format
-#| msgid "invalid schedule kind"
+#: c/c-parser.c:13584 cp/parser.c:33371 cp/parser.c:33596
+#, gcc-internal-format
 msgid "invalid depend kind"
-msgstr "некорректный тип планирования"
+msgstr "некорректный depend вид"
 
-#: c/c-parser.c:13669 cp/parser.c:33447
-#, fuzzy, gcc-internal-format
-#| msgid "invalid mask"
+#: c/c-parser.c:13669 cp/parser.c:33444
+#, gcc-internal-format
 msgid "invalid map kind"
-msgstr "некорректная маска"
+msgstr "некорректный map вид"
 
-#: c/c-parser.c:13767 cp/parser.c:33546
-#, fuzzy, gcc-internal-format
-#| msgid "invalid schedule kind"
+#: c/c-parser.c:13767 cp/parser.c:33543
+#, gcc-internal-format
 msgid "invalid dist_schedule kind"
-msgstr "некорректный тип планирования"
+msgstr "некорректный dist_schedule вид"
 
 #: c/c-parser.c:13839
-#, fuzzy, gcc-internal-format
-#| msgid "invalid schedule kind"
+#, gcc-internal-format
 msgid "invalid proc_bind kind"
-msgstr "некорректный тип планирования"
+msgstr "некорректный proc_bind вид"
 
-#: c/c-parser.c:14059 cp/parser.c:33825
-#, fuzzy, gcc-internal-format
-#| msgid "expected %<#pragma omp%> clause"
+#: c/c-parser.c:14059 cp/parser.c:33822
+#, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
-msgstr "ожидалась конструкция %<#pragma omp%>"
+msgstr "ожидалась %<#pragma acc%> клаузула"
 
-#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33836 cp/parser.c:34143
+#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33833 cp/parser.c:34140
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs не является корректным для %qs"
 
-#: c/c-parser.c:14214 cp/parser.c:34010
-#, fuzzy, gcc-internal-format
-#| msgid "%qs must be used with %qs"
+#: c/c-parser.c:14214 cp/parser.c:34007
+#, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
-msgstr "%qs следует использовать вместе с %qs"
+msgstr "%qs должна быть первой клаузулой %qs"
 
-#: c/c-parser.c:14334 cp/parser.c:34132
+#: c/c-parser.c:14334 cp/parser.c:34129
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "ожидалась конструкция %<#pragma omp%>"
 
-#: c/c-parser.c:14472 cp/parser.c:36803
+#: c/c-parser.c:14472 cp/parser.c:36800
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
-msgstr ""
+msgstr "нет допустимых клаузул заданных в %<#pragma acc declare%>"
 
-#: c/c-parser.c:14482 cp/parser.c:36813
-#, fuzzy, gcc-internal-format
-#| msgid "Array section in '%s' call at %L"
+#: c/c-parser.c:14482 cp/parser.c:36810
+#, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
-msgstr "Секция массива в '%s' вызове в %L"
+msgstr "секция массива в %<#pragma acc declare%>"
 
 #
-#: c/c-parser.c:14502 cp/parser.c:36833
-#, fuzzy, gcc-internal-format
-#| msgid "invalid use of %<--%> on bool variable %qD"
+#: c/c-parser.c:14502 cp/parser.c:36830
+#, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
-msgstr "некорректное использование %<--%> на булевой переменной %qD"
+msgstr "%qD должна быть глобальной переменной в %<#pragma acc declare link%>"
 
-#: c/c-parser.c:14513 cp/parser.c:36844
-#, fuzzy, gcc-internal-format
-#| msgid "invalid type in declaration"
+#: c/c-parser.c:14513 cp/parser.c:36841
+#, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
-msgstr "некорректный тип в декларации"
+msgstr "некорректная OpenACC клаузула в контексте файла"
 
-#: c/c-parser.c:14520 cp/parser.c:36851
-#, fuzzy, gcc-internal-format
-#| msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
+#: c/c-parser.c:14520 cp/parser.c:36848
+#, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
-msgstr "декларация %<extern%> переменной %qD в заголовке %<for%>-цикла"
+msgstr "некорректное использование %<extern%> переменной %qD в %<#pragma acc declare%>"
 
 #
-#: c/c-parser.c:14528 cp/parser.c:36859
-#, fuzzy, gcc-internal-format
-#| msgid "invalid use of %<--%> on bool variable %qD"
+#: c/c-parser.c:14528 cp/parser.c:36856
+#, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
-msgstr "некорректное использование %<--%> на булевой переменной %qD"
+msgstr "некорректное использование %<global%> переменной %qD в %<#pragma acc declare%>"
 
-#: c/c-parser.c:14540 cp/parser.c:36871
+#: c/c-parser.c:14540 cp/parser.c:36868
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
-msgstr ""
+msgstr "переменная %qD использована более одного раза с %<#pragma acc declare%>"
 
-#: c/c-parser.c:14632 cp/parser.c:36957
-#, fuzzy, gcc-internal-format
-#| msgid "expected %<@end%> before %<#pragma%>"
+#: c/c-parser.c:14632 cp/parser.c:36954
+#, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
-msgstr "ожидалось %<@end%> перед %<#pragma%>"
+msgstr "data %<@end%> после %<#pragma acc %s%>"
 
-#: c/c-parser.c:14648 cp/parser.c:36974
-#, fuzzy, gcc-internal-format
-#| msgid "%<#pragma GCC option%> is not a string"
+#: c/c-parser.c:14648 cp/parser.c:36971
+#, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
-msgstr "%<#pragma GCC option%> не является строковым литералом"
+msgstr "%<#pragma acc %s data%> не содержит клаузулу перемещения данных"
 
 #: c/c-parser.c:14874 cp/parser.c:2952
 #, gcc-internal-format
@@ -41282,67 +36202,59 @@
 msgstr "%qE не был декларирован"
 
 #: c/c-parser.c:14878
-#, fuzzy, gcc-internal-format
-#| msgid "expected function"
+#, gcc-internal-format
 msgid "expected function name"
-msgstr "ожидалась функция"
+msgstr "ожидалось имя функции"
 
-#: c/c-parser.c:14893 cp/parser.c:38064
-#, fuzzy, gcc-internal-format
-#| msgid "%q+D is not a function,"
+#: c/c-parser.c:14893 cp/parser.c:38061
+#, gcc-internal-format
 msgid "%qD does not refer to a function"
-msgstr "%q+D не является функцией,"
+msgstr "%qD не ссылается на функцию"
 
 #: c/c-parser.c:14913 c/c-parser.c:14961 cp/parser.c:1388
-#, fuzzy, gcc-internal-format
-#| msgid "an asm-specification is not allowed on a function-definition"
+#, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
-msgstr "спецификация asm не допускается при определении функции"
+msgstr "за %<#pragma acc routine%> не следует немедленно декларация или определение функции"
 
-#: c/c-parser.c:14953 cp/parser.c:38118 cp/parser.c:38160
-#, fuzzy, gcc-internal-format
-#| msgid "an asm-specification is not allowed on a function-definition"
+#: c/c-parser.c:14953 cp/parser.c:38115 cp/parser.c:38157
+#, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
-msgstr "спецификация asm не допускается при определении функции"
+msgstr "за %<#pragma acc routine%> не следует немедленно декларация или определение одиночной функции"
 
-#: c/c-parser.c:14970 cp/parser.c:38174
-#, fuzzy, gcc-internal-format
-#| msgid "%<#pragma GCC pch_preprocess%> must be first"
+#: c/c-parser.c:14970 cp/parser.c:38171
+#, gcc-internal-format
 msgid "%<#pragma acc routine%> already applied to %qD"
-msgstr "%<#pragma GCC pch_preprocess%> должна быть первой"
+msgstr "%<#pragma acc routine%> уже применена к %qD"
 
-#: c/c-parser.c:14979 cp/parser.c:38183
-#, fuzzy, gcc-internal-format
-#| msgid "%<#pragma GCC pch_preprocess%> must be first"
+#: c/c-parser.c:14979 cp/parser.c:38180
+#, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
-msgstr "%<#pragma GCC pch_preprocess%> должна быть первой"
+msgstr "%<#pragma acc routine%> должна быть применена до использования"
 
-#: c/c-parser.c:14980 cp/parser.c:38184
-#, fuzzy, gcc-internal-format
-#| msgid "%<#pragma GCC pch_preprocess%> must be first"
+#: c/c-parser.c:14980 cp/parser.c:38181
+#, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
-msgstr "%<#pragma GCC pch_preprocess%> должна быть первой"
+msgstr "%<#pragma acc routine%> должна быть применена до определения"
 
-#: c/c-parser.c:15023 cp/parser.c:37152
+#: c/c-parser.c:15023 cp/parser.c:37149
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
-msgstr ""
+msgstr "%<#pragma acc update%> должна содержать по крайней мере одну %<device%> или %<host%> клаузулу"
 
-#: c/c-parser.c:15435 cp/parser.c:34511 cp/parser.c:34537
+#: c/c-parser.c:15435 cp/parser.c:34508 cp/parser.c:34534
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "некорректный формат %<#pragma omp atomic%>"
 
-#: c/c-parser.c:15439 cp/parser.c:34568 cp/parser.c:34584
+#: c/c-parser.c:15439 cp/parser.c:34565 cp/parser.c:34581
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "некорректный оператор для %<#pragma omp atomic%>"
 
-#: c/c-parser.c:15488 cp/semantics.c:8401 cp/semantics.c:8411
-#, fuzzy, gcc-internal-format
-#| msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
+#: c/c-parser.c:15488 cp/semantics.c:8404 cp/semantics.c:8414
+#, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
-msgstr "в %<#pragma omp atomic capture%> используются две различные переменные для памяти"
+msgstr "%<#pragma omp atomic capture%> использует два различных выражения для памяти"
 
 #: c/c-parser.c:15553 c/c-parser.c:15575
 #, gcc-internal-format
@@ -41349,22 +36261,22 @@
 msgid "expected %<(%> or end of line"
 msgstr "ожидалось %<(%> или конец строки"
 
-#: c/c-parser.c:15619 cp/parser.c:35103
+#: c/c-parser.c:15619 cp/parser.c:35100
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
-msgstr ""
+msgstr "%<ordered%> параметр клаузулы меньше чем %<collapse%>"
 
-#: c/c-parser.c:15630 cp/parser.c:35114
+#: c/c-parser.c:15630 cp/parser.c:35111
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
-msgstr ""
+msgstr "%<linear%> клаузула не может задаваться вместе с %<ordered%> клаузулой с параметром"
 
-#: c/c-parser.c:15648 cp/parser.c:35141
+#: c/c-parser.c:15648 cp/parser.c:35138
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "ожидался оператор for"
 
-#: c/c-parser.c:15718 cp/semantics.c:8066 cp/semantics.c:8153
+#: c/c-parser.c:15718 cp/semantics.c:8069 cp/semantics.c:8156
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "ожидалась декларация итерации или инициализация"
@@ -41374,243 +36286,227 @@
 msgid "not enough perfectly nested loops"
 msgstr "недостаточно аккуратно вложенные циклы"
 
-#: c/c-parser.c:15862 cp/parser.c:35364
+#: c/c-parser.c:15862 cp/parser.c:35361
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr "сливаемые циклы не являются идеально вложенными"
 
-#: c/c-parser.c:15909 cp/parser.c:35184 cp/parser.c:35226 cp/pt.c:16385
+#: c/c-parser.c:15909 cp/parser.c:35181 cp/parser.c:35223 cp/pt.c:16407
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "итерационная переменная %qD не должна быть firstprivate"
 
-#: c/c-parser.c:16000 cp/parser.c:35437
-#, fuzzy, gcc-internal-format
-#| msgid "%<void%> as only parameter may not be qualified"
+#: c/c-parser.c:16000 cp/parser.c:35434
+#, gcc-internal-format
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
-msgstr "%<void%>, как единственный параметры не может содержать квалификаторы"
+msgstr "%<ordered%> клаузула с параметром не может быть задана в %qs конструкции"
 
-#: c/c-parser.c:16166 cp/parser.c:35600
-#, fuzzy, gcc-internal-format
-#| msgid "%<#pragma omp barrier%> may only be used in compound statements"
+#: c/c-parser.c:16166 cp/parser.c:35597
+#, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
-msgstr "%<#pragma omp barrier%> может использоваться только в составных операторах"
+msgstr "%<#pragma omp ordered%> с %<depend%> клаузулой может использоваться только в составных операторах"
 
-#: c/c-parser.c:16374 cp/parser.c:35799
-#, fuzzy, gcc-internal-format
-#| msgid "expected %<;%> before %qE"
+#: c/c-parser.c:16374 cp/parser.c:35796
+#, gcc-internal-format
 msgid "expected %<for%> after %qs"
-msgstr "ожидалось %<;%> перед %qE"
+msgstr "ожидался %<for%> после %qs"
 
-#: c/c-parser.c:16573 cp/parser.c:35995
-#, fuzzy, gcc-internal-format
-#| msgid "expected %<using%>"
+#: c/c-parser.c:16573 cp/parser.c:35992
+#, gcc-internal-format
 msgid "expected %<point%>"
-msgstr "ожидалось %<using%>"
+msgstr "ожидалось %<point%>"
 
-#: c/c-parser.c:16793 cp/parser.c:36232
+#: c/c-parser.c:16793 cp/parser.c:36229
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
-msgstr ""
+msgstr "%<#pragma omp target data%> с map-type отличном от %<to%>, %<from%>, %<tofrom%> или %<alloc%> на %<map%> клаузуле"
 
-#: c/c-parser.c:16806 cp/parser.c:36245
+#: c/c-parser.c:16806 cp/parser.c:36242
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
-msgstr ""
+msgstr "%<#pragma omp target data%> должна содержать хотя бы одну %<map%> клаузулу"
 
-#: c/c-parser.c:16853 cp/parser.c:36470
+#: c/c-parser.c:16853 cp/parser.c:36467
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
-msgstr ""
+msgstr "%<#pragma omp target update%> должна содержать хотя бы одну %<from%> или %<to%> клаузулу"
 
-#: c/c-parser.c:16925 cp/parser.c:36325
+#: c/c-parser.c:16925 cp/parser.c:36322
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
-msgstr ""
+msgstr "%<#pragma omp target enter data%> с map-type отличном от %<to%> или %<alloc%> на %<map%> клаузуле"
 
-#: c/c-parser.c:16937 cp/parser.c:36337
+#: c/c-parser.c:16937 cp/parser.c:36334
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
-msgstr ""
+msgstr "%<#pragma omp target enter data%> должна содержать хотя бы одну %<map%> клаузулу"
 
-#: c/c-parser.c:17011 cp/parser.c:36414
+#: c/c-parser.c:17011 cp/parser.c:36411
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
-msgstr ""
+msgstr "%<#pragma omp target exit data%> с map-type отличном от %<from%>, %<release%> или %<delete%> на %<map%> клаузуле"
 
-#: c/c-parser.c:17024 cp/parser.c:36427
+#: c/c-parser.c:17024 cp/parser.c:36424
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
-msgstr ""
+msgstr "%<#pragma omp target exit data%> должна содержать хотя бы одну %<map%> клаузулу"
 
-#: c/c-parser.c:17238 cp/parser.c:36680
+#: c/c-parser.c:17238 cp/parser.c:36677
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
-msgstr ""
+msgstr "%<#pragma omp target%> с map-type отличном от %<to%>, %<from%>, %<tofrom%> или %<alloc%> на %<map%> клаузуле"
 
 #: c/c-parser.c:17288
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> must be followed by function declaration or definition or another %<#pragma omp declare simd%>"
-msgstr ""
+msgstr "за %<#pragma omp declare simd%> должна следовать декларация функции или определение или другая %<#pragma omp declare simd%>"
 
 #: c/c-parser.c:17338 c/c-parser.c:17365
-#, fuzzy, gcc-internal-format
-#| msgid "%<#pragma align%> must appear before the declaration of %D, ignoring"
+#, gcc-internal-format
 msgid "%<#pragma omp declare simd%> must be followed by function declaration or definition"
-msgstr "%<#pragma align%> должна предшествовать декларации %D, игнорируется"
+msgstr "за %<#pragma omp declare simd%> должна следовать декларация или определение функции"
 
 #: c/c-parser.c:17387
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
-msgstr ""
+msgstr "%<#pragma omp declare simd%>, за которой не следует немедленно декларация функции или определение"
 
-#: c/c-parser.c:17395 cp/parser.c:37273
+#: c/c-parser.c:17395 cp/parser.c:37270
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
-msgstr ""
+msgstr "%<#pragma omp declare simd%>, за которой не следует немедленно одиночная декларация функции или определение"
 
-#: c/c-parser.c:17474 cp/parser.c:37343
+#: c/c-parser.c:17474 cp/parser.c:37340
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> with clauses in between %<#pragma omp declare target%> without clauses and %<#pragma omp end declare target%>"
-msgstr ""
+msgstr "%<#pragma omp declare target%> с клаузулами между %<#pragma omp declare target%> без клаузул и %<#pragma omp end declare target%>"
 
-#: c/c-parser.c:17493 cp/parser.c:37362
+#: c/c-parser.c:17493 cp/parser.c:37359
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
-msgstr ""
+msgstr "%qD задан и в declare target %<link%> и в %<to%> клаузулах"
 
-#: c/c-parser.c:17534 cp/parser.c:37409
-#, fuzzy, gcc-internal-format
-#| msgid "expected %<try%>"
+#: c/c-parser.c:17534 cp/parser.c:37406
+#, gcc-internal-format
 msgid "expected %<target%>"
-msgstr "ожидалось %<try%>"
+msgstr "ожидалось %<target%>"
 
-#: c/c-parser.c:17541 cp/parser.c:37416
-#, fuzzy, gcc-internal-format
-#| msgid "expected %<decltype%>"
+#: c/c-parser.c:17541 cp/parser.c:37413
+#, gcc-internal-format
 msgid "expected %<declare%>"
-msgstr "ожидалось %<decltype%>"
+msgstr "ожидалось %<declare%>"
 
-#: c/c-parser.c:17547 cp/parser.c:37423
-#, fuzzy, gcc-internal-format
-#| msgid "%<#pragma GCC pop_options%> without a corresponding %<#pragma GCC push_options%>"
+#: c/c-parser.c:17547 cp/parser.c:37420
+#, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
-msgstr "%<#pragma GCC pop_options%> без соответствующей %<#pragma GCC push_options%>"
+msgstr "%<#pragma omp end declare target%> без соответствующей %<#pragma omp declare target%>"
 
 #: c/c-parser.c:17575
-#, fuzzy, gcc-internal-format
-#| msgid "a template declaration cannot appear at block scope"
+#, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> not at file or block scope"
-msgstr "декларация шаблона не может появляться в блоке"
+msgstr "%<#pragma omp declare reduction%> не в контексте файла или блока"
 
 #: c/c-parser.c:17652
 #, gcc-internal-format
 msgid "predeclared arithmetic type in %<#pragma omp declare reduction%>"
-msgstr ""
+msgstr "предекларированный арифметический тип в %<#pragma omp declare reduction%>"
 
 #: c/c-parser.c:17656
 #, gcc-internal-format
 msgid "function or array type in %<#pragma omp declare reduction%>"
-msgstr ""
+msgstr "функциональный или массивный тип в %<#pragma omp declare reduction%>"
 
 #: c/c-parser.c:17659
-#, fuzzy, gcc-internal-format
-#| msgid "expected %<#pragma omp%> clause before %<decltype%>"
+#, gcc-internal-format
 msgid "%<_Atomic%> qualified type in %<#pragma omp declare reduction%>"
-msgstr "ожидалась конструкция %<#pragma omp%> перед %<decltype%>"
+msgstr "%<_Atomic%> квалифицированный тип в %<#pragma omp declare reduction%>"
 
 #: c/c-parser.c:17662
 #, gcc-internal-format
 msgid "const, volatile or restrict qualified type in %<#pragma omp declare reduction%>"
-msgstr ""
+msgstr "const, volatile или restrict квалифицированный тип в %<#pragma omp declare reduction%>"
 
 #: c/c-parser.c:17670
 #, gcc-internal-format
 msgid "redeclaration of %qs %<#pragma omp declare reduction%> for type %qT"
-msgstr ""
+msgstr "повторная декларация %qs %<#pragma omp declare reduction%> для типа %qT"
 
 #: c/c-parser.c:17679
-#, fuzzy, gcc-internal-format
-#| msgid "expected %<#pragma omp%> clause before %<decltype%>"
+#, gcc-internal-format
 msgid "previous %<#pragma omp declare reduction%>"
-msgstr "ожидалась конструкция %<#pragma omp%> перед %<decltype%>"
+msgstr "предыдущая %<#pragma omp declare reduction%>"
 
 #: c/c-parser.c:17796
-#, fuzzy, gcc-internal-format
-#| msgid "expected %<(%> or end of line"
+#, gcc-internal-format
 msgid "expected %<omp_priv%> or function-name"
-msgstr "ожидалось %<(%> или конец строки"
+msgstr "ожидалось %<omp_priv%> или имя функции"
 
 #: c/c-parser.c:17807
-#, fuzzy, gcc-internal-format
-#| msgid "expected function"
+#, gcc-internal-format
 msgid "expected function-name %<(%>"
-msgstr "ожидалась функция"
+msgstr "ожидалось имя функции %<(%>"
 
 #: c/c-parser.c:17826
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
-msgstr ""
+msgstr "одним из аргументов вызова инициализатора должен быть %<&omp_priv%>"
 
-#: c/c-parser.c:17947 cp/parser.c:37868
-#, fuzzy, gcc-internal-format
-#| msgid "expected %<#pragma omp section%> or %<}%>"
+#: c/c-parser.c:17947 cp/parser.c:37865
+#, gcc-internal-format
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
-msgstr "ожидалось %<#pragma omp section%> или %<}%>"
+msgstr "ожидалось %<simd%> или %<reduction%> или %<target%>"
 
-#: c/c-parser.c:18162 cp/semantics.c:7531
+#: c/c-parser.c:18162 cp/semantics.c:7534
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE объявлена %<threadprivate%> после первого использования"
 
-#: c/c-parser.c:18164 cp/semantics.c:7533
+#: c/c-parser.c:18164 cp/semantics.c:7536
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "автоматическая переменная %qE не может быть %<threadprivate%>"
 
-#: c/c-parser.c:18168 cp/semantics.c:7535
+#: c/c-parser.c:18168 cp/semantics.c:7538
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%<threadprivate%> %qE имеет неполный тип"
 
-#: c/c-parser.c:18368 cp/parser.c:38565
+#: c/c-parser.c:18368 cp/parser.c:38562
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr "%<__transaction_cancel%> без включения транзакционной памяти"
 
-#: c/c-parser.c:18374 cp/parser.c:38571
+#: c/c-parser.c:18374 cp/parser.c:38568
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr "%<__transaction_cancel%> внутри %<__transaction_relaxed%>"
 
-#: c/c-parser.c:18383 cp/parser.c:38580
+#: c/c-parser.c:18383 cp/parser.c:38577
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr "внешний %<__transaction_cancel%> не внутри внешнего %<__transaction_atomic%>"
 
-#: c/c-parser.c:18385 cp/parser.c:38583
+#: c/c-parser.c:18385 cp/parser.c:38580
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr "  либо %<transaction_may_cancel_outer%> функция"
 
-#: c/c-parser.c:18391 cp/parser.c:38589
+#: c/c-parser.c:18391 cp/parser.c:38586
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr "%<__transaction_cancel%> не внутри %<__transaction_atomic%>"
 
 #: c/c-parser.c:18472
-#, fuzzy, gcc-internal-format
-#| msgid "enclosing parallel"
+#, gcc-internal-format
 msgid "no closing brace"
-msgstr "объемлющая конструкция parallel"
+msgstr "нет закрывающей скобки"
 
 #: c/c-typeck.c:223
-#, fuzzy, gcc-internal-format
-#| msgid "%qD has an incomplete type"
+#, gcc-internal-format
 msgid "%qD has an incomplete type %qT"
-msgstr "%qD имеет неполный тип"
+msgstr "%qD имеет неполный тип %qT"
 
-#: c/c-typeck.c:237 c/c-typeck.c:9994 c/c-typeck.c:10036 cp/call.c:4147
+#: c/c-typeck.c:237 c/c-typeck.c:9999 c/c-typeck.c:10041 cp/call.c:4147
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "неправильное использование void-выражения"
@@ -41626,17 +36522,15 @@
 msgstr "неправильное использование массива с неопределенными границами"
 
 #: c/c-typeck.c:259
-#, fuzzy, gcc-internal-format
-#| msgid "invalid use of undefined type %<%s %E%>"
+#, gcc-internal-format
 msgid "invalid use of undefined type %qT"
-msgstr "неправильное использование неопределенного типа %<%s %E%>"
+msgstr "некорректное использование неопределенного типа %qT"
 
 #. If this type has a typedef-name, the TYPE_NAME is a TYPE_DECL.
 #: c/c-typeck.c:262
-#, fuzzy, gcc-internal-format
-#| msgid "invalid use of incomplete typedef %qD"
+#, gcc-internal-format
 msgid "invalid use of incomplete typedef %qT"
-msgstr "неправильное использование недоопределенного typedef %qD"
+msgstr "некорректное использование неполного typedef %qT"
 
 #: c/c-typeck.c:335
 #, gcc-internal-format
@@ -41664,10 +36558,9 @@
 msgstr "недопустимо смешивание операндов плавающего десятичного и другого плавающего типа"
 
 #: c/c-typeck.c:1295
-#, fuzzy, gcc-internal-format
-#| msgid "pointer target types incompatible in C++"
+#, gcc-internal-format
 msgid "pointers to arrays with different qualifiers are incompatible in ISO C"
-msgstr "указуемые типы несовместимы в C++"
+msgstr "указатели на массивы с разными квалификаторами не совместимы в ISO C"
 
 #: c/c-typeck.c:1299
 #, gcc-internal-format
@@ -41689,13 +36582,12 @@
 msgid "converting an array compound literal to a pointer is ill-formed in C++"
 msgstr "конвертация составного литерала-массива в указатель не годится в C++"
 
-#: c/c-typeck.c:2417 c/c-typeck.c:8641
-#, fuzzy, gcc-internal-format
-#| msgid "%qT has no member named %qE"
+#: c/c-typeck.c:2417 c/c-typeck.c:8646
+#, gcc-internal-format
 msgid "%qT has no member named %qE; did you mean %qE?"
-msgstr "%qT не содержит элемента с именем %qE"
+msgstr "%qT не содержит элемент с именем %qE; имелось в виду %qE?"
 
-#: c/c-typeck.c:2421 c/c-typeck.c:8645
+#: c/c-typeck.c:2421 c/c-typeck.c:8650
 #, gcc-internal-format
 msgid "%qT has no member named %qE"
 msgstr "%qT не содержит элемента с именем %qE"
@@ -41703,17 +36595,17 @@
 #: c/c-typeck.c:2430
 #, gcc-internal-format
 msgid "accessing a member %qE of an atomic structure %qE"
-msgstr ""
+msgstr "доступ к элементу %qE атомарной структуры %qE"
 
 #: c/c-typeck.c:2433
 #, gcc-internal-format
 msgid "accessing a member %qE of an atomic union %qE"
-msgstr ""
+msgstr "доступ к элементу %qE атомарного объединения %qE"
 
 #: c/c-typeck.c:2493
 #, gcc-internal-format
 msgid "%qE is a pointer; did you mean to use %<->%>?"
-msgstr ""
+msgstr "%qE указатель; имелось в виду использовать %<->%>?"
 
 #: c/c-typeck.c:2499
 #, gcc-internal-format
@@ -41721,10 +36613,9 @@
 msgstr "выборка элемента %qE из объекта, не являющегося структурой или объединением"
 
 #: c/c-typeck.c:2550
-#, fuzzy, gcc-internal-format
-#| msgid "dereferencing pointer to incomplete type"
+#, gcc-internal-format
 msgid "dereferencing pointer to incomplete type %qT"
-msgstr "доступ по указателю на неполный тип"
+msgstr "доступ по указателю на неполный тип %qT"
 
 #: c/c-typeck.c:2557
 #, gcc-internal-format
@@ -41764,25 +36655,22 @@
 #: c/c-typeck.c:2905 cp/typeck.c:1698
 #, gcc-internal-format
 msgid "%<sizeof%> on array function parameter %qE will return size of %qT"
-msgstr ""
+msgstr "%<sizeof%> от массивного параметра функции %qE вернет размер от %qT"
 
 #: c/c-typeck.c:3053
-#, fuzzy, gcc-internal-format
-#| msgid "called object %qE is not a function"
+#, gcc-internal-format
 msgid "called object %qE is not a function or function pointer"
-msgstr "вызываемый объект %qE не является функцией"
+msgstr "вызываемый объект %qE не является функцией или указателем на функцию"
 
 #: c/c-typeck.c:3058
-#, fuzzy, gcc-internal-format
-#| msgid "called object %qE is not a function"
+#, gcc-internal-format
 msgid "called object %qD is not a function or function pointer"
-msgstr "вызываемый объект %qE не является функцией"
+msgstr "вызываемый объект %qD не является функцией или указателем на функцию"
 
 #: c/c-typeck.c:3064
-#, fuzzy, gcc-internal-format
-#| msgid "called object %qE is not a function"
+#, gcc-internal-format
 msgid "called object is not a function or function pointer"
-msgstr "вызываемый объект %qE не является функцией"
+msgstr "вызываемый объект не является функцией или указателем на функцию"
 
 #. This situation leads to run-time undefined behavior.  We can't,
 #. therefore, simply error unless we can prove that all possible
@@ -41873,16 +36761,14 @@
 msgstr "сравнение со строковым литералом приводит к неопределенному поведению"
 
 #: c/c-typeck.c:3736 c/c-typeck.c:3743 cp/typeck.c:4772 cp/typeck.c:4792
-#, fuzzy, gcc-internal-format
-#| msgid "comparison between pointer and integer"
+#, gcc-internal-format
 msgid "comparison between pointer and zero character constant"
-msgstr "сравнение указателя и целого"
+msgstr "сравнение указателя и нулевой символьной константы"
 
 #: c/c-typeck.c:3738 c/c-typeck.c:3745 cp/typeck.c:4775 cp/typeck.c:4795
-#, fuzzy, gcc-internal-format
-#| msgid "casting %qT to %qT does not dereference pointer"
+#, gcc-internal-format
 msgid "did you mean to dereference the pointer?"
-msgstr "преобразование %qT в %qT не снимает указатель"
+msgstr "вы хотели перейти по указателю?"
 
 #: c/c-typeck.c:3764
 #, gcc-internal-format
@@ -41899,1306 +36785,1239 @@
 msgid "pointer to a function used in subtraction"
 msgstr "указатель на функцию в операции вычитания"
 
-#: c/c-typeck.c:3847
+#: c/c-typeck.c:3852
 #, gcc-internal-format
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "арифметическая операция над указателем на неполный тип"
 
-#: c/c-typeck.c:3852 cp/typeck.c:5562
-#, fuzzy, gcc-internal-format
-#| msgid "arithmetic on pointer to an incomplete type"
+#: c/c-typeck.c:3857 cp/typeck.c:5562
+#, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
-msgstr "арифметическая операция над указателем на неполный тип"
+msgstr "арифметическая операция над указателем на пустой агрегат"
 
-#: c/c-typeck.c:4283
-#, fuzzy, gcc-internal-format
-#| msgid "expected boolean expression"
+#: c/c-typeck.c:4288
+#, gcc-internal-format
 msgid "%<~%> on a boolean expression"
-msgstr "ожидалось boolean выражение"
+msgstr "%<~%> над булевым выражением"
 
-#: c/c-typeck.c:4287
+#: c/c-typeck.c:4292
 #, gcc-internal-format
 msgid "did you mean to use logical not?"
-msgstr ""
+msgstr "имелось в виду использовать логическое not?"
 
-#: c/c-typeck.c:4296
+#: c/c-typeck.c:4301
 #, gcc-internal-format
 msgid "ISO C does not support %<~%> for complex conjugation"
 msgstr "в ISO C не поддерживается использование %<~%> для обозначения операции комплексного сопряжения"
 
-#: c/c-typeck.c:4335
+#: c/c-typeck.c:4340
 #, gcc-internal-format
 msgid "wrong type argument to unary exclamation mark"
 msgstr "неверный тип аргумента для унарного `!'"
 
-#: c/c-typeck.c:4393
+#: c/c-typeck.c:4398
 #, gcc-internal-format
 msgid "increment of enumeration value is invalid in C++"
 msgstr "инкрементация значения перечислимого типа некорректна в C++"
 
-#: c/c-typeck.c:4396
+#: c/c-typeck.c:4401
 #, gcc-internal-format
 msgid "decrement of enumeration value is invalid in C++"
 msgstr "декрементация значения перечислимого типа некорректна в C++"
 
-#: c/c-typeck.c:4403
-#, fuzzy, gcc-internal-format
-#| msgid "expected boolean expression"
+#: c/c-typeck.c:4408
+#, gcc-internal-format
 msgid "increment of a boolean expression"
-msgstr "ожидалось boolean выражение"
+msgstr "инкремент булева выражения"
 
-#: c/c-typeck.c:4406
-#, fuzzy, gcc-internal-format
-#| msgid "expected boolean expression"
+#: c/c-typeck.c:4411
+#, gcc-internal-format
 msgid "decrement of a boolean expression"
-msgstr "ожидалось boolean выражение"
+msgstr "декремент булева выражения"
 
-#: c/c-typeck.c:4422
+#: c/c-typeck.c:4427
 #, gcc-internal-format
 msgid "ISO C does not support %<++%> and %<--%> on complex types"
 msgstr "в ISO C операции %<++%> и %<--%> для комплексных типов не поддерживаются"
 
-#: c/c-typeck.c:4447 c/c-typeck.c:4481
+#: c/c-typeck.c:4452 c/c-typeck.c:4486
 #, gcc-internal-format
 msgid "wrong type argument to increment"
 msgstr "неверный тип аргумента инкрементации"
 
-#: c/c-typeck.c:4449 c/c-typeck.c:4484
+#: c/c-typeck.c:4454 c/c-typeck.c:4489
 #, gcc-internal-format
 msgid "wrong type argument to decrement"
 msgstr "неверный тип аргумента декрементации"
 
-#: c/c-typeck.c:4469
-#, fuzzy, gcc-internal-format
-#| msgid "cannot increment a pointer to incomplete type %qT"
+#: c/c-typeck.c:4474
+#, gcc-internal-format
 msgid "increment of pointer to an incomplete type %qT"
-msgstr "невозможно инкрементировать указатель на неполный тип %qT"
+msgstr "инкремент указателя на неполный тип %qT"
 
-#: c/c-typeck.c:4473
-#, fuzzy, gcc-internal-format
-#| msgid "cannot decrement a pointer to incomplete type %qT"
+#: c/c-typeck.c:4478
+#, gcc-internal-format
 msgid "decrement of pointer to an incomplete type %qT"
-msgstr "невозможно декрементировать указатель на неполный тип %qT"
+msgstr "декремент указателя на неполный тип %qT"
 
-#: c/c-typeck.c:4577
+#: c/c-typeck.c:4582
 #, gcc-internal-format
 msgid "taking address of expression of type %<void%>"
 msgstr "взятие адреса от выражения типа %<void%>"
 
-#: c/c-typeck.c:4636
+#: c/c-typeck.c:4641
 #, gcc-internal-format
 msgid "cannot take address of bit-field %qD"
 msgstr "некорректная попытка взять адрес битового поля %qD"
 
-#: c/c-typeck.c:4649
-#, fuzzy, gcc-internal-format
-#| msgid "cannot take the address of %<this%>, which is an rvalue expression"
+#: c/c-typeck.c:4654
+#, gcc-internal-format
 msgid "cannot take address of scalar with reverse storage order"
-msgstr "нельзя взять адрес от %<this%>, поскольку это rvalue-выражение"
+msgstr "нельзя взять адрес от скаляра с обратным порядком памяти"
 
-#: c/c-typeck.c:4657
-#, fuzzy, gcc-internal-format
-#| msgid "address of register variable %qD requested"
+#: c/c-typeck.c:4662
+#, gcc-internal-format
 msgid "address of array with reverse scalar storage order requested"
-msgstr "запрошен адрес регистровой переменной %qD"
+msgstr "адрес массива с обратным порядком скалярной памяти"
 
-#: c/c-typeck.c:4838
+#: c/c-typeck.c:4843
 #, gcc-internal-format
 msgid "global register variable %qD used in nested function"
 msgstr "глобальная регистровая переменная %qD использована во вложенной функции"
 
-#: c/c-typeck.c:4841
+#: c/c-typeck.c:4846
 #, gcc-internal-format
 msgid "register variable %qD used in nested function"
 msgstr "регистровая переменная %qD использована во вложенной функции"
 
-#: c/c-typeck.c:4846
+#: c/c-typeck.c:4851
 #, gcc-internal-format
 msgid "address of global register variable %qD requested"
 msgstr "запрошен адрес глобальной регистровой переменной %qD"
 
-#: c/c-typeck.c:4848
+#: c/c-typeck.c:4853
 #, gcc-internal-format
 msgid "address of register variable %qD requested"
 msgstr "запрошен адрес регистровой переменной %qD"
 
-#: c/c-typeck.c:4951
+#: c/c-typeck.c:4956
 #, gcc-internal-format
 msgid "non-lvalue array in conditional expression"
 msgstr "не lvalue-массив в условном выражении"
 
-#: c/c-typeck.c:5033
+#: c/c-typeck.c:5038
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other result of conditional"
 msgstr "неявная конверсия из %qT в %qT для совместимости с другим результатом условного выражения"
 
-#: c/c-typeck.c:5092 c/c-typeck.c:5098
+#: c/c-typeck.c:5097 c/c-typeck.c:5103
 #, gcc-internal-format
 msgid "operand of ?: changes signedness from %qT to %qT due to unsignedness of other operand"
 msgstr ""
 
-#: c/c-typeck.c:5115
+#: c/c-typeck.c:5120
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr with only one void side"
 msgstr "в ISO C запрещены условные выражения, где только одна из альтернатив имеет тип void"
 
-#: c/c-typeck.c:5132
+#: c/c-typeck.c:5137
 #, gcc-internal-format
 msgid "pointers to disjoint address spaces used in conditional expression"
 msgstr "указатели на не связанные адресные пространства в условном выражении"
 
-#: c/c-typeck.c:5143 c/c-typeck.c:5160
-#, fuzzy, gcc-internal-format
-#| msgid "pointer type mismatch in conditional expression"
+#: c/c-typeck.c:5148 c/c-typeck.c:5165
+#, gcc-internal-format
 msgid "pointer to array loses qualifier in conditional expression"
-msgstr "несоответствие указательных типов в условном выражении"
+msgstr "указатель на массив теряет квалификатор в условном выражении"
 
-#: c/c-typeck.c:5148 c/c-typeck.c:5165
+#: c/c-typeck.c:5153 c/c-typeck.c:5170
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr between %<void *%> and function pointer"
 msgstr "в ISO C запрещены условные выражения, с альтернативами типа %<void *%> и указатель на функцию"
 
-#: c/c-typeck.c:5178
+#: c/c-typeck.c:5183
 #, gcc-internal-format
 msgid "pointer type mismatch in conditional expression"
 msgstr "несоответствие указательных типов в условном выражении"
 
-#: c/c-typeck.c:5187 c/c-typeck.c:5198
+#: c/c-typeck.c:5192 c/c-typeck.c:5203
 #, gcc-internal-format
 msgid "pointer/integer type mismatch in conditional expression"
 msgstr "несоответствие типов указатель/целое в условном выражении"
 
-#: c/c-typeck.c:5336
+#: c/c-typeck.c:5341
 #, gcc-internal-format
 msgid "left-hand operand of comma expression has no effect"
 msgstr "левый операнд операции `запятая' не имеет побочных эффектов"
 
-#: c/c-typeck.c:5354 c/c-typeck.c:10636
-#, fuzzy, gcc-internal-format
-#| msgid "left-hand operand of comma expression has no effect"
+#: c/c-typeck.c:5359 c/c-typeck.c:10641
+#, gcc-internal-format
 msgid "right-hand operand of comma expression has no effect"
-msgstr "левый операнд операции `запятая' не имеет побочных эффектов"
+msgstr "правый операнд comma выражения не имеет эффекта"
 
-#: c/c-typeck.c:5423
+#: c/c-typeck.c:5428
 msgid "cast adds %q#v qualifier to function type"
 msgstr "приведение типа добавляет квалификатор %q#v к типу функции"
 
-#: c/c-typeck.c:5429
-#, fuzzy
-#| msgid "cast discards %q#v qualifier from pointer target type"
+#: c/c-typeck.c:5434
 msgid "cast discards %qv qualifier from pointer target type"
-msgstr "приведение типа отменяет квалификатор %q#v указуемого типа"
+msgstr "приведение типа отбрасывает квалификатор типа цели указателя"
 
-#: c/c-typeck.c:5464
+#: c/c-typeck.c:5469
 #, gcc-internal-format
 msgid "to be safe all intermediate pointers in cast from %qT to %qT must be %<const%> qualified"
 msgstr "для надежности все промежуточные указатели в приведении типа от %qT к %qT должны быть снабжены квалификатором %<const%>"
 
-#: c/c-typeck.c:5554
+#: c/c-typeck.c:5559
 #, gcc-internal-format
 msgid "cast specifies array type"
 msgstr "тип массива в операции приведения типов"
 
-#: c/c-typeck.c:5560
+#: c/c-typeck.c:5565
 #, gcc-internal-format
 msgid "cast specifies function type"
 msgstr "тип функции в операции приведения типов"
 
-#: c/c-typeck.c:5575
+#: c/c-typeck.c:5580
 #, gcc-internal-format
 msgid "ISO C forbids casting nonscalar to the same type"
 msgstr "в ISO C приведение нескалярного типа к тому же типу запрещено"
 
-#: c/c-typeck.c:5595
+#: c/c-typeck.c:5600
 #, gcc-internal-format
 msgid "ISO C forbids casts to union type"
 msgstr "в ISO C приведение к типу объединения запрещено"
 
-#: c/c-typeck.c:5605
+#: c/c-typeck.c:5610
 #, gcc-internal-format
 msgid "cast to union type from type not present in union"
 msgstr "приведение к типу объединения от типа, отсутствующего в объединении"
 
-#: c/c-typeck.c:5640
+#: c/c-typeck.c:5645
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint generic address space pointer"
 msgstr "приведение типа к указателю на адресное пространство %s от указателя на не связанное общее адресное пространство"
 
-#: c/c-typeck.c:5645
+#: c/c-typeck.c:5650
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to generic address space pointer from disjoint %s address space pointer"
 msgstr "приведение типа к указателю на общее адресное пространство от указателя на не связанное адресное пространство %s"
 
-#: c/c-typeck.c:5650
+#: c/c-typeck.c:5655
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint %s address space pointer"
 msgstr "приведение типа к указателю на адресное пространство %s от указателя на не связанное адресное пространство %s"
 
-#: c/c-typeck.c:5670
+#: c/c-typeck.c:5675
 #, gcc-internal-format
 msgid "cast increases required alignment of target type"
 msgstr "приведение типа требует большего выравнивания, чем исходный тип"
 
-#: c/c-typeck.c:5681
+#: c/c-typeck.c:5686
 #, gcc-internal-format
 msgid "cast from pointer to integer of different size"
 msgstr "приведение указателя к целому другого размера"
 
-#: c/c-typeck.c:5686
+#: c/c-typeck.c:5691
 #, gcc-internal-format
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "приведение вызова функции типа %qT к несоответствующему типу %qT"
 
-#: c/c-typeck.c:5695 cp/typeck.c:7811
+#: c/c-typeck.c:5700 cp/typeck.c:7811
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "приведение к типу указателя от целого другого размера"
 
-#: c/c-typeck.c:5709
+#: c/c-typeck.c:5714
 #, gcc-internal-format
 msgid "ISO C forbids conversion of function pointer to object pointer type"
 msgstr "ISO C запрещает преобразование указателя на функцию к указателю на объект"
 
-#: c/c-typeck.c:5718
+#: c/c-typeck.c:5723
 #, gcc-internal-format
 msgid "ISO C forbids conversion of object pointer to function pointer type"
 msgstr "ISO C запрещает преобразование указателя на объект к указателю на функцию "
 
-#: c/c-typeck.c:5728
-#, fuzzy, gcc-internal-format
-#| msgid "can%'t convert from incomplete type %qT to %qT"
+#: c/c-typeck.c:5733
+#, gcc-internal-format
 msgid "cast between incompatible function types from %qT to %qT"
-msgstr "невозможно преобразовать неполный тип %qT в %qT"
+msgstr ""
 
-#: c/c-typeck.c:5815
+#: c/c-typeck.c:5820
 #, gcc-internal-format
 msgid "defining a type in a cast is invalid in C++"
 msgstr "определение типа в приведении типа некорректно в C++"
 
-#: c/c-typeck.c:5856
-#, fuzzy, gcc-internal-format
-#| msgid "assignment suppression"
+#: c/c-typeck.c:5861
+#, gcc-internal-format
 msgid "assignment to expression with array type"
-msgstr "подавление присваивания"
+msgstr "присваивание выражению с массивным типом"
 
-#: c/c-typeck.c:5982
+#: c/c-typeck.c:5987
 #, gcc-internal-format
 msgid "enum conversion in assignment is invalid in C++"
 msgstr "преобразование перечислимого типа в присваивании некорректно в C++"
 
-#: c/c-typeck.c:6180 c/c-typeck.c:6202 c/c-typeck.c:6226
+#: c/c-typeck.c:6185 c/c-typeck.c:6207 c/c-typeck.c:6231
 #, gcc-internal-format
 msgid "(near initialization for %qs)"
 msgstr "(где-то рядом с инициализацией для %qs)"
 
-#: c/c-typeck.c:6241
+#: c/c-typeck.c:6246
 #, gcc-internal-format
 msgid "array initialized from parenthesized string constant"
 msgstr "инициализация символьного массива строкой в скобках"
 
-#: c/c-typeck.c:6284 c/c-typeck.c:6476 c/c-typeck.c:6908
+#: c/c-typeck.c:6289 c/c-typeck.c:6481 c/c-typeck.c:6913
 #, gcc-internal-format
 msgid "expected %qT but argument is of type %qT"
 msgstr "ожидался тип %qT, но аргумент имеет тип %qT"
 
-#: c/c-typeck.c:6471
+#: c/c-typeck.c:6476
 #, gcc-internal-format
 msgid "enum conversion when passing argument %d of %qE is invalid in C++"
 msgstr "преобразование перечислимого типа при передаче аргумента %d %qE недопустимо в C++"
 
-#: c/c-typeck.c:6480
-#, fuzzy, gcc-internal-format
-#| msgid "enum conversion in assignment is invalid in C++"
+#: c/c-typeck.c:6485
+#, gcc-internal-format
 msgid "enum conversion from %qT to %qT in assignment is invalid in C++"
-msgstr "преобразование перечислимого типа в присваивании некорректно в C++"
+msgstr ""
 
-#: c/c-typeck.c:6484
-#, fuzzy, gcc-internal-format
-#| msgid "enum conversion in initialization is invalid in C++"
+#: c/c-typeck.c:6489
+#, gcc-internal-format
 msgid "enum conversion from %qT to %qT in initialization is invalid in C++"
-msgstr "преобразование типов в инициализаторе недопустимо в C++"
+msgstr ""
 
-#: c/c-typeck.c:6489
-#, fuzzy, gcc-internal-format
-#| msgid "enum conversion in return is invalid in C++"
+#: c/c-typeck.c:6494
+#, gcc-internal-format
 msgid "enum conversion from %qT to %qT in return is invalid in C++"
-msgstr "преобразование типов в операторе return недопустимо в C++"
+msgstr ""
 
-#: c/c-typeck.c:6523
+#: c/c-typeck.c:6528
 #, gcc-internal-format
 msgid "cannot pass rvalue to reference parameter"
 msgstr "передача rvalue-выражения в качестве параметра-ссылки запрещена"
 
-#: c/c-typeck.c:6656 c/c-typeck.c:6942
+#: c/c-typeck.c:6661 c/c-typeck.c:6947
 msgid "passing argument %d of %qE makes %q#v qualified function pointer from unqualified"
 msgstr "передача аргумента %d функции %qE добавляет квалификатор %q#v к указателю на функцию без квалификаторов"
 
-#: c/c-typeck.c:6659 c/c-typeck.c:6945
+#: c/c-typeck.c:6664 c/c-typeck.c:6950
 msgid "assignment makes %q#v qualified function pointer from unqualified"
 msgstr "присваивание добавляет квалификатор %q#v к указателю на функцию без квалификаторов"
 
-#: c/c-typeck.c:6662 c/c-typeck.c:6947
+#: c/c-typeck.c:6667 c/c-typeck.c:6952
 msgid "initialization makes %q#v qualified function pointer from unqualified"
 msgstr "инициализация добавляет квалификатор %q#v к указателю на функцию без квалификаторов"
 
-#: c/c-typeck.c:6665 c/c-typeck.c:6949
+#: c/c-typeck.c:6670 c/c-typeck.c:6954
 msgid "return makes %q#v qualified function pointer from unqualified"
 msgstr "возврат значения добавляет квалификатор %q#v к указателю на функцию без квалификаторов"
 
-#: c/c-typeck.c:6673 c/c-typeck.c:6840 c/c-typeck.c:6883
+#: c/c-typeck.c:6678 c/c-typeck.c:6845 c/c-typeck.c:6888
 msgid "passing argument %d of %qE discards %qv qualifier from pointer target type"
 msgstr "передача аргумента %d %qE отменяет квалификатор %qv указуемого типа"
 
-#: c/c-typeck.c:6675 c/c-typeck.c:6842 c/c-typeck.c:6885
+#: c/c-typeck.c:6680 c/c-typeck.c:6847 c/c-typeck.c:6890
 msgid "assignment discards %qv qualifier from pointer target type"
 msgstr "присваивание отменяет квалификатор %qv указуемого типа"
 
-#: c/c-typeck.c:6677 c/c-typeck.c:6844 c/c-typeck.c:6887
+#: c/c-typeck.c:6682 c/c-typeck.c:6849 c/c-typeck.c:6892
 msgid "initialization discards %qv qualifier from pointer target type"
 msgstr "инициализация отменяет квалификатор %qv указуемого типа"
 
-#: c/c-typeck.c:6679 c/c-typeck.c:6846 c/c-typeck.c:6889
+#: c/c-typeck.c:6684 c/c-typeck.c:6851 c/c-typeck.c:6894
 msgid "return discards %qv qualifier from pointer target type"
 msgstr "возврат результата отменяет квалификатор %qv указуемого типа"
 
-#: c/c-typeck.c:6688
+#: c/c-typeck.c:6693
 #, gcc-internal-format
 msgid "ISO C prohibits argument conversion to union type"
 msgstr "в ISO C преобразование аргумента к типу объединения запрещено"
 
-#: c/c-typeck.c:6750
+#: c/c-typeck.c:6755
 #, gcc-internal-format
 msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgstr "неявная конверсия из %qT в %qT, запрещенная в C++"
 
-#: c/c-typeck.c:6762
+#: c/c-typeck.c:6767
 #, gcc-internal-format
 msgid "passing argument %d of %qE from pointer to non-enclosed address space"
 msgstr "передача аргумента %d %qE по указателю на не замкнутое адресное пространство"
 
-#: c/c-typeck.c:6766
+#: c/c-typeck.c:6771
 #, gcc-internal-format
 msgid "assignment from pointer to non-enclosed address space"
 msgstr "присваивание по указателю на не замкнутое адресное пространство"
 
-#: c/c-typeck.c:6770
+#: c/c-typeck.c:6775
 #, gcc-internal-format
 msgid "initialization from pointer to non-enclosed address space"
 msgstr "инициализация по указателю на не замкнутое адресное пространство"
 
-#: c/c-typeck.c:6774
+#: c/c-typeck.c:6779
 #, gcc-internal-format
 msgid "return from pointer to non-enclosed address space"
 msgstr "возврат значения по указателю на не замкнутое адресное пространство"
 
-#: c/c-typeck.c:6792
+#: c/c-typeck.c:6797
 #, gcc-internal-format
 msgid "argument %d of %qE might be a candidate for a format attribute"
 msgstr "аргументу %d %qE, вероятно, можно назначить атрибут format"
 
-#: c/c-typeck.c:6798
+#: c/c-typeck.c:6803
 #, gcc-internal-format
 msgid "assignment left-hand side might be a candidate for a format attribute"
 msgstr "левой части присваивания, вероятно, можно назначить атрибут format"
 
-#: c/c-typeck.c:6803
+#: c/c-typeck.c:6808
 #, gcc-internal-format
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "левой части инициализации, вероятно, можно задать атрибут format"
 
-#: c/c-typeck.c:6808 cp/typeck.c:8891
+#: c/c-typeck.c:6813 cp/typeck.c:8891
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "тип результата, вероятно, может быть задан с атрибутом format"
 
-#: c/c-typeck.c:6857
+#: c/c-typeck.c:6862
 #, gcc-internal-format
 msgid "ISO C forbids passing argument %d of %qE between function pointer and %<void *%>"
 msgstr "в ISO C передача аргумента %d функции %qE с преобразованием указателя на функцию в тип %<void * %> запрещена"
 
-#: c/c-typeck.c:6860
+#: c/c-typeck.c:6865
 #, gcc-internal-format
 msgid "ISO C forbids assignment between function pointer and %<void *%>"
 msgstr "в ISO C присваивание с преобразованием указателя на функцию в тип %<void *%> запрещено"
 
-#: c/c-typeck.c:6862
+#: c/c-typeck.c:6867
 #, gcc-internal-format
 msgid "ISO C forbids initialization between function pointer and %<void *%>"
 msgstr "в ISO C инициализация с преобразованием указателя на функцию в тип %<void *%> запрещена"
 
-#: c/c-typeck.c:6864
+#: c/c-typeck.c:6869
 #, gcc-internal-format
 msgid "ISO C forbids return between function pointer and %<void *%>"
 msgstr "в ISO C возврат результата с преобразованием указателя на функцию в тип %<void *%> запрещен"
 
-#: c/c-typeck.c:6904
+#: c/c-typeck.c:6909
 #, gcc-internal-format
 msgid "pointer targets in passing argument %d of %qE differ in signedness"
 msgstr "при передаче аргумента %d %qE: указуемые типы различаются знаковостью"
 
-#: c/c-typeck.c:6913
-#, fuzzy, gcc-internal-format
-#| msgid "pointer targets in assignment differ in signedness"
+#: c/c-typeck.c:6918
+#, gcc-internal-format
 msgid "pointer targets in assignment from %qT to %qT differ in signedness"
-msgstr "в присваивании указуемые типы различаются знаковостью"
+msgstr ""
 
-#: c/c-typeck.c:6918
-#, fuzzy, gcc-internal-format
-#| msgid "pointer targets in initialization differ in signedness"
+#: c/c-typeck.c:6923
+#, gcc-internal-format
 msgid "pointer targets in initialization of %qT from %qT differ in signedness"
-msgstr "в инициализации указуемые типы различаются знаковостью"
+msgstr ""
 
-#: c/c-typeck.c:6923
-#, fuzzy, gcc-internal-format
-#| msgid "pointer targets in passing argument %d of %qE differ in signedness"
+#: c/c-typeck.c:6928
+#, gcc-internal-format
 msgid "pointer targets in returning %qT from a function with return type %qT differ in signedness"
-msgstr "при передаче аргумента %d %qE: указуемые типы различаются знаковостью"
+msgstr ""
 
-#: c/c-typeck.c:6961
+#: c/c-typeck.c:6966
 #, gcc-internal-format
 msgid "passing argument %d of %qE from incompatible pointer type"
 msgstr "в передаче аргумента %d %qE: несовместимый тип указателя"
 
-#: c/c-typeck.c:6967
-#, fuzzy, gcc-internal-format
-#| msgid "assignment from incompatible pointer type"
+#: c/c-typeck.c:6972
+#, gcc-internal-format
 msgid "assignment to %qT from incompatible pointer type %qT"
-msgstr "несовместимый тип указателя в присваивании"
+msgstr ""
 
-#: c/c-typeck.c:6972
-#, fuzzy, gcc-internal-format
-#| msgid "initialization from incompatible pointer type"
+#: c/c-typeck.c:6977
+#, gcc-internal-format
 msgid "initialization of %qT from incompatible pointer type %qT"
-msgstr "несовместимый тип указателя в инициализации"
+msgstr ""
 
-#: c/c-typeck.c:6977
-#, fuzzy, gcc-internal-format
-#| msgid "return with value in function with no return type"
+#: c/c-typeck.c:6982
+#, gcc-internal-format
 msgid "returning %qT from a function with incompatible return type %qT"
-msgstr "return со значением в функции без типа возврата"
+msgstr ""
 
 #. ??? This should not be an error when inlining calls to
 #. unprototyped functions.
-#: c/c-typeck.c:6991 c/c-typeck.c:7514 cp/typeck.c:2063
+#: c/c-typeck.c:6996 c/c-typeck.c:7519 cp/typeck.c:2063
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "некорректное использование массива, не являющегося левой частью присваивания"
 
-#: c/c-typeck.c:7004
+#: c/c-typeck.c:7009
 #, gcc-internal-format
 msgid "passing argument %d of %qE makes pointer from integer without a cast"
 msgstr "при передаче аргумента %d %qE целое преобразуется в указатель без приведения типа"
 
-#: c/c-typeck.c:7010
-#, fuzzy, gcc-internal-format
-#| msgid "assignment makes pointer from integer without a cast"
+#: c/c-typeck.c:7015
+#, gcc-internal-format
 msgid "assignment to %qT from %qT makes pointer from integer without a cast"
-msgstr "в присваивании целое преобразуется в указатель без приведения типа"
+msgstr ""
 
-#: c/c-typeck.c:7015
-#, fuzzy, gcc-internal-format
-#| msgid "initialization makes pointer from integer without a cast"
+#: c/c-typeck.c:7020
+#, gcc-internal-format
 msgid "initialization of %qT from %qT makes pointer from integer without a cast"
-msgstr "при инициализации целое преобразуется в указатель без приведения типа"
+msgstr ""
 
-#: c/c-typeck.c:7019
-#, fuzzy, gcc-internal-format
-#| msgid "passing argument %d of %qE makes pointer from integer without a cast"
+#: c/c-typeck.c:7024
+#, gcc-internal-format
 msgid "returning %qT from a function with return type %qT makes pointer from integer without a cast"
-msgstr "при передаче аргумента %d %qE целое преобразуется в указатель без приведения типа"
+msgstr ""
 
-#: c/c-typeck.c:7035
+#: c/c-typeck.c:7040
 #, gcc-internal-format
 msgid "passing argument %d of %qE makes integer from pointer without a cast"
 msgstr "при передаче аргумента %d %qE указатель преобразуется в целое без приведения типа"
 
-#: c/c-typeck.c:7041
-#, fuzzy, gcc-internal-format
-#| msgid "assignment makes integer from pointer without a cast"
+#: c/c-typeck.c:7046
+#, gcc-internal-format
 msgid "assignment to %qT from %qT makes integer from pointer without a cast"
-msgstr "в присваивании указатель преобразуется в целое без приведения типа"
+msgstr ""
 
-#: c/c-typeck.c:7046
-#, fuzzy, gcc-internal-format
-#| msgid "initialization makes integer from pointer without a cast"
+#: c/c-typeck.c:7051
+#, gcc-internal-format
 msgid "initialization of %qT from %qT makes integer from pointer without a cast"
-msgstr "при инициализации указатель преобразуется в целое без приведения типа"
+msgstr ""
 
-#: c/c-typeck.c:7050
-#, fuzzy, gcc-internal-format
-#| msgid "passing argument %d of %qE makes integer from pointer without a cast"
+#: c/c-typeck.c:7055
+#, gcc-internal-format
 msgid "returning %qT from a function with return type %qT makes integer from pointer without a cast"
-msgstr "при передаче аргумента %d %qE указатель преобразуется в целое без приведения типа"
+msgstr ""
 
-#: c/c-typeck.c:7073
+#: c/c-typeck.c:7078
 #, gcc-internal-format
 msgid "incompatible type for argument %d of %qE"
 msgstr "несовместимый тип аргумента %d функции %qE"
 
-#: c/c-typeck.c:7078
+#: c/c-typeck.c:7083
 #, gcc-internal-format
 msgid "incompatible types when assigning to type %qT from type %qT"
 msgstr "несовместимые типы в присваивании типу %qT значения типа %qT"
 
-#: c/c-typeck.c:7083
+#: c/c-typeck.c:7088
 #, gcc-internal-format
 msgid "incompatible types when initializing type %qT using type %qT"
 msgstr "несовместимые типы при инициализации типа %qT, используя тип %qT"
 
-#: c/c-typeck.c:7088
+#: c/c-typeck.c:7093
 #, gcc-internal-format
 msgid "incompatible types when returning type %qT but %qT was expected"
 msgstr "несовместимые типы при возврате значения типа %qT вместо ожидаемого типа %qT"
 
-#: c/c-typeck.c:7152
+#: c/c-typeck.c:7157
 #, gcc-internal-format
 msgid "traditional C rejects automatic aggregate initialization"
 msgstr "в традиционном C инициализация автоматических агрегатных переменных запрещена"
 
-#: c/c-typeck.c:7388 c/c-typeck.c:8284 cp/typeck2.c:1045
+#: c/c-typeck.c:7393 c/c-typeck.c:8289 cp/typeck2.c:1045
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "инициализация регулируемого элемента-массива"
 
-#: c/c-typeck.c:7398 cp/typeck2.c:1059
+#: c/c-typeck.c:7403 cp/typeck2.c:1059
 #, gcc-internal-format
 msgid "char-array initialized from wide string"
 msgstr "инициализация символьного массива строкой широких символов"
 
-#: c/c-typeck.c:7407
+#: c/c-typeck.c:7412
 #, gcc-internal-format
 msgid "wide character array initialized from non-wide string"
 msgstr "массив широких символов инициализирован не строкой широких символов"
 
-#: c/c-typeck.c:7413
+#: c/c-typeck.c:7418
 #, gcc-internal-format
 msgid "wide character array initialized from incompatible wide string"
 msgstr "массив широких символов инициализирован несовместимой строкой широких символов"
 
-#: c/c-typeck.c:7446
+#: c/c-typeck.c:7451
 #, gcc-internal-format
 msgid "array of inappropriate type initialized from string constant"
 msgstr "инициализация массива несоответствующего типа строковой константой"
 
-#: c/c-typeck.c:7533 c/c-typeck.c:7557 c/c-typeck.c:7560 c/c-typeck.c:7568
-#: c/c-typeck.c:7608 c/c-typeck.c:9131 c/c-typeck.c:9181
+#: c/c-typeck.c:7538 c/c-typeck.c:7562 c/c-typeck.c:7565 c/c-typeck.c:7573
+#: c/c-typeck.c:7613 c/c-typeck.c:9136 c/c-typeck.c:9186
 #, gcc-internal-format
 msgid "initializer element is not constant"
 msgstr "элемент инициализатора не является константой"
 
-#: c/c-typeck.c:7542
+#: c/c-typeck.c:7547
 #, gcc-internal-format
 msgid "array initialized from non-constant array expression"
 msgstr "инициализация массива неконстантным выражением"
 
-#: c/c-typeck.c:7573 c/c-typeck.c:7621 c/c-typeck.c:9191
+#: c/c-typeck.c:7578 c/c-typeck.c:7626 c/c-typeck.c:9196
 #, gcc-internal-format
 msgid "initializer element is not a constant expression"
 msgstr "элемент инициализатора не является константным выражением"
 
-#: c/c-typeck.c:7615 c/c-typeck.c:9186
+#: c/c-typeck.c:7620 c/c-typeck.c:9191
 #, gcc-internal-format
 msgid "initializer element is not computable at load time"
 msgstr "инициализирующий элемент не может быть вычислен во время компоновки"
 
-#: c/c-typeck.c:7634
+#: c/c-typeck.c:7639
 #, gcc-internal-format
 msgid "invalid initializer"
 msgstr "неверный инициализатор"
 
-#: c/c-typeck.c:7912 cp/decl.c:6396
+#: c/c-typeck.c:7917 cp/decl.c:6396
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "вектор скрытого типа не может быть инициализирован"
 
-#: c/c-typeck.c:8132
+#: c/c-typeck.c:8137
 #, gcc-internal-format
 msgid "extra brace group at end of initializer"
 msgstr "избыточные фигурные скобки в конце инициализатора"
 
-#: c/c-typeck.c:8215
+#: c/c-typeck.c:8220
 #, gcc-internal-format
 msgid "braces around scalar initializer"
 msgstr "фигурные скобки вокруг скалярного инициализатора"
 
-#: c/c-typeck.c:8281 c/c-typeck.c:9615 cp/typeck2.c:1084 cp/typeck2.c:1297
+#: c/c-typeck.c:8286 c/c-typeck.c:9620 cp/typeck2.c:1084 cp/typeck2.c:1297
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "инициализация элемента регулируемого элемента-массива во вложенном контексте"
 
-#: c/c-typeck.c:8318
+#: c/c-typeck.c:8323
 #, gcc-internal-format
 msgid "missing braces around initializer"
 msgstr "отсутствуют фигурные скобки вокруг инициализатора"
 
-#: c/c-typeck.c:8341
-#, fuzzy, gcc-internal-format
-#| msgid "missing initializer for member %qD"
+#: c/c-typeck.c:8346
+#, gcc-internal-format
 msgid "missing initializer for field %qD of %qT"
-msgstr "отсутствует инициализатор для элемента %qD"
+msgstr "отсутствует инициализатор для поля %qD из %qT"
 
-#: c/c-typeck.c:8365
+#: c/c-typeck.c:8370
 #, gcc-internal-format
 msgid "empty scalar initializer"
 msgstr "пустой скалярный инициализатор"
 
-#: c/c-typeck.c:8370
+#: c/c-typeck.c:8375
 #, gcc-internal-format
 msgid "extra elements in scalar initializer"
 msgstr "избыточные элементы в скалярном инициализаторе"
 
-#: c/c-typeck.c:8483 c/c-typeck.c:8565
+#: c/c-typeck.c:8488 c/c-typeck.c:8570
 #, gcc-internal-format
 msgid "array index in non-array initializer"
 msgstr "индекс массива в инициализаторе не для массива"
 
-#: c/c-typeck.c:8488 c/c-typeck.c:8627
+#: c/c-typeck.c:8493 c/c-typeck.c:8632
 #, gcc-internal-format
 msgid "field name not in record or union initializer"
 msgstr "имя поля в инициализаторе не для структуры или объединения"
 
-#: c/c-typeck.c:8538
+#: c/c-typeck.c:8543
 #, gcc-internal-format
 msgid "array index in initializer not of integer type"
 msgstr "индекс массива в инициализации не целого типа"
 
-#: c/c-typeck.c:8547 c/c-typeck.c:8556
+#: c/c-typeck.c:8552 c/c-typeck.c:8561
 #, gcc-internal-format
 msgid "array index in initializer is not an integer constant expression"
 msgstr "индекс массива в инициализации не является целочисленным константным выражением"
 
-#: c/c-typeck.c:8561 c/c-typeck.c:8563
+#: c/c-typeck.c:8566 c/c-typeck.c:8568
 #, gcc-internal-format
 msgid "nonconstant array index in initializer"
 msgstr "неконстантный индекс массива в инициализаторе"
 
-#: c/c-typeck.c:8567 c/c-typeck.c:8570
+#: c/c-typeck.c:8572 c/c-typeck.c:8575
 #, gcc-internal-format
 msgid "array index in initializer exceeds array bounds"
 msgstr "индекс массива в инициализаторе - за границами массива"
 
-#: c/c-typeck.c:8589
+#: c/c-typeck.c:8594
 #, gcc-internal-format
 msgid "empty index range in initializer"
 msgstr "пустой диапазон индексов в инициализаторе"
 
-#: c/c-typeck.c:8598
+#: c/c-typeck.c:8603
 #, gcc-internal-format
 msgid "array index range in initializer exceeds array bounds"
 msgstr "диапазон индексов массива в инициализаторе - за границами массива"
 
-#: c/c-typeck.c:8700 c/c-typeck.c:8730 c/c-typeck.c:9274
+#: c/c-typeck.c:8705 c/c-typeck.c:8735 c/c-typeck.c:9279
 #, gcc-internal-format
 msgid "initialized field with side-effects overwritten"
 msgstr "повторная инициализация поля с побочными эффектами"
 
-#: c/c-typeck.c:8704 c/c-typeck.c:8734 c/c-typeck.c:9277
+#: c/c-typeck.c:8709 c/c-typeck.c:8739 c/c-typeck.c:9282
 #, gcc-internal-format
 msgid "initialized field overwritten"
 msgstr "инициализированное поле перезаписано"
 
-#: c/c-typeck.c:9208
+#: c/c-typeck.c:9213
 #, gcc-internal-format
 msgid "enum conversion in initialization is invalid in C++"
 msgstr "преобразование типов в инициализаторе недопустимо в C++"
 
-#: c/c-typeck.c:9496
+#: c/c-typeck.c:9501
 #, gcc-internal-format
 msgid "excess elements in char array initializer"
 msgstr "избыточные элементы в инициализаторе символьного массива"
 
-#: c/c-typeck.c:9503 c/c-typeck.c:9574
+#: c/c-typeck.c:9508 c/c-typeck.c:9579
 #, gcc-internal-format
 msgid "excess elements in struct initializer"
 msgstr "избыточные элементы в инициализаторе структуры"
 
-#: c/c-typeck.c:9518
+#: c/c-typeck.c:9523
 #, gcc-internal-format
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
-msgstr ""
+msgstr "позиционная инициализация поля в %<struct%> декларированной с %<designated_init%> атрибутом"
 
-#: c/c-typeck.c:9589
+#: c/c-typeck.c:9594
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr "не статическая инициализация регулируемого элемента-массива в структуре"
 
-#: c/c-typeck.c:9687
+#: c/c-typeck.c:9692
 #, gcc-internal-format
 msgid "excess elements in union initializer"
 msgstr "избыточные элементы в инициализаторе объединения"
 
-#: c/c-typeck.c:9709
+#: c/c-typeck.c:9714
 #, gcc-internal-format
 msgid "traditional C rejects initialization of unions"
 msgstr "в традиционном C инициализация объединений запрещена"
 
-#: c/c-typeck.c:9777
+#: c/c-typeck.c:9782
 #, gcc-internal-format
 msgid "excess elements in array initializer"
 msgstr "избыточные элементы в инициализаторе массива"
 
-#: c/c-typeck.c:9811
+#: c/c-typeck.c:9816
 #, gcc-internal-format
 msgid "excess elements in vector initializer"
 msgstr "избыточные элементы в инициализаторе вектора"
 
-#: c/c-typeck.c:9843
+#: c/c-typeck.c:9848
 #, gcc-internal-format
 msgid "excess elements in scalar initializer"
 msgstr "избыточные элементы в инициализаторе скаляра"
 
-#: c/c-typeck.c:10086
+#: c/c-typeck.c:10091
 #, gcc-internal-format
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "в ISO C операторы вида %<goto *expr;%> запрещены"
 
-#: c/c-typeck.c:10113 c/gimple-parser.c:1604 cp/typeck.c:9113
+#: c/c-typeck.c:10118 c/gimple-parser.c:1604 cp/typeck.c:9113
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "функция декларированная с атрибутом %<noreturn%> содержит оператор %<return%>"
 
-#: c/c-typeck.c:10139 c/c-typeck.c:10143
+#: c/c-typeck.c:10144 c/c-typeck.c:10148
 #, gcc-internal-format
 msgid "%<return%> with no value, in function returning non-void"
 msgstr "оператор %<return%> без значения в функции, возвращающей не void-значение"
 
-#: c/c-typeck.c:10157 c/gimple-parser.c:1614
+#: c/c-typeck.c:10162 c/gimple-parser.c:1614
 #, gcc-internal-format
 msgid "%<return%> with a value, in function returning void"
 msgstr "оператор %<return%> <значение> в функции возвращающей void"
 
-#: c/c-typeck.c:10160
+#: c/c-typeck.c:10165
 #, gcc-internal-format
 msgid "ISO C forbids %<return%> with expression, in function returning void"
 msgstr "в ISO C запрещен оператор %<return%> с выражением в функции, возвращающей void"
 
-#: c/c-typeck.c:10236
-#, fuzzy, gcc-internal-format
-#| msgid "function returns address of local variable"
+#: c/c-typeck.c:10241
+#, gcc-internal-format
 msgid "function returns address of label"
-msgstr "функция возвращает адрес локальной переменной"
+msgstr "функция возвращает адрес метки"
 
-#: c/c-typeck.c:10327 cp/semantics.c:1171
+#: c/c-typeck.c:10332 cp/semantics.c:1171
 #, gcc-internal-format
 msgid "switch quantity not an integer"
 msgstr "в операторе switch задано не целое"
 
-#: c/c-typeck.c:10352
+#: c/c-typeck.c:10357
 #, gcc-internal-format
 msgid "%<long%> switch expression not converted to %<int%> in ISO C"
 msgstr "в ISO C %<long%>-выражение в операторе switch не преобразуется в %<int%>"
 
-#: c/c-typeck.c:10390 c/c-typeck.c:10398
+#: c/c-typeck.c:10395 c/c-typeck.c:10403
 #, gcc-internal-format
 msgid "case label is not an integer constant expression"
 msgstr "case-метка не является целочисленным константным выражением"
 
-#: c/c-typeck.c:10404 cp/parser.c:11067
+#: c/c-typeck.c:10409 cp/parser.c:11067
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "case-метка вне оператора switch"
 
-#: c/c-typeck.c:10406
+#: c/c-typeck.c:10411
 #, gcc-internal-format
 msgid "%<default%> label not within a switch statement"
 msgstr "метка %<default%> вне оператора switch"
 
-#: c/c-typeck.c:10578 cp/parser.c:12356
+#: c/c-typeck.c:10583 cp/parser.c:12353
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "оператор break вне цикла или оператора switch"
 
-#: c/c-typeck.c:10580 cp/parser.c:12379
+#: c/c-typeck.c:10585 cp/parser.c:12376
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "оператор continue вне цикла"
 
-#: c/c-typeck.c:10585 cp/parser.c:12369
+#: c/c-typeck.c:10590 cp/parser.c:12366
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr "оператор break использован с OpenMP для цикла"
 
-#: c/c-typeck.c:10590
-#, fuzzy, gcc-internal-format
-#| msgid "break statement not within loop or switch"
+#: c/c-typeck.c:10595
+#, gcc-internal-format
 msgid "break statement within %<#pragma simd%> loop body"
-msgstr "оператор break вне цикла или оператора switch"
+msgstr "оператор break внутри тела %<#pragma simd%> цикла"
 
-#: c/c-typeck.c:10592
-#, fuzzy, gcc-internal-format
-#| msgid "continue statement not within a loop"
+#: c/c-typeck.c:10597
+#, gcc-internal-format
 msgid "continue statement within %<#pragma simd%> loop body"
-msgstr "оператор continue вне цикла"
+msgstr "оператор continue внутри тела %<#pragma simd%> цикла"
 
-#: c/c-typeck.c:10618 cp/cp-gimplify.c:432
+#: c/c-typeck.c:10623 cp/cp-gimplify.c:432
 #, gcc-internal-format
 msgid "statement with no effect"
 msgstr "оператор без побочного эффекта"
 
-#: c/c-typeck.c:10662
+#: c/c-typeck.c:10667
 #, gcc-internal-format
 msgid "expression statement has incomplete type"
 msgstr "оператор-выражение имеет неполный тип"
 
-#: c/c-typeck.c:11476 c/c-typeck.c:11644 cp/typeck.c:5017
+#: c/c-typeck.c:11481 c/c-typeck.c:11649 cp/typeck.c:5017
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr "сравнение векторов с разными типами элементов"
 
-#: c/c-typeck.c:11484 c/c-typeck.c:11652 cp/typeck.c:5030
+#: c/c-typeck.c:11489 c/c-typeck.c:11657 cp/typeck.c:5030
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr "сравнение векторов с разным числом элементов"
 
-#: c/c-typeck.c:11509 c/c-typeck.c:11677 cp/typeck.c:5058
-#, fuzzy, gcc-internal-format
-#| msgid "could not find interface for class %qE"
+#: c/c-typeck.c:11514 c/c-typeck.c:11682 cp/typeck.c:5058
+#, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
-msgstr "невозможно найти интерфейс для класса %qE"
+msgstr "невозможно найти целый тип того же размера, что и %qT"
 
-#: c/c-typeck.c:11523 cp/typeck.c:4743
+#: c/c-typeck.c:11528 cp/typeck.c:4743
 #, gcc-internal-format
 msgid "comparing floating point with == or != is unsafe"
 msgstr "сравнение плавающих значений при помощи == или != не надежно"
 
-#: c/c-typeck.c:11541 c/c-typeck.c:11562
+#: c/c-typeck.c:11546 c/c-typeck.c:11567
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<false%> for the address of %qD will never be NULL"
 msgstr "результат сравнения всегда %<false%>, поскольку адрес %qD не может быть NULL"
 
-#: c/c-typeck.c:11547 c/c-typeck.c:11568
+#: c/c-typeck.c:11552 c/c-typeck.c:11573
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<true%> for the address of %qD will never be NULL"
 msgstr "результат сравнения всегда %<true%>, поскольку адрес %qD не может быть NULL"
 
-#: c/c-typeck.c:11589 c/c-typeck.c:11718
+#: c/c-typeck.c:11594 c/c-typeck.c:11723
 #, gcc-internal-format
 msgid "comparison of pointers to disjoint address spaces"
 msgstr "сравнение указателей на несвязанные адресные пространства"
 
-#: c/c-typeck.c:11596 c/c-typeck.c:11602
+#: c/c-typeck.c:11601 c/c-typeck.c:11607
 #, gcc-internal-format
 msgid "ISO C forbids comparison of %<void *%> with function pointer"
 msgstr "в ISO C сравнение указателя на функцию с указателем %<void *%> запрещено"
 
-#: c/c-typeck.c:11609 c/c-typeck.c:11728
+#: c/c-typeck.c:11614 c/c-typeck.c:11733
 #, gcc-internal-format
 msgid "comparison of distinct pointer types lacks a cast"
 msgstr "сравнение различных указательных типов без приведения типов"
 
-#: c/c-typeck.c:11621 c/c-typeck.c:11626 c/c-typeck.c:11754 c/c-typeck.c:11759
+#: c/c-typeck.c:11626 c/c-typeck.c:11631 c/c-typeck.c:11759 c/c-typeck.c:11764
 #, gcc-internal-format
 msgid "comparison between pointer and integer"
 msgstr "сравнение указателя и целого"
 
-#: c/c-typeck.c:11706
+#: c/c-typeck.c:11711
 #, gcc-internal-format
 msgid "comparison of complete and incomplete pointers"
 msgstr "сравнение указателей на полный и неполный типы"
 
-#: c/c-typeck.c:11708
+#: c/c-typeck.c:11713
 #, gcc-internal-format
 msgid "ISO C forbids ordered comparisons of pointers to functions"
 msgstr "ISO C разрешает сравнение указателей на функции только на равенство/неравенство"
 
-#: c/c-typeck.c:11713
+#: c/c-typeck.c:11718
 #, gcc-internal-format
 msgid "ordered comparison of pointer with null pointer"
 msgstr "упорядоченное сравнение указателя с нулевым указателем"
 
-#: c/c-typeck.c:11736 c/c-typeck.c:11739 c/c-typeck.c:11746 c/c-typeck.c:11749
+#: c/c-typeck.c:11741 c/c-typeck.c:11744 c/c-typeck.c:11751 c/c-typeck.c:11754
 #: cp/typeck.c:5081 cp/typeck.c:5088
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "упорядоченное сравнение указателя с целочисленным нулем"
 
-#: c/c-typeck.c:11811
+#: c/c-typeck.c:11816
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
 msgstr "неявная конверсия из %qT в %qT для совместимости с другим операндом бинарного выражения"
 
-#: c/c-typeck.c:12126
+#: c/c-typeck.c:12131
 #, gcc-internal-format
 msgid "used array that cannot be converted to pointer where scalar is required"
 msgstr "массив, не приводимый к указателю, употреблен в контексте, где допустимо только скалярное значение"
 
-#: c/c-typeck.c:12130
+#: c/c-typeck.c:12135
 #, gcc-internal-format
 msgid "used struct type value where scalar is required"
 msgstr "структурное значение употреблено в контексте, где допустимо только скалярное значение"
 
-#: c/c-typeck.c:12134
+#: c/c-typeck.c:12139
 #, gcc-internal-format
 msgid "used union type value where scalar is required"
 msgstr "объединение употреблено в контексте, где допустимо только скалярное значение"
 
-#: c/c-typeck.c:12150
+#: c/c-typeck.c:12155
 #, gcc-internal-format
 msgid "used vector type where scalar is required"
 msgstr "векторный тип использован в контексте, где допустимо только скалярное значение"
 
-#: c/c-typeck.c:12340 cp/semantics.c:8508
+#: c/c-typeck.c:12345 cp/semantics.c:8511
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
-msgstr ""
+msgstr "%<#pragma omp cancel%> должна задавать одну из %<parallel%>, %<for%>, %<sections%> или %<taskgroup%> клаузул"
 
-#: c/c-typeck.c:12379 cp/semantics.c:8545
+#: c/c-typeck.c:12384 cp/semantics.c:8548
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
-msgstr ""
+msgstr "%<#pragma omp cancellation point%> должна задавать одну из %<parallel%>, %<for%>, %<sections%> или %<taskgroup%> клаузул"
 
-#: c/c-typeck.c:12423 c/c-typeck.c:13581 c/c-typeck.c:13642 c/c-typeck.c:13704
-#, fuzzy, gcc-internal-format
-#| msgid "too many %qs clauses"
+#: c/c-typeck.c:12428 c/c-typeck.c:13586 c/c-typeck.c:13647 c/c-typeck.c:13709
+#, gcc-internal-format
 msgid "%<_Atomic%> %qE in %qs clause"
-msgstr "слишком много конструкций %qs"
+msgstr "%<_Atomic%> %qE в %qs клаузуле"
 
-#: c/c-typeck.c:12436 c/c-typeck.c:13628 cp/semantics.c:4546
-#: cp/semantics.c:6717
+#: c/c-typeck.c:12441 c/c-typeck.c:13633 cp/semantics.c:4549
+#: cp/semantics.c:6720
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
-msgstr ""
+msgstr "битовое поле %qE в %qs клаузуле"
 
-#: c/c-typeck.c:12445 c/c-typeck.c:13652 cp/semantics.c:4556
-#: cp/semantics.c:6735
-#, fuzzy, gcc-internal-format
-#| msgid "%qD is not a member template function"
+#: c/c-typeck.c:12450 c/c-typeck.c:13657 cp/semantics.c:4559
+#: cp/semantics.c:6738
+#, gcc-internal-format
 msgid "%qE is a member of a union"
-msgstr "%qD не является шаблонным элементом-функцией"
+msgstr "%qE является элементом объединения"
 
-#: c/c-typeck.c:12455 cp/semantics.c:4570 cp/semantics.c:6760
-#, fuzzy, gcc-internal-format
-#| msgid "%qD is not a variable in clause %qs"
+#: c/c-typeck.c:12460 cp/semantics.c:4573 cp/semantics.c:6763
+#, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
-msgstr "%qD не есть переменная в клаузуле %qs"
+msgstr "%qD не есть переменная в %qs клаузуле"
 
-#: c/c-typeck.c:12459 c/c-typeck.c:13669 cp/semantics.c:4574
-#: cp/semantics.c:6763
-#, fuzzy, gcc-internal-format
-#| msgid "%qE is not a variable in clause %qs"
+#: c/c-typeck.c:12464 c/c-typeck.c:13674 cp/semantics.c:4577
+#: cp/semantics.c:6766
+#, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
-msgstr "%qE не является переменной в конструкции %qs"
+msgstr "%qE не есть переменная в %qs клаузуле"
 
-#: c/c-typeck.c:12466
-#, fuzzy, gcc-internal-format
-#| msgid "too many %qs clauses"
+#: c/c-typeck.c:12471
+#, gcc-internal-format
 msgid "%<_Atomic%> %qD in %qs clause"
-msgstr "слишком много конструкций %qs"
+msgstr "%<_Atomic%> %qD в %qs клаузуле"
 
-#: c/c-typeck.c:12475 c/c-typeck.c:13676 c/c-typeck.c:13778
-#: cp/semantics.c:4591 cp/semantics.c:6769 cp/semantics.c:6931
-#, fuzzy, gcc-internal-format
-#| msgid "%qD is not a variable in clause %qs"
+#: c/c-typeck.c:12480 c/c-typeck.c:13681 c/c-typeck.c:13783
+#: cp/semantics.c:4594 cp/semantics.c:6772 cp/semantics.c:6934
+#, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
-msgstr "%qD не есть переменная в клаузуле %qs"
+msgstr "%qD есть threadprivate переменная в %qs клаузуле"
 
-#: c/c-typeck.c:12511 cp/semantics.c:4623
-#, fuzzy, gcc-internal-format
-#| msgid "size in array new must have integral type"
+#: c/c-typeck.c:12516 cp/semantics.c:4626
+#, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
-msgstr "размер в new для массива должен иметь целочисленный тип"
+msgstr "нижняя граница %qE секции массива не имеет целочисленный тип"
 
-#: c/c-typeck.c:12518 cp/semantics.c:4630
-#, fuzzy, gcc-internal-format
-#| msgid "size in array new must have integral type"
+#: c/c-typeck.c:12523 cp/semantics.c:4633
+#, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
-msgstr "размер в new для массива должен иметь целочисленный тип"
+msgstr "длина %qE секции массива не имеет целочисленный тип"
 
-#: c/c-typeck.c:12545 c/c-typeck.c:12609 c/c-typeck.c:12867
-#: cp/semantics.c:4666 cp/semantics.c:4730
-#, fuzzy, gcc-internal-format
-#| msgid "Array section in '%s' call at %L"
+#: c/c-typeck.c:12550 c/c-typeck.c:12614 c/c-typeck.c:12872
+#: cp/semantics.c:4669 cp/semantics.c:4733
+#, gcc-internal-format
 msgid "zero length array section in %qs clause"
-msgstr "Секция массива в '%s' вызове в %L"
+msgstr "секция массива нулевой длины в %qs клаузуле"
 
-#: c/c-typeck.c:12564 cp/semantics.c:4685
+#: c/c-typeck.c:12569 cp/semantics.c:4688
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
-msgstr ""
+msgstr "для массивного типа с неизвестной границей должно быть задано выражение для длины"
 
-#: c/c-typeck.c:12572 cp/semantics.c:4693
+#: c/c-typeck.c:12577 cp/semantics.c:4696
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
-msgstr ""
+msgstr "отрицательная нижняя граница в секции массива в %qs клаузуле"
 
-#: c/c-typeck.c:12581 c/c-typeck.c:12691 cp/semantics.c:4702
-#: cp/semantics.c:4812
-#, fuzzy, gcc-internal-format
-#| msgid "variable length array is used"
+#: c/c-typeck.c:12586 c/c-typeck.c:12696 cp/semantics.c:4705
+#: cp/semantics.c:4815
+#, gcc-internal-format
 msgid "negative length in array section in %qs clause"
-msgstr "используется массив переменного размера"
+msgstr "отрицательная длина в секции массива в %qs клаузуле"
 
-#: c/c-typeck.c:12598 cp/semantics.c:4719
+#: c/c-typeck.c:12603 cp/semantics.c:4722
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
-msgstr ""
+msgstr "нижняя граница %qE выше размера секции массива в %qs клаузуле"
 
-#: c/c-typeck.c:12635 cp/semantics.c:4756
+#: c/c-typeck.c:12640 cp/semantics.c:4759
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
-msgstr ""
+msgstr "длина %qE выше размера секции массива в %qs клаузуле"
 
-#: c/c-typeck.c:12650 cp/semantics.c:4771
+#: c/c-typeck.c:12655 cp/semantics.c:4774
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
-msgstr ""
+msgstr "верхняя граница %qE выше размера секции массива в %qs клаузуле"
 
-#: c/c-typeck.c:12683 cp/semantics.c:4804
-#, fuzzy, gcc-internal-format
-#| msgid "for increment expression has no effect"
+#: c/c-typeck.c:12688 cp/semantics.c:4807
+#, gcc-internal-format
 msgid "for pointer type length expression must be specified"
-msgstr "for инкрементное выражение не имеет эффекта"
+msgstr "для типа указателя должно быть задано выражение длины"
 
-#: c/c-typeck.c:12701 c/c-typeck.c:12810 cp/semantics.c:4822
-#: cp/semantics.c:4934
-#, fuzzy, gcc-internal-format
-#| msgid "Copy array sections into a contiguous block on procedure entry"
+#: c/c-typeck.c:12706 c/c-typeck.c:12815 cp/semantics.c:4825
+#: cp/semantics.c:4937
+#, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
-msgstr "При входе в процедуру копировать секции массивов в последовательный блок"
+msgstr "секция массив не непрерывна в %qs клаузуле"
 
-#: c/c-typeck.c:12709 cp/semantics.c:4830
-#, fuzzy, gcc-internal-format
-#| msgid "%qD does not have integral or enumeration type"
+#: c/c-typeck.c:12714 cp/semantics.c:4833
+#, gcc-internal-format
 msgid "%qE does not have pointer or array type"
-msgstr "%qD не имеет целый или перечислимый тип"
+msgstr "%qE не имеет тип указателя или массива"
 
-#: c/c-typeck.c:13103 c/c-typeck.c:13113
+#: c/c-typeck.c:13108 c/c-typeck.c:13118
 #, gcc-internal-format
 msgid "%qD in %<reduction%> clause is a zero size array"
-msgstr ""
+msgstr "%qD в %<reduction%> клаузуле есть массив нулевой длины"
 
-#: c/c-typeck.c:13130
-#, fuzzy, gcc-internal-format
-#| msgid "ISO C forbids qualified function types"
+#: c/c-typeck.c:13135
+#, gcc-internal-format
 msgid "%<_Atomic%> %qE in %<reduction%> clause"
-msgstr "в ISO C употребление квалификаторов в описании типа функции запрещено"
+msgstr "%<_Atomic%> %qE в %<reduction%> клаузуле"
 
-#: c/c-typeck.c:13178
+#: c/c-typeck.c:13183
 #, gcc-internal-format
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "%qE имеет недопустимый тип для %<reduction(%s)%>"
 
-#: c/c-typeck.c:13187 cp/semantics.c:5755
+#: c/c-typeck.c:13192 cp/semantics.c:5758
 #, gcc-internal-format
 msgid "user defined reduction not found for %qE"
-msgstr ""
+msgstr "определенная пользователем редукция не найдена для %qE"
 
-#: c/c-typeck.c:13275
-#, fuzzy, gcc-internal-format
-#| msgid "variable length array is used"
+#: c/c-typeck.c:13280
+#, gcc-internal-format
 msgid "variable length element type in array %<reduction%> clause"
-msgstr "используется массив переменного размера"
+msgstr "тип элемента переменой длины в предложении массива %<reduction%>"
 
-#: c/c-typeck.c:13293 c/c-typeck.c:13836 cp/semantics.c:7249
+#: c/c-typeck.c:13298 c/c-typeck.c:13841 cp/semantics.c:7252
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
-msgstr ""
+msgstr "%<nowait%> предложение не может использоваться вместе с %<copyprivate%>"
 
-#: c/c-typeck.c:13305 cp/semantics.c:7289
+#: c/c-typeck.c:13310 cp/semantics.c:7292
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE должно быть %<threadprivate%> для %<copyin%>"
 
-#: c/c-typeck.c:13319 cp/semantics.c:5929
+#: c/c-typeck.c:13324 cp/semantics.c:5932
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
-msgstr ""
+msgstr "модификатор не должен задаваться в предложении %<linear%> для конструкций %<simd%> или %<for%>"
 
-#: c/c-typeck.c:13327
+#: c/c-typeck.c:13332
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with type %qT"
-msgstr ""
+msgstr "линейное предложение применено к нецелой переменной без указателя с типом %qT"
 
-#: c/c-typeck.c:13335
+#: c/c-typeck.c:13340
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<linear%> clause"
-msgstr ""
+msgstr "%<_Atomic%> %qD в предложении %<linear%>"
 
-#: c/c-typeck.c:13354 cp/semantics.c:5999
+#: c/c-typeck.c:13359 cp/semantics.c:6002
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
-msgstr ""
+msgstr "шаг предложения %<linear%> %qE не является ни константой, ни параметром"
 
-#: c/c-typeck.c:13384 c/c-typeck.c:13771 cp/semantics.c:6083
-#: cp/semantics.c:6924
+#: c/c-typeck.c:13389 c/c-typeck.c:13776 cp/semantics.c:6086
+#: cp/semantics.c:6927
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
-msgstr "%qE не является переменной в конструкции %qs"
+msgstr "%qE не является переменной в предложении %qs"
 
-#: c/c-typeck.c:13393 cp/semantics.c:6092
-#, fuzzy, gcc-internal-format
-#| msgid "%qD appears more than once in data clauses"
+#: c/c-typeck.c:13398 cp/semantics.c:6095
+#, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
-msgstr "%qD появляется более одного раза в клаузуле данных"
+msgstr "%qD многократно встречается в предложениях сокращения"
 
-#: c/c-typeck.c:13404 c/c-typeck.c:13434 c/c-typeck.c:13463
+#: c/c-typeck.c:13409 c/c-typeck.c:13439 c/c-typeck.c:13468
 #, gcc-internal-format
 msgid "%qE appears more than once in data clauses"
-msgstr "%qE встречается более одного раза в конструкции данных"
+msgstr "%qE многократно встречается в предложениях данных"
 
-#: c/c-typeck.c:13411 c/c-typeck.c:13440 c/c-typeck.c:13600 c/c-typeck.c:13714
-#: c/c-typeck.c:13720 c/c-typeck.c:13733 c/c-typeck.c:13742
-#: cp/semantics.c:6102 cp/semantics.c:6109 cp/semantics.c:6160
-#: cp/semantics.c:6166 cp/semantics.c:6203 cp/semantics.c:6680
-#: cp/semantics.c:6817 cp/semantics.c:6823 cp/semantics.c:6836
-#: cp/semantics.c:6845
+#: c/c-typeck.c:13416 c/c-typeck.c:13445 c/c-typeck.c:13605 c/c-typeck.c:13719
+#: c/c-typeck.c:13725 c/c-typeck.c:13738 c/c-typeck.c:13747
+#: cp/semantics.c:6105 cp/semantics.c:6112 cp/semantics.c:6163
+#: cp/semantics.c:6169 cp/semantics.c:6206 cp/semantics.c:6683
+#: cp/semantics.c:6820 cp/semantics.c:6826 cp/semantics.c:6839
+#: cp/semantics.c:6848
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
-msgstr "%qD появляется более одного раза в клаузуле данных"
+msgstr "%qD многократно встречается в предложениях данных"
 
-#: c/c-typeck.c:13413 c/c-typeck.c:13442 c/c-typeck.c:13722 c/c-typeck.c:13744
-#: cp/semantics.c:6111 cp/semantics.c:6168 cp/semantics.c:6825
-#: cp/semantics.c:6847
-#, fuzzy, gcc-internal-format
-#| msgid "%qD appears more than once in data clauses"
+#: c/c-typeck.c:13418 c/c-typeck.c:13447 c/c-typeck.c:13727 c/c-typeck.c:13749
+#: cp/semantics.c:6114 cp/semantics.c:6171 cp/semantics.c:6828
+#: cp/semantics.c:6850
+#, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
-msgstr "%qD появляется более одного раза в клаузуле данных"
+msgstr "%qD встречается в предложениях данных и сопоставления"
 
-#: c/c-typeck.c:13427 cp/semantics.c:6154
+#: c/c-typeck.c:13432 cp/semantics.c:6157
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
-msgstr "%qE не является переменной в конструкции %<firstprivate%>"
+msgstr "%qE не является переменной в предложении %<firstprivate%>"
 
-#: c/c-typeck.c:13456 cp/semantics.c:6197
+#: c/c-typeck.c:13461 cp/semantics.c:6200
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
-msgstr "%qE не является переменной в конструкции %<lastprivate%>"
+msgstr "%qE не является переменной в предложении %<lastprivate%>"
 
-#: c/c-typeck.c:13475 cp/semantics.c:6545
-#, fuzzy, gcc-internal-format
-#| msgid "%qE is not a variable in clause %qs"
+#: c/c-typeck.c:13480 cp/semantics.c:6548
+#, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
-msgstr "%qE не является переменной в конструкции %qs"
+msgstr "%qE не является переменной в предложении %<aligned%>"
 
-#: c/c-typeck.c:13482
-#, fuzzy, gcc-internal-format
-#| msgid "type to vector delete is neither pointer or array type"
+#: c/c-typeck.c:13487
+#, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array"
-msgstr "тип, заданный в векторном delete, не является ни массивом, ни указателем"
+msgstr "%qE в предложении %<aligned%> не является ни указателем, ни массивом"
 
-#: c/c-typeck.c:13489
-#, fuzzy, gcc-internal-format
-#| msgid "%qD is not a variable in clause %qs"
+#: c/c-typeck.c:13494
+#, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<aligned%> clause"
-msgstr "%qD не есть переменная в клаузуле %qs"
+msgstr "%<_Atomic%> %qD в предложении %<aligned%>"
 
-#: c/c-typeck.c:13496
-#, fuzzy, gcc-internal-format
-#| msgid "%qE appears more than once in data clauses"
+#: c/c-typeck.c:13501
+#, gcc-internal-format
 msgid "%qE appears more than once in %<aligned%> clauses"
-msgstr "%qE встречается более одного раза в конструкции данных"
+msgstr "%qE многократно встречается в предложении %<aligned%>"
 
-#: c/c-typeck.c:13551 cp/semantics.c:6627
-#, fuzzy, gcc-internal-format
-#| msgid "%qE is not a variable in clause %qs"
+#: c/c-typeck.c:13556 cp/semantics.c:6630
+#, gcc-internal-format
 msgid "%qE is not a variable in %<depend%> clause"
-msgstr "%qE не является переменной в конструкции %qs"
+msgstr "%qE не является переменной в предложении %<depend%>"
 
-#: c/c-typeck.c:13573 cp/semantics.c:6658
-#, fuzzy, gcc-internal-format
-#| msgid "Array section not permitted in '%s' call at %L"
+#: c/c-typeck.c:13578 cp/semantics.c:6661
+#, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
-msgstr "Секция массива не разрешена в '%s' вызове в %L"
+msgstr "секция массива не имеет отображаемый тип в предложении %qs"
 
-#: c/c-typeck.c:13597 c/c-typeck.c:13731 cp/semantics.c:6677
-#: cp/semantics.c:6834
-#, fuzzy, gcc-internal-format
-#| msgid "%qD appears more than once in data clauses"
+#: c/c-typeck.c:13602 c/c-typeck.c:13736 cp/semantics.c:6680
+#: cp/semantics.c:6837
+#, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
-msgstr "%qD появляется более одного раза в клаузуле данных"
+msgstr "%qD многократно встречается в предложениях движения"
 
-#: c/c-typeck.c:13603 c/c-typeck.c:13735 cp/semantics.c:6683
-#: cp/semantics.c:6838
-#, fuzzy, gcc-internal-format
-#| msgid "%qD appears more than once in data clauses"
+#: c/c-typeck.c:13608 c/c-typeck.c:13740 cp/semantics.c:6686
+#: cp/semantics.c:6841
+#, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
-msgstr "%qD появляется более одного раза в клаузуле данных"
+msgstr "%qD многократно встречается в предложениях сопоставления"
 
-#: c/c-typeck.c:13635 cp/semantics.c:6724
-#, fuzzy, gcc-internal-format
-#| msgid "%qE is not a variable in clause %qs"
+#: c/c-typeck.c:13640 cp/semantics.c:6727
+#, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
-msgstr "%qE не является переменной в конструкции %qs"
+msgstr "%qE не имеет отображаемый тип в предложении %qs"
 
-#: c/c-typeck.c:13695 c/c-typeck.c:13785 cp/semantics.c:6799
-#: cp/semantics.c:6938
-#, fuzzy, gcc-internal-format
-#| msgid "%qD is not a variable in clause %qs"
+#: c/c-typeck.c:13700 c/c-typeck.c:13790 cp/semantics.c:6802
+#: cp/semantics.c:6941
+#, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
-msgstr "%qD не есть переменная в клаузуле %qs"
+msgstr "%qD не имеет отображаемый тип в предложении %qs"
 
-#: c/c-typeck.c:13766 cp/semantics.c:6918
-#, fuzzy, gcc-internal-format
-#| msgid "%qE is not a variable in clause %qs"
+#: c/c-typeck.c:13771 cp/semantics.c:6921
+#, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
-msgstr "%qE не является переменной в конструкции %qs"
+msgstr "%qE не является ни переменной, ни именем функции в предложении %qs"
 
-#: c/c-typeck.c:13794 cp/semantics.c:6947
-#, fuzzy, gcc-internal-format
-#| msgid "%qE appears more than once in data clauses"
+#: c/c-typeck.c:13799 cp/semantics.c:6950
+#, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
-msgstr "%qE встречается более одного раза в конструкции данных"
+msgstr "%qE многократно встречается в одной директиве %<declare target%>"
 
-#: c/c-typeck.c:13808 cp/semantics.c:6962
-#, fuzzy, gcc-internal-format
-#| msgid "%qD is not a variable in clause %qs"
+#: c/c-typeck.c:13813 cp/semantics.c:6965
+#, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
-msgstr "%qD не есть переменная в клаузуле %qs"
+msgstr "%qD не является аргументом в %<uniform%> предложении"
 
-#: c/c-typeck.c:13811 cp/semantics.c:6964
-#, fuzzy, gcc-internal-format
-#| msgid "%qE is not a variable in clause %qs"
+#: c/c-typeck.c:13816 cp/semantics.c:6967
+#, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
-msgstr "%qE не является переменной в конструкции %qs"
+msgstr "%qE не является аргументом в %<uniform%> предложении"
 
-#: c/c-typeck.c:13826
-#, fuzzy, gcc-internal-format
-#| msgid "type to vector delete is neither pointer or array type"
+#: c/c-typeck.c:13831
+#, gcc-internal-format
 msgid "%qs variable is neither a pointer nor an array"
-msgstr "тип, заданный в векторном delete, не является ни массивом, ни указателем"
+msgstr "%qs переменная не является ни указателем, ни массивом"
 
-#: c/c-typeck.c:13900 cp/semantics.c:6359
+#: c/c-typeck.c:13905 cp/semantics.c:6362
 #, gcc-internal-format
 msgid "%<nonmonotonic%> modifier specified for %qs schedule kind"
-msgstr ""
+msgstr "%<nonmonotonic%> модификатор задан для %qs вида планирования"
 
-#: c/c-typeck.c:13931 cp/semantics.c:7141
+#: c/c-typeck.c:13936 cp/semantics.c:7144
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
-msgstr ""
+msgstr "предложение %<inbranch%> несовместимо с %<notinbranch%>"
 
-#: c/c-typeck.c:13981 cp/semantics.c:7332
+#: c/c-typeck.c:13986 cp/semantics.c:7335
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
-msgstr "%qE является предопределенным %qs для %qs"
+msgstr "%qE является предопределённым %qs для %qs"
 
-#: c/c-typeck.c:14001 cp/semantics.c:7223
+#: c/c-typeck.c:14006 cp/semantics.c:7226
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
-msgstr ""
+msgstr "значение предложения %<simdlen%> больше значения %<safelen%> предложения"
 
-#: c/c-typeck.c:14013 cp/semantics.c:7236
+#: c/c-typeck.c:14018 cp/semantics.c:7239
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
-msgstr ""
+msgstr "%<nonmonotonic%> модификатор планирования задан вместе с %<ordered%> предложением"
 
-#: c/c-typeck.c:14031 cp/semantics.c:7203
+#: c/c-typeck.c:14036 cp/semantics.c:7206
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
-msgstr ""
+msgstr "шаг %<linear%> предложения является параметром %qD, который не указан в %<uniform%> предложении"
 
-#: c/c-typeck.c:14204
+#: c/c-typeck.c:14209
 #, gcc-internal-format
 msgid "cannot use %<va_arg%> with reverse storage order"
-msgstr ""
+msgstr "нельзя использовать %<va_arg%> с обратным порядком хранения"
 
-#: c/c-typeck.c:14209
-#, fuzzy, gcc-internal-format
-#| msgid "first argument to %<va_arg%> not of type %<va_list%>"
+#: c/c-typeck.c:14214
+#, gcc-internal-format
 msgid "second argument to %<va_arg%> is of incomplete type %qT"
-msgstr "первый аргумент %<va_start%> должен иметь тип %<va_list%>"
+msgstr "второй аргумент %<va_arg%> имеет неполный тип %qT"
 
-#: c/c-typeck.c:14215
+#: c/c-typeck.c:14220
 #, gcc-internal-format
 msgid "C++ requires promoted type, not enum type, in %<va_arg%>"
 msgstr "в C++ требуется расширенный тип, а не перечислимый тип в %<va_arg%>"
@@ -43206,135 +38025,113 @@
 #: c/gimple-parser.c:539
 #, gcc-internal-format
 msgid "%<&&%> not valid in GIMPLE"
-msgstr ""
+msgstr "%<&&%> некорректно в GIMPLE"
 
 #: c/gimple-parser.c:542
 #, gcc-internal-format
 msgid "%<||%> not valid in GIMPLE"
-msgstr ""
+msgstr "%<||%> некорректно в GIMPLE"
 
 #: c/gimple-parser.c:588
-#, fuzzy, gcc-internal-format
-#| msgid "expected identifier or %<*%>"
+#, gcc-internal-format
 msgid "expected pointer as argument of unary %<*%>"
-msgstr "ожидался идентификатор или %<*%>"
+msgstr "ожидался указатель как аргумент для унарного %<*%>"
 
 #: c/gimple-parser.c:614
 #, gcc-internal-format
 msgid "%<!%> not valid in GIMPLE"
-msgstr ""
+msgstr "%<!%> некорректно в GIMPLE"
 
 #: c/gimple-parser.c:686
-#, fuzzy, gcc-internal-format
-#| msgid "%qD not declared"
+#, gcc-internal-format
 msgid "SSA name undeclared"
-msgstr "отсутствует декларация %qD"
+msgstr "SSA имя не объявлено"
 
 #: c/gimple-parser.c:708
-#, fuzzy, gcc-internal-format
-#| msgid "unnamed variable or field declared void"
+#, gcc-internal-format
 msgid "base variable or SSA name undeclared"
-msgstr "декларация безымянной переменной или поля с типом void"
+msgstr "базовая переменная или SSA имя не объявлено"
 
 #: c/gimple-parser.c:715
-#, fuzzy, gcc-internal-format
-#| msgid "invalid type %<void%> for new"
+#, gcc-internal-format
 msgid "invalid base %qE for SSA name"
-msgstr "некорректный тип %<void%> задан для new"
+msgstr "недопустимая основа %qE для имени SSA"
 
 #: c/gimple-parser.c:835
-#, fuzzy, gcc-internal-format
-#| msgid "invalid %%P operand"
+#, gcc-internal-format
 msgid "invalid type of %<__MEM%> operand"
-msgstr "неверный операнд для кода %%P"
+msgstr "недопустимый тип операнда %<__MEM%>"
 
 #: c/gimple-parser.c:891 c/gimple-parser.c:899
-#, fuzzy, gcc-internal-format
-#| msgid "invalid %%d operand"
+#, gcc-internal-format
 msgid "invalid _Literal"
-msgstr "некорректный операнд для %%d"
+msgstr "недопустимый _Literal"
 
 #: c/gimple-parser.c:919
-#, fuzzy, gcc-internal-format
-#| msgid "invalid offset operand of MEM_REF"
+#, gcc-internal-format
 msgid "invalid number of operands to __FMA"
-msgstr "некорректный операнд смещения для MEM_REF"
+msgstr "недопустимое число операндов для __FMA"
 
 #: c/gimple-parser.c:954
-#, fuzzy, gcc-internal-format
-#| msgid "an anonymous union cannot have function members"
+#, gcc-internal-format
 msgid "anonymous SSA name cannot have default definition"
-msgstr "анонимное union не может иметь элементов-функций"
+msgstr "анонимное SSA имя не может иметь подразумеваемое определение"
 
 #: c/gimple-parser.c:1203
-#, fuzzy, gcc-internal-format
-#| msgid "expected class name"
+#, gcc-internal-format
 msgid "expected pass name"
-msgstr "ожидалось имя класса"
+msgstr "ожидалось pass имя"
 
 #: c/gimple-parser.c:1215
-#, fuzzy, gcc-internal-format
-#| msgid "invalid %%d operand"
+#, gcc-internal-format
 msgid "invalid operation"
-msgstr "некорректный операнд для %%d"
+msgstr "некорректная операция"
 
 #: c/gimple-parser.c:1380 c/gimple-parser.c:1409
-#, fuzzy, gcc-internal-format
-#| msgid "expected expression"
+#, gcc-internal-format
 msgid "expected goto expression"
-msgstr "ожидалось выражение"
+msgstr "ожидалось goto выражение"
 
 #: c/gimple-parser.c:1388
-#, fuzzy, gcc-internal-format
-#| msgid "expected statement"
+#, gcc-internal-format
 msgid "expected else statement"
-msgstr "ожидался оператор"
+msgstr "ожидался else оператор"
 
 #: c/gimple-parser.c:1538
-#, fuzzy, gcc-internal-format
-#| msgid "extra semicolon"
+#, gcc-internal-format
 msgid "expected semicolon"
-msgstr "лишняя точка с запятой"
+msgstr "ожидалась точка с запятой"
 
 #: c/gimple-parser.c:1548
-#, fuzzy, gcc-internal-format
-#| msgid "expected selection-statement"
+#, gcc-internal-format
 msgid "expected case label or goto statement"
-msgstr "ожидался selection-statement"
+msgstr "ожидалась case метка или goto оператор"
 
 #. A bad conversion for 'this' must be discarding cv-quals.
 #: cp/call.c:3409
-#, fuzzy, gcc-internal-format
-#| msgid "passing %qT as %<this%> argument of %q#D discards qualifiers"
+#, gcc-internal-format
 msgid "  passing %qT as %<this%> argument discards qualifiers"
-msgstr "передача %qT как аргумент %<this%> %q#D отменяет квалификаторы"
+msgstr "  передача %qT как аргумент %<this%> отбрасывает квалификаторы"
 
 #: cp/call.c:3413
-#, fuzzy
-#| msgid "  no known conversion for implicit %<this%> parameter from %qT to %qT"
 msgid "  no known conversion for implicit %<this%> parameter from %qH to %qI"
-msgstr "  нет известных преобразований для неявного параметра %<this%> из %qT в %qT"
+msgstr ""
 
 #: cp/call.c:3420
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "  no known conversion for argument %d from %qT to %qT"
+#, gcc-internal-format, gfc-internal-format
 msgid "  conversion of argument %d would be ill-formed:"
-msgstr "  нет известных преобразований для аргумента %d из %qT в %qT"
+msgstr ""
 
 #. Conversion of conversion function return value failed.
 #: cp/call.c:3427
-#, fuzzy
-#| msgid "  for conversion from %qT to %qT"
 msgid "  no known conversion from %qH to %qI"
-msgstr "  при преобразовании из %qT в %qT,"
+msgstr ""
 
 #: cp/call.c:3430
-#, fuzzy
-#| msgid "  no known conversion for argument %d from %qT to %qT"
 msgid "  no known conversion for argument %d from %qH to %qI"
-msgstr "  нет известных преобразований для аргумента %d из %qT в %qT"
+msgstr ""
 
-#: cp/call.c:3441 cp/pt.c:6495
+#: cp/call.c:3441 cp/pt.c:6509
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -43343,52 +38140,44 @@
 msgstr[2] "  кандидат ожидает %d аргументов, %d предоставлено"
 
 #: cp/call.c:3469
-#, fuzzy, gcc-internal-format
-#| msgid "%s%D(%T, %T, %T) <built-in>"
+#, gcc-internal-format
 msgid "%s%<%D(%T, %T, %T)%> <built-in>"
-msgstr "%s%D(%T, %T, %T) <built-in>"
+msgstr ""
 
 #: cp/call.c:3474
-#, fuzzy, gcc-internal-format
-#| msgid "%s%D(%T, %T) <built-in>"
+#, gcc-internal-format
 msgid "%s%<%D(%T, %T)%> <built-in>"
-msgstr "%s%D(%T, %T) <built-in>"
+msgstr ""
 
 #: cp/call.c:3478
-#, fuzzy, gcc-internal-format
-#| msgid "%s%D(%T) <built-in>"
+#, gcc-internal-format
 msgid "%s%<%D(%T)%> <built-in>"
-msgstr "%s%D(%T) <built-in>"
+msgstr ""
 
 #: cp/call.c:3482
-#, fuzzy, gcc-internal-format
-#| msgid "%s%T <conversion>"
+#, gcc-internal-format
 msgid "%s%qT <conversion>"
-msgstr "%s%T <conversion>"
+msgstr ""
 
 #: cp/call.c:3484
-#, fuzzy, gcc-internal-format
-#| msgid "%s%#D <near match>"
+#, gcc-internal-format
 msgid "%s%#qD <near match>"
-msgstr "%s%#D <near match>"
+msgstr ""
 
 #: cp/call.c:3486
-#, fuzzy, gcc-internal-format
-#| msgid "%s%#D <deleted>"
+#, gcc-internal-format
 msgid "%s%#qD <deleted>"
-msgstr "%s%#D <deleted>"
+msgstr ""
 
 #: cp/call.c:3488
-#, fuzzy, gcc-internal-format
-#| msgid "%s%#D"
+#, gcc-internal-format
 msgid "%s%#qD"
-msgstr "%s%#D"
+msgstr ""
 
 #: cp/call.c:3492
-#, fuzzy, gcc-internal-format
-#| msgid "  when initialized here"
+#, gcc-internal-format
 msgid "  inherited here"
-msgstr "  если инициализирован здесь"
+msgstr ""
 
 #: cp/call.c:3512
 #, gcc-internal-format
@@ -43422,10 +38211,8 @@
 msgstr ""
 
 #: cp/call.c:3934
-#, fuzzy
-#| msgid "conversion from %qT to %qT is ambiguous"
 msgid "conversion from %qH to %qI is ambiguous"
-msgstr "преобразование из %qT в %qT неоднозначно"
+msgstr ""
 
 #: cp/call.c:4080
 msgid "initializing %qH with %qI in converted constant expression does not bind directly"
@@ -43432,10 +38219,8 @@
 msgstr ""
 
 #: cp/call.c:4101
-#, fuzzy
-#| msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
 msgid "conversion from %qH to %qI in a converted constant expression"
-msgstr "неявная конверсия из %qT в %qT для совместимости с другим операндом бинарного выражения"
+msgstr ""
 
 #: cp/call.c:4238
 #, gcc-internal-format
@@ -43450,10 +38235,9 @@
 #. It's no good looking for an overloaded operator() on a
 #. pointer-to-member-function.
 #: cp/call.c:4476
-#, fuzzy, gcc-internal-format
-#| msgid "pointer-to-member function %E cannot be called without an object; consider using .* or ->*"
+#, gcc-internal-format
 msgid "pointer-to-member function %qE cannot be called without an object; consider using %<.*%> or %<->*%>"
-msgstr "указатель на элемент-функцию %E нельзя вызвать без задания объекта; рекомендуется использовать конструкцию .* или ->*"
+msgstr ""
 
 #: cp/call.c:4547
 #, gcc-internal-format
@@ -43466,28 +38250,24 @@
 msgstr "вызов %<(%T) (%A)%> неоднозначен"
 
 #: cp/call.c:4612
-#, fuzzy, gcc-internal-format
-#| msgid "ambiguous overload for %qs in %<%s %E%>"
+#, gcc-internal-format
 msgid "ambiguous overload for "
-msgstr "неоднозначная перегрузка для %qs в %<%s %E%>"
+msgstr ""
 
 #: cp/call.c:4613
-#, fuzzy, gcc-internal-format
-#| msgid "no match for %qs in %<%s %E%>"
+#, gcc-internal-format
 msgid "no match for "
-msgstr "нет соответствия для %qs в %<%s %E%>"
+msgstr ""
 
 #: cp/call.c:4616
-#, fuzzy, gcc-internal-format
-#| msgid "invalid operands to binary %s (have %qT and %qT)"
+#, gcc-internal-format
 msgid " (operand types are %qT, %qT, and %qT)"
-msgstr "неверные операнды бинарной операции %s (%qT и %qT)"
+msgstr ""
 
 #: cp/call.c:4618
-#, fuzzy, gcc-internal-format
-#| msgid "invalid operands to binary %s (have %qT and %qT)"
+#, gcc-internal-format
 msgid " (operand types are %qT and %qT)"
-msgstr "неверные операнды бинарной операции %s (%qT и %qT)"
+msgstr ""
 
 #: cp/call.c:4620
 #, gcc-internal-format
@@ -43495,64 +38275,54 @@
 msgstr ""
 
 #: cp/call.c:4636
-#, fuzzy, gcc-internal-format
-#| msgid "expected %<operator%>"
+#, gcc-internal-format
 msgid "ternary %<operator?:%>"
-msgstr "ожидалось %<operator%>"
+msgstr "тернарный %<operator?:%>"
 
 #: cp/call.c:4640
-#, fuzzy, gcc-internal-format
-#| msgid "no match for ternary %<operator?:%> in %<%E ? %E : %E%>"
+#, gcc-internal-format
 msgid "ternary %<operator?:%> in %<%E ? %E : %E%>"
-msgstr "нет соответствия для трехместного %<operator?:%> в %<%E ? %E : %E%>"
+msgstr ""
 
 #: cp/call.c:4649 cp/call.c:4680 cp/call.c:4689
-#, fuzzy, gcc-internal-format
-#| msgid "expected %<operator%>"
+#, gcc-internal-format
 msgid "%<operator%s%>"
-msgstr "ожидалось %<operator%>"
+msgstr "%<operator%s%>"
 
 #: cp/call.c:4652
-#, fuzzy, gcc-internal-format
-#| msgid "no match for %<operator%s%> in %<%E%s%>"
+#, gcc-internal-format
 msgid "%<operator%s%> in %<%E%s%>"
-msgstr "нет соответствия для %<operator%s%> в %<%E%s%>"
+msgstr "%<operator%s%> в %<%E%s%>"
 
 #: cp/call.c:4659
-#, fuzzy, gcc-internal-format
-#| msgid "expected %<operator%>"
+#, gcc-internal-format
 msgid "%<operator[]%>"
-msgstr "ожидалось %<operator%>"
+msgstr "%<operator[]%>"
 
 #: cp/call.c:4662
-#, fuzzy, gcc-internal-format
-#| msgid "no match for %<operator[]%> in %<%E[%E]%>"
+#, gcc-internal-format
 msgid "%<operator[]%> in %<%E[%E]%>"
-msgstr "нет соответствия для %<operator[]%> в %<%E[%E]%>"
+msgstr "%<operator[]%> в %<%E[%E]%>"
 
 #: cp/call.c:4670
-#, fuzzy, gcc-internal-format
-#| msgid "%s"
+#, gcc-internal-format
 msgid "%qs"
-msgstr "%s"
+msgstr "%qs"
 
 #: cp/call.c:4673
-#, fuzzy, gcc-internal-format
-#| msgid "no match for %qs in %<%s %E%>"
+#, gcc-internal-format
 msgid "%qs in %<%s %E%>"
-msgstr "нет соответствия для %qs в %<%s %E%>"
+msgstr "%qs в %<%s %E%>"
 
 #: cp/call.c:4683
-#, fuzzy, gcc-internal-format
-#| msgid "no match for %<operator%s%> in %<%E %s %E%>"
+#, gcc-internal-format
 msgid "%<operator%s%> in %<%E %s %E%>"
-msgstr "нет соответствия для %<operator%s%> в %<%E %s %E%>"
+msgstr "%<operator%s%> в %<%E %s %E%>"
 
 #: cp/call.c:4692
-#, fuzzy, gcc-internal-format
-#| msgid "no match for %<operator%s%> in %<%s%E%>"
+#, gcc-internal-format
 msgid "%<operator%s%> in %<%s%E%>"
-msgstr "нет соответствия для %<operator%s%> в %<%s%E%>"
+msgstr "%<operator%s%> в %<%s%E%>"
 
 #: cp/call.c:4801
 #, gcc-internal-format
@@ -43562,19 +38332,16 @@
 #: cp/call.c:4863
 #, gcc-internal-format
 msgid "inferred scalar type %qT is not an integer or floating point type of the same size as %qT"
-msgstr ""
+msgstr "выведенный скалярный тип %qT не есть целый или плавающий тип того же размера, что и %qT"
 
 #: cp/call.c:4880 cp/call.c:4887
-#, fuzzy
-#| msgid "conversion of scalar to vector involves truncation"
 msgid "conversion of scalar %qH to vector %qI involves truncation"
-msgstr "преобразование скаляра в вектор приводит к усечению значения"
+msgstr ""
 
 #: cp/call.c:4940
-#, fuzzy, gcc-internal-format
-#| msgid "enumeral mismatch in conditional expression: %qT vs %qT"
+#, gcc-internal-format
 msgid "incompatible vector types in conditional expression: %qT, %qT and %qT"
-msgstr "несоответствие перечислимых типов в условном выражении: %qT vs %qT"
+msgstr "несовместимые векторные типы в условном выражении: %qT, %qT и %qT"
 
 #: cp/call.c:5030
 #, gcc-internal-format
@@ -43597,10 +38364,8 @@
 msgstr ""
 
 #: cp/call.c:5280
-#, fuzzy
-#| msgid "implicit conversion from %qT to %qT to match other result of conditional"
 msgid "implicit conversion from %qH to %qI to match other result of conditional"
-msgstr "неявная конверсия из %qT в %qT для совместимости с другим результатом условного выражения"
+msgstr ""
 
 #: cp/call.c:5293
 #, gcc-internal-format
@@ -43630,18 +38395,17 @@
 #: cp/call.c:6265
 #, gcc-internal-format
 msgid "exception cleanup for this placement new selects non-placement operator delete"
-msgstr ""
+msgstr "очистка исключений для этого размещения new выбирает неразмещенный оператор delete"
 
 #: cp/call.c:6268
 #, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function in C++14 (or with -fsized-deallocation)"
-msgstr ""
+msgstr "%qD есть обычная (неразмещенная) функция освобождения в C++14 (или с -fsized-deallocation)"
 
 #: cp/call.c:6303
-#, fuzzy, gcc-internal-format
-#| msgid "non-placement deallocation function %q+D"
+#, gcc-internal-format
 msgid "%qD is a usual (non-placement) deallocation function"
-msgstr "неразмещенная функция освобождения %q+D"
+msgstr "%qD есть обычная (неразмещенная) функция освобождения"
 
 #: cp/call.c:6435
 #, gcc-internal-format
@@ -43654,34 +38418,29 @@
 msgstr "нет подходящего operator %s%> для %qT"
 
 #: cp/call.c:6476
-#, fuzzy, gcc-internal-format
-#| msgid "within this context"
+#, gcc-internal-format
 msgid "%q#D is private within this context"
-msgstr "в данном контексте"
+msgstr "%q#D private в данном контексте"
 
-#: cp/call.c:6478 cp/decl.c:7343
-#, fuzzy, gcc-internal-format
-#| msgid "declared here"
+#: cp/call.c:6478 cp/decl.c:7364
+#, gcc-internal-format
 msgid "declared private here"
-msgstr "объявлено здесь"
+msgstr "декларировано private здесь"
 
 #: cp/call.c:6484
-#, fuzzy, gcc-internal-format
-#| msgid "within this context"
+#, gcc-internal-format
 msgid "%q#D is protected within this context"
-msgstr "в данном контексте"
+msgstr "%q#D protected в данном контексте"
 
-#: cp/call.c:6486 cp/decl.c:7344
-#, fuzzy, gcc-internal-format
-#| msgid "declared here"
+#: cp/call.c:6486 cp/decl.c:7365
+#, gcc-internal-format
 msgid "declared protected here"
-msgstr "объявлено здесь"
+msgstr "декларировано protected здесь"
 
 #: cp/call.c:6492
-#, fuzzy, gcc-internal-format
-#| msgid "%q+#D is inaccessible"
+#, gcc-internal-format
 msgid "%q#D is inaccessible within this context"
-msgstr "%q+#D недоступен"
+msgstr "%q#D недоступно в данном контексте"
 
 #: cp/call.c:6556
 #, gcc-internal-format
@@ -43709,16 +38468,12 @@
 msgstr "слишком много фигурных скобок вокруг инициализатора для %qT"
 
 #: cp/call.c:6671
-#, fuzzy
-#| msgid "cannot convert %qT to %qT in initialization"
 msgid "converting to %qH from %qI requires direct-initialization"
-msgstr "ошибка преобразования %qT в %qT в инициализации"
+msgstr ""
 
 #: cp/call.c:6679
-#, fuzzy
-#| msgid "invalid user-defined conversion from %qT to %qT"
 msgid "invalid user-defined conversion from %qH to %qI"
-msgstr "некорректное определенное пользователем преобразование из %qT в %qT"
+msgstr ""
 
 #: cp/call.c:6696 cp/call.c:6720 cp/call.c:6843 cp/call.c:6938 cp/call.c:6990
 #: cp/call.c:7018 cp/typeck.c:8815
@@ -43727,10 +38482,8 @@
 msgstr "  при инициализации %P -го аргумента %qD"
 
 #: cp/call.c:6716 cp/cvt.c:226
-#, fuzzy
-#| msgid "invalid conversion from %qT to %qT"
 msgid "invalid conversion from %qH to %qI"
-msgstr "некорректное преобразование из %qT в %qT"
+msgstr ""
 
 #: cp/call.c:6757 cp/call.c:6764
 #, gcc-internal-format
@@ -43738,28 +38491,21 @@
 msgstr "преобразование в %qT из списка инициализации будет использовать явный конструктор %qD"
 
 #: cp/call.c:6760
-#, fuzzy, gcc-internal-format
-#| msgid "only declarations of constructors can be %<explicit%>"
+#, gcc-internal-format
 msgid "in C++11 and above a default constructor can be explicit"
-msgstr "только декларации конструкторов могут быть %<explicit%>"
+msgstr "в C++11 и выше подразумеваемый конструктор может быть явным"
 
 #: cp/call.c:7004
-#, fuzzy
-#| msgid "conversion to volatile reference type %q#T from rvalue of type %qT"
 msgid "cannot bind rvalue reference of type %qH to lvalue of type %qI"
-msgstr "преобразование к volatile ссылке типа %qT из rvalue типа %qT"
+msgstr ""
 
 #: cp/call.c:7008
-#, fuzzy
-#| msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
 msgid "cannot bind non-const lvalue reference of type %qH to an rvalue of type %qI"
-msgstr "некорректная инициализация неконстантной ссылки типа %qT из rvalue типа %qT"
+msgstr ""
 
 #: cp/call.c:7011
-#, fuzzy
-#| msgid "passing %qT as %<this%> argument of %q#D discards qualifiers"
 msgid "binding reference of type %qH to %qI discards qualifiers"
-msgstr "передача %qT как аргумент %<this%> %q#D отменяет квалификаторы"
+msgstr ""
 
 #: cp/call.c:7047
 #, gcc-internal-format
@@ -43777,33 +38523,28 @@
 msgstr "недопустимое связывание rvalue %qE с %qT"
 
 #: cp/call.c:7163
-#, fuzzy
-#| msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgid "implicit conversion from %qH to %qI when passing argument to function"
-msgstr "неявная конверсия из %qT в %qT при передаче аргумента функции"
+msgstr ""
 
 #: cp/call.c:7180 cp/cvt.c:1890
 #, gcc-internal-format
 msgid "scoped enum %qT passed through ... as %qT before -fabi-version=6, %qT after"
-msgstr ""
+msgstr "scoped enum %qT передан дальше ... как %qT перед fabi-version=6, %qT после"
 
 #: cp/call.c:7217
-#, fuzzy, gcc-internal-format
-#| msgid "cannot pass objects of non-trivially-copyable type %q#T through %<...%>"
+#, gcc-internal-format
 msgid "passing objects of non-trivially-copyable type %q#T through %<...%> is conditionally supported"
-msgstr "невозможно передать объекты нетривиально копируемого типа %q#T через %<...%>"
+msgstr "передача объектов нетривиально копируемого типа %q#T через %<...%> условно поддерживается"
 
 #: cp/call.c:7253
-#, fuzzy, gcc-internal-format
-#| msgid "cannot receive objects of non-trivially-copyable type %q#T through %<...%>; "
+#, gcc-internal-format
 msgid "cannot receive reference type %qT through %<...%>"
-msgstr "невозможно принять объекты нетривиально копируемого типа %q#T через %<...%>"
+msgstr "невозможно принять ссылочный тип %q#T через %<...%>"
 
 #: cp/call.c:7263
-#, fuzzy, gcc-internal-format
-#| msgid "cannot receive objects of non-trivially-copyable type %q#T through %<...%>; "
+#, gcc-internal-format
 msgid "receiving objects of non-trivially-copyable type %q#T through %<...%> is conditionally-supported"
-msgstr "невозможно принять объекты нетривиально копируемого типа %q#T через %<...%>"
+msgstr "прием объектов нетривиально копируемого типа %q#T через %<...%> условно поддерживается"
 
 #: cp/call.c:7331
 #, gcc-internal-format
@@ -43821,16 +38562,14 @@
 msgstr "аргумент вызова функции мог быть кандидатом для атрибута формата"
 
 #: cp/call.c:7499
-#, fuzzy, gcc-internal-format
-#| msgid "defaulted function %q+D with default argument"
+#, gcc-internal-format
 msgid "use of multiversioned function without a default"
-msgstr "подразумеваемая функция %q+D с подразумеваемым аргументом"
+msgstr "использование мультиверсионной функции без подразумеваемой"
 
 #: cp/call.c:7864
-#, fuzzy, gcc-internal-format
-#| msgid "passing %qT as %<this%> argument of %q#D discards qualifiers"
+#, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
-msgstr "передача %qT как аргумент %<this%> %q#D отменяет квалификаторы"
+msgstr "передача %qT как аргумент %<this%> отбрасывает квалификаторы"
 
 #: cp/call.c:7867 cp/call.c:7983 cp/call.c:10147
 #, gcc-internal-format
@@ -43853,10 +38592,9 @@
 msgstr "  (вы можете отключить это посредством -fno-deduce-init-list)"
 
 #: cp/call.c:8096
-#, fuzzy, gcc-internal-format
-#| msgid "too many arguments to constructor %q#D"
+#, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
-msgstr "слишком много аргументов для конструктора %q#D"
+msgstr "передача аргументов в многоточие унаследованного конструктора %qD"
 
 #: cp/call.c:8579
 #, gcc-internal-format
@@ -43864,10 +38602,9 @@
 msgstr ""
 
 #: cp/call.c:8582
-#, fuzzy, gcc-internal-format
-#| msgid "%qD cannot be thread-local because it has non-trivial type %qT"
+#, gcc-internal-format
 msgid "%qD writing to an object of non-trivial type %#qT%s"
-msgstr "%qD не может быть локально-поточным, поскольку имеет нетривиальный тип %qT"
+msgstr ""
 
 #: cp/call.c:8587
 #, gcc-internal-format
@@ -43880,22 +38617,19 @@
 msgstr ""
 
 #: cp/call.c:8607
-#, fuzzy, gcc-internal-format
-#| msgid "assignment (not initialization) in declaration"
+#, gcc-internal-format
 msgid "; use assignment or value-initialization instead"
-msgstr "присваивание (а не инициализация) в декларации"
+msgstr ""
 
 #: cp/call.c:8609
-#, fuzzy, gcc-internal-format
-#| msgid "use #include instead"
+#, gcc-internal-format
 msgid "; use assignment instead"
-msgstr "используйте директиву #include"
+msgstr ""
 
 #: cp/call.c:8611
-#, fuzzy, gcc-internal-format
-#| msgid "value-initialization of function type %qT"
+#, gcc-internal-format
 msgid "; use value-initialization instead"
-msgstr "инициализация значения функционального типа %qT"
+msgstr ""
 
 #: cp/call.c:8614
 #, gcc-internal-format
@@ -43903,10 +38637,9 @@
 msgstr ""
 
 #: cp/call.c:8617
-#, fuzzy, gcc-internal-format
-#| msgid "%qD cannot be thread-local because it has non-trivial type %qT"
+#, gcc-internal-format
 msgid "%qD clearing an object of non-trivial type %#qT%s"
-msgstr "%qD не может быть локально-поточным, поскольку имеет нетривиальный тип %qT"
+msgstr ""
 
 #: cp/call.c:8619
 #, gcc-internal-format
@@ -43914,22 +38647,19 @@
 msgstr ""
 
 #: cp/call.c:8640
-#, fuzzy, gcc-internal-format
-#| msgid "assignment (not initialization) in declaration"
+#, gcc-internal-format
 msgid "; use copy-assignment or copy-initialization instead"
-msgstr "присваивание (а не инициализация) в декларации"
+msgstr ""
 
 #: cp/call.c:8642
-#, fuzzy, gcc-internal-format
-#| msgid "use #include instead"
+#, gcc-internal-format
 msgid "; use copy-assignment instead"
-msgstr "используйте директиву #include"
+msgstr ""
 
 #: cp/call.c:8644
-#, fuzzy, gcc-internal-format
-#| msgid "Extension: re-initialization of '%s' at %L"
+#, gcc-internal-format
 msgid "; use copy-initialization instead"
-msgstr "Расширение: повторная инициализация '%s' в %L"
+msgstr ""
 
 #: cp/call.c:8647
 #, gcc-internal-format
@@ -43937,10 +38667,9 @@
 msgstr ""
 
 #: cp/call.c:8650
-#, fuzzy, gcc-internal-format
-#| msgid "conversion to void will not access object of non-trivially-copyable type %qT"
+#, gcc-internal-format
 msgid "%qD writing to an object of non-trivially copyable type %#qT%s"
-msgstr "преобразование к void не даст доступ к объекту нетривиально копируемого типа %qT"
+msgstr ""
 
 #: cp/call.c:8653
 #, gcc-internal-format
@@ -43968,10 +38697,9 @@
 msgstr ""
 
 #: cp/call.c:8706
-#, fuzzy, gcc-internal-format
-#| msgid "cannot receive objects of non-trivially-copyable type %q#T through %<...%>; "
+#, gcc-internal-format
 msgid "%qD moving an object of non-trivially copyable type %#qT; use %<new%> and %<delete%> instead"
-msgstr "невозможно принять объекты нетривиально копируемого типа %q#T через %<...%>"
+msgstr ""
 
 #: cp/call.c:8709
 #, gcc-internal-format
@@ -43989,16 +38717,14 @@
 msgstr ""
 
 #: cp/call.c:8743
-#, fuzzy, gcc-internal-format
-#| msgid "%qD declared here"
+#, gcc-internal-format
 msgid "%#qT declared here"
-msgstr "%qD объявлено здесь"
+msgstr ""
 
 #: cp/call.c:8839
-#, fuzzy, gcc-internal-format
-#| msgid "constant refers to itself"
+#, gcc-internal-format
 msgid "constructor delegates to itself"
-msgstr "константа ссылается на себя"
+msgstr "конструктор делегирует к себе"
 
 #: cp/call.c:9079
 #, gcc-internal-format
@@ -44005,16 +38731,15 @@
 msgid "call to non-function %qD"
 msgstr "вызов не функции %qD"
 
-#: cp/call.c:9119 cp/pt.c:15053 cp/typeck.c:2901
+#: cp/call.c:9119 cp/pt.c:15075 cp/typeck.c:2901
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "невозможно вызвать конструктор %<%T::%D%> непосредственно"
 
 #: cp/call.c:9121
-#, fuzzy, gcc-internal-format
-#| msgid "  for a function-style cast, remove the redundant %<::%D%>"
+#, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
-msgstr "  для приведения типов в функциональном стиле удалите лишние %<::%D%>"
+msgstr "для приведения типов в функциональном стиле удалите избыточные %<::%D%>"
 
 #: cp/call.c:9259
 #, gcc-internal-format
@@ -44022,16 +38747,14 @@
 msgstr "нет подходящей функции для вызова %<%T::operator %T(%A)%#V%>"
 
 #: cp/call.c:9276
-#, fuzzy, gcc-internal-format
-#| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
+#, gcc-internal-format
 msgid "no matching function for call to %<%T::%s%E(%A)%#V%>"
-msgstr "нет подходящей функции для вызова %<%T::%s(%A)%#V%>"
+msgstr ""
 
 #: cp/call.c:9300
-#, fuzzy, gcc-internal-format
-#| msgid "no matching function for call to %<%D(%A)%>"
+#, gcc-internal-format
 msgid "no matching function for call to %<%s(%A)%>"
-msgstr "нет соответствующей функции для вызова %<%D(%A)%>"
+msgstr "нет соответствующей функции для вызова %<%s(%A)%>"
 
 #: cp/call.c:9303
 #, gcc-internal-format
@@ -44040,24 +38763,21 @@
 
 #
 #: cp/call.c:9324
-#, fuzzy, gcc-internal-format
-#| msgid "non-static data member initializers"
+#, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
-msgstr "инициализаторы нестатических элементов данных"
+msgstr "чисто виртуальная %q#D вызвана из инициализатора нестатического элемента данных"
 
 #
 #: cp/call.c:9329
-#, fuzzy, gcc-internal-format
-#| msgid "non-static data member initializers"
+#, gcc-internal-format
 msgid "pure virtual %q#D called from constructor"
-msgstr "инициализаторы нестатических элементов данных"
+msgstr "чисто виртуальная %q#D вызвана из конструктора"
 
 #
 #: cp/call.c:9330
-#, fuzzy, gcc-internal-format
-#| msgid "non-static data member initializers"
+#, gcc-internal-format
 msgid "pure virtual %q#D called from destructor"
-msgstr "инициализаторы нестатических элементов данных"
+msgstr "чисто виртуальная %q#D вызвана из деструктора"
 
 #: cp/call.c:9353
 #, gcc-internal-format
@@ -44075,10 +38795,8 @@
 msgstr "предпочтение отдается %qD (а не %qD)"
 
 #: cp/call.c:10206
-#, fuzzy
-#| msgid "  for conversion from %qT to %qT"
 msgid "  for conversion from %qH to %qI"
-msgstr "  при преобразовании из %qT в %qT,"
+msgstr ""
 
 #: cp/call.c:10209
 #, gcc-internal-format
@@ -44091,16 +38809,14 @@
 msgstr "несоответствие подразумеваемого аргумента при разрешении перегрузки"
 
 #: cp/call.c:10437
-#, fuzzy, gcc-internal-format
-#| msgid " candidate 1: %q+#F"
+#, gcc-internal-format
 msgid " candidate 1: %q#F"
-msgstr " кандидат 1: %q+#F"
+msgstr ""
 
 #: cp/call.c:10439
-#, fuzzy, gcc-internal-format
-#| msgid " candidate 2: %q+#F"
+#, gcc-internal-format
 msgid " candidate 2: %q#F"
-msgstr " кандидат 2: %q+#F"
+msgstr ""
 
 #: cp/call.c:10484
 #, gcc-internal-format
@@ -44108,10 +38824,8 @@
 msgstr "ISO C++ говорит здесь о неоднозначности, хотя худшее преобразование для первого лучше, чем худшее преобразование для второго:"
 
 #: cp/call.c:10667
-#, fuzzy
-#| msgid "could not convert %qE from %qT to %qT"
 msgid "could not convert %qE from %qH to %qI"
-msgstr "ошибка преобразования %qE из %qT в %qT"
+msgstr ""
 
 #: cp/call.c:10869
 #, gcc-internal-format
@@ -44119,65 +38833,53 @@
 msgstr "временная граница %qD сохраняется, пока существует конструктор"
 
 #: cp/call.c:10994
-#, fuzzy
-#| msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
 msgid "invalid initialization of non-const reference of type %qH from an rvalue of type %qI"
-msgstr "некорректная инициализация неконстантной ссылки типа %qT из rvalue типа %qT"
+msgstr ""
 
 #: cp/call.c:10998
-#, fuzzy
-#| msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgid "invalid initialization of reference of type %qH from expression of type %qI"
-msgstr "некорректная инициализация ссылки типа %qT из выражения типа %qT"
+msgstr ""
 
 #: cp/class.c:314
-#, fuzzy, gcc-internal-format
-#| msgid "cannot convert from base %qT to derived type %qT via virtual base %qT"
+#, gcc-internal-format
 msgid "cannot convert from pointer to base class %qT to pointer to derived class %qT because the base is virtual"
-msgstr "ошибка преобразования базового %qT в производный тип %qT через виртуальный базовый тип %qT"
+msgstr "невозможно преобразовать из указателя на базовый класс %qT в указатель на производный класс %qT, так как база является виртуальной"
 
 #: cp/class.c:318
-#, fuzzy, gcc-internal-format
-#| msgid "cannot convert from base %qT to derived type %qT via virtual base %qT"
+#, gcc-internal-format
 msgid "cannot convert from base class %qT to derived class %qT because the base is virtual"
-msgstr "ошибка преобразования базового %qT в производный тип %qT через виртуальный базовый тип %qT"
+msgstr "невозможно преобразовать из базового класса %qT в производный класс %qT, так как база является виртуальной"
 
 #: cp/class.c:325
-#, fuzzy, gcc-internal-format
-#| msgid "cannot convert from base %qT to derived type %qT via virtual base %qT"
+#, gcc-internal-format
 msgid "cannot convert from pointer to base class %qT to pointer to derived class %qT via virtual base %qT"
-msgstr "ошибка преобразования базового %qT в производный тип %qT через виртуальный базовый тип %qT"
+msgstr "невозможно преобразовать из указателя на базовый класс %qT в указатель на производный класс %qT посредством виртуальной базы %qT"
 
 #: cp/class.c:330
-#, fuzzy, gcc-internal-format
-#| msgid "cannot convert from base %qT to derived type %qT via virtual base %qT"
+#, gcc-internal-format
 msgid "cannot convert from base class %qT to derived class %qT via virtual base %qT"
-msgstr "ошибка преобразования базового %qT в производный тип %qT через виртуальный базовый тип %qT"
+msgstr "невозможно преобразовать из базового класса %qT в производный класс %qT посредством виртуальной базы %qT"
 
 #: cp/class.c:1110
-#, fuzzy, gcc-internal-format
-#| msgid "conflicts with previous declaration here"
+#, gcc-internal-format
 msgid "%q#D conflicts with version inherited from %qT"
-msgstr "противоречит предыдущей декларации здесь"
+msgstr ""
 
 #: cp/class.c:1113
-#, fuzzy, gcc-internal-format
-#| msgid "%qD declared here"
+#, gcc-internal-format
 msgid "version inherited from %qT declared here"
-msgstr "%qD объявлено здесь"
+msgstr ""
 
 #: cp/class.c:1133
-#, fuzzy, gcc-internal-format
-#| msgid "%q+#D cannot be overloaded"
+#, gcc-internal-format
 msgid "%q#D cannot be overloaded with %q#D"
-msgstr "%q+#D не может быть перегружено"
+msgstr ""
 
 #: cp/class.c:1135 cp/decl.c:1706 cp/decl.c:1727 cp/decl.c:1759
 #: cp/name-lookup.c:2285 cp/name-lookup.c:2564
-#, fuzzy, gcc-internal-format
-#| msgid "previous declaration %q+#D"
+#, gcc-internal-format
 msgid "previous declaration %q#D"
-msgstr "предыдущая декларация %q+#D"
+msgstr "предыдущая декларация %q#D"
 
 #: cp/class.c:1181
 #, gcc-internal-format
@@ -44190,55 +38892,50 @@
 msgstr "противоречивые спецификации доступа для поля %qE, игнорируются"
 
 #: cp/class.c:1253
-#, fuzzy, gcc-internal-format
-#| msgid "  because of local method %q+#D with same name"
+#, gcc-internal-format
 msgid "%qD invalid in %q#T because of local method %q#D with same name"
-msgstr "  из-за локального метода %q+#D с тем же именем"
+msgstr ""
 
 #: cp/class.c:1257
-#, fuzzy, gcc-internal-format
-#| msgid "%q+#D declared here"
+#, gcc-internal-format
 msgid "local method %q#D declared here"
-msgstr "%q+#D декларировано здесь"
+msgstr ""
 
 #: cp/class.c:1263
-#, fuzzy, gcc-internal-format
-#| msgid "  because of local member %q+#D with same name"
+#, gcc-internal-format
 msgid "%qD invalid in %q#T because of local member %q#D with same name"
-msgstr "  из-за локального элемента %q+#D с тем же именем"
+msgstr ""
 
 #: cp/class.c:1267
-#, fuzzy, gcc-internal-format
-#| msgid "  %q+#D declared here"
+#, gcc-internal-format
 msgid "local member %q#D declared here"
-msgstr "  %q+#D декларировано здесь"
+msgstr ""
 
 #: cp/class.c:1322
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its return type) has"
-msgstr ""
+msgstr "%qD наследует %E ABI тэг, который имеет %qT (использованный в его типе возврата)"
 
 #: cp/class.c:1325 cp/class.c:1331 cp/class.c:1337 cp/class.c:1348
 #: cp/cvt.c:1028
-#, fuzzy, gcc-internal-format
-#| msgid "%qD declared here"
+#, gcc-internal-format
 msgid "%qT declared here"
-msgstr "%qD объявлено здесь"
+msgstr "%qT декларировано здесь"
 
 #: cp/class.c:1329
 #, gcc-internal-format
 msgid "%qD inherits the %E ABI tag that %qT (used in its type) has"
-msgstr ""
+msgstr "%qD наследует %E ABI тэг, который имеет %qT (использованный в его типе)"
 
 #: cp/class.c:1335
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that base %qT has"
-msgstr ""
+msgstr "%qT не имеет %E ABI тэг, который имеет базовый %qT"
 
 #: cp/class.c:1342
 #, gcc-internal-format
 msgid "%qT does not have the %E ABI tag that %qT (used in the type of %qD) has"
-msgstr ""
+msgstr "%qT не имеет %E ABI тэг, который имеет %qT (использованный в типе %qD)"
 
 #: cp/class.c:1647
 #, gcc-internal-format
@@ -44245,449 +38942,414 @@
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr "ошибка вывода из %<final%> base %qT в производном типе %qT"
 
-#: cp/class.c:2098
+#: cp/class.c:2103
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr "все элементы-функции в классе %qT - частные (private)"
 
-#: cp/class.c:2110
+#: cp/class.c:2115
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr "в %q#T определен только private деструктор и нет друзей"
 
-#: cp/class.c:2152
+#: cp/class.c:2156
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr "в %q#T определен только private конструктор и нет друзей"
 
-#: cp/class.c:2156
+#: cp/class.c:2160
 #, gcc-internal-format
 msgid "%q#D is public, but requires an existing %q#T object"
 msgstr ""
 
-#: cp/class.c:2430
+#: cp/class.c:2434
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr "отсутствует уникальное переопределение %qD в %qT"
 
-#: cp/class.c:2785
-#, fuzzy, gcc-internal-format
-#| msgid "%q+#D cannot be overloaded"
+#: cp/class.c:2789
+#, gcc-internal-format
 msgid "%qD can be marked override"
-msgstr "%q+#D не может быть перегружено"
+msgstr "%q#D может быть помечен override"
 
-#: cp/class.c:2797
-#, fuzzy, gcc-internal-format
-#| msgid "%q+#D marked final, but is not virtual"
+#: cp/class.c:2801
+#, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
-msgstr "%q+#D помечен как final, но не является virtual"
+msgstr "%q+#D помечен %<final%>, но не является virtual"
 
-#: cp/class.c:2799
-#, fuzzy, gcc-internal-format
-#| msgid "%q+#D marked override, but does not override"
+#: cp/class.c:2803
+#, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
-msgstr "%q+#D помечен как override, но не делается override"
+msgstr "%q+#D помечен %<override%>, но не делается override"
 
-#: cp/class.c:2861
-#, fuzzy, gcc-internal-format
-#| msgid "%q+D was hidden"
+#: cp/class.c:2865
+#, gcc-internal-format
 msgid "%qD was hidden"
-msgstr "%q+D скрыто"
+msgstr "%qD было скрыто"
 
-#: cp/class.c:2863
-#, fuzzy, gcc-internal-format
-#| msgid "  by %q+D"
+#: cp/class.c:2867
+#, gcc-internal-format
 msgid "  by %qD"
-msgstr "  методом %q+D"
+msgstr ""
 
-#: cp/class.c:2896
-#, fuzzy, gcc-internal-format
-#| msgid "%q+#D invalid; an anonymous union can only have non-static data members"
+#: cp/class.c:2900
+#, gcc-internal-format
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
-msgstr "%q+#D некорректно; анонимное объединение может иметь только нестатические элементы данных"
+msgstr ""
 
-#: cp/class.c:2906 cp/name-lookup.c:3293 cp/parser.c:19720
+#: cp/class.c:2910 cp/name-lookup.c:3293 cp/parser.c:19717
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
 
-#: cp/class.c:3097
+#: cp/class.c:3101
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
-msgstr ""
+msgstr "многоточие в %qD не наследуется"
 
-#: cp/class.c:3213
+#: cp/class.c:3217
 #, gcc-internal-format
 msgid "bit-field %q+#D with non-integral type"
 msgstr "битовое поле %q+#D с нецелым типом"
 
-#: cp/class.c:3229
+#: cp/class.c:3233
 #, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr "ширина битового поля %q+D не является целой константой"
 
-#: cp/class.c:3234
+#: cp/class.c:3238
 #, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr "отрицательная ширина битового поля %q+D"
 
-#: cp/class.c:3239
+#: cp/class.c:3243
 #, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr "нулевая ширина битового поля %q+D"
 
-#: cp/class.c:3249
-#, fuzzy, gcc-internal-format
-#| msgid "width of %q+D exceeds its type"
+#: cp/class.c:3253
+#, gcc-internal-format
 msgid "width of %qD exceeds its type"
-msgstr "ширина поля %q+D превышает ширину его типа"
+msgstr "ширина %qD превышает его тип"
 
-#: cp/class.c:3255
-#, fuzzy, gcc-internal-format
-#| msgid "%q+D is too small to hold all values of %q#T"
+#: cp/class.c:3259
+#, gcc-internal-format
 msgid "%qD is too small to hold all values of %q#T"
-msgstr "%q+D слишком мало для представления всех значений типа %q#T"
+msgstr "%qD слишком мало для хранения всех значений %q#T"
 
-#: cp/class.c:3316
+#: cp/class.c:3320
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr "элемент %q+#D с конструктором не допускается в объединении"
 
-#: cp/class.c:3319
+#: cp/class.c:3323
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr "элемент %q+#D с деструктором не допускается в объединении"
 
-#: cp/class.c:3321
+#: cp/class.c:3325
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr "элемент %q+#D с операцией присваивания путем копирования не допускается в объединении"
 
-#: cp/class.c:3325
+#: cp/class.c:3329
 #, gcc-internal-format
 msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgstr "unrestricted объединения допустимы только с -std=c++11 или -std=gnu++11"
 
-#: cp/class.c:3453
-#, fuzzy, gcc-internal-format
-#| msgid "%q+D may not be static because it is a member of a union"
+#: cp/class.c:3457
+#, gcc-internal-format
 msgid "in C++98 %q+D may not be static because it is a member of a union"
-msgstr "%q+D может быть не статическим, поскольку это элемент объединения"
+msgstr "в C++98 %q+D может не быть статическим, поскольку это элемент объединения"
 
-#: cp/class.c:3460
-#, fuzzy, gcc-internal-format
-#| msgid "non-static data member %qD has Java class type"
+#: cp/class.c:3464
+#, gcc-internal-format
 msgid "non-static data member %q+D in a union may not have reference type %qT"
-msgstr "нестатический элемент данных %qD имеет тип Java класса"
+msgstr "нестатический элемент данных %q+D в объединении может не иметь ссылочный тип %qT"
 
-#: cp/class.c:3470
+#: cp/class.c:3474
 #, gcc-internal-format
 msgid "field %q+D invalidly declared function type"
 msgstr "поле %q+D ошибочно декларировано с типом функции"
 
-#: cp/class.c:3476
+#: cp/class.c:3480
 #, gcc-internal-format
 msgid "field %q+D invalidly declared method type"
 msgstr "поле %q+D ошибочно декларировано с типом метода"
 
-#: cp/class.c:3536
-#, fuzzy, gcc-internal-format
-#| msgid "ignoring packed attribute because of unpacked non-POD field %q+#D"
+#: cp/class.c:3540
+#, gcc-internal-format
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
-msgstr "атрибут packed проигнорирован для неупакованного не-POD поля %q+#D"
+msgstr "атрибут packed проигнорирован из-за неупакованного не-POD поля %q#D"
 
-#: cp/class.c:3585
-#, fuzzy, gcc-internal-format
-#| msgid "non-member %qs cannot be declared %<mutable%>"
+#: cp/class.c:3589
+#, gcc-internal-format
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
-msgstr "недопустимая декларация не-элемента %qs как %<mutable%>"
+msgstr "элемент %q+D не может быть декларирован и как %<const%>, и как %<mutable%>"
 
-#: cp/class.c:3591
-#, fuzzy, gcc-internal-format
-#| msgid "non-member %qs cannot be declared %<mutable%>"
+#: cp/class.c:3595
+#, gcc-internal-format
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
-msgstr "недопустимая декларация не-элемента %qs как %<mutable%>"
+msgstr "элемент %q+D не может быть декларирован как %<mutable%> ссылка"
 
-#: cp/class.c:3617
+#: cp/class.c:3621
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr "инициализация нескольких полей в объединении %qT"
 
-#: cp/class.c:3658
-#, fuzzy, gcc-internal-format
-#| msgid "field %q+#D with same name as class"
+#: cp/class.c:3662
+#, gcc-internal-format
 msgid "field %q#D with same name as class"
-msgstr "поле %q+#D с тем же именем, что и класс"
+msgstr "поле %q#D с тем же именем, что и класс"
 
-#: cp/class.c:3681
+#: cp/class.c:3685
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr "%q+#T содержит элементы данных типа указатель"
 
-#: cp/class.c:3686
+#: cp/class.c:3690
 #, gcc-internal-format
 msgid "  but does not override %<%T(const %T&)%>"
 msgstr "  но не переопределяет %<%T(const %T&)%>"
 
-#: cp/class.c:3688
+#: cp/class.c:3692
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr "  или %<operator=(const %T&)%>"
 
-#: cp/class.c:3692
+#: cp/class.c:3696
 #, gcc-internal-format
 msgid "  but does not override %<operator=(const %T&)%>"
 msgstr "  но не переопределяет %<operator=(const %T&)%>"
 
-#: cp/class.c:4097
+#: cp/class.c:4101
 #, gcc-internal-format
 msgid "alignment of %qD increased in -fabi-version=9 (GCC 5.2)"
-msgstr ""
+msgstr "выравнивание %qD увеличено в -fabi-version=9 (GCC 5.2)"
 
-#: cp/class.c:4100
-#, fuzzy, gcc-internal-format
-#| msgid "alignment of %qD is bigger than original declaration"
+#: cp/class.c:4104
+#, gcc-internal-format
 msgid "alignment of %qD will increase in -fabi-version=9"
-msgstr "выравнивание %qD больше чем в исходной декларации"
+msgstr "выравнивание %qD увеличится в -fabi-version=9"
 
-#: cp/class.c:4378
+#: cp/class.c:4382
 #, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "инициализатор задан для невиртуального метода %q+D"
 
-#: cp/class.c:4813
+#: cp/class.c:4817
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr "метод перебивает оба метода %<transaction_pure%> и %qE"
 
-#: cp/class.c:4834
+#: cp/class.c:4838
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr "описанный метод %qE перебивает метод %qE"
 
-#: cp/class.c:5350 cp/constexpr.c:237
-#, fuzzy, gcc-internal-format
-#| msgid "enclosing class of constexpr non-static member function %q+#D is not a literal type"
+#: cp/class.c:5367 cp/constexpr.c:237
+#, gcc-internal-format
 msgid "enclosing class of %<constexpr%> non-static member function %q+#D is not a literal type"
-msgstr "объемлющий класс constexpr нестатической функции-элемента %q+#D не является литеральным типом"
+msgstr ""
 
-#: cp/class.c:5374
+#: cp/class.c:5391
 #, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr "%q+T не является литералом, поскольку:"
 
-#: cp/class.c:5377
+#: cp/class.c:5394
 #, gcc-internal-format
 msgid "  %qT is a closure type, which is only literal in C++17 and later"
 msgstr ""
 
-#: cp/class.c:5380
+#: cp/class.c:5397
 #, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr "  %q+T имеет нетривиальный деструктор"
 
-#: cp/class.c:5387
-#, fuzzy, gcc-internal-format
-#| msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no constexpr constructor that is not a copy or move constructor"
+#: cp/class.c:5404
+#, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no %<constexpr%> constructor that is not a copy or move constructor"
-msgstr "  %q+T не агрегат, не имеет тривиальный подразумеваемый конструктор и и не имеет constexpr конструктор, который не является конструктором copy или move"
+msgstr ""
 
-#: cp/class.c:5420
+#: cp/class.c:5437
 #, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "  базовый класс %qT %q+T не литерал"
 
-#: cp/class.c:5435
-#, fuzzy, gcc-internal-format
-#| msgid "  non-static data member %q+D has non-literal type"
+#: cp/class.c:5452
+#, gcc-internal-format
 msgid "  non-static data member %qD has non-literal type"
-msgstr "  нестатический элемент данных %q+D имеет нелитеральный тип"
+msgstr ""
 
-#: cp/class.c:5442
-#, fuzzy, gcc-internal-format
-#| msgid "  non-static data member %q+D has non-literal type"
+#: cp/class.c:5459
+#, gcc-internal-format
 msgid "  non-static data member %qD has volatile type"
-msgstr "  нестатический элемент данных %q+D имеет нелитеральный тип"
+msgstr ""
 
-#: cp/class.c:5561
-#, fuzzy, gcc-internal-format
-#| msgid "base class %q#T has a non-virtual destructor"
+#: cp/class.c:5578
+#, gcc-internal-format
 msgid "base class %q#T has accessible non-virtual destructor"
-msgstr "базовый класс %q#T имеет невиртуальный деструктор"
+msgstr "базовый класс %q#T имеет доступный невиртуальный деструктор"
 
-#: cp/class.c:5590
-#, fuzzy, gcc-internal-format
-#| msgid "non-static reference %q+#D in class without a constructor"
+#: cp/class.c:5607
+#, gcc-internal-format
 msgid "non-static reference %q#D in class without a constructor"
-msgstr "нестатическая ссылка %q+#D в классе без конструктора"
+msgstr "нестатическая ссылка %q#D в классе без конструктора"
 
-#: cp/class.c:5596
-#, fuzzy, gcc-internal-format
-#| msgid "non-static const member %q+#D in class without a constructor"
+#: cp/class.c:5613
+#, gcc-internal-format
 msgid "non-static const member %q#D in class without a constructor"
-msgstr "нестатический константный элемент %q+#D в классе без конструктора"
+msgstr "нестатический константный элемент %q#D в классе без конструктора"
 
 #. If the function is defaulted outside the class, we just
 #. give the synthesis error.
-#: cp/class.c:5624
+#: cp/class.c:5641
 #, gcc-internal-format
 msgid "%q+D declared to take const reference, but implicit declaration would take non-const"
 msgstr "%q+D декларировано принимать константные ссылки, но неявная декларация будет принимать неконстантные"
 
-#: cp/class.c:5898
+#: cp/class.c:5915
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr "непосредственная база %qT недоступна в %qT из-за неоднозначности"
 
-#: cp/class.c:5910
+#: cp/class.c:5927
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr "виртуальная база %qT недоступна в %qT из-за неоднозначности"
 
-#: cp/class.c:6133
-#, fuzzy, gcc-internal-format
-#| msgid "offset of %q+D is not ABI-compliant and may change in a future version of GCC"
+#: cp/class.c:6150
+#, gcc-internal-format
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
-msgstr "смещение %q+D несовместимо с ABI и может измениться в будущих версиях GCC"
+msgstr "смещение %qD несовместимо с ABI и может измениться в будущих версиях GCC"
 
-#: cp/class.c:6291
-#, fuzzy, gcc-internal-format
-#| msgid "size of array %qE is too large"
+#: cp/class.c:6308
+#, gcc-internal-format
 msgid "size of type %qT is too large (%qE bytes)"
-msgstr "размер массива %qE слишком велик"
+msgstr "размер типа %qT слишком велик (%qE байт)"
 
-#: cp/class.c:6576
-#, fuzzy, gcc-internal-format
-#| msgid "invalid use of %<...%> with non-slice"
+#: cp/class.c:6593
+#, gcc-internal-format
 msgid "invalid use of %q#T with a zero-size array in %q#D"
-msgstr "некорректное использование %<...%> с non-slice"
+msgstr "некорректное использование %q#T с массивом нулевого размера в %q#D"
 
-#: cp/class.c:6578
-#, fuzzy, gcc-internal-format
-#| msgid "invalid use of structure with flexible array member"
+#: cp/class.c:6595
+#, gcc-internal-format
 msgid "invalid use of %q#T with a flexible array member in %q#T"
-msgstr "неверное употребление структуры с регулируемым элементом-массивом"
+msgstr "недопустимое использование %q#T с элементом регулируемого массива в %q#T"
 
-#: cp/class.c:6583
-#, fuzzy, gcc-internal-format
-#| msgid "  %q+#D declared here"
+#: cp/class.c:6600
+#, gcc-internal-format
 msgid "array member %q#D declared here"
-msgstr "  %q+#D декларировано здесь"
+msgstr "элемент массива %q#D объявлен здесь"
 
-#: cp/class.c:6610
-#, fuzzy, gcc-internal-format
-#| msgid "flexible array member not at end of struct"
+#: cp/class.c:6627
+#, gcc-internal-format
 msgid "zero-size array member %qD not at end of %q#T"
-msgstr "регулируемый элемент-массив - не последний элемент структуры"
+msgstr "элемент массива нулевого размера %qD не в конце %q#T"
 
-#: cp/class.c:6612
-#, fuzzy, gcc-internal-format
-#| msgid "flexible array member in otherwise empty struct"
+#: cp/class.c:6629
+#, gcc-internal-format
 msgid "zero-size array member %qD in an otherwise empty %q#T"
-msgstr "регулируемый элемент-массив в структуре, которая иначе была бы пустой"
+msgstr "элемент массива нулевого размера %qD в другом пустом %q#T"
 
-#: cp/class.c:6620 cp/class.c:6650
-#, fuzzy, gcc-internal-format
-#| msgid "redefinition of %q#T"
+#: cp/class.c:6637 cp/class.c:6667
+#, gcc-internal-format
 msgid "in the definition of %q#T"
-msgstr "повторное определение %q#T"
+msgstr "в определении %q#T"
 
-#: cp/class.c:6628
-#, fuzzy, gcc-internal-format
-#| msgid "flexible array member not at end of struct"
+#: cp/class.c:6645
+#, gcc-internal-format
 msgid "flexible array member %qD not at end of %q#T"
-msgstr "регулируемый элемент-массив - не последний элемент структуры"
+msgstr "элемент регулируемого массива %qD не в конце %q#T"
 
-#: cp/class.c:6630
-#, fuzzy, gcc-internal-format
-#| msgid "flexible array member in otherwise empty struct"
+#: cp/class.c:6647
+#, gcc-internal-format
 msgid "flexible array member %qD in an otherwise empty %q#T"
-msgstr "регулируемый элемент-массив в структуре, которая иначе была бы пустой"
+msgstr "элемент регулируемого массива %qD в другом пустом %q#T"
 
-#: cp/class.c:6648
-#, fuzzy, gcc-internal-format
-#| msgid "  %q+#D declared here"
+#: cp/class.c:6665
+#, gcc-internal-format
 msgid "next member %q#D declared here"
-msgstr "  %q+#D декларировано здесь"
+msgstr "следующий элемент %q#D объявлен здесь"
 
-#: cp/class.c:6760 cp/parser.c:23239
+#: cp/class.c:6777 cp/parser.c:23236
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "повторное определение %q#T"
 
-#: cp/class.c:6897
+#: cp/class.c:6914
 #, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
-msgstr "%q#T содержит виртуальные функции, но невиртуальный деструктор"
+msgstr "%q#T содержит виртуальные функции и доступный невиртуальный деструктор"
 
-#: cp/class.c:6925
-#, fuzzy, gcc-internal-format
-#| msgid "type transparent class %qT does not have any fields"
+#: cp/class.c:6942
+#, gcc-internal-format
 msgid "type transparent %q#T does not have any fields"
-msgstr "в типе прозрачного класса %qT нет никаких полей"
+msgstr "тип transparent %q#T не имеет полей"
 
-#: cp/class.c:6931
+#: cp/class.c:6948
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr "type transparent класс %qT имеет базовые классы"
 
-#: cp/class.c:6935
+#: cp/class.c:6952
 #, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr "в типе прозрачного класса %qT есть виртуальные функции"
 
-#: cp/class.c:6941
+#: cp/class.c:6958
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
-msgstr ""
+msgstr "type transparent %q#T не может быть сделан прозрачным, так как тип первого поля имеет ABI, отличный от класса в целом"
 
-#: cp/class.c:7071
-#, fuzzy, gcc-internal-format
-#| msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
+#: cp/class.c:7088
+#, gcc-internal-format
 msgid "definition of %qD does not match %<#include <initializer_list>%>"
-msgstr "вывод из взятого в скобки списка инизиализатора требует #include <initializer_list>"
+msgstr "определение %qD не соответствует %<#include <initializer_list>%>"
 
-#: cp/class.c:7082
+#: cp/class.c:7099
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr "не удалось завершить структуру из-за предыдущих грамматических ошибок"
 
-#: cp/class.c:7582
+#: cp/class.c:7599
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "некорректная строка %<\"%E\"%>, задающая язык"
 
-#: cp/class.c:7672
+#: cp/class.c:7689
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr "ошибка при выборе перегруженной функции %qD при преобразовании к типу %qT"
 
-#: cp/class.c:7817
+#: cp/class.c:7834
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr "нет способа для преобразования функции %qD к типу %q#T"
 
-#: cp/class.c:7844
+#: cp/class.c:7861
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "преобразование перегруженной функции %qD к типу %q#T неоднозначно"
 
-#: cp/class.c:7870
+#: cp/class.c:7887
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "предполагается указатель на элемент %qD"
 
-#: cp/class.c:7873
+#: cp/class.c:7890
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(указатель на элемент можно получить только при помощи %<&%E%>)"
 
-#: cp/class.c:7948 cp/class.c:7990
+#: cp/class.c:7965 cp/class.c:8007
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "недостаточная информация о типе"
 
-#: cp/class.c:7968
+#: cp/class.c:7985
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "ошибка преобразования %qE из типа %qT в тип %qT"
@@ -44697,46 +39359,40 @@
 #. A name N used in a class S shall refer to the same declaration
 #. in its context and when re-evaluated in the completed scope of
 #. S.
-#: cp/class.c:8235
+#: cp/class.c:8252
 #, gcc-internal-format
 msgid "declaration of %q#D"
 msgstr "декларация %q#D"
 
-#: cp/class.c:8237
-#, fuzzy, gcc-internal-format
-#| msgid "changes meaning of %qD from %q+#D"
+#: cp/class.c:8254
+#, gcc-internal-format
 msgid "changes meaning of %qD from %q#D"
-msgstr "делает трактовку %qD отличной от %q+#D"
+msgstr "изменяет смысл %qD из %q#D"
 
 #: cp/constexpr.c:98
-#, fuzzy, gcc-internal-format
-#| msgid "the type %qT of constexpr variable %qD is not literal"
+#, gcc-internal-format
 msgid "the type %qT of %<constexpr%> variable %qD is not literal"
-msgstr "тип %qT constexpr переменной %qD не литерал"
+msgstr ""
 
 #: cp/constexpr.c:107
-#, fuzzy, gcc-internal-format
-#| msgid "temporary of non-literal type %qT in a constant expression"
+#, gcc-internal-format
 msgid "variable %qD of non-literal type %qT in %<constexpr%> function"
-msgstr "временная нелитерального типа %qT в константном выражении"
+msgstr "переменная %qD нелитерального типа %qT в %<constexpr%> функции"
 
 #: cp/constexpr.c:118
-#, fuzzy, gcc-internal-format
-#| msgid "parameter may not have variably modified type %qT"
+#, gcc-internal-format
 msgid "%<constexpr%> variable %qD has variably-modified type %qT"
-msgstr "параметр не может иметь модифицированный тип `%T"
+msgstr ""
 
 #: cp/constexpr.c:189
-#, fuzzy, gcc-internal-format
-#| msgid "defaulted constructor calls non-constexpr %q+D"
+#, gcc-internal-format
 msgid "inherited constructor %qD is not %<constexpr%>"
-msgstr "подразумеваемый конструктор вызывает non-constexpr %q+D"
+msgstr ""
 
 #: cp/constexpr.c:201
-#, fuzzy, gcc-internal-format
-#| msgid "invalid type for parameter %d of constexpr function %q+#D"
+#, gcc-internal-format
 msgid "invalid type for parameter %d of %<constexpr%> function %q+#D"
-msgstr "некорректный тип для параметра %d constexpr функции %q+#D"
+msgstr ""
 
 #: cp/constexpr.c:213
 #, gcc-internal-format
@@ -44744,10 +39400,9 @@
 msgstr ""
 
 #: cp/constexpr.c:223
-#, fuzzy, gcc-internal-format
-#| msgid "invalid return type %qT of constexpr function %q+D"
+#, gcc-internal-format
 msgid "invalid return type %qT of %<constexpr%> function %q+D"
-msgstr "некорректный тип результата %qT constexpr функции %q+D"
+msgstr ""
 
 #: cp/constexpr.c:246
 #, gcc-internal-format
@@ -44755,15 +39410,14 @@
 msgstr "%q#T имеет виртуальные базовые классы"
 
 #: cp/constexpr.c:507
-#, fuzzy, gcc-internal-format
-#| msgid "constexpr constructor does not have empty body"
+#, gcc-internal-format
 msgid "%<constexpr%> constructor does not have empty body"
-msgstr "constexpr конструктор не имеет пустое тело"
+msgstr ""
 
 #: cp/constexpr.c:613
 #, gcc-internal-format
 msgid "body of %<constexpr%> constructor cannot be a function-try-block"
-msgstr ""
+msgstr "тело %<constexpr%> конструктора не может быть function-try-block"
 
 #: cp/constexpr.c:766
 #, gcc-internal-format
@@ -44771,28 +39425,24 @@
 msgstr "%<constexpr%> конструктор для объединения %qT должен инициализировать в точности один нестатический элемент данных"
 
 #: cp/constexpr.c:818
-#, fuzzy, gcc-internal-format
-#| msgid "uninitialized member %qD in %<constexpr%> constructor"
+#, gcc-internal-format
 msgid "member %qD must be initialized by mem-initializer in %<constexpr%> constructor"
-msgstr "неинициализированный элемент %qD в %<constexpr%> конструкторе"
+msgstr "элемент %qD должен инициализироваться посредством mem-initializer в %<constexpr%> конструкторе"
 
 #: cp/constexpr.c:859
-#, fuzzy, gcc-internal-format
-#| msgid "body of constexpr function %qD not a return-statement"
+#, gcc-internal-format
 msgid "body of %<constexpr%> function %qD not a return-statement"
-msgstr "тело constexpr функции %qD не return-statement"
+msgstr ""
 
 #: cp/constexpr.c:920
-#, fuzzy, gcc-internal-format
-#| msgid "%q+D is not usable as a constexpr function because:"
+#, gcc-internal-format
 msgid "%qD is not usable as a %<constexpr%> function because:"
-msgstr "%q+D не может использоваться как constexpr функция поскольку:"
+msgstr ""
 
 #: cp/constexpr.c:1220 cp/constexpr.c:1728
-#, fuzzy, gcc-internal-format
-#| msgid "%<constexpr%> cannot be used for type declarations"
+#, gcc-internal-format
 msgid "%<constexpr%> call flows off the end of the function"
-msgstr "%<constexpr%> не может использоваться для деклараций типов"
+msgstr ""
 
 #: cp/constexpr.c:1225 cp/constexpr.c:1235 cp/constexpr.c:1840
 #, gcc-internal-format
@@ -44800,28 +39450,24 @@
 msgstr "%q+E не есть константное выражение"
 
 #: cp/constexpr.c:1414 cp/constexpr.c:5368
-#, fuzzy, gcc-internal-format
-#| msgid "internal function"
+#, gcc-internal-format
 msgid "call to internal function %qE"
-msgstr "внутренняя функция"
+msgstr "вызов внутренней функции %qE"
 
 #: cp/constexpr.c:1492
-#, fuzzy, gcc-internal-format
-#| msgid "expression %qE does not designate a constexpr function"
+#, gcc-internal-format
 msgid "expression %qE does not designate a %<constexpr%> function"
-msgstr "выражение %qE не обозначает constexpr функцию"
+msgstr ""
 
 #: cp/constexpr.c:1511 cp/constexpr.c:5386
-#, fuzzy, gcc-internal-format
-#| msgid "call to non-constexpr function %qD"
+#, gcc-internal-format
 msgid "call to non-%<constexpr%> function %qD"
-msgstr "вызов non-constexpr функции %qD"
+msgstr ""
 
 #: cp/constexpr.c:1583
-#, fuzzy, gcc-internal-format
-#| msgid "%qD called in a constant expression"
+#, gcc-internal-format
 msgid "%qD called in a constant expression before its definition is complete"
-msgstr "%qD вызвана в константном выражении"
+msgstr "%qD вызвана в константном выражении до завершения ее определения"
 
 #: cp/constexpr.c:1590
 #, gcc-internal-format
@@ -44839,74 +39485,64 @@
 msgstr "вызов имеет циклическую зависимость"
 
 #: cp/constexpr.c:1645
-#, fuzzy, gcc-internal-format
-#| msgid "constexpr evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
+#, gcc-internal-format
 msgid "%<constexpr%> evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
-msgstr "глубина обработки constexpr превышает максимум %d (задайте -fconstexpr-depth= чтобы увеличить максимум)"
+msgstr ""
 
 #: cp/constexpr.c:1880
-#, fuzzy, gcc-internal-format
-#| msgid "right shift count is negative"
+#, gcc-internal-format
 msgid "right operand of shift expression %q+E is negative"
-msgstr "сдвиг вправо на отрицательное число позиций"
+msgstr "правый операнд выражения сдвига %q+E отрицателен"
 
 #: cp/constexpr.c:1887
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is >= than the precision of the left operand"
-msgstr ""
+msgstr "правый операнд выражения сдвига %q+E >= точности левого операнда"
 
 #: cp/constexpr.c:1905
-#, fuzzy, gcc-internal-format
-#| msgid "left-hand operand of comma expression has no effect"
+#, gcc-internal-format
 msgid "left operand of shift expression %q+E is negative"
-msgstr "левый операнд операции `запятая' не имеет побочных эффектов"
+msgstr "левый операнд выражения сдвига %q+E отрицателен"
 
 #: cp/constexpr.c:1924
-#, fuzzy, gcc-internal-format
-#| msgid "integral expression %qE is not constant"
+#, gcc-internal-format
 msgid "shift expression %q+E overflows"
-msgstr "целочисленное выражение %qE не является константой"
+msgstr "переполнение выражения сдвига %q+E"
 
 #: cp/constexpr.c:2068
 #, gcc-internal-format
 msgid "arithmetic involving a null pointer in %qE"
-msgstr ""
+msgstr "вычисления включающие пустой указатель в %qE"
 
 #: cp/constexpr.c:2304
-#, fuzzy, gcc-internal-format
-#| msgid "array subscript is outside array bounds"
+#, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
-msgstr "индекс массива вне диапазона границ массива"
+msgstr "значение индекса массива %qE вне границ массива %qD типа %qT"
 
 #: cp/constexpr.c:2307
-#, fuzzy, gcc-internal-format
-#| msgid "array subscript is outside array bounds"
+#, gcc-internal-format
 msgid "non-zero array subscript %qE is used with array %qD of type %qT with unknown bounds"
-msgstr "индекс массива вне диапазона границ массива"
+msgstr ""
 
 #: cp/constexpr.c:2312
-#, fuzzy, gcc-internal-format
-#| msgid "array subscript is outside array bounds"
+#, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array type %qT"
-msgstr "индекс массива вне диапазона границ массива"
+msgstr "значение индекс массива %qE вне границ типа массива %qT"
 
 #: cp/constexpr.c:2315
-#, fuzzy, gcc-internal-format
-#| msgid "array subscript is outside array bounds"
+#, gcc-internal-format
 msgid "non-zero array subscript %qE is used with array of type %qT with unknown bounds"
-msgstr "индекс массива вне диапазона границ массива"
+msgstr ""
 
 #: cp/constexpr.c:2480
-#, fuzzy, gcc-internal-format
-#| msgid "missing initializer for member %qD"
+#, gcc-internal-format
 msgid "accessing uninitialized array element"
-msgstr "отсутствует инициализатор для элемента %qD"
+msgstr "доступ к неинициализированному элементу массива"
 
 #: cp/constexpr.c:2511
-#, fuzzy, gcc-internal-format
-#| msgid "dereferencing %<void *%> pointer"
+#, gcc-internal-format
 msgid "dereferencing a null pointer in %qE"
-msgstr "доступ по указателю %<void *%>"
+msgstr "доступ по пустому указателю в %qE"
 
 #: cp/constexpr.c:2525 cp/constexpr.c:2615 cp/constexpr.c:4131
 #: cp/constexpr.c:4204 cp/constexpr.c:5322
@@ -44925,16 +39561,14 @@
 msgstr "обращение к элементу %qD вместо инициализированного элемента %qD в константном выражении"
 
 #: cp/constexpr.c:2575
-#, fuzzy, gcc-internal-format
-#| msgid "missing initializer for member %qD"
+#, gcc-internal-format
 msgid "accessing uninitialized member %qD"
-msgstr "отсутствует инициализатор для элемента %qD"
+msgstr "доступ к неинициализированному элементу %qD"
 
 #: cp/constexpr.c:3312 cp/constexpr.c:4624
-#, fuzzy, gcc-internal-format
-#| msgid "dereferencing %<void *%> pointer"
+#, gcc-internal-format
 msgid "dereferencing a null pointer"
-msgstr "доступ по указателю %<void *%>"
+msgstr "доступ по пустому указателю"
 
 #: cp/constexpr.c:3331
 #, gcc-internal-format
@@ -44977,22 +39611,19 @@
 msgstr "%qD не имеет целый или перечислимый тип"
 
 #: cp/constexpr.c:3594
-#, fuzzy, gcc-internal-format
-#| msgid "division by zero is not a constant-expression"
+#, gcc-internal-format
 msgid "modification of %qE is not a constant expression"
-msgstr "деление на ноль не есть константное выражение"
+msgstr "модификация %qE не есть константное выражение"
 
 #: cp/constexpr.c:3970
-#, fuzzy, gcc-internal-format
-#| msgid "constexpr evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
+#, gcc-internal-format
 msgid "%<constexpr%> loop iteration count exceeds limit of %d (use -fconstexpr-loop-limit= to increase the limit)"
-msgstr "глубина обработки constexpr превышает максимум %d (задайте -fconstexpr-depth= чтобы увеличить максимум)"
+msgstr ""
 
 #: cp/constexpr.c:4109
-#, fuzzy, gcc-internal-format
-#| msgid "%qE is not a constant expression"
+#, gcc-internal-format
 msgid "value %qE of type %qT is not a constant expression"
-msgstr "%qE не есть константное выражение"
+msgstr "значение %qE типа %qT не есть константное выражение"
 
 #: cp/constexpr.c:4250 cp/constexpr.c:5864
 #, gcc-internal-format
@@ -45000,34 +39631,29 @@
 msgstr "временная нелитерального типа %qT в константном выражении"
 
 #: cp/constexpr.c:4587
-#, fuzzy, gcc-internal-format
-#| msgid "expression %qE is not a constant-expression"
+#, gcc-internal-format
 msgid "a reinterpret_cast is not a constant expression"
-msgstr "выражение %qE не является константным выражением"
+msgstr "reinterpret_cast не является константным выражением"
 
 #: cp/constexpr.c:4636
-#, fuzzy, gcc-internal-format
-#| msgid "temporary of non-literal type %qT in a constant expression"
+#, gcc-internal-format
 msgid "conversion of %qT null pointer to %qT is not a constant expression"
-msgstr "временная нелитерального типа %qT в константном выражении"
+msgstr "преобразование %qT пустого указателя в %qT не является константным выражением"
 
 #: cp/constexpr.c:4651
-#, fuzzy, gcc-internal-format
-#| msgid "expression %qE is not a constant-expression"
+#, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
-msgstr "выражение %qE не является константным выражением"
+msgstr "%<reinterpret_cast<%T>(%E)%> не является константным выражением"
 
 #: cp/constexpr.c:4716 cp/constexpr.c:5709 cp/constexpr.c:6035
-#, fuzzy, gcc-internal-format
-#| msgid "expression %qE is not a constant-expression"
+#, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "выражение %qE не является константным выражением"
 
 #: cp/constexpr.c:4798
-#, fuzzy, gcc-internal-format
-#| msgid "initializer element is not a constant expression"
+#, gcc-internal-format
 msgid "statement is not a constant expression"
-msgstr "элемент инициализатора не является константным выражением"
+msgstr "оператор не является константным выражением"
 
 #: cp/constexpr.c:4801
 #, gcc-internal-format
@@ -45035,22 +39661,19 @@
 msgstr "неожиданное выражение %qE вида %s"
 
 #: cp/constexpr.c:4873
-#, fuzzy, gcc-internal-format
-#| msgid "%qT cannot be the type of a complete constant expression because it has mutable sub-objects"
+#, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
-msgstr "%qT не может быть типом полного константного выражения поскольку он имеет mutable sub-objects"
+msgstr "%qE не есть константное выражение, поскольку оно ссылается на mutable подобъекты %qT"
 
 #: cp/constexpr.c:4882
-#, fuzzy, gcc-internal-format
-#| msgid "%qT cannot be the type of a complete constant expression because it has mutable sub-objects"
+#, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
-msgstr "%qT не может быть типом полного константного выражения поскольку он имеет mutable sub-objects"
+msgstr "%qE не есть константное выражение, поскольку оно ссылается на не полностью инициализированную переменную"
 
 #: cp/constexpr.c:4896
-#, fuzzy, gcc-internal-format
-#| msgid "conversion from pointer type %qT to arithmetic type %qT in a constant-expression"
+#, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
-msgstr "преобразование из указательного типа %qT в арифметический тип %qT в constant-expression"
+msgstr "преобразование из указательного типа %qT в арифметический тип %qT в константном выражении"
 
 #: cp/constexpr.c:5277
 #, gcc-internal-format
@@ -45058,10 +39681,9 @@
 msgstr "выражение %qE имеет побочные эффекты"
 
 #: cp/constexpr.c:5469
-#, fuzzy, gcc-internal-format
-#| msgid "division by zero is not a constant-expression"
+#, gcc-internal-format
 msgid "lambda capture of %qE is not a constant expression"
-msgstr "деление на ноль не есть константное выражение"
+msgstr ""
 
 #: cp/constexpr.c:5472
 #, gcc-internal-format
@@ -45069,10 +39691,9 @@
 msgstr ""
 
 #: cp/constexpr.c:5507
-#, fuzzy, gcc-internal-format
-#| msgid "reinterpret_cast from type %qT to type %qT casts away qualifiers"
+#, gcc-internal-format
 msgid "reinterpret_cast from integer to pointer"
-msgstr "reinterpret_cast от типа %qT к типу %qT отбрасывает квалификаторы"
+msgstr "reinterpret_cast из целого в указатель"
 
 #: cp/constexpr.c:5539
 #, gcc-internal-format
@@ -45080,51 +39701,44 @@
 msgstr "address-of объекта %qE с поточно-локальным или автоматическим хранением не есть константное выражение"
 
 #: cp/constexpr.c:5572
-#, fuzzy, gcc-internal-format
-#| msgid "%qE is not a constant expression"
+#, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
-msgstr "%qE не есть константное выражение"
+msgstr "использование %<this%> в константном выражении"
 
 #: cp/constexpr.c:5657
-#, fuzzy, gcc-internal-format
-#| msgid "expression %qE is not a constant-expression"
+#, gcc-internal-format
 msgid "lambda-expression is not a constant expression before C++17"
-msgstr "выражение %qE не является константным выражением"
+msgstr ""
 
 #: cp/constexpr.c:5721
 #, gcc-internal-format
 msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
-msgstr "typeid-expression не есть константное выражение поскольку %qE полиморфного типа"
+msgstr "typeid-expression не есть константное выражение, поскольку %qE полиморфного типа"
 
 #: cp/constexpr.c:5783
-#, fuzzy, gcc-internal-format
-#| msgid "temporary of non-literal type %qT in a constant expression"
+#, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
-msgstr "временная нелитерального типа %qT в константном выражении"
+msgstr "приведение к нецелочисленному типу %qT в константном выражении"
 
 #: cp/constexpr.c:5834
-#, fuzzy, gcc-internal-format
-#| msgid "%q+F declared %<static%> but never defined"
+#, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> context"
-msgstr "%q+F объявлена %<static%>, но нигде не определена"
+msgstr ""
 
 #: cp/constexpr.c:5841
-#, fuzzy, gcc-internal-format
-#| msgid "%qE undeclared here (not in a function)"
+#, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> context"
-msgstr "%qE не описан здесь (не в функции)"
+msgstr ""
 
 #: cp/constexpr.c:5913
-#, fuzzy, gcc-internal-format
-#| msgid "division by zero is not a constant-expression"
+#, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "деление на ноль не есть константное выражение"
 
 #: cp/constexpr.c:6012
-#, fuzzy, gcc-internal-format
-#| msgid "%qE is not a constant expression"
+#, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
-msgstr "%qE не есть константное выражение"
+msgstr "%<delete[]%> не есть константное выражение"
 
 #: cp/constexpr.c:6043
 #, gcc-internal-format
@@ -45132,10 +39746,9 @@
 msgstr "неконстантная инициализация массива"
 
 #: cp/constexpr.c:6065
-#, fuzzy, gcc-internal-format
-#| msgid "%qE is not a constant expression"
+#, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
-msgstr "%qE не есть константное выражение"
+msgstr "%<goto%> не есть константное выражение"
 
 #: cp/constexpr.c:6076
 #, gcc-internal-format, gfc-internal-format
@@ -45142,38 +39755,32 @@
 msgid "unexpected AST of kind %s"
 msgstr "неожиданное AST вида %s"
 
-#: cp/cp-gimplify.c:1415
+#: cp/cp-gimplify.c:1416
 #, gcc-internal-format
 msgid "throw will always call terminate()"
-msgstr ""
+msgstr "throw будет всегда вызывать terminate()"
 
-#: cp/cp-gimplify.c:1418
+#: cp/cp-gimplify.c:1419
 #, gcc-internal-format
 msgid "in C++11 destructors default to noexcept"
-msgstr ""
+msgstr "в C++11 деструкторы подразумевают noexcept"
 
-#: cp/cp-gimplify.c:1429
+#: cp/cp-gimplify.c:1430
 #, gcc-internal-format
 msgid "in C++11 this throw will terminate because destructors default to noexcept"
-msgstr ""
+msgstr "в C++11 это throw терминируется, поскольку деструкторы подразумевают noexcept"
 
 #: cp/cvt.c:91
-#, fuzzy
-#| msgid "can%'t convert from incomplete type %qT to %qT"
 msgid "can%'t convert from incomplete type %qH to %qI"
-msgstr "невозможно преобразовать неполный тип %qT в %qT"
+msgstr ""
 
 #: cp/cvt.c:101
-#, fuzzy
-#| msgid "conversion of %qE from %qT to %qT is ambiguous"
 msgid "conversion of %qE from %qH to %qI is ambiguous"
-msgstr "преобразование %qE из %qT в %qT неоднозначно"
+msgstr ""
 
 #: cp/cvt.c:173 cp/cvt.c:200 cp/cvt.c:254
-#, fuzzy
-#| msgid "cannot convert %qE from type %qT to type %qT"
 msgid "cannot convert %qE from type %qH to type %qI"
-msgstr "ошибка преобразования %qE из типа %qT в тип %qT"
+msgstr ""
 
 #: cp/cvt.c:389
 #, gcc-internal-format
@@ -45196,10 +39803,8 @@
 msgstr "преобразование к неконстантной ссылки типа %qT из rvalue типа %qT"
 
 #: cp/cvt.c:474
-#, fuzzy
-#| msgid "conversion from %qT to %qT discards qualifiers"
 msgid "conversion from %qH to %qI discards qualifiers"
-msgstr "преобразование из %qT в %qT отменяет квалификаторы"
+msgstr ""
 
 #: cp/cvt.c:496 cp/typeck.c:7356
 #, gcc-internal-format
@@ -45207,10 +39812,8 @@
 msgstr "преобразование %qT в %qT не снимает указатель"
 
 #: cp/cvt.c:524
-#, fuzzy
-#| msgid "cannot convert type %qT to type %qT"
 msgid "cannot convert type %qH to type %qI"
-msgstr "некорректное преобразование от типа %qT к типу %qT"
+msgstr ""
 
 #: cp/cvt.c:769
 #, gcc-internal-format
@@ -45228,10 +39831,9 @@
 msgstr "%q#T использовано там, где ожидалось %qT"
 
 #: cp/cvt.c:806
-#, fuzzy, gcc-internal-format
-#| msgid "could not convert %qE from %qT to %qT"
+#, gcc-internal-format
 msgid "could not convert %qE from %<void%> to %<bool%>"
-msgstr "ошибка преобразования %qE из %qT в %qT"
+msgstr "невозможно преобразовать %qE из %<void%> в %<bool%>"
 
 #: cp/cvt.c:865
 #, gcc-internal-format
@@ -45239,28 +39841,23 @@
 msgstr "%q#T использовано там, где ожидалось плавающее значение"
 
 #: cp/cvt.c:924
-#, fuzzy
-#| msgid "conversion from %qT to non-scalar type %qT requested"
 msgid "conversion from %qH to non-scalar type %qI requested"
-msgstr "запрошено преобразование от %qT к нескалярному типу %qT"
+msgstr ""
 
 #: cp/cvt.c:1013
-#, fuzzy, gcc-internal-format
-#| msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
+#, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute nodiscard"
-msgstr "результат %qD, декларированной с атрибутом warn_unused_result, игнорируется"
+msgstr "игнорирование возвращаемого значения от %qD, декларированной с атрибутом nodiscard"
 
 #: cp/cvt.c:1021
-#, fuzzy, gcc-internal-format
-#| msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
+#, gcc-internal-format
 msgid "ignoring returned value of type %qT, declared with attribute nodiscard"
-msgstr "результат %qD, декларированной с атрибутом warn_unused_result, игнорируется"
+msgstr "игнорирование возвращаемого значения типа %qT, декларированного с атрибутом nodiscard"
 
 #: cp/cvt.c:1026
-#, fuzzy, gcc-internal-format
-#| msgid "%qD declared here"
+#, gcc-internal-format
 msgid "in call to %qD, declared here"
-msgstr "%qD объявлено здесь"
+msgstr "в вызове %qD, декларированной здесь"
 
 #: cp/cvt.c:1093
 #, gcc-internal-format
@@ -45508,10 +40105,9 @@
 msgstr "преобразование NULL к неуказательному типу"
 
 #: cp/cvt.c:1791
-#, fuzzy, gcc-internal-format
-#| msgid "  couldn't deduce template parameter %qD"
+#, gcc-internal-format
 msgid "default type conversion can't deduce template argument for %qD"
-msgstr "  невозможно вывести параметр шаблона %qD"
+msgstr "преобразование подразумеваемого типа не может вывести аргумент шаблона для %qD"
 
 #: cp/cvt.c:1806
 #, gcc-internal-format
@@ -45529,16 +40125,14 @@
 msgstr "параметр-шаблона-"
 
 #: cp/decl.c:678
-#, fuzzy, gcc-internal-format
-#| msgid "invalid function declaration"
+#, gcc-internal-format
 msgid "unused structured binding declaration"
-msgstr "некорректная декларация функции"
+msgstr ""
 
 #: cp/decl.c:681
-#, fuzzy, gcc-internal-format
-#| msgid "unused variable %q+D"
+#, gcc-internal-format
 msgid "unused variable %qD"
-msgstr "неиспользуемая переменная %q+D"
+msgstr "неиспользуемая переменная %qD"
 
 #: cp/decl.c:690
 #, gcc-internal-format
@@ -45546,16 +40140,14 @@
 msgstr ""
 
 #: cp/decl.c:909
-#, fuzzy, gcc-internal-format
-#| msgid "%q+F declared %<static%> but never defined"
+#, gcc-internal-format
 msgid "%qF declared %<static%> but never defined"
-msgstr "%q+F объявлена %<static%>, но нигде не определена"
+msgstr "%qF декларирована %<static%>, но нигде не определена"
 
 #: cp/decl.c:916
-#, fuzzy, gcc-internal-format
-#| msgid "environment variable %qs not defined"
+#, gcc-internal-format
 msgid "odr-used inline variable %qD is not defined"
-msgstr "переменная окружения %qs не определена"
+msgstr "odr-used inline переменная %qD не определена"
 
 #: cp/decl.c:1214
 #, gcc-internal-format
@@ -45568,34 +40160,29 @@
 msgstr "декларация %qF имеет другой спецификатор исключений"
 
 #: cp/decl.c:1266
-#, fuzzy, gcc-internal-format
-#| msgid "from previous declaration %q+F"
+#, gcc-internal-format
 msgid "from previous declaration %qF"
-msgstr "предыдущая декларация %q+F"
+msgstr "из предыдущей декларации %qF"
 
 #: cp/decl.c:1301
-#, fuzzy, gcc-internal-format
-#| msgid "redeclaration %qD differs in %<constexpr%>"
+#, gcc-internal-format
 msgid "redeclaration %qD differs in %<constexpr%> from previous declaration"
-msgstr "редекларация %qD отличается в %<constexpr%>"
+msgstr "редекларация %qD отличается в %<constexpr%> от предыдущей декларации"
 
-#: cp/decl.c:1304 cp/decl.c:13843
-#, fuzzy, gcc-internal-format
-#| msgid "previous declaration %q+#D"
+#: cp/decl.c:1304 cp/decl.c:13867
+#, gcc-internal-format
 msgid "previous declaration %qD"
-msgstr "предыдущая декларация %q+#D"
+msgstr "предыдущая декларация %qD"
 
 #: cp/decl.c:1333
-#, fuzzy, gcc-internal-format
-#| msgid "uninitialized const %qD"
+#, gcc-internal-format
 msgid "cannot specialize concept %q#D"
-msgstr "неинициализированная константа %qD"
+msgstr "невозможно специализировать concept %q#D"
 
 #: cp/decl.c:1355
-#, fuzzy, gcc-internal-format
-#| msgid "redeclaration of friend %q#D may not have default template arguments"
+#, gcc-internal-format
 msgid "redeclaration of %q#D may not have default arguments"
-msgstr "редекларация friend %q#D не может иметь подразумеваемые аргументы шаблона"
+msgstr "редекларация %q#D не может иметь подразумеваемые аргументы"
 
 #: cp/decl.c:1424
 #, gcc-internal-format
@@ -45608,22 +40195,19 @@
 msgstr "сырой литеральный оператор %q+D противоречит шаблону литерального оператора %qD"
 
 #: cp/decl.c:1449
-#, fuzzy, gcc-internal-format
-#| msgid "previous definition of %q+D was here"
+#, gcc-internal-format
 msgid "previous definition of %qD was here"
-msgstr "здесь было предыдущее определение %q+D"
+msgstr "предыдущее определение %qD было здесь"
 
 #: cp/decl.c:1452
-#, fuzzy, gcc-internal-format
-#| msgid "previous declaration of %q+D was here"
+#, gcc-internal-format
 msgid "previous declaration of %qD was here"
-msgstr "здесь была предыдущая декларация %q+D"
+msgstr "предыдущая декларация %qD была здесь"
 
 #: cp/decl.c:1470
-#, fuzzy, gcc-internal-format
-#| msgid "built-in function %q+D declared as non-function"
+#, gcc-internal-format
 msgid "built-in function %qD declared as non-function"
-msgstr "внутренняя функция %q+D декларирована как не функция"
+msgstr ""
 
 #: cp/decl.c:1482 cp/decl.c:1616
 #, gcc-internal-format
@@ -45641,46 +40225,39 @@
 msgstr "библиотечная функция %q#D декларирована повторно как не функция %q#D"
 
 #: cp/decl.c:1494
-#, fuzzy, gcc-internal-format
-#| msgid "conflicts with built-in declaration %q#D"
+#, gcc-internal-format
 msgid "declaration of %q+#D conflicts with built-in declaration %q#D"
-msgstr "противоречит встроенной декларации %q#D"
+msgstr "декларация %q+#D конфликтует с внутренней декларацией %q#D"
 
 #: cp/decl.c:1502
-#, fuzzy, gcc-internal-format
-#| msgid "declaration of %qD shadows a global declaration"
+#, gcc-internal-format
 msgid "redeclaration of %<pragma omp declare reduction%>"
-msgstr "декларация %qD перекрывает глобальную декларацию"
+msgstr "редекларация %<pragma omp declare reduction%>"
 
 #: cp/decl.c:1504
-#, fuzzy, gcc-internal-format
-#| msgid "previous non-function declaration %q+#D"
+#, gcc-internal-format
 msgid "previous %<pragma omp declare reduction%> declaration"
-msgstr "предыдущая декларация не-функции %q+#D"
+msgstr "предыдущая декларация %<pragma omp declare reduction%>"
 
 #: cp/decl.c:1564
-#, fuzzy, gcc-internal-format
-#| msgid "conflicts with built-in declaration %q#D"
+#, gcc-internal-format
 msgid "declaration of %q#D conflicts with built-in declaration %q#D"
-msgstr "противоречит встроенной декларации %q#D"
+msgstr ""
 
 #: cp/decl.c:1592
-#, fuzzy, gcc-internal-format
-#| msgid "ambiguates built-in declaration %q#D"
+#, gcc-internal-format
 msgid "definition of %q#D ambiguates built-in declaration %q#D"
-msgstr "делает неоднозначной встроенную декларацию %#D"
+msgstr ""
 
 #: cp/decl.c:1597 cp/decl.c:1611
-#, fuzzy, gcc-internal-format
-#| msgid "ambiguates built-in declaration %q#D"
+#, gcc-internal-format
 msgid "new declaration %q#D ambiguates built-in declaration %q#D"
-msgstr "делает неоднозначной встроенную декларацию %#D"
+msgstr "новая декларация %q#D делает неоднозначной встроенную декларацию %#D"
 
 #: cp/decl.c:1601
-#, fuzzy, gcc-internal-format
-#| msgid "derived type declaration"
+#, gcc-internal-format
 msgid "ignoring the %q#D declaration"
-msgstr "декларация производного типа"
+msgstr ""
 
 #: cp/decl.c:1702
 #, gcc-internal-format
@@ -45688,82 +40265,69 @@
 msgstr "%q#D редекларирован как другой вид символа"
 
 #: cp/decl.c:1725
-#, fuzzy, gcc-internal-format
-#| msgid "declaration of template %q#D"
+#, gcc-internal-format
 msgid "conflicting declaration of template %q+#D"
-msgstr "декларация шаблона %q#D"
+msgstr "конфликтующая декларация шаблона %q+#D"
 
 #: cp/decl.c:1744
-#, fuzzy, gcc-internal-format
-#| msgid "ambiguates old declaration %q+#D"
+#, gcc-internal-format
 msgid "ambiguating new declaration %q+#D"
-msgstr "делает неоднозначной старую декларацию %q+#D"
+msgstr "делает неоднозначной новую декларацию %q+#D"
 
 #: cp/decl.c:1746 cp/decl.c:1774
-#, fuzzy, gcc-internal-format
-#| msgid "global declaration %q+#D"
+#, gcc-internal-format
 msgid "old declaration %q#D"
-msgstr "глобальная декларация %q+#D"
+msgstr "старая декларация %q#D"
 
 #: cp/decl.c:1756
-#, fuzzy, gcc-internal-format
-#| msgid "conflicting declaration %q#D"
+#, gcc-internal-format
 msgid "conflicting declaration of C function %q+#D"
-msgstr "противоречивая декларация %q#D"
+msgstr "конфликтующая декларация C функции %q+#D"
 
 #: cp/decl.c:1772
-#, fuzzy, gcc-internal-format
-#| msgid "ambiguates old declaration %q+#D"
+#, gcc-internal-format
 msgid "ambiguating new declaration of %q+#D"
-msgstr "делает неоднозначной старую декларацию %q+#D"
+msgstr "делает неоднозначной новую декларацию %q+#D"
 
 #: cp/decl.c:1782
-#, fuzzy, gcc-internal-format
-#| msgid "conflicting declaration %q#D"
+#, gcc-internal-format
 msgid "conflicting declaration %q+#D"
-msgstr "противоречивая декларация %q#D"
+msgstr "конфликтующая декларация %q+#D"
 
 #: cp/decl.c:1784
-#, fuzzy, gcc-internal-format
-#| msgid "previous declaration %q+#D"
+#, gcc-internal-format
 msgid "previous declaration as %q#D"
-msgstr "предыдущая декларация %q+#D"
+msgstr "предыдущая декларация %q#D"
 
 #: cp/decl.c:1842 cp/decl2.c:921
-#, fuzzy, gcc-internal-format
-#| msgid "%q+#D previously defined here"
+#, gcc-internal-format
 msgid "%q#D previously defined here"
-msgstr "%q+#D ранее определено здесь"
+msgstr "%q#D ранее определено здесь"
 
 #: cp/decl.c:1843 cp/name-lookup.c:2694 cp/name-lookup.c:2716
-#, fuzzy, gcc-internal-format
-#| msgid "%q+#D previously declared here"
+#, gcc-internal-format
 msgid "%q#D previously declared here"
-msgstr "%q+#D ранее декларировано здесь"
+msgstr "%q#D ранее декларировано здесь"
 
 #: cp/decl.c:1853
-#, fuzzy, gcc-internal-format
-#| msgid "prototype for %q+#D"
+#, gcc-internal-format
 msgid "prototype specified for %q#D"
-msgstr "прототип для %q+#D"
+msgstr "прототип задан для %q#D"
 
 #: cp/decl.c:1855
-#, fuzzy, gcc-internal-format
-#| msgid "follows non-prototype definition here"
+#, gcc-internal-format
 msgid "previous non-prototype definition here"
-msgstr "следует непрототипное определение здесь"
+msgstr "предыдущее непрототипное определение здесь"
 
 #: cp/decl.c:1893
-#, fuzzy, gcc-internal-format
-#| msgid "previous declaration of %q+#D with %qL linkage"
+#, gcc-internal-format
 msgid "conflicting declaration of %q+#D with %qL linkage"
-msgstr "предыдущая декларация %q+#D с %qL привязкой"
+msgstr "конфликтующая декларация %q+#D с %qL привязкой"
 
 #: cp/decl.c:1896
-#, fuzzy, gcc-internal-format
-#| msgid "previous declaration of %q+#D with %qL linkage"
+#, gcc-internal-format
 msgid "previous declaration with %qL linkage"
-msgstr "предыдущая декларация %q+#D с %qL привязкой"
+msgstr "предыдущая декларация с %qL привязкой"
 
 #: cp/decl.c:1930 cp/decl.c:1938
 #, gcc-internal-format
@@ -45771,10 +40335,9 @@
 msgstr "подразумеваемый аргумент задан для параметра %d %q#D"
 
 #: cp/decl.c:1933 cp/decl.c:1941
-#, fuzzy, gcc-internal-format
-#| msgid "after previous specification in %q+#D"
+#, gcc-internal-format
 msgid "previous specification in %q#D here"
-msgstr "после предыдущей спецификации в %q+#D"
+msgstr "предыдущая спецификации в %q#D здесь"
 
 #: cp/decl.c:2007
 #, gcc-internal-format
@@ -45782,10 +40345,9 @@
 msgstr "избыточная повторная декларация %qD в той же области видимости"
 
 #: cp/decl.c:2018
-#, fuzzy, gcc-internal-format
-#| msgid "deleted definition of %qD"
+#, gcc-internal-format
 msgid "deleted definition of %q+D"
-msgstr "удаленное определение %qD"
+msgstr "удаленное определение %q+D"
 
 #. From [temp.expl.spec]:
 #.
@@ -45801,10 +40363,9 @@
 msgstr "явная специализация %qD после первого использования"
 
 #: cp/decl.c:2589
-#, fuzzy, gcc-internal-format
-#| msgid "'setter' attribute of property %qD conflicts with previous declaration"
+#, gcc-internal-format
 msgid "%qD: visibility attribute ignored because it conflicts with previous declaration"
-msgstr "'setter' атрибут свойства %qD конфликтует с предшествующей декларацией"
+msgstr "%qD: атрибут видимости проигнорирован, так как он конфликтует с предыдущей декларацией"
 
 #. Reject two definitions.
 #: cp/decl.c:2843 cp/decl.c:2872 cp/decl.c:2905 cp/decl.c:2922 cp/decl.c:3017
@@ -45858,21 +40419,19 @@
 msgstr "редекларация %q#D"
 
 #: cp/decl.c:3009
-#, fuzzy, gcc-internal-format
-#| msgid "redundant redeclaration of %qD in same scope"
+#, gcc-internal-format
 msgid "redundant redeclaration of %<constexpr%> static data member %qD"
-msgstr "избыточная повторная декларация %qD в той же области видимости"
+msgstr "избыточное переопределение %<constexpr%> элемента статических данных %qD"
 
 #: cp/decl.c:3074
 #, gcc-internal-format
 msgid "local label %qE conflicts with existing label"
-msgstr ""
+msgstr "локальная метка %qE конфликтует с существующей меткой"
 
 #: cp/decl.c:3075
-#, fuzzy, gcc-internal-format
-#| msgid "previous declaration"
+#, gcc-internal-format
 msgid "previous label"
-msgstr "предыдущая декларация"
+msgstr "предыдущая метка"
 
 #: cp/decl.c:3169
 #, gcc-internal-format
@@ -45885,21 +40444,19 @@
 msgstr "  покидает OpenMP структурный блок"
 
 #: cp/decl.c:3219
-#, fuzzy, gcc-internal-format
-#| msgid "  crosses initialization of %q+#D"
+#, gcc-internal-format
 msgid "  crosses initialization of %q#D"
-msgstr "  пересекает инициализацию %q+#D"
+msgstr "  пересекает инициализацию %q#D"
 
 #: cp/decl.c:3222
-#, fuzzy, gcc-internal-format
-#| msgid "  enters scope of %q+#D which has non-trivial destructor"
+#, gcc-internal-format
 msgid "  enters scope of %q#D, which has non-trivial destructor"
-msgstr "  входит в область действия %q+#D имеющего нетривиальный деструктор"
+msgstr "  входит в контекст %q#D, имеющий нетривиальный деструктор"
 
 #: cp/decl.c:3277
 #, gcc-internal-format, gfc-internal-format
 msgid "  %s"
-msgstr ""
+msgstr "  %s"
 
 #: cp/decl.c:3372 cp/decl.c:3392
 #, gcc-internal-format
@@ -45907,16 +40464,14 @@
 msgstr "  входит в catch-блок"
 
 #: cp/decl.c:3379
-#, fuzzy, gcc-internal-format
-#| msgid "  skips initialization of %q+#D"
+#, gcc-internal-format
 msgid "  skips initialization of %q#D"
-msgstr "  пропускает инициализацию %q+#D"
+msgstr "  пропускает инициализацию %q#D"
 
 #: cp/decl.c:3382
-#, fuzzy, gcc-internal-format
-#| msgid "  enters scope of %q+#D which has non-trivial destructor"
+#, gcc-internal-format
 msgid "  enters scope of %q#D which has non-trivial destructor"
-msgstr "  входит в область действия %q+#D имеющего нетривиальный деструктор"
+msgstr "  входит в контекст %q#D, имеющий нетривиальный деструктор"
 
 #: cp/decl.c:3390
 #, gcc-internal-format
@@ -45926,12 +40481,12 @@
 #: cp/decl.c:3394
 #, gcc-internal-format
 msgid "  enters synchronized or atomic statement"
-msgstr ""
+msgstr "  входит в синхронизируемый или атомарный оператор"
 
 #: cp/decl.c:3396
 #, gcc-internal-format
 msgid "  enters %<constexpr%> if statement"
-msgstr ""
+msgstr "  входит в %<constexpr%> оператор if"
 
 #: cp/decl.c:3402
 #, gcc-internal-format
@@ -45938,7 +40493,7 @@
 msgid "  enters OpenMP structured block"
 msgstr "  входит в OpenMP структурный блок"
 
-#: cp/decl.c:3434 cp/parser.c:12366 cp/parser.c:12387
+#: cp/decl.c:3434 cp/parser.c:12363 cp/parser.c:12384
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr "некорректный выход из OpenMP структурного блока"
@@ -45948,7 +40503,7 @@
 msgid "%qD is not a type"
 msgstr "%qD не является типом"
 
-#: cp/decl.c:3838 cp/parser.c:6366
+#: cp/decl.c:3838 cp/parser.c:6369
 #, gcc-internal-format
 msgid "%qD used without template parameters"
 msgstr "использование %qD без параметров шаблона"
@@ -45984,28 +40539,24 @@
 msgstr "%<typename %T::%D%> именует %q#T, который не является типом"
 
 #: cp/decl.c:3977
-#, fuzzy, gcc-internal-format
-#| msgid "template parameters do not match template"
+#, gcc-internal-format
 msgid "template parameters do not match template %qD"
-msgstr "параметры не подходят шаблону"
+msgstr "параметры шаблона не соответствуют шаблону %qD"
 
 #: cp/decl.c:4177
-#, fuzzy, gcc-internal-format
-#| msgid "protocol %qE is deprecated"
+#, gcc-internal-format
 msgid "%<-fno-for-scope%> is deprecated"
-msgstr "протокол %qE устарел"
+msgstr ""
 
 #: cp/decl.c:4180
-#, fuzzy, gcc-internal-format
-#| msgid "protocol %qE is deprecated"
+#, gcc-internal-format
 msgid "%<-ffriend-injection%> is deprecated"
-msgstr "протокол %qE устарел"
+msgstr ""
 
 #: cp/decl.c:4276
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "-falign-labels=%d is not supported"
+#, gcc-internal-format, gfc-internal-format
 msgid "-faligned-new=%d is not a power of two"
-msgstr "-falign-labels=%d не поддерживается"
+msgstr "-faligned-new=%d не есть степень двойки"
 
 #: cp/decl.c:4733
 #, gcc-internal-format
@@ -46058,16 +40609,14 @@
 msgstr "в ISO C++ анонимные структуры запрещены"
 
 #: cp/decl.c:4847
-#, fuzzy, gcc-internal-format
-#| msgid "%qs can only be specified for functions"
+#, gcc-internal-format
 msgid "%<inline%> can only be specified for functions"
-msgstr "%qs допустим только для функций"
+msgstr "%<inline%> может задаваться только для функций"
 
 #: cp/decl.c:4850
-#, fuzzy, gcc-internal-format
-#| msgid "%qs can only be specified for functions"
+#, gcc-internal-format
 msgid "%<virtual%> can only be specified for functions"
-msgstr "%qs допустим только для функций"
+msgstr "%<virtual%> может задаваться только для функций"
 
 #: cp/decl.c:4855
 #, gcc-internal-format
@@ -46085,28 +40634,24 @@
 msgstr "класс хранения может быть задан только для объектов и функций"
 
 #: cp/decl.c:4865
-#, fuzzy, gcc-internal-format
-#| msgid "qualifiers can only be specified for objects and functions"
+#, gcc-internal-format
 msgid "%<const%> can only be specified for objects and functions"
-msgstr "квалификаторы могут быть заданы только для объектов и функций"
+msgstr "%<const%> может задаваться только для объектов и функций"
 
 #: cp/decl.c:4869
-#, fuzzy, gcc-internal-format
-#| msgid "qualifiers can only be specified for objects and functions"
+#, gcc-internal-format
 msgid "%<volatile%> can only be specified for objects and functions"
-msgstr "квалификаторы могут быть заданы только для объектов и функций"
+msgstr "%<volatile%> может задаваться только для объектов и функций"
 
 #: cp/decl.c:4873
-#, fuzzy, gcc-internal-format
-#| msgid "qualifiers can only be specified for objects and functions"
+#, gcc-internal-format
 msgid "%<__restrict%> can only be specified for objects and functions"
-msgstr "квалификаторы могут быть заданы только для объектов и функций"
+msgstr "%<__restrict%> может задаваться только для объектов и функций"
 
 #: cp/decl.c:4877
-#, fuzzy, gcc-internal-format
-#| msgid "a storage class can only be specified for objects and functions"
+#, gcc-internal-format
 msgid "%<__thread%> can only be specified for objects and functions"
-msgstr "класс хранения может быть задан только для объектов и функций"
+msgstr "%<__thread%> может задаваться только для объектов и функций"
 
 #: cp/decl.c:4881
 #, gcc-internal-format
@@ -46119,16 +40664,14 @@
 msgstr "%<constexpr%> не может использоваться для деклараций типов"
 
 #: cp/decl.c:4906
-#, fuzzy, gcc-internal-format
-#| msgid "attributes ignored on template instantiation"
+#, gcc-internal-format
 msgid "attribute ignored in explicit instantiation %q#T"
-msgstr "атрибуты игнорируются для конкретизации шаблона"
+msgstr "атрибут игнорируется в явной конкретизации %q#T"
 
 #: cp/decl.c:4909
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute can only be applied to class definitions"
+#, gcc-internal-format
 msgid "no attribute can be applied to an explicit instantiation"
-msgstr "%qE атрибут может применяться только к определениям классов"
+msgstr "никакой атрибут не может применяться к явной конкретизации"
 
 #: cp/decl.c:4981
 #, gcc-internal-format
@@ -46157,22 +40700,19 @@
 msgstr "определение функции %q#D помечено %<dllimport%>"
 
 #: cp/decl.c:5115
-#, fuzzy, gcc-internal-format
-#| msgid "%q#D is not a non-static data member of %qT"
+#, gcc-internal-format
 msgid "%q+#D is not a static data member of %q#T"
-msgstr "%q#D не есть нестатический элемент данных %qT"
+msgstr "%q+#D не есть статический элемент данных %q#T"
 
 #: cp/decl.c:5123
-#, fuzzy, gcc-internal-format
-#| msgid "template declaration of %q#D"
+#, gcc-internal-format
 msgid "non-member-template declaration of %qD"
-msgstr "шаблонная декларация %q#D"
+msgstr "non-member-template декларация %qD"
 
 #: cp/decl.c:5124
-#, fuzzy, gcc-internal-format
-#| msgid "invalid member template declaration %qD"
+#, gcc-internal-format
 msgid "does not match member template declaration here"
-msgstr "некорректная декларация элемента-шаблона %qD"
+msgstr "не соответствует декларации элемента шаблона здесь"
 
 #: cp/decl.c:5136
 #, gcc-internal-format
@@ -46190,16 +40730,14 @@
 msgstr "декларация %q#D вне класса не является определением"
 
 #: cp/decl.c:5230
-#, fuzzy, gcc-internal-format
-#| msgid "%qE undeclared here (not in a function)"
+#, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> function"
-msgstr "%qE не описан здесь (не в функции)"
+msgstr "%qD декларирована %<thread_local%> я %<constexpr%> функции"
 
 #: cp/decl.c:5233
-#, fuzzy, gcc-internal-format
-#| msgid "%q+F declared %<static%> but never defined"
+#, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> function"
-msgstr "%q+F объявлена %<static%>, но нигде не определена"
+msgstr "%qD декларирована %<static%> я %<constexpr%> функции"
 
 #: cp/decl.c:5298
 #, gcc-internal-format
@@ -46237,10 +40775,9 @@
 msgstr "нетривиально определенные инициализаторы не поддерживаются"
 
 #: cp/decl.c:5434
-#, fuzzy, gcc-internal-format
-#| msgid "size of array %qD is not an integral constant-expression"
+#, gcc-internal-format
 msgid "C99 designator %qE is not an integral constant-expression"
-msgstr "размер массива %qD не является целочисленным константным выражением"
+msgstr "C99 обозначение %qE не является целочисленным константным выражением"
 
 #: cp/decl.c:5490
 #, gcc-internal-format
@@ -46268,22 +40805,19 @@
 msgstr "размер памяти %qD не константа"
 
 #: cp/decl.c:5621
-#, fuzzy, gcc-internal-format
-#| msgid "sorry: semantics of inline function static data %q+#D are wrong (you%'ll wind up with multiple copies)"
+#, gcc-internal-format
 msgid "sorry: semantics of inline variable %q#D are wrong (you%'ll wind up with multiple copies)"
-msgstr "простите: ошибочная семантика статических данных %q+#D inline-функции (запутаетесь с несколькими копиями)"
+msgstr "простите: семантики inline переменной %q#D являются неверными (запутаетесь с несколькими копиями)"
 
 #: cp/decl.c:5625
-#, fuzzy, gcc-internal-format
-#| msgid "sorry: semantics of inline function static data %q+#D are wrong (you%'ll wind up with multiple copies)"
+#, gcc-internal-format
 msgid "sorry: semantics of inline function static data %q#D are wrong (you%'ll wind up with multiple copies)"
-msgstr "простите: ошибочная семантика статических данных %q+#D inline-функции (запутаетесь с несколькими копиями)"
+msgstr "простите: семантики статических данных inline функции %q#D являются неверными (запутаетесь с несколькими копиями)"
 
 #: cp/decl.c:5631
-#, fuzzy, gcc-internal-format
-#| msgid "  you can work around this by removing the initializer"
+#, gcc-internal-format
 msgid "you can work around this by removing the initializer"
-msgstr "  это можно обойти, удалив инициализатор"
+msgstr "это можно обойти, удалив инициализатор"
 
 #: cp/decl.c:5667
 #, gcc-internal-format
@@ -46291,16 +40825,14 @@
 msgstr "неинициализированная константа %qD"
 
 #: cp/decl.c:5674
-#, fuzzy, gcc-internal-format
-#| msgid "uninitialized member %qD in %<constexpr%> constructor"
+#, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
-msgstr "неинициализированный элемент %qD в %<constexpr%> конструкторе"
+msgstr "неинициализированная переменная %qD в %<constexpr%> функции"
 
 #: cp/decl.c:5681
-#, fuzzy, gcc-internal-format
-#| msgid "uninitialized member %qD in %<constexpr%> constructor"
+#, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> context"
-msgstr "неинициализированный элемент %qD в %<constexpr%> конструкторе"
+msgstr ""
 
 #: cp/decl.c:5689
 #, gcc-internal-format
@@ -46313,10 +40845,9 @@
 msgstr "конструктор не является предоставленным пользователем, поскольку он явно подразумевался в теле класса"
 
 #: cp/decl.c:5696
-#, fuzzy, gcc-internal-format
-#| msgid "and the implicitly-defined constructor does not initialize %q+#D"
+#, gcc-internal-format
 msgid "and the implicitly-defined constructor does not initialize %q#D"
-msgstr "и неявно определенный конструктор не инициализирует %q+#D"
+msgstr "и неявно определенный конструктор не инициализирует %q#D"
 
 #: cp/decl.c:5840
 #, gcc-internal-format
@@ -46339,10 +40870,9 @@
 msgstr "%qT не имеет нестатического элемента данных с именем %qD"
 
 #: cp/decl.c:5944
-#, fuzzy, gcc-internal-format
-#| msgid "invalid initializer for array member %q#D"
+#, gcc-internal-format
 msgid "invalid initializer for %q#D"
-msgstr "некорректный инициализатор для элемента массива %q#D"
+msgstr "некорректный инициализатор для %q#D"
 
 #: cp/decl.c:5974
 #, gcc-internal-format
@@ -46349,8 +40879,8 @@
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr "C99 обозначение %qE вне инициализатора агрегата"
 
-#: cp/decl.c:6011 cp/decl.c:6234 cp/typeck2.c:1310 cp/typeck2.c:1590
-#: cp/typeck2.c:1638 cp/typeck2.c:1685
+#: cp/decl.c:6011 cp/decl.c:6234 cp/typeck2.c:1310 cp/typeck2.c:1593
+#: cp/typeck2.c:1641 cp/typeck2.c:1688
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "избыточные элементы в инициализаторе для %qT"
@@ -46406,10 +40936,9 @@
 msgstr "неконстантная инициализация внутри класса некорректна для статического элемента %qD"
 
 #: cp/decl.c:6528
-#, fuzzy, gcc-internal-format
-#| msgid "non-constant in-class initialization invalid for static member %qD"
+#, gcc-internal-format
 msgid "non-constant in-class initialization invalid for non-inline static member %qD"
-msgstr "неконстантная инициализация внутри класса некорректна для статического элемента %qD"
+msgstr "неконстантная инициализация внутри класса некорректна для non-inline статического элемента %qD"
 
 #: cp/decl.c:6533
 #, gcc-internal-format
@@ -46417,10 +40946,9 @@
 msgstr "(запрошена инициализация вне класса)"
 
 #: cp/decl.c:6712
-#, fuzzy, gcc-internal-format
-#| msgid "%qD is initialized with itself"
+#, gcc-internal-format
 msgid "reference %qD is initialized with itself"
-msgstr "%qD инициализируется самим собой"
+msgstr "ссылка %qD инициализируется собой"
 
 #: cp/decl.c:6855
 #, gcc-internal-format
@@ -46427,29 +40955,25 @@
 msgid "assignment (not initialization) in declaration"
 msgstr "присваивание (а не инициализация) в декларации"
 
-#: cp/decl.c:6873 cp/decl.c:12605
-#, fuzzy, gcc-internal-format
-#| msgid "ISO C++ does not allow designated initializers"
+#: cp/decl.c:6873 cp/decl.c:12629
+#, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
-msgstr "ISO C++ не поддерживает назначенные инициализаторы"
+msgstr ""
 
-#: cp/decl.c:6877 cp/decl.c:12609
-#, fuzzy, gcc-internal-format
-#| msgid "storage class specified for %qs"
+#: cp/decl.c:6877 cp/decl.c:12633
+#, gcc-internal-format
 msgid "%<register%> storage class specifier used"
-msgstr "для %qs задан класс хранения"
+msgstr "использован %<register%> спецификатор класса хранения"
 
 #: cp/decl.c:6930
-#, fuzzy, gcc-internal-format
-#| msgid "invalid use of member function (did you forget the %<()%> ?)"
+#, gcc-internal-format
 msgid "initializer for %<decltype(auto) %D%> has function type (did you forget the %<()%> ?)"
-msgstr "некорректное использование функции-элемента (вы забыли %<()%> ?)"
+msgstr "инициализатор для %<decltype(auto) %D%> имеет тип функции (вы забыли %<()%> ?)"
 
 #: cp/decl.c:7026
-#, fuzzy, gcc-internal-format
-#| msgid "variable-sized object may not be initialized"
+#, gcc-internal-format
 msgid "variable concept has no initializer"
-msgstr "объект переменного размера нельзя инициализировать"
+msgstr "переменная concept не имеет инициализатора"
 
 #: cp/decl.c:7081
 #, gcc-internal-format
@@ -46461,55 +40985,50 @@
 msgid "function %q#D is initialized like a variable"
 msgstr "функция %q#D инициализирована как переменная"
 
-#: cp/decl.c:7329
-#, fuzzy, gcc-internal-format
-#| msgid "  cannot use obsolete binding at %q+D because it has a destructor"
+#: cp/decl.c:7350
+#, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
-msgstr "  нельзя использовать устаревшую привязку в %q+D, потому что имеется деструктор"
+msgstr "невозможна декомпозиция типа класса %qT, так как он содержит анонимный элемент структуры"
 
-#: cp/decl.c:7332
+#: cp/decl.c:7353
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
-msgstr ""
+msgstr "невозможна декомпозиция типа класса %qT, так как он имеет анонимный элемент объединения"
 
-#: cp/decl.c:7339
-#, fuzzy, gcc-internal-format
-#| msgid "cannot form pointer to member of non-class %q#T"
+#: cp/decl.c:7360
+#, gcc-internal-format
 msgid "cannot decompose inaccessible member %qD of %qT"
-msgstr "невозможно сформировать указатель на элемент не класса %q#T"
+msgstr ""
 
-#: cp/decl.c:7365
+#: cp/decl.c:7386
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
-msgstr ""
+msgstr "невозможна декомпозиция типа класса %qT: и он и его базовый класс %qT имеют нестатические элементы данных"
 
-#: cp/decl.c:7374
+#: cp/decl.c:7395
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
-msgstr ""
+msgstr "невозможна декомпозиция типа класса %qT: его базовые классы %qT и %qT имеют нестатические элементы данных"
 
-#: cp/decl.c:7592
-#, fuzzy, gcc-internal-format
-#| msgid "dereferencing pointer to incomplete type"
+#: cp/decl.c:7613
+#, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
-msgstr "доступ по указателю на неполный тип"
+msgstr ""
 
-#: cp/decl.c:7608
-#, fuzzy, gcc-internal-format
-#| msgid "ISO C90 forbids variable length array %qE"
+#: cp/decl.c:7629
+#, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
-msgstr "ISO C90 не поддерживает массив %qE переменного размера"
+msgstr "невозможна декомпозиция массива переменной длины %qT"
 
-#: cp/decl.c:7617 cp/decl.c:7702
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "%qs specified for structure field"
+#: cp/decl.c:7638 cp/decl.c:7723
+#, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
-msgstr[0] "%qs задано для поля структуры"
-msgstr[1] "%qs задано для поля структуры"
-msgstr[2] "%qs задано для поля структуры"
+msgstr[0] ""
+msgstr[1] ""
+msgstr[2] ""
 
-#: cp/decl.c:7621
+#: cp/decl.c:7642
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
@@ -46517,7 +41036,7 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/decl.c:7624
+#: cp/decl.c:7645
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
@@ -46525,1417 +41044,1337 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/decl.c:7669
-#, fuzzy, gcc-internal-format
-#| msgid "cannot declare pointer to %q#T"
+#: cp/decl.c:7690
+#, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
-msgstr "недопустимая декларация указателя на %q#T"
+msgstr ""
 
-#: cp/decl.c:7695
-#, fuzzy, gcc-internal-format
-#| msgid "size of array is not an integral constant-expression"
+#: cp/decl.c:7716
+#, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
-msgstr "размер массива не является целочисленным константным выражением"
+msgstr "%<std::tuple_size<%T>::value%> не является целочисленным константным выражением"
 
-#: cp/decl.c:7704
+#: cp/decl.c:7725
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.c:7725
-#, fuzzy, gcc-internal-format
-#| msgid "invalid type for iteration variable %qE"
+#: cp/decl.c:7746
+#, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
-msgstr "некорректный тип итерационной переменной %qE"
+msgstr ""
 
-#: cp/decl.c:7751
-#, fuzzy, gcc-internal-format
-#| msgid "cannot declare pointer to qualified function type %qT"
+#: cp/decl.c:7772
+#, gcc-internal-format
 msgid "cannot decompose union type %qT"
-msgstr "невозможно декларировать указатель на квалифицированный тип функции %qT"
+msgstr "невозможна декомпозиция типа объединения %qT"
 
-#: cp/decl.c:7756
-#, fuzzy, gcc-internal-format
-#| msgid "creating pointer to member of non-class type %qT"
+#: cp/decl.c:7777
+#, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
-msgstr "создание указателя на элемент не классового типа %qT"
+msgstr "невозможна декомпозиция non-array non-class типа %qT"
 
-#: cp/decl.c:7761
-#, fuzzy, gcc-internal-format
-#| msgid "cannot decompose address"
+#: cp/decl.c:7782
+#, gcc-internal-format
 msgid "cannot decompose lambda closure type %qT"
-msgstr "ошибка при декомпозиции адреса"
+msgstr "невозможна декомпозиция типа lambda замыкания %qT"
 
-#: cp/decl.c:7765
-#, fuzzy, gcc-internal-format
-#| msgid "dereferencing pointer to incomplete type"
+#: cp/decl.c:7786
+#, gcc-internal-format
 msgid "structured binding refers to incomplete class type %qT"
-msgstr "доступ по указателю на неполный тип"
+msgstr ""
 
-#: cp/decl.c:7774
-#, fuzzy, gcc-internal-format
-#| msgid "cannot apply %<offsetof%> to static data member %qD"
+#: cp/decl.c:7795
+#, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
-msgstr "недопустимое применение %<offsetof%> к статическому элементу данных %qD"
+msgstr "невозможна декомпозиция типа класса %qT без нестатических элементов данных"
 
-#: cp/decl.c:8213
+#: cp/decl.c:8234
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
-msgstr ""
+msgstr "нелокальная переменная %qD декларированная %<__thread%> требует динамической инициализации"
 
-#: cp/decl.c:8216
-#, fuzzy, gcc-internal-format
-#| msgid "  %q+T has a non-trivial destructor"
+#: cp/decl.c:8237
+#, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
-msgstr "  %q+T имеет нетривиальный деструктор"
+msgstr "нелокальная переменная %qD декларированная %<__thread%> имеет нетривиальный деструктор"
 
-#: cp/decl.c:8222
+#: cp/decl.c:8243
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
-msgstr ""
+msgstr "C++11 %<thread_local%> допускает динамическую инициализацию и уничтожение"
 
-#: cp/decl.c:8450
+#: cp/decl.c:8471
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "при инициализации не удалось определить размер %qT"
 
-#: cp/decl.c:8454
+#: cp/decl.c:8475
 #, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "не задан размер массива в %qT"
 
-#: cp/decl.c:8457
+#: cp/decl.c:8478
 #, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "нулевой размер массива %qT"
 
-#: cp/decl.c:8473
+#: cp/decl.c:8494
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "деструктор чужого класса %qT не может быть элементом"
 
-#: cp/decl.c:8475
+#: cp/decl.c:8496
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "конструктор чужого класса %qT не может быть элементом"
 
-#: cp/decl.c:8499
+#: cp/decl.c:8520
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD декларирована как %<virtual%> переменная"
 
-#: cp/decl.c:8501
+#: cp/decl.c:8522
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "спецификаторы %<const%> и %<volatile%> для функции %qD некорректны в декларации переменной"
 
-#: cp/decl.c:8506
+#: cp/decl.c:8527
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD декларирован как %<virtual%> параметр"
 
-#: cp/decl.c:8508
+#: cp/decl.c:8529
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD декларирован как %<inline%> параметр"
 
-#: cp/decl.c:8510
+#: cp/decl.c:8531
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "спецификаторы %<const%> и %<volatile%> для функции %qD некорректны в декларации параметра"
 
-#: cp/decl.c:8515
+#: cp/decl.c:8536
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD декларирован как %<virtual%> тип"
 
-#: cp/decl.c:8517
+#: cp/decl.c:8538
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD декларирован как %<inline%> тип"
 
-#: cp/decl.c:8519
+#: cp/decl.c:8540
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "спецификаторы %<const%> и %<volatile%> для функции %qD некорректны в декларации типа"
 
-#: cp/decl.c:8524
+#: cp/decl.c:8545
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD декларирован как %<virtual%> поле"
 
-#: cp/decl.c:8526
+#: cp/decl.c:8547
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD декларирован как %<inline%> поле"
 
-#: cp/decl.c:8528
+#: cp/decl.c:8549
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "спецификаторы %<const%> и %<volatile%> для функции %qD некорректны в декларации поля"
 
-#: cp/decl.c:8535
+#: cp/decl.c:8556
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D декларировано как friend"
 
-#: cp/decl.c:8542
+#: cp/decl.c:8563
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D декларировано со спецификацией исключений"
 
-#: cp/decl.c:8574
+#: cp/decl.c:8595
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "определение %qD вне пространства имён, объемлющего %qT"
 
-#: cp/decl.c:8614
+#: cp/decl.c:8635
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "статическая функция-член %q#D объявлена с квалификаторами типа"
 
-#: cp/decl.c:8624
-#, fuzzy, gcc-internal-format
-#| msgid "%qD declared as a non-parameter"
+#: cp/decl.c:8645
+#, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
-msgstr "%qD декларирован как не параметр"
+msgstr "concept %q#D декларирован с параметрами функциями"
 
-#: cp/decl.c:8630
-#, fuzzy, gcc-internal-format
-#| msgid "parameter %qD declared with void type"
+#: cp/decl.c:8651
+#, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
-msgstr "параметр %qD объявлен с типом void"
+msgstr "concept %q#D декларирован с выведенным типом возврата"
 
-#: cp/decl.c:8632
-#, fuzzy, gcc-internal-format
-#| msgid "Java method %qD has non-Java return type %qT"
+#: cp/decl.c:8653
+#, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
-msgstr "Java-метод %qD имеет тип результата %qT, не поддерживаемый Java"
+msgstr "concept %q#D с non-%<bool%> типом возврата %qT"
 
-#: cp/decl.c:8703
-#, fuzzy, gcc-internal-format
-#| msgid "expected %<;%> after union definition"
+#: cp/decl.c:8724
+#, gcc-internal-format
 msgid "concept %qD has no definition"
-msgstr "ожидалось %<;%> после определения объединения"
+msgstr "concept %qD не имеет определения"
 
-#: cp/decl.c:8772
+#: cp/decl.c:8793
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "определение явной специализации %qD в friend-декларации"
 
 #. Something like `template <class T> friend void f<T>()'.
-#: cp/decl.c:8782
+#: cp/decl.c:8803
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "некорректное использование идентификатора шаблона %qD в декларации первичного шаблона"
 
-#: cp/decl.c:8800
+#: cp/decl.c:8821
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "аргументы по умолчанию не допускаются в декларации специализации friend-шаблона %qD"
 
-#: cp/decl.c:8808
+#: cp/decl.c:8829
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "не допускается использовать %<inline%> в декларации специализации friend-шаблона %qD"
 
-#: cp/decl.c:8857
+#: cp/decl.c:8878
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "недопустимая декларация %<::main%> как шаблона"
 
-#: cp/decl.c:8859
+#: cp/decl.c:8880
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "недопустимая декларация %<::main%> как inline-функции"
 
-#: cp/decl.c:8861
-#, fuzzy, gcc-internal-format
-#| msgid "cannot declare %<::main%> to be inline"
+#: cp/decl.c:8882
+#, gcc-internal-format
 msgid "cannot declare %<::main%> to be %<constexpr%>"
-msgstr "недопустимая декларация %<::main%> как inline-функции"
+msgstr ""
 
-#: cp/decl.c:8863
+#: cp/decl.c:8884
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "недопустимая декларация %<::main%> как статической функции"
 
-#: cp/decl.c:8920
+#: cp/decl.c:8941
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "статическая элемент-функция %qD не может иметь cv-квалификатор"
 
-#: cp/decl.c:8921
+#: cp/decl.c:8942
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "не-элемент-функция %qD не может иметь cv-квалификатор"
 
-#: cp/decl.c:8929
-#, fuzzy, gcc-internal-format
-#| msgid "static member function %qD cannot have cv-qualifier"
+#: cp/decl.c:8950
+#, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
-msgstr "статическая элемент-функция %qD не может иметь cv-квалификатор"
+msgstr "статическая элемент-функция %qD не может иметь ref-квалификатор"
 
-#: cp/decl.c:8930
-#, fuzzy, gcc-internal-format
-#| msgid "non-member function %qD cannot have cv-qualifier"
+#: cp/decl.c:8951
+#, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
-msgstr "не-элемент-функция %qD не может иметь cv-квалификатор"
+msgstr "non-member функция %qD не может иметь ref-квалификатор"
 
-#: cp/decl.c:8940
-#, fuzzy, gcc-internal-format
-#| msgid "specialization of %qD must appear at namespace scope"
+#: cp/decl.c:8961
+#, gcc-internal-format
 msgid "deduction guide %qD must be declared at namespace scope"
-msgstr "специализация %qD должна появляться в пределах пространства имен"
+msgstr "руководство вывода %qD должно декларироваться в контексте пространства имен"
 
-#: cp/decl.c:8946
-#, fuzzy, gcc-internal-format
-#| msgid "declaration of %qD as non-function"
+#: cp/decl.c:8967
+#, gcc-internal-format
 msgid "deduction guide %qD must not have a function body"
-msgstr "декларация %qD как не-функции"
+msgstr "руководство вывода %qD не должно иметь тело функции"
 
-#: cp/decl.c:8959
+#: cp/decl.c:8980
 #, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr "литеральный оператор с C-привязкой"
 
-#: cp/decl.c:8969
+#: cp/decl.c:8990
 #, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "%qD имеет некорректный список аргументов"
 
-#: cp/decl.c:8977
-#, fuzzy, gcc-internal-format
-#| msgid "integer suffix %<%s%> shadowed by implementation"
+#: cp/decl.c:8998
+#, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
-msgstr "целый суффикс %<%s%> затенен реализацией"
+msgstr "целый суффикс %qs перекрыт реализацией"
 
-#: cp/decl.c:8983
-#, fuzzy, gcc-internal-format
-#| msgid "floating point suffix %<%s%> shadowed by implementation"
+#: cp/decl.c:9004
+#, gcc-internal-format
 msgid "floating point suffix %qs shadowed by implementation"
-msgstr "плавающий суффикс %<%s%> затенен реализацией"
+msgstr "суффикс плавающей точки %qs перекрыт реализацией"
 
-#: cp/decl.c:8991
+#: cp/decl.c:9012
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr "суффиксы литеральных операторов без предшествующего %<_%> зарезервированы для будущей стандартизации"
 
-#: cp/decl.c:8996
+#: cp/decl.c:9017
 #, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "%qD должен быть не-элемент-функцией"
 
-#: cp/decl.c:9076
+#: cp/decl.c:9097
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> должна возвращать %<int%>"
 
-#: cp/decl.c:9116
+#: cp/decl.c:9137
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "определение неявно декларированного %qD"
 
-#: cp/decl.c:9121
+#: cp/decl.c:9142
 #, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "определение явно подразумеваемого %q+D"
 
-#: cp/decl.c:9123
-#, fuzzy, gcc-internal-format
-#| msgid "%q+#D explicitly defaulted here"
+#: cp/decl.c:9144
+#, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
-msgstr "%q+#D явно подразумевается здесь"
+msgstr "%q#D явно подразумевается здесь"
 
-#: cp/decl.c:9140
+#: cp/decl.c:9161
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "нет элемента-функции %q#D в классе %qT"
 
-#: cp/decl.c:9329
-#, fuzzy, gcc-internal-format
-#| msgid "cannot declare %<::main%> to be a template"
+#: cp/decl.c:9350
+#, gcc-internal-format
 msgid "cannot declare %<::main%> to be a global variable"
-msgstr "недопустимая декларация %<::main%> как шаблона"
+msgstr "невозможно декларировать %<::main%> как глобальную переменную"
 
-#: cp/decl.c:9337
-#, fuzzy, gcc-internal-format
-#| msgid "automatic variable %qE cannot be %<threadprivate%>"
+#: cp/decl.c:9358
+#, gcc-internal-format
 msgid "a non-template variable cannot be %<concept%>"
-msgstr "автоматическая переменная %qE не может быть %<threadprivate%>"
+msgstr "non-template переменная не может быть %<concept%>"
 
-#: cp/decl.c:9344
+#: cp/decl.c:9365
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
-msgstr ""
+msgstr "concept должен иметь тип %<bool%>"
 
-#: cp/decl.c:9464
+#: cp/decl.c:9485
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "инициализация внутри класса статического элемента данных %q#D неполного типа"
 
-#: cp/decl.c:9468
+#: cp/decl.c:9489
 #, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "%<constexpr%> требуется для инициализации внутри класса статического элемента данных %q#D нецелого типа"
 
-#: cp/decl.c:9472
+#: cp/decl.c:9493
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "инициализация внутри класса статического элемента данных %q#D нелитерального типа"
 
-#: cp/decl.c:9486
+#: cp/decl.c:9507
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "некорректная инициализация внутри класса статического элемента данных нецелочисленного типа %qT"
 
-#: cp/decl.c:9493
+#: cp/decl.c:9514
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ISO C++ запрещает инициализацию внутри класса неконстантного статического элемента %qD"
 
-#: cp/decl.c:9498
+#: cp/decl.c:9519
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO C++ запрещает инициализацию элемента-константы %qD нецелочисленного типа %qT"
 
-#: cp/decl.c:9598
+#: cp/decl.c:9619
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "размер массива %qD имеет нецелочисленный тип %qT"
 
-#: cp/decl.c:9600
+#: cp/decl.c:9621
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "размер массива имеет нецелочисленный тип %qT"
 
-#: cp/decl.c:9630 cp/decl.c:9680
+#: cp/decl.c:9651 cp/decl.c:9701
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "размер массива не является целочисленным константным выражением"
 
-#: cp/decl.c:9646
+#: cp/decl.c:9667
 #, gcc-internal-format
 msgid "size of array %qD is negative"
 msgstr "размер массива %qD отрицательный"
 
-#: cp/decl.c:9648 cp/init.c:3651
+#: cp/decl.c:9669 cp/init.c:3667
 #, gcc-internal-format
 msgid "size of array is negative"
 msgstr "размер массива отрицательный"
 
-#: cp/decl.c:9662
+#: cp/decl.c:9683
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C++ запрещает массив нулевого размера %qD"
 
-#: cp/decl.c:9664
+#: cp/decl.c:9685
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++ запрещает массивы нулевого размера"
 
-#: cp/decl.c:9677
+#: cp/decl.c:9698
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "размер массива %qD не является целочисленным константным выражением"
 
-#: cp/decl.c:9686
+#: cp/decl.c:9707
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++ запрещает массив переменного размера %qD"
 
-#: cp/decl.c:9688
+#: cp/decl.c:9709
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++ запрещает массивы переменного размера"
 
-#: cp/decl.c:9694
+#: cp/decl.c:9715
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr "используется массив переменного размера %qD"
 
-#: cp/decl.c:9697
+#: cp/decl.c:9718
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr "используется массив переменного размера"
 
-#: cp/decl.c:9746
+#: cp/decl.c:9767
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "переполнение в размерности массива"
 
-#: cp/decl.c:9799
-#, fuzzy, gcc-internal-format
-#| msgid "%q+D declared as a friend"
+#: cp/decl.c:9820
+#, gcc-internal-format
 msgid "%qD declared as array of %qT"
-msgstr "%q+D декларировано как friend"
+msgstr "%qD декларировано как массив %qT"
 
-#: cp/decl.c:9809
+#: cp/decl.c:9830
 #, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "декларация %qD как массива void"
 
-#: cp/decl.c:9811
+#: cp/decl.c:9832
 #, gcc-internal-format
 msgid "creating array of void"
 msgstr "создание массива void"
 
-#: cp/decl.c:9816
+#: cp/decl.c:9837
 #, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "декларация %qD как массива функций"
 
-#: cp/decl.c:9818
+#: cp/decl.c:9839
 #, gcc-internal-format
 msgid "creating array of functions"
 msgstr "создание массива функций"
 
-#: cp/decl.c:9823
+#: cp/decl.c:9844
 #, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "декларация %qD как массива ссылок"
 
-#: cp/decl.c:9825
+#: cp/decl.c:9846
 #, gcc-internal-format
 msgid "creating array of references"
 msgstr "создание массива ссылок"
 
-#: cp/decl.c:9830
+#: cp/decl.c:9851
 #, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "декларация %qD как массива элементов-функций"
 
-#: cp/decl.c:9832
+#: cp/decl.c:9853
 #, gcc-internal-format
 msgid "creating array of function members"
 msgstr "создание массива элементов-функций"
 
-#: cp/decl.c:9846
+#: cp/decl.c:9867
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "декларация многомерного массива %qD должна определять границы для всех размерностей, кроме первой"
 
-#: cp/decl.c:9850
+#: cp/decl.c:9871
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "в многомерном массиве должны быть определены границы для всех размерностей, кроме первой"
 
-#: cp/decl.c:9909
+#: cp/decl.c:9930
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "некорректная спецификация возвращаемого типа в конструкторе"
 
-#: cp/decl.c:9912
-#, fuzzy, gcc-internal-format
-#| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
+#: cp/decl.c:9933
+#, gcc-internal-format
 msgid "qualifiers are not allowed on constructor declaration"
-msgstr "квалификаторы не допускаются в декларации %<operator %T%>"
+msgstr "квалификаторы не допускаются в декларации конструктора"
 
-#: cp/decl.c:9922
+#: cp/decl.c:9943
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "некорректная спецификация возвращаемого типа в деструкторе"
 
-#: cp/decl.c:9925
-#, fuzzy, gcc-internal-format
-#| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
+#: cp/decl.c:9946
+#, gcc-internal-format
 msgid "qualifiers are not allowed on destructor declaration"
-msgstr "квалификаторы не допускаются в декларации %<operator %T%>"
+msgstr "квалификаторы не допускаются в декларации деструктора"
 
-#: cp/decl.c:9937
+#: cp/decl.c:9958
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "тип результата задан для %<operator %T%>"
 
-#: cp/decl.c:9940
+#: cp/decl.c:9961
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "квалификаторы не допускаются в декларации %<operator %T%>"
 
-#: cp/decl.c:9948
-#, fuzzy, gcc-internal-format
-#| msgid "return type specification for destructor invalid"
+#: cp/decl.c:9969
+#, gcc-internal-format
 msgid "return type specified for deduction guide"
-msgstr "некорректная спецификация возвращаемого типа в деструкторе"
+msgstr "возвращаемый тип задан для руководства вывода"
 
-#: cp/decl.c:9951
-#, fuzzy, gcc-internal-format
-#| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
+#: cp/decl.c:9972
+#, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of deduction guide"
-msgstr "квалификаторы не допускаются в декларации %<operator %T%>"
+msgstr "квалификаторы не допускаются в декларации руководства вывода"
 
-#: cp/decl.c:9955
-#, fuzzy, gcc-internal-format
-#| msgid "conflicting specifiers in declaration of %qs"
+#: cp/decl.c:9976
+#, gcc-internal-format
 msgid "template template parameter %qT in declaration of deduction guide"
-msgstr "конфликтующие спецификаторы в декларации %qs"
+msgstr ""
 
-#: cp/decl.c:9964
-#, fuzzy, gcc-internal-format
-#| msgid "conflicting specifiers in declaration of %qs"
+#: cp/decl.c:9985
+#, gcc-internal-format
 msgid "decl-specifier in declaration of deduction guide"
-msgstr "конфликтующие спецификаторы в декларации %qs"
+msgstr "decl-спецификатор в декларации руководства вывода"
 
-#: cp/decl.c:9985
+#: cp/decl.c:10006
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "декларация безымянной переменной или поля с типом void"
 
-#: cp/decl.c:9992
+#: cp/decl.c:10013
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "декларация переменной или поля с типом void"
 
-#: cp/decl.c:10007
-#, fuzzy, gcc-internal-format
-#| msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
+#: cp/decl.c:10028
+#, gcc-internal-format
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
-msgstr "некорректно указано %<inline%> для функции %qs, объявленной вне глобальной области видимости"
+msgstr "%<inline%> спецификатор некорректен для переменной %qD декларированной в контексте блока"
 
-#: cp/decl.c:10013
-#, fuzzy, gcc-internal-format
-#| msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
+#: cp/decl.c:10034
+#, gcc-internal-format
 msgid "inline variables are only available with -std=c++17 or -std=gnu++17"
-msgstr "inline namespaces доступны только с -std=c++11 или -std=gnu++11"
+msgstr ""
 
-#: cp/decl.c:10268
+#: cp/decl.c:10292
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "недопустимое использование квалифицированного имени %<::%D%>"
 
-#: cp/decl.c:10271 cp/decl.c:10291
+#: cp/decl.c:10295 cp/decl.c:10315
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "недопустимое использование квалифицированного имени %<%T::%D%>"
 
-#: cp/decl.c:10274
+#: cp/decl.c:10298
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "недопустимое использование квалифицированного имени %<%D::%D%>"
 
-#: cp/decl.c:10283
+#: cp/decl.c:10307
 #, gcc-internal-format
 msgid "%q#T is not a class or a namespace"
 msgstr "%q#T не является классом или пространством имен"
 
-#: cp/decl.c:10305 cp/decl.c:10398 cp/decl.c:10407 cp/decl.c:11970
+#: cp/decl.c:10329 cp/decl.c:10422 cp/decl.c:10431 cp/decl.c:11994
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "декларация %qD как не-функции"
 
-#: cp/decl.c:10311
+#: cp/decl.c:10335
 #, gcc-internal-format
 msgid "declaration of %qD as non-member"
 msgstr "декларация %qD как не-элемента"
 
-#: cp/decl.c:10339
+#: cp/decl.c:10363
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "декларатор отсутствует; используется зарезервированное слово %qD"
 
-#: cp/decl.c:10390
+#: cp/decl.c:10414
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "определение функции не объявляет параметры"
 
-#: cp/decl.c:10415
+#: cp/decl.c:10439
 #, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "декларация %qD как %<typedef%>"
 
-#: cp/decl.c:10420
+#: cp/decl.c:10444
 #, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "декларация %qD как параметра"
 
-#: cp/decl.c:10454
-#, fuzzy, gcc-internal-format
-#| msgid "%<constexpr%> cannot appear in a typedef declaration"
+#: cp/decl.c:10478
+#, gcc-internal-format
 msgid "%<concept%> cannot appear in a typedef declaration"
-msgstr "%<constexpr%> не может встречаться в typedef декларации"
+msgstr "%<concept%> не может встречаться в typedef декларации"
 
-#: cp/decl.c:10460
+#: cp/decl.c:10484
 #, gcc-internal-format
 msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgstr "%<constexpr%> не может встречаться в typedef декларации"
 
-#: cp/decl.c:10468
+#: cp/decl.c:10492
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "два или более типа в декларации имени %qs"
 
-#: cp/decl.c:10474
+#: cp/decl.c:10498
 #, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr "конфликтующие спецификаторы в декларации %qs"
 
-#: cp/decl.c:10515
-#, fuzzy, gcc-internal-format
-#| msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
+#: cp/decl.c:10539
+#, gcc-internal-format
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
-msgstr "ISO C не поддерживает %<complex%> как эквивалент %<double complex%>"
+msgstr "ISO C++ не поддерживает плоские %<complex%> означающие %<double complex%>"
 
-#: cp/decl.c:10564 cp/decl.c:10567 cp/decl.c:10570
+#: cp/decl.c:10588 cp/decl.c:10591 cp/decl.c:10594
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ запрещает декларации %qs без типа"
 
-#: cp/decl.c:10586
-#, fuzzy, gcc-internal-format
-#| msgid "%<__int128%> is not supported by this target"
+#: cp/decl.c:10610
+#, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
-msgstr "%<__int128%> не поддерживается этой целевой платформой"
+msgstr "%<__int%d%> не поддерживается этой целевой платформой"
 
-#: cp/decl.c:10592
-#, fuzzy, gcc-internal-format
-#| msgid "ISO C++ does not support %<__int128%> for %qs"
+#: cp/decl.c:10616
+#, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
-msgstr "ISO C++ не поддерживает %<__int128%> для %qs"
+msgstr "ISO C++ не поддерживает %<__int%d%> для %qs"
 
-#: cp/decl.c:10614 cp/decl.c:10634
+#: cp/decl.c:10638 cp/decl.c:10658
 #, gcc-internal-format
 msgid "%<signed%> or %<unsigned%> invalid for %qs"
 msgstr "%<signed%> или %<unsigned%> некорректны для %qs"
 
-#: cp/decl.c:10616
+#: cp/decl.c:10640
 #, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgstr "%<signed%> и %<unsigned%> одновременно заданы для %qs"
 
-#: cp/decl.c:10618
+#: cp/decl.c:10642
 #, gcc-internal-format
 msgid "%<long long%> invalid for %qs"
 msgstr "недопустимо использовать %<long long%> для %qs"
 
-#: cp/decl.c:10620
+#: cp/decl.c:10644
 #, gcc-internal-format
 msgid "%<long%> invalid for %qs"
 msgstr "недопустимо использовать %<long%> для %qs"
 
-#: cp/decl.c:10622
+#: cp/decl.c:10646
 #, gcc-internal-format
 msgid "%<short%> invalid for %qs"
 msgstr "недопустимо использовать %<short%> для %qs"
 
-#: cp/decl.c:10624
+#: cp/decl.c:10648
 #, gcc-internal-format
 msgid "%<long%> or %<short%> invalid for %qs"
 msgstr "%<long%> или %<short%> некорректны для %qs"
 
-#: cp/decl.c:10626
+#: cp/decl.c:10650
 #, gcc-internal-format
 msgid "%<long%>, %<int%>, %<short%>, or %<char%> invalid for %qs"
 msgstr "%<long%>, %<int%>, %<short%> или %<char%> некорректны для %qs"
 
-#: cp/decl.c:10628
+#: cp/decl.c:10652
 #, gcc-internal-format
 msgid "%<long%> or %<short%> specified with char for %qs"
 msgstr "%<long%> или %<short%> заданы в описании %qs с типом char"
 
-#: cp/decl.c:10630
+#: cp/decl.c:10654
 #, gcc-internal-format
 msgid "%<long%> and %<short%> specified together for %qs"
 msgstr "%<long%> и %<short%> одновременно заданы для %qs"
 
-#: cp/decl.c:10636
+#: cp/decl.c:10660
 #, gcc-internal-format
 msgid "%<short%> or %<long%> invalid for %qs"
 msgstr "%<short%> или %<long%> некорректны для %qs"
 
-#: cp/decl.c:10644
+#: cp/decl.c:10668
 #, gcc-internal-format
 msgid "long, short, signed or unsigned used invalidly for %qs"
 msgstr "неверное употребление long, short, signed или unsigned в описании %s"
 
-#: cp/decl.c:10712
+#: cp/decl.c:10736
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "спецификатор complex для %qs недопустим"
 
-#: cp/decl.c:10751
+#: cp/decl.c:10775
 #, gcc-internal-format
 msgid "template placeholder type %qT must be followed by a simple declarator-id"
-msgstr ""
+msgstr "за типом заполнителя шаблона %qT должен следовать простой declarator-id"
 
-#: cp/decl.c:10769
-#, fuzzy, gcc-internal-format
-#| msgid "member %qD cannot be declared both virtual and static"
+#: cp/decl.c:10793
+#, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
-msgstr "элемент %qD не может быть декларирован как virtual и static"
+msgstr "элемент %qD не может быть декларирован и как %<virtual%> и как %<static%>"
 
-#: cp/decl.c:10775
-#, fuzzy, gcc-internal-format
-#| msgid "member %qD cannot be declared both virtual and static"
+#: cp/decl.c:10799
+#, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<constexpr%>"
-msgstr "элемент %qD не может быть декларирован как virtual и static"
+msgstr "элемент %qD не может быть декларирован и как %<virtual%> и как %<constexpr%>"
 
-#: cp/decl.c:10785
+#: cp/decl.c:10809
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "typedef-декларация не допускается в декларации параметров"
 
-#: cp/decl.c:10790
+#: cp/decl.c:10814
 #, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "класс хранения задан для параметра шаблона %qs"
 
-#: cp/decl.c:10796
+#: cp/decl.c:10820
 #, gcc-internal-format
 msgid "storage class specifiers invalid in parameter declarations"
 msgstr "спецификаторы класса хранения не допускаются в декларациях параметров"
 
-#: cp/decl.c:10800
-#, fuzzy, gcc-internal-format
-#| msgid "a parameter cannot be declared %<constexpr%>"
+#: cp/decl.c:10824
+#, gcc-internal-format
 msgid "a parameter cannot be declared %<concept%>"
-msgstr "параметр не может быть декларирован %<constexpr%>"
+msgstr "параметр не может быть декларирован %<concept%>"
 
-#: cp/decl.c:10805
+#: cp/decl.c:10829
 #, gcc-internal-format
 msgid "a parameter cannot be declared %<constexpr%>"
 msgstr "параметр не может быть декларирован %<constexpr%>"
 
-#: cp/decl.c:10815
+#: cp/decl.c:10839
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "%<virtual%> вне декларации класса"
 
-#: cp/decl.c:10825
-#, fuzzy, gcc-internal-format
-#| msgid "Warn when an inlined function cannot be inlined"
+#: cp/decl.c:10849
+#, gcc-internal-format
 msgid "structured binding declaration cannot be %<inline%>"
-msgstr "Предупреждать об inline-функциях, подстановка которых невозможна"
+msgstr ""
 
-#: cp/decl.c:10828
-#, fuzzy, gcc-internal-format
-#| msgid "template declaration of %<typedef%>"
+#: cp/decl.c:10852
+#, gcc-internal-format
 msgid "structured binding declaration cannot be %<typedef%>"
-msgstr "шаблонная декларация %<typedef%>"
+msgstr ""
 
-#: cp/decl.c:10830
-#, fuzzy, gcc-internal-format
-#| msgid "a destructor cannot be %<constexpr%>"
+#: cp/decl.c:10854
+#, gcc-internal-format
 msgid "structured binding declaration cannot be %<constexpr%>"
-msgstr "деструктор не может быть %<constexpr%>"
+msgstr ""
 
-#: cp/decl.c:10834
-#, fuzzy, gcc-internal-format
-#| msgid "attribute ignored in declaration of %q#T"
+#: cp/decl.c:10858
+#, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
-msgstr "атрибуты проигнорированы в декларации %q#T"
+msgstr ""
 
-#: cp/decl.c:10839
-#, fuzzy, gcc-internal-format
-#| msgid "a destructor cannot be %<constexpr%>"
+#: cp/decl.c:10863
+#, gcc-internal-format
 msgid "structured binding declaration cannot be %<concept%>"
-msgstr "деструктор не может быть %<constexpr%>"
+msgstr ""
 
-#: cp/decl.c:10845
-#, fuzzy, gcc-internal-format
-#| msgid "subscripting array declared %<register%>"
+#: cp/decl.c:10869
+#, gcc-internal-format
 msgid "structured binding declaration cannot be %<register%>"
-msgstr "индексируемый массив объявлен как %<register%>"
+msgstr ""
 
-#: cp/decl.c:10849
+#: cp/decl.c:10873
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<static%>"
 msgstr ""
 
-#: cp/decl.c:10853
-#, fuzzy, gcc-internal-format
-#| msgid "nested function %qE declared %<extern%>"
+#: cp/decl.c:10877
+#, gcc-internal-format
 msgid "structured binding declaration cannot be %<extern%>"
-msgstr "вложенная функция %qE объявлена %<extern%>"
+msgstr ""
 
-#: cp/decl.c:10857
-#, fuzzy, gcc-internal-format
-#| msgid "function %qs cannot be declared %<mutable%>"
+#: cp/decl.c:10881
+#, gcc-internal-format
 msgid "structured binding declaration cannot be %<mutable%>"
-msgstr "недопустимая декларация функции %qs как %<mutable%>"
+msgstr ""
 
-#: cp/decl.c:10861
+#: cp/decl.c:10885
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10872
-#, fuzzy, gcc-internal-format
-#| msgid "attribute ignored in declaration of %q#T"
+#: cp/decl.c:10896
+#, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
-msgstr "атрибуты проигнорированы в декларации %q#T"
+msgstr ""
 
-#: cp/decl.c:10875
+#: cp/decl.c:10899
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
-msgstr ""
+msgstr "тип должен быть cv-qualified %<auto%> или ссылкой на cv-qualified %<auto%>"
 
-#: cp/decl.c:10906
+#: cp/decl.c:10930
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "в декларации %qs задано более одного класса хранения"
 
-#: cp/decl.c:10929
+#: cp/decl.c:10953
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "для %qs задан класс хранения"
 
-#: cp/decl.c:10933
+#: cp/decl.c:10957
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "класс хранения в декларации параметра %qs"
 
-#: cp/decl.c:10946
+#: cp/decl.c:10970
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "вложенная функция %qs объявлена %<extern%>"
 
-#: cp/decl.c:10950
+#: cp/decl.c:10974
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "имя %qs описано на верхнем уровне с классом хранения %<auto%>"
 
-#: cp/decl.c:10957
+#: cp/decl.c:10981
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "имя %qs на уровне функции неявно имеет класс auto и объявлено %<__thread%>"
 
-#: cp/decl.c:10969
+#: cp/decl.c:10993
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "класс хранения не допускается в декларации friend-функции"
 
-#: cp/decl.c:11050
-#, fuzzy, gcc-internal-format
-#| msgid "multiple storage classes in declaration of %qs"
+#: cp/decl.c:11074
+#, gcc-internal-format
 msgid "unnecessary parentheses in declaration of %qs"
-msgstr "в декларации %qs задано более одного класса хранения"
+msgstr ""
 
-#: cp/decl.c:11098
+#: cp/decl.c:11122
 #, gcc-internal-format
 msgid "requires-clause on return type"
-msgstr ""
+msgstr "requires-клаузула для типа возврата"
 
-#: cp/decl.c:11118
+#: cp/decl.c:11142
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr "%qs функция использует %<auto%> спецификатор типа без завершающего типа возврата"
 
-#: cp/decl.c:11121
-#, fuzzy, gcc-internal-format
-#| msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
+#: cp/decl.c:11145
+#, gcc-internal-format
 msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
-msgstr "завершающий тип возврата доступен только с -std=c++11 или -std=gnu++11"
+msgstr "выведенный тип возврата доступен только с -std=c++14 или -std=gnu++14"
 
-#: cp/decl.c:11127
-#, fuzzy, gcc-internal-format
-#| msgid "virtual functions cannot be friends"
+#: cp/decl.c:11151
+#, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
-msgstr "виртуальные функции не могут быть friend-функциями"
+msgstr "виртуальная функция не может иметь выведенный тип возврата"
 
-#: cp/decl.c:11134
+#: cp/decl.c:11158
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr "%qs функция с завершающим типом возврата имеет %qT в качестве своего типа а не обычный %<auto%>"
 
-#: cp/decl.c:11147
-#, fuzzy, gcc-internal-format
-#| msgid "type qualifiers ignored on function return type"
+#: cp/decl.c:11171
+#, gcc-internal-format
 msgid "deduced class type %qD in function return type"
-msgstr "квалификаторы в описании типа возвращаемого значения функции "
+msgstr ""
 
-#: cp/decl.c:11156
-#, fuzzy, gcc-internal-format
-#| msgid "%qs function cannot have arguments"
+#: cp/decl.c:11180
+#, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
-msgstr "%qs функция не может иметь аргументы"
+msgstr "руководство вывода для %qT должно иметь завершающий тип возврата"
 
-#: cp/decl.c:11169
+#: cp/decl.c:11193
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
-msgstr ""
+msgstr "хвостовой тип возврата %qT руководства вывода не есть специализация %qT"
 
 #. Not using maybe_warn_cpp0x because this should
 #. always be an error.
-#: cp/decl.c:11180
+#: cp/decl.c:11204
 #, gcc-internal-format
 msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgstr "завершающий тип возврата доступен только с -std=c++11 или -std=gnu++11"
 
-#: cp/decl.c:11183
+#: cp/decl.c:11207
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr "%qs функция с завершающим типом возврата не декларирована с %<auto%> спецификатором типа"
 
-#: cp/decl.c:11212
+#: cp/decl.c:11236
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs объявлена как функция, возвращающая функцию"
 
-#: cp/decl.c:11218
+#: cp/decl.c:11242
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs объявлена как функция, возвращающая массив"
 
-#: cp/decl.c:11247
+#: cp/decl.c:11271
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "деструктор не может быть статической элементом-функцией"
 
-#: cp/decl.c:11248
+#: cp/decl.c:11272
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "конструктор не может быть статической элементом-функцией"
 
-#: cp/decl.c:11252
+#: cp/decl.c:11276
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "деструкторы не могут быть cv-квалифицированы"
 
-#: cp/decl.c:11253
+#: cp/decl.c:11277
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "конструкторы не могут быть cv-квалифицированы"
 
-#: cp/decl.c:11261
-#, fuzzy, gcc-internal-format
-#| msgid "destructors may not be cv-qualified"
+#: cp/decl.c:11285
+#, gcc-internal-format
 msgid "destructors may not be ref-qualified"
-msgstr "деструкторы не могут быть cv-квалифицированы"
+msgstr "деструкторы не могут быть ref-квалифицированы"
 
-#: cp/decl.c:11262
-#, fuzzy, gcc-internal-format
-#| msgid "destructors may not be cv-qualified"
+#: cp/decl.c:11286
+#, gcc-internal-format
 msgid "constructors may not be ref-qualified"
-msgstr "деструкторы не могут быть cv-квалифицированы"
+msgstr "конструкторы не могут быть ref-квалифицированы"
 
-#: cp/decl.c:11280
-#, fuzzy, gcc-internal-format
-#| msgid "constructors cannot be declared virtual"
+#: cp/decl.c:11304
+#, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
-msgstr "конструкторы нельзя декларировать как virtual"
+msgstr "конструкторы не могут быть декларированы %<virtual%>"
 
 #. Cannot be both friend and virtual.
-#: cp/decl.c:11295
+#: cp/decl.c:11319
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "виртуальные функции не могут быть friend-функциями"
 
-#: cp/decl.c:11299
+#: cp/decl.c:11323
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "friend-декларация вне определения класса"
 
-#: cp/decl.c:11301
+#: cp/decl.c:11325
 #, gcc-internal-format
 msgid "can%'t define friend function %qs in a local class definition"
 msgstr "невозможно определить friend-функцию %qs в определении локального класса"
 
-#: cp/decl.c:11313
-#, fuzzy, gcc-internal-format
-#| msgid "%qs function cannot have arguments"
+#: cp/decl.c:11337
+#, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
-msgstr "%qs функция не может иметь аргументы"
+msgstr "функция преобразования не может иметь завершающий тип возврата"
 
-#: cp/decl.c:11339
+#: cp/decl.c:11363
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "деструкторы не могут иметь параметров"
 
-#: cp/decl.c:11379
+#: cp/decl.c:11403
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "недопустимая декларация указателя на %q#T"
 
-#: cp/decl.c:11392 cp/decl.c:11399
+#: cp/decl.c:11416 cp/decl.c:11423
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "недопустимая декларация ссылки на %q#T"
 
-#: cp/decl.c:11401
+#: cp/decl.c:11425
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "недопустимая декларация указателя на элемент %q#T"
 
-#: cp/decl.c:11430
+#: cp/decl.c:11454
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "невозможно декларировать ссылку на квалифицированный тип функции %qT"
 
-#: cp/decl.c:11431
+#: cp/decl.c:11455
 #, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "невозможно декларировать указатель на квалифицированный тип функции %qT"
 
-#: cp/decl.c:11504
+#: cp/decl.c:11528
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr "Недопустимо определять ссылку на %q#T, которая не будет определением типа или аргументом шаблона"
 
-#: cp/decl.c:11574
+#: cp/decl.c:11598
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "идентификатор шаблона %qD использован как декларатор"
 
-#: cp/decl.c:11599
+#: cp/decl.c:11623
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "элементы-функции неявно считаются friend-функциями своего класса"
 
-#: cp/decl.c:11605
+#: cp/decl.c:11629
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "избыточная квалификация %<%T::%> элемента %qs"
 
-#: cp/decl.c:11635
-#, fuzzy, gcc-internal-format
-#| msgid "cannot define member function %<%T::%s%> within %<%T%>"
+#: cp/decl.c:11659
+#, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
-msgstr "недопустимая декларация элемента-функции %<%T::%s%> внутри %<%T%>"
+msgstr ""
 
-#: cp/decl.c:11637
-#, fuzzy, gcc-internal-format
-#| msgid "cannot declare member function %<%T::%s%> within %<%T%>"
+#: cp/decl.c:11661
+#, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
-msgstr "невозможно декларировать элемент-функцию %<%T::%s%> внутри %<%T%>"
+msgstr ""
 
-#: cp/decl.c:11645
+#: cp/decl.c:11669
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "недопустимая декларация элемента %<%T::%s%> внутри %qT"
 
-#: cp/decl.c:11685
+#: cp/decl.c:11709
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "не параметрический %qs не может содержать параметры"
 
-#: cp/decl.c:11693
+#: cp/decl.c:11717
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "элемент данных не может иметь тип %qT модифицируемого размера"
 
-#: cp/decl.c:11695
+#: cp/decl.c:11719
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "параметр не может иметь модифицированный тип `%T"
 
-#: cp/decl.c:11706
-#, fuzzy, gcc-internal-format
-#| msgid "%<virtual%> outside class declaration"
+#: cp/decl.c:11730
+#, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
-msgstr "%<virtual%> вне декларации класса"
+msgstr "%<explicit%> вне декларации класса"
 
-#: cp/decl.c:11709
-#, fuzzy, gcc-internal-format
-#| msgid "%<inline%> in empty declaration"
+#: cp/decl.c:11733
+#, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
-msgstr "%<inline%> в пустой декларации"
+msgstr "%<explicit%> в friend декларации"
 
-#: cp/decl.c:11712
-#, fuzzy, gcc-internal-format
-#| msgid "only declarations of constructors can be %<explicit%>"
+#: cp/decl.c:11736
+#, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
-msgstr "только декларации конструкторов могут быть %<explicit%>"
+msgstr "только декларации конструкторов и операторов преобразования могут быть %<explicit%>"
 
-#: cp/decl.c:11721
+#: cp/decl.c:11745
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "недопустимая декларация не-элемента %qs как %<mutable%>"
 
-#: cp/decl.c:11726
+#: cp/decl.c:11750
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "недопустимая декларация не объектного элемента %qs как %<mutable%>"
 
-#: cp/decl.c:11732
+#: cp/decl.c:11756
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "недопустимая декларация функции %qs как %<mutable%>"
 
-#: cp/decl.c:11737
+#: cp/decl.c:11761
 #, gcc-internal-format
 msgid "static %qs cannot be declared %<mutable%>"
 msgstr "недопустимая декларация статического %qs как %<mutable%>"
 
-#: cp/decl.c:11742
+#: cp/decl.c:11766
 #, gcc-internal-format
 msgid "const %qs cannot be declared %<mutable%>"
 msgstr "недопустимая декларация константного %qs как %<mutable%>"
 
-#: cp/decl.c:11747
+#: cp/decl.c:11771
 #, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "ссылка %qs не может быть декларирована %<mutable%>"
 
-#: cp/decl.c:11778
+#: cp/decl.c:11802
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "typedef декларирован %<auto%>"
 
-#: cp/decl.c:11783
+#: cp/decl.c:11807
 #, gcc-internal-format
 msgid "requires-clause on typedef"
-msgstr ""
+msgstr "requires-клаузула для typedef"
 
-#: cp/decl.c:11787
+#: cp/decl.c:11811
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "typedef имя не может быть вложенным спецификатором имени"
 
-#: cp/decl.c:11813
+#: cp/decl.c:11837
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ISO C++ запрещает определять вложенный тип %qD с тем же именем, что и объемлющий класс"
 
-#: cp/decl.c:11900
+#: cp/decl.c:11924
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "в декларации friend-класса использован квалификатор %<inline%>"
 
-#: cp/decl.c:11908
+#: cp/decl.c:11932
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "параметры шаблона не могут быть friend"
 
-#: cp/decl.c:11910
+#: cp/decl.c:11934
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "в friend-декларации требуется указание класса: %<friend class %T::%D%>"
 
-#: cp/decl.c:11914
+#: cp/decl.c:11938
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "в friend-декларации требуется указание класса: %<friend %#T%>"
 
-#: cp/decl.c:11927
+#: cp/decl.c:11951
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "попытка сделать класс %qT \"другом\" глобальной области видимости"
 
-#: cp/decl.c:11947
+#: cp/decl.c:11971
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "некорректные квалификаторы для типа функции, не являющейся элементом"
 
-#: cp/decl.c:11951
+#: cp/decl.c:11975
 #, gcc-internal-format
 msgid "requires-clause on type-id"
-msgstr ""
+msgstr "requires-клаузула для идентификатора типа"
 
-#: cp/decl.c:11961
+#: cp/decl.c:11985
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "абстрактный декларатор %qT использован в качестве декларатора"
 
-#: cp/decl.c:11976
-#, fuzzy, gcc-internal-format
-#| msgid "value-initialization of function type %qT"
+#: cp/decl.c:12000
+#, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
-msgstr "инициализация значения функционального типа %qT"
+msgstr "requires-клаузула в декларации нефункционального типа %qT"
 
-#: cp/decl.c:11995
+#: cp/decl.c:12019
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "недопустимое использование %<::%> в декларации параметра"
 
-#: cp/decl.c:12001
-#, fuzzy, gcc-internal-format
-#| msgid "%<this%> may not be used in this context"
+#: cp/decl.c:12025
+#, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
-msgstr "%<this%> недопустим в данном контексте"
+msgstr "%<auto%> параметр недопустим в данном контексте"
 
-#: cp/decl.c:12003
+#: cp/decl.c:12027
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "параметр декларирован %<auto%>"
 
-#: cp/decl.c:12052 cp/parser.c:3270
+#: cp/decl.c:12076 cp/parser.c:3270
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "некорректное использование имени шаблона %qE без списка аргументов"
 
-#: cp/decl.c:12056
-#, fuzzy, gcc-internal-format
-#| msgid "non-static data member declared %<auto%>"
+#: cp/decl.c:12080
+#, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
-msgstr "нестатический элемент данных декларирован %<auto%>"
+msgstr "нестатический элемент данных декларирован с заполнителем %qT"
 
-#: cp/decl.c:12080
-#, fuzzy, gcc-internal-format
-#| msgid "ISO C++ forbids zero-size array %qD"
+#: cp/decl.c:12104
+#, gcc-internal-format
 msgid "ISO C++ forbids flexible array member %qs"
-msgstr "ISO C++ запрещает массив нулевого размера %qD"
+msgstr "ISO C++ запрещает элемент регулируемый массив %qs"
 
-#: cp/decl.c:12083
-#, fuzzy, gcc-internal-format
-#| msgid "ISO C90 does not support flexible array members"
+#: cp/decl.c:12107
+#, gcc-internal-format
 msgid "ISO C++ forbids flexible array members"
-msgstr "ISO C90 не поддерживает регулируемые элементы-массивы"
+msgstr "ISO C++ запрещает элементы регулируемые массивы"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:12099
+#: cp/decl.c:12123
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "недопустимое использование %<::%>"
 
-#: cp/decl.c:12121
+#: cp/decl.c:12145
 #, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "декларация функции %qD в неверном контексте"
 
-#: cp/decl.c:12130
-#, fuzzy, gcc-internal-format
-#| msgid "function %qD declared virtual inside a union"
+#: cp/decl.c:12154
+#, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
-msgstr "функция %qD объявлена виртуальной внутри объединения"
+msgstr "функция %qD декларирована %<virtual%> внутри объединения"
 
-#: cp/decl.c:12139
-#, fuzzy, gcc-internal-format
-#| msgid "%qD cannot be declared virtual, since it is always static"
+#: cp/decl.c:12163
+#, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
-msgstr "%qD не может быть объявлена виртуальной, поскольку она всегда статическая"
+msgstr "%qD не может быть декларирована %<virtual%>, поскольку она всегда статическая"
 
-#: cp/decl.c:12153
+#: cp/decl.c:12177
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "ожидалось квалифицированное имя в friend декларации для деструктора %qD"
 
-#: cp/decl.c:12160
+#: cp/decl.c:12184
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "декларация %qD как элемента %qT"
 
-#: cp/decl.c:12166
-#, fuzzy, gcc-internal-format
-#| msgid "a destructor cannot be %<constexpr%>"
+#: cp/decl.c:12190
+#, gcc-internal-format
 msgid "a destructor cannot be %<concept%>"
-msgstr "деструктор не может быть %<constexpr%>"
+msgstr "деструктор не может быть %<concept%>"
 
-#: cp/decl.c:12171
+#: cp/decl.c:12195
 #, gcc-internal-format
 msgid "a destructor cannot be %<constexpr%>"
 msgstr "деструктор не может быть %<constexpr%>"
 
-#: cp/decl.c:12177
+#: cp/decl.c:12201
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "ожидалось квалифицированное имя в friend декларации для конструктора %qD"
 
-#: cp/decl.c:12185
-#, fuzzy, gcc-internal-format
-#| msgid "a destructor cannot be %<constexpr%>"
+#: cp/decl.c:12209
+#, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
-msgstr "деструктор не может быть %<constexpr%>"
+msgstr "конструктор не может быть %<concept%>"
 
-#: cp/decl.c:12190
-#, fuzzy, gcc-internal-format
-#| msgid "constructor cannot be static member function"
+#: cp/decl.c:12214
+#, gcc-internal-format
 msgid "a concept cannot be a member function"
-msgstr "конструктор не может быть статической элементом-функцией"
+msgstr "concept не может быть элементом-функцией"
 
-#: cp/decl.c:12199
-#, fuzzy, gcc-internal-format
-#| msgid "variable %qD redeclared as function"
+#: cp/decl.c:12223
+#, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
-msgstr "переменная %qD повторно декларирована как функция"
+msgstr "специализация переменного шаблона %qD декларирована как функция"
 
-#: cp/decl.c:12202
-#, fuzzy, gcc-internal-format
-#| msgid "original type declared here"
+#: cp/decl.c:12226
+#, gcc-internal-format
 msgid "variable template declared here"
-msgstr "исходный тип объявлен здесь"
+msgstr "переменный шаблон декларирован здесь"
 
-#: cp/decl.c:12257
-#, fuzzy, gcc-internal-format
-#| msgid "field %qD has incomplete type"
+#: cp/decl.c:12281
+#, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
-msgstr "поле %qD имеет неполный тип"
+msgstr "поле %qD имеет неполный тип %qT"
 
-#: cp/decl.c:12262
+#: cp/decl.c:12286
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "имя %qT имеет неполный тип"
 
-#: cp/decl.c:12272
+#: cp/decl.c:12296
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE не является ни функцией, ни элементом-функцией; не может быть декларировано как friend"
 
-#: cp/decl.c:12318
-#, fuzzy, gcc-internal-format
-#| msgid "non-static data member %qE declared %<constexpr%>"
+#: cp/decl.c:12342
+#, gcc-internal-format
 msgid "static data member %qE declared %<concept%>"
-msgstr "нестатический элемент данных %qE объявлен как %<constexpr%>"
+msgstr "статический элемент данных %qE декларирован %<concept%>"
 
-#: cp/decl.c:12322
-#, fuzzy, gcc-internal-format
-#| msgid "constexpr static data member %qD must have an initializer"
+#: cp/decl.c:12346
+#, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
-msgstr "constexpr статический элемент данных %qD должен иметь инициализатор"
+msgstr ""
 
-#: cp/decl.c:12350
-#, fuzzy, gcc-internal-format
-#| msgid "non-static data member %qE declared %<constexpr%>"
+#: cp/decl.c:12374
+#, gcc-internal-format
 msgid "non-static data member %qE declared %<concept%>"
-msgstr "нестатический элемент данных %qE объявлен как %<constexpr%>"
+msgstr "нестатический элемент данных %qE декларирован %<concept%>"
 
-#: cp/decl.c:12354
+#: cp/decl.c:12378
 #, gcc-internal-format
 msgid "non-static data member %qE declared %<constexpr%>"
 msgstr "нестатический элемент данных %qE объявлен как %<constexpr%>"
 
-#: cp/decl.c:12409
+#: cp/decl.c:12433
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "некорректный класс хранения %<auto%> для функции %qs"
 
-#: cp/decl.c:12411
+#: cp/decl.c:12435
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "некорректный класс хранения %<register%> для функции %qs"
 
-#: cp/decl.c:12415
+#: cp/decl.c:12439
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "некорректный класс хранения %<__thread%> для функции %qs"
 
-#: cp/decl.c:12418
-#, fuzzy, gcc-internal-format
-#| msgid "storage class %<__thread%> invalid for function %qs"
+#: cp/decl.c:12442
+#, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
-msgstr "некорректный класс хранения %<__thread%> для функции %qs"
+msgstr "класс хранения %<__thread_local%> некорректен для функции %qs"
 
-#: cp/decl.c:12423
+#: cp/decl.c:12447
 #, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "virt-спецификаторы в %qs не допускаются вне определения класса"
 
-#: cp/decl.c:12434
-#, fuzzy, gcc-internal-format
-#| msgid "%<static%> specified invalid for function %qs declared out of global scope"
+#: cp/decl.c:12458
+#, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
-msgstr "некорректно указано %<static%> для функции %qs, объявленной вне глобальной области видимости"
+msgstr "%<static%> спецификатор некорректен для функции %qs декларированной вне глобального контекста"
 
-#: cp/decl.c:12438
+#: cp/decl.c:12462
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "некорректно указано %<inline%> для функции %qs, объявленной вне глобальной области видимости"
 
-#: cp/decl.c:12446
+#: cp/decl.c:12470
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "виртуальная функция %qs не является элементом класса"
 
-#: cp/decl.c:12453
+#: cp/decl.c:12477
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "%qs определен не в контексте класса"
 
-#: cp/decl.c:12454
+#: cp/decl.c:12478
 #, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "%qs декларирован не в контексте класса"
 
-#: cp/decl.c:12489
+#: cp/decl.c:12513
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "недопустимая декларация статического элемента-функции %qD"
@@ -47942,82 +42381,79 @@
 
 #. 7.1.1: There can be no static function declarations within a
 #. block.
-#: cp/decl.c:12497
+#: cp/decl.c:12521
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "недопустимая декларация статической функции внутри другой функции"
 
-#: cp/decl.c:12533
+#: cp/decl.c:12557
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "слово %<static%> недопустимо при определении (в отличие от объявления) статического элемента данных в классе"
 
-#: cp/decl.c:12540
+#: cp/decl.c:12564
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "статический элемент %qD объявлен как %<register%>"
 
-#: cp/decl.c:12546
+#: cp/decl.c:12570
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "недопустимая явная extern-декларация элемента %q#D"
 
-#: cp/decl.c:12553
-#, fuzzy, gcc-internal-format
-#| msgid "declaration of constexpr variable %qD is not a definition"
+#: cp/decl.c:12577
+#, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
-msgstr "декларация constexpr переменной %qD не является определением"
+msgstr ""
 
-#: cp/decl.c:12574
+#: cp/decl.c:12598
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "декларация %q#D не имеет инициализатора"
 
-#: cp/decl.c:12585
+#: cp/decl.c:12609
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%<extern%> декларация %qs с инициализацией"
 
-#: cp/decl.c:12589
+#: cp/decl.c:12613
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "для %qs задан спецификатор %<extern%> и инициализатор"
 
-#: cp/decl.c:12754
+#: cp/decl.c:12778
 #, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "аргумент по умолчанию %qE использует %qD"
 
-#: cp/decl.c:12757
+#: cp/decl.c:12781
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "аргумент по умолчанию %qE использует локальную переменную %qD"
 
 #
-#: cp/decl.c:12841
-#, fuzzy, gcc-internal-format
-#| msgid "invalid use of %<virtual%> in template declaration of %q#D"
+#: cp/decl.c:12865
+#, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
-msgstr "некорректное использование %<virtual%> в декларации шаблона %q#D"
+msgstr "некорректное использование cv-квалифицированного типа %qT в декларации параметра"
 
 #
-#: cp/decl.c:12845
-#, fuzzy, gcc-internal-format
-#| msgid "invalid use of %<virtual%> in template declaration of %q#D"
+#: cp/decl.c:12869
+#, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
-msgstr "некорректное использование %<virtual%> в декларации шаблона %q#D"
+msgstr "некорректное использование типа %<void%> в декларации параметра"
 
-#: cp/decl.c:12868
+#: cp/decl.c:12892
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "некорректная декларация параметра %qD с типом метода"
 
-#: cp/decl.c:12895
+#: cp/decl.c:12919
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "параметр %qD включает указатель на массив с неизвестной границей %qT"
 
-#: cp/decl.c:12897
+#: cp/decl.c:12921
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "параметр %qD включает ссылку на массив с неизвестной границей %qT"
@@ -48037,177 +42473,169 @@
 #. or implicitly defined), there's no need to worry about their
 #. existence.  Theoretically, they should never even be
 #. instantiated, but that's hard to forestall.
-#: cp/decl.c:13150
+#: cp/decl.c:13174
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "некорректный конструктор; возможно, вы имели в виду %<%T (const %T&)%>"
 
-#: cp/decl.c:13228
+#: cp/decl.c:13252
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "декларация %qD может не действовать в пространстве имён"
 
-#: cp/decl.c:13234
+#: cp/decl.c:13258
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD можно не определять статической"
 
-#: cp/decl.c:13261
+#: cp/decl.c:13285
 #, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr "%qD должен быть нестатической элементом-функцией"
 
-#: cp/decl.c:13267
+#: cp/decl.c:13291
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD должен быть либо нестатическим элементом-функцией или функцией-не-элементом"
 
-#: cp/decl.c:13277
+#: cp/decl.c:13301
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD должен иметь аргумент типа класс или перечислимого типа"
 
 #. 13.4.0.3
-#: cp/decl.c:13303
+#: cp/decl.c:13327
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading operator ?:"
 msgstr "ISO C++ не поддерживает перегрузку операции ?:"
 
 #. Variadic.
-#: cp/decl.c:13314
+#: cp/decl.c:13338
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD не может иметь переменное число аргументов"
 
-#: cp/decl.c:13338
-#, fuzzy, gcc-internal-format
-#| msgid "%qD must take either zero or one argument"
+#: cp/decl.c:13362
+#, gcc-internal-format
 msgid "%qD must have either zero or one argument"
-msgstr "%qD должен иметь не более одного аргумента"
+msgstr ""
 
-#: cp/decl.c:13339
-#, fuzzy, gcc-internal-format
-#| msgid "%qD must take either one or two arguments"
+#: cp/decl.c:13363
+#, gcc-internal-format
 msgid "%qD must have either one or two arguments"
-msgstr "%qD должен иметь один или два аргумента"
+msgstr ""
 
-#: cp/decl.c:13350
-#, fuzzy, gcc-internal-format
-#| msgid "postfix %qD must take %<int%> as its argument"
+#: cp/decl.c:13374
+#, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its argument"
-msgstr "постфиксный %qD должен иметь аргумент типа %<int%>"
+msgstr ""
 
-#: cp/decl.c:13351
-#, fuzzy, gcc-internal-format
-#| msgid "postfix %qD must take %<int%> as its second argument"
+#: cp/decl.c:13375
+#, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its second argument"
-msgstr "постфиксный %qD должен иметь второй аргумент типа %<int%>"
+msgstr ""
 
-#: cp/decl.c:13361
-#, fuzzy, gcc-internal-format
-#| msgid "%qD must take exactly two arguments"
+#: cp/decl.c:13385
+#, gcc-internal-format
 msgid "%qD must have no arguments"
-msgstr "%qD должен иметь ровно два аргумента"
+msgstr ""
 
-#: cp/decl.c:13362 cp/decl.c:13371
-#, fuzzy, gcc-internal-format
-#| msgid "%qD must take exactly one argument"
+#: cp/decl.c:13386 cp/decl.c:13395
+#, gcc-internal-format
 msgid "%qD must have exactly one argument"
-msgstr "%qD должен иметь ровно один аргумент"
+msgstr ""
 
-#: cp/decl.c:13372
-#, fuzzy, gcc-internal-format
-#| msgid "%qD must take exactly two arguments"
+#: cp/decl.c:13396
+#, gcc-internal-format
 msgid "%qD must have exactly two arguments"
-msgstr "%qD должен иметь ровно два аргумента"
+msgstr ""
 
-#: cp/decl.c:13389 cp/decl.c:13392
+#: cp/decl.c:13413 cp/decl.c:13416
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD не может иметь аргументов по умолчанию"
 
-#: cp/decl.c:13419
+#: cp/decl.c:13443
 #, gcc-internal-format
 msgid "conversion to a reference to void will never use a type conversion operator"
 msgstr "преобразование к ссылке на void никогда не будет использовать операцию преобразования типа"
 
-#: cp/decl.c:13421
+#: cp/decl.c:13445
 #, gcc-internal-format
 msgid "conversion to void will never use a type conversion operator"
 msgstr "преобразование к void никогда не использует операцию преобразования типа"
 
-#: cp/decl.c:13428
+#: cp/decl.c:13452
 #, gcc-internal-format
 msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgstr "преобразование к ссылке на тот же тип никогда не будет использовать операцию преобразования типа"
 
-#: cp/decl.c:13430
+#: cp/decl.c:13454
 #, gcc-internal-format
 msgid "conversion to the same type will never use a type conversion operator"
 msgstr "преобразование к тому же типу никогда не будет использовать операцию преобразования типа"
 
-#: cp/decl.c:13438
+#: cp/decl.c:13462
 #, gcc-internal-format
 msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgstr "преобразование к ссылке на базовый класс никогда не будет использовать операцию преобразования типа"
 
-#: cp/decl.c:13440
+#: cp/decl.c:13464
 #, gcc-internal-format
 msgid "conversion to a base class will never use a type conversion operator"
 msgstr "преобразование к базовому классу никогда не будет использовать операцию преобразования типа"
 
-#: cp/decl.c:13455
+#: cp/decl.c:13479
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "пользовательский оператор %qD всегда вычисляет оба аргумента"
 
-#: cp/decl.c:13474
+#: cp/decl.c:13498
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "префиксный %qD должен возвращать %qT"
 
-#: cp/decl.c:13480
+#: cp/decl.c:13504
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "постфиксный %qD должен возвращать %qT"
 
-#: cp/decl.c:13492
+#: cp/decl.c:13516
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD должен возвращать результат по значению"
 
-#: cp/decl.c:13547
+#: cp/decl.c:13571
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "использование параметра шаблона %qT после %qs"
 
-#: cp/decl.c:13570
+#: cp/decl.c:13594
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "использование синонима специализации шаблона %qT после %qs"
 
-#: cp/decl.c:13573
+#: cp/decl.c:13597
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "использование typedef-имени %qD после %qs"
 
-#: cp/decl.c:13575
+#: cp/decl.c:13599
 #, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "%qD ранее декларирован здесь"
 
-#: cp/decl.c:13583
+#: cp/decl.c:13607
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "ссылка на %qT как на %qs"
 
-#: cp/decl.c:13584 cp/decl.c:13591
-#, fuzzy, gcc-internal-format
-#| msgid "%q+T has a previous declaration here"
+#: cp/decl.c:13608 cp/decl.c:13615
+#, gcc-internal-format
 msgid "%qT has a previous declaration here"
-msgstr "%q+T ранее декларирован здесь"
+msgstr "%qT ранее декларирован здесь"
 
-#: cp/decl.c:13590
+#: cp/decl.c:13614
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "ссылка на %qT как на enum"
@@ -48219,184 +42647,176 @@
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:13605
+#: cp/decl.c:13629
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "для %<%s %T%> нужен аргумент-шаблон"
 
-#: cp/decl.c:13659 cp/name-lookup.c:4652
+#: cp/decl.c:13683 cp/name-lookup.c:4652
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD имеет то же имя, что и класс, в котором он(а) декларируется"
 
-#: cp/decl.c:13689 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6425
-#: cp/pt.c:9209
+#: cp/decl.c:13713 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6428
+#: cp/pt.c:9223
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT не является шаблоном"
 
-#: cp/decl.c:13694
+#: cp/decl.c:13718
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
-msgstr ""
+msgstr "возможно вы хотите явно добавить %<%T::%>"
 
-#: cp/decl.c:13703 cp/name-lookup.c:4079 cp/name-lookup.c:4086
-#: cp/name-lookup.c:4939 cp/parser.c:6376 cp/parser.c:26300
+#: cp/decl.c:13727 cp/name-lookup.c:4079 cp/name-lookup.c:4086
+#: cp/name-lookup.c:4939 cp/parser.c:6379 cp/parser.c:26297
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "ссылка на %qD противоречива"
 
-#: cp/decl.c:13806
+#: cp/decl.c:13830
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "использование перечисления %q#D без предыдущей декларации"
 
-#: cp/decl.c:13842
+#: cp/decl.c:13866
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "повторная декларация %qT как не-шаблона"
 
-#: cp/decl.c:13982
+#: cp/decl.c:14006
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "некорректный производный тип union %qT"
 
-#: cp/decl.c:13989
+#: cp/decl.c:14013
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
-msgstr ""
+msgstr "%qT определен с многими непосредственными базами"
 
-#: cp/decl.c:14000
-#, fuzzy, gcc-internal-format
-#| msgid "type %qT is not a direct or virtual base of %qT"
+#: cp/decl.c:14024
+#, gcc-internal-format
 msgid "%qT defined with direct virtual base"
-msgstr "тип %qT не является непосредственной или виртуальной базой %qT"
+msgstr "%qT определен с непосредственной виртуальной базой"
 
-#: cp/decl.c:14025
+#: cp/decl.c:14049
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "базовый тип %qT не является ни структурой, ни классом"
 
-#: cp/decl.c:14055
+#: cp/decl.c:14079
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "рекурсивный тип %qT не определён"
 
-#: cp/decl.c:14057
+#: cp/decl.c:14081
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "некорректное дублирование базового типа %qT"
 
-#: cp/decl.c:14202
+#: cp/decl.c:14226
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr "scoped/unscoped рассогласование в enum %q#T"
 
-#: cp/decl.c:14205 cp/decl.c:14213 cp/decl.c:14225 cp/parser.c:18284
+#: cp/decl.c:14229 cp/decl.c:14237 cp/decl.c:14249 cp/parser.c:18281
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "предыдущее определение здесь"
 
-#: cp/decl.c:14210
+#: cp/decl.c:14234
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr "рассогласование основного типа в enum %q#T"
 
-#: cp/decl.c:14222
+#: cp/decl.c:14246
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr "отличающийся основной тип в enum %q#T"
 
-#: cp/decl.c:14300
-#, fuzzy, gcc-internal-format
-#| msgid "underlying type %<%T%> of %<%T%> must be an integral type"
+#: cp/decl.c:14324
+#, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
-msgstr "основной тип %<%T%> %<%T%> должен быть целочисленным типом"
+msgstr ""
 
 #. DR 377
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:14447
+#: cp/decl.c:14471
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "ни один целочисленный тип не годится для представления всех значений перечислимого типа %qT"
 
-#: cp/decl.c:14619
-#, fuzzy, gcc-internal-format
-#| msgid "enumerator value for %qD is not an integer constant"
+#: cp/decl.c:14643
+#, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
-msgstr "значение перечислимого типа для %qD не является константой целого типа"
+msgstr "значение перечислимого типа для %qD должно иметь целочисленный или unscoped перечислимый тип"
 
-#: cp/decl.c:14629
+#: cp/decl.c:14653
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "значение перечислимого типа для %qD не является константой целого типа"
 
-#: cp/decl.c:14678
+#: cp/decl.c:14702
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "увеличенное значение перечисления слишком велико для %<unsigned long%>"
 
-#: cp/decl.c:14679
-#, fuzzy, gcc-internal-format
-#| msgid "incremented enumerator value is too large for %<unsigned long%>"
+#: cp/decl.c:14703
+#, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
-msgstr "увеличенное значение перечисления слишком велико для %<unsigned long%>"
+msgstr "увеличенное значение перечисления слишком велико для %<long%>"
 
-#: cp/decl.c:14690
+#: cp/decl.c:14714
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "переполнение в перечисляемых значениях для %qD"
 
-#: cp/decl.c:14710
-#, fuzzy, gcc-internal-format
-#| msgid "enumerator value %E is too large for underlying type %<%T%>"
+#: cp/decl.c:14734
+#, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
-msgstr "значение перечисления %qE слишком велико для основного типа %<%T%>"
+msgstr ""
 
-#: cp/decl.c:14821
+#: cp/decl.c:14845
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "тип результата %q#T неполный"
 
-#: cp/decl.c:14999 cp/typeck.c:9286
+#: cp/decl.c:15023 cp/typeck.c:9286
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> должен возвращать ссылку на %<*this%>"
 
-#: cp/decl.c:15344
+#: cp/decl.c:15368
 #, gcc-internal-format
 msgid "invalid function declaration"
 msgstr "некорректная декларация функции"
 
-#: cp/decl.c:15786
-#, fuzzy, gcc-internal-format
-#| msgid "no return statement in function returning non-void"
+#: cp/decl.c:15810
+#, gcc-internal-format
 msgid "no return statements in function returning %qT"
-msgstr "в функции, которая должна возвращать значение, отсутствует оператор return"
+msgstr "нет операторов возврата в функции возвращающей %qT"
 
-#: cp/decl.c:15788 cp/typeck.c:9166
-#, fuzzy, gcc-internal-format
-#| msgid "function return types not compatible due to %<volatile%>"
+#: cp/decl.c:15812 cp/typeck.c:9166
+#, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
-msgstr "типы возвращаемых значений функции несовместимы из-за %<volatile%>"
+msgstr "только плоский %<auto%> тип возврата может быть приведен к %<void%>"
 
-#: cp/decl.c:15996
+#: cp/decl.c:16020
 #, gcc-internal-format
 msgid "invalid member function declaration"
 msgstr "некорректная декларация элемента-функции"
 
-#: cp/decl.c:16010
+#: cp/decl.c:16034
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD уже определена в классе %qT"
 
-#: cp/decl.c:16386
-#, fuzzy, gcc-internal-format
-#| msgid "type of %qD defaults to %<int%>"
+#: cp/decl.c:16410
+#, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
-msgstr "по умолчанию для %qD принят тип %<int%>"
+msgstr "использование %qD до приведения %<auto%>"
 
 #: cp/decl2.c:372
 #, gcc-internal-format
@@ -48414,10 +42834,9 @@
 msgstr "некорректные типы %<%T[%T]%> для индекса массива"
 
 #: cp/decl2.c:511
-#, fuzzy, gcc-internal-format
-#| msgid "deleting array %q#D"
+#, gcc-internal-format
 msgid "deleting array %q#E"
-msgstr "удаление массива %q#D"
+msgstr "удаление массива %q#E"
 
 #: cp/decl2.c:517
 #, gcc-internal-format
@@ -48427,7 +42846,7 @@
 #: cp/decl2.c:529
 #, gcc-internal-format
 msgid "cannot delete a function.  Only pointer-to-objects are valid arguments to %<delete%>"
-msgstr "удаление функции недопустимо.  Аргументами %<delete%> могут быть только указатели на объекты"
+msgstr ""
 
 #: cp/decl2.c:537
 #, gcc-internal-format
@@ -48434,7 +42853,7 @@
 msgid "deleting %qT is undefined"
 msgstr "удаление %qT не определено"
 
-#: cp/decl2.c:585 cp/pt.c:5552
+#: cp/decl2.c:585 cp/pt.c:5566
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "шаблонная декларация %q#D"
@@ -48447,16 +42866,15 @@
 #. [temp.mem]
 #.
 #. A destructor shall not be a member template.
-#: cp/decl2.c:640 cp/pt.c:5511
+#: cp/decl2.c:640 cp/pt.c:5525
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "деструктор %qD объявлен как шаблон элемента"
 
 #: cp/decl2.c:714
-#, fuzzy, gcc-internal-format
-#| msgid "global declaration %q+#D"
+#, gcc-internal-format
 msgid "no declaration matches %q#D"
-msgstr "глобальная декларация %q+#D"
+msgstr ""
 
 #: cp/decl2.c:719
 #, gcc-internal-format
@@ -48464,16 +42882,14 @@
 msgstr ""
 
 #: cp/decl2.c:722
-#, fuzzy, gcc-internal-format
-#| msgid "In function %qs"
+#, gcc-internal-format
 msgid "no functions named %qD"
-msgstr "В функции %qs"
+msgstr ""
 
 #: cp/decl2.c:724
-#, fuzzy, gcc-internal-format
-#| msgid "label %qD defined here"
+#, gcc-internal-format
 msgid "%#qT defined here"
-msgstr "метка %qD определена здесь"
+msgstr ""
 
 #: cp/decl2.c:778
 #, gcc-internal-format
@@ -48481,16 +42897,14 @@
 msgstr "локальный класс %q#T не должен иметь статический элемент данных %q#D"
 
 #: cp/decl2.c:786
-#, fuzzy, gcc-internal-format
-#| msgid "non-static data member %qD has Java class type"
+#, gcc-internal-format
 msgid "static data member %qD in unnamed class"
-msgstr "нестатический элемент данных %qD имеет тип Java класса"
+msgstr "статический элемент данных %qD в неименованном классе"
 
 #: cp/decl2.c:788
-#, fuzzy, gcc-internal-format
-#| msgid "union defined here"
+#, gcc-internal-format
 msgid "unnamed class defined here"
-msgstr "объединение определено здесь"
+msgstr "неименованный класс определен здесь"
 
 #: cp/decl2.c:856
 #, gcc-internal-format
@@ -48513,10 +42927,9 @@
 msgstr "некорректный инициализатор для элемента-функции %qD"
 
 #: cp/decl2.c:955
-#, fuzzy, gcc-internal-format
-#| msgid "initializer specified for static member function %qD"
+#, gcc-internal-format
 msgid "initializer specified for friend function %qD"
-msgstr "инициализатор задан для статического элемента функции %qD"
+msgstr "инициализатор задан для friend функции %qD"
 
 #: cp/decl2.c:958
 #, gcc-internal-format
@@ -48544,10 +42957,9 @@
 msgstr "недопустимая декларация битового поля %qD с типом функции"
 
 #: cp/decl2.c:1080
-#, fuzzy, gcc-internal-format
-#| msgid "cannot declare bit-field %qD with function type"
+#, gcc-internal-format
 msgid "cannot declare bit-field %qD with %<warn_if_not_aligned%> type"
-msgstr "недопустимая декларация битового поля %qD с типом функции"
+msgstr ""
 
 #: cp/decl2.c:1087
 #, gcc-internal-format
@@ -48565,10 +42977,9 @@
 msgstr "ширина битового поля %qD имеет нецелочисленный тип %qT"
 
 #: cp/decl2.c:1515
-#, fuzzy, gcc-internal-format
-#| msgid "%qD is not a static data member of a class template"
+#, gcc-internal-format
 msgid "%q+D static data member inside of declare target directive"
-msgstr "%qD не является статическим элементом данных шаблона класса"
+msgstr "%q+D статический элемент данных внутри declare target директивы"
 
 #: cp/decl2.c:1582
 #, gcc-internal-format
@@ -48576,22 +42987,19 @@
 msgstr "анонимная структура не внутри именованного типа"
 
 #: cp/decl2.c:1598
-#, fuzzy, gcc-internal-format
-#| msgid "%q+#D invalid; an anonymous union can only have non-static data members"
+#, gcc-internal-format
 msgid "%q#D invalid; an anonymous union can only have non-static data members"
-msgstr "%q+#D некорректно; анонимное объединение может иметь только нестатические элементы данных"
+msgstr "%q#D некорректно; анонимное объединение может иметь только нестатические элементы данных"
 
 #: cp/decl2.c:1605
-#, fuzzy, gcc-internal-format
-#| msgid "private member %q+#D in anonymous union"
+#, gcc-internal-format
 msgid "private member %q#D in anonymous union"
-msgstr "private-элемент %q+#D в анонимном объединении"
+msgstr "private-элемент %q#D в анонимном объединении"
 
 #: cp/decl2.c:1608
-#, fuzzy, gcc-internal-format
-#| msgid "protected member %q+#D in anonymous union"
+#, gcc-internal-format
 msgid "protected member %q#D in anonymous union"
-msgstr "protected-элемент %q+#D в анонимном объединении"
+msgstr "protected-элемент %q#D в анонимном объединении"
 
 #: cp/decl2.c:1673
 #, gcc-internal-format
@@ -48632,124 +43040,111 @@
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "%<operator delete%> имеет первый параметр типа %qT"
 
-#: cp/decl2.c:2660
-#, fuzzy, gcc-internal-format
-#| msgid "%qT has a field %qD whose type uses the anonymous namespace"
+#: cp/decl2.c:2650
+#, gcc-internal-format
 msgid "%qT has a field %qD whose type has no linkage"
-msgstr "%qT имеет поле %qD, использующее анонимное пространство имён"
+msgstr "%qT имеет поле %qD, тип которого не имеет привязки"
 
-#: cp/decl2.c:2664
-#, fuzzy, gcc-internal-format
-#| msgid "%qT has a field %qD whose type uses the anonymous namespace"
+#: cp/decl2.c:2654
+#, gcc-internal-format
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
-msgstr "%qT имеет поле %qD, использующее анонимное пространство имён"
+msgstr "%qT имеет поле %qD, тип которого зависит от типа %qT, который не имеет привязки"
 
-#: cp/decl2.c:2669
+#: cp/decl2.c:2659
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr "%qT имеет поле %qD, использующее анонимное пространство имён"
 
-#: cp/decl2.c:2677
+#: cp/decl2.c:2667
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr "%qT объявлен с большей областью видимости, чем тип его поля %qD"
 
-#: cp/decl2.c:2695
-#, fuzzy, gcc-internal-format
-#| msgid "%qT has a base %qT whose type uses the anonymous namespace"
+#: cp/decl2.c:2685
+#, gcc-internal-format
 msgid "%qT has a base %qT whose type has no linkage"
-msgstr "%qT наследован от %qT, использующего анонимное пространство имён"
+msgstr "%qT имеет базу %qT чей тип не имеет привязки"
 
-#: cp/decl2.c:2699
-#, fuzzy, gcc-internal-format
-#| msgid "%qT has a base %qT whose type uses the anonymous namespace"
+#: cp/decl2.c:2689
+#, gcc-internal-format
 msgid "%qT has a base %qT whose type depends on the type %qT which has no linkage"
-msgstr "%qT наследован от %qT, использующего анонимное пространство имён"
+msgstr "%qT имеет базу %qT чей тип зависит от типа %qT, который не имеет привязки"
 
-#: cp/decl2.c:2704
+#: cp/decl2.c:2694
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr "%qT наследован от %qT, использующего анонимное пространство имён"
 
-#: cp/decl2.c:2711
+#: cp/decl2.c:2701
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr "%qT объявлен с большей областью видимости, чем родитель %qT"
 
-#: cp/decl2.c:4309
-#, fuzzy, gcc-internal-format
-#| msgid "%q+#D, declared using anonymous type, is used but never defined"
+#: cp/decl2.c:4299
+#, gcc-internal-format
 msgid "%q#D, declared using unnamed type, is used but never defined"
-msgstr "%q+#D, декларированное посредством анонимного типа, используется, но не определяется"
+msgstr "%q#D, декларированное с использованием неименованного типа, используется, но не определяется"
 
 #. DRs 132, 319 and 389 seem to indicate types with
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4318
-#, fuzzy, gcc-internal-format
-#| msgid "anonymous type with no linkage used to declare variable %q#D with linkage"
+#: cp/decl2.c:4308
+#, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
-msgstr "анонимный тип без привязки использован для декларации переменной %q#D с привязкой"
+msgstr "неименованный тип без привязки использован для декларации переменной %q#D с привязкой"
 
-#: cp/decl2.c:4322
-#, fuzzy, gcc-internal-format
-#| msgid "anonymous type with no linkage used to declare function %q#D with linkage"
+#: cp/decl2.c:4312
+#, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
-msgstr "анонимный тип без привязки использован для декларации функции %q#D с привязкой"
+msgstr "неименованный тип без привязки использован для декларации функции %q#D с привязкой"
 
-#: cp/decl2.c:4326
-#, fuzzy, gcc-internal-format
-#| msgid "%q+#D does not refer to the unqualified type, so it is not used for linkage"
+#: cp/decl2.c:4316
+#, gcc-internal-format
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
-msgstr "%q+#D не ссылается на неквалифицированный тип, поэтому не используется для связывания"
+msgstr "%q#D не ссылается на неквалифицированный тип, поэтому не используется для привязки"
 
-#: cp/decl2.c:4334
-#, fuzzy, gcc-internal-format
-#| msgid "%q+#D, declared using local type %qT, is used but never defined"
+#: cp/decl2.c:4324
+#, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but never defined"
-msgstr "%q+#D, декларированное посредством локального типа %qT, используется, но не определяется"
+msgstr "%q#D, декларированное с использованием локального типа %qT, используется, но не определяется"
 
-#: cp/decl2.c:4338
+#: cp/decl2.c:4328
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr "тип %qT без привязки использован для декларации переменной %q#D с привязкой"
 
-#: cp/decl2.c:4341
+#: cp/decl2.c:4331
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "тип %qT без привязки использован для декларации функции %q#D с привязкой"
 
-#: cp/decl2.c:4529
-#, fuzzy, gcc-internal-format
-#| msgid "%q#D conflicts with a previous declaration"
+#: cp/decl2.c:4519
+#, gcc-internal-format
 msgid "mangling of %q#D as %qE conflicts with a previous mangle"
-msgstr "%q#D конфликтует с предыдущей декларацией"
+msgstr ""
 
-#: cp/decl2.c:4532
-#, fuzzy, gcc-internal-format
-#| msgid "previous declaration %q+#D"
+#: cp/decl2.c:4522
+#, gcc-internal-format
 msgid "previous mangling %q#D"
-msgstr "предыдущая декларация %q+#D"
+msgstr ""
 
-#: cp/decl2.c:4534
-#, fuzzy, gcc-internal-format
-#| msgid "-fabi-version=6 (or =0) avoids this error with a change in mangling"
+#: cp/decl2.c:4524
+#, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
-msgstr "-fabi-version=6 (или =0) избегает этой ошибки изменением в разборке"
+msgstr "более поздняя -fabi-version= (или =0) избегает этой ошибки изменением в разборке"
 
-#: cp/decl2.c:4606 cp/decl2.c:4609
+#: cp/decl2.c:4596 cp/decl2.c:4599
 #, gcc-internal-format
 msgid "the program should also define %qD"
-msgstr ""
+msgstr "программа должна также определять %qD"
 
-#: cp/decl2.c:4956
-#, fuzzy, gcc-internal-format
-#| msgid "inline function %q+D used but never defined"
+#: cp/decl2.c:4946
+#, gcc-internal-format
 msgid "inline function %qD used but never defined"
-msgstr "inline функция %q+D использована, но нигде не определена"
+msgstr "inline функция %qD использована, но нигде не определена"
 
-#: cp/decl2.c:5143
+#: cp/decl2.c:5133
 #, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr "отсутствует аргумент по умолчанию для параметра %P функции %q+#D"
@@ -48756,22 +43151,20 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5251
-#, fuzzy, gcc-internal-format
-#| msgid "converting lambda which uses %<...%> to function pointer"
+#: cp/decl2.c:5241
+#, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
-msgstr "преобразование lambda, использующей %<...%>, к указателю на функцию"
+msgstr ""
 
-#: cp/decl2.c:5254
+#: cp/decl2.c:5244
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "использование удаленной функции %qD"
 
-#: cp/decl2.c:5307
-#, fuzzy, gcc-internal-format
-#| msgid "using %<typename%> outside of template"
+#: cp/decl2.c:5297
+#, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
-msgstr "использование %<typename%> вне шаблона"
+msgstr ""
 
 #: cp/error.c:1523
 #, gcc-internal-format
@@ -48779,10 +43172,9 @@
 msgstr "с"
 
 #: cp/error.c:3689
-#, fuzzy, gcc-internal-format
-#| msgid "no arguments"
+#, gcc-internal-format
 msgid "(no argument)"
-msgstr "отсутствуют аргументы"
+msgstr ""
 
 #: cp/error.c:3781
 #, gcc-internal-format
@@ -48810,10 +43202,9 @@
 msgstr "lambda-выражения доступны только с -std=c++11 или -std=gnu++11"
 
 #: cp/error.c:4161
-#, fuzzy, gcc-internal-format
-#| msgid "C++0x auto only available with -std=c++11 or -std=gnu++11"
+#, gcc-internal-format
 msgid "C++11 auto only available with -std=c++11 or -std=gnu++11"
-msgstr "C++0x auto доступны только с -std=c++11 или -std=gnu++11"
+msgstr "C++11 auto доступно только с -std=c++11 или -std=gnu++11"
 
 #: cp/error.c:4165
 #, gcc-internal-format
@@ -48851,22 +43242,19 @@
 msgstr "делегирующие конструкторы доступны только с -std=c++11 или -std=gnu++11"
 
 #: cp/error.c:4199
-#, fuzzy, gcc-internal-format
-#| msgid "delegating constructors only available with -std=c++11 or -std=gnu++11"
+#, gcc-internal-format
 msgid "inheriting constructors only available with -std=c++11 or -std=gnu++11"
-msgstr "делегирующие конструкторы доступны только с -std=c++11 или -std=gnu++11"
+msgstr "наследуемые конструкторы доступны только с -std=c++11 или -std=gnu++11"
 
 #: cp/error.c:4204
-#, fuzzy, gcc-internal-format
-#| msgid "C++0x auto only available with -std=c++11 or -std=gnu++11"
+#, gcc-internal-format
 msgid "c++11 attributes only available with -std=c++11 or -std=gnu++11"
-msgstr "C++0x auto доступны только с -std=c++11 или -std=gnu++11"
+msgstr "C++11 атрибуты доступны только с -std=c++11 или -std=gnu++11"
 
 #: cp/error.c:4209
-#, fuzzy, gcc-internal-format
-#| msgid "user-defined literals only available with -std=c++11 or -std=gnu++11"
+#, gcc-internal-format
 msgid "ref-qualifiers only available with -std=c++11 or -std=gnu++11"
-msgstr "определенные пользователем литералы доступны только с -std=c++11 или -std=gnu++11"
+msgstr "ref-квалификаторы доступны только с -std=c++11 или -std=gnu++11"
 
 #: cp/error.c:4259
 #, gcc-internal-format
@@ -48909,22 +43297,19 @@
 msgstr "  в throw-выражении"
 
 #: cp/except.c:852
-#, fuzzy, gcc-internal-format
-#| msgid "cannot declare parameter %q+D to be of abstract type %qT"
+#, gcc-internal-format
 msgid "cannot declare catch parameter to be of rvalue reference type %qT"
-msgstr "невозможно декларировать параметр %q+D с абстрактным типом %qT"
+msgstr "невозможно декларировать catch параметр как rvalue тип ссылки %qT"
 
 #: cp/except.c:859
-#, fuzzy, gcc-internal-format
-#| msgid "cannot create type information for type %qT because it involves types of variable size"
+#, gcc-internal-format
 msgid "cannot throw expression of type %qT because it involves types of variable size"
-msgstr "невозможно создать информацию о типе для типа %qT поскольку он включает типы переменного размера"
+msgstr "невозможно throw выражение типа %qT, поскольку он включает типы переменного размера"
 
 #: cp/except.c:862
-#, fuzzy, gcc-internal-format
-#| msgid "cannot create type information for type %qT because it involves types of variable size"
+#, gcc-internal-format
 msgid "cannot catch type %qT because it involves types of variable size"
-msgstr "невозможно создать информацию о типе для типа %qT поскольку он включает типы переменного размера"
+msgstr "невозможно catch тип %qT, поскольку он включает типы переменного размера"
 
 #: cp/except.c:958
 #, gcc-internal-format
@@ -48947,10 +43332,9 @@
 msgstr "noexcept-expression приводится к %<false%> из-за вызова %qD"
 
 #: cp/except.c:1074
-#, fuzzy, gcc-internal-format
-#| msgid "but %q+D does not throw; perhaps it should be declared %<noexcept%>"
+#, gcc-internal-format
 msgid "but %qD does not throw; perhaps it should be declared %<noexcept%>"
-msgstr "но %q+D не делает throw; возможно его следует декларировать %<noexcept%>"
+msgstr "но %qD не делает throw; возможно его следует декларировать %<noexcept%>"
 
 #: cp/friend.c:192
 #, gcc-internal-format
@@ -48974,7 +43358,7 @@
 #: cp/friend.c:306
 #, gcc-internal-format
 msgid "perhaps you need explicit template arguments in your nested-name-specifier"
-msgstr ""
+msgstr "возможно вам нужны явные аргументы шаблона в вашем вложенном спецификаторе имени"
 
 #: cp/friend.c:318
 #, gcc-internal-format
@@ -49019,10 +43403,9 @@
 msgstr "%qT уже friend для %qT"
 
 #: cp/friend.c:485
-#, fuzzy, gcc-internal-format
-#| msgid "friend declaration %q#D declares a non-template function"
+#, gcc-internal-format
 msgid "friend declaration %qD may not have virt-specifiers"
-msgstr "friend декларация %q#D декларирует нешаблонную функцию"
+msgstr "friend декларация %qD не может иметь virt-спецификаторы"
 
 #: cp/friend.c:578
 #, gcc-internal-format
@@ -49061,356 +43444,337 @@
 
 #
 #: cp/init.c:566
-#, fuzzy, gcc-internal-format
-#| msgid "non-static data member initializers"
+#, gcc-internal-format
 msgid "recursive instantiation of default member initializer for %qD"
-msgstr "инициализаторы нестатических элементов данных"
+msgstr ""
 
-#: cp/init.c:613
+#: cp/init.c:629
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr ""
 
-#: cp/init.c:615
-#, fuzzy, gcc-internal-format
-#| msgid "union defined here"
+#: cp/init.c:631
+#, gcc-internal-format
 msgid "defined here"
-msgstr "объединение определено здесь"
+msgstr ""
 
-#: cp/init.c:673
-#, fuzzy, gcc-internal-format
-#| msgid "invalid initializer for array member %q#D"
+#: cp/init.c:689
+#, gcc-internal-format
 msgid "initializer for flexible array member %q#D"
-msgstr "некорректный инициализатор для элемента массива %q#D"
+msgstr "инициализатор для элемента регулируемого массива %q#D"
 
-#: cp/init.c:699
+#: cp/init.c:715
 #, gcc-internal-format
 msgid "%qD should be initialized in the member initialization list"
 msgstr "%qD следует инициализировать в списке инициализации элементов"
 
-#: cp/init.c:720
+#: cp/init.c:736
 #, gcc-internal-format
 msgid "%qD is initialized with itself"
 msgstr "%qD инициализируется самим собой"
 
-#: cp/init.c:831
+#: cp/init.c:847
 #, gcc-internal-format
 msgid "invalid initializer for array member %q#D"
 msgstr "некорректный инициализатор для элемента массива %q#D"
 
-#: cp/init.c:845 cp/init.c:869 cp/init.c:2410 cp/method.c:1368
+#: cp/init.c:861 cp/init.c:885 cp/init.c:2427 cp/method.c:1368
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr "неинициализированный const элемент в %q#T"
 
-#: cp/init.c:847 cp/init.c:864 cp/init.c:871 cp/init.c:2395 cp/init.c:2423
+#: cp/init.c:863 cp/init.c:880 cp/init.c:887 cp/init.c:2412 cp/init.c:2440
 #: cp/method.c:1371 cp/method.c:1382
-#, fuzzy, gcc-internal-format
-#| msgid "%qD should be initialized"
+#, gcc-internal-format
 msgid "%q#D should be initialized"
-msgstr "%qD должен быть инициализирован"
+msgstr "%q#D должен быть инициализирован"
 
-#: cp/init.c:862 cp/init.c:2382 cp/method.c:1379
+#: cp/init.c:878 cp/init.c:2399 cp/method.c:1379
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr "неинициализированный ссылочный элемент в %q#T"
 
-#: cp/init.c:1041
-#, fuzzy, gcc-internal-format
-#| msgid "%q+D will be initialized after"
+#: cp/init.c:1057
+#, gcc-internal-format
 msgid "%qD will be initialized after"
-msgstr "%q+D будет инициализирован после"
+msgstr "%qD будет инициализирован после"
 
-#: cp/init.c:1044
+#: cp/init.c:1060
 #, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr "базовый класс %qT будет инициализирован после"
 
-#: cp/init.c:1048
-#, fuzzy, gcc-internal-format
-#| msgid "  %q+#D"
+#: cp/init.c:1064
+#, gcc-internal-format
 msgid "  %q#D"
-msgstr "  %q+#D"
+msgstr "  %q#D"
 
-#: cp/init.c:1050
+#: cp/init.c:1066
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr "  базового класса %qT"
 
-#: cp/init.c:1052
+#: cp/init.c:1068
 #, gcc-internal-format
 msgid "  when initialized here"
 msgstr "  если инициализирован здесь"
 
-#: cp/init.c:1069
+#: cp/init.c:1085
 #, gcc-internal-format
 msgid "multiple initializations given for %qD"
 msgstr "повторные инициализации заданы для %qD"
 
-#: cp/init.c:1073
+#: cp/init.c:1089
 #, gcc-internal-format
 msgid "multiple initializations given for base %qT"
 msgstr "повторные инициализации заданы для базового класса %qT"
 
-#: cp/init.c:1158
+#: cp/init.c:1174
 #, gcc-internal-format
 msgid "initializations for multiple members of %qT"
 msgstr "инициализации для нескольких элементов %qT"
 
-#: cp/init.c:1255
+#: cp/init.c:1271
 #, gcc-internal-format
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr "базовый класс %q#T должен быть явно инициализирован в копирующем конструкторе"
 
-#: cp/init.c:1482 cp/init.c:1501
+#: cp/init.c:1498 cp/init.c:1517
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr "в классе %qT нет поля с именем %qD"
 
-#: cp/init.c:1488
+#: cp/init.c:1504
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr "%q#D есть статический элемент данных; он может быть инициализирован только при своем определении"
 
-#: cp/init.c:1495
+#: cp/init.c:1511
 #, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr "%q#D не есть нестатический элемент данных %qT"
 
-#: cp/init.c:1534
+#: cp/init.c:1550
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr "безымянный инициализатор для %qT, не имеющего базовых классов"
 
-#: cp/init.c:1542
+#: cp/init.c:1558
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr "безымянный инициализатор для %qT, имеющего множественное наследование"
 
-#: cp/init.c:1589
+#: cp/init.c:1605
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr "%qD - непосредственный базовый тип, а также косвенный виртуальный базовый тип"
 
-#: cp/init.c:1597
+#: cp/init.c:1613
 #, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr "тип %qT не является непосредственной или виртуальной базой %qT"
 
-#: cp/init.c:1600
+#: cp/init.c:1616
 #, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr "тип %qT не является непосредственной базой %qT"
 
-#: cp/init.c:1710 cp/init.c:4386 cp/typeck2.c:1175
+#: cp/init.c:1727 cp/init.c:4402 cp/typeck2.c:1175
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "массив должен быть инициализирован инициализатором в фигурных скобках"
 
-#: cp/init.c:2019 cp/semantics.c:3268
+#: cp/init.c:2036 cp/semantics.c:3271
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qT не является классовым типом"
 
-#: cp/init.c:2075
+#: cp/init.c:2092
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr "неполный тип %qT не имеет элемента %qD"
 
-#: cp/init.c:2089
+#: cp/init.c:2106
 #, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr "некорректный указатель на битовое поле %qD"
 
-#: cp/init.c:2175 cp/typeck.c:1893
+#: cp/init.c:2192 cp/typeck.c:1893
 #, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "некорректное использование нестатической функции-элемента %qD"
 
-#: cp/init.c:2182 cp/semantics.c:1835
+#: cp/init.c:2199 cp/semantics.c:1835
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "некорректное использование нестатического элемента %qD"
 
-#: cp/init.c:2379
+#: cp/init.c:2396
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
-msgstr "неинициализированный ссылочный элемент в %q#T использующий %<new%> без new-инициализатора"
+msgstr "неинициализированный ссылочный элемент в %q#T, использующий %<new%> без new-инициализатора"
 
-#: cp/init.c:2387
-#, fuzzy, gcc-internal-format
-#| msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
+#: cp/init.c:2404
+#, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
-msgstr "неинициализированный ссылочный элемент в %q#T использующий %<new%> без new-инициализатора"
+msgstr "неинициализированный ссылочный элемент в базе %q#T от %q#T, использующий %<new%> без new-инициализатора"
 
-#: cp/init.c:2391
-#, fuzzy, gcc-internal-format
-#| msgid "uninitialized reference member in %q#T"
+#: cp/init.c:2408
+#, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T"
-msgstr "неинициализированный ссылочный элемент в %q#T"
+msgstr "неинициализированный ссылочный элемент в базе %q#T от %q#T"
 
-#: cp/init.c:2407
+#: cp/init.c:2424
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
-msgstr "неинициализированный const элемент в %q#T использующий %<new%> без new-инициализатора"
+msgstr "неинициализированный const элемент в %q#T, использующий %<new%> без new-инициализатора"
 
-#: cp/init.c:2415
-#, fuzzy, gcc-internal-format
-#| msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
+#: cp/init.c:2432
+#, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
-msgstr "неинициализированный const элемент в %q#T использующий %<new%> без new-инициализатора"
+msgstr "неинициализированный ссылочный элемент в базе %q#T от %q#T, использующий %<new%> без new-инициализатора"
 
-#: cp/init.c:2419
-#, fuzzy, gcc-internal-format
-#| msgid "uninitialized const member in %q#T"
+#: cp/init.c:2436
+#, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T"
-msgstr "неинициализированный const элемент в %q#T"
+msgstr "неинициализированный const элемент в базе %q#T от %q#T"
 
-#: cp/init.c:2710
+#: cp/init.c:2727
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
-msgstr ""
+msgstr "размещение new создает объект типа %<%T [%wu]%> и размера %qwu в области типа %qT и размера %qwi"
 
-#: cp/init.c:2721
+#: cp/init.c:2738
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
-msgstr ""
+msgstr "размещение new создает массив объектов типа %qT и размера %qwu в области типа %qT и размера %qwi"
 
-#: cp/init.c:2732
+#: cp/init.c:2749
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
-msgstr ""
+msgstr "размещение new создает объект типа %qT и размера %qwu в области типа %qT и размера %qwi"
 
-#: cp/init.c:2880
-#, fuzzy, gcc-internal-format
-#| msgid "integer overflow in expression"
+#: cp/init.c:2896
+#, gcc-internal-format
 msgid "integer overflow in array size"
-msgstr "переполнение при вычислении целочисленного выражения"
+msgstr "целочисленное переполнение в размере массива"
 
-#: cp/init.c:2890
-#, fuzzy, gcc-internal-format
-#| msgid "num_threads expression must be integral"
+#: cp/init.c:2906
+#, gcc-internal-format
 msgid "array size in new-expression must be constant"
-msgstr "num_threads выражение должно быть целочисленным"
+msgstr "размер массива в new-выражении должно быть константным"
 
-#: cp/init.c:2904
-#, fuzzy, gcc-internal-format
-#| msgid "variably modified field at file scope"
+#: cp/init.c:2920
+#, gcc-internal-format
 msgid "variably modified type not allowed in new-expression"
-msgstr "переменно модифицированное поле на уровне файла"
+msgstr "переменно модифицированный тип не допускается в new-выражении"
 
-#: cp/init.c:2920
+#: cp/init.c:2936
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by typedef"
-msgstr ""
+msgstr "неконстантная длина массива new должна быть задана непосредственно, не с помощью typedef"
 
-#: cp/init.c:2922
-#, fuzzy, gcc-internal-format
-#| msgid "try removing the parentheses around the type-id"
+#: cp/init.c:2938
+#, gcc-internal-format
 msgid "non-constant array new length must be specified without parentheses around the type-id"
-msgstr "попробуйте убрать скобки вокруг идентификатора типа"
+msgstr "неконстантная длина new массива должна быть задана без скобок вокруг идентификатора типа"
 
-#: cp/init.c:2932
+#: cp/init.c:2948
 #, gcc-internal-format
 msgid "invalid type %<void%> for new"
 msgstr "некорректный тип %<void%> задан для new"
 
-#: cp/init.c:2975
+#: cp/init.c:2991
 #, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr "непроинициализированная константа в %<new%> от %q#T"
 
-#: cp/init.c:3101
+#: cp/init.c:3117
 #, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr "не найдено подходящего %qD в классе %qT"
 
-#: cp/init.c:3108 cp/search.c:1023
+#: cp/init.c:3124 cp/search.c:1026
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "запрос элемента %qD неоднозначен"
 
-#: cp/init.c:3181
+#: cp/init.c:3197
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
-msgstr ""
+msgstr "%<new%> типа %qT с расширенным выравниванием %d"
 
-#: cp/init.c:3184
-#, fuzzy, gcc-internal-format
-#| msgid "class %qT does not have any field named %qD"
+#: cp/init.c:3200
+#, gcc-internal-format
 msgid "uses %qD, which does not have an alignment parameter"
-msgstr "в классе %qT нет поля с именем %qD"
+msgstr "использует %qD, который не имеет параметра выравнивания"
 
-#: cp/init.c:3187
+#: cp/init.c:3203
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
-msgstr ""
+msgstr "используйте %<-faligned-new%>, чтобы включить C++17 поддержку over-aligned new"
 
-#: cp/init.c:3370
+#: cp/init.c:3386
 #, gcc-internal-format
 msgid "parenthesized initializer in array new"
 msgstr "инициализатор со скобками в new массива"
 
-#: cp/init.c:3633
+#: cp/init.c:3649
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr "размер в new для массива должен иметь целочисленный тип"
 
-#: cp/init.c:3665
+#: cp/init.c:3681
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr "new нельзя применять к ссылочному типу"
 
-#: cp/init.c:3674
+#: cp/init.c:3690
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr "new нельзя применять к типу функции"
 
-#: cp/init.c:3743
-#, fuzzy, gcc-internal-format
-#| msgid "possible problem detected in invocation of delete operator:"
+#: cp/init.c:3759
+#, gcc-internal-format
 msgid "possible problem detected in invocation of delete [] operator:"
-msgstr "в вызове оператора delete обнаружена возможная проблема:"
+msgstr "возможная проблема обнаружена в вызове delete [] оператора:"
 
-#: cp/init.c:3747
-#, fuzzy, gcc-internal-format
-#| msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
+#: cp/init.c:3763
+#, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete [] will be called, even if they are declared when the class is defined"
-msgstr "ни деструктор, ни специфический для класса оператор delete не будут вызваны, даже если они декларированы в определении класса"
+msgstr "ни деструктор, ни специфический для класса оператор delete [] не будут вызваны, даже если они декларированы в определении класса"
 
-#: cp/init.c:4295
+#: cp/init.c:4311
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "преждевременное завершение инициализатора"
 
-#: cp/init.c:4599
+#: cp/init.c:4615
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr "неизвестный размер массива в операторе delete"
 
-#: cp/init.c:4623
+#: cp/init.c:4639
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete operator:"
 msgstr "в вызове оператора delete обнаружена возможная проблема:"
 
-#: cp/init.c:4628
+#: cp/init.c:4644
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
 msgstr "ни деструктор, ни специфический для класса оператор delete не будут вызваны, даже если они декларированы в определении класса"
 
-#: cp/init.c:4642
-#, fuzzy, gcc-internal-format
-#| msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behaviour"
+#: cp/init.c:4658
+#, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
-msgstr "удаление объекта абстрактного класса типа %qT, имеющего нетривиальный деструктор, вызовет неопределенное поведение"
+msgstr "удаление объекта абстрактного типа класса %qT, имеющего невиртуальный деструктор, вызовет неопределенное поведение"
 
-#: cp/init.c:4647
-#, fuzzy, gcc-internal-format
-#| msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behaviour"
+#: cp/init.c:4663
+#, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
-msgstr "удаление объекта полиморфного класса типа %qT, имеющего нетривиальный деструктор, вызовет неопределенное поведение"
+msgstr "удаление объекта полиморфного типа класса %qT, имеющего невиртуальный деструктор, может вызвать неопределенное поведение"
 
-#: cp/init.c:4954
+#: cp/init.c:4970
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "тип, заданный в векторном delete, не является ни массивом, ни указателем"
@@ -49418,7 +43782,7 @@
 #: cp/lambda.c:542
 #, gcc-internal-format
 msgid "array of runtime bound cannot be captured by copy, only by reference"
-msgstr ""
+msgstr "массив с границей времени выполнения не может захватываться копированием, только по ссылке"
 
 #: cp/lambda.c:557
 #, gcc-internal-format
@@ -49426,10 +43790,9 @@
 msgstr ""
 
 #: cp/lambda.c:561
-#, fuzzy, gcc-internal-format
-#| msgid "compound literal has variable size"
+#, gcc-internal-format
 msgid "because the array element type %qT has variable size"
-msgstr "составной литерал имеет переменный размер"
+msgstr "так как тип элементов массива %qT имеет переменный размер"
 
 #: cp/lambda.c:585
 #, gcc-internal-format
@@ -49437,10 +43800,9 @@
 msgstr "невозможно захватить %qE по ссылке"
 
 #: cp/lambda.c:595
-#, fuzzy, gcc-internal-format
-#| msgid "invalid use of incomplete type %q#T"
+#, gcc-internal-format
 msgid "capture by copy of incomplete type %qT"
-msgstr "некорректное использование неполного типа %q#T"
+msgstr "захват копированием неполного типа %qT"
 
 #: cp/lambda.c:619
 #, gcc-internal-format
@@ -49525,7 +43887,7 @@
 #: cp/mangle.c:3264
 #, gcc-internal-format
 msgid "use of built-in trait %qE in function signature; use library traits instead"
-msgstr ""
+msgstr "использование встроенной особенности %qE в сигнатуре функции; используйте библиотечные особенности взамен"
 
 #: cp/mangle.c:3269
 #, gcc-internal-format, gfc-internal-format
@@ -49545,37 +43907,32 @@
 #: cp/mangle.c:3862
 #, gcc-internal-format
 msgid "mangled name for %qD will change in C++17 because the exception specification is part of a function type"
-msgstr ""
+msgstr "скорректированное имя для %qD изменится в C++17, так как спецификация исключительных ситуаций есть часть типа функции"
 
 #: cp/mangle.c:3909
-#, fuzzy, gcc-internal-format
-#| msgid "the mangled name of %qD will change in a future version of GCC"
+#, gcc-internal-format
 msgid "the mangled name of %qD changed between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
-msgstr "кодированное имя %qD изменится в будущих версиях GCC"
+msgstr ""
 
 #: cp/mangle.c:3915
-#, fuzzy, gcc-internal-format
-#| msgid "the mangled name of %qD will change in a future version of GCC"
+#, gcc-internal-format
 msgid "the mangled name of %qD changes between %<%s=%d%> (%qD) and %<%s=%d%> (%qD)"
-msgstr "кодированное имя %qD изменится в будущих версиях GCC"
+msgstr ""
 
 #: cp/mangle.c:4187
-#, fuzzy, gcc-internal-format
-#| msgid "the mangled name of %qD will change in a future version of GCC"
+#, gcc-internal-format
 msgid "the mangled name of a thunk for %qD changes between -fabi-version=%d and -fabi-version=%d"
-msgstr "кодированное имя %qD изменится в будущих версиях GCC"
+msgstr "скорректированное имя thunk для %qD изменяется между -fabi-version=%d и -fabi-version=%d"
 
 #: cp/mangle.c:4192
-#, fuzzy, gcc-internal-format
-#| msgid "the mangled name of %qD will change in a future version of GCC"
+#, gcc-internal-format
 msgid "the mangled name of %qD changes between -fabi-version=%d and -fabi-version=%d"
-msgstr "кодированное имя %qD изменится в будущих версиях GCC"
+msgstr "скорректированное имя для %qD изменяется между -fabi-version=%d и -fabi-version=%d"
 
 #: cp/mangle.c:4197
-#, fuzzy, gcc-internal-format
-#| msgid "the mangled name of %qD will change in a future version of GCC"
+#, gcc-internal-format
 msgid "the mangled name of the initialization guard variable for %qD changes between -fabi-version=%d and -fabi-version=%d"
-msgstr "кодированное имя %qD изменится в будущих версиях GCC"
+msgstr "скорректированное имя переменной руководства инициализации для %qD изменяется между -fabi-version=%d и -fabi-version=%d"
 
 #: cp/method.c:828 cp/method.c:1324
 #, gcc-internal-format
@@ -49588,10 +43945,9 @@
 msgstr "нестатический элемент-ссылка %q#D, использование операции присваивания по умолчанию недопустимо"
 
 #: cp/method.c:953
-#, fuzzy, gcc-internal-format
-#| msgid "synthesized method %qD first required here "
+#, gcc-internal-format
 msgid "synthesized method %qD first required here"
-msgstr "синтезированный метод %qD впервые потребовался здесь "
+msgstr ""
 
 #: cp/method.c:1270
 #, gcc-internal-format
@@ -49599,39 +43955,35 @@
 msgstr "элемент объединения %q+D с нетривиальным %qD"
 
 #: cp/method.c:1280
-#, fuzzy, gcc-internal-format
-#| msgid "defaulted constructor calls non-constexpr %q+D"
+#, gcc-internal-format
 msgid "defaulted constructor calls non-%<constexpr%> %qD"
-msgstr "подразумеваемый конструктор вызывает non-constexpr %q+D"
+msgstr ""
 
 #: cp/method.c:1347
-#, fuzzy, gcc-internal-format
-#| msgid "initializer for %q+#D is invalid"
+#, gcc-internal-format
 msgid "initializer for %q#D is invalid"
-msgstr "инициализатор для %q+#D некорректен"
+msgstr "инициализатор для %q#D некорректен"
 
 #: cp/method.c:1399
-#, fuzzy, gcc-internal-format
-#| msgid "defaulted default constructor does not initialize %q+#D"
+#, gcc-internal-format
 msgid "defaulted default constructor does not initialize %q#D"
-msgstr "подразумеваемый конструктор не инициализирует %q+#D"
+msgstr "сведенный к подразумеваемому подразумеваемый конструктор не инициализирует %q#D"
 
 #: cp/method.c:1410
-#, fuzzy, gcc-internal-format
-#| msgid "non-static data member %qD has Java class type"
+#, gcc-internal-format
 msgid "copying non-static data member %q#D of rvalue reference type"
-msgstr "нестатический элемент данных %qD имеет тип Java класса"
+msgstr "копирование нестатического элемента данных %q#D rvalue типа ссылки"
 
 #. A trivial constructor doesn't have any NSDMI.
 #: cp/method.c:1646
 #, gcc-internal-format
 msgid "defaulted default constructor does not initialize any non-static data member"
-msgstr "подразумеваемый конструктор не инициализирует нестатические элементы данных"
+msgstr "сведенный к подразумеваемому подразумеваемый конструктор не инициализирует нестатические элементы данных"
 
 #: cp/method.c:1691
 #, gcc-internal-format
 msgid "defaulted move assignment for %qT calls a non-trivial move assignment operator for virtual base %qT"
-msgstr ""
+msgstr "подразумеваемое move присваивание для %qT вызывает оператор нетривиального move присваивания для виртуальной базы %qT"
 
 #: cp/method.c:1815
 #, gcc-internal-format
@@ -49644,49 +43996,42 @@
 msgstr "тип замыкания lambda имеет удаленный оператор присваивания с копированием"
 
 #: cp/method.c:1827
-#, fuzzy, gcc-internal-format
-#| msgid "%q+#D is implicitly declared as deleted because %qT declares a move constructor or move assignment operator"
+#, gcc-internal-format
 msgid "%q#D is implicitly declared as deleted because %qT declares a move constructor or move assignment operator"
-msgstr "%q+#D неявно продекларирован как удаленный поскольку %qT декларирует перемещающий конструктор или оператор присваивания с перемещением"
+msgstr "%q#D неявно декларирован как удаленный, поскольку %qT декларирует перемещающий конструктор или перемещающий оператор присваивания"
 
 #: cp/method.c:1838
 #, gcc-internal-format
 msgid "%q#D inherits from multiple base subobjects"
-msgstr ""
+msgstr "%q#D наследует из нескольких базовых подобъектов"
 
 #: cp/method.c:1859
-#, fuzzy, gcc-internal-format
-#| msgid "%q+#D is implicitly deleted because the default definition would be ill-formed:"
+#, gcc-internal-format
 msgid "%q#D is implicitly deleted because the default definition would be ill-formed:"
-msgstr "%q+#D является неявно удаленным поскольку подразумеваемое определение будет синтаксически некорректным:"
+msgstr "%q#D неявно удален, поскольку подразумеваемое определение будет синтаксически некорректным:"
 
 #: cp/method.c:1868
 msgid "%q#F is implicitly deleted because its exception-specification does not match the implicit exception-specification %qX"
-msgstr ""
+msgstr "%q#F неявно удалено, так как его спецификация исключительных ситуаций не соответствует неявной спецификации исключительных ситуаций %qX"
 
 #: cp/method.c:2188
-#, fuzzy, gcc-internal-format
-#| msgid "does not match expected signature %qD"
+#, gcc-internal-format
 msgid "defaulted declaration %q+D does not match the expected signature"
-msgstr "не соответствует ожидаемой сигнатуре %qD"
+msgstr ""
 
 #: cp/method.c:2191
-#, fuzzy, gcc-internal-format
-#| msgid "does not match expected signature %qD"
+#, gcc-internal-format
 msgid "expected signature: %qD"
-msgstr "не соответствует ожидаемой сигнатуре %qD"
+msgstr ""
 
 #: cp/method.c:2229
-#, fuzzy
-#| msgid "function %q+D defaulted on its first declaration with an exception-specification that differs from the implicit declaration %q#D"
 msgid "function %q+D defaulted on its redeclaration with an exception-specification that differs from the implicit exception-specification %qX"
-msgstr "функция %q+D подразумевается при ее первой декларации со спецификацией обработки исключений, которая отличается от неявной декларации %q#D"
+msgstr "функция %q+D сводится к подразумеваемой при ее редекларации со спецификацией обработки исключений, которая отличается от неявной спецификации обработки исключений %qX"
 
 #: cp/method.c:2251
-#, fuzzy, gcc-internal-format
-#| msgid "explicitly defaulted function %q+D cannot be declared as constexpr because the implicit declaration is not constexpr:"
+#, gcc-internal-format
 msgid "explicitly defaulted function %q+D cannot be declared as %<constexpr%> because the implicit declaration is not %<constexpr%>:"
-msgstr "явно подразумеваемая функция %q+D не может быть декларирована как constexpr поскольку неявная декларация не есть constexpr:"
+msgstr ""
 
 #: cp/method.c:2296
 #, gcc-internal-format
@@ -49709,16 +44054,14 @@
 msgstr "%q#D конфликтует с предыдущей декларацией"
 
 #: cp/name-lookup.c:2435
-#, fuzzy, gcc-internal-format
-#| msgid "%q#D hides constructor for %q#T"
+#, gcc-internal-format
 msgid "%q#D hides constructor for %q#D"
-msgstr "%q#D скрывает конструктор для %q#T"
+msgstr ""
 
 #: cp/name-lookup.c:2562
-#, fuzzy, gcc-internal-format
-#| msgid "conflicting declaration %q#D"
+#, gcc-internal-format
 msgid "conflicting C language linkage declaration %q#D"
-msgstr "противоречивая декларация %q#D"
+msgstr ""
 
 #: cp/name-lookup.c:2567
 #, gcc-internal-format
@@ -49731,31 +44074,27 @@
 msgstr "декларация %q#D перекрывает параметр"
 
 #: cp/name-lookup.c:2784
-#, fuzzy, gcc-internal-format
-#| msgid "declaration of %qD as member of %qT"
+#, gcc-internal-format
 msgid "declaration of %qD shadows a member of %qT"
-msgstr "декларация %qD как элемента %qT"
+msgstr "декларация %qD перекрывает элемент %qT"
 
 #: cp/name-lookup.c:2945
-#, fuzzy, gcc-internal-format
-#| msgid "global declaration %q+#D"
+#, gcc-internal-format
 msgid "local external declaration %q#D"
-msgstr "глобальная декларация %q+#D"
+msgstr ""
 
 #: cp/name-lookup.c:2947
-#, fuzzy, gcc-internal-format
-#| msgid "conflicts with previous declaration %q+#D"
+#, gcc-internal-format
 msgid "does not match previous declaration %q#D"
-msgstr "противоречит предыдущей декларации %q+#D"
+msgstr ""
 
 #. In a local class, a friend function declaration must
 #. find a matching decl in the innermost non-class scope.
 #. [class.friend/11]
 #: cp/name-lookup.c:3070
-#, fuzzy, gcc-internal-format
-#| msgid "friend declaration %qD in local class without prior declaration"
+#, gcc-internal-format
 msgid "friend declaration %qD in local class without prior local declaration"
-msgstr "friend декларация %qD в локальном классе без предшествующей декларации"
+msgstr ""
 
 #: cp/name-lookup.c:3132
 #, gcc-internal-format
@@ -49768,16 +44107,14 @@
 msgstr "поиск имени %qD изменен"
 
 #: cp/name-lookup.c:3255
-#, fuzzy, gcc-internal-format
-#| msgid "  matches this %q+D under ISO standard rules"
+#, gcc-internal-format
 msgid "matches this %qD under ISO standard rules"
-msgstr "  соответствует декларации %q+D по правилам стандарта ISO"
+msgstr ""
 
 #: cp/name-lookup.c:3257
-#, fuzzy, gcc-internal-format
-#| msgid "  matches this %q+D under old rules"
+#, gcc-internal-format
 msgid "  matches this %qD under old rules"
-msgstr "  соответствует декларации %q+D по старым правилам"
+msgstr ""
 
 #: cp/name-lookup.c:3275 cp/name-lookup.c:3285
 #, gcc-internal-format
@@ -49785,22 +44122,19 @@
 msgstr "поиск имени %qD приведен в соответствие с правилами видимости ISO %<for%>"
 
 #: cp/name-lookup.c:3278
-#, fuzzy, gcc-internal-format
-#| msgid "  cannot use obsolete binding at %q+D because it has a destructor"
+#, gcc-internal-format
 msgid "cannot use obsolete binding %qD because it has a destructor"
-msgstr "  нельзя использовать устаревшую привязку в %q+D, потому что имеется деструктор"
+msgstr ""
 
 #: cp/name-lookup.c:3289
-#, fuzzy, gcc-internal-format
-#| msgid "  using obsolete binding at %q+D"
+#, gcc-internal-format
 msgid "using obsolete binding %qD"
-msgstr "  используется устаревшая привязка в %q+D"
+msgstr ""
 
 #: cp/name-lookup.c:3347
-#, fuzzy, gcc-internal-format
-#| msgid "%s %s(%E) %p %d\n"
+#, gcc-internal-format
 msgid "%s %<%s(%E)%> %p %d\n"
-msgstr "%s %s(%E) %p %d\n"
+msgstr ""
 
 #: cp/name-lookup.c:3350
 #, gcc-internal-format
@@ -49808,10 +44142,9 @@
 msgstr "%s %s %p %d\n"
 
 #: cp/name-lookup.c:4019
-#, fuzzy, gcc-internal-format
-#| msgid "%qT is not a namespace"
+#, gcc-internal-format
 msgid "%qT is not a namespace or unscoped enum"
-msgstr "%qT не является пространством имён"
+msgstr "%qT не является пространством имен или unscoped enum"
 
 #. 7.3.3/5
 #. A using-declaration shall not name a template-id.
@@ -49818,7 +44151,7 @@
 #: cp/name-lookup.c:4029
 #, gcc-internal-format
 msgid "a using-declaration cannot specify a template-id.  Try %<using %D%>"
-msgstr "в using-декларации нельзя задавать идентификатор шаблона. Попробуйте %<using %D%>"
+msgstr ""
 
 #: cp/name-lookup.c:4036
 #, gcc-internal-format
@@ -49861,7 +44194,7 @@
 #: cp/name-lookup.c:4843
 #, gcc-internal-format
 msgid "cannot inherit constructors from indirect base %qT"
-msgstr ""
+msgstr "невозможно унаследовать конструкторы от косвенной базы %qT"
 
 #: cp/name-lookup.c:4852
 #, gcc-internal-format
@@ -49879,16 +44212,14 @@
 msgstr "явные квалификаторы в декларации %qD"
 
 #: cp/name-lookup.c:5010
-#, fuzzy, gcc-internal-format
-#| msgid "%qE has not been declared"
+#, gcc-internal-format
 msgid "%qD has not been declared within %qD"
-msgstr "%qE не был декларирован"
+msgstr ""
 
 #: cp/name-lookup.c:5012
-#, fuzzy, gcc-internal-format
-#| msgid "%q+D declared as a friend"
+#, gcc-internal-format
 msgid "only here as a %<friend%>"
-msgstr "%q+D декларировано как friend"
+msgstr ""
 
 #: cp/name-lookup.c:5021
 #, gcc-internal-format
@@ -49903,21 +44234,19 @@
 #: cp/name-lookup.c:5076
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
-msgstr "%qD атрибут не имеет смысла поскольку элементы анонимного пространства имен получают локальные символы"
+msgstr "%qD атрибут не имеет смысла, поскольку элементы анонимного пространства имен получают локальные символы"
 
 #: cp/name-lookup.c:5086
-#, fuzzy, gcc-internal-format
-#| msgid "ignoring attributes on template argument %qT"
+#, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
-msgstr "игнорирование атрибутов аргумента шаблона %qT"
+msgstr "игнорирование %qD атрибута в анонимном пространстве имен"
 
 #: cp/name-lookup.c:5092
-#, fuzzy, gcc-internal-format
-#| msgid "ignoring attributes on template argument %qT"
+#, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
-msgstr "игнорирование атрибутов аргумента шаблона %qT"
+msgstr "игнорирование %qD атрибута в non-inline пространстве имен"
 
-#: cp/name-lookup.c:5111 cp/name-lookup.c:7065
+#: cp/name-lookup.c:5111 cp/name-lookup.c:7073
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "атрибут %qD игнорируется"
@@ -49941,11 +44270,9 @@
 msgstr "  %qE"
 
 #: cp/name-lookup.c:5472 cp/name-lookup.c:5764
-#, fuzzy, gcc-internal-format
-#| msgid "suggested alternative:"
-#| msgid_plural "suggested alternatives:"
+#, gcc-internal-format
 msgid "suggested alternative: %qs"
-msgstr "предлагаемый вариант:"
+msgstr "предлагаемый вариант: %qs"
 
 #: cp/name-lookup.c:5704
 #, gcc-internal-format
@@ -49953,76 +44280,67 @@
 msgstr ""
 
 #: cp/name-lookup.c:5711
-#, fuzzy, gcc-internal-format
-#| msgid "%qD is not a variable in clause %qs"
+#, gcc-internal-format
 msgid "%<std::%s%> is only available from %s onwards"
-msgstr "%qD не есть переменная в клаузуле %qs"
+msgstr ""
 
 #: cp/name-lookup.c:5929
-#, fuzzy, gcc-internal-format
-#| msgid "weak %q+D cannot be defined %qE"
+#, gcc-internal-format
 msgid "the macro %qs had not yet been defined"
-msgstr "weak %q+D не может быть определено %qE"
+msgstr ""
 
 #: cp/name-lookup.c:5932
-#, fuzzy, gcc-internal-format
-#| msgid "struct defined here"
+#, gcc-internal-format
 msgid "it was later defined here"
-msgstr "структура определена здесь"
+msgstr ""
 
-#: cp/name-lookup.c:6687
-#, fuzzy, gcc-internal-format
-#| msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
+#: cp/name-lookup.c:6695
+#, gcc-internal-format
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn't a template"
-msgstr "вывод из взятого в скобки списка инизиализатора требует #include <initializer_list>"
+msgstr ""
 
-#: cp/name-lookup.c:7059
-#, fuzzy, gcc-internal-format
-#| msgid "switch %qs is no longer supported"
+#: cp/name-lookup.c:7067
+#, gcc-internal-format
 msgid "strong using directive no longer supported"
-msgstr "ключ %qs больше не поддерживается"
+msgstr ""
 
-#: cp/name-lookup.c:7062
+#: cp/name-lookup.c:7070
 #, gcc-internal-format
 msgid "you may use an inline namespace instead"
 msgstr ""
 
-#: cp/name-lookup.c:7079
-#, fuzzy, gcc-internal-format
-#| msgid "attributes ignored on uninstantiated type"
+#: cp/name-lookup.c:7087
+#, gcc-internal-format
 msgid "attributes ignored on local using directive"
-msgstr "атрибуты игнорируются для неконкретизированного типа"
+msgstr ""
 
-#: cp/name-lookup.c:7163
+#: cp/name-lookup.c:7171
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "использование пространства имён %qD здесь недопустимо; предполагается %qD"
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:7183
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "%qD may not be declared within a namespace"
+#: cp/name-lookup.c:7191
+#, gcc-internal-format, gfc-internal-format
 msgid "cannot nest more than %d namespaces"
-msgstr "декларация %qD может не действовать в пространстве имён"
+msgstr ""
 
-#: cp/name-lookup.c:7218
-#, fuzzy, gcc-internal-format
-#| msgid "method attributes must be specified at the end only"
+#: cp/name-lookup.c:7226
+#, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
-msgstr "атрибуты методов задаются только в конце"
+msgstr ""
 
-#: cp/name-lookup.c:7219
-#, fuzzy, gcc-internal-format
-#| msgid "label %qD defined here"
+#: cp/name-lookup.c:7227
+#, gcc-internal-format
 msgid "%qD defined here"
-msgstr "метка %qD определена здесь"
+msgstr ""
 
-#: cp/name-lookup.c:7292
+#: cp/name-lookup.c:7300
 #, gcc-internal-format
 msgid "XXX entering pop_everything ()\n"
 msgstr "XXX вход в pop_everything ()\n"
 
-#: cp/name-lookup.c:7301
+#: cp/name-lookup.c:7309
 #, gcc-internal-format
 msgid "XXX leaving pop_everything ()\n"
 msgstr "XXX выход из pop_everything ()\n"
@@ -50040,12 +44358,12 @@
 #: cp/parser.c:1314 cp/parser.c:1327
 #, gcc-internal-format
 msgid "LEXER_DEBUGGING_ENABLED_P is not set to true"
-msgstr ""
+msgstr "LEXER_DEBUGGING_ENABLED_P не установлено в true"
 
-#: cp/parser.c:1352 cp/parser.c:37254
+#: cp/parser.c:1352 cp/parser.c:37251
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
-msgstr ""
+msgstr "за %<#pragma omp declare simd%> не следует непосредственно декларация функции или определение"
 
 #: cp/parser.c:2851
 #, gcc-internal-format
@@ -50067,7 +44385,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr "запрос элемента %qE в неклассовом типе %qT"
 
-#: cp/parser.c:2949 cp/parser.c:18221
+#: cp/parser.c:2949 cp/parser.c:18218
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "%<%T::%E%> не был декларирован"
@@ -50128,10 +44446,9 @@
 msgstr "(возможно, пропущена точка с запятой после определения %qT)"
 
 #: cp/parser.c:3100
-#, fuzzy, gcc-internal-format
-#| msgid "%qE is not a template"
+#, gcc-internal-format
 msgid "%qE is not a class template"
-msgstr "%qE не является шаблоном"
+msgstr "%qE не является шаблоном класса"
 
 #: cp/parser.c:3102
 #, gcc-internal-format
@@ -50144,12 +44461,11 @@
 msgstr "некорректный идентификатор шаблона"
 
 #: cp/parser.c:3139
-#, fuzzy, gcc-internal-format
-#| msgid "floating-point literal cannot appear in a constant-expression"
+#, gcc-internal-format
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
-msgstr "плавающий литерал не может появляться в константном выражении"
+msgstr "ISO C++ запрещает использование литералов с плавающей точкой в константном выражении"
 
-#: cp/parser.c:3143 cp/pt.c:17853
+#: cp/parser.c:3143 cp/pt.c:17890
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr "приведение к типу, отличному от целого или перечисления, не может появляться в константном выражении"
@@ -50220,10 +44536,9 @@
 msgstr "%qs не может присутствовать в константном выражении"
 
 #: cp/parser.c:3273
-#, fuzzy, gcc-internal-format
-#| msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
+#, gcc-internal-format
 msgid "class template argument deduction is only available with -std=c++17 or -std=gnu++17"
-msgstr "вариантные шаблоны доступны только с -std=c++11 или -std=gnu++11"
+msgstr ""
 
 #: cp/parser.c:3278
 #, gcc-internal-format
@@ -50237,10 +44552,9 @@
 msgstr "некорректная комбинация спецификаторов типа"
 
 #: cp/parser.c:3293
-#, fuzzy, gcc-internal-format
-#| msgid "%qE does not name a type"
+#, gcc-internal-format
 msgid "%qE does not name a type; did you mean %qs?"
-msgstr "%qE не является именем типа"
+msgstr "%qE не является именем типа; имелось в виду %qs?"
 
 #: cp/parser.c:3297
 #, gcc-internal-format
@@ -50253,22 +44567,19 @@
 msgstr "C++11 %<constexpr%> доступно только с -std=c++11 или -std=gnu++11"
 
 #: cp/parser.c:3309
-#, fuzzy, gcc-internal-format
-#| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
+#, gcc-internal-format
 msgid "C++11 %<noexcept%> only available with -std=c++11 or -std=gnu++11"
-msgstr "C++11 %<constexpr%> доступно только с -std=c++11 или -std=gnu++11"
+msgstr "C++11 %<noexcept%> доступно только с -std=c++11 или -std=gnu++11"
 
 #: cp/parser.c:3314
-#, fuzzy, gcc-internal-format
-#| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
+#, gcc-internal-format
 msgid "C++11 %<thread_local%> only available with -std=c++11 or -std=gnu++11"
-msgstr "C++11 %<constexpr%> доступно только с -std=c++11 или -std=gnu++11"
+msgstr "C++11 %<thread_local%> доступно только с -std=c++11 или -std=gnu++11"
 
 #: cp/parser.c:3317
-#, fuzzy, gcc-internal-format
-#| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
+#, gcc-internal-format
 msgid "%<concept%> only available with -fconcepts"
-msgstr "C++11 %<constexpr%> доступно только с -std=c++11 или -std=gnu++11"
+msgstr "%<concept%> доступно только с -fconcepts"
 
 #: cp/parser.c:3343
 #, gcc-internal-format
@@ -50276,10 +44587,9 @@
 msgstr "(возможно, подразумевалось %<typename %T::%E%>)"
 
 #: cp/parser.c:3361 cp/parser.c:3365
-#, fuzzy, gcc-internal-format
-#| msgid "%qE in namespace %qE does not name a type"
+#, gcc-internal-format
 msgid "%qE in namespace %qE does not name a template type"
-msgstr "%qE в пространстве имен %qE не именует тип"
+msgstr "%qE в пространстве имен %qE не именует тип шаблона"
 
 #: cp/parser.c:3369
 #, gcc-internal-format
@@ -50298,21 +44608,19 @@
 msgstr "и %qT не имеет шаблонных конструкторов"
 
 #: cp/parser.c:3392
-#, fuzzy, gcc-internal-format
-#| msgid "need %<typename%> before %<%T::%E%> because %qT is a dependent scope"
+#, gcc-internal-format
 msgid "need %<typename%> before %<%T::%D::%E%> because %<%T::%D%> is a dependent scope"
-msgstr "требуется %<typename%> перед %<%T::%E%> поскольку %qT зависимый контекст"
+msgstr ""
 
 #: cp/parser.c:3400
 #, gcc-internal-format
 msgid "need %<typename%> before %<%T::%E%> because %qT is a dependent scope"
-msgstr "требуется %<typename%> перед %<%T::%E%> поскольку %qT зависимый контекст"
+msgstr "требуется %<typename%> перед %<%T::%E%>, поскольку %qT зависимый контекст"
 
 #: cp/parser.c:3411 cp/parser.c:3415
-#, fuzzy, gcc-internal-format
-#| msgid "%qE in %q#T does not name a type"
+#, gcc-internal-format
 msgid "%qE in %q#T does not name a template type"
-msgstr "%qE в %q#T не именует тип"
+msgstr "%qE в %q#T не именует тип шаблона"
 
 #: cp/parser.c:3419
 #, gcc-internal-format
@@ -50340,22 +44648,19 @@
 msgstr "невозможно найти оператор символьного литерала %qD с аргументом %qT"
 
 #: cp/parser.c:4357
-#, fuzzy, gcc-internal-format
-#| msgid "floating constant exceeds range of %qT"
+#, gcc-internal-format
 msgid "integer literal exceeds range of %qT type"
-msgstr "плавающая константа превышает диапазон для %qT"
+msgstr "целый литерал превосходит диапазон %qT типа"
 
 #: cp/parser.c:4364
-#, fuzzy, gcc-internal-format
-#| msgid "floating constant exceeds range of %qT"
+#, gcc-internal-format
 msgid "floating literal exceeds range of %qT type"
-msgstr "плавающая константа превышает диапазон для %qT"
+msgstr "плавающий литерал превосходит диапазон %qT типа"
 
 #: cp/parser.c:4368
-#, fuzzy, gcc-internal-format
-#| msgid "floating constant truncated to zero"
+#, gcc-internal-format
 msgid "floating literal truncated to zero"
-msgstr "констaнтa с плавающей точкой усечена до нуля"
+msgstr "плавающий литерал усечен к нулю"
 
 #: cp/parser.c:4433
 #, gcc-internal-format
@@ -50382,40 +44687,35 @@
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr "невозможно найти оператор строкового литерала %qD с аргументами %qT, %qT"
 
-#: cp/parser.c:4587 cp/parser.c:12940
+#: cp/parser.c:4587 cp/parser.c:12937
 #, gcc-internal-format
 msgid "expected declaration"
 msgstr "ожидалась декларация"
 
 #: cp/parser.c:4934 cp/parser.c:4949
-#, fuzzy, gcc-internal-format
-#| msgid "expected operator"
+#, gcc-internal-format
 msgid "expected binary operator"
-msgstr "ожидался оператор"
+msgstr "ожидался бинарный оператор"
 
 #: cp/parser.c:4955
-#, fuzzy, gcc-internal-format
-#| msgid "expected %<...%>"
+#, gcc-internal-format
 msgid "expected ..."
-msgstr "ожидалось %<...%>"
+msgstr "ожидалось ..."
 
 #: cp/parser.c:4967
-#, fuzzy, gcc-internal-format
-#| msgid "%s expression list treated as compound expression"
+#, gcc-internal-format
 msgid "binary expression in operand of fold-expression"
-msgstr "%s - список выражений рассматривается как составное выражение"
+msgstr "бинарное выражение в операнде fold-выражения"
 
 #: cp/parser.c:4972
-#, fuzzy, gcc-internal-format
-#| msgid "a transaction expression cannot appear in a constant-expression"
+#, gcc-internal-format
 msgid "conditional expression in operand of fold-expression"
-msgstr "транзакционное выражение не может присутствовать в константном выражении"
+msgstr "условное выражение в операнде fold-выражения"
 
 #: cp/parser.c:4980
-#, fuzzy, gcc-internal-format
-#| msgid "type mismatch in vector shift expression"
+#, gcc-internal-format
 msgid "mismatched operator in fold-expression"
-msgstr "несоответствие типов в векторном выражении сдвига"
+msgstr "несоответствующий оператор в fold-выражении"
 
 #: cp/parser.c:5084
 #, gcc-internal-format
@@ -50433,12 +44733,11 @@
 msgstr "операторы-выражения не допустимы вне функций и списков аргументов шаблона"
 
 #: cp/parser.c:5217
-#, fuzzy, gcc-internal-format
-#| msgid "lambda expressions only available with -std=c++11 or -std=gnu++11"
+#, gcc-internal-format
 msgid "fold-expressions only available with -std=c++17 or -std=gnu++17"
-msgstr "lambda-выражения доступны только с -std=c++11 или -std=gnu++11"
+msgstr ""
 
-#: cp/parser.c:5275 cp/parser.c:5452 cp/parser.c:5630 cp/semantics.c:3612
+#: cp/parser.c:5275 cp/parser.c:5452 cp/parser.c:5633 cp/semantics.c:3615
 #, gcc-internal-format
 msgid "expected primary-expression"
 msgstr "ожидалось primary-expression"
@@ -50458,100 +44757,95 @@
 msgid "local variable %qD may not appear in this context"
 msgstr "локальная переменная %qD недопустима в данном контексте"
 
-#: cp/parser.c:5787
+#: cp/parser.c:5790
 #, gcc-internal-format
 msgid "expected id-expression"
 msgstr "ожидалось id-выражение"
 
-#: cp/parser.c:5919
+#: cp/parser.c:5922
 #, gcc-internal-format
 msgid "scope %qT before %<~%> is not a class-name"
 msgstr "область видимости %qT до %<~%> не является именем класса"
 
-#: cp/parser.c:5948 cp/parser.c:7860
-#, fuzzy, gcc-internal-format
-#| msgid "C++0x auto only available with -std=c++11 or -std=gnu++11"
+#: cp/parser.c:5951 cp/parser.c:7860
+#, gcc-internal-format
 msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
-msgstr "C++0x auto доступны только с -std=c++11 или -std=gnu++11"
+msgstr "%<~auto%> доступно только с -std=c++14 или -std=gnu++14"
 
-#: cp/parser.c:6059
+#: cp/parser.c:6062
 #, gcc-internal-format
 msgid "declaration of %<~%T%> as member of %qT"
 msgstr "декларация %<~%T%> как элемента %qT"
 
-#: cp/parser.c:6074
+#: cp/parser.c:6077
 #, gcc-internal-format
 msgid "typedef-name %qD used as destructor declarator"
 msgstr "typedef-имя %qD использовано как декларатор деструктора"
 
-#: cp/parser.c:6111 cp/parser.c:20249
+#: cp/parser.c:6114 cp/parser.c:20246
 #, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr "ожидался unqualified-id"
 
-#: cp/parser.c:6220
+#: cp/parser.c:6223
 #, gcc-internal-format
 msgid "found %<:%> in nested-name-specifier, expected %<::%>"
 msgstr "найдено %<:%> во вложенном спецификаторе имени, ожидалось %<::%>"
 
-#: cp/parser.c:6288
+#: cp/parser.c:6291
 #, gcc-internal-format
 msgid "decltype evaluates to %qT, which is not a class or enumeration type"
 msgstr "decltype обработано до %qT, что не является классом или перечислимым типом"
 
-#: cp/parser.c:6314
-#, fuzzy, gcc-internal-format
-#| msgid "incomplete type %qT used in nested name specifier"
+#: cp/parser.c:6317
+#, gcc-internal-format
 msgid "function template-id %qD in nested-name-specifier"
-msgstr "неполный тип %qT использован во вложенном спецификаторе имени"
+msgstr "идентификатор шаблона функции %qD в nested-name-specifier"
 
-#: cp/parser.c:6322
-#, fuzzy, gcc-internal-format
-#| msgid "expected nested-name-specifier"
+#: cp/parser.c:6325
+#, gcc-internal-format
 msgid "variable template-id %qD in nested-name-specifier"
-msgstr "ожидался вложенный спецификатор имени"
+msgstr "идентификатор переменного шаблона %qD в nested-name-specifier"
 
-#: cp/parser.c:6426 cp/typeck.c:2684 cp/typeck.c:2687 cp/typeck.c:2704
+#: cp/parser.c:6429 cp/typeck.c:2684 cp/typeck.c:2687 cp/typeck.c:2704
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD не является шаблоном"
 
-#: cp/parser.c:6504
+#: cp/parser.c:6507
 #, gcc-internal-format
 msgid "expected nested-name-specifier"
 msgstr "ожидался вложенный спецификатор имени"
 
-#: cp/parser.c:6711 cp/parser.c:8950
+#: cp/parser.c:6714 cp/parser.c:8950
 #, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr "типы нельзя определять в приведении типов"
 
-#: cp/parser.c:6797
+#: cp/parser.c:6800
 #, gcc-internal-format
 msgid "types may not be defined in a %<typeid%> expression"
 msgstr "типы нельзя определять в %<typeid%> выражении"
 
-#: cp/parser.c:6889
-#, fuzzy, gcc-internal-format
-#| msgid "wrong number of arguments to %<__builtin_shuffle%>"
+#: cp/parser.c:6892
+#, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_addressof%>"
-msgstr "неверное число аргументов в вызове аргументов в вызове %<__builtin_shuffle%>"
+msgstr "неверное число аргументов для %<__builtin_addressof%>"
 
-#: cp/parser.c:6901 cp/pt.c:18416
-#, fuzzy, gcc-internal-format
-#| msgid "wrong number of arguments to %<__builtin_complex%>"
+#: cp/parser.c:6904 cp/pt.c:18453
+#, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
-msgstr "неверное число аргументов в вызове %<__builtin_complex%>"
+msgstr "неверное число аргументов для %<__builtin_launder%>"
 
-#: cp/parser.c:6995
+#: cp/parser.c:6998
 #, gcc-internal-format
 msgid "ISO C++ forbids compound-literals"
 msgstr "в ISO C++ составные литеральные конструкции запрещены"
 
-#: cp/parser.c:7054
+#: cp/parser.c:7057
 #, gcc-internal-format
 msgid "two consecutive %<[%> shall only introduce an attribute"
-msgstr ""
+msgstr "два последовательных %<[%> только введут атрибут"
 
 #: cp/parser.c:7596 cp/typeck.c:2572
 #, gcc-internal-format
@@ -50596,13 +44890,12 @@
 #: cp/parser.c:8454
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
-msgstr ""
+msgstr "инициализация new-выражения для типа %<auto%> требует ровно один элемент"
 
 #: cp/parser.c:8502
-#, fuzzy, gcc-internal-format
-#| msgid "Expected expression type"
+#, gcc-internal-format
 msgid "expected expression-list or type-id"
-msgstr "Ожидался тип выражения"
+msgstr "ожидался список выражений или идентификатор типа"
 
 #: cp/parser.c:8531
 #, gcc-internal-format
@@ -50615,10 +44908,9 @@
 msgstr "выражение в деклараторе new должно иметь целый или перечислимый тип"
 
 #: cp/parser.c:9055
-#, fuzzy, gcc-internal-format
-#| msgid "use of old-style cast"
+#, gcc-internal-format
 msgid "use of old-style cast to %q#T"
-msgstr "использование устаревшей конструкции для приведения типа"
+msgstr ""
 
 #: cp/parser.c:9203
 #, gcc-internal-format
@@ -50636,10 +44928,9 @@
 msgstr "ISO C++ не допускает ?: с опущенным средним операндом"
 
 #: cp/parser.c:9832
-#, fuzzy, gcc-internal-format
-#| msgid "types may not be defined in conditions"
+#, gcc-internal-format
 msgid "types may not be defined within __builtin_offsetof"
-msgstr "типы нельзя определять в условиях"
+msgstr ""
 
 #: cp/parser.c:10119
 #, gcc-internal-format
@@ -50647,10 +44938,9 @@
 msgstr "lambda-expression в необрабатываемом контексте"
 
 #: cp/parser.c:10128
-#, fuzzy, gcc-internal-format
-#| msgid "lambda-expression in unevaluated context"
+#, gcc-internal-format
 msgid "lambda-expression in template-argument"
-msgstr "lambda-expression в необрабатываемом контексте"
+msgstr "lambda-выражение в аргументе шаблона"
 
 #: cp/parser.c:10281
 #, gcc-internal-format
@@ -50663,33 +44953,29 @@
 msgstr "явное by-copy capture %<this%> избыточно с by-copy capture умолчанием"
 
 #: cp/parser.c:10313
-#, fuzzy, gcc-internal-format
-#| msgid "C++0x auto only available with -std=c++11 or -std=gnu++11"
+#, gcc-internal-format
 msgid "%<*this%> capture only available with -std=c++17 or -std=gnu++17"
-msgstr "C++0x auto доступны только с -std=c++11 или -std=gnu++11"
+msgstr ""
 
 #: cp/parser.c:10358
-#, fuzzy, gcc-internal-format
-#| msgid "lambda expressions only available with -std=c++11 or -std=gnu++11"
+#, gcc-internal-format
 msgid "lambda capture initializers only available with -std=c++14 or -std=gnu++14"
-msgstr "lambda-выражения доступны только с -std=c++11 или -std=gnu++11"
+msgstr "lambda-захватывающие инициализаторы доступны только с -std=c++14 или -std=gnu++14"
 
 #: cp/parser.c:10365
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
-msgstr ""
+msgstr "пустой инициализатор для lambda init-capture"
 
 #: cp/parser.c:10387
-#, fuzzy, gcc-internal-format
-#| msgid "capture of non-variable %qD "
+#, gcc-internal-format
 msgid "capture of non-variable %qE"
-msgstr "capture непеременной %qD "
+msgstr ""
 
-#: cp/parser.c:10391 cp/parser.c:10401 cp/semantics.c:3453 cp/semantics.c:3465
-#, fuzzy, gcc-internal-format
-#| msgid "%q+#D declared here"
+#: cp/parser.c:10391 cp/parser.c:10401 cp/semantics.c:3456 cp/semantics.c:3468
+#, gcc-internal-format
 msgid "%q#D declared here"
-msgstr "%q+#D декларировано здесь"
+msgstr "%q#D декларировано здесь"
 
 #: cp/parser.c:10397
 #, gcc-internal-format
@@ -50707,16 +44993,14 @@
 msgstr "явное by-reference capture %qD избыточно с by-reference capture умолчанием"
 
 #: cp/parser.c:10494
-#, fuzzy, gcc-internal-format
-#| msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
+#, gcc-internal-format
 msgid "lambda templates are only available with -std=c++14 or -std=gnu++14"
-msgstr "вариантные шаблоны доступны только с -std=c++11 или -std=gnu++11"
+msgstr "lambda шаблоны доступны только с -std=c++14 или -std=gnu++14"
 
 #: cp/parser.c:10498
-#, fuzzy, gcc-internal-format
-#| msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
+#, gcc-internal-format
 msgid "lambda templates are only available with -std=c++2a or -std=gnu++2a"
-msgstr "вариантные шаблоны доступны только с -std=c++11 или -std=gnu++11"
+msgstr ""
 
 #: cp/parser.c:10530
 #, gcc-internal-format
@@ -50724,22 +45008,19 @@
 msgstr "задан аргумент по умолчанию для lambda-параметра"
 
 #: cp/parser.c:10548
-#, fuzzy, gcc-internal-format
-#| msgid "duplicate %<volatile%>"
+#, gcc-internal-format
 msgid "duplicate %<mutable%>"
-msgstr "повторное употребление %<volatile%>"
+msgstr "повторное %<mutable%>"
 
 #: cp/parser.c:10595
-#, fuzzy, gcc-internal-format
-#| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
+#, gcc-internal-format
 msgid "%<constexpr%> lambda only available with -std=c++17 or -std=gnu++17"
-msgstr "C++11 %<constexpr%> доступно только с -std=c++11 или -std=gnu++11"
+msgstr ""
 
 #: cp/parser.c:10965 cp/parser.c:11158
-#, fuzzy, gcc-internal-format
-#| msgid "attributes after parenthesized initializer ignored"
+#, gcc-internal-format
 msgid "attributes at the beginning of statement are ignored"
-msgstr "атрибуты после инициализатора в скобках проигнорированы"
+msgstr "атрибуты в начале оператора игнорируются"
 
 #: cp/parser.c:11005
 #, gcc-internal-format
@@ -50754,7 +45035,7 @@
 #: cp/parser.c:11165
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
-msgstr "требуется %<typename%> перед %qE поскольку %qT зависимый контекст"
+msgstr "требуется %<typename%> перед %qE, поскольку %qT зависимый контекст"
 
 #: cp/parser.c:11174
 #, gcc-internal-format
@@ -50762,24 +45043,21 @@
 msgstr "%<%T::%D%> обозначает конструктор, а не тип"
 
 #: cp/parser.c:11222
-#, fuzzy, gcc-internal-format
-#| msgid "compound-statement in constexpr function"
+#, gcc-internal-format
 msgid "compound-statement in %<constexpr%> function"
-msgstr "составной оператор в constexpr функции"
+msgstr ""
 
 #: cp/parser.c:11349
-#, fuzzy, gcc-internal-format
-#| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
+#, gcc-internal-format
 msgid "%<if constexpr%> only available with -std=c++17 or -std=gnu++17"
-msgstr "C++11 %<constexpr%> доступно только с -std=c++11 или -std=gnu++11"
+msgstr ""
 
 #: cp/parser.c:11376
-#, fuzzy, gcc-internal-format
-#| msgid "delegating constructors only available with -std=c++11 or -std=gnu++11"
+#, gcc-internal-format
 msgid "init-statement in selection statements only available with -std=c++17 or -std=gnu++17"
-msgstr "делегирующие конструкторы доступны только с -std=c++11 или -std=gnu++11"
+msgstr ""
 
-#: cp/parser.c:11546 cp/parser.c:28490
+#: cp/parser.c:11546 cp/parser.c:28487
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "ожидался selection-statement"
@@ -50799,593 +45077,558 @@
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr "противоречивые begin/end типы в range-based %<for%> операторе: %qT и %qT"
 
-#: cp/parser.c:12250 cp/parser.c:28493
+#: cp/parser.c:12250 cp/parser.c:28490
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "ожидался iteration-statement"
 
-#: cp/parser.c:12298
-#, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
+#: cp/parser.c:12297
+#, gcc-internal-format
 msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
-msgstr "unrestricted объединения допустимы только с -std=c++11 или -std=gnu++11"
+msgstr "диапазонные %<for%> циклы доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:12426
-#, fuzzy, gcc-internal-format
-#| msgid "compound-statement in constexpr function"
+#: cp/parser.c:12423
+#, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
-msgstr "составной оператор в constexpr функции"
+msgstr "%<goto%> в %<constexpr%> функции"
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:12434
+#: cp/parser.c:12431
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ не поддерживает вычисляемые goto"
 
-#: cp/parser.c:12447 cp/parser.c:28496
+#: cp/parser.c:12444 cp/parser.c:28493
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "ожидался оператор перехода"
 
-#: cp/parser.c:12620 cp/parser.c:23584
+#: cp/parser.c:12617 cp/parser.c:23581
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "избыточная %<;%>"
 
-#: cp/parser.c:12863
+#: cp/parser.c:12860
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr "%<__label__%> не в начале блока"
 
-#: cp/parser.c:13083
+#: cp/parser.c:13080
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
-msgstr ""
+msgstr "непеременная %qD в декларации с более чем одним декларатором с типом заполнителем"
 
-#: cp/parser.c:13103
+#: cp/parser.c:13100
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr "противоречивый вывод для %qT: %qT и затем %qT"
 
-#: cp/parser.c:13124
+#: cp/parser.c:13121
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr "смешивание деклараций и определений функций запрещено"
 
-#: cp/parser.c:13148
-#, fuzzy, gcc-internal-format
-#| msgid "types may not be defined in exception-declarations"
+#: cp/parser.c:13145
+#, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
-msgstr "типы нельзя определять в exception-declarations"
+msgstr "типы нельзя определять в декларации for-диапазона"
 
-#: cp/parser.c:13203
+#: cp/parser.c:13200
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
-msgstr ""
+msgstr "инициализатор в диапазонном %<for%> цикле"
 
-#: cp/parser.c:13206
+#: cp/parser.c:13203
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
-msgstr ""
+msgstr "несколько деклараций в диапазонном %<for%> цикле"
 
-#: cp/parser.c:13257
-#, fuzzy, gcc-internal-format
-#| msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
+#: cp/parser.c:13254
+#, gcc-internal-format
 msgid "structured bindings only available with -std=c++17 or -std=gnu++17"
-msgstr "unrestricted объединения допустимы только с -std=c++11 или -std=gnu++11"
+msgstr ""
 
-#: cp/parser.c:13306
-#, fuzzy, gcc-internal-format
-#| msgid "expected declaration"
+#: cp/parser.c:13303
+#, gcc-internal-format
 msgid "empty structured binding declaration"
-msgstr "ожидалась декларация"
+msgstr ""
 
-#: cp/parser.c:13324
-#, fuzzy, gcc-internal-format
-#| msgid "invalid initializer for member function %qD"
+#: cp/parser.c:13321
+#, gcc-internal-format
 msgid "invalid initializer for structured binding declaration"
-msgstr "некорректный инициализатор для элемента-функции %qD"
+msgstr "некорректный инициализатор для структурированной связывающей декларации"
 
-#: cp/parser.c:13491
+#: cp/parser.c:13488
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr "%<friend%> использовано вне класса"
 
-#: cp/parser.c:13558
+#: cp/parser.c:13555
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr "%<auto%> меняет смысл в C++11; пожалуйста удалите его"
 
-#: cp/parser.c:13594
+#: cp/parser.c:13591
 #, gcc-internal-format
 msgid "decl-specifier invalid in condition"
 msgstr "decl-specifier некорректен в условии"
 
-#: cp/parser.c:13600
-#, fuzzy, gcc-internal-format
-#| msgid "%q+D invalid in %q#T"
+#: cp/parser.c:13597
+#, gcc-internal-format
 msgid "%qD invalid in lambda"
-msgstr "%q+D некорректно в %q#T"
+msgstr "%qD некорректно в lambda"
 
-#: cp/parser.c:13693
+#: cp/parser.c:13690
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "определение класса не должно содержать friend"
 
-#: cp/parser.c:13763 cp/parser.c:24064
+#: cp/parser.c:13760 cp/parser.c:24061
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr "шаблоны не могут быть %<virtual%>"
 
-#: cp/parser.c:13805
+#: cp/parser.c:13802
 #, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr "некорректная linkage-specification"
 
-#: cp/parser.c:13909
-#, fuzzy, gcc-internal-format
-#| msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
+#: cp/parser.c:13906
+#, gcc-internal-format
 msgid "static_assert without a message only available with -std=c++17 or -std=gnu++17"
-msgstr "inline namespaces доступны только с -std=c++11 или -std=gnu++11"
+msgstr ""
 
-#: cp/parser.c:14111
+#: cp/parser.c:14108
 #, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr "типы нельзя определять в %<decltype%> выражениях"
 
-#: cp/parser.c:14264
-#, fuzzy, gcc-internal-format
-#| msgid "types may not be defined in a new-type-id"
+#: cp/parser.c:14261
+#, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
-msgstr "типы не могут быть определены в new-type-id"
+msgstr "типы не могут быть определены в conversion-type-id"
 
-#: cp/parser.c:14291
+#: cp/parser.c:14288
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "некорректное использование %<auto%> в операторе преобразования"
 
-#: cp/parser.c:14295
-#, fuzzy, gcc-internal-format
-#| msgid "invalid use of %<auto%> in conversion operator"
+#: cp/parser.c:14292
+#, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
-msgstr "некорректное использование %<auto%> в операторе преобразования"
+msgstr "использование %<auto%> в операторе преобразования элемента шаблона не может быть приведено"
 
-#: cp/parser.c:14379
+#: cp/parser.c:14376
 #, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr "только конструкторы берут инициализаторы элементов"
 
-#: cp/parser.c:14406
-#, fuzzy, gcc-internal-format
-#| msgid "cannot expand initializer for member %<%D%>"
+#: cp/parser.c:14403
+#, gcc-internal-format
 msgid "cannot expand initializer for member %qD"
-msgstr "невозможно расширить инициализатор для элемента %<%D%>"
+msgstr ""
 
-#: cp/parser.c:14418 cp/pt.c:24255
+#: cp/parser.c:14415 cp/pt.c:24333
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "mem-initializer для %qD следует за constructor delegation"
 
-#: cp/parser.c:14430 cp/pt.c:24267
+#: cp/parser.c:14427 cp/pt.c:24345
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr "constructor delegation следует за mem-initializer для %qD"
 
-#: cp/parser.c:14482
+#: cp/parser.c:14479
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr "устаревший стиль инициализатора базового класса"
 
-#: cp/parser.c:14552
+#: cp/parser.c:14549
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr "ключевое слово %<typename%> запрещено в этом контексте (инициализатор квалифицированного элемента неявно является типом)"
 
-#: cp/parser.c:14927
-#, fuzzy, gcc-internal-format
-#| msgid "missing space between %<\"\"%> and suffix identifier"
+#: cp/parser.c:14924
+#, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
-msgstr "отсутствует пробел между %<\"\"%> и суффикс-идентификатором"
+msgstr "неожиданное ключевое слово; удалите пробел между кавычками и суффикс идентификатором"
 
-#: cp/parser.c:14933
+#: cp/parser.c:14930
 #, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr "ожидался суффикс-идентификатор"
 
-#: cp/parser.c:14942
+#: cp/parser.c:14939
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr "ожидалась пустая строка после ключевого слова %<operator%>"
 
-#: cp/parser.c:14948
-#, fuzzy, gcc-internal-format
-#| msgid "invalid operands in ternary operation"
+#: cp/parser.c:14945
+#, gcc-internal-format
 msgid "invalid encoding prefix in literal operator"
-msgstr "неверные операнды тернарной операции"
+msgstr "некорректный префикс кодировки в литеральном операторе"
 
-#: cp/parser.c:14975
+#: cp/parser.c:14972
 #, gcc-internal-format
 msgid "expected operator"
 msgstr "ожидался оператор"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:15020
+#: cp/parser.c:15017
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "ключевое слово %<export%> не реализовано; игнорируется"
 
-#: cp/parser.c:15190
-#, fuzzy, gcc-internal-format
-#| msgid "invalid template non-type parameter"
+#: cp/parser.c:15187
+#, gcc-internal-format
 msgid "invalid constrained type parameter"
-msgstr "некорректный нетиповый параметр шаблона"
+msgstr "некорректный constrained type параметр"
 
 #
-#: cp/parser.c:15198
-#, fuzzy, gcc-internal-format
-#| msgid "invalid catch parameter"
+#: cp/parser.c:15195
+#, gcc-internal-format
 msgid "cv-qualified type parameter"
-msgstr "некорректный catch параметр"
+msgstr "cv-qualified type параметр"
 
-#: cp/parser.c:15283
+#: cp/parser.c:15280
 #, gcc-internal-format
 msgid "variadic constraint introduced without %<...%>"
-msgstr ""
+msgstr "вариантное ограничение введено без %<...%>"
 
-#: cp/parser.c:15347
-#, fuzzy, gcc-internal-format
-#| msgid "invalid use of template template parameter %qT"
+#: cp/parser.c:15344
+#, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
-msgstr "некорректное использование шаблона параметра шаблона %qT"
+msgstr "некорректное использование %<auto%> в подразумеваемом аргументе шаблона"
 
-#: cp/parser.c:15582 cp/parser.c:15668 cp/parser.c:21694
+#: cp/parser.c:15579 cp/parser.c:15665 cp/parser.c:21691
 #, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "pack параметр шаблона %qD не может иметь аргумент по умолчанию"
 
-#: cp/parser.c:15586 cp/parser.c:15672
+#: cp/parser.c:15583 cp/parser.c:15669
 #, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr "pack параметры шаблона не могут иметь аргументы по умолчанию"
 
-#: cp/parser.c:15738
+#: cp/parser.c:15735
 #, gcc-internal-format
 msgid "expected template-id"
 msgstr "ожидался template-id"
 
-#: cp/parser.c:15798
+#: cp/parser.c:15795
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "список аргументов шаблона не должен начинаться с %<<::%>"
 
-#: cp/parser.c:15802
+#: cp/parser.c:15799
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
-msgstr "%<<:%> - альтернативное написание %<[%>. Вставьте пробел между %<<%> и %<::%>"
+msgstr ""
 
-#: cp/parser.c:15806
-#, fuzzy, gcc-internal-format
-#| msgid "(if you use %<-fpermissive%> G++ will accept your code)"
+#: cp/parser.c:15803
+#, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
-msgstr "(если вы используете %<-fpermissive%> G++ примет ваш код)"
+msgstr "(если вы используете %<-fpermissive%> или %<-std=c++11%> или %<-std=gnu++11%> G++ примет ваш код)"
 
-#: cp/parser.c:15924
+#: cp/parser.c:15921
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "ошибка разбора в списке аргументов шаблона"
 
 #. The name does not name a template.
-#: cp/parser.c:15992 cp/parser.c:16122 cp/parser.c:16337
+#: cp/parser.c:15989 cp/parser.c:16119 cp/parser.c:16334
 #, gcc-internal-format
 msgid "expected template-name"
 msgstr "ожидалось template-name"
 
 #. Explain what went wrong.
-#: cp/parser.c:16038
+#: cp/parser.c:16035
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr "не шаблон %qD использован как шаблон"
 
-#: cp/parser.c:16040
+#: cp/parser.c:16037
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr "используйте нотацию %<%T::template %D%> для указания о том, что это шаблон"
 
-#: cp/parser.c:16189
+#: cp/parser.c:16186
 #, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr "ожидался pack параметр перед %<...%>"
 
-#: cp/parser.c:16298 cp/parser.c:16316 cp/parser.c:16483
+#: cp/parser.c:16295 cp/parser.c:16313 cp/parser.c:16480
 #, gcc-internal-format
 msgid "expected template-argument"
 msgstr "ожидался template-argument"
 
-#: cp/parser.c:16458
+#: cp/parser.c:16455
 #, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr "некорректный нетиповый аргумент шаблона"
 
-#: cp/parser.c:16585
+#: cp/parser.c:16582
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "явная конкретизация не должна использовать %<inline%> спецификатор"
 
-#: cp/parser.c:16589
+#: cp/parser.c:16586
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "явная конкретизация не должна использовать %<constexpr%> спецификатор"
 
-#: cp/parser.c:16648
+#: cp/parser.c:16645
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr "специализация шаблона с привязкой C"
 
-#: cp/parser.c:16869
+#: cp/parser.c:16866
 #, gcc-internal-format
 msgid "expected type specifier"
 msgstr "ожидался спецификатор типа"
 
-#: cp/parser.c:17053
-#, fuzzy, gcc-internal-format
-#| msgid "defaulted and deleted functions only available with -std=c++11 or -std=gnu++11"
+#: cp/parser.c:17050
+#, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
-msgstr "сведенные к подразумеваемым и удаленные функции доступны только с -std=c++11 или -std=gnu++11"
+msgstr "использование %<auto%> в декларации lambda параметра доступно только с -std=c++14 или -std=gnu++14"
 
-#: cp/parser.c:17059
-#, fuzzy, gcc-internal-format
-#| msgid "defaulted and deleted functions only available with -std=c++11 or -std=gnu++11"
+#: cp/parser.c:17056
+#, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
-msgstr "сведенные к подразумеваемым и удаленные функции доступны только с -std=c++11 или -std=gnu++11"
+msgstr "использование %<auto%> в декларации параметра доступно только с -std=c++14 или -std=gnu++14"
 
-#: cp/parser.c:17064
-#, fuzzy, gcc-internal-format
-#| msgid "defaulted and deleted functions only available with -std=c++11 or -std=gnu++11"
+#: cp/parser.c:17061
+#, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -fconcepts"
-msgstr "сведенные к подразумеваемым и удаленные функции доступны только с -std=c++11 или -std=gnu++11"
+msgstr ""
 
-#: cp/parser.c:17209
+#: cp/parser.c:17206
 #, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "ожидался template-id для типа"
 
-#: cp/parser.c:17278
+#: cp/parser.c:17275
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr "ожидалось имя типа"
 
-#: cp/parser.c:17631
-#, fuzzy, gcc-internal-format
-#| msgid "elaborated-type-specifier for a scoped enum must not use the %<%D%> keyword"
+#: cp/parser.c:17628
+#, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
-msgstr "elaborated-type-specifier для scoped enum не должен использовать ключевое слово %<%D%>"
+msgstr ""
 
-#: cp/parser.c:17854
+#: cp/parser.c:17851
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "декларация %qD ничего не декларирует"
 
-#: cp/parser.c:17942
+#: cp/parser.c:17939
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "атрибуты игнорируются для неконкретизированного типа"
 
-#: cp/parser.c:17946
+#: cp/parser.c:17943
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "атрибуты игнорируются для конкретизации шаблона"
 
-#: cp/parser.c:17951
+#: cp/parser.c:17948
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
-msgstr "атрибуты игнорируются для elaborated-type-specifier который не является forward декларацией"
+msgstr "атрибуты игнорируются для elaborated-type-specifier, который не является forward декларацией"
 
-#: cp/parser.c:18085
+#: cp/parser.c:18082
 #, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "%qD является шаблоном перечисления"
 
-#: cp/parser.c:18096
-#, fuzzy, gcc-internal-format
-#| msgid "%qD does not have integral or enumeration type"
+#: cp/parser.c:18093
+#, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
-msgstr "%qD не имеет целый или перечислимый тип"
+msgstr "%qD не именует перечисление в %qT"
 
-#: cp/parser.c:18111
-#, fuzzy, gcc-internal-format
-#| msgid "%<namespace%> definition is not allowed here"
+#: cp/parser.c:18108
+#, gcc-internal-format
 msgid "unnamed scoped enum is not allowed"
-msgstr "%<namespace%> определение здесь не допускается"
+msgstr "неименованный scoped enum не допускается"
 
-#: cp/parser.c:18166
+#: cp/parser.c:18163
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "ожидалось %<;%> или %<{%>"
 
-#: cp/parser.c:18215
+#: cp/parser.c:18212
 #, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "невозможно добавить enumerator список к конкретизации шаблона"
 
-#: cp/parser.c:18229
-#, fuzzy, gcc-internal-format
-#| msgid "friend declaration does not name a class or function"
+#: cp/parser.c:18226
+#, gcc-internal-format
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
-msgstr "в декларации friend нет имени класса или функции"
+msgstr "вложенный спецификатор имени %qT для enum декларации не именует класс или пространство имен"
 
-#: cp/parser.c:18241 cp/parser.c:23070
+#: cp/parser.c:18238 cp/parser.c:23067
 #, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "декларация %qD в пространстве имен %qD, которое не включает %qD"
 
-#: cp/parser.c:18246 cp/parser.c:23075
+#: cp/parser.c:18243 cp/parser.c:23072
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "декларация %qD в %qD, который не объемлет %qD"
 
-#: cp/parser.c:18258 cp/parser.c:23089
+#: cp/parser.c:18255 cp/parser.c:23086
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr "избыточная квалификация не допускается"
 
-#: cp/parser.c:18282
+#: cp/parser.c:18279
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "повторное определение %q#T"
 
-#: cp/parser.c:18295
-#, fuzzy, gcc-internal-format
-#| msgid "ISO C++ forbids incrementing an enum"
+#: cp/parser.c:18292
+#, gcc-internal-format
 msgid "ISO C++ forbids empty unnamed enum"
-msgstr "ISO C++ запрещает инкрементирование enum"
+msgstr "ISO C++ запрещает пустой неименованный enum"
 
-#: cp/parser.c:18315
+#: cp/parser.c:18312
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr "opaque-enum-specifier без имени"
 
-#: cp/parser.c:18318
+#: cp/parser.c:18315
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr "opaque-enum-specifier должен использовать простой идентификатор"
 
-#: cp/parser.c:18497
+#: cp/parser.c:18494
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD не есть namespace-name"
 
-#: cp/parser.c:18503
+#: cp/parser.c:18500
 #, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "ожидалось namespace-name"
 
-#: cp/parser.c:18570
-#, fuzzy, gcc-internal-format
-#| msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
+#: cp/parser.c:18567
+#, gcc-internal-format
 msgid "nested namespace definitions only available with -std=c++17 or -std=gnu++17"
-msgstr "inline namespaces доступны только с -std=c++11 или -std=gnu++11"
+msgstr ""
 
-#: cp/parser.c:18578
-#, fuzzy, gcc-internal-format
-#| msgid "expected namespace-name"
+#: cp/parser.c:18575
+#, gcc-internal-format
 msgid "nested namespace name required"
-msgstr "ожидалось namespace-name"
+msgstr ""
 
-#: cp/parser.c:18583
-#, fuzzy, gcc-internal-format
-#| msgid "use of namespace %qD as expression"
+#: cp/parser.c:18580
+#, gcc-internal-format
 msgid "namespace name required"
-msgstr "использование пространства имён %qD в качестве выражения"
+msgstr ""
 
-#: cp/parser.c:18587
-#, fuzzy, gcc-internal-format
-#| msgid "%<namespace%> definition is not allowed here"
+#: cp/parser.c:18584
+#, gcc-internal-format
 msgid "a nested namespace definition cannot have attributes"
-msgstr "%<namespace%> определение здесь не допускается"
+msgstr "определение вложенного пространства имен не может иметь атрибуты"
 
-#: cp/parser.c:18590
-#, fuzzy, gcc-internal-format
-#| msgid "Warn when an inlined function cannot be inlined"
+#: cp/parser.c:18587
+#, gcc-internal-format
 msgid "a nested namespace definition cannot be inline"
-msgstr "Предупреждать об inline-функциях, подстановка которых невозможна"
+msgstr "определение вложенного пространства имен не может быть inline"
 
-#: cp/parser.c:18597
-#, fuzzy, gcc-internal-format
-#| msgid "use of namespace %qD as expression"
+#: cp/parser.c:18594
+#, gcc-internal-format
 msgid "namespace %qD entered"
-msgstr "использование пространства имён %qD в качестве выражения"
+msgstr "вход в пространство имен %qD"
 
-#: cp/parser.c:18652
+#: cp/parser.c:18649
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "%<namespace%> определение здесь не допускается"
 
-#: cp/parser.c:18803
-#, fuzzy, gcc-internal-format
-#| msgid "lambda expressions only available with -std=c++11 or -std=gnu++11"
+#: cp/parser.c:18800
+#, gcc-internal-format
 msgid "pack expansion in using-declaration only available with -std=c++17 or -std=gnu++17"
-msgstr "lambda-выражения доступны только с -std=c++11 или -std=gnu++11"
+msgstr ""
 
-#: cp/parser.c:18818
+#: cp/parser.c:18815
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "идентификатор шаблона недопустим в using-декларации"
 
-#: cp/parser.c:18865
-#, fuzzy, gcc-internal-format
-#| msgid "defaulted and deleted functions only available with -std=c++11 or -std=gnu++11"
+#: cp/parser.c:18862
+#, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with -std=c++17 or -std=gnu++17"
-msgstr "сведенные к подразумеваемым и удаленные функции доступны только с -std=c++11 или -std=gnu++11"
+msgstr ""
 
-#: cp/parser.c:18875
+#: cp/parser.c:18872
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr "декларациям доступа следует предпочесть using-declarations; предлагается: добавьте ключевое слово %<using%>"
 
-#: cp/parser.c:18940
+#: cp/parser.c:18937
 #, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "типы нельзя определять в алиасных декларациях шаблонов"
 
-#: cp/parser.c:19106
-#, fuzzy, gcc-internal-format
-#| msgid "compound-statement in constexpr function"
+#: cp/parser.c:19103
+#, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
-msgstr "составной оператор в constexpr функции"
+msgstr "%<asm%> в %<constexpr%> функции"
 
-#: cp/parser.c:19493
+#: cp/parser.c:19490
 #, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "function-definition здесь не допускается"
 
-#: cp/parser.c:19504
+#: cp/parser.c:19501
 #, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr "спецификация asm не допускается при определении функции"
 
-#: cp/parser.c:19508
+#: cp/parser.c:19505
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "атрибуты не допускаются при определении функции"
 
-#: cp/parser.c:19559
+#: cp/parser.c:19556
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr "ожидался конструктор, деструктор или преобразование типа"
 
 #. Anything else is an error.
-#: cp/parser.c:19598 cp/parser.c:21906
+#: cp/parser.c:19595 cp/parser.c:21903
 #, gcc-internal-format
 msgid "expected initializer"
 msgstr "ожидался инициализатор"
 
-#: cp/parser.c:19679
+#: cp/parser.c:19676
 #, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "инициализатор задан для функции"
 
-#: cp/parser.c:19713
+#: cp/parser.c:19710
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "атрибуты после инициализатора в скобках проигнорированы"
 
-#: cp/parser.c:19727
-#, fuzzy, gcc-internal-format
-#| msgid "function %q+D redeclared as inline"
+#: cp/parser.c:19724
+#, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
-msgstr "функция %q+D повторно декларирована как inline"
+msgstr "не-функция %qD декларирована как неявный шаблон"
 
-#: cp/parser.c:20169
+#: cp/parser.c:20166
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "граница массива не является целой константой"
 
-#: cp/parser.c:20295
+#: cp/parser.c:20292
 #, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr "невозможно определить элемент зависимого typedef %qT"
 
-#: cp/parser.c:20299
+#: cp/parser.c:20296
 #, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "%<%T::%E%> не является типом"
@@ -51394,17 +45637,17 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:20328
+#: cp/parser.c:20325
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr "некорректная декларация"
 
-#: cp/parser.c:20336
+#: cp/parser.c:20333
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "некорректное использование конструктора как шаблона"
 
-#: cp/parser.c:20338
+#: cp/parser.c:20335
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr "используйте %<%T::%D%> вместо %<%T::%D%> для именования конструктора в имени с квалификатором"
@@ -51411,410 +45654,383 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:20410
-#, fuzzy, gcc-internal-format
-#| msgid "invalid type in declaration"
+#: cp/parser.c:20407
+#, gcc-internal-format
 msgid "qualified-id in declaration"
-msgstr "некорректный тип в декларации"
+msgstr "квалифицированный идентификатор в декларации"
 
-#: cp/parser.c:20435
+#: cp/parser.c:20432
 #, gcc-internal-format
 msgid "expected declarator"
 msgstr "ожидалась декларация"
 
-#: cp/parser.c:20554
+#: cp/parser.c:20551
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD является пространством имён"
 
-#: cp/parser.c:20556
+#: cp/parser.c:20553
 #, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "невозможно сформировать указатель на элемент не класса %q#T"
 
-#: cp/parser.c:20577
+#: cp/parser.c:20574
 #, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "ожидался ptr-operator"
 
-#: cp/parser.c:20638
+#: cp/parser.c:20635
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "повторный cv-qualifier"
 
-#: cp/parser.c:20692
-#, fuzzy, gcc-internal-format
-#| msgid "duplicate cv-qualifier"
+#: cp/parser.c:20689
+#, gcc-internal-format
 msgid "multiple ref-qualifiers"
-msgstr "повторный cv-qualifier"
+msgstr "несколько ref-квалификаторов"
 
-#: cp/parser.c:20729
-#, fuzzy, gcc-internal-format
-#| msgid "%<-mips3d%> requires %<-mpaired-single%>"
+#: cp/parser.c:20726
+#, gcc-internal-format
 msgid "%qE requires %<-fgnu-tm%>"
-msgstr "для %<-mips3d%> требуется %<-mpaired-single%>"
+msgstr ""
 
-#: cp/parser.c:20787
+#: cp/parser.c:20784
 #, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "повторный virt-specifier"
 
-#: cp/parser.c:21025
-#, fuzzy, gcc-internal-format
-#| msgid "in template argument for type %qT "
+#: cp/parser.c:21022
+#, gcc-internal-format
 msgid "missing template arguments after %qT"
-msgstr "в аргументе шаблона для типа %qT "
+msgstr "отсутствуют аргументы шаблона после %qT"
 
-#: cp/parser.c:21031 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2090
+#: cp/parser.c:21028 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2093
 #, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr "некорректное использование %qT"
 
-#: cp/parser.c:21052
+#: cp/parser.c:21049
 #, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "типы нельзя определять в аргументах шаблона"
 
-#: cp/parser.c:21057
-#, fuzzy, gcc-internal-format
-#| msgid "invalid non-type template argument"
+#: cp/parser.c:21054
+#, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
-msgstr "некорректный нетиповый аргумент шаблона"
+msgstr "некорректное использование %<auto%> в аргументе шаблона"
 
-#: cp/parser.c:21145
+#: cp/parser.c:21142
 #, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "ожидался type-specifier"
 
-#: cp/parser.c:21429
+#: cp/parser.c:21426
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "ожидалось %<,%> или %<...%>"
 
-#: cp/parser.c:21504
+#: cp/parser.c:21501
 #, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr "типы нельзя определять в типах параметров"
 
-#: cp/parser.c:21678
+#: cp/parser.c:21675
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "аргументы по умолчанию разрешены только для параметров функций"
 
-#: cp/parser.c:21696
+#: cp/parser.c:21693
 #, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "parameter pack %qD не может иметь подразумеваемый аргумент"
 
-#: cp/parser.c:21702
+#: cp/parser.c:21699
 #, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr "pack параметр шаблона не может иметь аргумент по умолчанию"
 
-#: cp/parser.c:21704
+#: cp/parser.c:21701
 #, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr "parameter pack не может иметь подразумеваемый аргумент"
 
-#: cp/parser.c:22131
-#, fuzzy, gcc-internal-format
-#| msgid "extended initializer lists only available with -std=c++11 or -std=gnu++11"
+#: cp/parser.c:22128
+#, gcc-internal-format
 msgid "C++ designated initializers only available with -std=c++2a or -std=gnu++2a"
-msgstr "расширенные списки инициализации доступны только с -std=c++11 или -std=gnu++11"
+msgstr ""
 
-#: cp/parser.c:22151
-#, fuzzy, gcc-internal-format
-#| msgid "ISO C++ does not allow designated initializers"
+#: cp/parser.c:22148
+#, gcc-internal-format
 msgid "ISO C++ does not allow GNU designated initializers"
-msgstr "ISO C++ не поддерживает назначенные инициализаторы"
+msgstr ""
 
-#: cp/parser.c:22189
+#: cp/parser.c:22186
 #, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C++ не поддерживает C99 назначенные инициализаторы"
 
-#: cp/parser.c:22203
+#: cp/parser.c:22200
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr ""
 
-#: cp/parser.c:22228
-#, fuzzy, gcc-internal-format
-#| msgid "ISO C++ does not allow designated initializers"
+#: cp/parser.c:22225
+#, gcc-internal-format
 msgid "%<...%> not allowed in designated initializer list"
-msgstr "ISO C++ не поддерживает назначенные инициализаторы"
+msgstr ""
 
-#: cp/parser.c:22266
+#: cp/parser.c:22263
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr ""
 
-#: cp/parser.c:22322 cp/parser.c:22448
+#: cp/parser.c:22319 cp/parser.c:22445
 #, gcc-internal-format
 msgid "expected class-name"
 msgstr "ожидалось class-name"
 
-#: cp/parser.c:22650
+#: cp/parser.c:22647
 #, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "ожидалось %<;%> после определения класса"
 
-#: cp/parser.c:22653
+#: cp/parser.c:22650
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "ожидалось %<;%> после определения структуры"
 
-#: cp/parser.c:22656
+#: cp/parser.c:22653
 #, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "ожидалось %<;%> после определения объединения"
 
-#: cp/parser.c:23012
+#: cp/parser.c:23009
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "ожидалось %<{%> или %<:%>"
 
-#: cp/parser.c:23023
+#: cp/parser.c:23020
 #, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "невозможно задать %<override%> для класса"
 
-#: cp/parser.c:23031
+#: cp/parser.c:23028
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr "global квалификация имени класса некорректна"
 
-#: cp/parser.c:23038
+#: cp/parser.c:23035
 #, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "квалифицированное имя не именует класс"
 
-#: cp/parser.c:23050
-#, fuzzy, gcc-internal-format
-#| msgid "keyword %<typename%> not allowed outside of templates"
+#: cp/parser.c:23047
+#, gcc-internal-format
 msgid "keyword %<template%> not allowed in class-head-name"
-msgstr "ключевое слово %<typename%> не допускается вне шаблонов"
+msgstr ""
 
-#: cp/parser.c:23056
+#: cp/parser.c:23053
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "некорректное имя класса в декларации %qD"
 
-#: cp/parser.c:23114
+#: cp/parser.c:23111
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "перед явной специализацией должно быть %<template <>%>"
 
-#: cp/parser.c:23146
+#: cp/parser.c:23143
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "шаблон функции %qD редекларирован как шаблон класса"
 
-#: cp/parser.c:23182
+#: cp/parser.c:23179
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr "невозможно разрешить typename type"
 
-#: cp/parser.c:23241
-#, fuzzy, gcc-internal-format
-#| msgid "previous definition of %q+#T"
+#: cp/parser.c:23238
+#, gcc-internal-format
 msgid "previous definition of %q#T"
-msgstr "предыдущее определение %q+#T"
+msgstr "предыдущее определение %q#T"
 
-#: cp/parser.c:23331 cp/parser.c:28499
+#: cp/parser.c:23328 cp/parser.c:28496
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr "ожидалось class-key"
 
-#: cp/parser.c:23355
+#: cp/parser.c:23352
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:23359
-#, fuzzy, gcc-internal-format
-#| msgid "expected %<class%>, %<typename%>, or %<template%>"
+#: cp/parser.c:23356
+#, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
-msgstr "ожидалось %<class%>, %<typename%> или %<template%>"
+msgstr "ожидалось %<class%> или %<typename%>"
 
-#: cp/parser.c:23605
+#: cp/parser.c:23602
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr "в C++03 class-key должен использоваться при декларировании friend"
 
-#: cp/parser.c:23623
+#: cp/parser.c:23620
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "в декларации friend нет имени класса или функции"
 
-#: cp/parser.c:23641
+#: cp/parser.c:23638
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
-msgstr ""
+msgstr "класс хранения для анонимного агрегата в контексте класса недопустим"
 
-#: cp/parser.c:23738
-#, fuzzy, gcc-internal-format
-#| msgid "extended initializer lists only available with -std=c++11 or -std=gnu++11"
+#: cp/parser.c:23735
+#, gcc-internal-format
 msgid "default member initializers for bit-fields only available with -std=c++2a or -std=gnu++2a"
-msgstr "расширенные списки инициализации доступны только с -std=c++11 или -std=gnu++11"
+msgstr ""
 
-#: cp/parser.c:23745
-#, fuzzy, gcc-internal-format
-#| msgid "alignment specified for unnamed bit-field"
+#: cp/parser.c:23742
+#, gcc-internal-format
 msgid "default member initializer for unnamed bit-field"
-msgstr "выравнивание задано для безымянного битового поля"
+msgstr ""
 
-#: cp/parser.c:23758
+#: cp/parser.c:23755
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr ""
 
-#: cp/parser.c:23903
+#: cp/parser.c:23900
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr "спецификатор pure в определении функции"
 
-#: cp/parser.c:23923
-#, fuzzy, gcc-internal-format
-#| msgid "expected %<;%> after class definition"
+#: cp/parser.c:23920
+#, gcc-internal-format
 msgid "extra %<;%> after in-class function definition"
-msgstr "ожидалось %<;%> после определения класса"
+msgstr ""
 
-#: cp/parser.c:23970
-#, fuzzy, gcc-internal-format
-#| msgid "expected %<;%> at end of member declaration"
+#: cp/parser.c:23967
+#, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
-msgstr "ожидалось %<;%> в конце декларации элемента"
+msgstr "случайная %<,%> в конце декларации элемента"
 
-#: cp/parser.c:23984
+#: cp/parser.c:23981
 #, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "ожидалось %<;%> в конце декларации элемента"
 
-#: cp/parser.c:24058
+#: cp/parser.c:24055
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr "некорректный спецификатор pure (только %<= 0%> допускается)"
 
-#: cp/parser.c:24093
+#: cp/parser.c:24090
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "инициализатор в фигурных скобках здесь не допускается"
 
-#: cp/parser.c:24223
-#, fuzzy, gcc-internal-format
-#| msgid "%<virtual%> specified more than once in base-specified"
+#: cp/parser.c:24220
+#, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
-msgstr "%<virtual%> задано более одного раза в base-specified"
+msgstr "%<virtual%> задано более одного раза в base-спецификаторе"
 
-#: cp/parser.c:24243
-#, fuzzy, gcc-internal-format
-#| msgid "more than one access specifier in base-specified"
+#: cp/parser.c:24240
+#, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
-msgstr "более одного спецификатора access в base-specified"
+msgstr "более одного спецификатора access в base-спецификаторе"
 
-#: cp/parser.c:24267
+#: cp/parser.c:24264
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "ключевое слово %<typename%> не допускается вне шаблонов"
 
-#: cp/parser.c:24270
+#: cp/parser.c:24267
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "ключевое слово %<typename%> запрещено в этом контексте (базовый класс неявно является типом)"
 
-#: cp/parser.c:24364 cp/parser.c:24442
+#: cp/parser.c:24361 cp/parser.c:24439
 #, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "типы нельзя определять в exception-specification"
 
-#: cp/parser.c:24450
-#, fuzzy, gcc-internal-format
-#| msgid "due to different exception specifications"
+#: cp/parser.c:24447
+#, gcc-internal-format
 msgid "ISO C++17 does not allow dynamic exception specifications"
-msgstr "из-за различных спецификаций исключений"
+msgstr ""
 
-#: cp/parser.c:24456
-#, fuzzy, gcc-internal-format
-#| msgid "dynamic exception specifications are deprecated in C++0x; use %<noexcept%> instead"
+#: cp/parser.c:24453
+#, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
-msgstr "динамические спецификации исключений не рекомендуются в C++0x; использийте вместо этого %<noexcept%>"
+msgstr "динамические спецификации исключительных ситуаций считаются устаревшими в C++11"
 
-#: cp/parser.c:24500
-#, fuzzy, gcc-internal-format
-#| msgid "invalid use of %<auto%> in conversion operator"
+#: cp/parser.c:24497
+#, gcc-internal-format
 msgid "invalid use of %<auto%> in exception-specification"
-msgstr "некорректное использование %<auto%> в операторе преобразования"
+msgstr "некорректное использование %<auto%> в спецификации исключительной ситуации"
 
 #
-#: cp/parser.c:24539
-#, fuzzy, gcc-internal-format
-#| msgid "%qD is not %<constexpr%>"
+#: cp/parser.c:24536
+#, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
-msgstr "%qD не есть %<constexpr%>"
+msgstr "%<try%> в %<constexpr%> функции"
 
-#: cp/parser.c:24650
+#: cp/parser.c:24647
 #, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr "типы нельзя определять в exception-declarations"
 
-#: cp/parser.c:25203
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute conflicts with attribute %s"
+#: cp/parser.c:25200
+#, gcc-internal-format
 msgid "attribute using prefix used together with scoped attribute token"
-msgstr "атрибут %qE конфликтует с атрибутом %s"
+msgstr "атрибутный using префикс использован вместе с scoped attribute token"
 
-#: cp/parser.c:25217
-#, fuzzy, gcc-internal-format
-#| msgid "expected identifier before string constant"
+#: cp/parser.c:25214
+#, gcc-internal-format
 msgid "expected an identifier for the attribute name"
-msgstr "ожидался идентификатор перед строковой константой"
+msgstr "ожидался идентификатор для имени атрибута"
 
-#: cp/parser.c:25301
+#: cp/parser.c:25298
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
-msgstr ""
+msgstr "атрибут %<noreturn%> может появляться не более одного раза в списке атрибутов"
 
-#: cp/parser.c:25305
+#: cp/parser.c:25302
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
-msgstr ""
+msgstr "атрибут %<deprecated%> может появляться не более одного раза в списке атрибутов"
 
-#: cp/parser.c:25342
-#, fuzzy, gcc-internal-format
-#| msgid "unexpected attribute before %qE"
+#: cp/parser.c:25339
+#, gcc-internal-format
 msgid "expected attribute before %<...%>"
-msgstr "неожиданный атрибут перед %qE"
+msgstr "ожидался атрибут перед %<...%>"
 
-#: cp/parser.c:25403
-#, fuzzy, gcc-internal-format
-#| msgid "C++0x auto only available with -std=c++11 or -std=gnu++11"
+#: cp/parser.c:25400
+#, gcc-internal-format
 msgid "attribute using prefix only available with -std=c++17 or -std=gnu++17"
-msgstr "C++0x auto доступны только с -std=c++11 или -std=gnu++11"
+msgstr ""
 
-#: cp/parser.c:25721
-#, fuzzy, gcc-internal-format
-#| msgid "%<@required%> is not available in Objective-C 1.0"
+#: cp/parser.c:25718
+#, gcc-internal-format
 msgid "%<requires%> only available with -fconcepts"
-msgstr "%<@required%> недоступно в Objective-C 1.0"
+msgstr "%<requires%> доступно только с -fconcepts"
 
-#: cp/parser.c:25753
-#, fuzzy, gcc-internal-format
-#| msgid "a transaction expression cannot appear in a constant-expression"
+#: cp/parser.c:25750
+#, gcc-internal-format
 msgid "a requires expression cannot appear outside a template"
-msgstr "транзакционное выражение не может присутствовать в константном выражении"
+msgstr "requires выражение не может появляться вне шаблона"
 
-#: cp/parser.c:26467
+#: cp/parser.c:26464
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr "специализация элемента %<%T::%E%> требует %<template<>%> синтаксис"
 
-#: cp/parser.c:26472
+#: cp/parser.c:26469
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "некорректная декларация %<%T::%E%>"
 
-#: cp/parser.c:26476
+#: cp/parser.c:26473
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "недостаточно списков параметров шаблонов"
@@ -51823,473 +46039,454 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:26483
+#: cp/parser.c:26480
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "слишком много списков параметров шаблонов"
 
-#: cp/parser.c:26832
+#: cp/parser.c:26829
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "именованные возвращаемые значения больше не поддерживаются"
 
-#: cp/parser.c:26991
-#, fuzzy, gcc-internal-format
-#| msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
+#: cp/parser.c:26988
+#, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
-msgstr "шаблон литерального оператора %qD имеет некорректный список параметров. Ожидался нетиповый pack аргумент шаблона <char...>"
+msgstr ""
 
-#: cp/parser.c:26996
+#: cp/parser.c:26993
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
-msgstr "шаблон литерального оператора %qD имеет некорректный список параметров. Ожидался нетиповый pack аргумент шаблона <char...>"
+msgstr ""
 
-#: cp/parser.c:27066
-#, fuzzy, gcc-internal-format
-#| msgid "Enable multiply instructions"
+#: cp/parser.c:27063
+#, gcc-internal-format
 msgid "empty introduction-list"
-msgstr "Включить инструкции умножения"
+msgstr "пустой introduction-список"
 
-#: cp/parser.c:27090
-#, fuzzy, gcc-internal-format
-#| msgid "no matching template for %qD found"
+#: cp/parser.c:27087
+#, gcc-internal-format
 msgid "no matching concept for template-introduction"
-msgstr "нет подходящего шаблона для %qD"
+msgstr "нет подходящего concept для template-introduction"
 
-#: cp/parser.c:27112
+#: cp/parser.c:27109
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "некорректная декларация шаблона элемента в локальном классе"
 
-#: cp/parser.c:27121
+#: cp/parser.c:27118
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "шаблон с привязкой C"
 
-#: cp/parser.c:27141
+#: cp/parser.c:27138
 #, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "некорректная явная специализация"
 
-#: cp/parser.c:27245
+#: cp/parser.c:27242
 #, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "шаблонная декларация %<typedef%>"
 
-#: cp/parser.c:27296
-#, fuzzy, gcc-internal-format
-#| msgid "declaration does not declare anything"
+#: cp/parser.c:27293
+#, gcc-internal-format
 msgid "a class template declaration must not declare anything else"
-msgstr "декларация ничего не описывает"
+msgstr "декларация шаблона класса не должна декларирован ничего иного"
 
-#: cp/parser.c:27342
+#: cp/parser.c:27339
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "явная специализация шаблона не может иметь класс хранения"
 
-#: cp/parser.c:27650
+#: cp/parser.c:27647
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%<>>%> должно быть %<> >%> внутри списка аргументов вложенного шаблона"
 
-#: cp/parser.c:27663
+#: cp/parser.c:27660
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "ошибочное использование %<>>%>, используйте %<>%> для завершения списка аргументов шаблона"
 
-#: cp/parser.c:27958
+#: cp/parser.c:27955
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
-msgstr ""
+msgstr "аргумент %<sizeof...%> должен быть окружен скобками"
 
-#: cp/parser.c:28118
+#: cp/parser.c:28115
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "некорректное использование %qD в спецификации привязки"
 
-#: cp/parser.c:28133
+#: cp/parser.c:28130
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> перед %qD"
 
-#: cp/parser.c:28267
+#: cp/parser.c:28264
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ 1998 не поддерживает %<long long%>"
 
 #
-#: cp/parser.c:28275
-#, fuzzy, gcc-internal-format
-#| msgid "both %<_Sat%> and %<char%> in declaration specifiers"
+#: cp/parser.c:28272
+#, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
-msgstr "в спецификаторах декларации заданы и %<_Sat%> и %<char%>"
+msgstr "заданы и %<__thread%> и %<thread_local%>"
 
-#: cp/parser.c:28280
-#, fuzzy, gcc-internal-format
-#| msgid "duplicate %qE"
+#: cp/parser.c:28277
+#, gcc-internal-format
 msgid "duplicate %qD"
-msgstr "дублирование %qE"
+msgstr "дублирование %qD"
 
-#: cp/parser.c:28304
+#: cp/parser.c:28301
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "дублирование %qs"
 
-#: cp/parser.c:28356
+#: cp/parser.c:28353
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "ожидалось %<new%>"
 
-#: cp/parser.c:28359
+#: cp/parser.c:28356
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "ожидалось %<delete%>"
 
-#: cp/parser.c:28362
+#: cp/parser.c:28359
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "ожидалось %<return%>"
 
-#: cp/parser.c:28368
+#: cp/parser.c:28365
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "ожидалось %<extern%>"
 
-#: cp/parser.c:28371
+#: cp/parser.c:28368
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "ожидалось %<static_assert%>"
 
-#: cp/parser.c:28374
+#: cp/parser.c:28371
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "ожидалось %<decltype%>"
 
-#: cp/parser.c:28377
+#: cp/parser.c:28374
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "ожидалось %<operator%>"
 
-#: cp/parser.c:28380
+#: cp/parser.c:28377
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "ожидалось %<class%>"
 
-#: cp/parser.c:28383
+#: cp/parser.c:28380
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "ожидалось %<template%>"
 
-#: cp/parser.c:28386
+#: cp/parser.c:28383
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "ожидалось %<namespace%>"
 
-#: cp/parser.c:28389
+#: cp/parser.c:28386
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "ожидалось %<using%>"
 
-#: cp/parser.c:28392
+#: cp/parser.c:28389
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "ожидалось %<asm%>"
 
-#: cp/parser.c:28395
+#: cp/parser.c:28392
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "ожидалось %<try%>"
 
-#: cp/parser.c:28398
+#: cp/parser.c:28395
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "ожидалось %<catch%>"
 
-#: cp/parser.c:28401
+#: cp/parser.c:28398
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "ожидалось %<throw%>"
 
-#: cp/parser.c:28404
+#: cp/parser.c:28401
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "ожидалось %<__label__%>"
 
-#: cp/parser.c:28407
+#: cp/parser.c:28404
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "ожидалось %<@try%>"
 
-#: cp/parser.c:28410
+#: cp/parser.c:28407
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "ожидалось %<@synchronized%>"
 
-#: cp/parser.c:28413
+#: cp/parser.c:28410
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "ожидалось %<@throw%>"
 
-#: cp/parser.c:28416
+#: cp/parser.c:28413
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "ожидалось %<__transaction_atomic%>"
 
-#: cp/parser.c:28419
+#: cp/parser.c:28416
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "ожидалось %<__transaction_relaxed%>"
 
-#: cp/parser.c:28451
+#: cp/parser.c:28448
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "ожидалось %<::%>"
 
-#: cp/parser.c:28463
+#: cp/parser.c:28460
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "ожидалось %<...%>"
 
-#: cp/parser.c:28466
+#: cp/parser.c:28463
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "ожидалось %<*%>"
 
-#: cp/parser.c:28469
+#: cp/parser.c:28466
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "ожидалось %<~%>"
 
-#: cp/parser.c:28475
+#: cp/parser.c:28472
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "ожидалось %<:%> или %<::%>"
 
-#: cp/parser.c:28502
+#: cp/parser.c:28499
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "ожидалось %<class%>, %<typename%> или %<template%>"
 
-#: cp/parser.c:28772
+#: cp/parser.c:28769
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "%qs tag использован в именовании %q#T"
 
-#: cp/parser.c:28777
+#: cp/parser.c:28774
 #, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "%q#T был ранее декларирован здесь"
 
-#: cp/parser.c:28798
+#: cp/parser.c:28795
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD редекларирован с другим доступом"
 
-#: cp/parser.c:28819
-#, fuzzy, gcc-internal-format
-#| msgid "%<template%> (as a disambiguator) is only allowed within templates"
+#: cp/parser.c:28816
+#, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
-msgstr "слово %<template%> (для снятия неоднозначности) допускается только внутри шаблонов"
+msgstr "в C++98 %<template%> (для снятия неоднозначности) допускается только внутри шаблонов"
 
-#: cp/parser.c:29062
+#: cp/parser.c:29059
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "конец файла в аргументе по умолчанию"
 
-#: cp/parser.c:29303 cp/parser.c:30620 cp/parser.c:30808
+#: cp/parser.c:29300 cp/parser.c:30617 cp/parser.c:30805
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "неверное положение %<@%D%> конструкции Objective-C++"
 
-#: cp/parser.c:29372
-#, fuzzy, gcc-internal-format
-#| msgid "objective-c++ message argument(s) are expected"
+#: cp/parser.c:29369
+#, gcc-internal-format
 msgid "objective-c++ message receiver expected"
-msgstr "ожидались objective-c++ аргумент(ы) сообщения"
+msgstr "objective-c++ получатель сообщения ожидался"
 
-#: cp/parser.c:29442
+#: cp/parser.c:29439
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr "ожидались objective-c++ аргумент(ы) сообщения"
 
-#: cp/parser.c:29473
+#: cp/parser.c:29470
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "в конструкции %<@encode%> в качестве аргумента должен быть задан тип"
 
-#: cp/parser.c:29883
+#: cp/parser.c:29880
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "некорректное Objective-C++ имя селектора"
 
-#: cp/parser.c:29958 cp/parser.c:29976
+#: cp/parser.c:29955 cp/parser.c:29973
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr "ожидалась objective-c++ декларация метода"
 
-#: cp/parser.c:29970 cp/parser.c:30035
+#: cp/parser.c:29967 cp/parser.c:30032
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "атрибуты метода должны задаваться в конце"
 
-#: cp/parser.c:30078
+#: cp/parser.c:30075
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr "случайное %qs между Objective-C++ методами"
 
-#: cp/parser.c:30284 cp/parser.c:30291 cp/parser.c:30298
+#: cp/parser.c:30281 cp/parser.c:30288 cp/parser.c:30295
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "некорректный тип для instance переменной"
 
-#: cp/parser.c:30413
+#: cp/parser.c:30410
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "ожидался идентификатор после %<@protocol%>"
 
-#: cp/parser.c:30585
+#: cp/parser.c:30582
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr "атрибуты нельзя задавать до %<@%D%> Objective-C++ ключевого слова"
 
-#: cp/parser.c:30592
+#: cp/parser.c:30589
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "префиксные атрибуты игнорируются до %<@%D%>"
 
-#: cp/parser.c:30867 cp/parser.c:30874 cp/parser.c:30881
+#: cp/parser.c:30864 cp/parser.c:30871 cp/parser.c:30878
 #, gcc-internal-format
 msgid "invalid type for property"
 msgstr "некорректный тип для property"
 
-#: cp/parser.c:32011
-#, fuzzy, gcc-internal-format
-#| msgid "num_threads expression must be integral"
+#: cp/parser.c:32008
+#, gcc-internal-format
 msgid "%<wait%> expression must be integral"
-msgstr "num_threads выражение должно быть целочисленным"
+msgstr "%<wait%> выражение должно быть целочисленным"
 
-#: cp/parser.c:32724
-#, fuzzy, gcc-internal-format
-#| msgid "invalid initializer"
+#: cp/parser.c:32721
+#, gcc-internal-format
 msgid "invalid reduction-identifier"
-msgstr "неверный инициализатор"
+msgstr "некорректный reduction-инициализатор"
 
-#: cp/parser.c:34911
+#: cp/parser.c:34908
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr "скобочная инициализация не допускается в OpenMP %<for%> цикле"
 
-#: cp/parser.c:35231 cp/pt.c:16392
+#: cp/parser.c:35228 cp/pt.c:16414
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "итерационная переменная %qD не должна быть reduction"
 
-#: cp/parser.c:35316
-#, fuzzy, gcc-internal-format
-#| msgid "not enough DO loops for collapsed !$OMP DO at %L"
+#: cp/parser.c:35313
+#, gcc-internal-format
 msgid "not enough for loops to collapse"
-msgstr "недостаточно DO циклов для сжатого !$OMP DO в %L"
+msgstr "недостаточно для сжатия циклов"
 
-#: cp/parser.c:37521
-#, fuzzy, gcc-internal-format
-#| msgid "invalid initializer"
+#: cp/parser.c:37518
+#, gcc-internal-format
 msgid "invalid initializer clause"
-msgstr "неверный инициализатор"
+msgstr "некорректная клаузула инициализатора"
 
-#: cp/parser.c:37549
-#, fuzzy, gcc-internal-format
-#| msgid "expected id-expression"
+#: cp/parser.c:37546
+#, gcc-internal-format
 msgid "expected id-expression (arguments)"
-msgstr "ожидалось id-выражение"
+msgstr "ожидалось id-выражение (аргументы)"
 
-#: cp/parser.c:37561
+#: cp/parser.c:37558
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
-msgstr ""
+msgstr "один из аргументов вызова инициализатора должен быть %<omp_priv%> или %<&omp_priv%>"
 
-#: cp/parser.c:37662
-#, fuzzy, gcc-internal-format
-#| msgid "new types may not be defined in a return type"
+#: cp/parser.c:37659
+#, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
-msgstr "в описании возвращаемого типа нельзя определять новые типы"
+msgstr "типы не могут определяться в declare reduction списке типов"
 
-#: cp/parser.c:37682 cp/semantics.c:5405
+#: cp/parser.c:37679 cp/semantics.c:5408
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
-msgstr ""
+msgstr "предекларированный арифметический тип %qT в %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:37687 cp/semantics.c:5414
+#: cp/parser.c:37684 cp/semantics.c:5417
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
-msgstr ""
+msgstr "функциональный или массивный тип %qT в %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:37690 cp/pt.c:12944 cp/semantics.c:5420
-#, fuzzy, gcc-internal-format
-#| msgid "expected %<#pragma omp%> clause before %<decltype%>"
+#: cp/parser.c:37687 cp/pt.c:12966 cp/semantics.c:5423
+#, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
-msgstr "ожидалась конструкция %<#pragma omp%> перед %<decltype%>"
+msgstr "тип ссылки %qT в %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:37693 cp/semantics.c:5426
+#: cp/parser.c:37690 cp/semantics.c:5429
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
-msgstr ""
+msgstr "const, volatile или __restrict квалифицированный тип %qT в %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:38047
+#: cp/parser.c:38044
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
-msgstr ""
+msgstr "%<#pragma acc routine%> именует множество перегрузок"
 
-#: cp/parser.c:38057
-#, fuzzy, gcc-internal-format
-#| msgid "%qD is not a member template function"
+#: cp/parser.c:38054
+#, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
-msgstr "%qD не является шаблонным элементом-функцией"
+msgstr "%qD не ссылается на функцию в контексте пространства имен"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:38392
+#: cp/parser.c:38389
 #, gcc-internal-format
 msgid "atomic_cancel"
-msgstr ""
+msgstr "atomic_cancel"
 
-#: cp/parser.c:38435 cp/semantics.c:8575
+#: cp/parser.c:38432 cp/semantics.c:8578
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr "%<__transaction_relaxed%> без включения поддержки транзакционной памяти"
 
-#: cp/parser.c:38437 cp/semantics.c:8577
+#: cp/parser.c:38434 cp/semantics.c:8580
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr "%<__transaction_atomic%> без включения поддержки транзакционной памяти"
 
-#: cp/parser.c:38631
+#: cp/parser.c:38628
 #, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "мусор в конце директивы %<#pragma GCC pch_preprocess%>"
 
-#: cp/parser.c:38927
-#, fuzzy, gcc-internal-format
-#| msgid "#pragma GCC optimize is not allowed inside functions"
+#: cp/parser.c:38924
+#, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
-msgstr "#pragma GCC optimize не допускается внутри функций"
+msgstr "%<#pragma GCC ivdep%> должна быть внутри функций"
 
-#: cp/parser.c:38959
-#, fuzzy, gcc-internal-format
-#| msgid "#pragma GCC optimize is not allowed inside functions"
+#: cp/parser.c:38956
+#, gcc-internal-format
 msgid "%<#pragma GCC unroll%> must be inside a function"
-msgstr "#pragma GCC optimize не допускается внутри функций"
+msgstr ""
 
-#: cp/parser.c:39039
+#: cp/parser.c:39036
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "межмодульные оптимизации не реализованы для C++"
 
-#: cp/parser.c:39295
-#, fuzzy, gcc-internal-format
-#| msgid "templates may not be %<virtual%>"
+#: cp/parser.c:39292
+#, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
-msgstr "шаблоны не могут быть %<virtual%>"
+msgstr "неявные шаблоны не могут быть %<virtual%>"
 
-#: cp/parser.c:39351
+#: cp/parser.c:39348
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
@@ -52325,10 +46522,9 @@
 msgstr "специализация %qD в другой namespace-области"
 
 #: cp/pt.c:804 cp/pt.c:1031
-#, fuzzy, gcc-internal-format
-#| msgid "  from definition of %q+#D"
+#, gcc-internal-format
 msgid "  from definition of %q#D"
-msgstr "  из определения %q+#D"
+msgstr ""
 
 #: cp/pt.c:821
 #, gcc-internal-format
@@ -52341,10 +46537,9 @@
 msgstr "имя класса затеняет шаблон параметра шаблона %qD"
 
 #: cp/pt.c:953
-#, fuzzy, gcc-internal-format
-#| msgid "partial specialization of alias template %qD"
+#, gcc-internal-format
 msgid "specialization of alias template %qD"
-msgstr "частичная специализация алиасного шаблона %qD"
+msgstr "специализация алиасного шаблона %qD"
 
 #: cp/pt.c:956 cp/pt.c:1093
 #, gcc-internal-format
@@ -52378,11 +46573,10 @@
 msgid "specialization of %qD after instantiation"
 msgstr "специализация %qD после конкретизации"
 
-#: cp/pt.c:1954 cp/semantics.c:5274
-#, fuzzy, gcc-internal-format
-#| msgid "%s %+#D"
+#: cp/pt.c:1954 cp/semantics.c:5277
+#, gcc-internal-format
 msgid "%s %#qD"
-msgstr "%s %+#D"
+msgstr ""
 
 #: cp/pt.c:2089
 #, gcc-internal-format
@@ -52390,10 +46584,9 @@
 msgstr "%qD не является шаблоном функции"
 
 #: cp/pt.c:2094
-#, fuzzy, gcc-internal-format
-#| msgid "%qD is not a variable"
+#, gcc-internal-format
 msgid "%qD is not a variable template"
-msgstr "%qD не переменная"
+msgstr "%qD не есть переменный шаблон"
 
 #: cp/pt.c:2365
 #, gcc-internal-format
@@ -52411,52 +46604,45 @@
 msgstr "неоднозначная конкретизация шаблона %qD для %q+D"
 
 #: cp/pt.c:2589
-#, fuzzy, gcc-internal-format
-#| msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
+#, gcc-internal-format
 msgid "variable templates only available with -std=c++14 or -std=gnu++14"
-msgstr "вариантные шаблоны доступны только с -std=c++11 или -std=gnu++11"
+msgstr "переменные шаблоны доступны только с -std=c++14 или -std=gnu++14"
 
 #: cp/pt.c:2598
-#, fuzzy, gcc-internal-format
-#| msgid "wrong number of template arguments (%d, should be %d)"
+#, gcc-internal-format
 msgid "too many template headers for %qD (should be %d)"
-msgstr "неправильное число аргументов шаблона (%d, а должно быть %d)"
+msgstr ""
 
 #: cp/pt.c:2604
 #, gcc-internal-format
 msgid "members of an explicitly specialized class are defined without a template header"
-msgstr ""
+msgstr "элементы явно специализированного класса определяются без заголовка шаблона"
 
 #: cp/pt.c:2628
-#, fuzzy, gcc-internal-format
-#| msgid "explicit specialization of %qD after first use"
+#, gcc-internal-format
 msgid "explicit specialization of %qD outside its namespace must use a nested-name-specifier"
-msgstr "явная специализация %qD после первого использования"
+msgstr "явная специализация %qD вне своего пространства имен должна использовать nested-name-specifier"
 
 #. This was allowed in C++98, so only pedwarn.
 #: cp/pt.c:2633
-#, fuzzy, gcc-internal-format
-#| msgid "explicit instantiation of %qD in namespace %qD (which does not enclose namespace %qD)"
+#, gcc-internal-format
 msgid "explicit instantiation of %qD outside its namespace must use a nested-name-specifier"
-msgstr "явная конкретизация %qD в пространстве имен %qD (которое не включает пространство имен %qD)"
+msgstr "явная конкретизация %qD вне своего пространства имен должна использовать nested-name-specifier"
 
 #: cp/pt.c:2730
-#, fuzzy, gcc-internal-format
-#| msgid "explicit specialization of %qD after first use"
+#, gcc-internal-format
 msgid "explicit specialization %q#D may be missing attributes"
-msgstr "явная специализация %qD после первого использования"
+msgstr ""
 
 #: cp/pt.c:2734
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "mismatched arguments"
+#, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attributes %s"
-msgstr "несовпадающие аргументы"
+msgstr ""
 
 #: cp/pt.c:2735
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "mismatched arguments"
+#, gcc-internal-format, gfc-internal-format
 msgid "missing primary template attribute %s"
-msgstr "несовпадающие аргументы"
+msgstr ""
 
 #. This case handles bogus declarations like template <>
 #. template <class T> void f<int>();
@@ -52491,22 +46677,19 @@
 msgstr "перед явной специализацией %qD должно быть %<template <>%>"
 
 #: cp/pt.c:2862
-#, fuzzy, gcc-internal-format
-#| msgid "explicit specialization of non-template %qT"
+#, gcc-internal-format
 msgid "explicit specialization declared %<concept%>"
-msgstr "явная специализация не-шаблона %qT"
+msgstr "явная специализация декларированного %<concept%>"
 
 #: cp/pt.c:2893
-#, fuzzy, gcc-internal-format
-#| msgid "function template partial specialization %qD is not allowed"
+#, gcc-internal-format
 msgid "non-type partial specialization %qD is not allowed"
-msgstr "частичная специализация шаблона функции %qD не допускается"
+msgstr "нетиповая частичная специализация %qD не допускается"
 
 #: cp/pt.c:2896
-#, fuzzy, gcc-internal-format
-#| msgid "function template partial specialization %qD is not allowed"
+#, gcc-internal-format
 msgid "non-class, non-variable partial specialization %qD is not allowed"
-msgstr "частичная специализация шаблона функции %qD не допускается"
+msgstr "неклассовая, непеременная частичная специализация %qD не допускается"
 
 #: cp/pt.c:2929
 #, gcc-internal-format
@@ -52537,143 +46720,126 @@
 msgstr "никакая элемент-функция %qD не декларирована в %qT"
 
 #: cp/pt.c:3076
-#, fuzzy, gcc-internal-format
-#| msgid "friend declaration %q#D declares a non-template function"
+#, gcc-internal-format
 msgid "friend declaration %qD is not visible to explicit specialization"
-msgstr "friend декларация %q#D декларирует нешаблонную функцию"
+msgstr "friend декларация %qD не видна для явной специализации"
 
 #: cp/pt.c:3079
-#, fuzzy, gcc-internal-format
-#| msgid "previous declaration %q+#D here"
+#, gcc-internal-format
 msgid "friend declaration here"
-msgstr "предыдущей декларации %q+#D здесь"
+msgstr "friend декларация здесь"
 
 #: cp/pt.c:3187
-#, fuzzy, gcc-internal-format
-#| msgid "explicit specialization of non-template %qT"
+#, gcc-internal-format
 msgid "explicit specialization of function concept %qD"
-msgstr "явная специализация не-шаблона %qT"
+msgstr "явная специализация function concept %qD"
 
 #: cp/pt.c:3621
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Argument of ACOS at %L must be between -1 and 1"
+#, gcc-internal-format, gfc-internal-format
 msgid "argument to __integer_pack must be between 0 and %d"
-msgstr "Аргумент ACOS в %L должен быть между -1 и 1"
+msgstr ""
 
-#: cp/pt.c:3942
-#, fuzzy, gcc-internal-format
-#| msgid "base initializer expansion %<%T%> contains no parameter packs"
+#: cp/pt.c:3955
+#, gcc-internal-format
 msgid "base initializer expansion %qT contains no parameter packs"
-msgstr "расширение базового инициализатора %<%T%> не содержит packs параметров"
+msgstr ""
 
-#: cp/pt.c:4010
-#, fuzzy, gcc-internal-format
-#| msgid "expansion pattern %<%T%> contains no argument packs"
+#: cp/pt.c:4023
+#, gcc-internal-format
 msgid "expansion pattern %qT contains no argument packs"
-msgstr "образец расширения %<%T%> не содержит packs аргументов"
+msgstr ""
 
-#: cp/pt.c:4012
-#, fuzzy, gcc-internal-format
-#| msgid "expansion pattern %<%E%> contains no argument packs"
+#: cp/pt.c:4025
+#, gcc-internal-format
 msgid "expansion pattern %qE contains no argument packs"
-msgstr "образец расширения %<%E%> не содержит packs аргументов"
+msgstr ""
 
-#: cp/pt.c:4063
+#: cp/pt.c:4077
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr "packs параметров не расширены с %<...%>:"
 
-#: cp/pt.c:4080 cp/pt.c:4835
+#: cp/pt.c:4094 cp/pt.c:4849
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
 
-#: cp/pt.c:4082
+#: cp/pt.c:4096
 #, gcc-internal-format
 msgid "        <anonymous>"
 msgstr "        <anonymous>"
 
-#: cp/pt.c:4208
-#, fuzzy, gcc-internal-format
-#| msgid "declaration of %q+D shadows a parameter"
+#: cp/pt.c:4222
+#, gcc-internal-format
 msgid "declaration of template parameter %q+D shadows template parameter"
-msgstr "декларация %q+D перекрывает параметр"
+msgstr "декларация параметра шаблона %q+D перекрывает параметр шаблона"
 
-#: cp/pt.c:4211
-#, fuzzy, gcc-internal-format
-#| msgid "declaration of %q+D shadows a parameter"
+#: cp/pt.c:4225
+#, gcc-internal-format
 msgid "declaration of %q+#D shadows template parameter"
-msgstr "декларация %q+D перекрывает параметр"
+msgstr "декларация %q+#D перекрывает параметр шаблона"
 
-#: cp/pt.c:4213
-#, fuzzy, gcc-internal-format
-#| msgid "template parameter type %qT declared %<friend%>"
+#: cp/pt.c:4227
+#, gcc-internal-format
 msgid "template parameter %qD declared here"
-msgstr "тип параметра шаблона %qT декларирован %<friend%>"
+msgstr "параметр шаблона %qD декларирован здесь"
 
-#: cp/pt.c:4771
-#, fuzzy, gcc-internal-format
-#| msgid "partial specialization of alias template %qD"
+#: cp/pt.c:4785
+#, gcc-internal-format
 msgid "specialization of variable concept %q#D"
-msgstr "частичная специализация алиасного шаблона %qD"
+msgstr "специализация variable concept %q#D"
 
-#: cp/pt.c:4830
-#, fuzzy, gcc-internal-format
-#| msgid "template parameters not used in partial specialization:"
+#: cp/pt.c:4844
+#, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
-msgstr "параметры шаблона не используются в частичной специализации:"
+msgstr "параметры шаблона не выводимы в частичной специализации:"
 
-#: cp/pt.c:4854
-#, fuzzy, gcc-internal-format
-#| msgid "partial specialization %qT does not specialize any template arguments"
+#: cp/pt.c:4868
+#, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
-msgstr "частичная специализация %qT не специализирует никакие аргументы шаблона"
+msgstr ""
 
-#: cp/pt.c:4858
-#, fuzzy, gcc-internal-format
-#| msgid "partial specialization %qT does not specialize any template arguments"
+#: cp/pt.c:4872
+#, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
-msgstr "частичная специализация %qT не специализирует никакие аргументы шаблона"
+msgstr ""
 
-#: cp/pt.c:4862 cp/pt.c:4873
-#, fuzzy, gcc-internal-format
-#| msgid "previously declared here"
+#: cp/pt.c:4876 cp/pt.c:4887
+#, gcc-internal-format
 msgid "primary template here"
-msgstr "предыдущая декларация здесь"
+msgstr "первичный шаблон здесь"
 
-#: cp/pt.c:4870
+#: cp/pt.c:4884
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
-msgstr ""
+msgstr "частичная специализация не более специальна чем первичный шаблон, так как она замещает несколько параметров пакетным расширением"
 
-#: cp/pt.c:4885
-#, fuzzy, gcc-internal-format
-#| msgid "partial specialization %qT does not specialize any template arguments"
+#: cp/pt.c:4899
+#, gcc-internal-format
 msgid "partial specialization %qD is not more specialized than"
-msgstr "частичная специализация %qT не специализирует никакие аргументы шаблона"
+msgstr "частичная специализация %qD не более специальна чем"
 
-#: cp/pt.c:4887
-#, fuzzy, gcc-internal-format
-#| msgid "previously declared here"
+#: cp/pt.c:4901
+#, gcc-internal-format
 msgid "primary template %qD"
-msgstr "предыдущая декларация здесь"
+msgstr "первичный шаблон %qD"
 
-#: cp/pt.c:4934
+#: cp/pt.c:4948
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr "parameter pack аргумент %qE должен быть в конце списка аргументов шаблона"
 
-#: cp/pt.c:4937
+#: cp/pt.c:4951
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr "parameter pack аргумент %qT должен быть в конце списка аргументов шаблона"
 
-#: cp/pt.c:4958
+#: cp/pt.c:4972
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr "аргумент шаблона %qE включает параметр(ы) шаблона"
 
-#: cp/pt.c:5004
+#: cp/pt.c:5018
 #, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
@@ -52681,19 +46847,17 @@
 msgstr[1] "тип %qT аргумента шаблона %qE зависит от параметров шаблона"
 msgstr[2] "тип %qT аргумента шаблона %qE зависит от параметров шаблона"
 
-#: cp/pt.c:5066
-#, fuzzy, gcc-internal-format
-#| msgid "ambiguous class template instantiation for %q#T"
+#: cp/pt.c:5080
+#, gcc-internal-format
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
-msgstr "неоднозначная конкретизация шаблона класса для %q#T"
+msgstr "декларация %qD делает неоднозначной более раннюю конкретизацию шаблона для %qD"
 
-#: cp/pt.c:5070
-#, fuzzy, gcc-internal-format
-#| msgid "partial specialization of %qT after instantiation of %qT"
+#: cp/pt.c:5084
+#, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
-msgstr "частичная специализация %qT после конкретизации %qT"
+msgstr "частичная специализация %qD после конкретизации %qD"
 
-#: cp/pt.c:5247
+#: cp/pt.c:5261
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "нет подразумеваемого аргумента для %qD"
@@ -52701,54 +46865,50 @@
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5269
-#, fuzzy, gcc-internal-format
-#| msgid "parameter pack %qE must be at the end of the template parameter list"
+#: cp/pt.c:5283
+#, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
-msgstr "parameter pack %qE должен быть в конце списка параметров шаблона"
+msgstr "parameter pack %q+D должен быть в конце списка параметров шаблона"
 
-#: cp/pt.c:5305
+#: cp/pt.c:5319
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "подразумеваемые аргументы шаблона не могут использоваться в редекларации friend шаблона функции"
 
-#: cp/pt.c:5308
-#, fuzzy, gcc-internal-format
-#| msgid "default template arguments may not be used in function template friend declarations"
+#: cp/pt.c:5322
+#, gcc-internal-format
 msgid "default template arguments may not be used in template friend declarations"
-msgstr "подразумеваемые аргументы шаблона не могут использоваться в декларации friend шаблона функции"
+msgstr ""
 
-#: cp/pt.c:5311
+#: cp/pt.c:5325
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without -std=c++11 or -std=gnu++11"
 msgstr "подразумеваемые аргументы шаблона не могут использоваться в шаблонах функций без -std=c++11 или -std=gnu++11"
 
-#: cp/pt.c:5314
+#: cp/pt.c:5328
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr "подразумеваемые аргументы шаблона не могут использоваться в частичных специализациях"
 
-#: cp/pt.c:5317 cp/pt.c:5375
+#: cp/pt.c:5331 cp/pt.c:5389
 #, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "подразумеваемый аргумент для параметра шаблона для класса включающего %qD"
 
-#: cp/pt.c:5489
-#, fuzzy, gcc-internal-format
-#| msgid "parameter %qD declared void"
+#: cp/pt.c:5503
+#, gcc-internal-format
 msgid "template %qD declared"
-msgstr "параметр %qD декларирован void"
+msgstr "шаблон %qD декларирован"
 
-#: cp/pt.c:5496
+#: cp/pt.c:5510
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "шаблон класса без имени"
 
-#: cp/pt.c:5504
-#, fuzzy, gcc-internal-format
-#| msgid "non-member function %qD cannot have cv-qualifier"
+#: cp/pt.c:5518
+#, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
-msgstr "не-элемент-функция %qD не может иметь cv-квалификатор"
+msgstr "элемент-шаблон %qD не может иметь virt-спецификаторы"
 
 #. [basic.stc.dynamic.allocation]
 #.
@@ -52755,58 +46915,57 @@
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5526
+#: cp/pt.c:5540
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "некорректная template-декларация %qD"
 
-#: cp/pt.c:5669
+#: cp/pt.c:5683
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "определение шаблона для не-шаблона %q#D"
 
-#: cp/pt.c:5712
+#: cp/pt.c:5726
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "ожидалось %d уровней параметров шаблона для %q#D, дано %d"
 
-#: cp/pt.c:5726
+#: cp/pt.c:5740
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "дано %d параметров шаблона для %q#D"
 
-#: cp/pt.c:5729
+#: cp/pt.c:5743
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "дано %d параметров шаблона для %q#T"
 
-#: cp/pt.c:5731
+#: cp/pt.c:5745
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  вместо требуемых %d"
 
-#: cp/pt.c:5752
+#: cp/pt.c:5766
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "аргументы шаблона для %qD не соответствуют первоначальному шаблону %qD"
 
-#: cp/pt.c:5755
-#, fuzzy, gcc-internal-format
-#| msgid "use template<> for an explicit specialization"
+#: cp/pt.c:5769
+#, gcc-internal-format
 msgid "use %<template<>%> for an explicit specialization"
-msgstr "используйте template<> для явной специализации"
+msgstr "используйте %<template<>%> для явной специализации"
 
-#: cp/pt.c:5882
+#: cp/pt.c:5896
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT не является шаблонным типом"
 
-#: cp/pt.c:5895
+#: cp/pt.c:5909
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "спецификаторы шаблона не заданы в декларации %qD"
 
-#: cp/pt.c:5906
+#: cp/pt.c:5920
 #, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
@@ -52814,22 +46973,20 @@
 msgstr[1] "редекларировано с %d параметрами шаблона"
 msgstr[2] "редекларировано с %d параметрами шаблона"
 
-#: cp/pt.c:5910
-#, fuzzy, gcc-internal-format
-#| msgid "previous declaration %q+D used %d template parameter"
-#| msgid_plural "previous declaration %q+D used %d template parameters"
+#: cp/pt.c:5924
+#, gcc-internal-format
 msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
-msgstr[0] "предыдущая декларация %q+D использовала %d параметр шаблона"
-msgstr[1] "предыдущая декларация %q+D использовала %d параметров шаблона"
-msgstr[2] "предыдущая декларация %q+D использовала %d параметров шаблона"
+msgstr[0] "предыдущая декларация %qD использовала %d параметр шаблона"
+msgstr[1] "предыдущая декларация %qD использовала %d параметра шаблона"
+msgstr[2] "предыдущая декларация %qD использовала %d параметра шаблона"
 
-#: cp/pt.c:5947
+#: cp/pt.c:5961
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "параметр шаблона %q+#D"
 
-#: cp/pt.c:5948
+#: cp/pt.c:5962
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "редекларирован здесь как %q#D"
@@ -52838,443 +46995,413 @@
 #.
 #. A template-parameter may not be given default arguments
 #. by two different declarations in the same scope.
-#: cp/pt.c:5958
+#: cp/pt.c:5972
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "редекларация аргумента по умолчанию для %q#D"
 
-#: cp/pt.c:5960
+#: cp/pt.c:5974
 #, gcc-internal-format
 msgid "original definition appeared here"
 msgstr "исходное определение находится здесь"
 
-#: cp/pt.c:5988
-#, fuzzy, gcc-internal-format
-#| msgid "redeclaration %qD differs in %<constexpr%>"
+#: cp/pt.c:6002
+#, gcc-internal-format
 msgid "redeclaration %q#D with different constraints"
-msgstr "редекларация %qD отличается в %<constexpr%>"
+msgstr "редекларация %q#D с другими ограничениями"
 
-#: cp/pt.c:5991
-#, fuzzy, gcc-internal-format
-#| msgid "original definition appeared here"
+#: cp/pt.c:6005
+#, gcc-internal-format
 msgid "original declaration appeared here"
-msgstr "исходное определение находится здесь"
+msgstr "исходная декларация находится здесь"
 
-#: cp/pt.c:6250 cp/pt.c:6318
+#: cp/pt.c:6264 cp/pt.c:6332
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%E не является корректным аргументом шаблона для типа %qT"
 
-#: cp/pt.c:6253
+#: cp/pt.c:6267
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr "это должно быть адресом функции с внешней привязкой"
 
-#: cp/pt.c:6256
-#, fuzzy, gcc-internal-format
-#| msgid "it must be the address of a function with external linkage"
+#: cp/pt.c:6270
+#, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
-msgstr "это должно быть адресом функции с внешней привязкой"
+msgstr "это должно быть именем функции с внешней привязкой"
 
-#: cp/pt.c:6268
+#: cp/pt.c:6282
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
-msgstr "%E не является корректным аргументом шаблона для типа %qT поскольку %qD не имеет привязки"
+msgstr "%E не является корректным аргументом шаблона для типа %qT, поскольку %qD не имеет привязки"
 
-#: cp/pt.c:6272
+#: cp/pt.c:6286
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
-msgstr "%E не является корректным аргументом шаблона для типа %qT поскольку %qD не имеет внешней привязки"
+msgstr "%E не является корректным аргументом шаблона для типа %qT, поскольку %qD не имеет внешней привязки"
 
-#: cp/pt.c:6321
+#: cp/pt.c:6335
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "это должно быть указателем на элемент вида %<&X::Y%>"
 
-#: cp/pt.c:6323
-#, fuzzy, gcc-internal-format
-#| msgid "%qD is not a member of %qT"
+#: cp/pt.c:6337
+#, gcc-internal-format
 msgid "because it is a member of %qT"
-msgstr "%qD не является элементом %qT"
+msgstr ""
 
-#: cp/pt.c:6383
+#: cp/pt.c:6397
 #, gcc-internal-format
 msgid "  couldn't deduce template parameter %qD"
 msgstr "  невозможно вывести параметр шаблона %qD"
 
-#: cp/pt.c:6392
+#: cp/pt.c:6406
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr "  типы %qT и %qT имеют несовместимые cv-qualifiers"
 
-#: cp/pt.c:6401
+#: cp/pt.c:6415
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr "  несоответствие типов %qT и %qT"
 
-#: cp/pt.c:6410
+#: cp/pt.c:6424
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr "  параметр шаблона %qD не есть parameter pack, но аргумент %qD таковым является"
 
-#: cp/pt.c:6421
+#: cp/pt.c:6435
 #, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "  аргумент шаблона %qE не соответствует указателю на элемент константе %qE"
 
-#: cp/pt.c:6431
+#: cp/pt.c:6445
 #, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr "  %qE не эквивалентно %qE"
 
-#: cp/pt.c:6440
+#: cp/pt.c:6454
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr "  противоречивый вывод parameter pack с %qT и %qT"
 
-#: cp/pt.c:6452
+#: cp/pt.c:6466
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr "  выведены конфликтующие типы для параметра %qT (%qT и %qT)"
 
-#: cp/pt.c:6456
+#: cp/pt.c:6470
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr "  выведены конфликтующие значения для нетипового параметра %qE (%qE и %qE)"
 
-#: cp/pt.c:6467
+#: cp/pt.c:6481
 #, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "  тип массива переменного размера %qT не есть корректный аргумент шаблона"
 
-#: cp/pt.c:6478
+#: cp/pt.c:6492
 #, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr "  тип элемента-функции %qT не есть корректный аргумент шаблона"
 
-#: cp/pt.c:6490
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "  candidate expects %d argument, %d provided"
-#| msgid_plural "  candidate expects %d arguments, %d provided"
+#: cp/pt.c:6504
+#, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
-msgstr[0] "  кандидат ожидает %d аргумент, %d предоставлено"
-msgstr[1] "  кандидат ожидает %d аргумента, %d предоставлено"
-msgstr[2] "  кандидат ожидает %d аргументов, %d предоставлено"
+msgstr[0] ""
+msgstr[1] ""
+msgstr[2] ""
 
-#: cp/pt.c:6521
+#: cp/pt.c:6535
 #, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "  невозможно преобразовать %qE (типа %qT) к типу %qT"
 
-#: cp/pt.c:6534
+#: cp/pt.c:6548
 #, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "  %qT является неоднозначным базовым классом %qT"
 
-#: cp/pt.c:6538
+#: cp/pt.c:6552
 #, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "  %qT не является производным от %qT"
 
-#: cp/pt.c:6549
+#: cp/pt.c:6563
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr "  параметры шаблона для шаблона аргумента шаблона несовместимы с другими выведенными аргументами шаблона"
 
-#: cp/pt.c:6559
+#: cp/pt.c:6573
 #, gcc-internal-format
 msgid "  can't deduce a template for %qT from non-template type %qT"
 msgstr "  невозможно вывести шаблон для %qT из нешаблонного типа %qT"
 
-#: cp/pt.c:6569
-#, fuzzy, gcc-internal-format
-#| msgid "  template argument %qE does not match %qD"
+#: cp/pt.c:6583
+#, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
-msgstr "  аргумент шаблона %qE не соответствует %qD"
+msgstr ""
 
-#: cp/pt.c:6609
+#: cp/pt.c:6623
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
-msgstr "%qE не есть корректный аргумент шаблона для типа %qT поскольку строковые литералы не могут быть использованы в этом контексте"
+msgstr "%qE не есть корректный аргумент шаблона для типа %qT, поскольку строковые литералы не могут быть использованы в этом контексте"
 
-#: cp/pt.c:6758
-#, fuzzy, gcc-internal-format
-#| msgid "in template argument for type %qT "
+#: cp/pt.c:6772
+#, gcc-internal-format
 msgid "in template argument for type %qT"
-msgstr "в аргументе шаблона для типа %qT "
+msgstr ""
 
-#: cp/pt.c:6772
-#, fuzzy, gcc-internal-format
-#| msgid "in template argument for type %qT "
+#: cp/pt.c:6786
+#, gcc-internal-format
 msgid "template argument %qE for type %qT not a constant integer"
-msgstr "в аргументе шаблона для типа %qT "
+msgstr ""
 
-#: cp/pt.c:6833
+#: cp/pt.c:6847
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
-msgstr "%qD не есть корректный аргумент шаблона поскольку %qD переменная, а не адрес переменной"
+msgstr "%qD не есть корректный аргумент шаблона, поскольку %qD переменная, а не адрес переменной"
 
-#: cp/pt.c:6841
-#, fuzzy, gcc-internal-format
-#| msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
+#: cp/pt.c:6855
+#, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
-msgstr "%qD не есть корректный аргумент шаблона поскольку %qD переменная, а не адрес переменной"
+msgstr "%qE не есть корректный аргумент шаблона для %qT, поскольку не является адресом переменной"
 
-#: cp/pt.c:6857
+#: cp/pt.c:6871
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
-msgstr "%qE не есть корректный аргумент шаблона типа %qT поскольку %qE не переменная"
+msgstr "%qE не есть корректный аргумент шаблона типа %qT, поскольку %qE не переменная"
 
-#: cp/pt.c:6864
+#: cp/pt.c:6878
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
-msgstr "%qE не есть корректный аргумент шаблона типа %qT поскольку %qD не имеет внешней привязки"
+msgstr "%qE не есть корректный аргумент шаблона типа %qT, поскольку %qD не имеет внешней привязки"
 
-#: cp/pt.c:6873
+#: cp/pt.c:6887
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
-msgstr "%qE не есть корректный аргумент шаблона типа %qT поскольку %qD не имеет привязки"
+msgstr "%qE не есть корректный аргумент шаблона типа %qT, поскольку %qD не имеет привязки"
 
-#: cp/pt.c:6888
-#, fuzzy, gcc-internal-format
-#| msgid "  variable-sized array type %qT is not a valid template argument"
+#: cp/pt.c:6902
+#, gcc-internal-format
 msgid "the address of %qD is not a valid template argument"
-msgstr "  тип массива переменного размера %qT не есть корректный аргумент шаблона"
+msgstr "адрес %qD не есть корректный аргумент шаблона"
 
-#: cp/pt.c:6897
-#, fuzzy, gcc-internal-format
-#| msgid "  variable-sized array type %qT is not a valid template argument"
+#: cp/pt.c:6911
+#, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
-msgstr "  тип массива переменного размера %qT не есть корректный аргумент шаблона"
+msgstr "адрес %qT подобъекта %qD не есть корректный аргумент шаблона"
 
-#: cp/pt.c:6904
-#, fuzzy, gcc-internal-format
-#| msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
+#: cp/pt.c:6918
+#, gcc-internal-format
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
-msgstr "%qE не есть корректный аргумент шаблона типа %qT поскольку %qD не имеет внешней привязки"
+msgstr "адрес %qD не есть корректный аргумент шаблона, так как он не имеет статический срок хранения"
 
-#: cp/pt.c:6933
+#: cp/pt.c:6947
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "%qE не есть корректный аргумент шаблона для типа %qT из-за конфликтов в cv-qualification"
 
-#: cp/pt.c:6941
+#: cp/pt.c:6955
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
-msgstr "%qE не есть корректный аргумент шаблона для типа %qT поскольку он не есть lvalue"
+msgstr "%qE не есть корректный аргумент шаблона для типа %qT, поскольку он не есть lvalue"
 
-#: cp/pt.c:6959
+#: cp/pt.c:6973
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
-msgstr "%q#D не есть корректный аргумент шаблона для типа %qT поскольку ссылочная переменная не имеет постоянного адреса"
+msgstr "%q#D не есть корректный аргумент шаблона для типа %qT, поскольку ссылочная переменная не имеет постоянного адреса"
 
-#: cp/pt.c:6975
-#, fuzzy, gcc-internal-format
-#| msgid "%qE is not a valid template argument for type %qT because it is not an object with external linkage"
+#: cp/pt.c:6989
+#, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an object with linkage"
-msgstr "%qE не есть корректный аргумент шаблона для типа %qT поскольку он не является объектом с внешней привязкой"
+msgstr "%qE не есть корректный аргумент шаблона для типа %qT, поскольку он не является объектом с привязкой"
 
-#: cp/pt.c:6986
-#, fuzzy, gcc-internal-format
-#| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
+#: cp/pt.c:7000
+#, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because object %qD does not have linkage"
-msgstr "%qE не есть корректный аргумент шаблона для типа %qT поскольку объект %qD не имеет внешней привязки"
+msgstr "%qE не есть корректный аргумент шаблона для типа %qT, поскольку объект %qD не имеет привязки"
 
-#: cp/pt.c:7036
+#: cp/pt.c:7050
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
-msgstr "%qE не есть корректный аргумент шаблона для типа %qT поскольку он является указателем"
+msgstr "%qE не есть корректный аргумент шаблона для типа %qT, поскольку он является указателем"
 
-#: cp/pt.c:7038
+#: cp/pt.c:7052
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "попробуйте задать %qE"
 
-#: cp/pt.c:7092
+#: cp/pt.c:7106
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
-msgstr "%qE не есть корректный аргумент шаблона для типа %qT поскольку он имеет тип %qT"
+msgstr "%qE не есть корректный аргумент шаблона для типа %qT, поскольку он имеет тип %qT"
 
-#: cp/pt.c:7654
+#: cp/pt.c:7668
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "игнорирование атрибутов аргумента шаблона %qT"
 
-#: cp/pt.c:7670
-#, fuzzy, gcc-internal-format
-#| msgid "ignoring attributes on template argument %qT"
+#: cp/pt.c:7684
+#, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
-msgstr "игнорирование атрибутов аргумента шаблона %qT"
+msgstr "игнорирование атрибутов аргумента шаблона %qE"
 
-#: cp/pt.c:7805
+#: cp/pt.c:7819
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "injected-class-name %qD использовано как шаблон аргумента шаблона"
 
-#: cp/pt.c:7834
+#: cp/pt.c:7848
 #, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "некорректное использование деструктора %qE в качестве типа"
 
-#: cp/pt.c:7839
+#: cp/pt.c:7853
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "для того чтобы сослаться на тип параметра шаблона, используйте конструкцию %<typename %E%>"
 
-#: cp/pt.c:7855 cp/pt.c:7877 cp/pt.c:7931
+#: cp/pt.c:7869 cp/pt.c:7891 cp/pt.c:7945
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "несоответствия типа/значения в аргументе %d в списке параметров шаблона для %qD"
 
-#: cp/pt.c:7860
+#: cp/pt.c:7874
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  ожидалась константа типа %qT, а обнаружено %qT"
 
-#: cp/pt.c:7865
+#: cp/pt.c:7879
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  ожидался шаблон класса, а обнаружено %qE"
 
-#: cp/pt.c:7868
+#: cp/pt.c:7882
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  ожидался тип, обнаружено %qE"
 
-#: cp/pt.c:7882
+#: cp/pt.c:7896
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  ожидался тип, обнаружено %qT"
 
-#: cp/pt.c:7885
+#: cp/pt.c:7899
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  ожидался шаблон класса, обнаружено %qT"
 
-#: cp/pt.c:7935
+#: cp/pt.c:7949
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  ожидался шаблон типа %qD, обнаружено %qT"
 
-#: cp/pt.c:7949
-#, fuzzy, gcc-internal-format
-#| msgid "type/value mismatch at argument %d in template parameter list for %qD"
+#: cp/pt.c:7963
+#, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
-msgstr "несоответствия типа/значения в аргументе %d в списке параметров шаблона для %qD"
+msgstr "несоответствие ограничений в аргументе %d в списке параметров шаблона для %qD"
 
-#: cp/pt.c:7952
-#, fuzzy, gcc-internal-format
-#| msgid "  expected a type, got %qE"
+#: cp/pt.c:7966
+#, gcc-internal-format
 msgid "  expected %qD but got %qD"
-msgstr "  ожидался тип, обнаружено %qE"
+msgstr ""
 
-#: cp/pt.c:8012
-#, fuzzy, gcc-internal-format
-#| msgid "could not convert template argument %qE to %qT"
+#: cp/pt.c:8026
+#, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
-msgstr "ошибка при преобразовании аргумента шаблона %qE в %qT"
+msgstr "ошибка при преобразовании аргумента шаблона %qE из %qT в %qT"
 
-#: cp/pt.c:8149 cp/pt.c:8465
+#: cp/pt.c:8163 cp/pt.c:8479
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "некорректный аргумент шаблона %d"
 
-#: cp/pt.c:8164 cp/pt.c:8298
+#: cp/pt.c:8178 cp/pt.c:8312
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "неправильное число аргументов шаблона (%d, а должно быть %d)"
 
-#: cp/pt.c:8294
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "wrong number of template arguments (%d, should be %d)"
+#: cp/pt.c:8308
+#, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
-msgstr "неправильное число аргументов шаблона (%d, а должно быть %d)"
+msgstr "неправильное число аргументов шаблона (%d, а должно быть по крайней мере %d)"
 
-#: cp/pt.c:8303
-#, fuzzy, gcc-internal-format
-#| msgid "provided for %q+D"
+#: cp/pt.c:8317
+#, gcc-internal-format
 msgid "provided for %qD"
-msgstr "задано для %q+D"
+msgstr "предоставлено для %qD"
 
-#: cp/pt.c:8328
-#, fuzzy, gcc-internal-format
-#| msgid "default argument for template parameter for class enclosing %qD"
+#: cp/pt.c:8342
+#, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
-msgstr "подразумеваемый аргумент для параметра шаблона для класса включающего %qD"
+msgstr "pack expansion аргумент для non-pack параметра %qD алиасного шаблона %qD"
 
-#: cp/pt.c:8332
-#, fuzzy, gcc-internal-format
-#| msgid "default argument given for parameter %d of %q#D"
+#: cp/pt.c:8346
+#, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
-msgstr "подразумеваемый аргумент задан для параметра %d %q#D"
+msgstr "pack expansion аргумент для non-pack параметра %qD concept %qD"
 
-#: cp/pt.c:8431
+#: cp/pt.c:8445
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
-msgstr ""
+msgstr "так что любая конкретизация с непустым пакетом параметров была бы синтаксически некорректной"
 
-#: cp/pt.c:9054
+#: cp/pt.c:9068
 #, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%q#D не является шаблоном функции"
 
-#: cp/pt.c:9221
+#: cp/pt.c:9235
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "не-шаблонный тип %qT использован как шаблон"
 
-#: cp/pt.c:9223
+#: cp/pt.c:9237
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "для декларации шаблона %q+D"
 
-#: cp/pt.c:9346
-#, fuzzy, gcc-internal-format
-#| msgid "internal consistency failure"
+#: cp/pt.c:9360
+#, gcc-internal-format
 msgid "template constraint failure"
-msgstr "обнаружена несогласованность внутреннего представления gcc"
+msgstr "нарушение ограничения шаблона"
 
-#: cp/pt.c:9697
-#, fuzzy, gcc-internal-format
-#| msgid "%qD is not a variable"
+#: cp/pt.c:9718
+#, gcc-internal-format
 msgid "use of invalid variable template %qE"
-msgstr "%qD не переменная"
+msgstr "использование некорректного переменного шаблона %qE"
 
-#: cp/pt.c:10125
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum) substituting %qS"
+#: cp/pt.c:10148
+#, gcc-internal-format, gfc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
-msgstr "глубина конкретизации шаблона превышает максимум %d (задайте -ftemplate-depth= чтобы увеличить максимум) при подстановке %qS"
+msgstr "глубина конкретизации шаблона превышает максимум %d (используйте -ftemplate-depth=, чтобы увеличить максимум)"
 
-#: cp/pt.c:11202
-#, fuzzy, gcc-internal-format
-#| msgid "flexible array member in union"
+#: cp/pt.c:11225
+#, gcc-internal-format
 msgid "flexible array member %qD in union"
-msgstr "регулируемый элемент-массив в объединении"
+msgstr ""
 
-#: cp/pt.c:11691
+#: cp/pt.c:11713
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
-msgstr ""
+msgstr "свертка пустого расширения над %O"
 
-#: cp/pt.c:12160
-#, fuzzy, gcc-internal-format
-#| msgid "mismatched argument pack lengths while expanding %<%T%>"
+#: cp/pt.c:12182
+#, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
-msgstr "несоответствие длин argument pack при расширении %<%T%>"
+msgstr ""
 
-#: cp/pt.c:12163
-#, fuzzy, gcc-internal-format
-#| msgid "mismatched argument pack lengths while expanding %<%E%>"
+#: cp/pt.c:12185
+#, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
-msgstr "несоответствие длин argument pack при расширении %<%E%>"
+msgstr ""
 
-#: cp/pt.c:12747
-#, fuzzy, gcc-internal-format
-#| msgid "redefinition of default argument for %q#D"
+#: cp/pt.c:12769
+#, gcc-internal-format
 msgid "  when instantiating default argument for call to %qD"
-msgstr "редекларация аргумента по умолчанию для %q#D"
+msgstr ""
 
 #. It may seem that this case cannot occur, since:
 #.
@@ -53289,289 +47416,279 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:13708
+#: cp/pt.c:13730
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "переменная %qD имеет тип функции"
 
-#: cp/pt.c:13881
+#: cp/pt.c:13903
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "некорректный тип параметра %qT"
 
-#: cp/pt.c:13883
+#: cp/pt.c:13905
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "в декларации %q+D"
 
-#: cp/pt.c:14001
+#: cp/pt.c:14023
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "функция возвращает массив"
 
-#: cp/pt.c:14003
+#: cp/pt.c:14025
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "функция возвращает функцию"
 
-#: cp/pt.c:14043
+#: cp/pt.c:14065
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "создание указателя на элемент-функцию не классового типа %qT"
 
-#: cp/pt.c:14637
+#: cp/pt.c:14659
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "создание ссылки на void"
 
-#: cp/pt.c:14639
+#: cp/pt.c:14661
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "формирование указателя на ссылочный тип %qT"
 
-#: cp/pt.c:14641
+#: cp/pt.c:14663
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "формирование ссылки на ссылочный тип %qT"
 
-#: cp/pt.c:14654
-#, fuzzy, gcc-internal-format
-#| msgid "cannot declare pointer to qualified function type %qT"
+#: cp/pt.c:14676
+#, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
-msgstr "невозможно декларировать указатель на квалифицированный тип функции %qT"
+msgstr "формирование указателя на квалифицированный тип функции %qT"
 
-#: cp/pt.c:14657
-#, fuzzy, gcc-internal-format
-#| msgid "cannot declare reference to qualified function type %qT"
+#: cp/pt.c:14679
+#, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
-msgstr "невозможно декларировать ссылку на квалифицированный тип функции %qT"
+msgstr "формирование ссылки на квалифицированный тип функции %qT"
 
-#: cp/pt.c:14705
+#: cp/pt.c:14727
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "создание указателя на элемент не классового типа %qT"
 
-#: cp/pt.c:14711
+#: cp/pt.c:14733
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "создание указателя на элемент ссылочного типа %qT"
 
-#: cp/pt.c:14717
+#: cp/pt.c:14739
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "создание указателя на элемент типа void"
 
-#: cp/pt.c:14783
+#: cp/pt.c:14805
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "создание массива элементов типа %qT"
 
-#: cp/pt.c:14816
+#: cp/pt.c:14838
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT не является типом class, struct или union"
 
-#: cp/pt.c:14853
+#: cp/pt.c:14875
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT разрешается в %qT, который не является перечислимым типом"
 
-#: cp/pt.c:14861
+#: cp/pt.c:14883
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr "%qT разрешается в %qT, который не является классовым типом"
 
-#: cp/pt.c:14925
-#, fuzzy, gcc-internal-format
-#| msgid "ISO C++ does not allow initializers in lambda expression capture lists"
+#: cp/pt.c:14947
+#, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
-msgstr "ISO C++ не допускает инициализаторы в списках lambda expression capture"
+msgstr "пустой инициализатор в lambda init-capture"
 
-#: cp/pt.c:15000
+#: cp/pt.c:15022
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "использование %qs в шаблоне"
 
-#: cp/pt.c:15178
+#: cp/pt.c:15200
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "квалифицированный тип %qT не соответствует имени деструктора ~%qT"
 
-#: cp/pt.c:15193
+#: cp/pt.c:15215
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "зависимое имя %qE разбирается как не тип, но конкретизация дает тип"
 
-#: cp/pt.c:15195
+#: cp/pt.c:15217
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "задайте %<typename %E%>, если подразумевается тип"
 
-#: cp/pt.c:15394
+#: cp/pt.c:15416
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "использование некорректного поля %qD"
 
-#: cp/pt.c:15883 cp/pt.c:17386
+#: cp/pt.c:15905 cp/pt.c:17408
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "некорректное использование pack expansion expression"
 
-#: cp/pt.c:15887 cp/pt.c:17390
+#: cp/pt.c:15909 cp/pt.c:17412
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "используйте %<...%> для расширения argument pack"
 
-#: cp/pt.c:18334
+#: cp/pt.c:18371
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr "%qD не декларирован в этом контексте, и не было найдено деклараций при зависимом от аргументов поиске в точке конкретизации"
 
-#: cp/pt.c:18362
+#: cp/pt.c:18399
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr "декларации в зависимой базе %qT не найдены при неквалифицированном поиске"
 
-#: cp/pt.c:18367
+#: cp/pt.c:18404
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "используйте %<this->%D%>"
 
-#: cp/pt.c:18370
+#: cp/pt.c:18407
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "используйте %<%T::%D%>"
 
-#: cp/pt.c:18375
-#, fuzzy, gcc-internal-format
-#| msgid "%q+D declared here, later in the translation unit"
+#: cp/pt.c:18412
+#, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
-msgstr "%q+D декларировано здесь, позднее в единице компиляции"
+msgstr "%qD декларировано здесь, позднее в единице трансляции"
 
-#: cp/pt.c:18712
+#: cp/pt.c:18752
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT не является классом или пространством имён"
 
-#: cp/pt.c:18715
+#: cp/pt.c:18755
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD не является классом или пространством имён"
 
-#: cp/pt.c:19026
-#, fuzzy, gcc-internal-format
-#| msgid "%qT is/uses anonymous type"
+#: cp/pt.c:19066
+#, gcc-internal-format
 msgid "%qT is/uses unnamed type"
-msgstr "%qT есть/использует анонимный тип"
+msgstr "%qT есть/использует неименованный тип"
 
-#: cp/pt.c:19028
+#: cp/pt.c:19068
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "аргумент шаблона для %qD использует локальный тип %qT"
 
-#: cp/pt.c:19038
+#: cp/pt.c:19078
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT есть переменно модифицированный тип"
 
-#: cp/pt.c:19053
+#: cp/pt.c:19093
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "целочисленное выражение %qE не является константой"
 
-#: cp/pt.c:19071
+#: cp/pt.c:19111
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  при конкретизации %qD"
 
-#: cp/pt.c:22972
-#, fuzzy, gcc-internal-format
-#| msgid "ambiguous class template instantiation for %q#T"
+#: cp/pt.c:23050
+#, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
-msgstr "неоднозначная конкретизация шаблона класса для %q#T"
+msgstr "неоднозначная конкретизация шаблона для %q#T"
 
-#: cp/pt.c:22974
-#, fuzzy, gcc-internal-format
-#| msgid "ambiguous class template instantiation for %q#T"
+#: cp/pt.c:23052
+#, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
-msgstr "неоднозначная конкретизация шаблона класса для %q#T"
+msgstr "неоднозначная конкретизация шаблона класса для %q#D"
 
-#: cp/pt.c:22980
-#, fuzzy
-#| msgid "%s %+#D"
+#: cp/pt.c:23058
 msgid "%s %#qS"
-msgstr "%s %+#D"
+msgstr ""
 
-#: cp/pt.c:23004 cp/pt.c:23091
+#: cp/pt.c:23082 cp/pt.c:23169
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "явная конкретизация нешаблона %q#D"
 
-#: cp/pt.c:23023
+#: cp/pt.c:23101
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD не является статическим элементом данных шаблона класса"
 
-#: cp/pt.c:23029 cp/pt.c:23086
+#: cp/pt.c:23107 cp/pt.c:23164
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "нет подходящего шаблона для %qD"
 
-#: cp/pt.c:23034
+#: cp/pt.c:23112
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "тип %qT для явной конкретизации %qD не соответствует декларированному типу %qT"
 
-#: cp/pt.c:23042
+#: cp/pt.c:23120
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "явная конкретизация %q#D"
 
-#: cp/pt.c:23078
+#: cp/pt.c:23156
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "повторная явная конкретизация %q#D"
 
-#: cp/pt.c:23101 cp/pt.c:23187
+#: cp/pt.c:23179 cp/pt.c:23265
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ 1998 запрещает использование %<extern%> в явной конкретизации"
 
-#: cp/pt.c:23106 cp/pt.c:23204
+#: cp/pt.c:23184 cp/pt.c:23282
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "класс хранения %qD в конкретизации шаблона"
 
-#: cp/pt.c:23163
+#: cp/pt.c:23241
 #, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "явная конкретизация неклассового шаблона %qD"
 
-#: cp/pt.c:23165
+#: cp/pt.c:23243
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "явная конкретизация типа %qT, не являющегося шаблоном"
 
-#: cp/pt.c:23174
+#: cp/pt.c:23252
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "явная конкретизация %q#T до определения шаблона"
 
-#: cp/pt.c:23192
+#: cp/pt.c:23270
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ запрещает использование %qE в явных конкретизациях"
 
-#: cp/pt.c:23238
+#: cp/pt.c:23316
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "повторная явная конкретизация %q#T"
 
-#: cp/pt.c:23536
-#, fuzzy, gcc-internal-format
-#| msgid "explicit specialization of %qD after first use"
+#: cp/pt.c:23614
+#, gcc-internal-format
 msgid "exception specification of %qD depends on itself"
-msgstr "явная специализация %qD после первого использования"
+msgstr ""
 
 #. [temp.explicit]
 #.
@@ -53580,121 +47697,110 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:23842
+#: cp/pt.c:23920
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "явная конкретизация %qD без определения"
 
-#: cp/pt.c:24043
+#: cp/pt.c:24121
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
-msgstr "глубина конкретизации шаблона превышает максимум %d при конкретизации %q+D, возможно при генерации виртуальной таблицы (задайте -ftemplate-depth= чтобы увеличить максимум)"
+msgstr "глубина конкретизации шаблона превышает максимум %d при конкретизации %q+D, возможно при генерации виртуальной таблицы (задайте -ftemplate-depth=, чтобы увеличить максимум)"
 
-#: cp/pt.c:24418
+#: cp/pt.c:24496
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "некорректный нетиповый параметр шаблона"
 
-#: cp/pt.c:24420
+#: cp/pt.c:24498
 #, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T не является корректным типом для нетипового параметра шаблона"
 
-#: cp/pt.c:25723
-#, fuzzy, gcc-internal-format
-#| msgid "keyword %<typename%> not allowed outside of templates"
+#: cp/pt.c:25802
+#, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
-msgstr "ключевое слово %<typename%> не допускается вне шаблонов"
+msgstr ""
 
-#: cp/pt.c:25961
-#, fuzzy, gcc-internal-format
-#| msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
+#: cp/pt.c:26040
+#, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
-msgstr "вывод из взятого в скобки списка инизиализатора требует #include <initializer_list>"
+msgstr ""
 
-#: cp/pt.c:26440
-#, fuzzy, gcc-internal-format
-#| msgid "non-template %qD used as template"
+#: cp/pt.c:26519
+#, gcc-internal-format
 msgid "non-class template %qT used without template arguments"
-msgstr "не шаблон %qD использован как шаблон"
+msgstr "неклассовый шаблон %qT использован без аргументов шаблона"
 
-#: cp/pt.c:26586
+#: cp/pt.c:26665
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
-msgstr ""
+msgstr "невозможно вывести аргументы шаблона для инициализации копированием %qT, поскольку он имеет неявное руководство вывода или декларированные пользователем конструкторы"
 
-#: cp/pt.c:26593
-#, fuzzy, gcc-internal-format
-#| msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
+#: cp/pt.c:26672
+#, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
-msgstr "%qE не есть корректный аргумент шаблона типа %qT поскольку %qD не имеет привязки"
+msgstr ""
 
-#: cp/pt.c:26607
-#, fuzzy, gcc-internal-format
-#| msgid "  template argument deduction/substitution failed:"
+#: cp/pt.c:26686
+#, gcc-internal-format
 msgid "class template argument deduction failed:"
-msgstr "  вывод/подстановка аргумента шаблона неудачна:"
+msgstr "вывод аргумента шаблона класса потерпел неудачу:"
 
-#: cp/pt.c:26614
-#, fuzzy, gcc-internal-format
-#| msgid "function not considered for inlining"
+#: cp/pt.c:26693
+#, gcc-internal-format
 msgid "explicit deduction guides not considered for copy-initialization"
-msgstr "функция не подлежит inline-подстановке"
+msgstr "явные руководства вывода не рассматриваются для copy-инициализации"
 
-#: cp/pt.c:26676
+#: cp/pt.c:26755
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
-msgstr ""
+msgstr "direct-list-initialization %<auto%> требует ровно один элемент"
 
-#: cp/pt.c:26679
+#: cp/pt.c:26758
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
-msgstr ""
+msgstr "для вывода к %<std::initializer_list%> используйте copy-list-initialization (то есть добавьте %<=%> перед %<{%>)"
 
-#: cp/pt.c:26711
+#: cp/pt.c:26790
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
-msgstr ""
+msgstr "%qT как тип а не плоский %<decltype(auto)%>"
 
-#: cp/pt.c:26746
-#, fuzzy, gcc-internal-format
-#| msgid "unable to deduce %qT from %qE"
+#: cp/pt.c:26825
+#, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
-msgstr "невозможно вывести %qT из %qE"
+msgstr "не удается вывести возвращаемый тип lambda из %qE"
 
-#: cp/pt.c:26748
+#: cp/pt.c:26827
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "невозможно вывести %qT из %qE"
 
-#: cp/pt.c:26781
+#: cp/pt.c:26860
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
-msgstr ""
+msgstr "ограничения заполнителя не удовлетворены"
 
-#: cp/pt.c:26785
-#, fuzzy, gcc-internal-format
-#| msgid "insn does not satisfy its constraints:"
+#: cp/pt.c:26864
+#, gcc-internal-format
 msgid "deduced initializer does not satisfy placeholder constraints"
-msgstr "RTL-инструкция не удовлетворяет своим ограничениям:"
+msgstr "выведенный инициализатор не удовлетворяет ограничениям заполнителя"
 
-#: cp/pt.c:26789
-#, fuzzy, gcc-internal-format
-#| msgid "insn does not satisfy its constraints:"
+#: cp/pt.c:26868
+#, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
-msgstr "RTL-инструкция не удовлетворяет своим ограничениям:"
+msgstr "выведенный тип возврата не удовлетворяет ограничениям заполнителя"
 
-#: cp/pt.c:26793
-#, fuzzy, gcc-internal-format
-#| msgid "insn does not satisfy its constraints:"
+#: cp/pt.c:26872
+#, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
-msgstr "RTL-инструкция не удовлетворяет своим ограничениям:"
+msgstr "выведенный тип выражения не удовлетворяет ограничениям заполнителя"
 
-#: cp/pt.c:26912
-#, fuzzy, gcc-internal-format
-#| msgid "invalid non-type template argument"
+#: cp/pt.c:26991
+#, gcc-internal-format
 msgid "invalid use of %qT in template argument"
-msgstr "некорректный нетиповый аргумент шаблона"
+msgstr ""
 
 #: cp/repo.c:113
 #, gcc-internal-format
@@ -53712,27 +47818,24 @@
 msgstr "ошибка при создании информационного файла репозитория %qs"
 
 #: cp/rtti.c:313
-#, fuzzy, gcc-internal-format
-#| msgid "cannot use typeid with -fno-rtti"
+#, gcc-internal-format
 msgid "cannot use %<typeid%> with -fno-rtti"
-msgstr "использование идентификатора типа с ключом -fno-rtti недопустимо"
+msgstr ""
 
 #: cp/rtti.c:322
-#, fuzzy, gcc-internal-format
-#| msgid "must #include <typeinfo> before using typeid"
+#, gcc-internal-format
 msgid "must %<#include <typeinfo>%> before using %<typeid%>"
-msgstr "необходимо включить #include <typeinfo> до использования идентификатора типа"
+msgstr ""
 
 #: cp/rtti.c:425
 #, gcc-internal-format
 msgid "cannot create type information for type %qT because it involves types of variable size"
-msgstr "невозможно создать информацию о типе для типа %qT поскольку он включает типы переменного размера"
+msgstr "невозможно создать информацию о типе для типа %qT, поскольку он включает типы переменного размера"
 
 #: cp/rtti.c:515
-#, fuzzy, gcc-internal-format
-#| msgid "cannot declare pointer to qualified function type %qT"
+#, gcc-internal-format
 msgid "typeid of qualified function type %qT"
-msgstr "невозможно декларировать указатель на квалифицированный тип функции %qT"
+msgstr "идентификатор типа квалифицированного типа функции %qT"
 
 #: cp/rtti.c:696 cp/rtti.c:711
 #, gcc-internal-format
@@ -53749,98 +47852,89 @@
 msgid "cannot dynamic_cast %qE (of type %q#T) to type %q#T (%s)"
 msgstr "невозможно dynamic_cast %qE (типа %q#T) к типу %q#T (%s)"
 
-#: cp/search.c:240
+#: cp/search.c:243
 #, gcc-internal-format
 msgid "%qT is an ambiguous base of %qT"
 msgstr "%qT является неоднозначной базой %qT"
 
-#: cp/search.c:256
+#: cp/search.c:259
 #, gcc-internal-format
 msgid "%qT is an inaccessible base of %qT"
 msgstr "%qT является недостижимой базой %qT"
 
-#: cp/search.c:1905
-#, fuzzy, gcc-internal-format
-#| msgid "invalid covariant return type for %q+#D"
+#: cp/search.c:1908
+#, gcc-internal-format
 msgid "invalid covariant return type for %q#D"
-msgstr "некорректный ковариантный тип результата для %q+#D"
+msgstr "некорректный ковариантный тип результата для %q#D"
 
-#: cp/search.c:1907 cp/search.c:1922 cp/search.c:1928 cp/search.c:1957
-#, fuzzy, gcc-internal-format
-#| msgid "overriding deleted function %q+D"
+#: cp/search.c:1910 cp/search.c:1925 cp/search.c:1931 cp/search.c:1960
+#, gcc-internal-format
 msgid "overridden function is %q#D"
-msgstr "перебивание удаленной функции %q+D"
+msgstr ""
 
-#: cp/search.c:1920
+#: cp/search.c:1923
 #, gcc-internal-format
 msgid "invalid covariant return type for %q+#D"
 msgstr "некорректный ковариантный тип результата для %q+#D"
 
-#: cp/search.c:1926
+#: cp/search.c:1929
 #, gcc-internal-format
 msgid "conflicting return type specified for %q+#D"
 msgstr "задан несовместимый тип результата для %q+#D"
 
-#: cp/search.c:1942
+#: cp/search.c:1945
 #, gcc-internal-format
 msgid "looser throw specifier for %q+#F"
 msgstr "неточный throw спецификатор для %q+#F"
 
-#: cp/search.c:1944
-#, fuzzy, gcc-internal-format
-#| msgid "overriding deleted function %q+D"
+#: cp/search.c:1947
+#, gcc-internal-format
 msgid "overridden function is %q#F"
-msgstr "перебивание удаленной функции %q+D"
+msgstr ""
 
-#: cp/search.c:1955
+#: cp/search.c:1958
 #, gcc-internal-format
 msgid "conflicting type attributes specified for %q+#D"
 msgstr "заданы несовместимые атрибуты типа для %q+#D"
 
-#: cp/search.c:1972
-#, fuzzy, gcc-internal-format
-#| msgid "expected %<__transaction_atomic%>"
+#: cp/search.c:1975
+#, gcc-internal-format
 msgid "%qD declared %<transaction_safe_dynamic%>"
-msgstr "ожидалось %<__transaction_atomic%>"
+msgstr "%qD декларировано %<transaction_safe_dynamic%>"
 
-#: cp/search.c:1974
-#, fuzzy, gcc-internal-format
-#| msgid "variable %q+D declared %<inline%>"
+#: cp/search.c:1977
+#, gcc-internal-format
 msgid "overriding %qD declared %<transaction_safe%>"
-msgstr "переменная %q+D декларирована со спецификатором %<inline%>"
+msgstr "перебивает %qD декларированное %<transaction_safe%>"
 
-#: cp/search.c:1981
-#, fuzzy, gcc-internal-format
-#| msgid "overriding non-deleted function %q+D"
+#: cp/search.c:1984
+#, gcc-internal-format
 msgid "deleted function %q+D overriding non-deleted function"
-msgstr "перебивание неудаленной функции %q+D"
+msgstr ""
 
-#: cp/search.c:1984 cp/search.c:1992 cp/search.c:2000
-#, fuzzy, gcc-internal-format
-#| msgid "overriding deleted function %q+D"
+#: cp/search.c:1987 cp/search.c:1995 cp/search.c:2003
+#, gcc-internal-format
 msgid "overridden function is %qD"
-msgstr "перебивание удаленной функции %q+D"
+msgstr ""
 
-#: cp/search.c:1989
-#, fuzzy, gcc-internal-format
-#| msgid "non-deleted function %q+D"
+#: cp/search.c:1992
+#, gcc-internal-format
 msgid "non-deleted function %q+D overriding deleted function"
-msgstr "неудаленная функция %q+D"
+msgstr ""
 
-#: cp/search.c:1998
-#, fuzzy, gcc-internal-format
-#| msgid "built-in function %q+D declared as non-function"
+#: cp/search.c:2001
+#, gcc-internal-format
 msgid "virtual function %q+D overriding final function"
-msgstr "внутренняя функция %q+D декларирована как не функция"
+msgstr ""
 
 #. A static member function cannot match an inherited
 #. virtual member function.
-#: cp/search.c:2082
+#: cp/search.c:2085
 #, gcc-internal-format
 msgid "%q+#D cannot be declared"
 msgstr "декларация %q+#D недопустима,"
 
-#: cp/search.c:2083
+#: cp/search.c:2086
 #, gcc-internal-format
 msgid "  since %q+#D declared in base class"
 msgstr "  поскольку %q+#D объявлена в базовом классе"
@@ -53861,10 +47955,9 @@
 msgstr ""
 
 #: cp/semantics.c:1360
-#, fuzzy, gcc-internal-format
-#| msgid "creating pointer to member reference type %qT"
+#, gcc-internal-format
 msgid "catching non-reference type %q#T"
-msgstr "создание указателя на элемент ссылочного типа %qT"
+msgstr ""
 
 #: cp/semantics.c:1569
 #, gcc-internal-format
@@ -53877,638 +47970,595 @@
 msgstr "__label__ декларации допускаются только в контекстах функций"
 
 #: cp/semantics.c:1833
-#, fuzzy, gcc-internal-format
-#| msgid "invalid use of member %q+D in static member function"
+#, gcc-internal-format
 msgid "invalid use of member %qD in static member function"
-msgstr "некорректное использование элемента %q+D в статическом элементе-функции"
+msgstr "некорректное использование элемента %qD в статическом элементе-функции"
 
-#: cp/semantics.c:2153
+#: cp/semantics.c:2156
 #, gcc-internal-format
 msgid "a statement expression is an insufficient context for overload resolution"
 msgstr ""
 
-#: cp/semantics.c:2540
+#: cp/semantics.c:2543
 #, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr "аргументы к деструктору не допускаются"
 
-#: cp/semantics.c:2622
+#: cp/semantics.c:2625
 #, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr "имя %<this%> недоступно для статических элементов-функций"
 
-#: cp/semantics.c:2624
+#: cp/semantics.c:2627
 #, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr "некорректное использование %<this%> в функции, не являющейся элементом"
 
-#: cp/semantics.c:2626
+#: cp/semantics.c:2629
 #, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr "некорректное использование %<this%> на внешнем уровне"
 
-#: cp/semantics.c:2648
+#: cp/semantics.c:2651
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "некорректный квалифицированный контекст в имени псевдодеструктора"
 
-#: cp/semantics.c:2656 cp/typeck.c:2604
+#: cp/semantics.c:2659 cp/typeck.c:2604
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "квалифицированный тип %qT не соответствует имени деструктора ~%qT"
 
-#: cp/semantics.c:2678
+#: cp/semantics.c:2681
 #, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr "%qE не имеет тип %qT"
 
-#: cp/semantics.c:2751
+#: cp/semantics.c:2754
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr "составной литерал необъектного типа %qT"
 
-#: cp/semantics.c:2892
+#: cp/semantics.c:2895
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr "параметры шаблона, являющиеся типами, должны задаваться при помощи ключевых слов %<class%> или %<typename%>"
 
-#: cp/semantics.c:2942
+#: cp/semantics.c:2945
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr "некорректное использование типа %qT как подразумеваемого значения для шаблона параметра шаблона"
 
-#: cp/semantics.c:2945
+#: cp/semantics.c:2948
 #, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr "некорректный подразумеваемый аргумент для шаблона параметра шаблона"
 
-#: cp/semantics.c:2962
+#: cp/semantics.c:2965
 #, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr "определение %q#T внутри списка параметров шаблона"
 
-#: cp/semantics.c:2993
+#: cp/semantics.c:2996
 #, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr "некорректное определение квалифицированного типа %qT"
 
-#: cp/semantics.c:3263
+#: cp/semantics.c:3266
 #, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "некорректная спецификация базового класса"
 
-#: cp/semantics.c:3423
-#, fuzzy, gcc-internal-format
-#| msgid "protected member %q+#D in anonymous union"
+#: cp/semantics.c:3426
+#, gcc-internal-format
 msgid "cannot capture member %qD of anonymous union"
-msgstr "protected-элемент %q+#D в анонимном объединении"
+msgstr "невозможно захватить элемент %qD анонимного объединения"
 
-#: cp/semantics.c:3443 cp/semantics.c:9269
+#: cp/semantics.c:3446 cp/semantics.c:9272
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qD не захватывается"
 
-#: cp/semantics.c:3448
+#: cp/semantics.c:3451
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
-msgstr ""
+msgstr "lambda не имеет подразумеваемого захвата"
 
-#: cp/semantics.c:3450
+#: cp/semantics.c:3453
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
-msgstr ""
+msgstr "lambda в локальном классе %q+T не может захватывать переменные из объемлющего контекста"
 
-#: cp/semantics.c:3462
-#, fuzzy, gcc-internal-format
-#| msgid "use of %<auto%> variable from containing function"
+#: cp/semantics.c:3465
+#, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
-msgstr "использование %<auto%> переменной из внутренней функции"
+msgstr "использование локальной переменной с автоматическим хранением из объемлющей функции"
 
-#: cp/semantics.c:3464
+#: cp/semantics.c:3467
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr "использование параметра из внутренней функции"
 
-#: cp/semantics.c:3596
-#, fuzzy, gcc-internal-format
-#| msgid "use of parameter %qD outside function body"
+#: cp/semantics.c:3599
+#, gcc-internal-format
 msgid "use of parameter outside function body"
-msgstr "использование параметра %qD вне тела функции"
+msgstr "использование параметра вне тела функции"
 
-#: cp/semantics.c:3606
-#, fuzzy, gcc-internal-format
-#| msgid "mismatched arguments"
+#: cp/semantics.c:3609
+#, gcc-internal-format
 msgid "missing template arguments"
-msgstr "несовпадающие аргументы"
+msgstr "отсутствуют аргументы шаблона"
 
-#: cp/semantics.c:3633
+#: cp/semantics.c:3636
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
-msgstr "параметр шаблона %qD типа %qT не допускается в целочисленном константном выражении поскольку он не целого или перечислимого типа"
+msgstr "параметр шаблона %qD типа %qT не допускается в целочисленном константном выражении, поскольку он не целого или перечислимого типа"
 
-#: cp/semantics.c:3664
+#: cp/semantics.c:3667
 #, gcc-internal-format
 msgid "use of namespace %qD as expression"
 msgstr "использование пространства имён %qD в качестве выражения"
 
-#: cp/semantics.c:3669
+#: cp/semantics.c:3672
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr "использование шаблона класса %qT в качестве выражения"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:3675
+#: cp/semantics.c:3678
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "запрос элемента %qD неоднозначен в сетке множественного наследования"
 
-#: cp/semantics.c:3702
+#: cp/semantics.c:3705
 #, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "%qD не может появляться в константном выражении"
 
-#: cp/semantics.c:3841
+#: cp/semantics.c:3844
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "тип %qE неизвестен"
 
-#: cp/semantics.c:3870
+#: cp/semantics.c:3873
 #, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr "%qT не имеет перечислимый тип"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4009
+#: cp/semantics.c:4012
 #, gcc-internal-format
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr "Parameter pack __bases допустим только в декларации шаблона"
 
-#: cp/semantics.c:4038
+#: cp/semantics.c:4041
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr "невозможно применить %<offsetof%> к деструктору %<~%T%>"
 
-#: cp/semantics.c:4052
+#: cp/semantics.c:4055
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "невозможно применить %<offsetof%> к элементу-функции %qD"
 
-#: cp/semantics.c:4056
-#, fuzzy, gcc-internal-format
-#| msgid "cannot apply %<offsetof%> to member function %qD"
+#: cp/semantics.c:4059
+#, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function"
-msgstr "невозможно применить %<offsetof%> к элементу-функции %qD"
+msgstr ""
 
-#: cp/semantics.c:4061
-#, fuzzy, gcc-internal-format
-#| msgid "cannot apply %<offsetof%> to member function %qD"
+#: cp/semantics.c:4064
+#, gcc-internal-format
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
-msgstr "невозможно применить %<offsetof%> к элементу-функции %qD"
+msgstr ""
 
-#: cp/semantics.c:4072
-#, fuzzy, gcc-internal-format
-#| msgid "cannot receive objects of non-trivially-copyable type %q#T through %<...%>; "
+#: cp/semantics.c:4075
+#, gcc-internal-format
 msgid "offsetof within non-standard-layout type %qT is conditionally-supported"
-msgstr "невозможно принять объекты нетривиально копируемого типа %q#T через %<...%>"
+msgstr ""
 
-#: cp/semantics.c:4583 cp/semantics.c:6069 cp/semantics.c:6140
-#: cp/semantics.c:6183 cp/semantics.c:6533 cp/semantics.c:6632
-#: cp/semantics.c:6775
+#: cp/semantics.c:4586 cp/semantics.c:6072 cp/semantics.c:6143
+#: cp/semantics.c:6186 cp/semantics.c:6536 cp/semantics.c:6635
+#: cp/semantics.c:6778
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
-msgstr ""
+msgstr "%<this%> допускается в OpenMP только в %<declare simd%> клаузулах"
 
-#: cp/semantics.c:5271
-#, fuzzy, gcc-internal-format
-#| msgid "reference to %qD is ambiguous"
+#: cp/semantics.c:5274
+#, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
-msgstr "ссылка на %qD противоречива"
+msgstr "определенный пользователем reduction поиск неоднозначен"
 
-#: cp/semantics.c:5544
+#: cp/semantics.c:5547
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
-msgstr ""
+msgstr "%qE в %<reduction%> клаузуле есть массив нулевого размера"
 
-#: cp/semantics.c:5592
-#, fuzzy, gcc-internal-format
-#| msgid "%qE has invalid type for %<reduction%>"
+#: cp/semantics.c:5595
+#, gcc-internal-format
 msgid "%qE has const type for %<reduction%>"
-msgstr "%qE имеет неверный тип для %<reduction%>"
+msgstr "%qE имеет const тип для %<reduction%>"
 
-#: cp/semantics.c:5707
+#: cp/semantics.c:5710
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
-msgstr ""
+msgstr "определенная пользователем редукция в конструкторским инициализатором для базового класса %qT"
 
-#: cp/semantics.c:5941
+#: cp/semantics.c:5944
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
-msgstr ""
+msgstr "linear клаузула с %qs модификатором применена к нессылочной переменной с %qT типом"
 
-#: cp/semantics.c:5955
+#: cp/semantics.c:5958
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
-msgstr ""
+msgstr "linear клаузула применена к нецелой, неуказательной переменной с %qT типом"
 
-#: cp/semantics.c:5977
-#, fuzzy, gcc-internal-format
-#| msgid "num_threads expression must be integral"
+#: cp/semantics.c:5980
+#, gcc-internal-format
 msgid "linear step expression must be integral"
-msgstr "num_threads выражение должно быть целочисленным"
+msgstr "выражение линейного шага должно быть целочисленным"
 
-#: cp/semantics.c:6080
+#: cp/semantics.c:6083
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD не есть переменная в клаузуле %qs"
 
-#: cp/semantics.c:6152
+#: cp/semantics.c:6155
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "%qD не есть переменная в клаузуле %<firstprivate%>"
 
-#: cp/semantics.c:6195
+#: cp/semantics.c:6198
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "%qD не есть переменная в клаузуле %<lastprivate%>"
 
-#: cp/semantics.c:6240
-#, fuzzy, gcc-internal-format
-#| msgid "num_threads expression must be integral"
+#: cp/semantics.c:6243
+#, gcc-internal-format
 msgid "%<gang%> static expression must be integral"
-msgstr "num_threads выражение должно быть целочисленным"
+msgstr "%<gang%> статическое выражение должно быть целочисленным"
 
-#: cp/semantics.c:6254
-#, fuzzy, gcc-internal-format
-#| msgid "%<num_threads%> value must be positive"
+#: cp/semantics.c:6257
+#, gcc-internal-format
 msgid "%<gang%> static value must be positive"
-msgstr "значение %<num_threads%> должно быть положительным"
+msgstr "%<gang%> статическое значение должно быть положительным"
 
-#: cp/semantics.c:6288
-#, fuzzy, gcc-internal-format
-#| msgid "num_threads expression must be integral"
+#: cp/semantics.c:6291
+#, gcc-internal-format
 msgid "%<gang%> num expression must be integral"
-msgstr "num_threads выражение должно быть целочисленным"
+msgstr "%<gang%> числовое выражение должно быть целочисленным"
 
-#: cp/semantics.c:6291
-#, fuzzy, gcc-internal-format
-#| msgid "num_threads expression must be integral"
+#: cp/semantics.c:6294
+#, gcc-internal-format
 msgid "%<vector%> length expression must be integral"
-msgstr "num_threads выражение должно быть целочисленным"
+msgstr "%<vector%> выражение длины должно быть целочисленным"
 
-#: cp/semantics.c:6295
-#, fuzzy, gcc-internal-format
-#| msgid "num_threads expression must be integral"
+#: cp/semantics.c:6298
+#, gcc-internal-format
 msgid "%<worker%> num expression must be integral"
-msgstr "num_threads выражение должно быть целочисленным"
+msgstr "%<worker%> числовое выражение должно быть целочисленным"
 
-#: cp/semantics.c:6317
-#, fuzzy, gcc-internal-format
-#| msgid "%<num_threads%> value must be positive"
+#: cp/semantics.c:6320
+#, gcc-internal-format
 msgid "%<gang%> num value must be positive"
-msgstr "значение %<num_threads%> должно быть положительным"
+msgstr "%<gang%> числовое значение должно быть положительным"
 
-#: cp/semantics.c:6321
-#, fuzzy, gcc-internal-format
-#| msgid "%<num_threads%> value must be positive"
+#: cp/semantics.c:6324
+#, gcc-internal-format
 msgid "%<vector%> length value must be positive"
-msgstr "значение %<num_threads%> должно быть положительным"
+msgstr "%<vector%> значение длины должно быть положительным"
 
-#: cp/semantics.c:6326
-#, fuzzy, gcc-internal-format
-#| msgid "%<num_threads%> value must be positive"
+#: cp/semantics.c:6329
+#, gcc-internal-format
 msgid "%<worker%> num value must be positive"
-msgstr "значение %<num_threads%> должно быть положительным"
+msgstr "%<worker%> числовое значение должно быть положительным"
 
-#: cp/semantics.c:6376
+#: cp/semantics.c:6379
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr "schedule chunk size выражение должно быть целочисленным"
 
-#: cp/semantics.c:6406
-#, fuzzy, gcc-internal-format
-#| msgid "num_threads expression must be integral"
+#: cp/semantics.c:6409
+#, gcc-internal-format
 msgid "%qs length expression must be integral"
-msgstr "num_threads выражение должно быть целочисленным"
+msgstr "%qs выражение длины должно быть целочисленным"
 
-#: cp/semantics.c:6419
-#, fuzzy, gcc-internal-format
-#| msgid "collapse argument needs positive constant integer expression"
+#: cp/semantics.c:6422
+#, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
-msgstr "collapse аргумент требует положительного константного целого выражения"
+msgstr "%qs выражение длины должно быть положительным константным целочисленным выражением"
 
-#: cp/semantics.c:6438
-#, fuzzy, gcc-internal-format
-#| msgid "num_threads expression must be integral"
+#: cp/semantics.c:6441
+#, gcc-internal-format
 msgid "%<async%> expression must be integral"
-msgstr "num_threads выражение должно быть целочисленным"
+msgstr "%<async%> выражение должно быть целочисленным"
 
-#: cp/semantics.c:6466
-#, fuzzy, gcc-internal-format
-#| msgid "num_threads expression must be integral"
+#: cp/semantics.c:6469
+#, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
-msgstr "num_threads выражение должно быть целочисленным"
+msgstr "%<thread_limit%> выражение должно быть целочисленным"
 
-#: cp/semantics.c:6495
-#, fuzzy, gcc-internal-format
-#| msgid "slice end must be integer"
+#: cp/semantics.c:6498
+#, gcc-internal-format
 msgid "%<device%> id must be integral"
-msgstr "конец вырезки должен быть целым"
+msgstr "%<device%> идентификатор должен быть целочисленным"
 
-#: cp/semantics.c:6516
-#, fuzzy, gcc-internal-format
-#| msgid "schedule chunk size expression must be integral"
+#: cp/semantics.c:6519
+#, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
-msgstr "schedule chunk size выражение должно быть целочисленным"
+msgstr "%<dist_schedule%> выражение размера чанка должно быть целочисленным"
 
-#: cp/semantics.c:6543
-#, fuzzy, gcc-internal-format
-#| msgid "%qD is not a variable in clause %qs"
+#: cp/semantics.c:6546
+#, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
-msgstr "%qD не есть переменная в клаузуле %qs"
+msgstr "%qD не есть переменная в %<aligned%> клаузуле"
 
-#: cp/semantics.c:6557
+#: cp/semantics.c:6560
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
-msgstr ""
+msgstr "%qE в %<aligned%> клаузуле не указатель, не массив и не ссылка на указатель или массив"
 
-#: cp/semantics.c:6563
-#, fuzzy, gcc-internal-format
-#| msgid "%qD appears more than once in data clauses"
+#: cp/semantics.c:6566
+#, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
-msgstr "%qD появляется более одного раза в клаузуле данных"
+msgstr "%qD появляется более одного раза в %<aligned%> клаузулах"
 
-#: cp/semantics.c:6576
-#, fuzzy, gcc-internal-format
-#| msgid "schedule chunk size expression must be integral"
+#: cp/semantics.c:6579
+#, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
-msgstr "schedule chunk size выражение должно быть целочисленным"
+msgstr "%<aligned%> клаузула выражения выравнивания должна быть целочисленной"
 
-#: cp/semantics.c:6625
-#, fuzzy, gcc-internal-format
-#| msgid "%qD is not a variable in clause %qs"
+#: cp/semantics.c:6628
+#, gcc-internal-format
 msgid "%qD is not a variable in %<depend%> clause"
-msgstr "%qD не есть переменная в клаузуле %qs"
+msgstr "%qD не есть переменная в %<depend%> клаузуле"
 
-#: cp/semantics.c:6910
-#, fuzzy, gcc-internal-format
-#| msgid "too many %qs clauses"
+#: cp/semantics.c:6913
+#, gcc-internal-format
 msgid "template %qE in clause %qs"
-msgstr "слишком много конструкций %qs"
+msgstr "шаблон %qE в клаузуле %qs"
 
-#: cp/semantics.c:6914
+#: cp/semantics.c:6917
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
-msgstr ""
+msgstr "перегрузка имени функции %qE в клаузуле %qs"
 
-#: cp/semantics.c:6979
-#, fuzzy, gcc-internal-format
-#| msgid "num_threads expression must be integral"
+#: cp/semantics.c:6982
+#, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
-msgstr "num_threads выражение должно быть целочисленным"
+msgstr "%<grainsize%> выражение должно быть целочисленным"
 
-#: cp/semantics.c:7008
-#, fuzzy, gcc-internal-format
-#| msgid "num_threads expression must be integral"
+#: cp/semantics.c:7011
+#, gcc-internal-format
 msgid "%<priority%> expression must be integral"
-msgstr "num_threads выражение должно быть целочисленным"
+msgstr "%<priority%> выражение должно быть целочисленным"
 
-#: cp/semantics.c:7037
-#, fuzzy, gcc-internal-format
-#| msgid "num_threads expression must be integral"
+#: cp/semantics.c:7040
+#, gcc-internal-format
 msgid "%<num_tasks%> expression must be integral"
-msgstr "num_threads выражение должно быть целочисленным"
+msgstr "%<num_tasks%> выражение должно быть целочисленным"
 
-#: cp/semantics.c:7066
-#, fuzzy, gcc-internal-format
-#| msgid "type to vector delete is neither pointer or array type"
+#: cp/semantics.c:7069
+#, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
-msgstr "тип, заданный в векторном delete, не является ни массивом, ни указателем"
+msgstr "%qs переменная не является ни указателем, ни массивом, ни ссылкой на указатель или массив"
 
-#: cp/semantics.c:7105
-#, fuzzy, gcc-internal-format
-#| msgid "%<num_threads%> value must be positive"
+#: cp/semantics.c:7108
+#, gcc-internal-format
 msgid "%<tile%> argument needs integral type"
-msgstr "значение %<num_threads%> должно быть положительным"
+msgstr "%<tile%> аргумент требует целочисленный тип"
 
-#: cp/semantics.c:7524
+#: cp/semantics.c:7527
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr "%<threadprivate%> %qD не есть переменная файла, пространства имен или контекста блока"
 
-#: cp/semantics.c:7538
+#: cp/semantics.c:7541
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "%<threadprivate%> %qE директива не в %qT определении"
 
-#: cp/semantics.c:7743
+#: cp/semantics.c:7746
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr "разность между %qE и %qD не имеет целый тип"
 
-#: cp/semantics.c:8171
-#, fuzzy, gcc-internal-format
-#| msgid "%<#pragma omp atomic update%> uses two different variables for memory"
+#: cp/semantics.c:8174
+#, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
-msgstr "в %<#pragma omp atomic update%> используются две различные переменные для памяти"
+msgstr "%<#pragma omp simd%> использована с итерационной переменной класса %qE"
 
-#: cp/semantics.c:8398 cp/semantics.c:8408
-#, fuzzy, gcc-internal-format
-#| msgid "%<#pragma omp atomic update%> uses two different variables for memory"
+#: cp/semantics.c:8401 cp/semantics.c:8411
+#, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
-msgstr "в %<#pragma omp atomic update%> используются две различные переменные для памяти"
+msgstr "%<#pragma omp atomic update%> использует два различных выражения для памяти"
 
-#: cp/semantics.c:8702
-#, fuzzy, gcc-internal-format
-#| msgid "static assertion failed: %E"
+#: cp/semantics.c:8705
+#, gcc-internal-format
 msgid "static assertion failed"
-msgstr "не выполнено статическое утверждение: %E"
+msgstr "нарушено статическое утверждение"
 
-#: cp/semantics.c:8704
+#: cp/semantics.c:8707
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr "неудача static assertion: %s"
 
-#: cp/semantics.c:8709
+#: cp/semantics.c:8712
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "неконстантное условие для static assertion"
 
-#: cp/semantics.c:8739
+#: cp/semantics.c:8742
 #, gcc-internal-format
 msgid "argument to decltype must be an expression"
 msgstr "аргумент decltype должен быть выражением"
 
-#: cp/semantics.c:8767
+#: cp/semantics.c:8770
 #, gcc-internal-format
 msgid "decltype cannot resolve address of overloaded function"
 msgstr "decltype не может разрешить адрес перегруженной функции"
 
-#: cp/semantics.c:9308
-#, fuzzy, gcc-internal-format
-#| msgid "third operand of conditional expression has no effect"
+#: cp/semantics.c:9311
+#, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
-msgstr "третий операнд условного выражения ссылка не имеет эффекта"
+msgstr "операнд выражения свертки не имеет нерасширенных пакетов параметров"
 
-#: cp/semantics.c:9361
-#, fuzzy, gcc-internal-format
-#| msgid "template argument %qE involves template parameter(s)"
+#: cp/semantics.c:9364
+#, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
-msgstr "аргумент шаблона %qE включает параметр(ы) шаблона"
+msgstr "оба аргумента в бинарной свертке имеют нерасширенные пакеты параметров"
 
-#: cp/semantics.c:9363
+#: cp/semantics.c:9366
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
-msgstr ""
+msgstr "нет нерасширенных пакетов параметров в бинарной свертке"
 
-#: cp/semantics.c:9381
-#, fuzzy, gcc-internal-format
-#| msgid "unsupported argument to %<__builtin_return_address%>"
+#: cp/semantics.c:9384
+#, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
-msgstr "неподдерживаемый аргумент для %<__builtin_return_address%>"
+msgstr "неуказательный аргумент для %<__builtin_launder%>"
 
-#: cp/tree.c:1276
+#: cp/tree.c:1295
 #, gcc-internal-format
 msgid "%qV qualifiers cannot be applied to %qT"
 msgstr "квалификаторы %qV не могут быть применены к %qT"
 
-#: cp/tree.c:1788
-#, fuzzy, gcc-internal-format
-#| msgid "expression %qE is not a constant-expression"
+#: cp/tree.c:1807
+#, gcc-internal-format
 msgid "lambda-expression in a constant expression"
-msgstr "выражение %qE не является константным выражением"
+msgstr "lambda-выражение в константном выражении"
 
-#: cp/tree.c:1792
-#, fuzzy, gcc-internal-format
-#| msgid "expression %qE is not a constant-expression"
+#: cp/tree.c:1811
+#, gcc-internal-format
 msgid "statement-expression in a constant expression"
-msgstr "выражение %qE не является константным выражением"
+msgstr ""
 
-#: cp/tree.c:4050
-#, fuzzy, gcc-internal-format
-#| msgid "alignment of %qD is bigger than original declaration"
-msgid "the calling convention for %qT changes in -fabi-version=12 (GCC 8)"
-msgstr "выравнивание %qD больше чем в исходной декларации"
+#: cp/tree.c:4083
+#, gcc-internal-format
+msgid "-fabi-version=13 (GCC 8.2) fixes the calling convention for %qT, which was accidentally changed in 8.1"
+msgstr ""
 
-#: cp/tree.c:4055
+#: cp/tree.c:4087
 #, gcc-internal-format
+msgid "-fabi-version=12 (GCC 8.1) accidentally changes the calling convention for %qT"
+msgstr ""
+
+#: cp/tree.c:4090
+#, gcc-internal-format
+msgid " declared here"
+msgstr " объявлено здесь"
+
+#: cp/tree.c:4094
+#, gcc-internal-format
+msgid "the calling convention for %qT changes in -fabi-version=13 (GCC 8.2)"
+msgstr ""
+
+#: cp/tree.c:4096
+#, gcc-internal-format
 msgid " because all of its copy and move constructors are deleted"
 msgstr ""
 
-#: cp/tree.c:4416
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute ignored on types"
+#: cp/tree.c:4464
+#, gcc-internal-format
 msgid "%qE attribute applied to %qD with void return type"
-msgstr "атрибут %qE для типов игнорируется"
+msgstr "%qE атрибут применен к %qD с void типом возврата"
 
-#: cp/tree.c:4423
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute can only be applied to class definitions"
+#: cp/tree.c:4471
+#, gcc-internal-format
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
-msgstr "%qE атрибут может применяться только к определениям классов"
+msgstr "%qE атрибут может применяться только к функциям или к классовым или перечислимым типам"
 
-#: cp/tree.c:4475
+#: cp/tree.c:4523
 #, gcc-internal-format
 msgid "requested init_priority is not an integer constant"
 msgstr "заданный init_priority не является целой константой"
 
-#: cp/tree.c:4497
+#: cp/tree.c:4545
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr "%qE атрибут может использоваться только для определений объектов типа class на уровне файла"
 
-#: cp/tree.c:4505
+#: cp/tree.c:4553
 #, gcc-internal-format
 msgid "requested init_priority is out of range"
 msgstr "заданный init_priority вне диапазона"
 
-#: cp/tree.c:4515
+#: cp/tree.c:4563
 #, gcc-internal-format
 msgid "requested init_priority is reserved for internal use"
 msgstr "заданный init_priority зарезервировано для внутреннего использования"
 
-#: cp/tree.c:4526
+#: cp/tree.c:4574
 #, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr "%qE атрибут не поддерживается на данной платформе"
 
-#: cp/tree.c:4553
-#, fuzzy, gcc-internal-format
-#| msgid "declaration of %qD as member of %qT"
+#: cp/tree.c:4601
+#, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %qE"
-msgstr "декларация %qD как элемента %qT"
+msgstr ""
 
-#: cp/tree.c:4573
-#, fuzzy, gcc-internal-format
-#| msgid "%qD attribute requires a single NTBS argument"
+#: cp/tree.c:4621
+#, gcc-internal-format
 msgid "the %qE attribute requires arguments"
-msgstr "%qD атрибут требует единственный NTBS аргумент"
+msgstr "%qE атрибуту требуются аргументы"
 
-#: cp/tree.c:4584
-#, fuzzy, gcc-internal-format
-#| msgid "argument of %qE attribute is not a string constant"
+#: cp/tree.c:4632
+#, gcc-internal-format
 msgid "arguments to the %qE attribute must be narrow string literals"
-msgstr "аргумент %qE атрибута не строковая константа"
+msgstr "аргументы для %qE атрибута должны быть узкими строковыми литералами"
 
-#: cp/tree.c:4597 cp/tree.c:4610
-#, fuzzy, gcc-internal-format
-#| msgid "argument of %qE attribute is not a string constant"
+#: cp/tree.c:4645 cp/tree.c:4658
+#, gcc-internal-format
 msgid "arguments to the %qE attribute must contain valid identifiers"
-msgstr "аргумент %qE атрибута не строковая константа"
+msgstr "аргументы для %qE атрибута должны содержать корректные идентификаторы"
 
-#: cp/tree.c:4599
-#, fuzzy, gcc-internal-format
-#| msgid "%<%T::%D%> is not a valid declarator"
+#: cp/tree.c:4647
+#, gcc-internal-format
 msgid "%<%c%> is not a valid first character for an identifier"
-msgstr "%<%T::%D%> не является корректным декларатором"
+msgstr "%<%c%> не является корректным символом для идентификатора"
 
-#: cp/tree.c:4612
-#, fuzzy, gcc-internal-format
-#| msgid "%<%T::%D%> is not a valid declarator"
+#: cp/tree.c:4660
+#, gcc-internal-format
 msgid "%<%c%> is not a valid character in an identifier"
-msgstr "%<%T::%D%> не является корректным декларатором"
+msgstr "%<%c%> не является корректным символом в идентификаторе"
 
-#: cp/tree.c:4636
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute ignored on non-class types"
+#: cp/tree.c:4684
+#, gcc-internal-format
 msgid "%qE attribute applied to non-class, non-enum type %qT"
-msgstr "атрибут %qE для не классовых типов игнорируется"
+msgstr "атрибут %qE применен к неклассовому, неперечислимому типу %qT"
 
-#: cp/tree.c:4642
-#, fuzzy, gcc-internal-format
-#| msgid "ignoring attributes applied to %qT after definition"
+#: cp/tree.c:4690
+#, gcc-internal-format
 msgid "%qE attribute applied to %qT after its definition"
-msgstr "проигнорированы атрибуты, примененные к %qT после определения"
+msgstr "атрибут %qE применен к %qT после его определения"
 
-#: cp/tree.c:4649
-#, fuzzy, gcc-internal-format
-#| msgid "ignoring attributes applied to %qT after definition"
+#: cp/tree.c:4697
+#, gcc-internal-format
 msgid "ignoring %qE attribute applied to template instantiation %qT"
-msgstr "проигнорированы атрибуты, примененные к %qT после определения"
+msgstr "игнорирование %qE атрибута, примененного к конкретизации шаблона %qT"
 
-#: cp/tree.c:4656
-#, fuzzy, gcc-internal-format
-#| msgid "ignoring attributes applied to %qT after definition"
+#: cp/tree.c:4704
+#, gcc-internal-format
 msgid "ignoring %qE attribute applied to template specialization %qT"
-msgstr "проигнорированы атрибуты, примененные к %qT после определения"
+msgstr "игнорирование %qE атрибута, примененного к специализации шаблона %qT"
 
-#: cp/tree.c:4678
-#, fuzzy, gcc-internal-format
-#| msgid "%qE attribute only applies to functions, not %s"
+#: cp/tree.c:4726
+#, gcc-internal-format
 msgid "%qE attribute applied to non-function, non-variable %qD"
-msgstr "атрибут %qE применим только к функциям, а не к %s"
+msgstr "атрибут %qE применен к нефункции, непеременной %qD"
 
-#: cp/tree.c:4684
-#, fuzzy, gcc-internal-format
-#| msgid "%s attribute applied to %s %s at %L"
+#: cp/tree.c:4732
+#, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
-msgstr "%s атрибут применен к %s %s в %L"
+msgstr "атрибут %qE применен к extern \"C\" декларации %qD"
 
-#: cp/tree.c:5440
+#: cp/tree.c:5488
 #, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "ноль как константа пустой указатель"
 
-#: cp/tree.c:5453
+#: cp/tree.c:5501
 #, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr "lang_* check: ошибка в %s, в %s:%d"
@@ -54559,16 +48609,14 @@
 msgstr "условное выражение между различными pointer-to-member типами %qT и %qT без приведения типов"
 
 #: cp/typeck.c:1480
-#, fuzzy, gcc-internal-format
-#| msgid "canonical types differ for identical types %T and %T"
+#, gcc-internal-format
 msgid "canonical types differ for identical types %qT and %qT"
-msgstr "канонические типы различаются для идентичных типов %T and %T"
+msgstr ""
 
 #: cp/typeck.c:1487
-#, fuzzy, gcc-internal-format
-#| msgid "same canonical type node for different types %T and %T"
+#, gcc-internal-format
 msgid "same canonical type node for different types %qT and %qT"
-msgstr "общий узел канонического типа для различных типов %T и %T"
+msgstr ""
 
 #: cp/typeck.c:1620
 #, gcc-internal-format
@@ -54596,16 +48644,14 @@
 msgstr "ISO C++ запрещает применение %<__alignof%> к выражению функционального типа"
 
 #: cp/typeck.c:1853
-#, fuzzy, gcc-internal-format
-#| msgid "size of array has non-integral type %qT"
+#, gcc-internal-format
 msgid "%<alignas%> argument has non-integral type %qT"
-msgstr "размер массива имеет нецелочисленный тип %qT"
+msgstr "%<alignas%> аргумент имеет нецелочисленный тип %qT"
 
 #: cp/typeck.c:1898
-#, fuzzy, gcc-internal-format
-#| msgid "invalid use of non-static member function %qD"
+#, gcc-internal-format
 msgid "invalid use of non-static member function of type %qT"
-msgstr "некорректное использование нестатической функции-элемента %qD"
+msgstr "некорректное использование нестатической функции-элемента типа %qT"
 
 #: cp/typeck.c:2072
 #, gcc-internal-format
@@ -54613,10 +48659,9 @@
 msgstr "взятие адреса от временного массива"
 
 #: cp/typeck.c:2238
-#, fuzzy, gcc-internal-format
-#| msgid "deprecated conversion from string constant to %qT"
+#, gcc-internal-format
 msgid "ISO C++ forbids converting a string constant to %qT"
-msgstr "устаревшее преобразование из строковой константы в %qT"
+msgstr "ISO C++ запрещает преобразование строковой константы в %qT"
 
 #: cp/typeck.c:2242
 #, gcc-internal-format
@@ -54639,10 +48684,9 @@
 msgstr "некорректное использование нестатического элемента данных %qE"
 
 #: cp/typeck.c:2470
-#, fuzzy, gcc-internal-format
-#| msgid "invalid access to non-static data member %qD  of NULL object"
+#, gcc-internal-format
 msgid "invalid access to non-static data member %qD in virtual base of NULL object"
-msgstr "некорректный доступ к нестатическому элементу данных %qD NULL объекта"
+msgstr "недопустимый доступ к нестатическому элементу данных в %qD в виртуальной базе NULL объекта"
 
 #: cp/typeck.c:2619
 #, gcc-internal-format
@@ -54657,7 +48701,7 @@
 #: cp/typeck.c:2745
 #, gcc-internal-format
 msgid "field %q#D can be accessed via %q#D"
-msgstr ""
+msgstr "поле %q#D доступно через %q#D"
 
 #: cp/typeck.c:2851 cp/typeck.c:2877
 #, gcc-internal-format
@@ -54670,16 +48714,14 @@
 msgstr "%qT не является базовым для %qT"
 
 #: cp/typeck.c:2952
-#, fuzzy, gcc-internal-format
-#| msgid "%qT has no member named %qE"
+#, gcc-internal-format
 msgid "%q#T has no member named %qE; did you mean %qE?"
-msgstr "%qT не содержит элемента с именем %qE"
+msgstr "%q#T не содержит элемента с именем %qE; имелось в виду %qE?"
 
 #: cp/typeck.c:2959
-#, fuzzy, gcc-internal-format
-#| msgid "%qT has no member named %qE"
+#, gcc-internal-format
 msgid "%q#T has no member named %qE"
-msgstr "%qT не содержит элемента с именем %qE"
+msgstr "%q#T не содержит элемента с именем %qE"
 
 #: cp/typeck.c:2988
 #, gcc-internal-format
@@ -54709,7 +48751,7 @@
 #: cp/typeck.c:3207
 #, gcc-internal-format
 msgid "left hand operand of %<->*%> must be a pointer to class, but is a pointer to member of type %qT"
-msgstr ""
+msgstr "левый операнд %<->*%> должен быть указателем на класс, но является указателем на элемент типа %qT"
 
 #: cp/typeck.c:3271
 #, gcc-internal-format
@@ -54732,10 +48774,9 @@
 msgstr "не задан объект при использовании %qE"
 
 #: cp/typeck.c:3704
-#, fuzzy, gcc-internal-format
-#| msgid "cannot disable built-in function %qs"
+#, gcc-internal-format
 msgid "cannot call function %qD"
-msgstr "невозможно отменить внутреннюю функцию %s"
+msgstr "невозможно вызвать функцию %qD"
 
 #: cp/typeck.c:3719
 #, gcc-internal-format
@@ -54753,16 +48794,14 @@
 msgstr "%qE нельзя использовать как функцию"
 
 #: cp/typeck.c:3760
-#, fuzzy, gcc-internal-format
-#| msgid "%qE cannot be used as a function"
+#, gcc-internal-format
 msgid "%qD cannot be used as a function"
-msgstr "%qE нельзя использовать как функцию"
+msgstr "%qD нельзя использовать как функцию"
 
 #: cp/typeck.c:3763
-#, fuzzy, gcc-internal-format
-#| msgid "%qE cannot be used as a function"
+#, gcc-internal-format
 msgid "expression cannot be used as a function"
-msgstr "%qE нельзя использовать как функцию"
+msgstr "выражение нельзя использовать как функцию"
 
 #: cp/typeck.c:3820
 #, gcc-internal-format
@@ -54830,10 +48869,9 @@
 msgstr "адрес %qD никогда не будет NULL"
 
 #: cp/typeck.c:4186
-#, fuzzy, gcc-internal-format
-#| msgid "the comparison will always evaluate as %<true%> for the address of %qD will never be NULL"
+#, gcc-internal-format
 msgid "the compiler can assume that the address of %qD will never be NULL"
-msgstr "результат сравнения всегда %<true%>, поскольку адрес %qD не может быть NULL"
+msgstr "компилятор может предположить, что адрес %qD не может быть NULL"
 
 #: cp/typeck.c:4304 cp/typeck.c:4315
 #, gcc-internal-format
@@ -54871,10 +48909,9 @@
 msgstr "ISO C++ не поддерживает сравнение между указателем и целым"
 
 #: cp/typeck.c:5019 cp/typeck.c:5032
-#, fuzzy, gcc-internal-format
-#| msgid "no type named %q#T in %q#T"
+#, gcc-internal-format
 msgid "operand types are %qT and %qT"
-msgstr "нет имени типа %q#T в %q#T"
+msgstr "типы операндов %qT и %qT"
 
 #: cp/typeck.c:5133
 #, gcc-internal-format
@@ -54882,10 +48919,8 @@
 msgstr "аргумент неупорядоченного сравнения - не плавающее значение"
 
 #: cp/typeck.c:5178
-#, fuzzy
-#| msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
 msgid "implicit conversion from %qH to %qI to match other operand of binary expression"
-msgstr "неявная конверсия из %qT в %qT для совместимости с другим операндом бинарного выражения"
+msgstr ""
 
 #: cp/typeck.c:5188
 #, gcc-internal-format
@@ -54913,16 +48948,14 @@
 msgstr "некорректное использование указателя на неполный тип в вычислениях с указателями"
 
 #: cp/typeck.c:5628
-#, fuzzy, gcc-internal-format
-#| msgid "taking address of constructor %qE"
+#, gcc-internal-format
 msgid "taking address of constructor %qD"
-msgstr "взятие адреса от конструктора %qE"
+msgstr ""
 
 #: cp/typeck.c:5629
-#, fuzzy, gcc-internal-format
-#| msgid "taking address of destructor %qE"
+#, gcc-internal-format
 msgid "taking address of destructor %qD"
-msgstr "взятие адреса от деструктора %qE"
+msgstr ""
 
 #: cp/typeck.c:5645
 #, gcc-internal-format
@@ -54943,12 +48976,12 @@
 #: cp/typeck.c:5831
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of an unqualified or parenthesized non-static member function to form a pointer to member function.  Say %<&%T::%D%>"
-msgstr "ISO C++ не поддерживает взятие адреса от неквалифицированного элемента-функции или элемента в скобках для формирования указателя на элемент-функцию.Используйте синтаксис %<&%T::%D%>"
+msgstr ""
 
 #: cp/typeck.c:5836
 #, gcc-internal-format
 msgid "ISO C++ forbids taking the address of a bound member function to form a pointer to member function.  Say %<&%T::%D%>"
-msgstr "ISO C++  не поддерживает взятие адреса от bound-элемента-функции для формирования указателя на элемент-функцию. Используйте синтаксис %<&%T::%D%>"
+msgstr ""
 
 #. Make this a permerror because we used to accept it.
 #: cp/typeck.c:5873
@@ -54972,21 +49005,19 @@
 msgstr "нельзя создать указатель на элемент-ссылку %qD"
 
 #: cp/typeck.c:5969
-#, fuzzy, gcc-internal-format
-#| msgid "cannot take address of bit-field %qD"
+#, gcc-internal-format
 msgid "attempt to take address of bit-field"
-msgstr "некорректная попытка взять адрес битового поля %qD"
+msgstr "попытка взять адрес битового поля"
 
 #: cp/typeck.c:6118
-#, fuzzy, gcc-internal-format
-#| msgid "taking address of expression of type %<void%>"
+#, gcc-internal-format
 msgid "%<~%> on an expression of type bool"
-msgstr "взятие адреса от выражения типа %<void%>"
+msgstr "%<~%> от выражения типа bool"
 
 #: cp/typeck.c:6119
 #, gcc-internal-format
 msgid "did you mean to use logical not (%<!%>)?"
-msgstr ""
+msgstr "имелось в виду использовать логическое отрицание (%<!%>)?"
 
 #: cp/typeck.c:6240
 #, gcc-internal-format
@@ -55021,7 +49052,7 @@
 #: cp/typeck.c:6305
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator--%> is forbidden"
-msgstr ""
+msgstr "использование операнда типа %qT в %<operator--%> запрещено"
 
 #: cp/typeck.c:6314
 #, gcc-internal-format
@@ -55031,7 +49062,7 @@
 #: cp/typeck.c:6321
 #, gcc-internal-format
 msgid "use of an operand of type %qT in %<operator++%> is deprecated"
-msgstr ""
+msgstr "использование операнда типа %qT в %<operator++%> устарело"
 
 #: cp/typeck.c:6502
 #, gcc-internal-format
@@ -55095,16 +49126,14 @@
 
 #
 #: cp/typeck.c:6813
-#, fuzzy, gcc-internal-format
-#| msgid "%qT uses local type %qT"
+#, gcc-internal-format
 msgid "useless cast to type %q#T"
-msgstr "%qT использует локальный тип %qT"
+msgstr ""
 
 #: cp/typeck.c:6826
-#, fuzzy, gcc-internal-format
-#| msgid "type qualifiers ignored on function return type"
+#, gcc-internal-format
 msgid "type qualifiers ignored on cast result type"
-msgstr "квалификаторы в описании типа возвращаемого значения функции "
+msgstr ""
 
 #: cp/typeck.c:7249
 #, gcc-internal-format
@@ -55112,10 +49141,8 @@
 msgstr "некорректное применение static_cast от типа %qT к типу %qT"
 
 #: cp/typeck.c:7275
-#, fuzzy
-#| msgid "converting from %qT to %qT"
 msgid "converting from %qH to %qI"
-msgstr "преобразование из %qT в %qT"
+msgstr ""
 
 #: cp/typeck.c:7343
 #, gcc-internal-format
@@ -55123,10 +49150,8 @@
 msgstr "некорректное приведение rvalue выражения из типа %qT к типу %qT"
 
 #: cp/typeck.c:7413
-#, fuzzy
-#| msgid "cast from %qT to %qT loses precision"
 msgid "cast from %qH to %qI loses precision"
-msgstr "приведение из типа %qT к типу %qT теряет точность"
+msgstr ""
 
 #: cp/typeck.c:7438
 msgid "cast between incompatible function types from %qH to %qI"
@@ -55133,22 +49158,17 @@
 msgstr ""
 
 #: cp/typeck.c:7449
-#, fuzzy
-#| msgid "comparison between distinct pointer-to-member types %qT and %qT lacks a cast"
 msgid "cast between incompatible pointer to member types from %qH to %qI"
-msgstr "сравнение между различными pointer-to-member типами %qT и %qT без приведения типов"
+msgstr ""
 
 #: cp/typeck.c:7470 cp/typeck.c:7652
-#, fuzzy
-#| msgid "cast from %qT to %qT increases required alignment of target type"
 msgid "cast from %qH to %qI increases required alignment of target type"
-msgstr "приведение от %qT к %qT увеличивает размер выравнивания для указуемого типа"
+msgstr ""
 
 #: cp/typeck.c:7486
-#, fuzzy, gcc-internal-format
-#| msgid "ISO C++ forbids casting between pointer-to-function and pointer-to-object"
+#, gcc-internal-format
 msgid "casting between pointer-to-function and pointer-to-object is conditionally-supported"
-msgstr "ISO C++ не поддерживает приведение типа указателя на функцию к указателю на объект"
+msgstr "приведение указателя на функцию к указателю на объект условно поддерживается"
 
 #: cp/typeck.c:7500
 #, gcc-internal-format
@@ -55231,46 +49251,33 @@
 msgstr "некорректное преобразование к типу %qT от типа %qT"
 
 #: cp/typeck.c:8812 cp/typeck.c:8829
-#, fuzzy
-#| msgid "cannot convert %qT to %qT"
 msgid "cannot convert %qH to %qI"
-msgstr "ошибка преобразования %qT в %qT"
+msgstr ""
 
 #: cp/typeck.c:8821
-#, fuzzy
-#| msgid "cannot convert %qT to %qT in default argument"
 msgid "cannot convert %qH to %qI in default argument"
-msgstr "ошибка преобразования %qT в %qT в подразумеваемом аргументе"
+msgstr ""
 
 #: cp/typeck.c:8825
-#, fuzzy
-#| msgid "cannot convert %qT to %qT in argument passing"
 msgid "cannot convert %qH to %qI in argument passing"
-msgstr "ошибка преобразования %qT в %qT при передаче аргументов"
+msgstr ""
 
 #: cp/typeck.c:8833
-#, fuzzy
-#| msgid "cannot convert %qT to %qT in initialization"
 msgid "cannot convert %qH to %qI in initialization"
-msgstr "ошибка преобразования %qT в %qT в инициализации"
+msgstr ""
 
 #: cp/typeck.c:8837
-#, fuzzy
-#| msgid "cannot convert %qT to %qT in return"
 msgid "cannot convert %qH to %qI in return"
-msgstr "ошибка преобразования %qT в %qT при возврате"
+msgstr ""
 
 #: cp/typeck.c:8841
-#, fuzzy
-#| msgid "cannot convert %qT to %qT in assignment"
 msgid "cannot convert %qH to %qI in assignment"
-msgstr "ошибка преобразования %qT в %qT в присваивании"
+msgstr ""
 
 #: cp/typeck.c:8854
-#, fuzzy, gcc-internal-format
-#| msgid "return type %q#T is incomplete"
+#, gcc-internal-format
 msgid "class type %qT is incomplete"
-msgstr "тип результата %q#T неполный"
+msgstr "тип класса %qT неполный"
 
 #: cp/typeck.c:8872
 #, gcc-internal-format
@@ -55298,10 +49305,9 @@
 msgstr "левая часть присваивания могла быть кандидатом для атрибута формата"
 
 #: cp/typeck.c:8991
-#, fuzzy, gcc-internal-format
-#| msgid "in passing argument %P of %q+D"
+#, gcc-internal-format
 msgid "in passing argument %P of %qD"
-msgstr "при передаче аргумента %P функции %q+D"
+msgstr "при передаче аргумента %P от %qD"
 
 #: cp/typeck.c:9050
 #, gcc-internal-format
@@ -55314,22 +49320,19 @@
 msgstr "возвращена ссылка на не-lvalue-выражение"
 
 #: cp/typeck.c:9072
-#, fuzzy, gcc-internal-format
-#| msgid "reference to local variable %q+D returned"
+#, gcc-internal-format
 msgid "reference to local variable %qD returned"
-msgstr "возвращена ссылка на локальную переменную %q+D"
+msgstr "возвращена ссылка на локальную переменную %qD"
 
 #: cp/typeck.c:9076
-#, fuzzy, gcc-internal-format
-#| msgid "address of local variable %q+D returned"
+#, gcc-internal-format
 msgid "address of label %qD returned"
-msgstr "возвращен адрес локальной переменной %q+D"
+msgstr "возвращен адрес метки %qD"
 
 #: cp/typeck.c:9080
-#, fuzzy, gcc-internal-format
-#| msgid "address of local variable %q+D returned"
+#, gcc-internal-format
 msgid "address of local variable %qD returned"
-msgstr "возвращен адрес локальной переменной %q+D"
+msgstr "возвращен адрес локальной переменной %qD"
 
 #: cp/typeck.c:9119
 #, gcc-internal-format
@@ -55356,10 +49359,9 @@
 msgstr "return без значения в функции, возвращающей %qT"
 
 #: cp/typeck.c:9172
-#, fuzzy, gcc-internal-format
-#| msgid "<brace-enclosed initializer list>"
+#, gcc-internal-format
 msgid "returning initializer list"
-msgstr "<инициализатор в фигурных скобках>"
+msgstr "возврат списка инициализатора"
 
 #: cp/typeck.c:9191
 #, gcc-internal-format
@@ -55367,16 +49369,14 @@
 msgstr "противоречивые типы %qT и %qT выведены для возвращаемого типа lambda"
 
 #: cp/typeck.c:9194
-#, fuzzy, gcc-internal-format
-#| msgid "inconsistent deduction for %qT: %qT and then %qT"
+#, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
-msgstr "противоречивый вывод для %qT: %qT и затем %qT"
+msgstr "противоречивый вывод для auto return type: %qT и затем %qT"
 
 #: cp/typeck.c:9230
-#, fuzzy, gcc-internal-format
-#| msgid "return-statement with no value, in function returning %qT"
+#, gcc-internal-format
 msgid "return-statement with a value, in function returning %qT"
-msgstr "return без значения в функции, возвращающей %qT"
+msgstr ""
 
 #: cp/typeck.c:9259
 #, gcc-internal-format
@@ -55450,10 +49450,9 @@
 msgstr "невозможно декларировать параметр %q+D с абстрактным типом %qT"
 
 #: cp/typeck2.c:329
-#, fuzzy, gcc-internal-format
-#| msgid "cannot declare parameter %q+D to be of abstract type %qT"
+#, gcc-internal-format
 msgid "cannot declare parameter to be of abstract type %qT"
-msgstr "невозможно декларировать параметр %q+D с абстрактным типом %qT"
+msgstr "невозможно декларировать параметр с абстрактным типом %qT"
 
 #: cp/typeck2.c:333
 #, gcc-internal-format
@@ -55487,40 +49486,34 @@
 msgstr "создание массива элементов типа %qT, являющегося абстрактным классом"
 
 #: cp/typeck2.c:352
-#, fuzzy, gcc-internal-format
-#| msgid "invalid cast to function type %qT"
+#, gcc-internal-format
 msgid "invalid cast to abstract class type %qT"
-msgstr "некорректное приведение к типу функции %qT"
+msgstr "некорректное приведение к типу абстрактного класса %qT"
 
 #: cp/typeck2.c:355
-#, fuzzy, gcc-internal-format
-#| msgid "invalid cast of an rvalue expression of type %qT to type %qT"
+#, gcc-internal-format
 msgid "invalid new-expression of abstract class type %qT"
-msgstr "некорректное приведение rvalue выражения из типа %qT к типу %qT"
+msgstr "некорректное new-выражения типа абстрактного класса %qT"
 
 #: cp/typeck2.c:358
-#, fuzzy, gcc-internal-format
-#| msgid "invalid parameter type %qT"
+#, gcc-internal-format
 msgid "invalid abstract return type %qT"
-msgstr "некорректный тип параметра %qT"
+msgstr "некорректный абстрактный возвращаемый тип %qT"
 
 #: cp/typeck2.c:361
-#, fuzzy, gcc-internal-format
-#| msgid "invalid parameter type %qT"
+#, gcc-internal-format
 msgid "invalid abstract parameter type %qT"
-msgstr "некорректный тип параметра %qT"
+msgstr "некорректный абстрактный тип параметра %qT"
 
 #: cp/typeck2.c:364
-#, fuzzy, gcc-internal-format
-#| msgid "expression %qE of abstract class type %qT cannot be used in throw-expression"
+#, gcc-internal-format
 msgid "expression of abstract class type %qT cannot be used in throw-expression"
-msgstr "выражение %qE, имеющее тип абстрактного класса %qT, нельзя использовать в throw-выражении"
+msgstr "выражение типа абстрактного класса %qT нельзя использовать в throw-выражении"
 
 #: cp/typeck2.c:368
-#, fuzzy, gcc-internal-format
-#| msgid "cannot declare parameter %q+D to be of abstract type %qT"
+#, gcc-internal-format
 msgid "cannot declare catch parameter to be of abstract class type %qT"
-msgstr "невозможно декларировать параметр %q+D с абстрактным типом %qT"
+msgstr "невозможно декларировать catch параметр с типом абстрактного класса %qT"
 
 #: cp/typeck2.c:372
 #, gcc-internal-format
@@ -55538,28 +49531,24 @@
 msgstr ""
 
 #: cp/typeck2.c:441
-#, fuzzy, gcc-internal-format
-#| msgid "definition of %qD is not in namespace enclosing %qT"
+#, gcc-internal-format
 msgid "definition of %q#T is not complete until the closing brace"
-msgstr "определение %qD вне пространства имён, объемлющего %qT"
+msgstr "определение %q#T не полно вплоть до закрывающей фигурной скобки"
 
 #: cp/typeck2.c:444
-#, fuzzy, gcc-internal-format
-#| msgid "forward declaration of %q+#T"
+#, gcc-internal-format
 msgid "forward declaration of %q#T"
-msgstr "forward декларация %q+#T"
+msgstr "forward декларация %q#T"
 
 #: cp/typeck2.c:446
-#, fuzzy, gcc-internal-format
-#| msgid "declaration of %q+#T"
+#, gcc-internal-format
 msgid "declaration of %q#T"
-msgstr "декларация %q+#T"
+msgstr "декларация %q#T"
 
 #: cp/typeck2.c:473
-#, fuzzy, gcc-internal-format
-#| msgid "%q#D has incomplete type"
+#, gcc-internal-format
 msgid "%qD has incomplete type"
-msgstr "%q#D имеет неполный тип"
+msgstr "%qD имеет неполный тип"
 
 #: cp/typeck2.c:486
 #, gcc-internal-format
@@ -55567,22 +49556,19 @@
 msgstr "некорректное использование неполного типа %q#T"
 
 #: cp/typeck2.c:517
-#, fuzzy, gcc-internal-format
-#| msgid "invalid use of member function (did you forget the %<()%> ?)"
+#, gcc-internal-format
 msgid "invalid use of member function %qD (did you forget the %<()%> ?)"
-msgstr "некорректное использование функции-элемента (вы забыли %<()%> ?)"
+msgstr "некорректное использование функции-элемента %qD (вы забыли %<()%> ?)"
 
 #: cp/typeck2.c:521
-#, fuzzy, gcc-internal-format
-#| msgid "invalid use of member (did you forget the %<&%> ?)"
+#, gcc-internal-format
 msgid "invalid use of member %qD (did you forget the %<&%> ?)"
-msgstr "некорректное использование элемента (вы забыли %<()%> ?)"
+msgstr "некорректное использование элемента %qD (вы забыли %<()%> ?)"
 
 #: cp/typeck2.c:531
-#, fuzzy, gcc-internal-format
-#| msgid "invalid use of %qT"
+#, gcc-internal-format
 msgid "invalid use of placeholder %qT"
-msgstr "некорректное использование %qT"
+msgstr "некорректное использование заполнителя %qT"
 
 #: cp/typeck2.c:538
 #, gcc-internal-format
@@ -55625,22 +49611,17 @@
 msgstr "использован синтаксис конструктора для типа %qT, который не имеет конструкторов"
 
 #: cp/typeck2.c:966
-#, fuzzy
-#| msgid "narrowing conversion of %qE from %qT to %qT inside { } is ill-formed in C++11"
 msgid "narrowing conversion of %qE from %qH to %qI inside { } is ill-formed in C++11"
-msgstr "сужающее преобразование %qE из %qT в %qT внутри { } считается неверно оформленным в C++11"
+msgstr ""
 
 #: cp/typeck2.c:977 cp/typeck2.c:991
-#, fuzzy
-#| msgid "narrowing conversion of %qE from %qT to %qT inside { }"
 msgid "narrowing conversion of %qE from %qH to %qI inside { }"
-msgstr "сужающее преобразование %qE из %qT в %qT внутри { }"
+msgstr ""
 
 #: cp/typeck2.c:981
-#, fuzzy, gcc-internal-format
-#| msgid "expression in static assertion is not an integer constant expression"
+#, gcc-internal-format
 msgid " the expression has a constant value but is not a C++ constant-expression"
-msgstr "выражение в статическом утверждении не является целочисленным константным выражением"
+msgstr ""
 
 #: cp/typeck2.c:1069
 #, gcc-internal-format
@@ -55662,113 +49643,107 @@
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "невозможно инициализировать агрегат типа %qT составным литералом"
 
-#: cp/typeck2.c:1496 cp/typeck2.c:1523
+#: cp/typeck2.c:1499 cp/typeck2.c:1526
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "отсутствует инициализатор для элемента %qD"
 
-#: cp/typeck2.c:1504
+#: cp/typeck2.c:1507
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "элемент %qD - неинициализированная ссылка"
 
-#: cp/typeck2.c:1511
-#, fuzzy, gcc-internal-format
-#| msgid "member %qD is uninitialized reference"
+#: cp/typeck2.c:1514
+#, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
-msgstr "элемент %qD - неинициализированная ссылка"
+msgstr "элемент %qD с неинициализированными ссылочными полями"
 
-#: cp/typeck2.c:1587
-#, fuzzy, gcc-internal-format
-#| msgid "type of %qD does not match original declaration"
+#: cp/typeck2.c:1590
+#, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
-msgstr "тип %qD не соответствует исходной декларации"
+msgstr ""
 
-#: cp/typeck2.c:1660
+#: cp/typeck2.c:1663
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "поле %qD не найдено в инициализируемом объединении"
 
-#: cp/typeck2.c:1671
+#: cp/typeck2.c:1674
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "значение индекса вместо имени поля в инициализаторе объединения"
 
-#: cp/typeck2.c:1858
+#: cp/typeck2.c:1861
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "обнаружено циклическое делегирование указателей"
 
-#: cp/typeck2.c:1872
+#: cp/typeck2.c:1875
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "базовый операнд %<->%> имеет неуказательный тип %qT"
 
-#: cp/typeck2.c:1898
+#: cp/typeck2.c:1901
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "результат %<operator->()%> не является указателем"
 
-#: cp/typeck2.c:1900
+#: cp/typeck2.c:1903
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "базовый операнд %<->%> не является указателем"
 
-#: cp/typeck2.c:1927
+#: cp/typeck2.c:1930
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE не может использоваться как элемент, поскольку имеет тип %qT"
 
-#: cp/typeck2.c:1936
+#: cp/typeck2.c:1939
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "невозможно применить элементный указатель %qE к %qE, который имеет неклассовый тип %qT"
 
-#: cp/typeck2.c:1958
+#: cp/typeck2.c:1961
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "указатель на элементный тип %qT несовместим с объектным типом %qT"
 
-#: cp/typeck2.c:2018
-#, fuzzy, gcc-internal-format
-#| msgid "pointer to member function used in arithmetic"
+#: cp/typeck2.c:2021
+#, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
-msgstr "в арифметическом выражении использован указатель на элемент-функцию"
+msgstr "тип указатель на элемент-функцию %qT требует rvalue"
 
-#: cp/typeck2.c:2029
-#, fuzzy, gcc-internal-format
-#| msgid "pointer to member function used in arithmetic"
+#: cp/typeck2.c:2032
+#, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
-msgstr "в арифметическом выражении использован указатель на элемент-функцию"
+msgstr "тип указатель на элемент-функцию %qT требует lvalue"
 
-#: cp/typeck2.c:2037
-#, fuzzy, gcc-internal-format
-#| msgid "pointer to member function used in arithmetic"
+#: cp/typeck2.c:2040
+#, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++2a"
-msgstr "в арифметическом выражении использован указатель на элемент-функцию"
+msgstr ""
 
-#: cp/typeck2.c:2080
+#: cp/typeck2.c:2083
 #, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "функциональное приведение к массивному типу %qT"
 
-#: cp/typeck2.c:2096
-#, fuzzy, gcc-internal-format
-#| msgid "in template argument for type %qT "
+#: cp/typeck2.c:2099
+#, gcc-internal-format
 msgid "cannot deduce template arguments for %qT from ()"
-msgstr "в аргументе шаблона для типа %qT "
+msgstr "невозможно вывести аргументы шаблона для %qT из ()"
 
-#: cp/typeck2.c:2114
+#: cp/typeck2.c:2117
 #, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "некорректная инициализация значения ссылочного типа"
 
-#: cp/typeck2.c:2341
+#: cp/typeck2.c:2344
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "вызов функции %qD, которая вызывает исключение неполного типа %q#T"
 
-#: cp/typeck2.c:2344
+#: cp/typeck2.c:2347
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "вызов функции, которая вызывает исключение неполного типа %q#T"
@@ -55776,17 +49751,17 @@
 #: cp/vtable-class-hierarchy.c:719
 #, gcc-internal-format
 msgid "unable to open log file %<vtv_class_set_sizes.log%>: %m"
-msgstr ""
+msgstr "не удается открыть файл протокола %<vtv_class_set_sizes.log%>: %m"
 
 #: cp/vtable-class-hierarchy.c:859
 #, gcc-internal-format
 msgid "unable to open log file %<vtv_set_ptr_data.log%>: %m"
-msgstr ""
+msgstr "не удается открыть файл протокола %<vtv_set_ptr_data.log%>: %m"
 
 #: cp/vtable-class-hierarchy.c:1109
 #, gcc-internal-format
 msgid "unable to open log file %<vtv_count_data.log%>: %m"
-msgstr ""
+msgstr "не удается открыть файл протокола %<vtv_count_data.log%>: %m"
 
 #: fortran/arith.c:45
 #, gcc-internal-format, gfc-internal-format
@@ -55794,67 +49769,64 @@
 msgstr "Преобразование бесконечности или нечисла в %L к INTEGER"
 
 #: fortran/arith.c:117 fortran/arith.c:1973
-#, fuzzy, gcc-internal-format
-#| msgid "gfc_trans_code(): Bad statement code"
+#, gcc-internal-format
 msgid "gfc_arith_error(): Bad error code"
-msgstr "gfc_trans_code(): Некорректный код оператора"
+msgstr "gfc_arith_error(): Некорректный код ошибки"
 
 #: fortran/arith.c:150
 #, gcc-internal-format
 msgid "Fix min_int calculation"
-msgstr ""
+msgstr "Исправьте min_int вычисление"
 
 #: fortran/arith.c:530
-#, fuzzy, gcc-internal-format
-#| msgid "gfc_trans_code(): Bad statement code"
+#, gcc-internal-format
 msgid "gfc_range_check(): Bad type"
-msgstr "gfc_trans_code(): Некорректный код оператора"
+msgstr "gfc_range_check(): Некорректный тип"
 
 #: fortran/arith.c:603
 #, gcc-internal-format
 msgid "gfc_arith_uminus(): Bad basic type"
-msgstr ""
+msgstr "gfc_arith_uminus(): Некорректный базовый тип"
 
 #: fortran/arith.c:637
 #, gcc-internal-format
 msgid "gfc_arith_plus(): Bad basic type"
-msgstr ""
+msgstr "gfc_arith_plus(): Некорректный базовый тип"
 
 #: fortran/arith.c:671
 #, gcc-internal-format
 msgid "gfc_arith_minus(): Bad basic type"
-msgstr ""
+msgstr "gfc_arith_minus(): Некорректный базовый тип"
 
 #: fortran/arith.c:706
 #, gcc-internal-format
 msgid "gfc_arith_times(): Bad basic type"
-msgstr ""
+msgstr "gfc_arith_times(): Некорректный базовый тип"
 
 #: fortran/arith.c:745
 #, gcc-internal-format
 msgid "Integer division truncated to constant %qs at %L"
-msgstr ""
+msgstr "Целочисленное деление усечено до константы %qs в %L"
 
 #: fortran/arith.c:791
 #, gcc-internal-format
 msgid "gfc_arith_divide(): Bad basic type"
-msgstr ""
+msgstr "gfc_arith_divide(): Некорректный базовый тип"
 
 #: fortran/arith.c:837
 #, gcc-internal-format
 msgid "arith_power(): Bad base"
-msgstr ""
+msgstr "arith_power(): Некорректная база"
 
 #: fortran/arith.c:878
 #, gcc-internal-format, gfc-internal-format
 msgid "Negative exponent of integer has zero result at %L"
-msgstr ""
+msgstr "Отрицательная степень целого имеет нулевой результат в %L"
 
 #: fortran/arith.c:928 fortran/arith.c:953
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2003: Noninteger exponent in an initialization expression at %L"
+#, gcc-internal-format, gfc-internal-format
 msgid "Noninteger exponent in an initialization expression at %L"
-msgstr "Fortran 2003: Нецелый показатель степени в инициализационном выражении в %L"
+msgstr "Нецелый показатель степени в инициализационном выражении в %L"
 
 #: fortran/arith.c:939
 #, gcc-internal-format, gfc-internal-format
@@ -55862,31 +49834,29 @@
 msgstr "Возведение отрицательного REAL в %L в REAL степень запрещено"
 
 #: fortran/arith.c:967
-#, fuzzy, gcc-internal-format
-#| msgid "ia64_print_operand: unknown code"
+#, gcc-internal-format
 msgid "arith_power(): unknown type"
-msgstr "ia64_print_operand: некорректный код"
+msgstr "arith_power(): неизвестный тип"
 
 #: fortran/arith.c:1033
-#, fuzzy, gcc-internal-format
-#| msgid "Bad operator"
+#, gcc-internal-format
 msgid "compare_real(): Bad operator"
-msgstr "Некорректный оператор"
+msgstr "compare_real(): Некорректный оператор"
 
 #: fortran/arith.c:1068
 #, gcc-internal-format
 msgid "gfc_compare_expr(): Bad basic type"
-msgstr ""
+msgstr "gfc_compare_expr(): Некорректный базовый тип"
 
 #: fortran/arith.c:1579
 #, gcc-internal-format
 msgid "eval_intrinsic(): Bad operator"
-msgstr ""
+msgstr "eval_intrinsic(): Некорректный оператор"
 
 #: fortran/arith.c:1632
 #, gcc-internal-format
 msgid "eval_type_intrinsic0(): op NULL"
-msgstr ""
+msgstr "eval_type_intrinsic0(): op NULL"
 
 #: fortran/arith.c:1941
 #, gcc-internal-format, gfc-internal-format
@@ -55894,22 +49864,19 @@
 msgstr "Арифметическое OK при преобразовании %s в %s в %L"
 
 #: fortran/arith.c:1945
-#, fuzzy, gcc-internal-format
-#| msgid "Arithmetic overflow converting %s to %s at %L. This check can be disabled with the option -fno-range-check"
+#, gcc-internal-format
 msgid "Arithmetic overflow converting %s to %s at %L. This check can be disabled with the option %<-fno-range-check%>"
-msgstr "Арифметическое переполнение при преобразовании %s в %s в %L. Эта проверка может быть выключена опцией -fno-range-check"
+msgstr ""
 
 #: fortran/arith.c:1950
-#, fuzzy, gcc-internal-format
-#| msgid "Arithmetic underflow converting %s to %s at %L. This check can be disabled with the option -fno-range-check"
+#, gcc-internal-format
 msgid "Arithmetic underflow converting %s to %s at %L. This check can be disabled with the option %<-fno-range-check%>"
-msgstr "Арифметическая потеря значимости при преобразовании %s в %s в %L. Эта проверка может быть выключена опцией -fno-range-check"
+msgstr ""
 
 #: fortran/arith.c:1955
-#, fuzzy, gcc-internal-format
-#| msgid "Arithmetic NaN converting %s to %s at %L. This check can be disabled with the option -fno-range-check"
+#, gcc-internal-format
 msgid "Arithmetic NaN converting %s to %s at %L. This check can be disabled with the option %<-fno-range-check%>"
-msgstr "Арифметическое NaN при преобразовании %s в %s в %L. Эта проверка может быть выключена опцией -fno-range-check"
+msgstr ""
 
 #: fortran/arith.c:1960
 #, gcc-internal-format, gfc-internal-format
@@ -55929,36 +49896,31 @@
 #: fortran/arith.c:2055 fortran/arith.c:2164 fortran/arith.c:2224
 #: fortran/arith.c:2276 fortran/arith.c:2336 fortran/arith.c:2405
 #: fortran/arith.c:2472
-#, fuzzy, gcc-internal-format
-#| msgid "Conversion from %s to %s at %L"
+#, gcc-internal-format
 msgid "Conversion from %qs to %qs at %L"
-msgstr "Преобразование из %s в %s в %L"
+msgstr "Преобразование из %qs в %qs в %L"
 
 #: fortran/arith.c:2084 fortran/arith.c:2117 fortran/arith.c:2156
 #: fortran/arith.c:2214 fortran/arith.c:2266 fortran/arith.c:2326
 #: fortran/arith.c:2395
-#, fuzzy, gcc-internal-format
-#| msgid "Change of value in conversion from  %s to %s at %L"
+#, gcc-internal-format
 msgid "Change of value in conversion from %qs to %qs at %L"
-msgstr "Изменение значения в преобразовании из %s в %s в %L"
+msgstr "Изменение значения в преобразовании из %qs в %qs в %L"
 
 #: fortran/arith.c:2312 fortran/arith.c:2381
-#, fuzzy, gcc-internal-format
-#| msgid "Possible change of value in conversion from %s to %s at %L"
+#, gcc-internal-format
 msgid "Non-zero imaginary part discarded in conversion from %qs to %qs at %L"
-msgstr "Возможное изменение значения в преобразовании из %s в %s в %L"
+msgstr "Ненулевая мнимая часть отброшена в преобразовании из %qs в %qs в %L"
 
 #: fortran/arith.c:2464
-#, fuzzy, gcc-internal-format
-#| msgid "Change of value in conversion from  %s to %s at %L"
+#, gcc-internal-format
 msgid "Change of value in conversion from  %qs to %qs at %L"
-msgstr "Изменение значения в преобразовании из %s в %s в %L"
+msgstr "Изменение значения в преобразовании из %qs в %qs в %L"
 
 #: fortran/arith.c:2549
-#, fuzzy, gcc-internal-format
-#| msgid "The Hollerith constant at %L is too long to convert to %s"
+#, gcc-internal-format
 msgid "The Hollerith constant at %L is too long to convert to %qs"
-msgstr "Hollerith константа в %L слишком длинна для преобразования в %s"
+msgstr "Холлеритова константа в %L слишком длинна для преобразования в %qs"
 
 #: fortran/array.c:95
 #, gcc-internal-format, gfc-internal-format
@@ -55966,10 +49928,9 @@
 msgstr "Ожидался индекс массива в %C"
 
 #: fortran/array.c:104
-#, fuzzy, gcc-internal-format
-#| msgid "Unexpected '*' in coarray subscript at %C"
+#, gcc-internal-format
 msgid "Unexpected %<*%> in coarray subscript at %C"
-msgstr "Неожиданная '*' в индексе комассива в %C"
+msgstr "Неожиданная %<*%> в индексе комассива в %C"
 
 #: fortran/array.c:128
 #, gcc-internal-format, gfc-internal-format
@@ -55987,10 +49948,9 @@
 msgstr "Некорректная форма ссылки на массив в %C"
 
 #: fortran/array.c:203
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Array reference at %C cannot have more than %d dimensions"
+#, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %C has more than 7 dimensions"
-msgstr "Ссылка на массив в %C не может иметь больше чем %d измерений"
+msgstr ""
 
 #: fortran/array.c:206 fortran/array.c:307
 #, gcc-internal-format, gfc-internal-format
@@ -55998,15 +49958,14 @@
 msgstr "Ссылка на массив в %C не может иметь больше чем %d измерений"
 
 #: fortran/array.c:221 fortran/array.c:661 fortran/check.c:2849
-#: fortran/check.c:5222 fortran/check.c:5260 fortran/check.c:5302
-#: fortran/check.c:5329 fortran/check.c:5529 fortran/match.c:1821
+#: fortran/check.c:5225 fortran/check.c:5263 fortran/check.c:5305
+#: fortran/check.c:5332 fortran/check.c:5532 fortran/match.c:1821
 #: fortran/match.c:3174 fortran/match.c:3516 fortran/match.c:3712
-#: fortran/simplify.c:2909 fortran/simplify.c:2939 fortran/simplify.c:5764
-#: fortran/simplify.c:7658
-#, fuzzy, gcc-internal-format
-#| msgid "Coarrays disabled at %C, use -fcoarray= to enable"
+#: fortran/simplify.c:2909 fortran/simplify.c:2939 fortran/simplify.c:5769
+#: fortran/simplify.c:7663
+#, gcc-internal-format
 msgid "Coarrays disabled at %C, use %<-fcoarray=%> to enable"
-msgstr "Комассивы выключены в %C, используйте -fcoarray= для включения"
+msgstr "Комассивы выключены в %C, используйте %<-fcoarray=%> для включения"
 
 #: fortran/array.c:227
 #, gcc-internal-format, gfc-internal-format
@@ -56014,15 +49973,14 @@
 msgstr "Неожиданное обозначение комассива в %C"
 
 #: fortran/array.c:249
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "%qE attribute duplicated"
+#, gcc-internal-format, gfc-internal-format
 msgid "TEAM= attribute in %C misplaced"
-msgstr "атрибут %qE продублирован"
+msgstr ""
 
 #: fortran/array.c:261
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= attribute in %C misplaced"
-msgstr ""
+msgstr "STAT= атрибут в %C не на месте"
 
 #: fortran/array.c:270
 #, gcc-internal-format, gfc-internal-format
@@ -56035,10 +49993,9 @@
 msgstr "Слишком много коизмерений в %C, ожидалось %d а не %d"
 
 #: fortran/array.c:286 fortran/array.c:294
-#, fuzzy, gcc-internal-format
-#| msgid "Unexpected '*' for codimension %d of %d at %C"
+#, gcc-internal-format
 msgid "Unexpected %<*%> for codimension %d of %d at %C"
-msgstr "Неожиданная '*' для коизмерения %d из %d в %C"
+msgstr "Неожиданная %<*%> для коизмерения %d из %d в %C"
 
 #: fortran/array.c:289
 #, gcc-internal-format, gfc-internal-format
@@ -56048,18 +50005,17 @@
 #: fortran/array.c:301
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid codimension %d at %C, only %d codimensions exist"
-msgstr "Некорректное коизмерение %d в %C, только %d коизмерений существует"
+msgstr "Некорректное коизмерение %d в %C, существует только %d коизмерений"
 
 #: fortran/array.c:353
-#, fuzzy, gcc-internal-format
-#| msgid "Variable '%s' at %L in this context must be constant"
+#, gcc-internal-format
 msgid "Variable %qs at %L in this context must be constant"
-msgstr "Переменная '%s' в %L в этом контексте должна быть константой"
+msgstr "Переменная '%qs' в %L в этом контексте должна быть константой"
 
 #: fortran/array.c:356
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression at %L in this context must be constant"
-msgstr "Выражение в %L в этом контексте должна быть константой"
+msgstr "Выражение в %L в этом контексте должно быть константой"
 
 #: fortran/array.c:454
 #, gcc-internal-format, gfc-internal-format
@@ -56067,15 +50023,14 @@
 msgstr "Ожидалось выражение в спецификации массива в %C"
 
 #: fortran/array.c:467 fortran/array.c:499
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Expected scalar initialization expression at %C"
+#, gcc-internal-format, gfc-internal-format
 msgid "Expecting a scalar INTEGER expression at %C, found %s"
-msgstr "Ожидалось скалярное инициализационное выражение в %C"
+msgstr "Ожидалось скалярное INTEGER выражение в %C, найдено %s"
 
 #: fortran/array.c:536
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %C"
-msgstr ""
+msgstr "массив подразумеваемой размерности в %C"
 
 #: fortran/array.c:570
 #, gcc-internal-format, gfc-internal-format
@@ -56113,167 +50068,157 @@
 msgstr "Спецификация массива в %C имеет больше чем %d измерений"
 
 #: fortran/array.c:644
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Array specification at %C has more than %d dimensions"
+#, gcc-internal-format, gfc-internal-format
 msgid "Array specification at %C with more than 7 dimensions"
-msgstr "Спецификация массива в %C имеет больше чем %d измерений"
+msgstr "Спецификация массива в %C с более чем 7 измерениями"
 
 #: fortran/array.c:656
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2008: Coarray declaration at %C"
+#, gcc-internal-format, gfc-internal-format
 msgid "Coarray declaration at %C"
-msgstr "Fortran 2008: Декларация комассива в %C"
+msgstr "Декларация комассива в %C"
 
 #: fortran/array.c:753
-#, fuzzy, gcc-internal-format
-#| msgid "Upper bound of last coarray dimension must be '*' at %C"
+#, gcc-internal-format
 msgid "Upper bound of last coarray dimension must be %<*%> at %C"
-msgstr "Верхняя граница последнего измерения комассива должна быть '*' в %C"
+msgstr "Верхняя граница последнего измерения комассива должна быть %<*%> в %C"
 
 #: fortran/array.c:821
-#, fuzzy, gcc-internal-format
-#| msgid "Data target at %L shall not have a coindex"
+#, gcc-internal-format
 msgid "The assumed-rank array %qs at %L shall not have a codimension"
-msgstr "Целевые данные в %L не должны иметь коиндекс"
+msgstr "Массив предполагаемой размерности %qs в %L не должен иметь коизмерения"
 
 #: fortran/array.c:905
 #, gcc-internal-format
 msgid "gfc_compare_array_spec(): Array spec clobbered"
-msgstr ""
+msgstr "gfc_compare_array_spec(): Спецификация массива испорчена"
 
 #: fortran/array.c:981
-#, fuzzy, gcc-internal-format
-#| msgid "DO-iterator '%s' at %L is inside iterator of the same name"
+#, gcc-internal-format
 msgid "DO-iterator %qs at %L is inside iterator of the same name"
-msgstr "DO-iterator '%s' в %L находится внутри итератора с тем же именем"
+msgstr "DO-итератор %qs в %L находится внутри итератора с тем же именем"
 
-#: fortran/array.c:1073 fortran/array.c:1255
+#: fortran/array.c:1073 fortran/array.c:1264
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in array constructor at %C"
 msgstr "Синтаксическая ошибка в конструкторе массива в %C"
 
-#: fortran/array.c:1129
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2003: [...] style array constructors at %C"
+#: fortran/array.c:1105
+#, gcc-internal-format, gfc-internal-format
+msgid "NULL() at %C cannot appear in an array constructor"
+msgstr ""
+
+#: fortran/array.c:1138
+#, gcc-internal-format, gfc-internal-format
 msgid "[...] style array constructors at %C"
-msgstr "Fortran 2003: [...] стиль конструкторов массива в %C"
+msgstr "[...] стиль конструкторов массива в %C"
 
-#: fortran/array.c:1149
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2003: Array constructor including type specification at %C"
+#: fortran/array.c:1158
+#, gcc-internal-format, gfc-internal-format
 msgid "Array constructor including type specification at %C"
-msgstr "Fortran 2003: Конструктор массива включающий спецификацию типа в %C"
+msgstr "Конструктор массива, включающий спецификацию типа в %C"
 
-#: fortran/array.c:1155 fortran/match.c:4148
+#: fortran/array.c:1164 fortran/match.c:4148
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-spec at %L cannot contain a deferred type parameter"
 msgstr "Type-spec в %L не может содержать параметр отложенного типа"
 
-#: fortran/array.c:1163
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Type-spec at %L cannot contain a deferred type parameter"
+#: fortran/array.c:1172
+#, gcc-internal-format, gfc-internal-format
 msgid "Type-spec at %L cannot contain an asterisk for a type parameter"
-msgstr "Type-spec в %L не может содержать параметр отложенного типа"
+msgstr "Type-spec в %L не может содержать звездочку для параметра типа"
 
-#: fortran/array.c:1181
+#: fortran/array.c:1190
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty array constructor at %C is not allowed"
 msgstr "Пустой конструктор массива в %C не допускается"
 
-#: fortran/array.c:1218 fortran/array.c:1228
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "incompatible type for argument %d of %qE"
+#: fortran/array.c:1227 fortran/array.c:1237
+#, gcc-internal-format, gfc-internal-format
 msgid "Incompatible typespec for array element at %L"
-msgstr "несовместимый тип аргумента %d функции %qE"
+msgstr "Несовместимая спецификация типа для элемента массива в %L"
 
-#: fortran/array.c:1302
+#: fortran/array.c:1311
 #, gcc-internal-format, gfc-internal-format
 msgid "Element in %s array constructor at %L is %s"
 msgstr "Элемент в %s конструкторе массива в %L есть %s"
 
-#: fortran/array.c:1633
+#: fortran/array.c:1642
 #, gcc-internal-format, gfc-internal-format
 msgid "Iterator step at %L cannot be zero"
 msgstr "Шаг итератора в %L не может быть нулевым"
 
-#: fortran/array.c:1770
-#, fuzzy, gcc-internal-format
-#| msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit.   See -fmax-array-constructor option"
+#: fortran/array.c:1779
+#, gcc-internal-format
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit.   See %<-fmax-array-constructor%> option"
-msgstr "Число элементов в конструкторе массива в %L требует увеличения допустимой %d верхней границы. См. опцию -fmax-array-constructor"
+msgstr ""
 
-#: fortran/array.c:1940
+#: fortran/array.c:1949
 #, gcc-internal-format, gfc-internal-format
 msgid "AC-IMPLIED-DO initial expression references control variable at %L"
-msgstr ""
+msgstr "AC-IMPLIED-DO начальное выражение ссылается на управляющую переменную в %L"
 
 #
-#: fortran/array.c:1947
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "expresion reference type error at %L"
+#: fortran/array.c:1956
+#, gcc-internal-format, gfc-internal-format
 msgid "AC-IMPLIED-DO final expression references control variable at %L"
-msgstr "ошибка типа ссылки на выражение в %L"
+msgstr "AC-IMPLIED-DO финальное выражение ссылается на управляющую переменную в %L"
 
 #
-#: fortran/array.c:1954
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "expresion reference type error at %L"
+#: fortran/array.c:1963
+#, gcc-internal-format, gfc-internal-format
 msgid "AC-IMPLIED-DO step expression references control variable at %L"
-msgstr "ошибка типа ссылки на выражение в %L"
+msgstr "AC-IMPLIED-DO выражение шага ссылается на управляющую переменную в %L"
 
-#: fortran/array.c:1966
+#: fortran/array.c:1975
 #, gcc-internal-format, gfc-internal-format
 msgid "Array constructor value at %L shall not be unlimited polymorphic [F2008: C4106]"
-msgstr ""
+msgstr "Значение конструктора массива в %L не должно быть неограниченно полиморфным [F2008: C4106]"
 
-#: fortran/array.c:2055
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Different CHARACTER lengths (%d/%d) in array constructor at %L"
+#: fortran/array.c:2067
+#, gcc-internal-format, gfc-internal-format
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor at %L"
-msgstr "Разные CHARACTER длины (%d/%d) в конструкторе массива в %L"
+msgstr ""
 
-#: fortran/array.c:2174
+#: fortran/array.c:2186
 #, gcc-internal-format
 msgid "spec_dimen_size(): Bad dimension"
-msgstr ""
+msgstr "spec_dimen_size(): Некорректная размерность"
 
-#: fortran/array.c:2233
+#: fortran/array.c:2245
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimension"
-msgstr ""
+msgstr "gfc_ref_dimen_size(): Некорректная размерность"
 
-#: fortran/array.c:2237
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Bad array reference at %L"
+#: fortran/array.c:2249
+#, gcc-internal-format, gfc-internal-format
 msgid "Bad array dimension at %L"
-msgstr "Некорректная ссылка на массив в %L"
+msgstr ""
 
-#: fortran/array.c:2264 fortran/data.c:552 fortran/data.c:571
-#: fortran/data.c:585 fortran/data.c:714
-#, fuzzy, gcc-internal-format
-#| msgid "gimplification failed"
+#: fortran/array.c:2276 fortran/data.c:563 fortran/data.c:582
+#: fortran/data.c:596 fortran/data.c:725
+#, gcc-internal-format
 msgid "Simplification error"
-msgstr "преобразование в gimple завершилось неуспешно"
+msgstr ""
 
-#: fortran/array.c:2376
+#: fortran/array.c:2388
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimen_type"
-msgstr ""
+msgstr "gfc_ref_dimen_size(): Некорректный тип размерности"
 
-#: fortran/array.c:2427
+#: fortran/array.c:2439
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad dimension"
-msgstr ""
+msgstr "gfc_array_dimen_size(): Некорректная размерность"
 
-#: fortran/array.c:2472
+#: fortran/array.c:2484
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad EXPR_ARRAY expr"
-msgstr ""
+msgstr "gfc_array_dimen_size(): Некорректное EXPR_ARRAY выражение"
 
-#: fortran/array.c:2620
+#: fortran/array.c:2632
 #, gcc-internal-format
 msgid "gfc_find_array_ref(): No ref found"
-msgstr ""
+msgstr "gfc_find_array_ref(): Ссылка не найдена"
 
 #. if (c == 0)
 #: fortran/bbt.c:119
@@ -56282,58 +50227,49 @@
 msgstr ""
 
 #: fortran/check.c:46
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L must be a scalar"
+#, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a scalar"
-msgstr "'%s' аргумент '%s' встроенной функции в %L должен быть скаляром"
+msgstr "%qs аргумент %qs встроенной функции в %L должен быть скаляром"
 
 #: fortran/check.c:62
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L must be %s"
+#, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be %s"
-msgstr "'%s' аргумент '%s' встроенной функции в %L должен быть %s"
+msgstr "%qs аргумент %qs встроенной функции в %L должен быть %s"
 
 #: fortran/check.c:96
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L must be a numeric type"
+#, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must have a numeric type"
-msgstr "'%s' аргумент '%s' встроенной функции в %L должен быть числовым типом"
+msgstr "%qs аргумент %qs встроенной функции в %L должен иметь числовой тип"
 
 #: fortran/check.c:111 fortran/check.c:141
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L must be INTEGER or REAL"
+#, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or REAL"
-msgstr "'%s' аргумент '%s' встроенной функции в %L должен быть INTEGER или REAL"
+msgstr "%qs аргумент %qs встроенной функции в %L должен быть INTEGER или REAL"
 
 #: fortran/check.c:129
-#, fuzzy, gcc-internal-format
-#| msgid "Expected coarray variable as '%s' argument to the %s intrinsic at %L"
+#, gcc-internal-format
 msgid "Fortran 2003: Character for %qs argument of %qs intrinsic at %L"
-msgstr "Ожидалась комассивная переменная как '%s' аргумент для %s встроенной функции в %L"
+msgstr ""
 
 #: fortran/check.c:136
-#, fuzzy, gcc-internal-format
-#| msgid "'a1' argument of '%s' intrinsic at %L must be INTEGER, REAL or CHARACTER"
+#, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or REAL or CHARACTER"
-msgstr "'a1' аргумент '%s' встроенной функции в %L должен быть INTEGER, REAL или CHARACTER"
+msgstr ""
 
 #: fortran/check.c:159
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L must be REAL or COMPLEX"
+#, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be REAL or COMPLEX"
-msgstr "'%s' аргумент '%s' встроенной функции в %L должен быть REAL или COMPLEX"
+msgstr "%qs аргумент %qs встроенной функции в %L должен быть REAL или COMPLEX"
 
 #: fortran/check.c:176
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L must be INTEGER or PROCEDURE"
+#, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or PROCEDURE"
-msgstr "'%s' аргумент '%s' встроенной функции в %L должен быть INTEGER или PROCEDURE"
+msgstr "%qs аргумент %qs встроенной функции в %L должен быть INTEGER или PROCEDURE"
 
-#: fortran/check.c:205 fortran/check.c:6658
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L must be a constant"
+#: fortran/check.c:205 fortran/check.c:6661
+#, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a constant"
-msgstr "'%s' аргумент '%s' встроенной функции в %L должен быть константой"
+msgstr "%qs аргумент %qs встроенной функции в %L должен быть константой"
 
 #: fortran/check.c:214
 #, gcc-internal-format, gfc-internal-format
@@ -56341,124 +50277,104 @@
 msgstr "Некорректный вид для %s в %L"
 
 #: fortran/check.c:233
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L must be double precision"
+#, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be double precision"
-msgstr "'%s' аргумент '%s' встроенной функции в %L должен быть двойной точности"
+msgstr "%qs аргумент %qs встроенной функции в %L должен быть двойной точности"
 
 #: fortran/check.c:256
-#, fuzzy, gcc-internal-format
-#| msgid "Expected coarray variable as '%s' argument to the %s intrinsic at %L"
+#, gcc-internal-format
 msgid "Expected coarray variable as %qs argument to the %s intrinsic at %L"
-msgstr "Ожидалась комассивная переменная как '%s' аргумент для %s встроенной функции в %L"
+msgstr "Ожидалась комассивная переменная как %qs аргумент для %s встроенной функции в %L"
 
 #: fortran/check.c:273
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L must be a logical array"
+#, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a logical array"
-msgstr "'%s' аргумент '%s' встроенной функции в %L должен быть логическим массивом"
+msgstr "%qs аргумент %qs встроенной функции в %L должен быть логическим массивом"
 
 #: fortran/check.c:299
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L must be an array"
+#, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be an array"
-msgstr "'%s' аргумент '%s' встроенной функции в %L должен быть массивом"
+msgstr "%qs аргумент %qs встроенной функции в %L должен быть массивом"
 
 #: fortran/check.c:320
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' at %L must be nonnegative"
+#, gcc-internal-format
 msgid "%qs at %L must be nonnegative"
-msgstr "'%s' в %L должен быть неотрицательным"
+msgstr "%qs в %L должен быть неотрицательным"
 
 #: fortran/check.c:341
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L must be %s"
+#, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be positive"
-msgstr "'%s' аргумент '%s' встроенной функции в %L должен быть %s"
+msgstr "%qs аргумент %qs встроенной функции в %L должен быть положительным"
 
 #: fortran/check.c:374
-#, fuzzy, gcc-internal-format
-#| msgid "The absolute value of SHIFT at %L must be less than or equal to BIT_SIZE('%s')"
+#, gcc-internal-format
 msgid "The absolute value of SHIFT at %L must be less than or equal to BIT_SIZE(%qs)"
-msgstr "Абсолютная величина SHIFT в %L должна быть меньше или равна BIT_SIZE('%s')"
+msgstr "Абсолютная величина SHIFT в %L должна быть меньше или равна BIT_SIZE(%qs)"
 
 #: fortran/check.c:385
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' at %L must be less than or equal to BIT_SIZE('%s')"
+#, gcc-internal-format
 msgid "%qs at %L must be less than or equal to BIT_SIZE(%qs)"
-msgstr "'%s' в %L должна быть меньше или равна BIT_SIZE('%s')"
+msgstr "%qs в %L должна быть меньше или равна BIT_SIZE(%qs)"
 
 #: fortran/check.c:395
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' at %L must be less than BIT_SIZE('%s')"
+#, gcc-internal-format
 msgid "%qs at %L must be less than BIT_SIZE(%qs)"
-msgstr "'%s' в %L должна быть меньше чем BIT_SIZE('%s')"
+msgstr "%qs в %L должна быть меньше чем BIT_SIZE(%qs)"
 
 #: fortran/check.c:422
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' at %L must be less than or equal to the BIT_SIZE of INTEGER(KIND=%d)"
+#, gcc-internal-format
 msgid "%qs at %L must be less than or equal to the BIT_SIZE of INTEGER(KIND=%d)"
-msgstr "'%s' в %L должна быть меньше или равна BIT_SIZE от INTEGER(KIND=%d)"
+msgstr "%qs в %L должна быть меньше или равна BIT_SIZE от INTEGER(KIND=%d)"
 
 #: fortran/check.c:448
-#, fuzzy, gcc-internal-format
-#| msgid "'%s + %s' at %L must be less than or equal to BIT_SIZE('%s')"
+#, gcc-internal-format
 msgid "%<%s + %s%> at %L must be less than or equal to BIT_SIZE(%qs)"
-msgstr "'%s + %s' в %L должна быть меньше или равна BIT_SIZE('%s')"
+msgstr "%<%s + %s%> в %L должна быть меньше или равна BIT_SIZE(%qs)"
 
 #: fortran/check.c:481
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L must be the same type and kind as '%s'"
+#, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be the same type and kind as %qs"
-msgstr "'%s' аргумент '%s' встроенной функции в %L должен быть того же типа и вида что и '%s'"
+msgstr "%qs аргумент %qs встроенной функции в %L должен быть того же типа и вида, что и %qs"
 
 #: fortran/check.c:498
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L must be of rank %d"
+#, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of rank %d"
-msgstr "'%s' аргумент '%s' встроенной функции в %L должен быть ранга %d"
+msgstr "%qs аргумент %qs встроенной функции в %L должен быть ранга %d"
 
 #: fortran/check.c:513
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L must not be OPTIONAL"
+#, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must not be OPTIONAL"
-msgstr "'%s' аргумент '%s' встроенной функции в %L не должен быть OPTIONAL"
+msgstr "%qs аргумент %qs встроенной функции в %L не должен быть OPTIONAL"
 
 #: fortran/check.c:534
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L must be ALLOCATABLE"
+#, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be ALLOCATABLE"
-msgstr "'%s' аргумент '%s' встроенной функции в %L должен быть ALLOCATABLE"
+msgstr "%qs аргумент %qs встроенной функции в %L должен быть ALLOCATABLE"
 
 #: fortran/check.c:552
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L must be of kind %d"
+#, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of kind %d"
-msgstr "'%s' аргумент '%s' встроенной функции в %L должен быть вида %d"
+msgstr "%qs аргумент %qs встроенной функции в %L должен быть вида %d"
 
 #: fortran/check.c:590
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L cannot be INTENT(IN)"
+#, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L cannot be INTENT(IN)"
-msgstr "'%s' аргумент '%s' встроенной функции в %L не может быть INTENT(IN)"
+msgstr "%qs аргумент %qs встроенной функции в %L не может быть INTENT(IN)"
 
 #: fortran/check.c:611
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L must be a variable"
+#, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a variable"
-msgstr "'%s' аргумент '%s' встроенной функции в %L должен быть переменной"
+msgstr "%qs аргумент %qs встроенной функции в %L должен быть переменной"
 
 #: fortran/check.c:660
-#, fuzzy, gcc-internal-format
-#| msgid "'dim' argument of '%s' intrinsic at %L is not a valid codimension index"
+#, gcc-internal-format
 msgid "%<dim%> argument of %qs intrinsic at %L is not a valid codimension index"
-msgstr "'dim' аргумент '%s' встроенной функции в %L не есть корректный индекс коизмерения"
+msgstr "%<dim%> аргумент %qs встроенной функции в %L не есть корректный индекс коизмерения"
 
 #: fortran/check.c:710
-#, fuzzy, gcc-internal-format
-#| msgid "'dim' argument of %s intrinsic at %L is not a valid dimension index"
+#, gcc-internal-format
 msgid "%<dim%> argument of %qs intrinsic at %L is not a valid dimension index"
-msgstr "'dim' аргумент встроенной функции %s в %L не есть корректный индекс измерения"
+msgstr "%<dim%> аргумент встроенной функции %qs в %L не есть корректный индекс измерения"
 
 #: fortran/check.c:813
 #, gcc-internal-format, gfc-internal-format
@@ -56465,42 +50381,36 @@
 msgid "Unequal character lengths (%ld/%ld) in %s at %L"
 msgstr "Неравные character длины (%ld/%ld) в %s в %L"
 
-#: fortran/check.c:946 fortran/check.c:6602
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' and '%s' arguments of '%s' intrinsic at %L must have the same type"
+#: fortran/check.c:946 fortran/check.c:6605
+#, gcc-internal-format
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have the same type"
-msgstr "'%s' и '%s' аргументы '%s' встроенной функции в %L должны иметь одинаковый тип"
+msgstr "%qs и %qs аргументы %qs встроенной функции в %L должны иметь одинаковый тип"
 
 #: fortran/check.c:955 fortran/check.c:2480 fortran/check.c:2606
 #: fortran/check.c:2680 fortran/check.c:3113
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Extension: Different type kinds at %L"
+#, gcc-internal-format, gfc-internal-format
 msgid "Different type kinds at %L"
-msgstr "Расширение: Различные виды типов в %L"
+msgstr "Различные виды типов в %L"
 
 #: fortran/check.c:991
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L must be a POINTER"
+#, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a POINTER"
-msgstr "'%s' аргумент '%s' встроенной функции в %L должен быть POINTER"
+msgstr "%qs аргумент %qs встроенной функции в %L должен быть POINTER"
 
 #: fortran/check.c:1000 fortran/check.c:1036 fortran/check.c:3696
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L shall not be coindexed"
+#, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be coindexed"
-msgstr "'%s' аргумент '%s' встроенной функции в %L не должен быть коиндексирован"
+msgstr "%qs аргумент %qs встроенной функции в %L не должен быть коиндексирован"
 
 #: fortran/check.c:1018
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L must be a pointer or target VARIABLE or FUNCTION"
+#, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a pointer or target VARIABLE or FUNCTION"
-msgstr "'%s' аргумент '%s' встроенной функции в %L должен быть указателем или целевой VARIABLE или FUNCTION"
+msgstr "%qs аргумент %qs встроенной функции в %L должен быть указателем или целевой VARIABLE или FUNCTION"
 
 #: fortran/check.c:1027
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L must be a POINTER or a TARGET"
+#, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a POINTER or a TARGET"
-msgstr "'%s' аргумент '%s' встроенной функции в %L должен быть POINTER или TARGET"
+msgstr "%qs аргумент %qs встроенной функции в %L должен быть POINTER или TARGET"
 
 #: fortran/check.c:1052
 #, gcc-internal-format, gfc-internal-format
@@ -56508,10 +50418,9 @@
 msgstr "Секция массива с векторным индексом в %L не должна быть целью указателя"
 
 #: fortran/check.c:1063
-#, fuzzy, gcc-internal-format
-#| msgid "NULL pointer at %L is not permitted as actual argument of '%s' intrinsic function"
+#, gcc-internal-format
 msgid "NULL pointer at %L is not permitted as actual argument of %qs intrinsic function"
-msgstr "NULL указатель в %L не разрешен в качестве фактического аргумента '%s' встроенной функции"
+msgstr "NULL указатель в %L не разрешен в качестве фактического аргумента %qs встроенной функции"
 
 #: fortran/check.c:1106
 #, gcc-internal-format, gfc-internal-format
@@ -56524,16 +50433,14 @@
 msgstr "ATOM аргумент в %L для %s встроенной функции должен быть комассивом или коиндексированным"
 
 #: fortran/check.c:1121
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L must be the same type and kind as '%s'"
+#, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall have the same type as %qs at %L"
-msgstr "'%s' аргумент '%s' встроенной функции в %L должен быть того же типа и вида что и '%s'"
+msgstr "%qs аргумент %qs встроенной функции в %L должен иметь тот же тип, что и %qs в %L"
 
 #: fortran/check.c:1139 fortran/check.c:1352
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Too many arguments to %s at %L"
+#, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument to %s at %L"
-msgstr "Слишком много аргументов %s в %L"
+msgstr "STAT= аргумент для %s в %L"
 
 #: fortran/check.c:1158 fortran/check.c:1292 fortran/check.c:1389
 #, gcc-internal-format, gfc-internal-format
@@ -56541,10 +50448,9 @@
 msgstr "ATOM аргумент для %s встроенной функции в %L должен быть определяемым"
 
 #: fortran/check.c:1172 fortran/check.c:1372
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "ATOM argument at %L to intrinsic function %s shall be an integer of ATOMIC_INT_KIND or a logical of ATOMIC_LOGICAL_KIND"
+#, gcc-internal-format, gfc-internal-format
 msgid "ATOM argument at %L to intrinsic function %s shall be an integer of ATOMIC_INT_KIND"
-msgstr "ATOM аргумент в %L для встроенной функции %s должен быть целым ATOMIC_INT_KIND или логическим ATOMIC_LOGICAL_KIND"
+msgstr "ATOM аргумент в %L для встроенной функции %s должен быть целым ATOMIC_INT_KIND"
 
 #: fortran/check.c:1192
 #, gcc-internal-format, gfc-internal-format
@@ -56552,127 +50458,112 @@
 msgstr "VALUE аргумент для %s встроенной функции в %L должен быть определяемым"
 
 #: fortran/check.c:1211 fortran/check.c:1225 fortran/check.c:1260
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L must be %s"
+#, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L not yet supported"
-msgstr "'%s' аргумент '%s' встроенной функции в %L должен быть %s"
+msgstr "%qs аргумент %qs встроенной функции в %L пока не поддерживается"
 
 #: fortran/check.c:1245
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L is not a valid dimension index"
+#, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall specify a valid integer kind"
-msgstr "'%s' аргумент '%s' встроенной функции в %L не есть корректный индекс измерения"
+msgstr "%qs аргумент %qs встроенной функции в %L должен задавать корректный целый вид"
 
 #: fortran/check.c:1299 fortran/check.c:1396
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "ATOM argument of the %s intrinsic function at %L shall be definable"
+#, gcc-internal-format, gfc-internal-format
 msgid "OLD argument of the %s intrinsic function at %L shall be definable"
-msgstr "ATOM аргумент для %s встроенной функции в %L должен быть определяемым"
+msgstr "OLD аргумент для %s встроенной функции в %L должен быть определяемым"
 
 #: fortran/check.c:1314
 #, gcc-internal-format, gfc-internal-format
 msgid "EVENT argument at %L to the intrinsic EVENT_QUERY shall be of type EVENT_TYPE"
-msgstr ""
+msgstr "EVENT аргумент в %L для встроенной функции EVENT_QUERY должен быть типа EVENT_TYPE"
 
 #: fortran/check.c:1324
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "ATOM argument of the %s intrinsic function at %L shall be definable"
+#, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument of the EVENT_QUERY intrinsic function at %L shall be definable"
-msgstr "ATOM аргумент для %s встроенной функции в %L должен быть определяемым"
+msgstr "COUNT аргумент для EVENT_QUERY встроенной функции в %L должен быть определяемым"
 
 #: fortran/check.c:1337
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "ATOM argument of the %s intrinsic function at %L shall be definable"
+#, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument of the EVENT_QUERY intrinsic function at %L shall have at least the range of the default integer"
-msgstr "ATOM аргумент для %s встроенной функции в %L должен быть определяемым"
+msgstr "COUNT аргумент для EVENT_QUERY встроенной функции в %L должен иметь по крайней мере диапазон подразумеваемых целых"
 
 #: fortran/check.c:1416
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Extension: Negative argument N at %L"
+#, gcc-internal-format, gfc-internal-format
 msgid "Negative argument N at %L"
-msgstr "Расширение: Отрицательный аргумент N в %L"
+msgstr "Отрицательный аргумент N в %L"
 
 #: fortran/check.c:1588 fortran/check.c:2045
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L must not be present if 'x' is COMPLEX"
+#, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must not be present if %<x%> is COMPLEX"
-msgstr "'%s' аргумент '%s' встроенной функции в %L не должен присутствовать если 'x' есть COMPLEX"
+msgstr "%qs аргумент %qs встроенной функции в %L не должен присутствовать, если %<x%> есть COMPLEX"
 
 #: fortran/check.c:1597 fortran/check.c:2054
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L must have a type of either REAL or INTEGER"
+#, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must have a type of either REAL or INTEGER"
-msgstr "'%s' аргумент '%s' встроенной функции в %L должен иметь тип либо REAL либо INTEGER"
+msgstr "%qs аргумент %qs встроенной функции в %L должен иметь тип либо REAL либо INTEGER"
 
 #: fortran/check.c:1611 fortran/check.c:1617
 #, gcc-internal-format, gfc-internal-format
 msgid "Conversion from %s to default-kind COMPLEX(%d) at %L might lose precision, consider using the KIND argument"
-msgstr ""
+msgstr "Преобразование из %s в COMPLEX(%d) подразумеваемого вида в %L может привести к потере точности, попробуйте использовать KIND аргумент"
 
 #: fortran/check.c:1639
 #, gcc-internal-format
 msgid "Argument %<A%> with INTENT(INOUT) at %L of the intrinsic subroutine %s shall not have a vector subscript"
-msgstr ""
+msgstr "Аргумент %<A%> с INTENT(INOUT) в %L от встроенной подпрограммы %s не будет иметь индекс вектора"
 
 #: fortran/check.c:1647
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L shall not be coindexed"
+#, gcc-internal-format, gfc-internal-format
 msgid "The A argument at %L to the intrinsic %s shall not be coindexed"
-msgstr "'%s' аргумент '%s' встроенной функции в %L не должен быть коиндексирован"
+msgstr "A аргумент в %L встроенной функции %s не должен быть коиндексирован"
 
 #: fortran/check.c:1670
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "STAT= argument at %L must be a scalar INTEGER variable"
+#, gcc-internal-format, gfc-internal-format
 msgid "The stat= argument at %L must be a kind=4 integer variable"
-msgstr "STAT= аргумент в %L должна быть скалярной INTEGER переменной"
+msgstr "stat= аргумент в %L должна быть kind=4 integer переменной"
 
 #: fortran/check.c:1686
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "STAT= argument at %L must be a scalar INTEGER variable"
+#, gcc-internal-format, gfc-internal-format
 msgid "The errmsg= argument at %L must be a default-kind character variable"
-msgstr "STAT= аргумент в %L должна быть скалярной INTEGER переменной"
+msgstr "errmsg= аргумент в %L должен быть подразумеваемого вида character переменной"
 
 #: fortran/check.c:1694
-#, fuzzy, gcc-internal-format
-#| msgid "Coarrays disabled at %C, use -fcoarray= to enable"
+#, gcc-internal-format
 msgid "Coarrays disabled at %L, use %<-fcoarray=%> to enable"
-msgstr "Комассивы выключены в %C, используйте -fcoarray= для включения"
+msgstr "Комассивы выключены в %L, используйте %<-fcoarray=%> для включения"
 
 #: fortran/check.c:1709
 #, gcc-internal-format, gfc-internal-format
 msgid "Support for the A argument at %L which is polymorphic A argument or has allocatable components is not yet implemented"
-msgstr ""
+msgstr "Поддержка для A аргумента в %L, который есть полиморфный A аргумент или имеет размещаемые компоненты пока не реализована"
 
 #: fortran/check.c:1728
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Actual argument to '%s' at %L must be polymorphic"
+#, gcc-internal-format, gfc-internal-format
 msgid "The A argument at %L of CO_REDUCE shall not be polymorphic"
-msgstr "Фактический аргумент для '%s' в %L должен быть полиморфным"
+msgstr "A аргумент в %L для CO_REDUCE не должен быть полиморфным"
 
 #: fortran/check.c:1735
 #, gcc-internal-format, gfc-internal-format
 msgid "Support for the A argument at %L with allocatable components is not yet implemented"
-msgstr ""
+msgstr "Поддержка для A аргумента в %L с размещаемыми компонентами пока не реализована"
 
 #: fortran/check.c:1749
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Argument of %s at %L must be of length one"
+#, gcc-internal-format, gfc-internal-format
 msgid "OPERATOR argument at %L must be a PURE function"
-msgstr "Аргумент %s в %L должен быть длины один"
+msgstr "OPERATOR Аргумент в %L должен быть PURE функцией"
 
 #. None of the intrinsics fulfills the criteria of taking two arguments,
 #. returning the same type and kind as the arguments and being permitted
 #. as actual argument.
 #: fortran/check.c:1759
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Intrinsic function '%s' at %L is not permitted in an initialization expression"
+#, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic function %s at %L is not permitted for CO_REDUCE"
-msgstr "Встроенная функция '%s' в %L не разрешена в инициализационном выражении"
+msgstr "Встроенная функция %s в %L не разрешена для CO_REDUCE"
 
 #: fortran/check.c:1776
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have two arguments"
-msgstr ""
+msgstr "Функция переданная как OPERATOR в %L должна иметь два аргумента"
 
 #: fortran/check.c:1786
 #, gcc-internal-format, gfc-internal-format
@@ -56682,117 +50573,105 @@
 #: fortran/check.c:1795
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L has arguments of type %s and %s but shall have type %s"
-msgstr ""
+msgstr "Функция переданная как OPERATOR в %L имеет аргументы типа %s и %s, но должна иметь тип %s"
 
 #: fortran/check.c:1806
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have scalar nonallocatable nonpointer arguments and return a nonallocatable nonpointer scalar"
-msgstr ""
+msgstr "Функция переданная как OPERATOR в %L должна иметь скалярные, неразмещаемые, неуказательные аргументы и возвращать неразмещаемый неуказательные скаляр"
 
 #: fortran/check.c:1814
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have the VALUE attribute either for none or both arguments"
-msgstr ""
+msgstr "Функция переданная как OPERATOR в %L должна иметь VALUE атрибут либо ни для одного, либо для обоих аргументов"
 
 #: fortran/check.c:1821
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have the TARGET attribute either for none or both arguments"
-msgstr ""
+msgstr "Функция переданная как OPERATOR в %L должна иметь TARGET атрибут либо ни для одного, либо для обоих аргументов"
 
 #: fortran/check.c:1828
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall have the ASYNCHRONOUS attribute either for none or both arguments"
-msgstr ""
+msgstr "Функция переданная как OPERATOR в %L должна иметь ASYNCHRONOUS атрибут либо ни для одного, либо для обоих аргументов"
 
 #: fortran/check.c:1836
 #, gcc-internal-format, gfc-internal-format
 msgid "The function passed as OPERATOR at %L shall not have the OPTIONAL attribute for either of the arguments"
-msgstr ""
+msgstr "Функция переданная как OPERATOR в %L должна иметь OPTIONAL атрибут либо ни для одного, либо для обоих аргументов"
 
 #: fortran/check.c:1866
 #, gcc-internal-format, gfc-internal-format
 msgid "The character length of the A argument at %L and of the arguments of the OPERATOR at %L shall be the same"
-msgstr ""
+msgstr "Символьная длина A аргумента в %L и аргументов OPERATOR в %L должна быть одинаковой"
 
 #: fortran/check.c:1873
 #, gcc-internal-format, gfc-internal-format
 msgid "The character length of the A argument at %L and of the function result of the OPERATOR at %L shall be the same"
-msgstr ""
+msgstr "Символьная длина A аргумента в %L и результата функции OPERATOR в %L должна быть одинаковой"
 
 #: fortran/check.c:1891
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L shall not be coindexed"
+#, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall be of type integer, real or character"
-msgstr "'%s' аргумент '%s' встроенной функции в %L не должен быть коиндексирован"
+msgstr "%qs аргумент %qs встроенной функции в %L должен быть типа integer, real или character"
 
 #: fortran/check.c:1939 fortran/check.c:2525 fortran/check.c:2628
-#: fortran/check.c:2835 fortran/check.c:2880 fortran/check.c:4256
-#: fortran/check.c:4390 fortran/check.c:4445 fortran/check.c:5515
-#: fortran/check.c:5644
-#, fuzzy, gcc-internal-format
-#| msgid "Fortran 2003: '%s' intrinsic with KIND argument at %L"
+#: fortran/check.c:2835 fortran/check.c:2880 fortran/check.c:4259
+#: fortran/check.c:4393 fortran/check.c:4448 fortran/check.c:5518
+#: fortran/check.c:5647
+#, gcc-internal-format
 msgid "%qs intrinsic with KIND argument at %L"
-msgstr "Fortran 2003: '%s' встроенная функция с KIND аргументом в %L"
+msgstr "%qs встроенная функция с KIND аргументом в %L"
 
 #: fortran/check.c:1986 fortran/check.c:2238 fortran/check.c:2298
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L has invalid shape in dimension %d (%ld/%ld)"
+#, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has invalid shape in dimension %d (%ld/%ld)"
-msgstr "'%s' аргумент '%s' встроенной функции в %L имеет некорректную форму в измерении %d (%ld/%ld)"
+msgstr "%qs аргумент %qs встроенной функции в %L имеет некорректную форму в измерении %d (%ld/%ld)"
 
 #: fortran/check.c:2001 fortran/check.c:2253 fortran/check.c:2313
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' argument of intrinsic '%s' at %L of must have rank %d or be a scalar"
+#, gcc-internal-format
 msgid "%qs argument of intrinsic %qs at %L of must have rank %d or be a scalar"
-msgstr "'%s' аргумент '%s' встроенной функции в %L должен иметь ранг %d или быть скаляром"
+msgstr "%qs аргумент %qs встроенной функции в %L должен иметь ранг %d или быть скаляром"
 
 #: fortran/check.c:2104 fortran/check.c:3207 fortran/check.c:3215
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L must be numeric or LOGICAL"
+#, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be numeric or LOGICAL"
-msgstr "'%s' аргумент '%s' встроенной функции в %L должен быть числовым или LOGICAL"
+msgstr "%qs аргумент %qs встроенной функции в %L должен быть числовым или LOGICAL"
 
 #: fortran/check.c:2118
-#, fuzzy, gcc-internal-format
-#| msgid "Different shape for arguments '%s' and '%s' at %L for intrinsic 'dot_product'"
+#, gcc-internal-format
 msgid "Different shape for arguments %qs and %qs at %L for intrinsic %<dot_product%>"
-msgstr "Разная форма для аргументов '%s' и '%s' в %L для встроенной функции 'dot_product'"
+msgstr "Разная форма для аргументов %qs и %qs в %L для встроенной функции %<dot_product%>"
 
 #: fortran/check.c:2138 fortran/check.c:2146
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L must be default real"
+#, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be default real"
-msgstr "'%s' аргумент '%s' встроенной функции в %L должен быть подразумеваемым вещественным"
+msgstr "%qs аргумент %qs встроенной функции в %L должен быть подразумеваемым вещественным"
 
 #: fortran/check.c:2167
-#, fuzzy, gcc-internal-format
-#| msgid "'I' at %L and 'J' at %L cannot both be BOZ literal constants"
+#, gcc-internal-format
 msgid "%<I%> at %L and %<J%>' at %L cannot both be BOZ literal constants"
-msgstr "'I' в %L и 'J' в %L не могут обе быть BOZ литеральными константами"
+msgstr "%<I%> в %L и %<J%> в %L не могут обе быть BOZ литеральными константами"
 
 #: fortran/check.c:2274
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L must be the same type and kind as '%s'"
+#, gcc-internal-format
 msgid "%qs must be of same type and kind as %qs at %L in %qs"
-msgstr "'%s' аргумент '%s' встроенной функции в %L должен быть того же типа и вида что и '%s'"
+msgstr ""
 
 #: fortran/check.c:2332
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L must be %s"
+#, gcc-internal-format
 msgid "Missing %qs argument to %qs intrinsic at %L for %qs of type %qs"
-msgstr "'%s' аргумент '%s' встроенной функции в %L должен быть %s"
+msgstr ""
 
 #: fortran/check.c:2351
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "GNU extension: non-default INTEGER kind argument to %s intrinsic at %L"
+#, gcc-internal-format, gfc-internal-format
 msgid "non-default INTEGER kind argument to %s intrinsic at %L"
-msgstr "GNU расширение: неподразумеваемый INTEGER вида аргумент '%s' встроенной функции в %L"
+msgstr "неподразумеваемый INTEGER вида аргумент для %s встроенной функции в %L"
 
 #: fortran/check.c:2412
-#, fuzzy, gcc-internal-format
-#| msgid "Fortran 2008: COMPLEX argument '%s' argument of '%s' intrinsic at %L"
+#, gcc-internal-format
 msgid "COMPLEX argument %qs of %qs intrinsic at %L"
-msgstr "Fortran 2008: COMPLEX аргумент '%s' аргумент '%s' встроенной функции в %L"
+msgstr "COMPLEX аргумент %qs %qs встроенной функции в %L"
 
 #: fortran/check.c:2576
 #, gcc-internal-format, gfc-internal-format
@@ -56800,10 +50679,9 @@
 msgstr "Аргумент %s в %L должен быть длины один"
 
 #: fortran/check.c:2635
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L must be the same kind as '%s'"
+#, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be the same kind as %qs"
-msgstr "'%s' аргумент '%s' встроенной функции в %L должен быть того же вида что и '%s'"
+msgstr "%qs аргумент %qs встроенной функции в %L должен быть того же вида, что и %qs"
 
 #: fortran/check.c:2725
 #, gcc-internal-format, gfc-internal-format
@@ -56816,615 +50694,541 @@
 msgstr "Абсолютная величина SHIFT в %L должна быть меньше или равна SIZE в %L"
 
 #: fortran/check.c:2804
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L must be a numeric type"
+#, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of intrinsic type"
-msgstr "'%s' аргумент '%s' встроенной функции в %L должен быть числовым типом"
+msgstr "%qs аргумент %qs встроенной функции в %L должен быть встроенного типа"
 
 #: fortran/check.c:2811
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L must be a constant"
+#, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a data entity"
-msgstr "'%s' аргумент '%s' встроенной функции в %L должен быть константой"
+msgstr "%qs аргумент %qs встроенной функции в %L должен быть сущностью данных"
 
 #: fortran/check.c:3022
-#, fuzzy, gcc-internal-format
-#| msgid "Intrinsic '%s' at %L must have at least two arguments"
+#, gcc-internal-format
 msgid "Intrinsic %qs at %L must have at least two arguments"
-msgstr "Встроенная функция '%s' в %L должна иметь по крайней мере два аргумента"
+msgstr "Встроенная функция %qs в %L должна иметь по крайней мере два аргумента"
 
 #: fortran/check.c:3070
-#, fuzzy, gcc-internal-format
-#| msgid "Missing argument to '%s' at %C"
+#, gcc-internal-format
 msgid "Missing %qs argument to the %s intrinsic at %L"
-msgstr "Отсутствует аргумент для '%s' в %C"
+msgstr "Отсутствует %qs аргумент для %s встроенной функции в %L"
 
 #: fortran/check.c:3085
-#, fuzzy, gcc-internal-format
-#| msgid "arguments '%s' and '%s' for intrinsic %s"
+#, gcc-internal-format
 msgid "Duplicate argument %qs at %L to intrinsic %s"
-msgstr "аргументы '%s' и '%s' для внутренней функции %s"
+msgstr "Повторяющийся аргумент %qs в %L для встроенной функции %s"
 
 #: fortran/check.c:3090
-#, fuzzy, gcc-internal-format
-#| msgid "arguments '%s' and '%s' for intrinsic %s"
+#, gcc-internal-format
 msgid "Unknown argument %qs at %L to intrinsic %s"
-msgstr "аргументы '%s' и '%s' для внутренней функции %s"
+msgstr "Неизвестный аргумент %qs в %L для встроенной функции %s"
 
 #: fortran/check.c:3119
-#, fuzzy, gcc-internal-format
-#| msgid "'a%d' argument of '%s' intrinsic at %L must be %s(%d)"
+#, gcc-internal-format
 msgid "%<a%d%> argument of %qs intrinsic at %L must be %s(%d)"
-msgstr "'a%d' аргумент '%s' встроенной функции в %L должен быть %s(%d)"
+msgstr "%<a%d%> аргумент %qs встроенной функции в %L должен быть %s(%d)"
 
 #: fortran/check.c:3150
-#, fuzzy, gcc-internal-format
-#| msgid "Fortran 2003: '%s' intrinsic with CHARACTER argument at %L"
+#, gcc-internal-format
 msgid "%qs intrinsic with CHARACTER argument at %L"
-msgstr "Fortran 2003: '%s' встроенная функция с CHARACTER аргументом в %L"
+msgstr "%qs встроенная функция с CHARACTER аргументом в %L"
 
 #: fortran/check.c:3157
-#, fuzzy, gcc-internal-format
-#| msgid "'a1' argument of '%s' intrinsic at %L must be INTEGER, REAL or CHARACTER"
+#, gcc-internal-format
 msgid "%<a1%> argument of %qs intrinsic at %L must be INTEGER, REAL or CHARACTER"
-msgstr "'a1' аргумент '%s' встроенной функции в %L должен быть INTEGER, REAL или CHARACTER"
+msgstr "%<a1%> аргумент %qs встроенной функции в %L должен быть INTEGER, REAL или CHARACTER"
 
 #: fortran/check.c:3224
-#, fuzzy, gcc-internal-format
-#| msgid "Argument types of '%s' intrinsic at %L must match (%s/%s)"
+#, gcc-internal-format
 msgid "Argument types of %qs intrinsic at %L must match (%s/%s)"
-msgstr "Типы аргументов '%s' встроенной функции в %L должны соответствовать (%s/%s)"
+msgstr "Типы аргументов %qs встроенной функции в %L должны соответствовать (%s/%s)"
 
 #: fortran/check.c:3238
-#, fuzzy, gcc-internal-format
-#| msgid "Different shape on dimension 1 for arguments '%s' and '%s' at %L for intrinsic matmul"
+#, gcc-internal-format
 msgid "Different shape on dimension 1 for arguments %qs and %qs at %L for intrinsic matmul"
-msgstr "Разная форма по измерению 1 для аргументов '%s' и '%s' в %L для встроенной функции matmul"
+msgstr "Разная форма по измерению 1 для аргументов %qs и %qs в %L для встроенной функции matmul"
 
 #: fortran/check.c:3257
-#, fuzzy, gcc-internal-format
-#| msgid "Different shape on dimension 2 for argument '%s' and dimension 1 for argument '%s' at %L for intrinsic matmul"
+#, gcc-internal-format
 msgid "Different shape on dimension 2 for argument %qs and dimension 1 for argument %qs at %L for intrinsic matmul"
-msgstr "Разная форма по измерению 2 для аргументов '%s' и '%s' в %L для встроенной функции matmul"
+msgstr "Разная форма по измерению 2 для аргументов %qs и %qs в %L для встроенной функции matmul"
 
 #: fortran/check.c:3266
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L must be of rank 1 or 2"
+#, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of rank 1 or 2"
-msgstr "'%s' аргумент '%s' встроенной функции в %L должен быть ранга 1 или 2"
+msgstr "%qs аргумент %qs встроенной функции в %L должен быть ранга 1 или 2"
 
 #: fortran/check.c:3313
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L is empty"
+#, gcc-internal-format
 msgid "BACK argument to %qs intrinsic not yet implemented"
-msgstr "'%s' аргумент '%s' встроенной функции в %L пуст"
+msgstr ""
 
 #: fortran/check.c:3466
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L must be INTEGER"
+#, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER"
-msgstr "'%s' аргумент '%s' встроенной функции в %L должен быть INTEGER"
+msgstr "%qs аргумент %qs встроенной функции в %L должен быть INTEGER"
 
 #: fortran/check.c:3526
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L shall not be coindexed"
+#, gcc-internal-format, gfc-internal-format
 msgid "The FROM argument to MOVE_ALLOC at %L shall not be coindexed"
-msgstr "'%s' аргумент '%s' встроенной функции в %L не должен быть коиндексирован"
+msgstr "FROM аргумент для MOVE_ALLOC в %L не должен быть коиндексирован"
 
 #: fortran/check.c:3537
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L shall not be coindexed"
+#, gcc-internal-format, gfc-internal-format
 msgid "The TO argument to MOVE_ALLOC at %L shall not be coindexed"
-msgstr "'%s' аргумент '%s' встроенной функции в %L не должен быть коиндексирован"
+msgstr "TO аргумент для MOVE_ALLOC в %L не должен быть коиндексирован"
 
 #: fortran/check.c:3544
 #, gcc-internal-format, gfc-internal-format
 msgid "The TO arguments in MOVE_ALLOC at %L must be polymorphic if FROM is polymorphic"
-msgstr "TO аргументы в MOVE_ALLOC в %L должны быть полиморфными если FROM является полиморфным"
+msgstr "TO аргументы в MOVE_ALLOC в %L должны быть полиморфными, если FROM является полиморфным"
 
 #: fortran/check.c:3555
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "the '%s' and '%s' arguments of '%s' intrinsic at %L must have the same rank %d/%d"
+#, gcc-internal-format, gfc-internal-format
 msgid "The FROM and TO arguments of the MOVE_ALLOC intrinsic at %L must have the same rank %d/%d"
-msgstr "'%s' и '%s' аргументы '%s' встроенной функции в %L должны иметь одинаковый ранг %d/%d"
+msgstr "FROM и TO аргументы MOVE_ALLOC встроенной функции в %L должны иметь одинаковый ранг %d/%d"
 
 #: fortran/check.c:3564
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "the '%s' and '%s' arguments of '%s' intrinsic at %L must have the same rank %d/%d"
+#, gcc-internal-format, gfc-internal-format
 msgid "The FROM and TO arguments of the MOVE_ALLOC intrinsic at %L must have the same corank %d/%d"
-msgstr "'%s' и '%s' аргументы '%s' встроенной функции в %L должны иметь одинаковый ранг %d/%d"
+msgstr "FROM и TO аргументы MOVE_ALLOC встроенной функции в %L должны иметь одинаковый коранг %d/%d"
 
 #: fortran/check.c:3604
 #, gcc-internal-format, gfc-internal-format
 msgid "The FROM and TO arguments at %L violate aliasing restrictions (F2003 12.4.1.7)"
-msgstr ""
+msgstr "Аргументы FROM и TO в %L нарушают ограничения синонимии (F2003 12.4.1.7)"
 
 #: fortran/check.c:3631
-#, fuzzy, gcc-internal-format
-#| msgid "Argument 'S' of NEAREST at %L shall not be zero"
+#, gcc-internal-format
 msgid "Argument %<S%> of NEAREST at %L shall not be zero"
-msgstr "Аргумент 'S' NEAREST в %L не должен быть нулем"
+msgstr "Аргумент %<S%> NEAREST в %L не должен быть нулем"
 
 #: fortran/check.c:3681
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L must be a POINTER, ALLOCATABLE or procedure pointer"
+#, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a POINTER, ALLOCATABLE or procedure pointer"
-msgstr "'%s' аргумент '%s' встроенной функции в %L должен быть POINTER, ALLOCATABLE или процедурным указателем"
+msgstr "%qs аргумент %qs встроенной функции в %L должен быть POINTER, ALLOCATABLE или процедурным указателем"
 
 #: fortran/check.c:3689
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2003: NULL intrinsic with allocatable MOLD at %L"
+#, gcc-internal-format, gfc-internal-format
 msgid "NULL intrinsic with allocatable MOLD at %L"
-msgstr "Fortran 2003: NULL встроенная функция с размещаемым MOLD в %L"
+msgstr "NULL встроенная функция с размещаемым MOLD в %L"
 
-#: fortran/check.c:3768 fortran/check.c:5591
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L must provide at least as many elements as there are .TRUE. values in '%s' (%ld/%d)"
+#: fortran/check.c:3768 fortran/check.c:5594
+#, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must provide at least as many elements as there are .TRUE. values in %qs (%ld/%d)"
-msgstr "'%s' аргумент '%s' встроенной функции в %L должен предоставлять по крайней мере столько элементов, сколько есть .TRUE. значений в '%s' (%ld/%d)"
+msgstr ""
 
 #: fortran/check.c:3826
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L must be of a dummy variable"
+#, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of a dummy variable"
-msgstr "'%s' аргумент '%s' встроенной функции в %L должен быть формальной переменной"
+msgstr "%qs аргумент %qs встроенной функции в %L должен быть формальной переменной"
 
 #: fortran/check.c:3834
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L must be of an OPTIONAL dummy variable"
+#, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of an OPTIONAL dummy variable"
-msgstr "'%s' аргумент '%s' встроенной функции в %L должен быть OPTIONAL формальной переменной"
+msgstr "%qs аргумент %qs встроенной функции в %L должен быть OPTIONAL формальной переменной"
 
 #: fortran/check.c:3853
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L must not be a subobject of '%s'"
+#, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must not be a subobject of %qs"
-msgstr "'%s' аргумент '%s' встроенной функции в %L не должен быть подобъектом '%s'"
+msgstr "%qs аргумент %qs встроенной функции в %L не должен быть подобъектом %qs"
 
-#: fortran/check.c:3901
+#: fortran/check.c:3904
 #, gcc-internal-format, gfc-internal-format
 msgid "The argument of the RANK intrinsic at %L must be a data object"
 msgstr "Аргумент RANK встроенной функции в %L должен быть объектом данных"
 
-#: fortran/check.c:4005
-#, fuzzy, gcc-internal-format
-#| msgid "'shape' argument of 'reshape' intrinsic at %L must be an array of constant size"
+#: fortran/check.c:4008
+#, gcc-internal-format
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L must be an array of constant size"
-msgstr "'shape' аргумент 'reshape' встроенной функции в %L должен быть массивом константного размера"
+msgstr "%<shape%> аргумент %<reshape%> встроенной функции в %L должен быть массивом константного размера"
 
-#: fortran/check.c:4015
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L is empty"
+#: fortran/check.c:4018
+#, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L is empty"
-msgstr "'%s' аргумент '%s' встроенной функции в %L пуст"
+msgstr "%qs аргумент %qs встроенной функции в %L пуст"
 
-#: fortran/check.c:4022
-#, fuzzy, gcc-internal-format
-#| msgid "'shape' argument of 'reshape' intrinsic at %L has more than %d elements"
+#: fortran/check.c:4025
+#, gcc-internal-format
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L has more than %d elements"
-msgstr "'shape' аргумент 'reshape' встроенной функции в %L имеет больше чем %d элементов"
+msgstr "%<shape%> аргумент %<reshape%> встроенной функции в %L имеет больше чем %d элементов"
 
-#: fortran/check.c:4039
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L has negative element (%d)"
+#: fortran/check.c:4042
+#, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has negative element (%d)"
-msgstr "'%s' аргумент '%s' встроенной функции в %L имеет отрицательный элемент (%d)"
+msgstr "%qs аргумент %qs встроенной функции в %L имеет отрицательный элемент (%d)"
 
-#: fortran/check.c:4071
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Complex argument of LOG at %L cannot be zero"
+#: fortran/check.c:4074
+#, gcc-internal-format, gfc-internal-format
 msgid "Element %d of actual argument of RESHAPE at %L cannot be negative"
-msgstr "Complex аргумент LOG в %L не может быть нулевым"
+msgstr "Элемент %d фактического аргумента RESHAPE в %L не может быть отрицательным"
 
-#: fortran/check.c:4109
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L has wrong number of elements (%d/%d)"
+#: fortran/check.c:4112
+#, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has wrong number of elements (%d/%d)"
-msgstr "'%s' аргумент '%s' встроенной функции в %L имеет неверное число элементов (%d/%d)"
+msgstr "%qs аргумент %qs встроенной функции в %L имеет неверное число элементов (%d/%d)"
 
-#: fortran/check.c:4127
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L has out-of-range dimension (%d)"
+#: fortran/check.c:4130
+#, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has out-of-range dimension (%d)"
-msgstr "'%s' аргумент '%s' встроенной функции в %L имеет измерение вне диапазона (%d)"
+msgstr "%qs аргумент %qs встроенной функции в %L имеет измерение вне диапазона (%d)"
 
-#: fortran/check.c:4136
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L has invalid permutation of dimensions (dimension '%d' duplicated)"
+#: fortran/check.c:4139
+#, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has invalid permutation of dimensions (dimension %qd duplicated)"
-msgstr "'%s' аргумент '%s' встроенной функции в %L имеет некорректную перестановку измерений (измерение '%d' дублировано)"
+msgstr "%qs аргумент %qs встроенной функции в %L имеет некорректную перестановку измерений (измерение %qd дублировано)"
 
-#: fortran/check.c:4172
+#: fortran/check.c:4175
 #, gcc-internal-format, gfc-internal-format
 msgid "Without padding, there are not enough elements in the intrinsic RESHAPE source at %L to match the shape"
-msgstr "Без дополнения не хватает элементов во встроенной функции RESHAPE source в %L чтобы соответствовать форме"
+msgstr "Без дополнения не хватает элементов во встроенной функции RESHAPE source в %L, чтобы соответствовать форме"
 
-#: fortran/check.c:4189 fortran/check.c:4208
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L must be %s"
+#: fortran/check.c:4192 fortran/check.c:4211
+#, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L cannot be of type %s"
-msgstr "'%s' аргумент '%s' встроенной функции в %L должен быть %s"
+msgstr "%qs аргумент %qs встроенной функции в %L не может быть типа %s"
 
-#: fortran/check.c:4199 fortran/check.c:4218
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L must be of an extensible type"
+#: fortran/check.c:4202 fortran/check.c:4221
+#, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of an extensible type"
-msgstr "'%s' аргумент '%s' встроенной функции в %L должен быть расширяемого типа"
+msgstr "%qs аргумент %qs встроенной функции в %L должен быть расширяемого типа"
 
-#: fortran/check.c:4317
-#, fuzzy, gcc-internal-format
-#| msgid "Fortran 2008: SELECTED_REAL_KIND with neither 'P' nor 'R' argument at %L"
+#: fortran/check.c:4320
+#, gcc-internal-format
 msgid "SELECTED_REAL_KIND with neither %<P%> nor %<R%> argument at %L"
-msgstr "Fortran 2008: SELECTED_REAL_KIND с аргументом не 'P' и не 'R' в %L"
+msgstr "SELECTED_REAL_KIND с аргументом не %<P%> и не %<R%> в %L"
 
-#: fortran/check.c:4348
-#, fuzzy, gcc-internal-format
-#| msgid "Fortran 2008: '%s' intrinsic with RADIX argument at %L"
+#: fortran/check.c:4351
+#, gcc-internal-format
 msgid "%qs intrinsic with RADIX argument at %L"
-msgstr "Fortran 2008: '%s' встроенная функция с RADIX аргументом в %L"
+msgstr "%qs встроенная функция с RADIX аргументом в %L"
 
-#: fortran/check.c:4383
-#, fuzzy, gcc-internal-format
-#| msgid "'source' argument of 'shape' intrinsic at %L must not be an assumed size array"
+#: fortran/check.c:4386
+#, gcc-internal-format
 msgid "%<source%> argument of %<shape%> intrinsic at %L must not be an assumed size array"
-msgstr "'source' аргумент 'shape' встроенной функции в %L не должен быть массивом предполагаемого размера"
+msgstr "%<source%> аргумент %<shape%> встроенной функции в %L не должен быть массивом предполагаемого размера"
 
-#: fortran/check.c:4460 fortran/check.c:6641
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L may not be a procedure"
+#: fortran/check.c:4463 fortran/check.c:6644
+#, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be a procedure"
-msgstr "'%s' аргумент '%s' встроенной функции в %L не может быть процедурой"
+msgstr "%qs аргумент %qs встроенной функции в %L не должен быть процедурой"
 
-#: fortran/check.c:4473 fortran/check.c:4612 fortran/check.c:6633
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L shall not be coindexed"
+#: fortran/check.c:4476 fortran/check.c:4615 fortran/check.c:6636
+#, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be TYPE(*)"
-msgstr "'%s' аргумент '%s' встроенной функции в %L не должен быть коиндексирован"
+msgstr "%qs аргумент %qs встроенной функции в %L не должен быть TYPE(*)"
 
-#: fortran/check.c:4484 fortran/check.c:4624
-#, fuzzy, gcc-internal-format
-#| msgid "'source' argument of 'shape' intrinsic at %L must not be an assumed size array"
+#: fortran/check.c:4487 fortran/check.c:4627
+#, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be an assumed-size array"
-msgstr "'source' аргумент 'shape' встроенной функции в %L не должен быть массивом предполагаемого размера"
+msgstr "%qs аргумент %qs встроенной функции в %L не должен быть массивом предполагаемого размера"
 
-#: fortran/check.c:4554
+#: fortran/check.c:4557
 #, gcc-internal-format
 msgid "is_c_interoperable(): gfc_simplify_expr failed"
-msgstr ""
+msgstr "is_c_interoperable(): gfc_simplify_expr потерпело неудачу"
 
-#: fortran/check.c:4603
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L must be an interoperable data entity"
+#: fortran/check.c:4606
+#, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be an interoperable data entity: %s"
-msgstr "'%s' аргумент '%s' встроенной функции в %L должен быть интероперабельной сущностью данных"
+msgstr "%qs аргумент %qs встроенной функции в %L должен быть интероперабельной сущностью данных: %s"
 
-#: fortran/check.c:4642
+#: fortran/check.c:4645
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_1 at %L to C_ASSOCIATED shall have the type TYPE(C_PTR) or TYPE(C_FUNPTR)"
-msgstr ""
+msgstr "Аргумент C_PTR_1 в %L для C_ASSOCIATED должен иметь тип TYPE(C_PTR) или TYPE(C_FUNPTR)"
 
-#: fortran/check.c:4656
+#: fortran/check.c:4659
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_2 at %L to C_ASSOCIATED shall have the same type as C_PTR_1: %s instead of %s"
-msgstr ""
+msgstr "Аргумент C_PTR_2 в %L для C_ASSOCIATED должен иметь тот же тип, что и C_PTR_1: %s вместо %s"
 
-#: fortran/check.c:4680
+#: fortran/check.c:4683
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_POINTER shall have the type TYPE(C_PTR)"
-msgstr ""
+msgstr "Аргумент CPTR в %L для C_F_POINTER должен иметь тип TYPE(C_PTR)"
 
-#: fortran/check.c:4692
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "argument %d of %qE must be a pointer type"
+#: fortran/check.c:4695
+#, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER must be a pointer"
-msgstr "аргумент %d для %qE должен быть указателем"
+msgstr "Аргумент FPTR в %L для C_F_POINTER должен быть указателем"
 
-#: fortran/check.c:4699
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Actual argument to '%s' at %L must be polymorphic"
+#: fortran/check.c:4702
+#, gcc-internal-format, gfc-internal-format
 msgid "FPTR argument at %L to C_F_POINTER shall not be polymorphic"
-msgstr "Фактический аргумент для '%s' в %L должен быть полиморфным"
+msgstr "FPTR аргумент в %L для C_F_POINTER должен быть полиморфным"
 
-#: fortran/check.c:4706
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Pointer object at %C shall not be coindexed"
+#: fortran/check.c:4709
+#, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER shall not be coindexed"
-msgstr "Указательный объект в %C не должен быть коиндексирован"
+msgstr "Аргумент FPTR в %L для C_F_POINTER не должен быть коиндексирован"
 
-#: fortran/check.c:4713
+#: fortran/check.c:4716
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected SHAPE argument at %L to C_F_POINTER with scalar FPTR"
-msgstr ""
+msgstr "Неожиданный SHAPE аргумент в %L для C_F_POINTER со скалярным FPTR"
 
-#: fortran/check.c:4719
+#: fortran/check.c:4722
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected SHAPE argument to C_F_POINTER with array FPTR at %L"
-msgstr ""
+msgstr "Ожидался SHAPE аргумент для C_F_POINTER с массивным FPTR в %L"
 
-#: fortran/check.c:4738
+#: fortran/check.c:4741
 #, gcc-internal-format, gfc-internal-format
 msgid "SHAPE argument at %L to C_F_POINTER must have the same size as the RANK of FPTR"
-msgstr ""
+msgstr "SHAPE аргумент в %L для C_F_POINTER должен иметь тот же размер, что и RANK FPTR"
 
-#: fortran/check.c:4748
+#: fortran/check.c:4751
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic FPTR at %L to C_F_POINTER"
-msgstr ""
+msgstr "Полиморфный FPTR в %L для C_F_POINTER"
 
-#: fortran/check.c:4753
+#: fortran/check.c:4756
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array FPTR at %L to C_F_POINTER: %s"
-msgstr ""
+msgstr "Неинтероперабельный массив FPTR в %L для C_F_POINTER: %s"
 
-#: fortran/check.c:4769
+#: fortran/check.c:4772
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_PROCPOINTER shall have the type TYPE(C_FUNPTR)"
-msgstr ""
+msgstr "Аргумент CPTR в %L для C_F_PROCPOINTER должен иметь тип TYPE(C_FUNPTR)"
 
-#: fortran/check.c:4781
+#: fortran/check.c:4784
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall be a procedure pointer"
-msgstr ""
+msgstr "Аргумент FPTR в %L для C_F_PROCPOINTER должен быть указателем на процедуру"
 
-#: fortran/check.c:4788
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Pointer object at %C shall not be coindexed"
+#: fortran/check.c:4791
+#, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall not be coindexed"
-msgstr "Указательный объект в %C не должен быть коиндексирован"
+msgstr "Аргумент FPTR в %L для C_F_PROCPOINTER должен быть коиндексирован"
 
-#: fortran/check.c:4794
+#: fortran/check.c:4797
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure pointer at %L to C_F_PROCPOINTER"
-msgstr ""
+msgstr "Неинтероперабельный указатель на процедуру в %L для C_F_PROCPOINTER"
 
-#: fortran/check.c:4808
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Pointer object at %C shall not be coindexed"
+#: fortran/check.c:4811
+#, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall not be coindexed"
-msgstr "Указательный объект в %C не должен быть коиндексирован"
+msgstr "Аргумент X в %L для C_FUNLOC не должен быть коиндексирован"
 
-#: fortran/check.c:4823
-#, fuzzy, gcc-internal-format
-#| msgid "Function result '%s' at %L has no IMPLICIT type"
+#: fortran/check.c:4826
+#, gcc-internal-format
 msgid "Function result %qs at %L is invalid as X argument to C_FUNLOC"
-msgstr "Результат функции '%s' в %L не имеет IMPLICIT типа"
+msgstr "Результат функции %qs в %L не годится как X аргумент для C_FUNLOC"
 
-#: fortran/check.c:4831
+#: fortran/check.c:4834
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall be a procedure or a procedure pointer"
-msgstr ""
+msgstr "Аргумент X в %L для C_FUNLOC должен быть процедурой или указателем на процедуру"
 
-#: fortran/check.c:4837
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "User operator procedure '%s' at %L must be a FUNCTION"
+#: fortran/check.c:4840
+#, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure at %L to C_FUNLOC"
-msgstr "Процедура пользовательского оператора '%s' в %L должна быть FUNCTION"
+msgstr "Неинтероперабельная процедура в %L для C_FUNLOC"
 
-#: fortran/check.c:4851
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Pointer object at %C shall not be coindexed"
+#: fortran/check.c:4854
+#, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall not be coindexed"
-msgstr "Указательный объект в %C не должен быть коиндексирован"
+msgstr "Аргумент X в %L для C_LOC не должен быть коиндексирован"
 
-#: fortran/check.c:4857
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Actual argument to '%s' at %L must be polymorphic"
+#: fortran/check.c:4860
+#, gcc-internal-format, gfc-internal-format
 msgid "X argument at %L to C_LOC shall not be polymorphic"
-msgstr "Фактический аргумент для '%s' в %L должен быть полиморфным"
+msgstr "X аргумент в %L для C_LOC не должен быть полиморфным"
 
-#: fortran/check.c:4868
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Component at %C must have the POINTER attribute"
+#: fortran/check.c:4871
+#, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall have either the POINTER or the TARGET attribute"
-msgstr "Компонент в %C должен иметь атрибут POINTER"
+msgstr "Аргумент X в %L для C_LOC должен иметь POINTER или TARGET атрибут"
 
-#: fortran/check.c:4876
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Argument 'S' of NEAREST at %L shall not be zero"
+#: fortran/check.c:4879
+#, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall be not be a zero-sized string"
-msgstr "Аргумент 'S' NEAREST в %L не должен быть нулем"
+msgstr "Аргумент X в %L для C_LOC не должен быть строкой нулевого размера"
 
-#: fortran/check.c:4885
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Actual argument to '%s' at %L must be polymorphic"
+#: fortran/check.c:4888
+#, gcc-internal-format, gfc-internal-format
 msgid "Argument at %L to C_LOC shall not be polymorphic"
-msgstr "Фактический аргумент для '%s' в %L должен быть полиморфным"
+msgstr "Аргумент в %L для C_LOC не должен быть полиморфным"
 
-#: fortran/check.c:4892
+#: fortran/check.c:4895
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array at %L as argument to C_LOC: %s"
-msgstr ""
+msgstr "Неинтероперабельный массив в %L как аргумент для C_LOC: %s"
 
-#: fortran/check.c:4903
+#: fortran/check.c:4906
 #, gcc-internal-format, gfc-internal-format
 msgid "Array of interoperable type at %L to C_LOC which is nonallocatable and neither assumed size nor explicit size"
-msgstr ""
+msgstr "Массив неинтероперабельного типа в %L для C_LOC, который является неразмещаемым и не подразумеваемого и не явного размера"
 
-#: fortran/check.c:4908
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Array section in '%s' call at %L"
+#: fortran/check.c:4911
+#, gcc-internal-format, gfc-internal-format
 msgid "Array section at %L to C_LOC"
-msgstr "Секция массива в '%s' вызове в %L"
+msgstr "Секция массива в %L для C_LOC"
 
-#: fortran/check.c:4936
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "GNU extension: non double precision REAL argument to %s intrinsic at %L"
+#: fortran/check.c:4939
+#, gcc-internal-format, gfc-internal-format
 msgid "non double precision REAL argument to %s intrinsic at %L"
-msgstr "GNU расширение: не двойной точности REAL аргумент для '%s' встроенной функции в %L"
+msgstr "не двойной точности REAL аргумент для %s встроенной функции в %L"
 
-#: fortran/check.c:4949
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L must be less than rank %d"
+#: fortran/check.c:4952
+#, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be less than rank %d"
-msgstr "'%s' аргумент '%s' встроенной функции в %L должен быть меньше чем ранг %d"
+msgstr "%qs аргумент %qs встроенной функции в %L должен быть меньше чем ранг %d"
 
-#: fortran/check.c:4968
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L is not a valid dimension index"
+#: fortran/check.c:4971
+#, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L is not a valid dimension index"
-msgstr "'%s' аргумент '%s' встроенной функции в %L не есть корректный индекс измерения"
+msgstr "%qs аргумент %qs встроенной функции в %L не есть корректный индекс измерения"
 
-#: fortran/check.c:5231
+#: fortran/check.c:5234
 #, gcc-internal-format, gfc-internal-format
 msgid "%s argument to IMAGE_INDEX must be a rank one array at %L"
 msgstr "'%s' аргумент для IMAGE_INDEX должен быть массивом ранга один в %L"
 
-#: fortran/check.c:5242
+#: fortran/check.c:5245
 #, gcc-internal-format, gfc-internal-format
 msgid "The number of array elements of the SUB argument to IMAGE_INDEX at %L shall be %d (corank) not %d"
 msgstr "Число элементов массива SUB аргумента для IMAGE_INDEX в %L должно быть %d (коранг) а не %d"
 
-#: fortran/check.c:5275
+#: fortran/check.c:5278
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to NUM_IMAGES at %L"
-msgstr ""
+msgstr "DISTANCE= аргумент для NUM_IMAGES в %L"
 
-#: fortran/check.c:5288
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "MOLD argument to NULL required at %L"
+#: fortran/check.c:5291
+#, gcc-internal-format, gfc-internal-format
 msgid "FAILED= argument to NUM_IMAGES at %L"
-msgstr "MOLD аргумент в NULL требуется в %L"
+msgstr "FAILED= аргумент в NUM_IMAGES в %L"
 
-#: fortran/check.c:5312
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L shall not be coindexed"
+#: fortran/check.c:5315
+#, gcc-internal-format, gfc-internal-format
 msgid "TEAM argument at %L to the intrinsic TEAM_NUMBER shall be of type TEAM_TYPE"
-msgstr "'%s' аргумент '%s' встроенной функции в %L не должен быть коиндексирован"
+msgstr ""
 
-#: fortran/check.c:5338
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "DIM argument without ARRAY argument not allowed for THIS_IMAGE intrinsic at %L"
+#: fortran/check.c:5341
+#, gcc-internal-format, gfc-internal-format
 msgid "DIM argument without COARRAY argument not allowed for THIS_IMAGE intrinsic at %L"
-msgstr "DIM аргумент без ARRAY аргумента не допускается для THIS_IMAGE встроенной функции в %L"
+msgstr "DIM аргумент без COARRAY аргумента не допускается для THIS_IMAGE встроенной функции в %L"
 
-#: fortran/check.c:5345
+#: fortran/check.c:5348
 #, gcc-internal-format, gfc-internal-format
 msgid "The DISTANCE argument may not be specified together with the COARRAY or DIM argument in intrinsic at %L"
-msgstr ""
+msgstr "DISTANCE аргумент не должен быть задан вместе с COARRAY или DIM аргументом во встроенной функции в %L"
 
-#: fortran/check.c:5356
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Unexpected junk in formal argument list at %C"
+#: fortran/check.c:5359
+#, gcc-internal-format, gfc-internal-format
 msgid "Unexpected DIM argument with noncoarray argument at %L"
-msgstr "Неожиданный мусор в списке формальных аргументов в %C"
+msgstr "Неожиданный DIM аргумент с некомассивным аргументом в %L"
 
-#: fortran/check.c:5374
+#: fortran/check.c:5377
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to THIS_IMAGE at %L"
-msgstr ""
+msgstr "DISTANCE= аргумент для THIS_IMAGE в %L"
 
-#: fortran/check.c:5454
-#, fuzzy, gcc-internal-format
-#| msgid "'MOLD' argument of 'TRANSFER' intrinsic at %L must not be %s"
+#: fortran/check.c:5457
+#, gcc-internal-format
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L must not be %s"
-msgstr "'MOLD' аргумент 'TRANSFER' встроенной функции в %L не должен быть %s"
+msgstr "%<MOLD%> аргумент %<TRANSFER%> встроенной функции в %L не должен быть %s"
 
-#: fortran/check.c:5483
+#: fortran/check.c:5486
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic TRANSFER at %L has partly undefined result: source size %ld < result size %ld"
 msgstr "Встроенная функция TRANSFER в %L имеет частично неопределенный результат: исходный размер %ld < размера результата %ld"
 
-#: fortran/check.c:5605
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L must have the same rank as '%s' or be a scalar"
+#: fortran/check.c:5608
+#, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must have the same rank as %qs or be a scalar"
-msgstr "'%s' аргумент '%s' встроенной функции в %L должен иметь тот же ранг что и '%s' или быть скаляром"
+msgstr "%qs аргумент %qs встроенной функции в %L должен иметь тот же ранг, что и %qs или быть скаляром"
 
-#: fortran/check.c:5618
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' and '%s' arguments of '%s' intrinsic at %L must have identical shape."
+#: fortran/check.c:5621
+#, gcc-internal-format
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have identical shape."
-msgstr "'%s' и '%s' аргументы '%s' встроенной функции в %L должны иметь идентичную форму."
+msgstr "%qs и %qs аргументы %qs встроенной функции в %L должны иметь идентичную форму."
 
-#: fortran/check.c:5861 fortran/check.c:5893
-#, fuzzy, gcc-internal-format
-#| msgid "Size of '%s' argument of '%s' intrinsic at %L too small (%i/%i)"
+#: fortran/check.c:5864 fortran/check.c:5896
+#, gcc-internal-format
 msgid "Size of %qs argument of %qs intrinsic at %L too small (%i/%i)"
-msgstr "Размер '%s' аргумента '%s' встроенной функции в %L слишком мал (%i/%i)"
+msgstr "Размер %qs аргумента %qs встроенной функции в %L слишком мал (%i/%i)"
 
-#: fortran/check.c:5901
+#: fortran/check.c:5904
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many arguments to %s at %L"
 msgstr "Слишком много аргументов %s в %L"
 
-#: fortran/check.c:5919
+#: fortran/check.c:5922
 #, gcc-internal-format
 msgid "fe_runtime_error string must be null terminated"
-msgstr ""
+msgstr "fe_runtime_error цепочка должна быть null-терминирована"
 
-#: fortran/check.c:5931
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "wrong number of template arguments (%d, should be %d)"
+#: fortran/check.c:5934
+#, gcc-internal-format, gfc-internal-format
 msgid "fe_runtime_error: Wrong number of arguments (%d instead of %d)"
-msgstr "неправильное число аргументов шаблона (%d, а должно быть %d)"
+msgstr "fe_runtime_error: Неправильное число аргументов (%d вместо %d)"
 
-#: fortran/check.c:5971
+#: fortran/check.c:5974
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument to SYSTEM_CLOCK at %L has non-default kind"
-msgstr ""
+msgstr "COUNT аргумент для SYSTEM_CLOCK в %L имеет неподразумеваемый вид"
 
-#: fortran/check.c:5990
+#: fortran/check.c:5993
 #, gcc-internal-format, gfc-internal-format
 msgid "Real COUNT_RATE argument to SYSTEM_CLOCK at %L"
-msgstr ""
+msgstr "Вещественный COUNT_RATE аргумент для SYSTEM_CLOCK в %L"
 
-#: fortran/check.c:6000
+#: fortran/check.c:6003
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT_RATE argument to SYSTEM_CLOCK at %L has non-default kind"
-msgstr ""
+msgstr "COUNT_RATE аргумент для SYSTEM_CLOCK в %L имеет неподразумеваемый вид"
 
-#: fortran/check.c:6017
+#: fortran/check.c:6020
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT_MAX argument to SYSTEM_CLOCK at %L has non-default kind"
-msgstr ""
+msgstr "COUNT_MAX аргумент для SYSTEM_CLOCK в %L имеет неподразумеваемый вид"
 
-#: fortran/check.c:6234
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L must be of a kind not wider than the default kind (%d)"
+#: fortran/check.c:6237
+#, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of a kind not wider than the default kind (%d)"
-msgstr "'%s' аргумент '%s' встроенной функции в %L должен быть вида не шире чем подразумеваемый вид (%d)"
+msgstr "%qs аргумент %qs встроенной функции в %L должен быть вида не шире чем подразумеваемый вид (%d)"
 
-#: fortran/check.c:6586 fortran/check.c:6594
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L must be INTEGER or LOGICAL"
+#: fortran/check.c:6589 fortran/check.c:6597
+#, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or LOGICAL"
-msgstr "'%s' аргумент '%s' встроенной функции в %L должен быть INTEGER или LOGICAL"
+msgstr "%qs аргумент %qs встроенной функции в %L должен быть INTEGER или LOGICAL"
 
-#: fortran/check.c:6625
+#: fortran/check.c:6628
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic function NULL at %L cannot be an actual argument to STORAGE_SIZE, because it returns a disassociated pointer"
-msgstr ""
+msgstr "Встроенная функция NULL в %L не может быть фактическим аргументом для STORAGE_SIZE, так как она возвращает неассоциированный указатель"
 
 #: fortran/class.c:616
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size polymorphic objects or components, such as that at %C, have not yet been implemented"
-msgstr "Предполагаемый размер полиморфных объектов или компонентов таких как в %C пока не реализован"
+msgstr "Предполагаемый размер полиморфных объектов или компонентов, таких как в %C, пока не реализован"
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:727 fortran/decl.c:3636 fortran/decl.c:10066
-#, fuzzy, gcc-internal-format
-#| msgid "Maximum extension level reached with type '%s' at %L"
+#: fortran/class.c:727 fortran/decl.c:3655 fortran/decl.c:10091
+#, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
-msgstr "Максимальный уровень расширения достигнут с типом '%s' в %L"
+msgstr "Максимальный уровень расширения достигнут с типом %qs в %L"
 
 #: fortran/class.c:2884 fortran/class.c:2958
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' of '%s' is PRIVATE at %L"
+#, gcc-internal-format
 msgid "%qs of %qs is PRIVATE at %L"
-msgstr "'%s' от '%s' является PRIVATE в %L"
+msgstr "%qs от %qs является PRIVATE в %L"
 
 #: fortran/cpp.c:450
-#, fuzzy, gcc-internal-format
-#| msgid "To enable preprocessing, use -cpp"
+#, gcc-internal-format
 msgid "To enable preprocessing, use %<-cpp%>"
-msgstr "Для включения препроцессирования используйте -cpp"
+msgstr "Для включения препроцессирования используйте %<-cpp%>"
 
 #: fortran/cpp.c:548 fortran/cpp.c:559 fortran/cpp.c:666
-#, fuzzy, gcc-internal-format
-#| msgid "opening output file %s: %s"
+#, gcc-internal-format
 msgid "opening output file %qs: %s"
-msgstr "при открытии выходного файла %s: %s"
+msgstr "при открытии выходного файла %qs: %s"
 
 #: fortran/data.c:65
 #, gcc-internal-format, gfc-internal-format
@@ -57431,66 +51235,65 @@
 msgid "non-constant array in DATA statement %L"
 msgstr "неконстантный массив в DATA операторе %L"
 
-#: fortran/data.c:137
+#: fortran/data.c:140
 #, gcc-internal-format, gfc-internal-format
 msgid "failure to simplify substring reference in DATA statement at %L"
 msgstr "Не удалось упростить ссылку на подстроку в DATA операторе в %L"
 
-#: fortran/data.c:170
+#: fortran/data.c:173
 #, gcc-internal-format, gfc-internal-format
 msgid "Unused initialization string at %L because variable has zero length"
-msgstr ""
+msgstr "Неиспользуемая инициализационная цепочка в %L, так как переменная имеет нулевую длину"
 
-#: fortran/data.c:176
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Initialization string starting at %L was truncated to fit the variable (%d/%d)"
+#: fortran/data.c:179
+#, gcc-internal-format, gfc-internal-format
 msgid "Initialization string at %L was truncated to fit the variable (%ld/%ld)"
-msgstr "строка инициализации начинающаяся в %L была усечена чтобы подойти переменной (%d/%d)"
+msgstr ""
 
-#: fortran/data.c:265
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' at %L already is initialized at %L"
+#: fortran/data.c:268
+#, gcc-internal-format
 msgid "%qs at %L already is initialized at %L"
-msgstr "'%s' в %L уже инициализирован в %L"
+msgstr "%qs в %L уже инициализирован в %L"
 
-#: fortran/data.c:289
+#: fortran/data.c:292
 #, gcc-internal-format, gfc-internal-format
 msgid "Data element below array lower bound at %L"
 msgstr "Элемент данных ниже нижней границы массива в %L"
 
-#: fortran/data.c:306 fortran/data.c:395
+#: fortran/data.c:309 fortran/data.c:398
 #, gcc-internal-format, gfc-internal-format
 msgid "Data element above array upper bound at %L"
 msgstr "Элемент данных выше верхней границы массива в %L"
 
-#: fortran/data.c:336 fortran/data.c:505
-#, fuzzy, gcc-internal-format
-#| msgid "Extension: re-initialization of '%s' at %L"
+#: fortran/data.c:339 fortran/data.c:496
+#, gcc-internal-format
 msgid "re-initialization of %qs at %L"
-msgstr "Расширение: повторная инициализация '%s' в %L"
+msgstr "реинициализация %qs в %L"
 
-#: fortran/data.c:727
+#: fortran/data.c:515
 #, gcc-internal-format
-msgid "TODO: Vector sections in data statements"
+msgid "Nonpointer object %qs with default initialization shall not appear in a DATA statement at %L"
 msgstr ""
 
+#: fortran/data.c:738
+#, gcc-internal-format
+msgid "TODO: Vector sections in data statements"
+msgstr "TODO: Векторные секции в data операторах"
+
 #: fortran/decl.c:290
-#, fuzzy, gcc-internal-format
-#| msgid "Host associated variable '%s' may not be in the DATA statement at %C"
+#, gcc-internal-format
 msgid "Host associated variable %qs may not be in the DATA statement at %C"
-msgstr "Ассоциированная с хостом переменная '%s' не должна быть в DATA операторе в %C"
+msgstr "Ассоциированная с хостом переменная %qs не должна быть в DATA операторе в %C"
 
 #: fortran/decl.c:297
-#, fuzzy, gcc-internal-format
-#| msgid "Extension: initialization of common block variable '%s' in DATA statement at %C"
+#, gcc-internal-format
 msgid "initialization of common block variable %qs in DATA statement at %C"
-msgstr "Расширение: инициализация переменной из common блока '%s' в DATA операторе в %C"
+msgstr "инициализация переменной из common блока %qs в DATA операторе в %C"
 
 #: fortran/decl.c:408
-#, fuzzy, gcc-internal-format
-#| msgid "Symbol '%s' must be a PARAMETER in DATA statement at %C"
+#, gcc-internal-format
 msgid "Symbol %qs must be a PARAMETER in DATA statement at %C"
-msgstr "Символ '%s' должен быть PARAMETER в DATA операторе в %C"
+msgstr "Символ %qs должен быть PARAMETER в DATA операторе в %C"
 
 #: fortran/decl.c:434
 #, gcc-internal-format, gfc-internal-format
@@ -57497,1917 +51300,1753 @@
 msgid "Invalid initializer %s in Data statement at %C"
 msgstr "Некорректный инициализатор %s в Data операторе в %C"
 
-#: fortran/decl.c:536
+#: fortran/decl.c:537
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C is not allowed in a PURE procedure"
 msgstr "Инициализация в %C не допускается в PURE процедуре"
 
-#: fortran/decl.c:573
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "ENTRY statement at %C cannot appear within an INTERFACE"
+#: fortran/decl.c:574
+#, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %C cannot appear within an INTERFACE"
-msgstr "ENTRY оператор в %C не может появляться внутри INTERFACE"
+msgstr "DATA оператор в %C не может появляться внутри INTERFACE"
 
-#: fortran/decl.c:597
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Invalid initializer %s in Data statement at %C"
+#: fortran/decl.c:598
+#, gcc-internal-format, gfc-internal-format
 msgid "Invalid substring in data-implied-do at %L in DATA statement"
-msgstr "Некорректный инициализатор %s в Data операторе в %C"
+msgstr ""
 
-#: fortran/decl.c:619
+#: fortran/decl.c:620
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %C is not allowed in a PURE procedure"
 msgstr "DATA оператор в %C не допускается в PURE процедуре"
 
-#: fortran/decl.c:664
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Extension: Old-style initialization at %C"
+#: fortran/decl.c:662
+#, gcc-internal-format, gfc-internal-format
 msgid "Empty old style initializer list at %C"
-msgstr "Расширение: Старомодная инициализация в %C"
+msgstr "Пустой старомодный список инициализатора в %C"
 
-#: fortran/decl.c:684
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "extra elements in scalar initializer"
+#: fortran/decl.c:671
+#, gcc-internal-format, gfc-internal-format
+msgid "Array in initializer list at %L must have an explicit shape"
+msgstr ""
+
+#: fortran/decl.c:694
+#, gcc-internal-format, gfc-internal-format
 msgid "Repeat spec invalid in scalar initializer at %C"
-msgstr "избыточные элементы в скалярном инициализаторе"
+msgstr "Repeat spec некорректна в скалярном инициализаторе в %C"
 
-#: fortran/decl.c:689
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "selector must be an integer constant in the range 0..%wi"
+#: fortran/decl.c:699
+#, gcc-internal-format, gfc-internal-format
 msgid "Repeat spec must be an integer at %C"
-msgstr "селектор должен быть целой константой в диапазоне 0..%wi"
+msgstr "Repeat spec должна быть integer в %C"
 
-#: fortran/decl.c:698
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Expected alternate return label at %C"
+#: fortran/decl.c:710
+#, gcc-internal-format, gfc-internal-format
 msgid "Expected data constant after repeat spec at %C"
-msgstr "Ожидалась метка альтернативного возврата в %C"
+msgstr "Ожидалась константа данных после repeat spec в %C"
 
-#: fortran/decl.c:729
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Expected scalar initialization expression at %C"
+#: fortran/decl.c:742
+#, gcc-internal-format, gfc-internal-format
 msgid "End of scalar initializer expected at %C"
-msgstr "Ожидалось скалярное инициализационное выражение в %C"
+msgstr "Конец скалярного инициализатора ожидался в %C"
 
-#: fortran/decl.c:758
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "nonconstant array index in initializer"
-msgid "Expected constant array-spec in initializer list at %L"
-msgstr "неконстантный индекс массива в инициализаторе"
-
-#: fortran/decl.c:767
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "excess elements in array initializer"
+#: fortran/decl.c:773
+#, gcc-internal-format, gfc-internal-format
 msgid "Not enough elements in array initializer at %C"
-msgstr "избыточные элементы в инициализаторе массива"
+msgstr "Недостаточно элементов в инициализаторе массива в %C"
 
-#: fortran/decl.c:769
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "excess elements in array initializer"
+#: fortran/decl.c:775
+#, gcc-internal-format, gfc-internal-format
 msgid "Too many elements in array initializer at %C"
-msgstr "избыточные элементы в инициализаторе массива"
+msgstr "Слишком много элементов в инициализаторе массива в %C"
 
-#: fortran/decl.c:790
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Syntax error in OpenMP variable list at %C"
+#: fortran/decl.c:795
+#, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in old style initializer list at %C"
-msgstr "Синтаксическая ошибка в OpenMP списке переменных в %C"
+msgstr "Синтаксическая ошибка в старомодном списке инициализатора в %C"
 
-#: fortran/decl.c:812
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Data target at %L shall not have a coindex"
+#: fortran/decl.c:821
+#, gcc-internal-format, gfc-internal-format
 msgid "The assumed-rank array at %C shall not have a codimension"
-msgstr "Целевые данные в %L не должны иметь коиндекс"
+msgstr "Массив предполагаемой размерности в %C не должен иметь коизмерения"
 
-#: fortran/decl.c:876
+#: fortran/decl.c:885
 #, gcc-internal-format, gfc-internal-format
 msgid "Sum of array rank %d and corank %d at %C exceeds maximum allowed dimensions of %d"
 msgstr ""
 
-#: fortran/decl.c:900
+#: fortran/decl.c:909
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad INTENT specification at %C"
 msgstr "Некорректная INTENT спецификация в %C"
 
-#: fortran/decl.c:921
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2003: deferred type parameter at %C"
+#: fortran/decl.c:930
+#, gcc-internal-format, gfc-internal-format
 msgid "deferred type parameter at %C"
-msgstr "Fortran 2003: отложенный параметр типа в %C"
+msgstr "отложенный параметр типа в %C"
 
-#: fortran/decl.c:1004 fortran/resolve.c:11705
+#: fortran/decl.c:1013 fortran/resolve.c:11725
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
-msgstr ""
+msgstr "Скалярное INTEGER выражение ожидалось в %L"
 
-#: fortran/decl.c:1030
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Obsolescent feature: Old-style character length at %C"
+#: fortran/decl.c:1039
+#, gcc-internal-format, gfc-internal-format
 msgid "Old-style character length at %C"
-msgstr "Устаревшая возможность: Старый стиль длины строки в %C"
+msgstr "Старый стиль длины строки в %C"
 
-#: fortran/decl.c:1061
+#: fortran/decl.c:1070
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in character length specification at %C"
 msgstr "Синтаксическая ошибка в спецификации длины строки в %C"
 
-#: fortran/decl.c:1212 fortran/decl.c:1217 fortran/decl.c:1266
-#, fuzzy, gcc-internal-format
-#| msgid "Procedure '%s' at %C is already defined at %L"
+#: fortran/decl.c:1221 fortran/decl.c:1226 fortran/decl.c:1275
+#, gcc-internal-format
 msgid "Procedure %qs at %C is already defined at %L"
-msgstr "Процедура '%s' в %C уже определена в %L"
+msgstr "Процедура %qs в %C уже определена в %L"
 
-#: fortran/decl.c:1222
-#, fuzzy, gcc-internal-format
-#| msgid "Procedure '%s' at %C is already defined at %L"
+#: fortran/decl.c:1231
+#, gcc-internal-format
 msgid "Contained procedure %qs at %C clashes with procedure defined at %L"
-msgstr "Процедура '%s' в %C уже определена в %L"
+msgstr ""
 
-#: fortran/decl.c:1231
-#, fuzzy, gcc-internal-format
-#| msgid "Name '%s' at %C is already defined as a generic interface at %L"
+#: fortran/decl.c:1240
+#, gcc-internal-format
 msgid "Name %qs at %C is already defined as a generic interface at %L"
-msgstr "Имя '%s' в %C уже определено как обобщенный интерфейс в %L"
+msgstr "Имя %qs в %C уже определено как обобщенный интерфейс в %L"
 
-#: fortran/decl.c:1244
-#, fuzzy, gcc-internal-format
-#| msgid "Procedure '%s' at %C has an explicit interface and must not have attributes declared at %L"
+#: fortran/decl.c:1253
+#, gcc-internal-format
 msgid "Procedure %qs at %C has an explicit interface from a previous declaration"
-msgstr "Процедура '%s' в %C имеет явный интерфейс и не должна иметь атрибуты декларированные в %L"
+msgstr ""
 
-#: fortran/decl.c:1257
+#: fortran/decl.c:1266
 #, gcc-internal-format
 msgid "Procedure %qs defined in interface body at %L clashes with internal procedure defined at %C"
 msgstr ""
 
-#: fortran/decl.c:1335
-#, fuzzy, gcc-internal-format
-#| msgid "Procedure '%s' at %L must have the BIND(C) attribute to be C interoperable"
+#: fortran/decl.c:1344
+#, gcc-internal-format
 msgid "Procedure %qs at %L must have the BIND(C) attribute to be C interoperable"
-msgstr "Процедура '%s' в %L должна иметь BIND(C) атрибут чтобы быть C-совместимой"
+msgstr "Процедура %qs в %L должна иметь BIND(C) атрибут, чтобы быть C-совместимой"
 
-#: fortran/decl.c:1362
-#, fuzzy, gcc-internal-format
-#| msgid "Variable '%s' at %L is a dummy argument to the BIND(C) procedure '%s' but is not C interoperable because derived type '%s' is not C interoperable"
+#: fortran/decl.c:1371
+#, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because derived type %qs is not C interoperable"
-msgstr "Переменная '%s' в %L является формальным аргументом BIND(C) процедуры '%s' но не является C-совместимой поскольку производный тип '%s' не является C-совместимым"
+msgstr "Переменная %qs в %L является формальным аргументом BIND(C) процедуры %qs, но не является C-совместимой, поскольку производный тип %qs не является C-совместимым"
 
-#: fortran/decl.c:1369
-#, fuzzy, gcc-internal-format
-#| msgid "Variable '%s' at %L is a dummy argument to the BIND(C) procedure '%s' but is not C interoperable because it is polymorphic"
+#: fortran/decl.c:1378
+#, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because it is polymorphic"
-msgstr "Переменная '%s' в %L является формальным аргументом BIND(C) процедуры '%s' но не является C-совместимой поскольку та полиморфна"
+msgstr "Переменная %qs в %L является формальным аргументом BIND(C) процедуры %qs, но не является C-совместимой, поскольку та полиморфна"
 
-#: fortran/decl.c:1376
-#, fuzzy, gcc-internal-format
-#| msgid "Variable '%s' at %L is a parameter to the BIND(C) procedure '%s' but may not be C interoperable"
+#: fortran/decl.c:1385
+#, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument of the BIND(C) procedure %qs but may not be C interoperable"
-msgstr "Переменная '%s' в %L является параметром BIND(C) процедуры '%s' но может не быть C-совместимой"
+msgstr "Переменная %qs в %L является формальным аргументом BIND(C) процедуры %qs, но может не быть C-совместимой"
 
-#: fortran/decl.c:1391
-#, fuzzy, gcc-internal-format
-#| msgid "Character argument '%s' at %L must be length 1 because procedure '%s' is BIND(C)"
+#: fortran/decl.c:1400
+#, gcc-internal-format
 msgid "Character argument %qs at %L must be length 1 because procedure %qs is BIND(C)"
-msgstr "Character аргумент '%s' в %L должен быть длины 1 поскольку процедура '%s' является BIND(C)"
+msgstr "Character аргумент %qs в %L должен быть длины 1, поскольку процедура %qs является BIND(C)"
 
-#: fortran/decl.c:1404
-#, fuzzy, gcc-internal-format
-#| msgid "TS29113: Variable '%s' at %L with OPTIONAL attribute in procedure '%s' which is BIND(C)"
+#: fortran/decl.c:1413
+#, gcc-internal-format
 msgid "Variable %qs at %L with ALLOCATABLE attribute in procedure %qs with BIND(C)"
-msgstr "TS29113: Переменная '%s' в %L с OPTIONAL атрибутом в процедуре '%s' являющейся BIND(C)"
+msgstr "Переменная %qs в %L с ALLOCATABLE атрибутом в процедуре %qs с BIND(C)"
 
-#: fortran/decl.c:1412
-#, fuzzy, gcc-internal-format
-#| msgid "TS29113: Variable '%s' at %L with OPTIONAL attribute in procedure '%s' which is BIND(C)"
+#: fortran/decl.c:1421
+#, gcc-internal-format
 msgid "Variable %qs at %L with POINTER attribute in procedure %qs with BIND(C)"
-msgstr "TS29113: Переменная '%s' в %L с OPTIONAL атрибутом в процедуре '%s' являющейся BIND(C)"
+msgstr "Переменная %qs в %L с POINTER атрибутом в процедуре %qs с BIND(C)"
 
-#: fortran/decl.c:1421
+#: fortran/decl.c:1430
 #, gcc-internal-format
 msgid "Scalar variable %qs at %L with POINTER or ALLOCATABLE in procedure %qs with BIND(C) is not yet supported"
-msgstr ""
+msgstr "Скалярная переменная %qs в %L с POINTER или ALLOCATABLE в процедуре %qs с BIND(C) пока не поддерживается"
 
-#: fortran/decl.c:1430
-#, fuzzy, gcc-internal-format
-#| msgid "Variable '%s' at %L cannot have both the OPTIONAL and the VALUE attribute because procedure '%s' is BIND(C)"
+#: fortran/decl.c:1439
+#, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the OPTIONAL and the VALUE attribute because procedure %qs is BIND(C)"
-msgstr "Переменная '%s' в %L не может иметь оба атрибута OPTIONAL и VALUE поскольку процедура '%s' является BIND(C)"
+msgstr "Переменная %qs в %L не может иметь оба атрибута OPTIONAL и VALUE, поскольку процедура %qs является BIND(C)"
 
-#: fortran/decl.c:1437
-#, fuzzy, gcc-internal-format
-#| msgid "TS29113: Variable '%s' at %L with OPTIONAL attribute in procedure '%s' which is BIND(C)"
+#: fortran/decl.c:1446
+#, gcc-internal-format
 msgid "Variable %qs at %L with OPTIONAL attribute in procedure %qs which is BIND(C)"
-msgstr "TS29113: Переменная '%s' в %L с OPTIONAL атрибутом в процедуре '%s' являющейся BIND(C)"
+msgstr "Переменная %qs в %L с OPTIONAL атрибутом в процедуре %qs являющейся BIND(C)"
 
-#: fortran/decl.c:1448
-#, fuzzy, gcc-internal-format
-#| msgid "Assumed-shape array '%s' at %L cannot be an argument to the procedure '%s' at %L because the procedure is BIND(C)"
+#: fortran/decl.c:1457
+#, gcc-internal-format
 msgid "Assumed-shape array %qs at %L as dummy argument to the BIND(C) procedure %qs at %L"
-msgstr "Массив предполагаемого размера '%s' в %L не может быть аргументом процедуры '%s' в %L поскольку процедура является BIND(C)"
+msgstr "Массив предполагаемого размера %qs в %L как формальный аргумент в BIND(C) процедуре %qs в %L"
 
-#: fortran/decl.c:1516
-#, fuzzy, gcc-internal-format
-#| msgid "Symbol '%s' at %L already has basic type of %s"
+#: fortran/decl.c:1525
+#, gcc-internal-format
 msgid "Symbol %qs at %C also declared as a type at %L"
-msgstr "Символ '%s' в %L уже имеет базовый тип %s"
+msgstr "Символ %qs в %C декларирован так же, как тип в %L"
 
-#: fortran/decl.c:1575
-#, fuzzy, gcc-internal-format
-#| msgid "Variable '%s' in common block '%s' at %C must be declared with a C interoperable kind since common block '%s' is BIND(C)"
+#: fortran/decl.c:1584
+#, gcc-internal-format
 msgid "Variable %qs in common block %qs at %C must be declared with a C interoperable kind since common block %qs is BIND(C)"
-msgstr "Переменная '%s' в common блоке '%s' в %C должна быть декларирована с C совместимым видом поскольку common блок '%s' является BIND(C)"
+msgstr "Переменная %qs в common блоке %qs в %C должна быть декларирована с C совместимым видом, поскольку common блок %qs является BIND(C)"
 
-#: fortran/decl.c:1615
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Different CHARACTER lengths (%d/%d) in array constructor at %L"
+#: fortran/decl.c:1624
+#, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER length must be a constant at %L"
-msgstr "Разные CHARACTER длины (%d/%d) в конструкторе массива в %L"
+msgstr "CHARACTER длина должна быть константой в %L"
 
-#: fortran/decl.c:1630
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "CHARACTER expression at %L is being truncated (%d/%d)"
+#: fortran/decl.c:1639
+#, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression at %L is being truncated (%ld/%ld)"
-msgstr "CHARACTER выражение в %L усекается (%d/%d)"
+msgstr "CHARACTER выражение в %L усекается (%ld/%ld)"
 
-#: fortran/decl.c:1638
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "The CHARACTER elements of the array constructor at %L must have the same length (%d/%d)"
+#: fortran/decl.c:1647
+#, gcc-internal-format, gfc-internal-format
 msgid "The CHARACTER elements of the array constructor at %L must have the same length (%ld/%ld)"
-msgstr "CHARACTER элементы конструктора массива в %L должны иметь одинаковую длину (%d/%d)"
+msgstr "CHARACTER элементы конструктора массива в %L должны иметь одинаковую длину (%ld/%ld)"
 
-#: fortran/decl.c:1729
-#, fuzzy, gcc-internal-format
-#| msgid "Initializer not allowed for PARAMETER '%s' at %C"
+#: fortran/decl.c:1738
+#, gcc-internal-format
 msgid "Initializer not allowed for PARAMETER %qs at %C"
-msgstr "Инициализатор не допускается для PARAMETER '%s' в %C"
+msgstr "Инициализатор не допускается для PARAMETER %qs в %C"
 
-#: fortran/decl.c:1739
+#: fortran/decl.c:1748
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER at %L is missing an initializer"
 msgstr "PARAMETER в %L остался без инициализатора"
 
-#: fortran/decl.c:1749
-#, fuzzy, gcc-internal-format
-#| msgid "Variable '%s' at %C with an initializer already appears in a DATA statement"
+#: fortran/decl.c:1758
+#, gcc-internal-format
 msgid "Variable %qs at %C with an initializer already appears in a DATA statement"
-msgstr "Переменная '%s' в %C с инициализатором уже появлялась в DATA операторе"
+msgstr "Переменная %qs в %C с инициализатором уже появлялась в DATA операторе"
 
-#: fortran/decl.c:1792
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Can't initialize implied-shape array at %L with scalar"
+#: fortran/decl.c:1801
+#, gcc-internal-format, gfc-internal-format
 msgid "Cannot initialize parameter array at %L with variable length elements"
-msgstr "Невозможно инициализировать массив выводимой формы в %L с помощью скаляра"
+msgstr "Невозможно инициализировать parameter массив в %L с элементами переменной длины"
 
-#: fortran/decl.c:1861
+#: fortran/decl.c:1870
 #, gcc-internal-format, gfc-internal-format
 msgid "Can't initialize implied-shape array at %L with scalar"
 msgstr "Невозможно инициализировать массив выводимой формы в %L с помощью скаляра"
 
-#: fortran/decl.c:1896
+#: fortran/decl.c:1905
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-constant lower bound in implied-shape declaration at %L"
 msgstr "Неконстантная нижняя граница декларации выводимой формы в %L"
 
-#: fortran/decl.c:1982 fortran/decl.c:1989
+#: fortran/decl.c:1991 fortran/decl.c:1998
 #, gcc-internal-format, gfc-internal-format
 msgid "Component at %C must have the POINTER attribute"
 msgstr "Компонент в %C должен иметь атрибут POINTER"
 
-#: fortran/decl.c:1998
-#, fuzzy, gcc-internal-format
-#| msgid "Component '%s' with CLASS at %L must be allocatable or pointer"
+#: fortran/decl.c:2007
+#, gcc-internal-format
 msgid "Component %qs with CLASS at %C must be allocatable or pointer"
-msgstr "Компонент '%s' с CLASS в %L должен быть размещаемым или указателем"
+msgstr "Компонент %qs с CLASS в %C должен быть размещаемым или указателем"
 
-#: fortran/decl.c:2007
+#: fortran/decl.c:2016
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr "Компонент-массив структуры в %C должен иметь явную или отложенную форму"
 
-#: fortran/decl.c:2031 fortran/symbol.c:2230
-#, fuzzy, gcc-internal-format
-#| msgid "Component '%s' at %C already declared at %L"
+#: fortran/decl.c:2040 fortran/symbol.c:2244
+#, gcc-internal-format
 msgid "Component %qs at %C already declared at %L"
-msgstr "Компонент '%s' в %C уже декларирован в %L"
+msgstr "Компонент %qs в %C уже декларирован в %L"
 
-#: fortran/decl.c:2079
+#: fortran/decl.c:2088
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer array component of structure at %C must have a deferred shape"
 msgstr "Компонент-массив указателей структуры в %C должен иметь отложенную форму"
 
-#: fortran/decl.c:2088
+#: fortran/decl.c:2097
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component of structure at %C must have a deferred shape"
 msgstr "Размещаемый компонент структуры в %C должен иметь отложенную форму"
 
-#: fortran/decl.c:2097
+#: fortran/decl.c:2106
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have an explicit shape"
 msgstr "Компонент-массив структуры в %C должен иметь явную форму"
 
-#: fortran/decl.c:2114
-#, fuzzy, gcc-internal-format
-#| msgid "a parameter list with an ellipsis can%'t match an empty parameter name list declaration"
+#: fortran/decl.c:2123
+#, gcc-internal-format
 msgid "Type parameter %qs at %C has no corresponding entry in the type parameter name list at %L"
-msgstr "список параметров с многоточием несовместим с пустым списком параметров"
+msgstr ""
 
-#: fortran/decl.c:2171
+#: fortran/decl.c:2180
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C is ambiguous"
 msgstr "NULL() инициализация в %C неоднозначна"
 
-#: fortran/decl.c:2188
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "NULL() initialization at %C is ambiguous"
+#: fortran/decl.c:2197
+#, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C may not have MOLD"
-msgstr "NULL() инициализация в %C неоднозначна"
+msgstr "NULL() инициализация в %C не может иметь MOLD"
 
-#: fortran/decl.c:2205
+#: fortran/decl.c:2214
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of pointer at %C is not allowed in a PURE procedure"
 msgstr "Инициализация указателя в %C не допускается в PURE процедуре"
 
-#: fortran/decl.c:2226
+#: fortran/decl.c:2235
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in pointer initialization at %C"
 msgstr "Ошибка в инициализации указателя в %C"
 
-#: fortran/decl.c:2233
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2008: non-NULL pointer initialization at %C"
+#: fortran/decl.c:2242
+#, gcc-internal-format, gfc-internal-format
 msgid "non-NULL pointer initialization at %C"
-msgstr "Fortran 2008: не-NULL инициализация указателя в %C"
+msgstr "не-NULL инициализация указателя в %C"
 
-#: fortran/decl.c:2256
+#: fortran/decl.c:2265
 #, gcc-internal-format
 msgid "RESULT variable %qs at %L prohibits FUNCTION name %qs at %C from appearing in a specification statement"
 msgstr ""
 
-#: fortran/decl.c:2318
-#, fuzzy, gcc-internal-format
-#| msgid "VALUE is not allowed inside of BLOCK at %C"
+#: fortran/decl.c:2327
+#, gcc-internal-format
 msgid "%qs not allowed outside STRUCTURE at %C"
-msgstr "VALUE не допускается внутри BLOCK в %C"
+msgstr ""
 
-#: fortran/decl.c:2320
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' at %C is not a member of the '%s' structure"
+#: fortran/decl.c:2329
+#, gcc-internal-format
 msgid "%qs at %C is a DEC extension, enable with %<-fdec-structure%>"
-msgstr "'%s' в %C не является членом '%s' структуры"
+msgstr ""
 
-#: fortran/decl.c:2327
-#, fuzzy, gcc-internal-format
-#| msgid "%qs function cannot have arguments"
+#: fortran/decl.c:2336
+#, gcc-internal-format
 msgid "%qs entity cannot have attributes at %C"
-msgstr "%qs функция не может иметь аргументы"
+msgstr ""
 
-#: fortran/decl.c:2367
-#, fuzzy, gcc-internal-format
-#| msgid "Non-PARAMETER symbol '%s' at %L can't be implied-shape"
+#: fortran/decl.c:2376
+#, gcc-internal-format
 msgid "Non-PARAMETER symbol %qs at %L can't be implied-shape"
-msgstr "Не-PARAMETER символ '%s' в %L не может быть выводимой формы"
+msgstr "Не-PARAMETER символ %qs в %L не может быть выводимой формы"
 
-#: fortran/decl.c:2377
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2008: Implied-shape array at %L"
+#: fortran/decl.c:2386
+#, gcc-internal-format, gfc-internal-format
 msgid "Implied-shape array at %L"
-msgstr "Fortran 2008: Массив выводимой формы в %L"
+msgstr "Массив выводимой формы в %L"
 
-#: fortran/decl.c:2422
+#: fortran/decl.c:2431
 #, gcc-internal-format, gfc-internal-format
 msgid "Explicit shaped array with nonconstant bounds at %C"
 msgstr ""
 
-#: fortran/decl.c:2501
+#: fortran/decl.c:2510
 #, gcc-internal-format
 msgid "%qs at %C is a redefinition of the declaration in the corresponding interface for MODULE PROCEDURE %qs"
-msgstr ""
+msgstr "%qs в %C есть переопределение декларации в соответствующем интерфейсе для MODULE PROCEDURE %qs"
 
-#: fortran/decl.c:2512
-#, fuzzy, gcc-internal-format
-#| msgid "Dummy '%s' at %L cannot have an initializer"
+#: fortran/decl.c:2521
+#, gcc-internal-format
 msgid "%qs entity cannot have an initializer at %C"
-msgstr "Формальный параметр '%s' в %L не может иметь инициализатор"
+msgstr ""
 
-#: fortran/decl.c:2538 fortran/decl.c:8369
+#: fortran/decl.c:2547 fortran/decl.c:8388
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr "Повторная спецификация массива для Cray указателя в %C"
 
-#: fortran/decl.c:2546
+#: fortran/decl.c:2555
 #, gcc-internal-format
 msgid "Couldn't set pointee array spec."
-msgstr ""
+msgstr "Невозможно установить спецификацию указуемого массива"
 
-#: fortran/decl.c:2609
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Extension: Old-style initialization at %C"
+#: fortran/decl.c:2618
+#, gcc-internal-format, gfc-internal-format
 msgid "Old-style initialization at %C"
-msgstr "Расширение: Старомодная инициализация в %C"
+msgstr "Старомодная инициализация в %C"
 
-#: fortran/decl.c:2617
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "invalid value-initialization of reference type"
+#: fortran/decl.c:2626
+#, gcc-internal-format, gfc-internal-format
 msgid "Invalid old style initialization for derived type component at %C"
-msgstr "некорректная инициализация значения ссылочного типа"
+msgstr "некорректная старомодная инициализация для компонента производного типа в %C"
 
-#: fortran/decl.c:2630
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Error in pointer initialization at %C"
+#: fortran/decl.c:2639
+#, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in old style initialization of %s at %C"
-msgstr "Ошибка в инициализации указателя в %C"
+msgstr "Синтаксическая ошибка в старомодной инициализации %s в %C"
 
-#: fortran/decl.c:2650 fortran/decl.c:6661
+#: fortran/decl.c:2659 fortran/decl.c:6680
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr "Инициализация в %C не для указательной переменной"
 
-#: fortran/decl.c:2663
-#, fuzzy, gcc-internal-format
-#| msgid "Pointer initialization at %C requires '=>', not '='"
+#: fortran/decl.c:2672
+#, gcc-internal-format
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
-msgstr "Инициализация указателя в %C требует '=>', а не '='"
+msgstr "Инициализация указателя в %C требует %<=>%>, не %<=%>"
 
-#: fortran/decl.c:2672 fortran/decl.c:10240
+#: fortran/decl.c:2681 fortran/decl.c:10265
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr "Ожидалось инициализационное выражение в %C"
 
-#: fortran/decl.c:2679
+#: fortran/decl.c:2688
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr "Инициализация переменной в %C не допускается в PURE процедуре"
 
-#: fortran/decl.c:2696
+#: fortran/decl.c:2705
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr "Инициализация размещаемого компонента в %C не допускается"
 
-#: fortran/decl.c:2710
+#: fortran/decl.c:2719
 #, gcc-internal-format, gfc-internal-format
 msgid "The component with KIND or LEN attribute at %C does not not appear in the type parameter list at %L"
 msgstr ""
 
-#: fortran/decl.c:2718
+#: fortran/decl.c:2727
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C that appears in the type parameter list at %L has neither the KIND nor LEN attribute"
 msgstr ""
 
-#: fortran/decl.c:2726
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "The pointer component '%s' of '%s' at %L is a type that has not been declared"
+#: fortran/decl.c:2735
+#, gcc-internal-format, gfc-internal-format
 msgid "The component at %C which is a type parameter must be a scalar"
-msgstr "Компонент указатель '%s' от '%s' в %L есть тип который не был декларирован"
+msgstr ""
 
-#: fortran/decl.c:2789 fortran/decl.c:2825
+#: fortran/decl.c:2798 fortran/decl.c:2834
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr "Старомодная декларация типа %s*%d не поддерживается в %C"
 
-#: fortran/decl.c:2831
+#: fortran/decl.c:2840
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr "Нестандартная декларация типа %s*%d в %C"
 
-#: fortran/decl.c:2890 fortran/decl.c:2967
+#: fortran/decl.c:2899 fortran/decl.c:2976
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis at %C"
 msgstr "Отсутствует правая скобка в %C"
 
-#: fortran/decl.c:2903 fortran/decl.c:3038
+#: fortran/decl.c:2912 fortran/decl.c:3047
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr "Явное инициализационное выражение в %C"
 
-#: fortran/decl.c:2911 fortran/decl.c:3044
+#: fortran/decl.c:2920 fortran/decl.c:3053
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr "Ожидалось скалярное инициализационное выражение в %C"
 
-#: fortran/decl.c:2941 fortran/decl.c:3657
+#: fortran/decl.c:2950 fortran/decl.c:3676
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr "Вид %d не поддерживается для типа %s в %C"
 
-#: fortran/decl.c:2954
+#: fortran/decl.c:2963
 #, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
-msgstr "C вид параметра типа задан для типа %s но тип в %L есть %s"
+msgstr "C вид параметра типа задан для типа %s, но тип в %L есть %s"
 
-#: fortran/decl.c:2965
+#: fortran/decl.c:2974
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr "Отсутствует правая скобка или запятая в %C"
 
-#: fortran/decl.c:3070
+#: fortran/decl.c:3079
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr "Вид %d не поддерживается для CHARACTER в %C"
 
-#: fortran/decl.c:3202
+#: fortran/decl.c:3211
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr "Синтаксическая ошибка в CHARACTER декларации в %C"
 
-#: fortran/decl.c:3291
+#: fortran/decl.c:3310
 #, gcc-internal-format, gfc-internal-format
 msgid "RECORD at %C is an extension, enable it with -fdec-structure"
-msgstr ""
+msgstr "RECORD в %C является расширением, включите его посредством -fdec-structure"
 
-#: fortran/decl.c:3304
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Interface-name expected after '(' at %C"
+#: fortran/decl.c:3323
+#, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected after RECORD at %C"
-msgstr "Interface-name ожидалось после '(' в %C"
+msgstr "Имя структуры ожидалось после RECORD в %C"
 
-#: fortran/decl.c:3417
+#: fortran/decl.c:3436
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C cannot contain both ASSUMED and DEFERRED parameters"
 msgstr ""
 
-#: fortran/decl.c:3441
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Kind type parameter for entity at %L differs from the kind type parameter of the typespec"
+#: fortran/decl.c:3460
+#, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C does not contain enough parameter expressions"
-msgstr "Вид параметра типа для сущности в %L отличается от вида параметра типа из typespec"
+msgstr ""
 
-#: fortran/decl.c:3465
-#, fuzzy, gcc-internal-format
-#| msgid "the first parameter of %<operator new%> cannot have a default argument"
+#: fortran/decl.c:3484
+#, gcc-internal-format
 msgid "The derived parameter %qs at %C does not have a default value"
-msgstr "первый аргумент %<operator new%> не может иметь значение по умолчанию"
+msgstr ""
 
-#: fortran/decl.c:3497
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Expression at %L must be of INTEGER type, found %s"
+#: fortran/decl.c:3516
+#, gcc-internal-format, gfc-internal-format
 msgid "The parameter expression at %C must be of INTEGER type and not %s type"
-msgstr "Выражение в %L должно быть INTEGER типа, найдено %s"
+msgstr ""
 
-#: fortran/decl.c:3525
+#: fortran/decl.c:3544
 #, gcc-internal-format
 msgid "The KIND parameter %qs at %C cannot either be ASSUMED or DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:3532
-#, fuzzy, gcc-internal-format
-#| msgid "Array '%s' at %L is a variable, which does not reduce to a constant expression"
+#: fortran/decl.c:3551
+#, gcc-internal-format
 msgid "The value for the KIND parameter %qs at %C does not reduce to a constant expression"
-msgstr "Массив '%s' в %L является переменной, которая не сводится к константному выражению"
+msgstr ""
 
-#: fortran/decl.c:3547
+#: fortran/decl.c:3566
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C contains too many parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3556
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "reference to %qD is ambiguous"
+#: fortran/decl.c:3575
+#, gcc-internal-format, gfc-internal-format
 msgid "Parameterized derived type at %C is ambiguous"
-msgstr "ссылка на %qD противоречива"
+msgstr ""
 
-#: fortran/decl.c:3819
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Extension: BYTE type at %C"
+#: fortran/decl.c:3838
+#, gcc-internal-format, gfc-internal-format
 msgid "BYTE type at %C"
-msgstr "Расширение: BYTE тип в %C"
+msgstr "BYTE тип в %C"
 
-#: fortran/decl.c:3824
+#: fortran/decl.c:3843
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr "BYTE тип использованный в %C не доступен на целевой машине"
 
-#: fortran/decl.c:3846
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "By-value argument at %L is not allowed in this context"
+#: fortran/decl.c:3865
+#, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C is not allowed for components"
-msgstr "Аргумент по значению в %L не допускается в этом контексте"
+msgstr "Предполагаемый тип в %C не допускается для компонентов"
 
-#: fortran/decl.c:3849
+#: fortran/decl.c:3868
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
-msgstr ""
+msgstr "Предполагаемый тип в %C"
 
-#: fortran/decl.c:3872 fortran/decl.c:3903 fortran/decl.c:3932
-#: fortran/decl.c:4216
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2008: TYPE with intrinsic-type-spec at %C"
+#: fortran/decl.c:3891 fortran/decl.c:3922 fortran/decl.c:3951
+#: fortran/decl.c:4235
+#, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
-msgstr "Fortran 2008: TYPE с intrinsic-type-spec в %C"
+msgstr "TYPE с intrinsic-type-spec в %C"
 
-#: fortran/decl.c:3928
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Extension: DOUBLE COMPLEX at %C"
+#: fortran/decl.c:3947
+#, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
-msgstr "Расширение: DOUBLE COMPLEX в %C"
+msgstr "DOUBLE COMPLEX в %C"
 
-#: fortran/decl.c:3971 fortran/decl.c:4107 fortran/decl.c:4119
-#: fortran/decl.c:4133 fortran/decl.c:4611 fortran/decl.c:4619
-#, fuzzy, gcc-internal-format
-#| msgid "Type name '%s' at %C is ambiguous"
+#: fortran/decl.c:3990 fortran/decl.c:4126 fortran/decl.c:4138
+#: fortran/decl.c:4152 fortran/decl.c:4630 fortran/decl.c:4638
+#, gcc-internal-format
 msgid "Type name %qs at %C is ambiguous"
-msgstr "Имя типа '%s' в %C неоднозначно"
+msgstr "Имя типа %qs в %C неоднозначно"
 
-#: fortran/decl.c:4066
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2003: CLASS statement at %C"
+#: fortran/decl.c:4085
+#, gcc-internal-format, gfc-internal-format
 msgid "CLASS statement at %C"
-msgstr "Fortran 2003: CLASS оператор в %C"
+msgstr "CLASS оператор в %C"
 
-#: fortran/decl.c:4148
-#, fuzzy, gcc-internal-format
-#| msgid "Type name '%s' at %C conflicts with previously declared entity at %L, which has the same name"
+#: fortran/decl.c:4167
+#, gcc-internal-format
 msgid "Type name %qs at %C conflicts with previously declared entity at %L, which has the same name"
-msgstr "Имя типа '%s' в %C конфликтует с ранее декларированной сущностью в %L, которая имеет то же имя"
+msgstr "Имя типа %qs в %C конфликтует с ранее декларированной сущностью в %L, которая имеет то же имя"
 
-#: fortran/decl.c:4287
+#: fortran/decl.c:4306
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr "Повторный IMPLICIT NONE оператор в %C"
 
-#: fortran/decl.c:4296
+#: fortran/decl.c:4315
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
-msgstr ""
+msgstr "IMPORT NONE со списком спецификаций в %C"
 
-#: fortran/decl.c:4355
+#: fortran/decl.c:4374
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr "Отсутствует символьный диапазон в IMPLICIT в %C"
 
-#: fortran/decl.c:4401
+#: fortran/decl.c:4420
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr "Буквы должны быть в алфавитном порядке в IMPLICIT операторе в %C"
 
-#: fortran/decl.c:4454
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "SAVE statement at %C follows blanket SAVE statement"
+#: fortran/decl.c:4473
+#, gcc-internal-format, gfc-internal-format
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
-msgstr "SAVE оператор в %C следует за общим SAVE оператором"
+msgstr "IMPLICIT оператор в %C следует за IMPLICIT NONE (тип) оператором"
 
-#: fortran/decl.c:4464
+#: fortran/decl.c:4483
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr "Пустой IMPLICIT оператор в %C"
 
-#: fortran/decl.c:4570
+#: fortran/decl.c:4589
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr "IMPORT оператор в %C допустим только в INTERFACE теле"
 
-#: fortran/decl.c:4577
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "IMPORT statement at %C only permitted in an INTERFACE body"
+#: fortran/decl.c:4596
+#, gcc-internal-format, gfc-internal-format
 msgid "F2008: C1210 IMPORT statement at %C is not permitted in a module procedure interface body"
-msgstr "IMPORT оператор в %C допустим только в INTERFACE теле"
+msgstr "F2008: C1210 IMPORT оператор в %C не допускается в теле интерфейса процедуры модуля"
 
-#: fortran/decl.c:4582
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Empty IMPLICIT statement at %C"
+#: fortran/decl.c:4601
+#, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C"
-msgstr "Пустой IMPLICIT оператор в %C"
+msgstr "IMPORT оператор в %C"
 
-#: fortran/decl.c:4596
+#: fortran/decl.c:4615
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr "Ожидается список именованных сущностей в %C"
 
-#: fortran/decl.c:4625
-#, fuzzy, gcc-internal-format
-#| msgid "Cannot IMPORT '%s' from host scoping unit at %C - does not exist."
+#: fortran/decl.c:4644
+#, gcc-internal-format
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
-msgstr "Невозможно IMPORT '%s' из единицы компиляции уровня хоста в %C - не существует."
+msgstr "Невозможно IMPORT %qs из единицы компиляции уровня хоста в %C - не существует."
 
-#: fortran/decl.c:4632
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' is already IMPORTed from host scoping unit at %C."
+#: fortran/decl.c:4651
+#, gcc-internal-format
 msgid "%qs is already IMPORTed from host scoping unit at %C"
-msgstr "'%s' уже IMPORTed из единицы компиляции уровня хоста в %C."
+msgstr "%qs уже IMPORTed из единицы компиляции уровня хоста в %C."
 
-#: fortran/decl.c:4673
+#: fortran/decl.c:4692
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IMPORT statement at %C"
 msgstr "Синтаксическая ошибка в IMPORT операторе в %C"
 
-#: fortran/decl.c:5010
+#: fortran/decl.c:5029
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing codimension specification at %C"
 msgstr "Отсутствует спецификатор коизмерения в %C"
 
-#: fortran/decl.c:5012
+#: fortran/decl.c:5031
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr "Отсутствует спецификатор измерения в %C"
 
-#: fortran/decl.c:5107
+#: fortran/decl.c:5126
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr "Повторный %s атрибут в %L"
 
-#: fortran/decl.c:5124
+#: fortran/decl.c:5143
 #, gcc-internal-format
 msgid "%s at %L is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:5141
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2003: ALLOCATABLE attribute at %C in a TYPE definition"
+#: fortran/decl.c:5160
+#, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
-msgstr "Fortran 2003: ALLOCATABLE атрибут в %C в TYPE определении"
+msgstr "ALLOCATABLE атрибут в %C в TYPE определении"
 
-#: fortran/decl.c:5150
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2003: Attribute %s at %L in a TYPE definition"
+#: fortran/decl.c:5169
+#, gcc-internal-format, gfc-internal-format
 msgid "KIND attribute at %C in a TYPE definition"
-msgstr "Fortran 2003: Атрибут %s в %L в TYPE определении"
+msgstr ""
 
-#: fortran/decl.c:5158
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L must be INTEGER"
+#: fortran/decl.c:5177
+#, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be INTEGER"
-msgstr "'%s' аргумент '%s' встроенной функции в %L должен быть INTEGER"
+msgstr ""
 
-#: fortran/decl.c:5165
+#: fortran/decl.c:5184
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5174
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2003: ALLOCATABLE attribute at %C in a TYPE definition"
+#: fortran/decl.c:5193
+#, gcc-internal-format, gfc-internal-format
 msgid "LEN attribute at %C in a TYPE definition"
-msgstr "Fortran 2003: ALLOCATABLE атрибут в %C в TYPE определении"
+msgstr ""
 
-#: fortran/decl.c:5182
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "'%s' argument of '%s' intrinsic at %L must be INTEGER"
+#: fortran/decl.c:5201
+#, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be INTEGER"
-msgstr "'%s' аргумент '%s' встроенной функции в %L должен быть INTEGER"
+msgstr ""
 
-#: fortran/decl.c:5189
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Component '%s' with CLASS at %L must be allocatable or pointer"
+#: fortran/decl.c:5208
+#, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be default integer kind (%d)"
-msgstr "Компонент '%s' с CLASS в %L должен быть размещаемым или указателем"
+msgstr ""
 
-#: fortran/decl.c:5198
+#: fortran/decl.c:5217
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr "Атрибут в %L не допускается в TYPE определении"
 
-#: fortran/decl.c:5216
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2003: Attribute %s at %L in a TYPE definition"
+#: fortran/decl.c:5235
+#, gcc-internal-format, gfc-internal-format
 msgid "Attribute %s at %L in a TYPE definition"
-msgstr "Fortran 2003: Атрибут %s в %L в TYPE определении"
+msgstr "Атрибут %s в %L в TYPE определении"
 
-#: fortran/decl.c:5226
+#: fortran/decl.c:5245
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr "%s атрибут в %L не допускается вне спецификационной части модуля"
 
-#: fortran/decl.c:5236
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Attribute at %L is not allowed in a TYPE definition"
+#: fortran/decl.c:5255
+#, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed outside a TYPE definition"
-msgstr "Атрибут в %L не допускается в TYPE определении"
+msgstr ""
 
-#: fortran/decl.c:5249
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2003: ASYNCHRONOUS attribute at %C"
+#: fortran/decl.c:5268
+#, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
-msgstr "Fortran 2003: ASYNCHRONOUS атрибут в %C"
+msgstr "ASYNCHRONOUS атрибут в %C"
 
-#: fortran/decl.c:5260
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2008: CONTIGUOUS attribute at %C"
+#: fortran/decl.c:5279
+#, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
-msgstr "Fortran 2008: CONTIGUOUS атрибут в %C"
+msgstr "CONTIGUOUS атрибут в %C"
 
-#: fortran/decl.c:5315 fortran/decl.c:8673
+#: fortran/decl.c:5334 fortran/decl.c:8692
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr "PROTECTED в %C допускается только в спецификационной части модуля"
 
-#: fortran/decl.c:5321
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2003: PROTECTED attribute at %C"
+#: fortran/decl.c:5340
+#, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute at %C"
-msgstr "Fortran 2003: PROTECTED атрибут в %C"
+msgstr "PROTECTED атрибут в %C"
 
-#: fortran/decl.c:5355
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2003: VALUE attribute at %C"
+#: fortran/decl.c:5374
+#, gcc-internal-format, gfc-internal-format
 msgid "VALUE attribute at %C"
-msgstr "Fortran 2003: VALUE атрибут в %C"
+msgstr "VALUE атрибут в %C"
 
-#: fortran/decl.c:5362
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2003: VOLATILE attribute at %C"
+#: fortran/decl.c:5381
+#, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
-msgstr "Fortran 2003: VOLATILE атрибут в %C"
+msgstr "VOLATILE атрибут в %C"
 
-#: fortran/decl.c:5369
+#: fortran/decl.c:5388
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
-msgstr ""
+msgstr "match_attr_spec(): Некорректный атрибут"
 
-#: fortran/decl.c:5410
+#: fortran/decl.c:5429
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr "Несколько идентификаторов задано с одним NAME= спецификатором в %C"
 
-#: fortran/decl.c:5508
-#, fuzzy, gcc-internal-format
-#| msgid "Implicitly declared BIND(C) function '%s' at %L may not be C interoperable"
+#: fortran/decl.c:5527
+#, gcc-internal-format
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
-msgstr "Неявно декларированная BIND(C) функция '%s' в %L может не быть C совместимой"
+msgstr "Неявно декларированная BIND(C) функция %qs в %L может не быть C совместимой"
 
-#: fortran/decl.c:5530
-#, fuzzy, gcc-internal-format
-#| msgid "Variable '%s' in common block '%s' at %L may not be a C interoperable kind though common block '%s' is BIND(C)"
+#: fortran/decl.c:5549
+#, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
-msgstr "Переменная '%s' в common блоке '%s' в %L может не быть C совместимого вида хотя common блок '%s' есть BIND(C)"
+msgstr "Переменная %qs в common блоке %qs в %L может не быть C совместимого вида хотя common блок %qs есть BIND(C)"
 
-#: fortran/decl.c:5539
-#, fuzzy, gcc-internal-format
-#| msgid "Type declaration '%s' at %L is not C interoperable but it is BIND(C)"
+#: fortran/decl.c:5558
+#, gcc-internal-format
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
-msgstr "Декларация типа '%s' at %L не является C совместимой но входит в BIND(C)"
+msgstr "Декларация типа %qs at %L не является C совместимой, но является BIND(C)"
 
-#: fortran/decl.c:5543
-#, fuzzy, gcc-internal-format
-#| msgid "Variable '%s' at %L may not be a C interoperable kind but it is bind(c)"
+#: fortran/decl.c:5562
+#, gcc-internal-format
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
-msgstr "Переменная '%s' в %L может не быть C совместимого вида но входит в bind(c)"
+msgstr "Переменная %qs в %L может не быть C совместимого вида, но является BIND(C)"
 
-#: fortran/decl.c:5555
-#, fuzzy, gcc-internal-format
-#| msgid "Variable '%s' in common block '%s' at %L cannot be declared with BIND(C) since it is not a global"
+#: fortran/decl.c:5574
+#, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
-msgstr "Переменная '%s' в common блоке '%s' в %L не может быть декларирована с BIND(C) поскольку она не является глобальной"
+msgstr "Переменная %qs в common блоке %qs в %L не может быть декларирована с BIND(C), поскольку она не является глобальной"
 
-#: fortran/decl.c:5569
-#, fuzzy, gcc-internal-format
-#| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
+#: fortran/decl.c:5588
+#, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
-msgstr "Переменная '%s' в %L не может иметь оба атрибута POINTER и BIND(C)"
+msgstr "Переменная %qs в %L не может иметь оба атрибута POINTER и BIND(C)"
 
-#: fortran/decl.c:5577
-#, fuzzy, gcc-internal-format
-#| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
+#: fortran/decl.c:5596
+#, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
-msgstr "Переменная '%s' в %L не может иметь оба атрибута ALLOCATABLE и BIND(C)"
+msgstr "Переменная %qs в %L не может иметь оба атрибута ALLOCATABLE и BIND(C)"
 
-#: fortran/decl.c:5589
-#, fuzzy, gcc-internal-format
-#| msgid "Return type of BIND(C) function '%s' at %L cannot be an array"
+#: fortran/decl.c:5608
+#, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
-msgstr "Возвращаемый тип BIND(C) функции '%s' в %L не может быть массивом"
+msgstr "Возвращаемый тип BIND(C) функции %qs в %L не может быть массивом"
 
-#: fortran/decl.c:5597
-#, fuzzy, gcc-internal-format
-#| msgid "Return type of BIND(C) function '%s' at %L cannot be a character string"
+#: fortran/decl.c:5616
+#, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be a character string"
-msgstr "Возвращаемый тип BIND(C) функции '%s' в %L не может быть character строкой"
+msgstr "Возвращаемый тип BIND(C) функции %qs в %L не может быть character строкой"
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:5608
-#, fuzzy, gcc-internal-format
-#| msgid "Symbol '%s' at %L is marked PRIVATE but has been given the binding label '%s'"
+#: fortran/decl.c:5627
+#, gcc-internal-format
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
-msgstr "Символ '%s' в %L помечен как PRIVATE но получил связывающую метку '%s'"
+msgstr "Символ %qs в %L помечен как PRIVATE, но получил связывающую метку %qs"
 
-#: fortran/decl.c:5682
+#: fortran/decl.c:5701
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr "Требуется имя либо сущности либо common блока для оператора спецификации атрибутов в %C"
 
-#: fortran/decl.c:5727
+#: fortran/decl.c:5746
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr "Отсутствует имя сущности или common блока для оператора спецификации атрибутов в %C"
 
-#: fortran/decl.c:5734
-#, fuzzy, gcc-internal-format
-#| msgid "missing number"
+#: fortran/decl.c:5753
+#, gcc-internal-format
 msgid "Missing symbol"
-msgstr "отсутствует число"
+msgstr "Отсутствует символ"
 
-#: fortran/decl.c:5763
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Empty IMPLICIT statement at %C"
+#: fortran/decl.c:5782
+#, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) statement at %C"
-msgstr "Пустой IMPLICIT оператор в %C"
+msgstr "BIND(C) оператор в %C"
 
-#: fortran/decl.c:5850
+#: fortran/decl.c:5869
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr "Производный тип в %C не был ранее определен и поэтому не может появляться в определении производного типа"
 
-#: fortran/decl.c:5892
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Syntax error in data declaration at %C"
+#: fortran/decl.c:5911
+#, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in anonymous structure declaration at %C"
-msgstr "Синтаксическая ошибка в декларации данных в %C"
+msgstr "Синтаксическая ошибка в декларации анонимной структуры в %C"
 
-#: fortran/decl.c:5901
+#: fortran/decl.c:5920
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr "Синтаксическая ошибка в декларации данных в %C"
 
-#: fortran/decl.c:5951
+#: fortran/decl.c:5970
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C"
-msgstr ""
+msgstr "MODULE префикс в %C"
 
-#: fortran/decl.c:5996
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2008: IMPURE procedure at %C"
+#: fortran/decl.c:6015
+#, gcc-internal-format, gfc-internal-format
 msgid "IMPURE procedure at %C"
-msgstr "Fortran 2008: IMPURE процедура в %C"
+msgstr "IMPURE процедура в %C"
 
-#: fortran/decl.c:6008
+#: fortran/decl.c:6027
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr "PURE и IMPURE не должны оба появляться в %C"
 
-#: fortran/decl.c:6054
+#: fortran/decl.c:6073
 #, gcc-internal-format, gfc-internal-format
 msgid "ELEMENTAL prefix in MODULE PROCEDURE interface is missing at %L"
-msgstr ""
+msgstr "ELEMENTAL префикс в MODULE интерфейсе отсутствует в %L"
 
-#: fortran/decl.c:6061
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2008: double colon in MODULE PROCEDURE statement at %L"
+#: fortran/decl.c:6080
+#, gcc-internal-format, gfc-internal-format
 msgid "PURE prefix in MODULE PROCEDURE interface is missing at %L"
-msgstr "Fortran 2008: двойное двоеточие в MODULE PROCEDURE операторе в %L"
+msgstr "PURE префикс в MODULE PROCEDURE интерфейсе отсутствует в %L"
 
-#: fortran/decl.c:6068
+#: fortran/decl.c:6087
 #, gcc-internal-format, gfc-internal-format
 msgid "RECURSIVE prefix in MODULE PROCEDURE interface is missing at %L"
-msgstr ""
+msgstr "RECURSIVE префикс в MODULE PROCEDURE интерфейсе отсутствует в %L"
 
-#: fortran/decl.c:6134 fortran/primary.c:1820
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Expected alternate return label at %C"
+#: fortran/decl.c:6153 fortran/primary.c:1820
+#, gcc-internal-format, gfc-internal-format
 msgid "Alternate-return argument at %C"
-msgstr "Ожидалась метка альтернативного возврата в %C"
+msgstr "Аргумент альтернативного возврата в %C"
 
-#: fortran/decl.c:6140 fortran/decl.c:6148
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Left parenthesis required after '*'"
+#: fortran/decl.c:6159 fortran/decl.c:6167
+#, gcc-internal-format, gfc-internal-format
 msgid "A parameter name is required at %C"
-msgstr "Левая скобка требуется после '*'"
+msgstr ""
 
-#: fortran/decl.c:6188
-#, fuzzy, gcc-internal-format
-#| msgid "Name '%s' at %C is the name of the procedure"
+#: fortran/decl.c:6207
+#, gcc-internal-format
 msgid "Name %qs at %C is the name of the procedure"
-msgstr "Имя '%s' в %C есть имя процедуры"
+msgstr "Имя %qs в %C есть имя процедуры"
 
-#: fortran/decl.c:6201
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Expected another dimension in array declaration at %C"
+#: fortran/decl.c:6220
+#, gcc-internal-format, gfc-internal-format
 msgid "Expected parameter list in type declaration at %C"
-msgstr "Ожидается другая размерность массива в определении %C"
+msgstr ""
 
-#: fortran/decl.c:6204
+#: fortran/decl.c:6223
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr "Неожиданный мусор в списке формальных аргументов в %C"
 
-#: fortran/decl.c:6222
-#, fuzzy, gcc-internal-format
-#| msgid "Duplicate name '%s' in association at %C"
+#: fortran/decl.c:6241
+#, gcc-internal-format
 msgid "Duplicate name %qs in parameter list at %C"
-msgstr "Повторение имени '%s' в ассоциации в %C"
+msgstr ""
 
-#: fortran/decl.c:6225
-#, fuzzy, gcc-internal-format
-#| msgid "Duplicate symbol '%s' in formal argument list at %C"
+#: fortran/decl.c:6244
+#, gcc-internal-format
 msgid "Duplicate symbol %qs in formal argument list at %C"
-msgstr "Повторяющийся символ '%s' в списке формальных аргументов в %C"
+msgstr "Повторяющийся символ %qs в списке формальных аргументов в %C"
 
-#: fortran/decl.c:6264
+#: fortran/decl.c:6283
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in MODULE PROCEDURE formal argument names (%s/%s) at %C"
-msgstr ""
+msgstr "Несоответствие в MODULE PROCEDURE именах формальных аргументов (%s/%s) в %C"
 
-#: fortran/decl.c:6270
+#: fortran/decl.c:6289
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in number of MODULE PROCEDURE formal arguments at %C"
-msgstr ""
+msgstr "Несоответствие в числе MODULE PROCEDURE формальных аргументов в %C"
 
-#: fortran/decl.c:6309
+#: fortran/decl.c:6328
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr "RESULT переменная в %C должна отличаться от имени функции"
 
-#: fortran/decl.c:6386
+#: fortran/decl.c:6405
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr "Неожиданный мусор после декларации функции в %C"
 
-#: fortran/decl.c:6396 fortran/decl.c:7494
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2008: BIND(C) attribute at %L may not be specified for an internal procedure"
+#: fortran/decl.c:6415 fortran/decl.c:7513
+#, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
-msgstr "Fortran 2008: BIND(C) атрибут в %L не может быть специфицирован для внутренней процедуры"
+msgstr "BIND(C) атрибут в %L не может быть специфицирован для внутренней процедуры"
 
-#: fortran/decl.c:6600
+#: fortran/decl.c:6619
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr "BIND(C) атрибут в %C требует интерфейс с BIND(C)"
 
-#: fortran/decl.c:6607
+#: fortran/decl.c:6626
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr "BIND(C) процедура с NAME не может иметь POINTER атрибут в %C"
 
-#: fortran/decl.c:6613
+#: fortran/decl.c:6632
 #, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr "Формальным процедура в %C не может иметь BIND(C) атрибут с NAME"
 
-#: fortran/decl.c:6636
-#, fuzzy, gcc-internal-format
-#| msgid "Procedure '%s' at %L already has basic type of %s"
+#: fortran/decl.c:6655
+#, gcc-internal-format
 msgid "Procedure %qs at %L already has basic type of %s"
-msgstr "Процедура '%s' в %L уже имеет базовый тип %s"
+msgstr "Процедура %qs в %L уже имеет базовый тип %s"
 
-#: fortran/decl.c:6682 fortran/decl.c:6870 fortran/decl.c:10723
+#: fortran/decl.c:6701 fortran/decl.c:6889 fortran/decl.c:10748
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr "Синтаксическая ошибка в операторе PROCEDURE в %C"
 
-#: fortran/decl.c:6731 fortran/decl.c:10623
-#, fuzzy, gcc-internal-format
-#| msgid "Expected '::' after binding-attributes at %C"
+#: fortran/decl.c:6750 fortran/decl.c:10648
+#, gcc-internal-format
 msgid "Expected %<::%> after binding-attributes at %C"
-msgstr "Ожидалось '::' после атрибутов связывания в %C"
+msgstr "Ожидалось %<::%> после атрибутов связывания в %C"
 
-#: fortran/decl.c:6738
+#: fortran/decl.c:6757
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr "NOPASS или явный интерфейс требуются в %C"
 
-#: fortran/decl.c:6742
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2003: Procedure pointer component at %C"
+#: fortran/decl.c:6761
+#, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component at %C"
-msgstr "Fortran 2003: Компонент указателя на процедуру в %C"
+msgstr "Компонент указатель на процедуру в %C"
 
-#: fortran/decl.c:6814
+#: fortran/decl.c:6833
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in procedure pointer component at %C"
 msgstr "Синтаксическая ошибка в компоненте указателя на процедуру в %C"
 
-#: fortran/decl.c:6832
+#: fortran/decl.c:6851
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr "PROCEDURE в %C должна быть в generic интерфейсе"
 
-#: fortran/decl.c:6841 fortran/decl.c:9392
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2008: double colon in MODULE PROCEDURE statement at %L"
+#: fortran/decl.c:6860 fortran/decl.c:9411
+#, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
-msgstr "Fortran 2008: двойное двоеточие в MODULE PROCEDURE операторе в %L"
+msgstr "двойное двоеточие в MODULE PROCEDURE операторе в %L"
 
-#: fortran/decl.c:6911
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2003: PROCEDURE statement at %C"
+#: fortran/decl.c:6930
+#, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE statement at %C"
-msgstr "Fortran 2003: PROCEDURE оператор в %C"
+msgstr "PROCEDURE оператор в %C"
 
-#: fortran/decl.c:6983
+#: fortran/decl.c:7002
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr "Ожидался список формальный аргументов в определении функции в %C"
 
-#: fortran/decl.c:7007 fortran/decl.c:7011 fortran/decl.c:7266
-#: fortran/decl.c:7270 fortran/decl.c:7462 fortran/decl.c:7466
-#: fortran/symbol.c:1875
+#: fortran/decl.c:7026 fortran/decl.c:7030 fortran/decl.c:7285
+#: fortran/decl.c:7289 fortran/decl.c:7481 fortran/decl.c:7485
+#: fortran/symbol.c:1889
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr "BIND(C) атрибут в %L может использоваться только для переменных или common блоков"
 
-#: fortran/decl.c:7164
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Empty IMPLICIT statement at %C"
+#: fortran/decl.c:7183
+#, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C"
-msgstr "Пустой IMPLICIT оператор в %C"
+msgstr "ENTRY оператор в %C"
 
-#: fortran/decl.c:7173
+#: fortran/decl.c:7192
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr "ENTRY оператор в %C не может появляться внутри PROGRAM"
 
-#: fortran/decl.c:7176
+#: fortran/decl.c:7195
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr "ENTRY оператор в %C не может появляться внутри MODULE"
 
-#: fortran/decl.c:7179
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "ENTRY statement at %C cannot appear within a MODULE"
+#: fortran/decl.c:7198
+#, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SUBMODULE"
-msgstr "ENTRY оператор в %C не может появляться внутри MODULE"
+msgstr "ENTRY оператор в %C не может появляться внутри SUBMODULE"
 
-#: fortran/decl.c:7182
+#: fortran/decl.c:7201
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr "ENTRY оператор в %C не может появляться внутри BLOCK DATA"
 
-#: fortran/decl.c:7186 fortran/decl.c:7231
+#: fortran/decl.c:7205 fortran/decl.c:7250
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr "ENTRY оператор в %C не может появляться внутри INTERFACE"
 
-#: fortran/decl.c:7190
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "ENTRY statement at %C cannot appear within a SELECT block"
+#: fortran/decl.c:7209
+#, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a STRUCTURE block"
-msgstr "ENTRY оператор в %C не может появляться внутри SELECT блока"
+msgstr "ENTRY оператор в %C не может появляться внутри STRUCTURE блока"
 
-#: fortran/decl.c:7194
+#: fortran/decl.c:7213
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr "ENTRY оператор в %C не может появляться внутри DERIVED TYPE блока"
 
-#: fortran/decl.c:7198
+#: fortran/decl.c:7217
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr "ENTRY оператор в %C не может появляться внутри IF-THEN блока"
 
-#: fortran/decl.c:7203
+#: fortran/decl.c:7222
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr "ENTRY оператор в %C не может появляться внутри DO блока"
 
-#: fortran/decl.c:7207
+#: fortran/decl.c:7226
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr "ENTRY оператор в %C не может появляться внутри SELECT блока"
 
-#: fortran/decl.c:7211
+#: fortran/decl.c:7230
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr "ENTRY оператор в %C не может появляться внутри FORALL блока"
 
-#: fortran/decl.c:7215
+#: fortran/decl.c:7234
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr "ENTRY оператор в %C не может появляться внутри WHERE блока"
 
-#: fortran/decl.c:7219
+#: fortran/decl.c:7238
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr "ENTRY оператор в %C не может появляться внутри внутренней подпрограммы"
 
-#: fortran/decl.c:7223
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Unexpected END statement at %C"
+#: fortran/decl.c:7242
+#, gcc-internal-format, gfc-internal-format
 msgid "Unexpected ENTRY statement at %C"
-msgstr "Неожиданный END оператор в %C"
+msgstr "Неожиданный ENTRY оператор в %C"
 
-#: fortran/decl.c:7244
+#: fortran/decl.c:7263
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr "ENTRY оператор в %C не может появляться внутри внутренней процедуры"
 
-#: fortran/decl.c:7295 fortran/decl.c:7501
+#: fortran/decl.c:7314 fortran/decl.c:7520
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr "Отсутствуют обязательные скобки перед BIND(C) в %C"
 
-#: fortran/decl.c:7563 fortran/decl.c:7570
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Invalid C name in NAME= specifier at %C"
+#: fortran/decl.c:7582 fortran/decl.c:7589
+#, gcc-internal-format, gfc-internal-format
 msgid "Invalid C identifier in NAME= specifier at %C"
-msgstr "Некорректное C имя в NAME= спецификаторе в %C"
+msgstr "Некорректный C идентификатор в NAME= спецификаторе в %C"
 
-#: fortran/decl.c:7610
+#: fortran/decl.c:7629
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr "Синтаксическая ошибка в NAME= спецификаторе для связывающей метки в %C"
 
-#: fortran/decl.c:7626
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "ASYNCHRONOUS= specifier at %L must be an initialization expression"
+#: fortran/decl.c:7645
+#, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a constant expression"
-msgstr "ASYNCHRONOUS= спецификатор в %L должен быть инициализационным выражением"
+msgstr "NAME= спецификатор в %C должен быть константным выражением"
 
-#: fortran/decl.c:7634
+#: fortran/decl.c:7653
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
-msgstr ""
+msgstr "NAME= спецификатор в %C должен быть скаляром подразумеваемого character вида"
 
-#: fortran/decl.c:7653
+#: fortran/decl.c:7672
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing closing paren for binding label at %C"
 msgstr "Отсутствует закрывающая скобка для связывающей метки в %C"
 
-#: fortran/decl.c:7659
+#: fortran/decl.c:7678
 #, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr "Связывающее имя не допускается в BIND(C) в %C"
 
-#: fortran/decl.c:7665
+#: fortran/decl.c:7684
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr "Для формальной процедуры %s связывающее имя не допускается в BIND(C) в %C"
 
-#: fortran/decl.c:7694
+#: fortran/decl.c:7713
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr "NAME не допускается в BIND(C) для ABSTRACT INTERFACE в %C"
 
-#: fortran/decl.c:7939
+#: fortran/decl.c:7958
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr "Неожиданный END оператор в %C"
 
-#: fortran/decl.c:7948
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2008: END statement instead of %s statement at %L"
+#: fortran/decl.c:7967
+#, gcc-internal-format, gfc-internal-format
 msgid "END statement instead of %s statement at %L"
-msgstr "Fortran 2008: END оператор вместо %s оператора в %L"
+msgstr "END оператор вместо %s оператора в %L"
 
 #. We would have required END [something].
-#: fortran/decl.c:7957
+#: fortran/decl.c:7976
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr "%s оператор ожидался в %L"
 
-#: fortran/decl.c:7968
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Expecting %s statement at %C"
+#: fortran/decl.c:7987
+#, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s statement at %L"
-msgstr "Ожидается %s оператор в %C"
+msgstr "Ожидается %s оператор в %L"
 
-#: fortran/decl.c:7988
-#, fuzzy, gcc-internal-format
-#| msgid "Expected block name of '%s' in %s statement at %C"
+#: fortran/decl.c:8007
+#, gcc-internal-format
 msgid "Expected block name of %qs in %s statement at %L"
-msgstr "Ожидалось имя блока от '%s' в %s операторе в %C"
+msgstr "Ожидалось имя блока от %qs в %s операторе в %L"
 
-#: fortran/decl.c:8005
+#: fortran/decl.c:8024
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr "Ожидалось завершающее имя в %C"
 
-#: fortran/decl.c:8019 fortran/decl.c:8027
-#, fuzzy, gcc-internal-format
-#| msgid "Expected label '%s' for %s statement at %C"
+#: fortran/decl.c:8038 fortran/decl.c:8046
+#, gcc-internal-format
 msgid "Expected label %qs for %s statement at %C"
-msgstr "Ожидалась метка '%s' для %s оператора в %C"
+msgstr "Ожидалась метка %qs для %s оператора в %C"
 
-#: fortran/decl.c:8126
+#: fortran/decl.c:8145
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr "Отсутствует спецификация массива в %L в DIMENSION операторе"
 
-#: fortran/decl.c:8134
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Dimensions specified for %s at %L after its initialisation"
+#: fortran/decl.c:8153
+#, gcc-internal-format, gfc-internal-format
 msgid "Dimensions specified for %s at %L after its initialization"
-msgstr "Измерение специфицировано для %s в %L после его инициализации"
+msgstr "Измерения специфицированы для %s в %L после его инициализации"
 
-#: fortran/decl.c:8142
+#: fortran/decl.c:8161
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr "Отсутствует спецификация массива в %L в CODIMENSION операторе"
 
-#: fortran/decl.c:8151
+#: fortran/decl.c:8170
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr "Спецификация массива должна быть отложенной в %L"
 
-#: fortran/decl.c:8249
+#: fortran/decl.c:8268
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr "Неожиданный символ в списке переменных в %C"
 
-#: fortran/decl.c:8286
-#, fuzzy, gcc-internal-format
-#| msgid "Expected '(' at %C"
+#: fortran/decl.c:8305
+#, gcc-internal-format
 msgid "Expected %<(%> at %C"
-msgstr "Ожидалась '(' в %C"
+msgstr "Ожидалась %<(%> в %C"
 
-#: fortran/decl.c:8300 fortran/decl.c:8340
+#: fortran/decl.c:8319 fortran/decl.c:8359
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr "Ожидалось имя переменной в %C"
 
-#: fortran/decl.c:8316
+#: fortran/decl.c:8335
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C must be an integer"
 msgstr "Cray указатель в %C должен быть целым"
 
-#: fortran/decl.c:8320
+#: fortran/decl.c:8339
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr "Cray указатель в %C имеет %d байт точности; адреса памяти требуют %d байт"
 
-#: fortran/decl.c:8326
+#: fortran/decl.c:8345
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr "Ожидалась \",\" в %C"
 
-#: fortran/decl.c:8365
+#: fortran/decl.c:8384
 #, gcc-internal-format
 msgid "Couldn't set Cray pointee array spec."
-msgstr ""
+msgstr "Невозможно установить Cray спецификацию указуемого массива"
 
-#: fortran/decl.c:8389
+#: fortran/decl.c:8408
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr "Ожидалась \")\" в %C"
 
-#: fortran/decl.c:8401
-#, fuzzy, gcc-internal-format
-#| msgid "Expected \",\" or end of statement at %C"
+#: fortran/decl.c:8420
+#, gcc-internal-format
 msgid "Expected %<,%> or end of statement at %C"
-msgstr "Ожидалась \",\" или окончание оператора в %C"
+msgstr "Ожидалась %<,%> или окончание оператора в %C"
 
-#: fortran/decl.c:8427
+#: fortran/decl.c:8446
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr "INTENT не допускается внутри BLOCK в %C"
 
-#: fortran/decl.c:8459
+#: fortran/decl.c:8478
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr "OPTIONAL не допускается внутри BLOCK в %C"
 
-#: fortran/decl.c:8478
+#: fortran/decl.c:8497
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer declaration at %C requires -fcray-pointer flag"
 msgstr "Декларация Cray указателя в %C требует -fcray-pointer флаг"
 
-#: fortran/decl.c:8517
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2008: CONTIGUOUS statement at %C"
+#: fortran/decl.c:8536
+#, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS statement at %C"
-msgstr "Fortran 2008: CONTIGUOUS оператор в %C"
+msgstr "CONTIGUOUS оператор в %C"
 
-#: fortran/decl.c:8623
+#: fortran/decl.c:8642
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr "Спецификация доступа %s оператора в %C уже была специфицирована"
 
-#: fortran/decl.c:8640
+#: fortran/decl.c:8659
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
-msgstr "Спецификация доступа .%s. оператора в %C уже была специфицирована"
+msgstr ""
 
-#: fortran/decl.c:8679
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2003: PROTECTED statement at %C"
+#: fortran/decl.c:8698
+#, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED statement at %C"
-msgstr "Fortran 2003: PROTECTED оператор в %C"
+msgstr "PROTECTED оператор в %C"
 
-#: fortran/decl.c:8717
+#: fortran/decl.c:8736
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr "Синтаксическая ошибка в PROTECTED операторе в %C"
 
-#: fortran/decl.c:8741
+#: fortran/decl.c:8760
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr "PRIVATE оператор в %C допустим только в спецификационной части модуля"
 
-#: fortran/decl.c:8778
+#: fortran/decl.c:8797
 #, gcc-internal-format, gfc-internal-format
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr "PUBLIC оператор в %C допустим только в спецификационной части модуля"
 
-#: fortran/decl.c:8806
+#: fortran/decl.c:8825
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr "Ожидалось имя переменной в %C в PARAMETER операторе"
 
-#: fortran/decl.c:8813
+#: fortran/decl.c:8832
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr "Ожидался = знак в PARAMETER операторе в %C"
 
-#: fortran/decl.c:8819
+#: fortran/decl.c:8838
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr "Ожидалось выражение в %C в PARAMETER операторе"
 
-#: fortran/decl.c:8839
+#: fortran/decl.c:8858
 #, gcc-internal-format, gfc-internal-format
 msgid "Initializing already initialized variable at %C"
 msgstr "Инициализация уже инициализированной переменной в %C"
 
 #. With legacy PARAMETER statements, don't expect a terminating ')'.
-#: fortran/decl.c:8864
+#: fortran/decl.c:8883
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER without '()' at %C"
-msgstr ""
+msgstr "PARAMETER без '()' в %C"
 
-#: fortran/decl.c:8880
+#: fortran/decl.c:8899
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr "Неожиданные символы в PARAMETER операторе в %C"
 
-#: fortran/decl.c:8899 fortran/decl.c:8955
+#: fortran/decl.c:8918 fortran/decl.c:8974
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:8934
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Expected variable in READ statement at %C"
+#: fortran/decl.c:8953
+#, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in AUTOMATIC statement at %C"
-msgstr "Ожидалась переменная в READ операторе в %C"
+msgstr "Ожидался список сущностей в AUTOMATIC операторе в %C"
 
-#: fortran/decl.c:8941
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Syntax error in VOLATILE statement at %C"
+#: fortran/decl.c:8960
+#, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in AUTOMATIC statement at %C"
-msgstr "Синтаксическая ошибка в VOLATILE операторе в %C"
+msgstr "Синтаксическая ошибка в AUTOMATIC операторе в %C"
 
-#: fortran/decl.c:8990
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Expected variable in READ statement at %C"
+#: fortran/decl.c:9009
+#, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in STATIC statement at %C"
-msgstr "Ожидалась переменная в READ операторе в %C"
+msgstr "Ожидался список сущностей в STATIC операторе в %C"
 
-#: fortran/decl.c:8997
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Syntax error in SAVE statement at %C"
+#: fortran/decl.c:9016
+#, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in STATIC statement at %C"
-msgstr "Синтаксическая ошибка в SAVE операторе в %C"
+msgstr "Синтаксическая ошибка в STATIC операторе в %C"
 
-#: fortran/decl.c:9016
+#: fortran/decl.c:9035
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr "Общий SAVE оператор в %C следует за предыдущим SAVE оператором"
 
-#: fortran/decl.c:9027
+#: fortran/decl.c:9046
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr "SAVE оператор в %C следует за общим SAVE оператором"
 
-#: fortran/decl.c:9073
+#: fortran/decl.c:9092
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr "Синтаксическая ошибка в SAVE операторе в %C"
 
-#: fortran/decl.c:9087
+#: fortran/decl.c:9106
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr "VALUE не допускается внутри BLOCK в %C"
 
-#: fortran/decl.c:9091
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2003: VALUE statement at %C"
+#: fortran/decl.c:9110
+#, gcc-internal-format, gfc-internal-format
 msgid "VALUE statement at %C"
-msgstr "Fortran 2003: VALUE оператор в %C"
+msgstr "VALUE оператор в %C"
 
-#: fortran/decl.c:9129
+#: fortran/decl.c:9148
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VALUE statement at %C"
 msgstr "Синтаксическая ошибка в VALUE операторе в %C"
 
-#: fortran/decl.c:9141
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2003: VOLATILE statement at %C"
+#: fortran/decl.c:9160
+#, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE statement at %C"
-msgstr "Fortran 2003: VOLATILE оператор в %C"
+msgstr "VOLATILE оператор в %C"
 
-#: fortran/decl.c:9168
-#, fuzzy, gcc-internal-format
-#| msgid "Specifying VOLATILE for coarray variable '%s' at %C, which is use-/host-associated"
+#: fortran/decl.c:9187
+#, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
-msgstr "Указание VOLATILE для комассивной переменной '%s' в %C, которая является use-/host-associated"
+msgstr "Задание VOLATILE для комассивной переменной %qs в %C, которая является use-/host-associated"
 
-#: fortran/decl.c:9193
+#: fortran/decl.c:9212
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr "Синтаксическая ошибка в VOLATILE операторе в %C"
 
-#: fortran/decl.c:9205
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2003: ASYNCHRONOUS statement at %C"
+#: fortran/decl.c:9224
+#, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS statement at %C"
-msgstr "Fortran 2003: ASYNCHRONOUS оператор в %C"
+msgstr "ASYNCHRONOUS оператор в %C"
 
-#: fortran/decl.c:9249
+#: fortran/decl.c:9268
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr "Синтаксическая ошибка в ASYNCHRONOUS операторе в %C"
 
-#: fortran/decl.c:9274
+#: fortran/decl.c:9293
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE declaration at %C"
-msgstr ""
+msgstr "MODULE PROCEDURE декларация в %C"
 
-#: fortran/decl.c:9367
+#: fortran/decl.c:9386
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr "MODULE PROCEDURE в %C должна быть в generic module interface"
 
-#: fortran/decl.c:9425
+#: fortran/decl.c:9444
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr "Встроенная процедура в %L не может быть MODULE PROCEDURE"
 
-#: fortran/decl.c:9474
+#: fortran/decl.c:9493
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr "Неоднозначный символ в TYPE определении в %C"
 
-#: fortran/decl.c:9483
-#, fuzzy, gcc-internal-format
-#| msgid "Symbol '%s' at %C has already been host associated"
+#: fortran/decl.c:9502
+#, gcc-internal-format
 msgid "Symbol %qs at %C has not been previously defined"
-msgstr "Символ '%s' в %C уже был host ассоциирован"
+msgstr "Символ %qs в %C не был ранее определен"
 
-#: fortran/decl.c:9489
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' in EXTENDS expression at %C is not a derived type"
+#: fortran/decl.c:9508
+#, gcc-internal-format
 msgid "%qs in EXTENDS expression at %C is not a derived type"
-msgstr "'%s' в EXTENDS выражении в %C не есть производный тип"
+msgstr "%qs в EXTENDS выражении в %C не есть производный тип"
 
-#: fortran/decl.c:9496
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' cannot be extended at %C because it is BIND(C)"
+#: fortran/decl.c:9515
+#, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is BIND(C)"
-msgstr "'%s' не может быть расширено в %C поскольку оно BIND(C)"
+msgstr "%qs не может быть расширено в %C, поскольку оно BIND(C)"
 
-#: fortran/decl.c:9503
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' cannot be extended at %C because it is a SEQUENCE type"
+#: fortran/decl.c:9522
+#, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
-msgstr "'%s' не может быть расширено в %C поскольку оно SEQUENCE тип"
+msgstr "%qs не может быть расширено в %C, поскольку оно SEQUENCE тип"
 
-#: fortran/decl.c:9526
+#: fortran/decl.c:9545
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr "Производный тип в %C может быть только PRIVATE в спецификационной части модуля"
 
-#: fortran/decl.c:9538
+#: fortran/decl.c:9557
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr "Производный тип в %C может быть только PUBLIC в спецификационной части модуля"
 
-#: fortran/decl.c:9559
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "ABSTRACT type '%s' used at %L"
+#: fortran/decl.c:9578
+#, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
-msgstr "ABSTRACT тип '%s' использован в %L"
+msgstr "ABSTRACT тип в %C"
 
-#: fortran/decl.c:9605
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "failed to close read state file %s [%s]"
+#: fortran/decl.c:9624
+#, gcc-internal-format, gfc-internal-format
 msgid "Failed to create structure type '%s' at %C"
-msgstr "ошибка закрытия файла состояния файла %s [%s]"
+msgstr "Не удалось создать тип структуры '%s' в %C"
 
-#: fortran/decl.c:9611
-#, fuzzy, gcc-internal-format
-#| msgid "Derived type definition of '%s' at %C has already been defined"
+#: fortran/decl.c:9630
+#, gcc-internal-format
 msgid "Type definition of %qs at %C was already defined at %L"
-msgstr "Определение производного типа '%s' at %C уже было определено"
+msgstr "Определение типа %qs в %C уже было определено в %L"
 
-#: fortran/decl.c:9658
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Junk after ASSOCIATE statement at %C"
+#: fortran/decl.c:9677
+#, gcc-internal-format, gfc-internal-format
 msgid "Junk after MAP statement at %C"
-msgstr "Мусор после ASSOCIATE оператора в %C"
+msgstr "Мусор после MAP оператора в %C"
 
-#: fortran/decl.c:9691
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Junk after ASSOCIATE statement at %C"
+#: fortran/decl.c:9710
+#, gcc-internal-format, gfc-internal-format
 msgid "Junk after UNION statement at %C"
-msgstr "Мусор после ASSOCIATE оператора в %C"
+msgstr "Мусор после UNION оператора в %C"
 
-#: fortran/decl.c:9726
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' at %C is not a member of the '%s' structure"
+#: fortran/decl.c:9745
+#, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-structure%>"
-msgstr "'%s' в %C не является членом '%s' структуры"
+msgstr "%s в %C является DEC расширением, включите его посредством %<-fdec-structure%>"
 
-#: fortran/decl.c:9740
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Unexpected junk after function declaration at %C"
+#: fortran/decl.c:9759
+#, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected in non-nested structure declaration at %C"
-msgstr "Неожиданный мусор после декларации функции в %C"
+msgstr "Имя структуры ожидалось в декларации невложенной структуры в %C"
 
-#: fortran/decl.c:9758
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Junk after ASSOCIATE statement at %C"
+#: fortran/decl.c:9777
+#, gcc-internal-format, gfc-internal-format
 msgid "Junk after non-nested STRUCTURE statement at %C"
-msgstr "Мусор после ASSOCIATE оператора в %C"
+msgstr "Мусор после невложенного STRUCTURE оператора в %C"
 
-#: fortran/decl.c:9765
-#, fuzzy, gcc-internal-format
-#| msgid "Type name '%s' at %C cannot be the same as an intrinsic type"
+#: fortran/decl.c:9784
+#, gcc-internal-format
 msgid "Structure name %qs at %C cannot be the same as an intrinsic type"
-msgstr "Имя типа в '%s' в %C не может быть тем же что у встроенного типа"
+msgstr "Имя структуры %qs в %C не может быть тем же, что у встроенного типа"
 
-#: fortran/decl.c:9926
+#: fortran/decl.c:9947
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr "Ожидалось :: в TYPE определении в %C"
 
-#: fortran/decl.c:9954
-#, fuzzy, gcc-internal-format
-#| msgid "Type name '%s' at %C cannot be the same as an intrinsic type"
+#: fortran/decl.c:9975
+#, gcc-internal-format
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
-msgstr "Имя типа в '%s' в %C не может быть тем же что у встроенного типа"
+msgstr "Имя типа в %qs в %C не может быть тем же, что у встроенного типа"
 
-#: fortran/decl.c:9964
-#, fuzzy, gcc-internal-format
-#| msgid "Derived type name '%s' at %C already has a basic type of %s"
+#: fortran/decl.c:9986
+#, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type of %s"
-msgstr "Имя производного типа '%s' в %C уже имеет базовый тип в %s"
+msgstr "Имя производного типа %qs в %C уже имеет базовый тип в %s"
 
-#: fortran/decl.c:9981
-#, fuzzy, gcc-internal-format
-#| msgid "Derived type definition of '%s' at %C has already been defined"
+#: fortran/decl.c:9989
+#, gcc-internal-format
+msgid "Derived type name %qs at %C already has a basic type"
+msgstr ""
+
+#: fortran/decl.c:10006
+#, gcc-internal-format
 msgid "Derived type definition of %qs at %C has already been defined"
-msgstr "Определение производного типа '%s' at %C уже было определено"
+msgstr "Определение производного типа %qs at %C уже было определено"
 
-#: fortran/decl.c:10042
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Syntax error in CHARACTER declaration at %C"
+#: fortran/decl.c:10067
+#, gcc-internal-format, gfc-internal-format
 msgid "Garbage after PARAMETERIZED TYPE declaration at %C"
-msgstr "Синтаксическая ошибка в CHARACTER декларации в %C"
+msgstr ""
 
-#: fortran/decl.c:10126
+#: fortran/decl.c:10151
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr "Cray указуемое в %C не может быть массивом предполагаемой формы"
 
-#: fortran/decl.c:10146
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2003: ENUM and ENUMERATOR at %C"
+#: fortran/decl.c:10171
+#, gcc-internal-format, gfc-internal-format
 msgid "ENUM and ENUMERATOR at %C"
-msgstr "Fortran 2003: ENUM и ENUMERATOR в %C"
+msgstr "ENUM и ENUMERATOR в %C"
 
-#: fortran/decl.c:10178
+#: fortran/decl.c:10203
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr "Перечислитель превосходит целый тип C в %C"
 
-#: fortran/decl.c:10257
+#: fortran/decl.c:10282
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr "ENUMERATOR %L не инициализирован целым выражением"
 
-#: fortran/decl.c:10305
+#: fortran/decl.c:10330
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr "ENUM оператор определения ожидался до %C"
 
-#: fortran/decl.c:10341
+#: fortran/decl.c:10366
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr "Синтаксическая ошибка в ENUMERATOR определении в %C"
 
-#: fortran/decl.c:10388 fortran/decl.c:10403
+#: fortran/decl.c:10413 fortran/decl.c:10428
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate access-specifier at %C"
 msgstr "Повторный спецификатор доступа в %C"
 
-#: fortran/decl.c:10423
+#: fortran/decl.c:10448
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr "Связывающие атрибуты уже специфицировали passing, некоректный NOPASS в %C"
 
-#: fortran/decl.c:10443
+#: fortran/decl.c:10468
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr "Связывающие атрибуты уже специфицировали passing, некоректный PASS в %C"
 
-#: fortran/decl.c:10470
+#: fortran/decl.c:10495
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate POINTER attribute at %C"
 msgstr "Повторный POINTER атрибут в %C"
 
-#: fortran/decl.c:10488
+#: fortran/decl.c:10513
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr "Повторный NON_OVERRIDABLE в %C"
 
-#: fortran/decl.c:10504
+#: fortran/decl.c:10529
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DEFERRED at %C"
 msgstr "Повторный DEFERRED в %C"
 
-#: fortran/decl.c:10517
+#: fortran/decl.c:10542
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected access-specifier at %C"
 msgstr "Ожидался спецификатор доступа в %C"
 
-#: fortran/decl.c:10519
+#: fortran/decl.c:10544
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr "Ожидался связывающий атрибут в %C"
 
-#: fortran/decl.c:10527
+#: fortran/decl.c:10552
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED can't both appear at %C"
 msgstr "NON_OVERRIDABLE и DEFERRED не могут оба появляться в %C"
 
-#: fortran/decl.c:10539
+#: fortran/decl.c:10564
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr "POINTER атрибут требуется для компонента указателя на процедуру в %C"
 
-#: fortran/decl.c:10581
-#, fuzzy, gcc-internal-format
-#| msgid "Interface-name expected after '(' at %C"
+#: fortran/decl.c:10606
+#, gcc-internal-format
 msgid "Interface-name expected after %<(%> at %C"
-msgstr "Interface-name ожидалось после '(' в %C"
+msgstr "Имя интерфейса ожидалось после %<(%> в %C"
 
-#: fortran/decl.c:10587
-#, fuzzy, gcc-internal-format
-#| msgid "')' expected at %C"
+#: fortran/decl.c:10612
+#, gcc-internal-format
 msgid "%<)%> expected at %C"
-msgstr "')' ожидалась в %C"
+msgstr "%<)%> ожидалась в %C"
 
-#: fortran/decl.c:10607
+#: fortran/decl.c:10632
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr "Интерфейс должен быть специфицирован для DEFERRED связывания в %C"
 
-#: fortran/decl.c:10612
+#: fortran/decl.c:10637
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr "PROCEDURE(interface) at %C следует декларировать DEFERRED"
 
-#: fortran/decl.c:10635
+#: fortran/decl.c:10660
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr "Ожидалось связывающее имя в %C"
 
-#: fortran/decl.c:10639
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2008: PROCEDURE list at %C"
+#: fortran/decl.c:10664
+#, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
-msgstr "Fortran 2008: PROCEDURE список в %C"
+msgstr "PROCEDURE список в %C"
 
-#: fortran/decl.c:10651
-#, fuzzy, gcc-internal-format
-#| msgid "'=> target' is invalid for DEFERRED binding at %C"
+#: fortran/decl.c:10676
+#, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
-msgstr "'=> target' некорректно для DEFERRED связывания в %C"
+msgstr "%<=> target%> некорректно для DEFERRED связывания в %C"
 
-#: fortran/decl.c:10657
-#, fuzzy, gcc-internal-format
-#| msgid "'::' needed in PROCEDURE binding with explicit target at %C"
+#: fortran/decl.c:10682
+#, gcc-internal-format
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
-msgstr "'::' требуется в PROCEDURE связывании с явной целью в %C"
+msgstr "%<::%> требуется в PROCEDURE связывании с явной целью в %C"
 
-#: fortran/decl.c:10667
-#, fuzzy, gcc-internal-format
-#| msgid "Expected binding target after '=>' at %C"
+#: fortran/decl.c:10692
+#, gcc-internal-format
 msgid "Expected binding target after %<=>%> at %C"
-msgstr "Ожидалась цель связывания после '=>' в %C"
+msgstr "Ожидалась цель связывания после %<=>%> в %C"
 
-#: fortran/decl.c:10684
-#, fuzzy, gcc-internal-format
-#| msgid "Type '%s' containing DEFERRED binding at %C is not ABSTRACT"
+#: fortran/decl.c:10709
+#, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
-msgstr "Тип '%s' содержащий DEFERRED связывание в %C не есть ABSTRACT"
+msgstr "Тип %qs, содержащий DEFERRED связывание в %C, не есть ABSTRACT"
 
-#: fortran/decl.c:10695
-#, fuzzy, gcc-internal-format
-#| msgid "There is already a procedure with binding name '%s' for the derived type '%s' at %C"
+#: fortran/decl.c:10720
+#, gcc-internal-format
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
-msgstr "Уже есть процедура со связывающим именем '%s' для производного типа '%s' в %C"
+msgstr "Уже есть процедура со связывающим именем %qs для производного типа %qs в %C"
 
-#: fortran/decl.c:10746
+#: fortran/decl.c:10771
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr "GENERIC в %C должно быть внутри производного типа CONTAINS"
 
-#: fortran/decl.c:10766
-#, fuzzy, gcc-internal-format
-#| msgid "Expected '::' at %C"
+#: fortran/decl.c:10791
+#, gcc-internal-format
 msgid "Expected %<::%> at %C"
-msgstr "Ожидалось '::' в %C"
+msgstr "Ожидалось %<::%> в %C"
 
-#: fortran/decl.c:10778
+#: fortran/decl.c:10803
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected generic name or operator descriptor at %C"
 msgstr "Ожидалось generic имя или дескриптор оператора в %C"
 
-#: fortran/decl.c:10799
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Invalid form of PROGRAM statement at %C"
+#: fortran/decl.c:10824
+#, gcc-internal-format, gfc-internal-format
 msgid "Malformed GENERIC statement at %C"
-msgstr "Некорректная форма PROGRAM оператора в %C"
+msgstr "Некорректная форма GENERIC оператора в %C"
 
-#: fortran/decl.c:10810
-#, fuzzy, gcc-internal-format
-#| msgid "Expected '=>' at %C"
+#: fortran/decl.c:10835
+#, gcc-internal-format
 msgid "Expected %<=>%> at %C"
-msgstr "Ожидалось '=>' в %C"
+msgstr "Ожидалось %<=>%> в %C"
 
-#: fortran/decl.c:10846
-#, fuzzy, gcc-internal-format
-#| msgid "There's already a non-generic procedure with binding name '%s' for the derived type '%s' at %C"
+#: fortran/decl.c:10871
+#, gcc-internal-format
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
-msgstr "Уже есть non-generic процедура со связывающим именем '%s' для производного типа '%s' в %C"
+msgstr "Уже есть не-generic процедура со связывающим именем %qs для производного типа %qs в %C"
 
-#: fortran/decl.c:10854
-#, fuzzy, gcc-internal-format
-#| msgid "Binding at %C must have the same access as already defined binding '%s'"
+#: fortran/decl.c:10879
+#, gcc-internal-format
 msgid "Binding at %C must have the same access as already defined binding %qs"
-msgstr "Связывание в %C должно иметь тот же доступ что и уже определенное связывание '%s'"
+msgstr "Связывание в %C должно иметь тот же доступ, что и уже определенное связывание %qs"
 
-#: fortran/decl.c:10902
+#: fortran/decl.c:10927
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr "Ожидалось конкретное связывающее имя в %C"
 
-#: fortran/decl.c:10912
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' already defined as specific binding for the generic '%s' at %C"
+#: fortran/decl.c:10937
+#, gcc-internal-format
 msgid "%qs already defined as specific binding for the generic %qs at %C"
-msgstr "'%s' уже определено как конкретное связывание для generic '%s' в %C"
+msgstr "%qs уже определено как конкретное связывание для generic %qs в %C"
 
-#: fortran/decl.c:10930
+#: fortran/decl.c:10955
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr "Мусор после GENERIC связывания в %C"
 
-#: fortran/decl.c:10965
+#: fortran/decl.c:10990
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr "FINAL декларация в %C должна быть внутри секции CONTAINS производного типа"
 
-#: fortran/decl.c:10976
+#: fortran/decl.c:11001
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr "Декларация производного типа с FINAL в %C должна быть в спецификационной части модуля"
 
-#: fortran/decl.c:10998
+#: fortran/decl.c:11023
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr "Пустое FINAL в %C"
 
-#: fortran/decl.c:11005
+#: fortran/decl.c:11030
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr "Ожидалось имя модульной процедуры в %C"
 
-#: fortran/decl.c:11015
-#, fuzzy, gcc-internal-format
-#| msgid "Expected \",\" at %C"
+#: fortran/decl.c:11040
+#, gcc-internal-format
 msgid "Expected %<,%> at %C"
-msgstr "Ожидалась \",\" в %C"
+msgstr "Ожидалась %<,%> в %C"
 
-#: fortran/decl.c:11021
-#, fuzzy, gcc-internal-format
-#| msgid "Unknown procedure name \"%s\" at %C"
+#: fortran/decl.c:11046
+#, gcc-internal-format
 msgid "Unknown procedure name %qs at %C"
-msgstr "Неизвестное име процедуры \"%s\" в %C"
+msgstr "Неизвестное имя процедуры %qs в %C"
 
-#: fortran/decl.c:11034
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' at %C is already defined as FINAL procedure!"
+#: fortran/decl.c:11059
+#, gcc-internal-format
 msgid "%qs at %C is already defined as FINAL procedure"
-msgstr "'%s' в %C уже определена как FINAL процедура!"
+msgstr ""
 
-#: fortran/decl.c:11104
+#: fortran/decl.c:11129
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr "Неизвестный атрибут в !GCC$ ATTRIBUTES операторе в %C"
 
-#: fortran/decl.c:11150
+#: fortran/decl.c:11175
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr "Синтаксическая ошибка в !GCC$ ATTRIBUTES операторе в %C"
 
-#: fortran/decl.c:11170
+#: fortran/decl.c:11195
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive requires a non-negative integral constant less than or equal to %u at %C"
 msgstr ""
 
-#: fortran/decl.c:11184
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Syntax error in FORALL iterator at %C"
+#: fortran/decl.c:11209
+#, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ UNROLL directive at %C"
-msgstr "Синтаксическая ошибка в FORALL итераторе в %C"
+msgstr ""
 
 #: fortran/dependency.c:105
 #, gcc-internal-format
 msgid "identical_array_ref(): inconsistent dimensions"
-msgstr ""
+msgstr "identical_array_ref(): противоречивые размерности"
 
 #: fortran/dependency.c:193
 #, gcc-internal-format
 msgid "are_identical_variables: Bad type"
-msgstr ""
+msgstr "are_identical_variables: Некорректный тип"
 
 #. We are told not to check dependencies.
 #. We do it, however, and issue a warning in case we find one.
@@ -59422,46 +53061,42 @@
 #: fortran/dependency.c:1280
 #, gcc-internal-format
 msgid "gfc_check_dependency: expecting an EXPR_VARIABLE"
-msgstr ""
+msgstr "gfc_check_dependency: ожидается EXPR_VARIABLE"
 
 #: fortran/dump-parse-tree.c:201
 #, gcc-internal-format
 msgid "show_array_spec(): Unhandled array shape type."
-msgstr ""
+msgstr "show_array_spec(): Необрабатываемый тип формы массива."
 
 #: fortran/dump-parse-tree.c:280
 #, gcc-internal-format
 msgid "show_array_ref(): Unknown array reference"
-msgstr ""
+msgstr "show_array_ref(): Неизвестная массивная ссылка"
 
 #: fortran/dump-parse-tree.c:312
-#, fuzzy, gcc-internal-format
-#| msgid "gfc_trans_code(): Bad statement code"
+#, gcc-internal-format
 msgid "show_ref(): Bad component code"
-msgstr "gfc_trans_code(): Некорректный код оператора"
+msgstr "show_ref(): Некорректный код компонента"
 
 #: fortran/dump-parse-tree.c:575
-#, fuzzy, gcc-internal-format
-#| msgid "Expected expression type"
+#, gcc-internal-format
 msgid "show_expr(): Bad intrinsic in expression"
-msgstr "Ожидался тип выражения"
+msgstr ""
 
 #: fortran/dump-parse-tree.c:618
 #, gcc-internal-format
 msgid "show_expr(): Don't know how to show expr"
-msgstr ""
+msgstr "show_expr(): Не знаю, как показать выражение"
 
 #: fortran/dump-parse-tree.c:2856
-#, fuzzy, gcc-internal-format
-#| msgid "gfc_trans_code(): Bad statement code"
+#, gcc-internal-format
 msgid "show_code_node(): Bad statement code"
-msgstr "gfc_trans_code(): Некорректный код оператора"
+msgstr "show_code_node(): Некорректный код оператора"
 
 #: fortran/dump-parse-tree.c:3150 fortran/dump-parse-tree.c:3242
-#, fuzzy, gcc-internal-format
-#| msgid "cannot convert to a pointer type"
+#, gcc-internal-format
 msgid "Cannot convert %qs to interoperable type at %L"
-msgstr "преобразование к типу указателя невозможно"
+msgstr ""
 
 #: fortran/error.c:335
 #, gcc-internal-format, gfc-internal-format
@@ -59476,18 +53111,17 @@
 #: fortran/expr.c:149
 #, gcc-internal-format
 msgid "gfc_get_constant_expr(): locus %<where%> cannot be NULL"
-msgstr ""
+msgstr "gfc_get_constant_expr(): местоположение %<where%> не может быть NULL"
 
 #: fortran/expr.c:349
-#, fuzzy, gcc-internal-format
-#| msgid "gfc_trans_code(): Bad statement code"
+#, gcc-internal-format
 msgid "gfc_copy_expr(): Bad expr node"
-msgstr "gfc_trans_code(): Некорректный код оператора"
+msgstr "gfc_copy_expr(): Некорректный узел выражения"
 
 #: fortran/expr.c:499
 #, gcc-internal-format
 msgid "free_expr0(): Bad expr type"
-msgstr ""
+msgstr "free_expr0(): Некорректный тип выражения"
 
 #: fortran/expr.c:646 fortran/expr.c:648 fortran/expr.c:699 fortran/expr.c:701
 #, gcc-internal-format, gfc-internal-format
@@ -59507,12 +53141,12 @@
 #: fortran/expr.c:1050
 #, gcc-internal-format
 msgid "gfc_is_constant_expr(): Unknown expression type"
-msgstr ""
+msgstr "gfc_is_constant_expr(): Неизвестный тип выражения"
 
 #: fortran/expr.c:1207
 #, gcc-internal-format
 msgid "simplify_intrinsic_op(): Bad operator"
-msgstr ""
+msgstr "simplify_intrinsic_op(): Некорректный оператор"
 
 #: fortran/expr.c:1313
 #, gcc-internal-format, gfc-internal-format
@@ -59527,7 +53161,7 @@
 #: fortran/expr.c:1628
 #, gcc-internal-format, gfc-internal-format
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit.   See -fmax-array-constructor option"
-msgstr "Число элементов в конструкторе массива в %L требует увеличения допустимой %d верхней границы. См. опцию -fmax-array-constructor"
+msgstr ""
 
 #: fortran/expr.c:2175
 #, gcc-internal-format, gfc-internal-format
@@ -59552,7 +53186,7 @@
 #: fortran/expr.c:2261
 #, gcc-internal-format, gfc-internal-format
 msgid ".NOT. operator in expression at %L must have a LOGICAL operand"
-msgstr ".NOT. оператор в выражении в %L должен иметь LOGICAL операнд"
+msgstr ""
 
 #: fortran/expr.c:2277
 #, gcc-internal-format, gfc-internal-format
@@ -59570,136 +53204,114 @@
 msgstr "Числовые операнды требуются в выражении в %L"
 
 #: fortran/expr.c:2319
-#, fuzzy, gcc-internal-format
-#| msgid "Invalid initialization expression for ALLOCATABLE component '%s' in structure constructor at %L"
+#, gcc-internal-format
 msgid "Invalid initialization expression for ALLOCATABLE component %qs in structure constructor at %L"
-msgstr "Некорректное инициализационное выражение для ALLOCATABLE компонента '%s' в конструкторе структуры в %L"
+msgstr "Некорректное инициализационное выражение для ALLOCATABLE компонента %qs в конструкторе структуры в %L"
 
 #: fortran/expr.c:2430
-#, fuzzy, gcc-internal-format
-#| msgid "Assumed or deferred character length variable '%s'  in constant expression at %L"
+#, gcc-internal-format
 msgid "Assumed or deferred character length variable %qs in constant expression at %L"
-msgstr "Предполагаемая или отложенная переменная character длины '%s' в константном выражении в %L"
+msgstr "Переменная предполагаемой или отложенной character длины %qs в константном выражении в %L"
 
 #: fortran/expr.c:2496
-#, fuzzy, gcc-internal-format
-#| msgid "transformational intrinsic '%s' at %L is not permitted in an initialization expression"
+#, gcc-internal-format
 msgid "transformational intrinsic %qs at %L is not permitted in an initialization expression"
-msgstr "трансформационная встроенная функция '%s' в %L не разрешена в инициализационном выражении"
+msgstr "трансформационная встроенная функция %qs в %L не разрешена в инициализационном выражении"
 
 #: fortran/expr.c:2527
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Extension: Evaluation of nonstandard initialization expression at %L"
+#, gcc-internal-format, gfc-internal-format
 msgid "Evaluation of nonstandard initialization expression at %L"
-msgstr "Расширение: Обработка нестандартного инициализационного выражения в %L"
+msgstr "Вычисление нестандартного инициализационного выражения в %L"
 
 #: fortran/expr.c:2604 fortran/resolve.c:2688
-#, fuzzy, gcc-internal-format
-#| msgid "Function '%s' in initialization expression at %L must be an intrinsic function"
+#, gcc-internal-format
 msgid "Function %qs in initialization expression at %L must be an intrinsic function"
-msgstr "Функция '%s' в инициализационном выражении в %L должна быть встроенной функцией"
+msgstr "Функция %qs в инициализационном выражении в %L должна быть встроенной функцией"
 
 #: fortran/expr.c:2616
-#, fuzzy, gcc-internal-format
-#| msgid "Intrinsic function '%s' at %L is not permitted in an initialization expression"
+#, gcc-internal-format
 msgid "Intrinsic function %qs at %L is not permitted in an initialization expression"
-msgstr "Встроенная функция '%s' в %L не разрешена в инициализационном выражении"
+msgstr "Встроенная функция %qs в %L не разрешена в инициализационном выражении"
 
 #: fortran/expr.c:2655
-#, fuzzy, gcc-internal-format
-#| msgid "PARAMETER '%s' is used at %L before its definition is complete"
+#, gcc-internal-format
 msgid "PARAMETER %qs is used at %L before its definition is complete"
-msgstr "PARAMETER '%s' использован в %L до завершения его определения"
+msgstr "PARAMETER %qs использован в %L до завершения его определения"
 
 #: fortran/expr.c:2675
-#, fuzzy, gcc-internal-format
-#| msgid "Assumed size array '%s' at %L is not permitted in an initialization expression"
+#, gcc-internal-format
 msgid "Assumed size array %qs at %L is not permitted in an initialization expression"
-msgstr "Массив предполагаемого размера '%s' в %L не разрешен в инициализационном выражении"
+msgstr "Массив предполагаемого размера %qs в %L не разрешен в инициализационном выражении"
 
 #: fortran/expr.c:2681
-#, fuzzy, gcc-internal-format
-#| msgid "Assumed shape array '%s' at %L is not permitted in an initialization expression"
+#, gcc-internal-format
 msgid "Assumed shape array %qs at %L is not permitted in an initialization expression"
-msgstr "Массив предполагаемой формы '%s' в %L не разрешен в инициализационном выражении"
+msgstr "Массив предполагаемой формы %qs в %L не разрешен в инициализационном выражении"
 
 #: fortran/expr.c:2687
-#, fuzzy, gcc-internal-format
-#| msgid "Deferred array '%s' at %L is not permitted in an initialization expression"
+#, gcc-internal-format
 msgid "Deferred array %qs at %L is not permitted in an initialization expression"
-msgstr "Отложенный массив '%s' в %L не разрешен в инициализационном выражении"
+msgstr "Отложенный массив %qs в %L не разрешен в инициализационном выражении"
 
 #: fortran/expr.c:2693
-#, fuzzy, gcc-internal-format
-#| msgid "Array '%s' at %L is a variable, which does not reduce to a constant expression"
+#, gcc-internal-format
 msgid "Array %qs at %L is a variable, which does not reduce to a constant expression"
-msgstr "Массив '%s' в %L является переменной, которая не сводится к константному выражению"
+msgstr "Массив %qs в %L является переменной, которая не сводится к константному выражению"
 
 #: fortran/expr.c:2703
-#, fuzzy, gcc-internal-format
-#| msgid "Parameter '%s' at %L has not been declared or is a variable, which does not reduce to a constant expression"
+#, gcc-internal-format
 msgid "Parameter %qs at %L has not been declared or is a variable, which does not reduce to a constant expression"
-msgstr "Parameter '%s' at %L не был декларирован или является переменной, которая не сводится к константному выражению"
+msgstr "Parameter %qs at %L не был декларирован или является переменной, которая не сводится к константному выражению"
 
 #: fortran/expr.c:2757
-#, fuzzy, gcc-internal-format
-#| msgid "Expected expression type"
+#, gcc-internal-format
 msgid "check_init_expr(): Unknown expression type"
-msgstr "Ожидался тип выражения"
+msgstr "check_init_expr(): Неизвестный тип выражения"
 
 #: fortran/expr.c:2891
-#, fuzzy, gcc-internal-format
-#| msgid "Specification function '%s' at %L cannot be a statement function"
+#, gcc-internal-format
 msgid "Specification function %qs at %L cannot be a statement function"
-msgstr "Спецификационная функция '%s' в %L не может быть оператор-функцией"
+msgstr "Спецификационная функция %qs в %L не может быть оператор-функцией"
 
 #: fortran/expr.c:2898
-#, fuzzy, gcc-internal-format
-#| msgid "Specification function '%s' at %L cannot be an internal function"
+#, gcc-internal-format
 msgid "Specification function %qs at %L cannot be an internal function"
-msgstr "Спецификационная функция '%s' в %L не может быть внутренней функцией"
+msgstr "Спецификационная функция %qs в %L не может быть внутренней функцией"
 
 #: fortran/expr.c:2905
-#, fuzzy, gcc-internal-format
-#| msgid "Specification function '%s' at %L must be PURE"
+#, gcc-internal-format
 msgid "Specification function %qs at %L must be PURE"
-msgstr "Спецификационная функция '%s' в %L должна быть PURE"
+msgstr "Спецификационная функция %qs в %L должна быть PURE"
 
 #: fortran/expr.c:2913
-#, fuzzy, gcc-internal-format
-#| msgid "Specification function '%s' at %L cannot be RECURSIVE"
+#, gcc-internal-format
 msgid "Specification function %qs at %L cannot be RECURSIVE"
-msgstr "Спецификационная функция '%s' в %L не может быть RECURSIVE"
+msgstr "Спецификационная функция %qs в %L не может быть RECURSIVE"
 
 #: fortran/expr.c:3059
-#, fuzzy, gcc-internal-format
-#| msgid "Dummy argument '%s' not allowed in expression at %L"
+#, gcc-internal-format
 msgid "Dummy argument %qs not allowed in expression at %L"
-msgstr "Формальный аргумент '%s' не допускается в выражении в %L"
+msgstr "Формальный аргумент %qs не допускается в выражении в %L"
 
 #: fortran/expr.c:3066
-#, fuzzy, gcc-internal-format
-#| msgid "Dummy argument '%s' at %L cannot be OPTIONAL"
+#, gcc-internal-format
 msgid "Dummy argument %qs at %L cannot be OPTIONAL"
-msgstr "Формальный аргумент '%s' в %L не может быть OPTIONAL"
+msgstr "Формальный аргумент %qs в %L не может быть OPTIONAL"
 
 #: fortran/expr.c:3073
-#, fuzzy, gcc-internal-format
-#| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
+#, gcc-internal-format
 msgid "Dummy argument %qs at %L cannot be INTENT(OUT)"
-msgstr "Формальный аргумент '%s' в %L не может быть INTENT(OUT)"
+msgstr "Формальный аргумент %qs в %L не может быть INTENT(OUT)"
 
 #: fortran/expr.c:3102
-#, fuzzy, gcc-internal-format
-#| msgid "Variable '%s' cannot appear in the expression at %L"
+#, gcc-internal-format
 msgid "Variable %qs cannot appear in the expression at %L"
-msgstr "Переменная '%s' не может появляться в выражении в %L"
+msgstr "Переменная %qs не может появляться в выражении в %L"
 
 #: fortran/expr.c:3133
-#, fuzzy, gcc-internal-format
-#| msgid "Expected expression type"
+#, gcc-internal-format
 msgid "check_restricted(): Unknown expression type"
-msgstr "Ожидался тип выражения"
+msgstr "check_restricted(): Неизвестный тип выражения"
 
 #: fortran/expr.c:3153
 #, gcc-internal-format, gfc-internal-format
@@ -59707,10 +53319,9 @@
 msgstr "Выражение в %L должно быть INTEGER типа, найдено %s"
 
 #: fortran/expr.c:3165
-#, fuzzy, gcc-internal-format
-#| msgid "Function '%s' at %L must be PURE"
+#, gcc-internal-format
 msgid "Function %qs at %L must be PURE"
-msgstr "Функция '%s' в %L должна быть PURE"
+msgstr "Функция %qs в %L должна быть PURE"
 
 #: fortran/expr.c:3174
 #, gcc-internal-format, gfc-internal-format
@@ -59728,10 +53339,9 @@
 msgstr "Иная форма для %s в %L по измерению %d (%d и %d)"
 
 #: fortran/expr.c:3318
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' at %L is not a VALUE"
+#, gcc-internal-format
 msgid "%qs at %L is not a VALUE"
-msgstr "'%s' в %L не есть VALUE"
+msgstr "%qs в %L не есть VALUE"
 
 #: fortran/expr.c:3325
 #, gcc-internal-format, gfc-internal-format
@@ -59749,374 +53359,342 @@
 msgstr "NULL появляется в правой части присваивания в %L"
 
 #: fortran/expr.c:3354
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "POINTER valued function appears on right-hand side of assignment at %L"
+#, gcc-internal-format, gfc-internal-format
 msgid "POINTER-valued function appears on right-hand side of assignment at %L"
-msgstr "Возвращающая POINTER функция появляется в правой части присваивания в %L"
+msgstr "Функция с POINTER-значением появляется в правой части присваивания в %L"
 
 #: fortran/expr.c:3364
-#, fuzzy, gcc-internal-format
-#| msgid "Extension: BOZ literal at %L used to initialize non-integer variable '%s'"
+#, gcc-internal-format
 msgid "BOZ literal at %L used to initialize non-integer variable %qs"
-msgstr "Расширение: BOZ литерал в %L использован для инициализации нецелой переменной '%s'"
+msgstr "BOZ литерал в %L использован для инициализации нецелой переменной %qs"
 
-#: fortran/expr.c:3369 fortran/resolve.c:10197
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Extension: BOZ literal at %L outside a DATA statement and outside INT/REAL/DBLE/CMPLX"
+#: fortran/expr.c:3369 fortran/resolve.c:10210
+#, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal at %L outside a DATA statement and outside INT/REAL/DBLE/CMPLX"
-msgstr "Расширение: BOZ литерал в %L вне DATA оператора и вне INT/REAL/DBLE/CMPLX"
+msgstr "BOZ литерал в %L вне DATA оператора и вне INT/REAL/DBLE/CMPLX"
 
-#: fortran/expr.c:3380 fortran/resolve.c:10208
-#, fuzzy, gcc-internal-format
-#| msgid "BOZ literal at %L is bitwise transferred non-integer symbol '%s'"
+#: fortran/expr.c:3380 fortran/resolve.c:10221
+#, gcc-internal-format
 msgid "BOZ literal at %L is bitwise transferred non-integer symbol %qs"
-msgstr "BOZ литерал в %L есть побитно преобразованный нецелый символ '%s'"
+msgstr "BOZ литерал в %L есть побитно преобразованный нецелый символ %qs"
 
-#: fortran/expr.c:3388 fortran/resolve.c:10217
-#, fuzzy, gcc-internal-format
-#| msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option -fno-range-check"
+#: fortran/expr.c:3388 fortran/resolve.c:10230
+#, gcc-internal-format
 msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
-msgstr "Арифметическая потеря значимости побитно преобразованного BOZ at %L. Эту проверку можно выключить опцией -fno-range-check"
+msgstr ""
 
-#: fortran/expr.c:3392 fortran/resolve.c:10221
-#, fuzzy, gcc-internal-format
-#| msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option -fno-range-check"
+#: fortran/expr.c:3392 fortran/resolve.c:10234
+#, gcc-internal-format
 msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
-msgstr "Арифметическая переполнение побитно преобразованного BOZ at %L. Эту проверку можно выключить опцией -fno-range-check"
+msgstr ""
 
-#: fortran/expr.c:3396 fortran/resolve.c:10225
-#, fuzzy, gcc-internal-format
-#| msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option -fno-range-check"
+#: fortran/expr.c:3396 fortran/resolve.c:10238
+#, gcc-internal-format
 msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
-msgstr "Арифметическое NaN побитно преобразованного BOZ at %L. Эту проверку можно выключить опцией -fno-range-check"
+msgstr ""
 
 #: fortran/expr.c:3405
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Deferred-length character component '%s' at %L is not yet supported"
+#, gcc-internal-format, gfc-internal-format
 msgid "The assignment to a KIND or LEN component of a parameterized type at %L is not allowed"
-msgstr "Character компонент с отложенной длиной '%s' в %L пока не поддерживается"
+msgstr ""
 
-#: fortran/expr.c:3426
+#: fortran/expr.c:3429
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible types in DATA statement at %L; attempted conversion of %s to %s"
 msgstr "Несовместимые типы в DATA операторе в %L; попытка преобразования %s в %s"
 
-#: fortran/expr.c:3465
+#: fortran/expr.c:3468
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is not a POINTER at %L"
 msgstr "Цель указательного присваивания не есть POINTER в %L"
 
-#: fortran/expr.c:3473
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' in the pointer assignment at %L cannot be an l-value since it is a procedure"
+#: fortran/expr.c:3476
+#, gcc-internal-format
 msgid "%qs in the pointer assignment at %L cannot be an l-value since it is a procedure"
-msgstr "'%s' в указательном присваивании в %L не может быть l-value поскольку это процедура"
+msgstr "%qs в указательном присваивании в %L не может быть l-value, поскольку это процедура"
 
-#: fortran/expr.c:3496
-#, fuzzy, gcc-internal-format
-#| msgid "Expected bounds specification for '%s' at %L"
+#: fortran/expr.c:3499
+#, gcc-internal-format
 msgid "Expected bounds specification for %qs at %L"
-msgstr "Ожидалась спецификация границ для '%s' в %L"
+msgstr "Ожидалась спецификация границ для %qs в %L"
 
-#: fortran/expr.c:3501
-#, fuzzy, gcc-internal-format
-#| msgid "Fortran 2003: Bounds specification for '%s' in pointer assignment at %L"
+#: fortran/expr.c:3504
+#, gcc-internal-format
 msgid "Bounds specification for %qs in pointer assignment at %L"
-msgstr "Fortran 2003: Спецификация границ для '%s' в указательном присваивании в %L"
+msgstr "Спецификация границ для %qs в указательном присваивании в %L"
 
-#: fortran/expr.c:3514
+#: fortran/expr.c:3517
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower bound has to be present at %L"
 msgstr "Нижняя граница должна присутствовать в %L"
 
-#: fortran/expr.c:3520
+#: fortran/expr.c:3523
 #, gcc-internal-format, gfc-internal-format
 msgid "Stride must not be present at %L"
 msgstr "Шаг не может присутствовать в %L"
 
-#: fortran/expr.c:3532
+#: fortran/expr.c:3535
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the upper bounds must be specified at %L"
 msgstr "Все или никакие верхние границы должны быть специфицированы в %L"
 
-#: fortran/expr.c:3558
+#: fortran/expr.c:3561
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %L shall not have a coindex"
 msgstr "Указательный объект в %L не должен иметь коиндекс"
 
-#: fortran/expr.c:3579
+#: fortran/expr.c:3582
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure pointer assignment at %L"
 msgstr "Некорректное присваивание указателя на процедуру в %L"
 
-#: fortran/expr.c:3603
-#, fuzzy, gcc-internal-format
-#| msgid "Statement function '%s' is invalid in procedure pointer assignment at %L"
+#: fortran/expr.c:3606
+#, gcc-internal-format
 msgid "Function result %qs is invalid as proc-target in procedure pointer assignment at %L"
-msgstr "Оператор-функция '%s' некорректна в присваивании указателя на процедуру в %L"
+msgstr "Результат функции %qs некорректен как процедурная цель в присваивании указателя на процедуру в %L"
 
-#: fortran/expr.c:3612
-#, fuzzy, gcc-internal-format
-#| msgid "Abstract interface '%s' is invalid in procedure pointer assignment at %L"
+#: fortran/expr.c:3615
+#, gcc-internal-format
 msgid "Abstract interface %qs is invalid in procedure pointer assignment at %L"
-msgstr "Абстрактный интерфейс '%s' некорректен в присваивании указателя на процедуру в %L"
+msgstr "Абстрактный интерфейс %qs некорректен в присваивании указателя на процедуру в %L"
 
-#: fortran/expr.c:3622
-#, fuzzy, gcc-internal-format
-#| msgid "Statement function '%s' is invalid in procedure pointer assignment at %L"
+#: fortran/expr.c:3625
+#, gcc-internal-format
 msgid "Statement function %qs is invalid in procedure pointer assignment at %L"
-msgstr "Оператор-функция '%s' некорректна в присваивании указателя на процедуру в %L"
+msgstr "Оператор-функция %qs некорректна в присваивании указателя на процедуру в %L"
 
-#: fortran/expr.c:3628
-#, fuzzy, gcc-internal-format
-#| msgid "Internal procedure '%s' is invalid in procedure pointer assignment at %L"
+#: fortran/expr.c:3631
+#, gcc-internal-format
 msgid "Internal procedure %qs is invalid in procedure pointer assignment at %L"
-msgstr "Внутренняя процедура '%s' некорректна в присваивании указателя на процедуру в %L"
+msgstr "Внутренняя процедура %qs некорректна в присваивании указателя на процедуру в %L"
 
-#: fortran/expr.c:3635
-#, fuzzy, gcc-internal-format
-#| msgid "Internal procedure '%s' is invalid in procedure pointer assignment at %L"
+#: fortran/expr.c:3638
+#, gcc-internal-format
 msgid "Intrinsic %qs at %L is invalid in procedure pointer assignment"
-msgstr "Внутренняя процедура '%s' некорректна в присваивании указателя на процедуру в %L"
+msgstr "Встроенная функция %qs в %L некорректна в присваивании указателя на процедуру"
 
-#: fortran/expr.c:3643
-#, fuzzy, gcc-internal-format
-#| msgid "Nonintrinsic elemental procedure '%s' is invalid in procedure pointer assigment at %L"
+#: fortran/expr.c:3646
+#, gcc-internal-format
 msgid "Nonintrinsic elemental procedure %qs is invalid in procedure pointer assignment at %L"
-msgstr "Невстроенная элементная процедура '%s' некорректна в присваивании указателя на процедуру в %L"
+msgstr "Невстроенная элементная процедура %qs некорректна в присваивании указателя на процедуру в %L"
 
-#: fortran/expr.c:3666
+#: fortran/expr.c:3669
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in the procedure pointer assignment at %L: mismatch in the calling convention"
 msgstr "Несоответствие в присваивании указателя на процедуру в %L: несоответствие в соглашении о вызове"
 
-#: fortran/expr.c:3719
-#, fuzzy, gcc-internal-format
-#| msgid "Interface mismatch in procedure pointer assignment at %L: %s"
+#: fortran/expr.c:3722
+#, gcc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %qs is not a subroutine"
-msgstr "Несоответствие интерфейсов в присваивании указателя на процедуру в %L: %s"
+msgstr "Несоответствие интерфейсов в присваивании указателя на процедуру в %L: %qs не есть подпрограмма"
 
-#: fortran/expr.c:3729 fortran/expr.c:3744
-#, fuzzy, gcc-internal-format
-#| msgid "NOPASS or explicit interface required at %C"
+#: fortran/expr.c:3732 fortran/expr.c:3747
+#, gcc-internal-format
 msgid "Explicit interface required for component %qs at %L: %s"
-msgstr "NOPASS или явный интерфейс требуются в %C"
+msgstr "Явный интерфейс требуются для компонента %qs в %L: %s"
 
-#: fortran/expr.c:3735 fortran/expr.c:3750 fortran/resolve.c:2566
-#, fuzzy, gcc-internal-format
-#| msgid "NOPASS or explicit interface required at %C"
+#: fortran/expr.c:3738 fortran/expr.c:3753 fortran/resolve.c:2566
+#, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
-msgstr "NOPASS или явный интерфейс требуются в %C"
+msgstr "Явный интерфейс требуются для %qs в %L: %s"
 
-#: fortran/expr.c:3762
+#: fortran/expr.c:3765
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %s"
 msgstr "Несоответствие интерфейсов в присваивании указателя на процедуру в %L: %s"
 
-#: fortran/expr.c:3771
+#: fortran/expr.c:3774
 #, gcc-internal-format
 msgid "Procedure pointer target %qs at %L must be either an intrinsic, host or use associated, referenced or have the EXTERNAL attribute"
-msgstr ""
+msgstr "Цель указателя на процедуру %qs в %L должна быть встроенной функцией, host или use ассоциированной, на нее должна быть ссылка или она должна иметь EXTERNAL атрибут"
 
-#: fortran/expr.c:3788
+#: fortran/expr.c:3791
 #, gcc-internal-format, gfc-internal-format
 msgid "Data-pointer-object at %L must be unlimited polymorphic, or of a type with the BIND or SEQUENCE attribute, to be compatible with an unlimited polymorphic target"
-msgstr ""
+msgstr "Data-pointer-object в %L должен быть неограниченно полиморфным или иметь тип с BIND или SEQUENCE атрибутами, чтобы быть совместимым с неограниченно полиморфной целью"
 
-#: fortran/expr.c:3793
+#: fortran/expr.c:3796
 #, gcc-internal-format, gfc-internal-format
 msgid "Different types in pointer assignment at %L; attempted assignment of %s to %s"
 msgstr "Разные типа в присваивании указателя в %L; попытка присвоить %s в %s"
 
-#: fortran/expr.c:3802
+#: fortran/expr.c:3805
 #, gcc-internal-format, gfc-internal-format
 msgid "Different kind type parameters in pointer assignment at %L"
 msgstr "Разные виды типовых параметров в присваивании указателя в %L"
 
-#: fortran/expr.c:3809
+#: fortran/expr.c:3812
 #, gcc-internal-format, gfc-internal-format
 msgid "Different ranks in pointer assignment at %L"
 msgstr "Разные ранги в присваивании указателя в %L"
 
-#: fortran/expr.c:3828
+#: fortran/expr.c:3831
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is smaller than size of the pointer (%ld < %ld) at %L"
 msgstr "Цель переотображения ранга меньше чем размер указателя (%ld < %ld) в %L"
 
-#: fortran/expr.c:3841
+#: fortran/expr.c:3844
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target must be rank 1 or simply contiguous at %L"
 msgstr "Цель переотображения ранга должна быть ранга 1 или просто непрерывна в %L"
 
-#: fortran/expr.c:3845
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2008: Rank remapping target is not rank 1 at %L"
+#: fortran/expr.c:3848
+#, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is not rank 1 at %L"
-msgstr "Fortran 2008: Цель переотображения ранга не ранга 1 в %L"
+msgstr "Цель, переотображающая ранг, не ранга 1 в %L"
 
 #. The test above might need to be extend when F08, Note 5.4 has to be
 #. interpreted in the way that target and pointer with the same coindex
 #. are allowed.
-#: fortran/expr.c:3877 fortran/expr.c:3925
+#: fortran/expr.c:3880 fortran/expr.c:3928
 #, gcc-internal-format, gfc-internal-format
 msgid "Data target at %L shall not have a coindex"
 msgstr "Целевые данные в %L не должны иметь коиндекс"
 
-#: fortran/expr.c:3880
+#: fortran/expr.c:3883
 #, gcc-internal-format, gfc-internal-format
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr "Целевое выражение в присваивании указателя в %L должна выдавать указательный результат"
 
-#: fortran/expr.c:3888
+#: fortran/expr.c:3891
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr "Цель присваивания указателя не TARGET и не POINTER в %L"
 
-#: fortran/expr.c:3895
+#: fortran/expr.c:3898
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr "Некорректная цель в присваивании указателя в PURE процедуре в %L"
 
-#: fortran/expr.c:3904
+#: fortran/expr.c:3907
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr "Присваивание указателя с индексом вектора в правой части в %L"
 
-#: fortran/expr.c:3912
+#: fortran/expr.c:3915
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr "Цель присваивания указателя имеет PROTECTED атрибут в %L"
 
-#: fortran/expr.c:3936
+#: fortran/expr.c:3939
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to contiguous pointer from non-contiguous target at %L"
 msgstr ""
 
-#: fortran/expr.c:3975
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Target expression in pointer assignment at %L must deliver a pointer result"
+#: fortran/expr.c:3978
+#, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
-msgstr "Целевое выражение в присваивании указателя в %L должна выдавать указательный результат"
+msgstr "Указатель в %L в присваивании указателя может пережить цель указателя"
 
-#: fortran/expr.c:4051 fortran/resolve.c:1452
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Pointer initialization target at %L must not be ALLOCATABLE "
+#: fortran/expr.c:4054 fortran/resolve.c:1452
+#, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
-msgstr "Цель инициализации указателя в %L не должна быть ALLOCATABLE "
+msgstr "Цель инициализации указателя в %L не должна быть ALLOCATABLE"
 
-#: fortran/expr.c:4057
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Pointer initialization target at %C must have the TARGET attribute"
+#: fortran/expr.c:4060
+#, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the TARGET attribute"
-msgstr "Цель инициализации указателя в %C должна иметь TARGET атрибут"
+msgstr "Цель инициализации указателя в %L должна иметь TARGET атрибут"
 
-#: fortran/expr.c:4072 fortran/resolve.c:1458
+#: fortran/expr.c:4075 fortran/resolve.c:1458
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr "Цель инициализации указателя в %L должна иметь SAVE атрибут"
 
-#: fortran/expr.c:4084
+#: fortran/expr.c:4087
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr "Цель инициализации указателя на процедуру в %L не может быть указателем на процедуру"
 
-#: fortran/expr.c:5512
+#: fortran/expr.c:4557
+#, gcc-internal-format
+msgid "generate_isocbinding_initializer(): bad iso_c_binding type, expected %<c_ptr%> or %<c_funptr%>"
+msgstr ""
+
+#: fortran/expr.c:5568
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr "Fortran 2008: Указательные функции в контексте определения переменных (%s) в %L"
 
-#: fortran/expr.c:5520
+#: fortran/expr.c:5576
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr "Non-variable выражение в контексте определения переменных (%s) в %L"
 
-#: fortran/expr.c:5528
-#, fuzzy, gcc-internal-format
-#| msgid "Named constant '%s' in variable definition context (%s) at %L"
+#: fortran/expr.c:5584
+#, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
-msgstr "Именованная константа '%s' в контексте определения переменных (%s) в %L"
+msgstr "Именованная константа %qs в контексте определения переменных (%s) в %L"
 
-#: fortran/expr.c:5537
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' in variable definition context (%s) at %L is not a variable"
+#: fortran/expr.c:5593
+#, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
-msgstr "'%s' в контексте определения переменных (%s) в %L не есть переменная"
+msgstr "%qs в контексте определения переменных (%s) в %L не есть переменная"
 
-#: fortran/expr.c:5548
+#: fortran/expr.c:5604
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr "Non-POINTER в контексте ассоциации указателей (%s) в %L"
 
-#: fortran/expr.c:5557
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Named constant '%s' in variable definition context (%s) at %L"
+#: fortran/expr.c:5613
+#, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
-msgstr "Именованная константа '%s' в контексте определения переменных (%s) в %L"
+msgstr "Тип недоступен в контексте определения переменных (%s) в %L"
 
-#: fortran/expr.c:5570
+#: fortran/expr.c:5626
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr "LOCK_TYPE в контексте определения переменных (%s) в %L"
 
-#: fortran/expr.c:5583
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "LOCK_TYPE in variable definition context (%s) at %L"
+#: fortran/expr.c:5639
+#, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
-msgstr "LOCK_TYPE в контексте определения переменных (%s) в %L"
+msgstr "LOCK_EVENT в контексте определения переменных (%s) в %L"
 
-#: fortran/expr.c:5613
-#, fuzzy, gcc-internal-format
-#| msgid "Dummy argument '%s' with INTENT(IN) in pointer association context (%s) at %L"
+#: fortran/expr.c:5669
+#, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
-msgstr "Формальный аргумент '%s' с INTENT(IN) в контексте ассоциации указателей (%s) в %L"
+msgstr "Формальный аргумент %qs с INTENT(IN) в контексте ассоциации указателей (%s) в %L"
 
-#: fortran/expr.c:5621
-#, fuzzy, gcc-internal-format
-#| msgid "Dummy argument '%s' with INTENT(IN) in variable definition context (%s) at %L"
+#: fortran/expr.c:5677
+#, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
-msgstr "Формальный аргумент '%s' с INTENT(IN) в контексте определения переменных (%s) в %L"
+msgstr "Формальный аргумент %qs с INTENT(IN) в контексте определения переменных (%s) в %L"
 
-#: fortran/expr.c:5634
-#, fuzzy, gcc-internal-format
-#| msgid "Variable '%s' is PROTECTED and can not appear in a pointer association context (%s) at %L"
+#: fortran/expr.c:5690
+#, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a pointer association context (%s) at %L"
-msgstr "Переменная '%s' является PROTECTED и не может появляться в контексте ассоциации указателей (%s) в %L"
+msgstr "Переменная %qs является PROTECTED и не может появляться в контексте ассоциации указателей (%s) в %L"
 
-#: fortran/expr.c:5642
-#, fuzzy, gcc-internal-format
-#| msgid "Variable '%s' is PROTECTED and can not appear in a variable definition context (%s) at %L"
+#: fortran/expr.c:5698
+#, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a variable definition context (%s) at %L"
-msgstr "Переменная '%s' является PROTECTED и не может появляться в контексте определения переменных (%s) в %L"
+msgstr "Переменная %qs является PROTECTED и не может появляться в контексте определения переменных (%s) в %L"
 
-#: fortran/expr.c:5654
-#, fuzzy, gcc-internal-format
-#| msgid "Variable '%s' can not appear in a variable definition context (%s) at %L in PURE procedure"
+#: fortran/expr.c:5710
+#, gcc-internal-format
 msgid "Variable %qs can not appear in a variable definition context (%s) at %L in PURE procedure"
-msgstr "Переменная '%s' не может появляться в контексте определения переменных (%s) в %L"
+msgstr "Переменная %qs не может появляться в контексте определения переменных (%s) в %L"
 
-#: fortran/expr.c:5713
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
+#: fortran/expr.c:5769
+#, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
-msgstr "'%s' в %L ассоциированное с векторно индексированной целью не может использоваться в контексте определения переменных (%s)"
+msgstr "%qs в %L ассоциированное с векторно индексированной целью не может использоваться в контексте определения переменных (%s)"
 
-#: fortran/expr.c:5717
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' at %L associated to expression can not be used in a variable definition context (%s)"
+#: fortran/expr.c:5773
+#, gcc-internal-format
 msgid "%qs at %L associated to expression can not be used in a variable definition context (%s)"
-msgstr "'%s' в %L ассоциированное с выражением не может использоваться в контексте определения переменных (%s)"
+msgstr "%qs в %L ассоциированное с выражением не может использоваться в контексте определения переменных (%s)"
 
-#: fortran/expr.c:5728
-#, fuzzy, gcc-internal-format
-#| msgid "Associate-name '%s' can not appear in a variable definition context (%s) at %L because its target at %L can not, either"
+#: fortran/expr.c:5784
+#, gcc-internal-format
 msgid "Associate-name %qs can not appear in a variable definition context (%s) at %L because its target at %L can not, either"
-msgstr "Имя ассоциации '%s' не может появляться в контексте определения переменных (%s) в %L поскольку его цель в %L также не может"
+msgstr "Имя ассоциации %qs не может появляться в контексте определения переменных (%s) в %L, поскольку его цель в %L также не может"
 
-#: fortran/expr.c:5770
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "'%s' at %L associated to expression can not be used in a variable definition context (%s)"
+#: fortran/expr.c:5826
+#, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
-msgstr "'%s' в %L ассоциированное с выражением не может использоваться в контексте определения переменных (%s)"
+msgstr "Элементы с одинаковым значением в %L и %L в векторном индексе в контексте определения переменной (%s)"
 
 #: fortran/f95-lang.c:251
 #, gcc-internal-format, gfc-internal-format
@@ -60123,24 +53701,22 @@
 msgid "can't open input file: %s"
 msgstr "ошибка открытия входного файла: %s"
 
-#: fortran/frontend-passes.c:190
-#, fuzzy, gcc-internal-format
-#| msgid "in statement"
+#: fortran/frontend-passes.c:192
+#, gcc-internal-format
 msgid "No location in statement"
-msgstr "в операторе"
+msgstr "Нет расположения в операторе"
 
-#: fortran/frontend-passes.c:205
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Expected exponent in expression at %C"
+#: fortran/frontend-passes.c:207
+#, gcc-internal-format, gfc-internal-format
 msgid "No location in expression near %L"
-msgstr "Ожидалась экспонента в выражении в %C"
+msgstr "Нет расположения в выражении около %L"
 
-#: fortran/frontend-passes.c:409
+#: fortran/frontend-passes.c:414
 #, gcc-internal-format
 msgid "Illegal id in copy_walk_reduction_arg"
-msgstr ""
+msgstr "Некорректный идентификатор в copy_walk_reduction_arg"
 
-#: fortran/frontend-passes.c:817 fortran/trans-array.c:1182
+#: fortran/frontend-passes.c:822 fortran/trans-array.c:1182
 #: fortran/trans-array.c:6440 fortran/trans-array.c:7864
 #: fortran/trans-intrinsic.c:7307
 #, gcc-internal-format, gfc-internal-format
@@ -60147,77 +53723,67 @@
 msgid "Creating array temporary at %L"
 msgstr "Создание временного массива в %L"
 
-#: fortran/frontend-passes.c:842 fortran/frontend-passes.c:846
-#, fuzzy, gcc-internal-format
-#| msgid "Removing call to function '%s' at %L"
+#: fortran/frontend-passes.c:847 fortran/frontend-passes.c:851
+#, gcc-internal-format
 msgid "Removing call to function %qs at %L"
-msgstr "Удаление вызова функции '%s' в %L"
+msgstr "Удаление вызова функции %qs в %L"
 
-#: fortran/frontend-passes.c:1273 fortran/frontend-passes.c:1312
-#, fuzzy, gcc-internal-format
-#| msgid "expected expression"
+#: fortran/frontend-passes.c:1278 fortran/frontend-passes.c:1317
+#, gcc-internal-format
 msgid "bad expression"
-msgstr "ожидалось выражение"
+msgstr ""
 
-#: fortran/frontend-passes.c:1308
-#, fuzzy, gcc-internal-format
-#| msgid "bad move"
+#: fortran/frontend-passes.c:1313
+#, gcc-internal-format
 msgid "bad op"
-msgstr "некорректная пересылка"
+msgstr ""
 
-#: fortran/frontend-passes.c:2161
-#, fuzzy, gcc-internal-format
-#| msgid "invalid operands in gimple comparison"
+#: fortran/frontend-passes.c:2166
+#, gcc-internal-format
 msgid "illegal OP in optimize_comparison"
-msgstr "некорректные операнды в gimple сравнении"
+msgstr "некорректный OP в optimize_comparison"
 
-#: fortran/frontend-passes.c:2407
-#, fuzzy, gcc-internal-format
-#| msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
+#: fortran/frontend-passes.c:2412
+#, gcc-internal-format
 msgid "Variable %qs at %L set to undefined value inside loop  beginning at %L as INTENT(OUT) argument to subroutine %qs"
-msgstr "Переменная '%s' в %C не может быть переопределена внутри цикла начинающегося в %L"
+msgstr "Переменная %qs в %L установлена в неопределенное значение внутри цикла, начинающегося в %L, как INTENT(OUT) аргумент для подпрограммы %qs"
 
-#: fortran/frontend-passes.c:2414
-#, fuzzy, gcc-internal-format
-#| msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
+#: fortran/frontend-passes.c:2419
+#, gcc-internal-format
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to subroutine %qs"
-msgstr "Переменная '%s' в %C не может быть переопределена внутри цикла начинающегося в %L"
+msgstr "Переменная %qs в %L не определяется внутри цикла, начинающегося в %L, как INTENT(OUT) аргумент для подпрограммы %qs"
 
-#: fortran/frontend-passes.c:2637 fortran/frontend-passes.c:2661
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
+#: fortran/frontend-passes.c:2642 fortran/frontend-passes.c:2666
+#, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L out of bounds (%ld < %ld) in loop beginning at %L"
-msgstr "Ссылка на массив в %L вне диапазона (%ld < %ld) в коизмерении %d"
+msgstr ""
 
-#: fortran/frontend-passes.c:2646 fortran/frontend-passes.c:2670
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
+#: fortran/frontend-passes.c:2651 fortran/frontend-passes.c:2675
+#, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L out of bounds (%ld > %ld) in loop beginning at %L"
-msgstr "Ссылка на массив в %L вне диапазона (%ld > %ld) в коизмерении %d"
+msgstr ""
 
-#: fortran/frontend-passes.c:2730
-#, fuzzy, gcc-internal-format
-#| msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
+#: fortran/frontend-passes.c:2735
+#, gcc-internal-format
 msgid "Variable %qs at %L set to undefined value inside loop beginning at %L as INTENT(OUT) argument to function %qs"
-msgstr "Переменная '%s' в %C не может быть переопределена внутри цикла начинающегося в %L"
+msgstr "Переменная %qs в %L установлена в неопределенное значение внутри цикла, начинающегося в %L, как INTENT(OUT) аргумент для функции %qs"
 
-#: fortran/frontend-passes.c:2736
-#, fuzzy, gcc-internal-format
-#| msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
+#: fortran/frontend-passes.c:2741
+#, gcc-internal-format
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
-msgstr "Переменная '%s' в %C не может быть переопределена внутри цикла начинающегося в %L"
+msgstr "Переменная %qs в %L не определяется внутри цикла, начинающегося в %L, как INTENT(OUT) аргумент для функции %qs"
 
-#: fortran/frontend-passes.c:3128 fortran/trans-expr.c:1581
+#: fortran/frontend-passes.c:3133 fortran/trans-expr.c:1581
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
-msgstr ""
+msgstr "Код для переразмещения размещаемого массива в %L будет добавлен"
 
-#: fortran/frontend-passes.c:3637
+#: fortran/frontend-passes.c:3642
 #, gcc-internal-format
 msgid "Scalarization using DIMEN_RANGE unimplemented"
-msgstr ""
+msgstr "Скаляризация, использующая DIMEN_RANGE, не реализована"
 
-#: fortran/frontend-passes.c:4429
+#: fortran/frontend-passes.c:4434
 #, gcc-internal-format, gfc-internal-format
 msgid "Interchanging loops at %L"
 msgstr ""
@@ -60243,16 +53809,14 @@
 msgstr "Синтаксическая ошибка: Мусор в хвосте INTERFACE оператора в %C"
 
 #: fortran/interface.c:272
-#, fuzzy, gcc-internal-format
-#| msgid "Dummy procedure '%s' at %C cannot have a generic interface"
+#, gcc-internal-format
 msgid "Dummy procedure %qs at %C cannot have a generic interface"
-msgstr "Формальная процедура '%s' в %C не может иметь generic интерфейс"
+msgstr "Формальная процедура %qs в %C не может иметь generic интерфейс"
 
 #: fortran/interface.c:305
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2003: ABSTRACT INTERFACE at %C"
+#, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT INTERFACE at %C"
-msgstr "Fortran 2003: ABSTRACT INTERFACE в %C"
+msgstr "ABSTRACT INTERFACE в %C"
 
 #: fortran/interface.c:312
 #, gcc-internal-format, gfc-internal-format
@@ -60270,39 +53834,34 @@
 msgstr "Ожидался безымянный интерфейс в %C"
 
 #: fortran/interface.c:369
-#, fuzzy, gcc-internal-format
-#| msgid "Expected 'END INTERFACE ASSIGNMENT (=)' at %C"
+#, gcc-internal-format
 msgid "Expected %<END INTERFACE ASSIGNMENT (=)%> at %C"
-msgstr "Ожидалось 'END INTERFACE ASSIGNMENT (=)' в %C"
+msgstr "Ожидалось %<END INTERFACE ASSIGNMENT (=)%> в %C"
 
 #: fortran/interface.c:400
-#, fuzzy, gcc-internal-format
-#| msgid "Expecting 'END INTERFACE OPERATOR (.%s.)' at %C"
+#, gcc-internal-format
 msgid "Expecting %<END INTERFACE OPERATOR (%s)%> at %C"
-msgstr "Ожидался 'END INTERFACE OPERATOR (.%s.)' в %C"
+msgstr "Ожидается %<END INTERFACE OPERATOR (%s)%> в %C"
 
 #: fortran/interface.c:403
-#, fuzzy, gcc-internal-format
-#| msgid "Expecting 'END INTERFACE OPERATOR (%s)' at %C, but got %s"
+#, gcc-internal-format
 msgid "Expecting %<END INTERFACE OPERATOR (%s)%> at %C, but got %qs"
-msgstr "Ожидался 'END INTERFACE OPERATOR (%s)' в %C, а получено %s"
+msgstr "Ожидается %<END INTERFACE OPERATOR (%s)%> в %C, а получено %qs"
 
 #: fortran/interface.c:417
-#, fuzzy, gcc-internal-format
-#| msgid "Expecting 'END INTERFACE OPERATOR (.%s.)' at %C"
+#, gcc-internal-format
 msgid "Expecting %<END INTERFACE OPERATOR (.%s.)%> at %C"
-msgstr "Ожидался 'END INTERFACE OPERATOR (.%s.)' в %C"
+msgstr "Ожидается %<END INTERFACE OPERATOR (.%s.)%> в %C"
 
 #: fortran/interface.c:429
-#, fuzzy, gcc-internal-format
-#| msgid "Expecting 'END INTERFACE %s' at %C"
+#, gcc-internal-format
 msgid "Expecting %<END INTERFACE %s%> at %C"
-msgstr "Ожидалось 'END INTERFACE %s' в %C"
+msgstr "Ожидается %<END INTERFACE %s%> в %C"
 
 #: fortran/interface.c:619
 #, gcc-internal-format
 msgid "gfc_compare_derived_types: invalid derived type"
-msgstr ""
+msgstr "gfc_compare_derived_types: некорректный производный тип"
 
 #: fortran/interface.c:871
 #, gcc-internal-format, gfc-internal-format
@@ -60344,12 +53903,12 @@
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "Второй аргумент определенного присваивания в %L должен быть INTENT(IN)"
 
-#: fortran/interface.c:970 fortran/resolve.c:16351
+#: fortran/interface.c:970 fortran/resolve.c:16378
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "Первый аргумент интерфейса оператора в %L должен быть INTENT(IN)"
 
-#: fortran/interface.c:977 fortran/resolve.c:16369
+#: fortran/interface.c:977 fortran/resolve.c:16396
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "Второй аргумент интерфейса оператора в %L должен быть INTENT(IN)"
@@ -60362,41 +53921,37 @@
 #: fortran/interface.c:1419 fortran/interface.c:1478
 #, gcc-internal-format, gfc-internal-format
 msgid "check_dummy_characteristics: Unexpected result %i of gfc_dep_compare_expr"
-msgstr ""
+msgstr "check_dummy_characteristics: Неожиданный результат %i от gfc_dep_compare_expr"
 
 #: fortran/interface.c:1591
 #, gcc-internal-format, gfc-internal-format
 msgid "check_result_characteristics (1): Unexpected result %i of gfc_dep_compare_expr"
-msgstr ""
+msgstr "check_result_characteristics (1): Неожиданный результат %i от gfc_dep_compare_expr"
 
 #: fortran/interface.c:1638
 #, gcc-internal-format, gfc-internal-format
 msgid "check_result_characteristics (2): Unexpected result %i of gfc_dep_compare_expr"
-msgstr ""
+msgstr "check_result_characteristics (2): Неожиданный результат %i от gfc_dep_compare_expr"
 
 #: fortran/interface.c:1810
-#, fuzzy, gcc-internal-format
-#| msgid "Procedure '%s' in %s at %L has no explicit interface"
+#, gcc-internal-format
 msgid "Procedure %qs in %s at %L has no explicit interface; did you mean %qs?"
-msgstr "Процедура '%s' в %s в %L не имеет явного интерфейса"
+msgstr ""
 
 #: fortran/interface.c:1815
-#, fuzzy, gcc-internal-format
-#| msgid "Procedure '%s' in %s at %L has no explicit interface"
+#, gcc-internal-format
 msgid "Procedure %qs in %s at %L has no explicit interface"
-msgstr "Процедура '%s' в %s в %L не имеет явного интерфейса"
+msgstr "Процедура %qs в %s в %L не имеет явного интерфейса"
 
 #: fortran/interface.c:1819
-#, fuzzy, gcc-internal-format
-#| msgid "Procedure '%s' in %s at %L is neither function nor subroutine"
+#, gcc-internal-format
 msgid "Procedure %qs in %s at %L is neither function nor subroutine; did you mean %qs?"
-msgstr "Процедура '%s' в %s в %L не функция и не подпрограмма"
+msgstr ""
 
 #: fortran/interface.c:1823
-#, fuzzy, gcc-internal-format
-#| msgid "Procedure '%s' in %s at %L is neither function nor subroutine"
+#, gcc-internal-format
 msgid "Procedure %qs in %s at %L is neither function nor subroutine"
-msgstr "Процедура '%s' в %s в %L не функция и не подпрограмма"
+msgstr "Процедура %qs в %s в %L не функция и не подпрограмма"
 
 #: fortran/interface.c:1835
 #, gcc-internal-format, gfc-internal-format
@@ -60406,55 +53961,47 @@
 #: fortran/interface.c:1839
 #, gcc-internal-format, gfc-internal-format
 msgid "In %s at %L procedures must be all FUNCTIONs as the generic name is also the name of a derived type"
-msgstr "В %s в %L процедуры должны быть все FUNCTIONs поскольку generic имя есть также имя производного типа"
+msgstr "В %s в %L процедуры должны быть все FUNCTIONs, поскольку generic имя есть также имя производного типа"
 
 #: fortran/interface.c:1847
-#, fuzzy, gcc-internal-format
-#| msgid "Fortran 2008: Internal procedure '%s' in %s at %L"
+#, gcc-internal-format
 msgid "Internal procedure %qs in %s at %L"
-msgstr "Fortran 2008: Внутренняя процедура '%s' в %s в %L"
+msgstr "Внутренняя процедура %qs в %s в %L"
 
 #: fortran/interface.c:1904 fortran/interface.c:1909
-#, fuzzy, gcc-internal-format
-#| msgid "Ambiguous interfaces '%s' and '%s' in %s at %L"
+#, gcc-internal-format
 msgid "Ambiguous interfaces in %s for %qs at %L and %qs at %L"
-msgstr "Неоднозначные интерфейсы '%s' и '%s' в %s в %L"
+msgstr "Неоднозначные интерфейсы в %s для %qs в %L и %qs в %L"
 
 #: fortran/interface.c:1914
-#, fuzzy, gcc-internal-format
-#| msgid "Although not referenced, '%s' has ambiguous interfaces at %L"
+#, gcc-internal-format
 msgid "Although not referenced, %qs has ambiguous interfaces at %L"
-msgstr "Хотя без ссылки, '%s' имеет неоднозначные интерфейсы в %L"
+msgstr "Хотя на нее нет ссылки, %qs имеет неоднозначные интерфейсы в %L"
 
 #: fortran/interface.c:1949
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' at %L is not a module procedure"
+#, gcc-internal-format
 msgid "%qs at %L is not a module procedure"
-msgstr "'%s' в %L не есть процедура модуля"
+msgstr "%qs в %L не есть процедура модуля"
 
 #: fortran/interface.c:2152
-#, fuzzy, gcc-internal-format
-#| msgid "Assumed shape array at %L must be a dummy argument"
+#, gcc-internal-format
 msgid "The assumed-rank array at %L requires that the dummy argument %qs has assumed-rank"
-msgstr "Массив предполагаемой формы в %L должен быть формальным аргументом"
+msgstr "Массив предполагаемого ранга в %L требует, чтобы формальный аргумент %qs имел предполагаемый ранг"
 
 #: fortran/interface.c:2155
-#, fuzzy, gcc-internal-format
-#| msgid "Rank mismatch in argument '%s' at %L (scalar and rank-%d)"
+#, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (scalar and rank-%d)"
-msgstr "Несоответствие рангов в аргументе '%s' в %L (скаляр и ранг--%d)"
+msgstr "Несоответствие рангов в аргументе %qs в %L (скаляр и ранг-%d)"
 
 #: fortran/interface.c:2158
-#, fuzzy, gcc-internal-format
-#| msgid "Rank mismatch in argument '%s' at %L (rank-%d and scalar)"
+#, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (rank-%d and scalar)"
-msgstr "Несоответствие рангов в аргументе '%s' в %L (ранг--%d и скаляр)"
+msgstr "Несоответствие рангов в аргументе %qs в %L (ранг-%d и скаляр)"
 
 #: fortran/interface.c:2161
-#, fuzzy, gcc-internal-format
-#| msgid "Rank mismatch in argument '%s' at %L (rank-%d and rank-%d)"
+#, gcc-internal-format
 msgid "Rank mismatch in argument %qs at %L (rank-%d and rank-%d)"
-msgstr "Несоответствие рангов в аргументе '%s' в %L (ранг--%d и ранг--%d)"
+msgstr "Несоответствие рангов в аргументе %qs в %L (ранг-%d и ранг-%d)"
 
 #: fortran/interface.c:2203
 #, gcc-internal-format, gfc-internal-format
@@ -60462,141 +54009,119 @@
 msgstr "Некорректный аргумент процедуры в %L"
 
 #: fortran/interface.c:2212 fortran/interface.c:2240
-#, fuzzy, gcc-internal-format
-#| msgid "Interface mismatch in dummy procedure '%s' at %L: %s"
+#, gcc-internal-format
 msgid "Interface mismatch in dummy procedure %qs at %L: %s"
-msgstr "Несоответствие интерфейса в формальной процедуре '%s' в %L: %s"
+msgstr "Несоответствие интерфейса в формальной процедуре %qs в %L: %s"
 
 #: fortran/interface.c:2251
-#, fuzzy, gcc-internal-format
-#| msgid "Actual argument to contiguous pointer dummy '%s' at %L must be simply contigous"
+#, gcc-internal-format
 msgid "Actual argument to contiguous pointer dummy %qs at %L must be simply contiguous"
-msgstr "Фактический аргумент для непрерывного указательного формального параметра '%s' в %L должен быть просто непрерывным"
+msgstr "Фактический аргумент для непрерывного указательного формального параметра %qs в %L должен быть просто непрерывным"
 
 #: fortran/interface.c:2271
-#, fuzzy, gcc-internal-format
-#| msgid "Type mismatch in argument '%s' at %L; passed %s to %s"
+#, gcc-internal-format
 msgid "Type mismatch in argument %qs at %L; passed %s to %s"
-msgstr "Несоответствие типа в аргументе '%s' в %L; передано %s в %s"
+msgstr "Несоответствие типа в аргументе %qs в %L; передано %s в %s"
 
 #: fortran/interface.c:2280
-#, fuzzy, gcc-internal-format
-#| msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument '%s' due to VOLATILE attribute"
+#, gcc-internal-format
 msgid "Assumed-type actual argument at %L requires that dummy argument %qs is of assumed type"
-msgstr "Фактический аргумент предполагаемой формы в %L несовместим с non-assumed-shape формальным аргументом '%s' из-за VOLATILE атрибута"
+msgstr "Фактический аргумент предполагаемого типа в %L требует, чтобы формальный аргумент %qs был предполагаемого типа"
 
 #: fortran/interface.c:2296
-#, fuzzy, gcc-internal-format
-#| msgid "Actual argument to '%s' at %L must be polymorphic"
+#, gcc-internal-format
 msgid "Actual argument to %qs at %L must be polymorphic"
-msgstr "Фактический аргумент для '%s' в %L должен быть полиморфным"
+msgstr "Фактический аргумент для %qs в %L должен быть полиморфным"
 
 #: fortran/interface.c:2306
-#, fuzzy, gcc-internal-format
-#| msgid "Actual argument to '%s' at %L must have the same declared type"
+#, gcc-internal-format
 msgid "Actual argument to %qs at %L must have the same declared type"
-msgstr "Фактический аргумент для '%s' в %L должен иметь тот же декларированный тип"
+msgstr "Фактический аргумент для %qs в %L должен иметь тот же декларированный тип"
 
 #: fortran/interface.c:2321
 #, gcc-internal-format
 msgid "Actual argument to %qs at %L must be unlimited polymorphic since the formal argument is a pointer or allocatable unlimited polymorphic entity [F2008: 12.5.2.5]"
-msgstr ""
+msgstr "Фактический аргумент для %qs в %L должен быть неограниченно полиморфным, так как формальный аргумент есть указатель или размещаемая неограниченно полиморфная сущность [F2008: 12.5.2.5]"
 
 #: fortran/interface.c:2332
-#, fuzzy, gcc-internal-format
-#| msgid "Actual argument to '%s' at %L must be a coarray"
+#, gcc-internal-format
 msgid "Actual argument to %qs at %L must be a coarray"
-msgstr "Фактический аргумент для '%s' в %L должен быть комассивом"
+msgstr "Фактический аргумент для %qs в %L должен быть комассивом"
 
 #: fortran/interface.c:2351
-#, fuzzy, gcc-internal-format
-#| msgid "Corank mismatch in argument '%s' at %L (%d and %d)"
+#, gcc-internal-format
 msgid "Corank mismatch in argument %qs at %L (%d and %d)"
-msgstr "Несоответствие корангов в аргументе '%s' в %L (%d и %d)"
+msgstr "Несоответствие корангов в аргументе %qs в %L (%d и %d)"
 
 #: fortran/interface.c:2369
-#, fuzzy, gcc-internal-format
-#| msgid "Actual argument to '%s' at %L must be simply contiguous"
+#, gcc-internal-format
 msgid "Actual argument to %qs at %L must be simply contiguous or an element of such an array"
-msgstr "Фактический аргумент для '%s' в %L должен быть просто непрерывным"
+msgstr "Фактический аргумент для %qs в %L должен быть просто непрерывным или элементом такого массива"
 
 #: fortran/interface.c:2384
-#, fuzzy, gcc-internal-format
-#| msgid "Actual argument to non-INTENT(INOUT) dummy '%s' at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
+#, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
-msgstr "Фактический аргумент для non-INTENT(INOUT) формального параметра '%s' в %L, который есть LOCK_TYPE или имеет LOCK_TYPE компонент"
+msgstr "Фактический аргумент для не-INTENT(INOUT) формального параметра %qs в %L, который есть LOCK_TYPE или имеет LOCK_TYPE компонент"
 
 #: fortran/interface.c:2399
-#, fuzzy, gcc-internal-format
-#| msgid "Actual argument to non-INTENT(INOUT) dummy '%s' at %L, which is LOCK_TYPE or has a LOCK_TYPE component"
+#, gcc-internal-format
 msgid "Actual argument to non-INTENT(INOUT) dummy %qs at %L, which is EVENT_TYPE or has a EVENT_TYPE component"
-msgstr "Фактический аргумент для non-INTENT(INOUT) формального параметра '%s' в %L, который есть LOCK_TYPE или имеет LOCK_TYPE компонент"
+msgstr "Фактический аргумент для не-INTENT(INOUT) формального параметра %qs в %L, который есть EVENT_TYPE или имеет EVENT_TYPE компонент"
 
 #: fortran/interface.c:2418
-#, fuzzy, gcc-internal-format
-#| msgid "Dummy argument '%s' has to be a pointer or assumed-shape array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
+#, gcc-internal-format
 msgid "Dummy argument %qs has to be a pointer, assumed-shape or assumed-rank array without CONTIGUOUS attribute - as actual argument at %L is not simply contiguous and both are ASYNCHRONOUS or VOLATILE"
-msgstr "Формальный аргумент '%s' должен быть указателем или массивом предполагаемой формы без CONTIGUOUS атрибута - поскольку фактический аргумент в %L не является просто непрерывным и оба являются ASYNCHRONOUS или VOLATILE"
+msgstr "Формальный аргумент %qs должен быть указателем или массивом предполагаемой формы или ранга без CONTIGUOUS атрибута - поскольку фактический аргумент в %L не является просто непрерывным и оба являются ASYNCHRONOUS или VOLATILE"
 
 #: fortran/interface.c:2431
-#, fuzzy, gcc-internal-format
-#| msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument '%s'"
+#, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray, INTENT(OUT) dummy argument %qs"
-msgstr "Передача комассива в %L в allocatable, noncoarray, INTENT(OUT) формальный аргумент '%s'"
+msgstr "Передача комассива в %L в allocatable, noncoarray, INTENT(OUT) формальный аргумент %qs"
 
 #: fortran/interface.c:2438
-#, fuzzy, gcc-internal-format
-#| msgid "Passing coarray at %L to allocatable, noncoarray dummy argument '%s', which is invalid if the allocation status is modified"
+#, gcc-internal-format
 msgid "Passing coarray at %L to allocatable, noncoarray dummy argument %qs, which is invalid if the allocation status is modified"
-msgstr "Передача комассива в %L в allocatable, noncoarray формальный аргумент '%s', что некорректно если статус размещения модифицирован"
+msgstr "Передача комассива в %L в allocatable, noncoarray формальный аргумент %qs, что некорректно, если статус размещения модифицирован"
 
 #: fortran/interface.c:2501
-#, fuzzy, gcc-internal-format
-#| msgid "Polymorphic scalar passed to array dummy argument '%s' at %L"
+#, gcc-internal-format
 msgid "Polymorphic scalar passed to array dummy argument %qs at %L"
-msgstr "Полиморфный скаляр передан в формальный аргумент массив '%s' в %L"
+msgstr "Полиморфный скаляр передан в формальный аргумент массив %qs в %L"
 
 #: fortran/interface.c:2510
-#, fuzzy, gcc-internal-format
-#| msgid "Element of assumed-shaped or pointer array passed to array dummy argument '%s' at %L"
+#, gcc-internal-format
 msgid "Element of assumed-shaped or pointer array passed to array dummy argument %qs at %L"
-msgstr "Элемент массива предполагаемой формы или указательного передан в формальный аргумент массив '%s' в %L"
+msgstr "Элемент массива предполагаемой формы или указательного передан в формальный аргумент массив %qs в %L"
 
 #: fortran/interface.c:2522
-#, fuzzy, gcc-internal-format
-#| msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument '%s' at %L"
+#, gcc-internal-format
 msgid "Extension: Scalar non-default-kind, non-C_CHAR-kind CHARACTER actual argument with array dummy argument %qs at %L"
-msgstr "Расширение: Скалярный неподразумеваемого вида, non-C_CHAR-kind CHARACTER фактический аргумент с формальным аргументом массивом '%s' в %L"
+msgstr "Расширение: Скалярный неподразумеваемого вида, не-C_CHAR-вида CHARACTER фактический аргумент с формальным аргументом массивом %qs в %L"
 
 #: fortran/interface.c:2530
-#, fuzzy, gcc-internal-format
-#| msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument '%s' at %L"
+#, gcc-internal-format
 msgid "Fortran 2003: Scalar CHARACTER actual argument with array dummy argument %qs at %L"
-msgstr "Fortran 2003: Скалярный CHARACTER фактический аргумент с формальным аргументом массивом '%s' в %L"
+msgstr "Fortran 2003: Скалярный CHARACTER фактический аргумент с формальным аргументом массивом %qs в %L"
 
 #: fortran/interface.c:2870
-#, fuzzy, gcc-internal-format
-#| msgid "Keyword argument '%s' at %L is not in the procedure"
+#, gcc-internal-format
 msgid "Keyword argument %qs at %L is invalid in a statement function"
-msgstr "Аргумент с ключевым словом '%s' в %L не в процедуре"
+msgstr ""
 
 #: fortran/interface.c:2893
-#, fuzzy, gcc-internal-format
-#| msgid "Keyword argument '%s' at %L is not in the procedure"
+#, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure; did you mean %qs?"
-msgstr "Аргумент с ключевым словом '%s' в %L не в процедуре"
+msgstr ""
 
 #: fortran/interface.c:2897
-#, fuzzy, gcc-internal-format
-#| msgid "Keyword argument '%s' at %L is not in the procedure"
+#, gcc-internal-format
 msgid "Keyword argument %qs at %L is not in the procedure"
-msgstr "Аргумент с ключевым словом '%s' в %L не в процедуре"
+msgstr "Аргумент с ключевым словом %qs в %L не в процедуре"
 
 #: fortran/interface.c:2906
-#, fuzzy, gcc-internal-format
-#| msgid "Keyword argument '%s' at %L is already associated with another actual argument"
+#, gcc-internal-format
 msgid "Keyword argument %qs at %L is already associated with another actual argument"
-msgstr "Аргумент с ключевым словом '%s' в %L уже ассоциирован с другим фактическим аргументом"
+msgstr "Аргумент с ключевым словом %qs в %L уже ассоциирован с другим фактическим аргументом"
 
 #: fortran/interface.c:2916
 #, gcc-internal-format, gfc-internal-format
@@ -60614,173 +54139,149 @@
 msgstr "Неожиданная спецификация альтернативного возврата в вызове подпрограммы в %L"
 
 #: fortran/interface.c:2963
-#, fuzzy, gcc-internal-format
-#| msgid "Unexpected NULL() intrinsic at %L to dummy '%s'"
+#, gcc-internal-format
 msgid "Unexpected NULL() intrinsic at %L to dummy %qs"
-msgstr "Неожиданная NULL() встроенная в %L в формальный параметр '%s'"
+msgstr "Неожиданная NULL() встроенная функция в %L для формального параметра %qs"
 
 #: fortran/interface.c:2966
-#, fuzzy, gcc-internal-format
-#| msgid "Fortran 2008: Null pointer at %L to non-pointer dummy '%s'"
+#, gcc-internal-format
 msgid "Fortran 2008: Null pointer at %L to non-pointer dummy %qs"
-msgstr "Fortran 2008: Пустой указатель в %L в неуказательный формальный параметр '%s'"
+msgstr "Fortran 2008: Пустой указатель в %L в неуказательный формальный параметр %qs"
 
 #: fortran/interface.c:2990
 #, gcc-internal-format, gfc-internal-format
 msgid "Actual argument at %L to assumed-type dummy is of derived type with type-bound or FINAL procedures"
-msgstr ""
+msgstr "Фактический аргумент в %L для формального параметра предполагаемого типа имеет производный тип с type-bound или FINAL процедурами"
 
 #: fortran/interface.c:3013
-#, fuzzy, gcc-internal-format
-#| msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument '%s' at %L"
+#, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and pointer or allocatable dummy argument %qs at %L"
-msgstr "Несоответствие character длин (%ld/%ld) между фактическим аргументом и указательным или размещаемым формальным аргументом '%s' в %L"
+msgstr "Несоответствие character длин (%ld/%ld) между фактическим аргументом и указательным или размещаемым формальным аргументом %qs в %L"
 
 #: fortran/interface.c:3021
-#, fuzzy, gcc-internal-format
-#| msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument '%s' at %L"
+#, gcc-internal-format
 msgid "Character length mismatch (%ld/%ld) between actual argument and assumed-shape dummy argument %qs at %L"
-msgstr "Несоответствие character длин (%ld/%ld) между фактическим аргументом и формальным аргументом предполагаемой формы '%s' в %L"
+msgstr "Несоответствие character длин (%ld/%ld) между фактическим аргументом и формальным аргументом предполагаемой формы %qs в %L"
 
 #: fortran/interface.c:3035
-#, fuzzy, gcc-internal-format
-#| msgid "Actual argument at %L to allocatable or pointer dummy argument '%s' must have a deferred length type parameter if and only if the dummy has one"
+#, gcc-internal-format
 msgid "Actual argument at %L to allocatable or pointer dummy argument %qs must have a deferred length type parameter if and only if the dummy has one"
-msgstr "Фактический аргумент в %L в размещаемый или указательный формальный аргумент '%s' должен иметь типовый параметр отложенной длины тогда и только тогда когда таковой имеется у формального"
+msgstr "Фактический аргумент в %L в размещаемый или указательный формальный аргумент %qs должен иметь типовый параметр отложенной длины тогда и только тогда, когда таковой имеется у формального"
 
 #: fortran/interface.c:3053
-#, fuzzy, gcc-internal-format
-#| msgid "Character length of actual argument shorter than of dummy argument '%s' (%lu/%lu) at %L"
+#, gcc-internal-format
 msgid "Character length of actual argument shorter than of dummy argument %qs (%lu/%lu) at %L"
-msgstr "Character длина фактического аргумента короче чем у формального аргумента '%s' (%lu/%lu) в %L"
+msgstr "Character длина фактического аргумента короче чем у формального аргумента %qs (%lu/%lu) в %L"
 
 #: fortran/interface.c:3062 fortran/interface.c:3067
-#, fuzzy, gcc-internal-format
-#| msgid "Actual argument contains too few elements for dummy argument '%s' (%lu/%lu) at %L"
+#, gcc-internal-format
 msgid "Actual argument contains too few elements for dummy argument %qs (%lu/%lu) at %L"
-msgstr "Фактический аргумент содержит слишком мало элементов для формального аргумента '%s' (%lu/%lu) в %L"
+msgstr "Фактический аргумент содержит слишком мало элементов для формального аргумента %qs (%lu/%lu) в %L"
 
 #: fortran/interface.c:3087
-#, fuzzy, gcc-internal-format
-#| msgid "Expected a procedure pointer for argument '%s' at %L"
+#, gcc-internal-format
 msgid "Expected a procedure pointer for argument %qs at %L"
-msgstr "Ожидался указатель на процедуру для аргумента '%s' в %L"
+msgstr "Ожидался указатель на процедуру для аргумента %qs в %L"
 
 #: fortran/interface.c:3103
-#, fuzzy, gcc-internal-format
-#| msgid "Expected a procedure for argument '%s' at %L"
+#, gcc-internal-format
 msgid "Expected a procedure for argument %qs at %L"
-msgstr "Ожидалась процедура для аргумента '%s' в %L"
+msgstr "Ожидалась процедура для аргумента %qs в %L"
 
 #: fortran/interface.c:3117
-#, fuzzy, gcc-internal-format
-#| msgid "Actual argument for '%s' cannot be an assumed-size array at %L"
+#, gcc-internal-format
 msgid "Actual argument for %qs cannot be an assumed-size array at %L"
-msgstr "Фактический аргумент для '%s' не может быть массивом предполагаемого размера в %L"
+msgstr "Фактический аргумент для %qs не может быть массивом предполагаемого размера в %L"
 
 #: fortran/interface.c:3126
-#, fuzzy, gcc-internal-format
-#| msgid "Actual argument for '%s' must be a pointer at %L"
+#, gcc-internal-format
 msgid "Actual argument for %qs must be a pointer at %L"
-msgstr "Фактический аргумент для '%s' должен быть указателем в %L"
+msgstr "Фактический аргумент для %qs должен быть указателем в %L"
 
 #: fortran/interface.c:3136
-#, fuzzy, gcc-internal-format
-#| msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy '%s'"
+#, gcc-internal-format
 msgid "Fortran 2008: Non-pointer actual argument at %L to pointer dummy %qs"
-msgstr "Fortran 2008: Неуказательный фактический аргумент в %L в указательный формальный параметр '%s'"
+msgstr "Fortran 2008: Неуказательный фактический аргумент в %L в указательный формальный параметр %qs"
 
 #: fortran/interface.c:3146
-#, fuzzy, gcc-internal-format
-#| msgid "Coindexed actual argument at %L to pointer dummy '%s'"
+#, gcc-internal-format
 msgid "Coindexed actual argument at %L to pointer dummy %qs"
-msgstr "Коиндексированный фактический аргумент в %L в указательный формальный параметр '%s'"
+msgstr "Коиндексированный фактический аргумент в %L в указательный формальный параметр %qs"
 
 #: fortran/interface.c:3159
-#, fuzzy, gcc-internal-format
-#| msgid "Coindexed actual argument at %L to allocatable dummy '%s' requires INTENT(IN)"
+#, gcc-internal-format
 msgid "Coindexed actual argument at %L to allocatable dummy %qs requires INTENT(IN)"
-msgstr "Коиндексированный фактический аргумент в %L в размещаемый формальный параметр '%s' требует INTENT(IN)"
+msgstr "Коиндексированный фактический аргумент в %L в размещаемый формальный параметр %qs требует INTENT(IN)"
 
 #: fortran/interface.c:3173
-#, fuzzy, gcc-internal-format
-#| msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy '%s' has neither ASYNCHRONOUS nor VOLATILE"
+#, gcc-internal-format
 msgid "Coindexed ASYNCHRONOUS or VOLATILE actual argument at %L requires that dummy %qs has neither ASYNCHRONOUS nor VOLATILE"
-msgstr "Коиндексированный ASYNCHRONOUS или VOLATILE фактический аргумент в %L требует чтобы формальный параметр '%s' не имел ни ASYNCHRONOUS ни VOLATILE"
+msgstr "Коиндексированный ASYNCHRONOUS или VOLATILE фактический аргумент в %L требует, чтобы формальный параметр %qs не имел ни ASYNCHRONOUS ни VOLATILE"
 
 #: fortran/interface.c:3187
-#, fuzzy, gcc-internal-format
-#| msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy '%s' requires either VALUE or INTENT(IN)"
+#, gcc-internal-format
 msgid "Coindexed actual argument at %L with allocatable ultimate component to dummy %qs requires either VALUE or INTENT(IN)"
-msgstr "Коиндексированный фактический аргумент в %L с размещаемым окончательным компонентом для формального параметра '%s' требует либо VALUE либо INTENT(IN)"
+msgstr "Коиндексированный фактический аргумент в %L с размещаемым окончательным компонентом для формального параметра %qs требует либо VALUE либо INTENT(IN)"
 
 #: fortran/interface.c:3199
-#, fuzzy, gcc-internal-format
-#| msgid "Actual CLASS array argument for '%s' must be a full array at %L"
+#, gcc-internal-format
 msgid "Actual CLASS array argument for %qs must be a full array at %L"
-msgstr "Фактический аргумент CLASS array для '%s' должен быть полным массивом в %L"
+msgstr "Фактический аргумент CLASS массив для %qs должен быть полным массивом в %L"
 
 #: fortran/interface.c:3209
-#, fuzzy, gcc-internal-format
-#| msgid "Actual argument for '%s' must be ALLOCATABLE at %L"
+#, gcc-internal-format
 msgid "Actual argument for %qs must be ALLOCATABLE at %L"
-msgstr "Фактический аргумент для '%s' должен быть ALLOCATABLE в %L"
+msgstr "Фактический аргумент для %qs должен быть ALLOCATABLE в %L"
 
 #: fortran/interface.c:3239
-#, fuzzy, gcc-internal-format
-#| msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument '%s'"
+#, gcc-internal-format
 msgid "Array-section actual argument with vector subscripts at %L is incompatible with INTENT(OUT), INTENT(INOUT), VOLATILE or ASYNCHRONOUS attribute of the dummy argument %qs"
-msgstr "Фактический аргумент секция массива с векторными индексами в %L несовместим с INTENT(OUT), INTENT(INOUT), VOLATILE или ASYNCHRONOUS атрибутом формального аргумента '%s'"
+msgstr "Фактический аргумент секция массива с векторными индексами в %L несовместим с INTENT(OUT), INTENT(INOUT), VOLATILE или ASYNCHRONOUS атрибутом формального аргумента %qs"
 
 #: fortran/interface.c:3258
-#, fuzzy, gcc-internal-format
-#| msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument '%s' due to VOLATILE attribute"
+#, gcc-internal-format
 msgid "Assumed-shape actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
-msgstr "Фактический аргумент предполагаемой формы в %L несовместим с non-assumed-shape формальным аргументом '%s' из-за VOLATILE атрибута"
+msgstr "Фактический аргумент предполагаемой формы в %L несовместим с non-assumed-shape формальным аргументом %qs из-за VOLATILE атрибута"
 
 #: fortran/interface.c:3275
-#, fuzzy, gcc-internal-format
-#| msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument '%s' due to VOLATILE attribute"
+#, gcc-internal-format
 msgid "Array-section actual argument at %L is incompatible with the non-assumed-shape dummy argument %qs due to VOLATILE attribute"
-msgstr "Фактический аргумент секция массива в %L несовместим с non-assumed-shape формальным аргументом '%s' из-за VOLATILE атрибута"
+msgstr "Фактический аргумент секция массива в %L несовместим с non-assumed-shape формальным аргументом %qs из-за VOLATILE атрибута"
 
 #: fortran/interface.c:3295
-#, fuzzy, gcc-internal-format
-#| msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument '%s' due to VOLATILE attribute"
+#, gcc-internal-format
 msgid "Pointer-array actual argument at %L requires an assumed-shape or pointer-array dummy argument %qs due to VOLATILE attribute"
-msgstr "Фактический аргумент pointer-array в %L требует assumed-shape или pointer-array формальный аргумент '%s' из-за VOLATILE атрибута"
+msgstr "Фактический аргумент pointer-array в %L требует assumed-shape или pointer-array формальный аргумент %qs из-за VOLATILE атрибута"
 
 #: fortran/interface.c:3326
-#, fuzzy, gcc-internal-format
-#| msgid "Missing actual argument for argument '%s' at %L"
+#, gcc-internal-format
 msgid "Missing actual argument for argument %qs at %L"
-msgstr "Отсутствует фактический аргумент для аргумента '%s' в %L"
+msgstr "Отсутствует фактический аргумент для аргумента %qs в %L"
 
 #: fortran/interface.c:3445
 #, gcc-internal-format
 msgid "compare_actual_expr(): Bad component code"
-msgstr ""
+msgstr "compare_actual_expr(): Некорректный код компонента"
 
 #: fortran/interface.c:3474
 #, gcc-internal-format
 msgid "check_some_aliasing(): List mismatch"
-msgstr ""
+msgstr "check_some_aliasing(): Несоответствие списка"
 
 #: fortran/interface.c:3500
 #, gcc-internal-format
 msgid "check_some_aliasing(): corrupted data"
-msgstr ""
+msgstr "check_some_aliasing(): поврежденные данные"
 
 #: fortran/interface.c:3510
-#, fuzzy, gcc-internal-format
-#| msgid "Same actual argument associated with INTENT(%s) argument '%s' and INTENT(%s) argument '%s' at %L"
+#, gcc-internal-format
 msgid "Same actual argument associated with INTENT(%s) argument %qs and INTENT(%s) argument %qs at %L"
-msgstr "Один и тот же фактический аргумент ассоциирован с INTENT(%s) аргументом '%s' и INTENT(%s) аргументом '%s' в %L"
+msgstr "Один и тот же фактический аргумент ассоциирован с INTENT(%s) аргументом %qs и INTENT(%s) аргументом %qs в %L"
 
 #: fortran/interface.c:3540
 #, gcc-internal-format
 msgid "check_intents(): List mismatch"
-msgstr ""
+msgstr "check_intents(): Несоответствие списка"
 
 #: fortran/interface.c:3560
 #, gcc-internal-format, gfc-internal-format
@@ -60798,70 +54299,59 @@
 msgstr "Коиндексированный фактический аргумент в %L в PURE процедуре передан в POINTER формальный аргумент"
 
 #: fortran/interface.c:3593
-#, fuzzy, gcc-internal-format
-#| msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument '%s'"
+#, gcc-internal-format
 msgid "Coindexed polymorphic actual argument at %L is passed polymorphic dummy argument %qs"
-msgstr "Коиндексированный полиморфный фактический аргумент в %L передан в полиморфный формальный аргумент '%s'"
+msgstr "Коиндексированный полиморфный фактический аргумент в %L передан в полиморфный формальный аргумент %qs"
 
 #: fortran/interface.c:3625
-#, fuzzy, gcc-internal-format
-#| msgid "Procedure '%s' called at %L is not explicitly declared"
+#, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared; did you mean %qs?"
-msgstr "Процедура '%s' вызванная в %L не декларирована явно"
+msgstr ""
 
 #: fortran/interface.c:3629 fortran/interface.c:3639
-#, fuzzy, gcc-internal-format
-#| msgid "Procedure '%s' called at %L is not explicitly declared"
+#, gcc-internal-format
 msgid "Procedure %qs called at %L is not explicitly declared"
-msgstr "Процедура '%s' вызванная в %L не декларирована явно"
+msgstr "Процедура %qs вызванная в %L не декларирована явно"
 
 #: fortran/interface.c:3635
-#, fuzzy, gcc-internal-format
-#| msgid "Procedure '%s' called with an implicit interface at %L"
+#, gcc-internal-format
 msgid "Procedure %qs called with an implicit interface at %L"
-msgstr "Процедура '%s' вызвана с неявным интерфейсом в %L"
+msgstr "Процедура %qs вызвана с неявным интерфейсом в %L"
 
 #: fortran/interface.c:3647
-#, fuzzy, gcc-internal-format
-#| msgid "The pointer object '%s' at %L must have an explicit function interface or be declared as array"
+#, gcc-internal-format
 msgid "The pointer object %qs at %L must have an explicit function interface or be declared as array"
-msgstr "Указательный объект '%s' в %L должен иметь явный функциональный интерфейс или быть декларированным как массив"
+msgstr "Указательный объект %qs в %L должен иметь явный функциональный интерфейс или быть декларированным как массив"
 
 #: fortran/interface.c:3655
-#, fuzzy, gcc-internal-format
-#| msgid "The allocatable object '%s' at %L must have an explicit function interface or be declared as array"
+#, gcc-internal-format
 msgid "The allocatable object %qs at %L must have an explicit function interface or be declared as array"
-msgstr "Размещаемый объект '%s' в %L должен иметь явный функциональный интерфейс или быть декларированным как массив"
+msgstr "Размещаемый объект %qs в %L должен иметь явный функциональный интерфейс или быть декларированным как массив"
 
 #: fortran/interface.c:3663
-#, fuzzy, gcc-internal-format
-#| msgid "Allocatable function '%s' at %L must have an explicit function interface"
+#, gcc-internal-format
 msgid "Allocatable function %qs at %L must have an explicit function interface"
-msgstr "Размещаемая функция '%s' в %L должна иметь явный функциональный интерфейс"
+msgstr "Размещаемая функция %qs в %L должна иметь явный функциональный интерфейс"
 
 #: fortran/interface.c:3673
-#, fuzzy, gcc-internal-format
-#| msgid "Keyword argument requires explicit interface for procedure '%s' at %L"
+#, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure %qs at %L"
-msgstr "Аргумент с ключевым словом требует явный интерфейс для процедуры '%s' в %L"
+msgstr "Аргумент с ключевым словом требует явный интерфейс для процедуры %qs в %L"
 
 #: fortran/interface.c:3682
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Symbol '%s' at %L already has an explicit interface"
+#, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type argument %s at %L requires an explicit interface"
-msgstr "Символ '%s' в %L уже имеет явный интерфейс"
+msgstr "Аргумент предполагаемого типа %s в %L требует явный интерфейс"
 
 #: fortran/interface.c:3695
-#, fuzzy, gcc-internal-format
-#| msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure '%s'"
+#, gcc-internal-format
 msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure %qs"
-msgstr "Фактический аргумент LOCK_TYPE или с LOCK_TYPE компонентом в %L требует явный интерфейс для процедуры '%s'"
+msgstr "Фактический аргумент LOCK_TYPE или с LOCK_TYPE компонентом в %L требует явный интерфейс для процедуры %qs"
 
 #: fortran/interface.c:3708
-#, fuzzy, gcc-internal-format
-#| msgid "Actual argument of LOCK_TYPE or with LOCK_TYPE component at %L requires an explicit interface for procedure '%s'"
+#, gcc-internal-format
 msgid "Actual argument of EVENT_TYPE or with EVENT_TYPE component at %L requires an explicit interface for procedure %qs"
-msgstr "Фактический аргумент LOCK_TYPE или с LOCK_TYPE компонентом в %L требует явный интерфейс для процедуры '%s'"
+msgstr "Фактический аргумент EVENT_TYPE или с EVENT_TYPE компонентом в %L требует явный интерфейс для процедуры %qs"
 
 #: fortran/interface.c:3717
 #, gcc-internal-format, gfc-internal-format
@@ -60869,22 +54359,19 @@
 msgstr "MOLD аргумент в NULL требуется в %L"
 
 #: fortran/interface.c:3725
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Keyword argument requires explicit interface for procedure '%s' at %L"
+#, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank argument requires an explicit interface at %L"
-msgstr "Аргумент с ключевым словом требует явный интерфейс для процедуры '%s' в %L"
+msgstr "Аргумент предполагаемого ранга требует явный интерфейс в %L"
 
 #: fortran/interface.c:3766
-#, fuzzy, gcc-internal-format
-#| msgid "Procedure pointer component '%s' called with an implicit interface at %L"
+#, gcc-internal-format
 msgid "Procedure pointer component %qs called with an implicit interface at %L"
-msgstr "Компонент указатель на процедуру '%s' вызван с неявным интерфейсом в %L"
+msgstr "Компонент указатель на процедуру %qs вызван с неявным интерфейсом в %L"
 
 #: fortran/interface.c:3777
-#, fuzzy, gcc-internal-format
-#| msgid "Keyword argument requires explicit interface for procedure pointer component '%s' at %L"
+#, gcc-internal-format
 msgid "Keyword argument requires explicit interface for procedure pointer component %qs at %L"
-msgstr "Аргумент с ключевым словом требует явный интерфейс для компонента указателя на процедуру '%s' в %L"
+msgstr "Аргумент с ключевым словом требует явный интерфейс для компонента указателя на процедуру %qs в %L"
 
 #: fortran/interface.c:3862
 #, gcc-internal-format, gfc-internal-format
@@ -60892,235 +54379,199 @@
 msgstr "MOLD= требуется в NULL() аргументе в %L: Неоднозначность между конкретными функциями %s и %s"
 
 #: fortran/interface.c:3932
-#, fuzzy, gcc-internal-format
-#| msgid "%q+D aliased to undefined symbol %qE"
+#, gcc-internal-format
 msgid "Unable to find symbol %qs"
-msgstr "%q+D - алиас неопределенного символа %qE"
+msgstr "Не удается найти символ %qs"
 
 #: fortran/interface.c:4299
-#, fuzzy, gcc-internal-format
-#| msgid "Entity '%s' at %C is already present in the interface"
+#, gcc-internal-format
 msgid "Entity %qs at %L is already present in the interface"
-msgstr "Сущность '%s' в %C уже присутствует в интерфейсе"
+msgstr "Сущность %qs в %L уже присутствует в интерфейсе"
 
 #: fortran/interface.c:4416
 #, gcc-internal-format
 msgid "gfc_add_interface(): Bad interface type"
-msgstr ""
+msgstr "gfc_add_interface(): Некорректный тип интерфейса"
 
 #: fortran/interface.c:4510
-#, fuzzy, gcc-internal-format
-#| msgid "Can't overwrite GENERIC '%s' at %L"
+#, gcc-internal-format
 msgid "Can't overwrite GENERIC %qs at %L"
-msgstr "Не удалось переписать GENERIC '%s' в %L"
+msgstr "Не удалось перебить GENERIC %qs в %L"
 
 #: fortran/interface.c:4522
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' at %L overrides a procedure binding declared NON_OVERRIDABLE"
+#, gcc-internal-format
 msgid "%qs at %L overrides a procedure binding declared NON_OVERRIDABLE"
-msgstr "'%s' в %L перебивает связывание процедуры декларированной NON_OVERRIDABLE"
+msgstr "%qs в %L перебивает связывание процедуры декларированной NON_OVERRIDABLE"
 
 #: fortran/interface.c:4530
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
+#, gcc-internal-format
 msgid "%qs at %L must not be DEFERRED as it overrides a non-DEFERRED binding"
-msgstr "'%s' в %L не должно быть DEFERRED поскольку это перебивает non-DEFERRED связывание"
+msgstr "%qs в %L не должно быть DEFERRED, поскольку это перебивает не-DEFERRED связывание"
 
 #: fortran/interface.c:4538
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' at %L overrides a PURE procedure and must also be PURE"
+#, gcc-internal-format
 msgid "%qs at %L overrides a PURE procedure and must also be PURE"
-msgstr "'%s' в %L перебивает PURE процедуру и должна также быть PURE"
+msgstr "%qs в %L перебивает PURE процедуру и должна также быть PURE"
 
 #: fortran/interface.c:4547
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
+#, gcc-internal-format
 msgid "%qs at %L overrides an ELEMENTAL procedure and must also be ELEMENTAL"
-msgstr "'%s' в %L перебивает ELEMENTAL процедуру и должна также быть ELEMENTAL"
+msgstr "%qs в %L перебивает ELEMENTAL процедуру и должна также быть ELEMENTAL"
 
 #: fortran/interface.c:4553
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
+#, gcc-internal-format
 msgid "%qs at %L overrides a non-ELEMENTAL procedure and must not be ELEMENTAL, either"
-msgstr "'%s' в %L перебивает non-ELEMENTAL процедуру и не должна быть ELEMENTAL, также"
+msgstr "%qs в %L перебивает не-ELEMENTAL процедуру и не должна быть ELEMENTAL, также"
 
 #: fortran/interface.c:4562
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
+#, gcc-internal-format
 msgid "%qs at %L overrides a SUBROUTINE and must also be a SUBROUTINE"
-msgstr "'%s' в %L перебивает SUBROUTINE и должна также быть SUBROUTINE"
+msgstr "%qs в %L перебивает SUBROUTINE и должна также быть SUBROUTINE"
 
 #: fortran/interface.c:4573
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' at %L overrides a FUNCTION and must also be a FUNCTION"
+#, gcc-internal-format
 msgid "%qs at %L overrides a FUNCTION and must also be a FUNCTION"
-msgstr "'%s' в %L перебивает FUNCTION и должна также быть FUNCTION"
+msgstr "%qs в %L перебивает FUNCTION и должна также быть FUNCTION"
 
 #: fortran/interface.c:4581
-#, fuzzy, gcc-internal-format
-#| msgid "Argument mismatch for the overriding procedure '%s' at %L: %s"
+#, gcc-internal-format
 msgid "Result mismatch for the overriding procedure %qs at %L: %s"
-msgstr "Несоответствие аргументов для перебиваемой процедуры '%s' в %L: %s"
+msgstr "Несоответствие результатов для перебивающей процедуры %qs в %L: %s"
 
 #: fortran/interface.c:4592
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' at %L overrides a PUBLIC procedure and must not be PRIVATE"
+#, gcc-internal-format
 msgid "%qs at %L overrides a PUBLIC procedure and must not be PRIVATE"
-msgstr "'%s' в %L перебивает PUBLIC процедуру и не должна быть PRIVATE"
+msgstr "%qs в %L перебивает PUBLIC процедуру и не должна быть PRIVATE"
 
 #: fortran/interface.c:4622
-#, fuzzy, gcc-internal-format
-#| msgid "Dummy argument '%s' of '%s' at %L should be named '%s' as to match the corresponding argument of the overridden procedure"
+#, gcc-internal-format
 msgid "Dummy argument %qs of %qs at %L should be named %qs as to match the corresponding argument of the overridden procedure"
-msgstr "Формальный аргумент '%s' от '%s' в %L должен именоваться '%s' чтобы подходить соответствующему аргументу перебиваемой процедуры"
+msgstr "Формальный аргумент %qs от %qs в %L должен именоваться %qs, чтобы подходить соответствующему аргументу перебиваемой процедуры"
 
 #: fortran/interface.c:4634
-#, fuzzy, gcc-internal-format
-#| msgid "Argument mismatch for the overriding procedure '%s' at %L: %s"
+#, gcc-internal-format
 msgid "Argument mismatch for the overriding procedure %qs at %L: %s"
-msgstr "Несоответствие аргументов для перебиваемой процедуры '%s' в %L: %s"
+msgstr "Несоответствие аргументов для перебивающей процедуры %qs в %L: %s"
 
 #: fortran/interface.c:4643
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' at %L must have the same number of formal arguments as the overridden procedure"
+#, gcc-internal-format
 msgid "%qs at %L must have the same number of formal arguments as the overridden procedure"
-msgstr "'%s' at %L должен иметь то же число формальных аргументов что и перебиваемая процедура"
+msgstr "%qs в %L должен иметь то же число формальных аргументов, что и перебиваемая процедура"
 
 #: fortran/interface.c:4652
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' at %L overrides a NOPASS binding and must also be NOPASS"
+#, gcc-internal-format
 msgid "%qs at %L overrides a NOPASS binding and must also be NOPASS"
-msgstr "'%s' в %L перебивает NOPASS связывание и должен также быть NOPASS"
+msgstr "%qs в %L перебивает NOPASS связывание и должен также быть NOPASS"
 
 #: fortran/interface.c:4663
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' at %L overrides a binding with PASS and must also be PASS"
+#, gcc-internal-format
 msgid "%qs at %L overrides a binding with PASS and must also be PASS"
-msgstr "'%s' в %L перебивает связывание с PASS и должен также быть PASS"
+msgstr "%qs в %L перебивает связывание с PASS и должен также быть PASS"
 
 #: fortran/interface.c:4670
-#, fuzzy, gcc-internal-format
-#| msgid "Passed-object dummy argument of '%s' at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
+#, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be at the same position as the passed-object dummy argument of the overridden procedure"
-msgstr "Passed-object фиктивный аргумент от '%s' в %L должен быть на той же позиции что и passed-object формальный аргумент перебиваемой процедуры"
+msgstr "Passed-object формальный аргумент от %qs в %L должен быть на той же позиции, что и passed-object формальный аргумент перебиваемой процедуры"
 
 #: fortran/interface.c:4691
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "%s tag at %L must be of type %s"
+#, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of type %s"
-msgstr "%s тег в %L должен быть типа %s"
+msgstr "DTIO формальный аргумент в %L должен быть типа %s"
 
 #: fortran/interface.c:4698
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Argument dim at %L must be of INTEGER type"
+#, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be of KIND = %d"
-msgstr "Аргумент dim в %L должен быть INTEGER типа"
+msgstr "DTIO формальный аргумент в %L должен быть KIND = %d"
 
 #: fortran/interface.c:4705
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Argument dim at %L must be scalar"
+#, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be a scalar"
-msgstr "Аргумент dim в %L должен быть скаляром"
+msgstr "DTIO формальный аргумент в %L должен быть скаляром"
 
 #: fortran/interface.c:4709
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Argument of %s at %L must be of length one"
+#, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must be an ASSUMED SHAPE ARRAY"
-msgstr "Аргумент %s в %L должен быть длины один"
+msgstr "DTIO формальный аргумент в %L должен быть ASSUMED SHAPE ARRAY"
 
 #: fortran/interface.c:4713
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Character-valued %s '%s' at %L must not be assumed length"
+#, gcc-internal-format, gfc-internal-format
 msgid "DTIO character argument at %L must have assumed length"
-msgstr "%s с character значением '%s' в %L не должен быть предполагаемой длины"
+msgstr ""
 
 #: fortran/interface.c:4717
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
+#, gcc-internal-format, gfc-internal-format
 msgid "DTIO dummy argument at %L must have INTENT %s"
-msgstr "Формальный аргумент '%s' в %L не может быть INTENT(OUT)"
+msgstr "DTIO формальный аргумент в %L должен иметь INTENT %s"
 
 #: fortran/interface.c:4776 fortran/interface.c:4820
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "DATA statement at %C is not allowed in a PURE procedure"
+#, gcc-internal-format, gfc-internal-format
 msgid "Alternate return at %L is not permitted in a DTIO procedure"
-msgstr "DATA оператор в %C не допускается в PURE процедуре"
+msgstr "Альтернативный возврат в %L не допускается в DTIO процедуре"
 
 #: fortran/interface.c:4788
-#, fuzzy, gcc-internal-format
-#| msgid "Procedure '%s' in %s at %L is neither function nor subroutine"
+#, gcc-internal-format
 msgid "DTIO procedure %qs at %L must be a subroutine"
-msgstr "Процедура '%s' в %s в %L не функция и не подпрограмма"
+msgstr "DTIO процедура %qs в %L должна быть подпрограммой"
 
 #: fortran/interface.c:4797
-#, fuzzy, gcc-internal-format
-#| msgid "Too many arguments in call to '%s' at %L"
+#, gcc-internal-format
 msgid "Too few dummy arguments in DTIO procedure %qs at %L"
-msgstr "Слишком много аргументов в вызове '%s' в %L"
+msgstr "Слишком мало формальных аргументов в DTIO процедуре %qs в %L"
 
 #: fortran/interface.c:4804
-#, fuzzy, gcc-internal-format
-#| msgid "Too many arguments in call to '%s' at %L"
+#, gcc-internal-format
 msgid "Too many dummy arguments in DTIO procedure %qs at %L"
-msgstr "Слишком много аргументов в вызове '%s' в %L"
+msgstr "Слишком много формальных аргументов в DTIO процедуре %qs в %L"
 
 #: fortran/intrinsic.c:196
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "NULL pointer at %L is not permitted as actual argument of '%s' intrinsic function"
+#, gcc-internal-format, gfc-internal-format
 msgid "Variable with NO_ARG_CHECK attribute at %L is only permitted as argument to the intrinsic functions C_LOC and PRESENT"
-msgstr "NULL указатель в %L не разрешен в качестве фактического аргумента '%s' встроенной функции"
+msgstr "Переменная с NO_ARG_CHECK атрибутом в %L допустима только как аргумент для встроенных функций C_LOC и PRESENT"
 
 #: fortran/intrinsic.c:211
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "NULL pointer at %L is not permitted as actual argument of '%s' intrinsic function"
+#, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type argument at %L is not permitted as actual argument to the intrinsic %s"
-msgstr "NULL указатель в %L не разрешен в качестве фактического аргумента '%s' встроенной функции"
+msgstr "Аргумент предполагаемого типа в %L не допустим в качестве фактического аргумента встроенной функции %s"
 
 #: fortran/intrinsic.c:218
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "NULL pointer at %L is not permitted as actual argument of '%s' intrinsic function"
+#, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type argument at %L is only permitted as first actual argument to the intrinsic %s"
-msgstr "NULL указатель в %L не разрешен в качестве фактического аргумента '%s' встроенной функции"
+msgstr "Аргумент предполагаемого типа в %L допустим только как первый фактический аргумент встроенной функции %s"
 
 #: fortran/intrinsic.c:225
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "NULL pointer at %L is not permitted as actual argument of '%s' intrinsic function"
+#, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank argument at %L is only permitted as actual argument to intrinsic inquiry functions"
-msgstr "NULL указатель в %L не разрешен в качестве фактического аргумента '%s' встроенной функции"
+msgstr "Аргумент предполагаемого ранга в %L допустим только как фактический аргумент встроенных inquiry функций"
 
 #: fortran/intrinsic.c:232
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "NULL pointer at %L is not permitted as actual argument of '%s' intrinsic function"
+#, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank argument at %L is only permitted as first actual argument to the intrinsic inquiry function %s"
-msgstr "NULL указатель в %L не разрешен в качестве фактического аргумента '%s' встроенной функции"
+msgstr "Аргумент предполагаемого ранга в %L допустим только как первый фактический аргумент встроенной inquiry функции %s"
 
 #: fortran/intrinsic.c:280
-#, fuzzy, gcc-internal-format
-#| msgid "too many arguments"
+#, gcc-internal-format
 msgid "do_check(): too many args"
-msgstr "слишком много аргументов"
+msgstr "do_check(): слишком много аргументов"
 
 #: fortran/intrinsic.c:360
 #, gcc-internal-format
 msgid "add_sym(): Bad sizing mode"
-msgstr ""
+msgstr "add_sym(): Некорректный режим размера"
 
 #: fortran/intrinsic.c:1083
-#, fuzzy, gcc-internal-format
-#| msgid "The intrinsic '%s' at %L is not included in the selected standard but %s and '%s' will be treated as if declared EXTERNAL.  Use an appropriate -std=* option or define -fall-intrinsics to allow this intrinsic."
+#, gcc-internal-format
 msgid "The intrinsic %qs at %L is not included in the selected standard but %s and %qs will be treated as if declared EXTERNAL.  Use an appropriate -std=* option or define -fall-intrinsics to allow this intrinsic."
-msgstr "Встроенная '%s' в %L не включена в выбранный стандарт но %s и '%s' будут трактоваться как декларированные EXTERNAL. Используйте подходящую -std=* опцию или определите -fall-intrinsics чтобы допустить эту встроенную."
+msgstr ""
 
 #: fortran/intrinsic.c:1118
 #, gcc-internal-format
 msgid "make_generic(): Can't find generic symbol %qs"
-msgstr ""
+msgstr "make_generic(): Не найден generic символ %qs"
 
 #: fortran/intrinsic.c:4133
-#, fuzzy, gcc-internal-format
-#| msgid "Too many arguments in call to '%s' at %L"
+#, gcc-internal-format
 msgid "Too many arguments in call to %qs at %L"
-msgstr "Слишком много аргументов в вызове '%s' в %L"
+msgstr "Слишком много аргументов в вызове %qs в %L"
 
 #: fortran/intrinsic.c:4148
 #, gcc-internal-format, gfc-internal-format
@@ -61128,22 +54579,19 @@
 msgstr "Функции списка аргументов %%VAL, %%LOC или %%REF не допускаются в этом контексте в %L"
 
 #: fortran/intrinsic.c:4151
-#, fuzzy, gcc-internal-format
-#| msgid "Can't find keyword named '%s' in call to '%s' at %L"
+#, gcc-internal-format
 msgid "Can't find keyword named %qs in call to %qs at %L"
-msgstr "Не удалось найти ключевое слово '%s' в вызове '%s' в %L"
+msgstr "Не удалось найти ключевое слово %qs в вызове %qs в %L"
 
 #: fortran/intrinsic.c:4158
-#, fuzzy, gcc-internal-format
-#| msgid "Argument '%s' appears twice in call to '%s' at %L"
+#, gcc-internal-format
 msgid "Argument %qs appears twice in call to %qs at %L"
-msgstr "Аргумент '%s' появляется дважды в вызове '%s' в %L"
+msgstr "Аргумент %qs появляется дважды в вызове %qs в %L"
 
 #: fortran/intrinsic.c:4172
-#, fuzzy, gcc-internal-format
-#| msgid "Missing actual argument '%s' in call to '%s' at %L"
+#, gcc-internal-format
 msgid "Missing actual argument %qs in call to %qs at %L"
-msgstr "Отсутствует фактический аргумент '%s' в вызове '%s' в %L"
+msgstr "Отсутствует фактический аргумент %qs в вызове %qs в %L"
 
 #: fortran/intrinsic.c:4187
 #, gcc-internal-format, gfc-internal-format
@@ -61151,67 +54599,59 @@
 msgstr "ALTERNATE RETURN не разрешается в %L"
 
 #: fortran/intrinsic.c:4244
-#, fuzzy, gcc-internal-format
-#| msgid "Type of argument '%s' in call to '%s' at %L should be %s, not %s"
+#, gcc-internal-format
 msgid "Type of argument %qs in call to %qs at %L should be %s, not %s"
-msgstr "Тип аргумента '%s' в вызове '%s' в %L должен быть %s, а не %s"
+msgstr "Тип аргумента %qs в вызове %qs в %L должен быть %s, а не %s"
 
 #: fortran/intrinsic.c:4350
 #, gcc-internal-format
 msgid "resolve_intrinsic(): Too many args for intrinsic"
-msgstr ""
+msgstr "resolve_intrinsic(): Слишком много аргументов для встроенной функции"
 
 #: fortran/intrinsic.c:4445
 #, gcc-internal-format
 msgid "do_simplify(): Too many args for intrinsic"
-msgstr ""
+msgstr "do_simplify(): Слишком много аргументов для встроенной функции"
 
 #: fortran/intrinsic.c:4484
-#, fuzzy, gcc-internal-format
-#| msgid "too many arguments"
+#, gcc-internal-format
 msgid "init_arglist(): too many arguments"
-msgstr "слишком много аргументов"
+msgstr "init_arglist(): слишком много аргументов"
 
 #: fortran/intrinsic.c:4634
 #, gcc-internal-format
 msgid "Invalid standard code on intrinsic %qs (%d)"
-msgstr ""
+msgstr "Некорректный стандартный код во встроенной функции %qs (%d)"
 
 #: fortran/intrinsic.c:4643
-#, fuzzy, gcc-internal-format
-#| msgid "Intrinsic '%s' (is %s) is used at %L"
+#, gcc-internal-format
 msgid "Intrinsic %qs (is %s) is used at %L"
-msgstr "Встроенная '%s' (есть %s) использована в %L"
+msgstr "Встроенная функция %qs (есть %s) использована в %L"
 
 #: fortran/intrinsic.c:4714
-#, fuzzy, gcc-internal-format
-#| msgid "Fortran 2003: Function '%s' as initialization expression at %L"
+#, gcc-internal-format
 msgid "Function %qs as initialization expression at %L"
-msgstr "Fortran 2003: Функция '%s' как инициализационное выражение в %L"
+msgstr "Функция %qs как инициализационное выражение в %L"
 
 #: fortran/intrinsic.c:4732
-#, fuzzy, gcc-internal-format
-#| msgid "transformational intrinsic '%s' at %L is not permitted in an initialization expression"
+#, gcc-internal-format
 msgid "Transformational function %qs at %L is invalid in an initialization expression"
-msgstr "трансформационная встроенная функция '%s' в %L не разрешена в инициализационном выражении"
+msgstr "трансформационная встроенная функция %qs в %L некорректна в инициализационном выражении"
 
 #: fortran/intrinsic.c:4811
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2003: Elemental function as initialization expression with non-integer/non-character arguments at %L"
+#, gcc-internal-format, gfc-internal-format
 msgid "Elemental function as initialization expression with non-integer/non-character arguments at %L"
-msgstr "Fortran 2003: Элементная функция как инициализационное выражение с non-integer/non-character аргументами в %L"
+msgstr "Элементная функция как инициализационное выражение с non-integer/non-character аргументами в %L"
 
 #: fortran/intrinsic.c:4882
-#, fuzzy, gcc-internal-format
-#| msgid "Subroutine call to '%s' in DO CONCURRENT block at %L is not PURE"
+#, gcc-internal-format
 msgid "Subroutine call to intrinsic %qs in DO CONCURRENT block at %L is not PURE"
-msgstr "Вызов подпрограммы '%s' в DO CONCURRENT блоке в %L не есть PURE"
+msgstr "Вызов подпрограммы во встроенную функцию %qs в DO CONCURRENT блоке в %L не есть PURE"
 
 #: fortran/intrinsic.c:4889
-#, fuzzy, gcc-internal-format
-#| msgid "Subroutine call to intrinsic '%s' at %L is not PURE"
+#, gcc-internal-format
 msgid "Subroutine call to intrinsic %qs at %L is not PURE"
-msgstr "Подпрограммный вызов встроенной '%s' в %L не есть PURE"
+msgstr "Вызов подпрограммы во встроенную функцию %qs в %L не есть PURE"
 
 #: fortran/intrinsic.c:4967
 #, gcc-internal-format, gfc-internal-format
@@ -61234,22 +54674,19 @@
 msgstr "Не удалось преобразовать %s в %s в %L"
 
 #: fortran/intrinsic.c:5089
-#, fuzzy, gcc-internal-format
-#| msgid "Can't convert %s to %s at %L"
+#, gcc-internal-format
 msgid "Can't convert %qs to %qs at %L"
-msgstr "Не удалось преобразовать %s в %s в %L"
+msgstr "Не удалось преобразовать %qs в %qs в %L"
 
 #: fortran/intrinsic.c:5181
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' declared at %L may shadow the intrinsic of the same name.  In order to call the intrinsic, explicit INTRINSIC declarations may be required."
+#, gcc-internal-format
 msgid "%qs declared at %L may shadow the intrinsic of the same name.  In order to call the intrinsic, explicit INTRINSIC declarations may be required."
-msgstr "'%s' декларированная в %L может затенять встроенную с тем же именем. Чтобы вызвать встроенную, явная INTRINSIC декларация может потребоваться."
+msgstr ""
 
 #: fortran/intrinsic.c:5187
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' declared at %L is also the name of an intrinsic.  It can only be called via an explicit interface or if declared EXTERNAL."
+#, gcc-internal-format
 msgid "%qs declared at %L is also the name of an intrinsic.  It can only be called via an explicit interface or if declared EXTERNAL."
-msgstr "'%s' декларированная в %L есть также имя встроенной. Она может быть вызвана только посредством явного интерфейса или будучи декларированной EXTERNAL."
+msgstr ""
 
 #: fortran/io.c:180 fortran/primary.c:922
 #, gcc-internal-format, gfc-internal-format
@@ -61257,40 +54694,34 @@
 msgstr "Расширение: backslash символ в %C"
 
 #: fortran/io.c:214
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Nonconforming tab character at %C"
+#, gcc-internal-format, gfc-internal-format
 msgid "Nonconforming tab character in format at %C"
-msgstr "Неподходящий символ табуляции в %C"
+msgstr "Неподходящий символ табуляции в формате в %C"
 
 #: fortran/io.c:457
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2003: DP format specifier not allowed at %C"
+#, gcc-internal-format, gfc-internal-format
 msgid "DP format specifier not allowed at %C"
-msgstr "Fortran 2003: DP спецификатор формата не допускается в %C"
+msgstr "DP спецификатор формата не допускается в %C"
 
 #: fortran/io.c:464
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2003: DC format specifier not allowed at %C"
+#, gcc-internal-format, gfc-internal-format
 msgid "DC format specifier not allowed at %C"
-msgstr "Fortran 2003: DC спецификатор формата не допускается в %C"
+msgstr "DC спецификатор формата не допускается в %C"
 
 #: fortran/io.c:471
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2003: DP format specifier not allowed at %C"
+#, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2003: DT format specifier not allowed at %C"
-msgstr "Fortran 2003: DP спецификатор формата не допускается в %C"
+msgstr "Fortran 2003: DT спецификатор формата не допускается в %C"
 
 #: fortran/io.c:699
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Extension: X descriptor requires leading space count at %L"
+#, gcc-internal-format, gfc-internal-format
 msgid "X descriptor requires leading space count at %L"
-msgstr "Расширение: X дескриптор требует предшествующий счетчик пробелов в %L"
+msgstr "X дескриптор требует предшествующий счетчик пробелов в %L"
 
 #: fortran/io.c:728
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Extension: $ descriptor at %L"
+#, gcc-internal-format, gfc-internal-format
 msgid "$ descriptor at %L"
-msgstr "Расширение: $ дескриптор в %L"
+msgstr "$ дескриптор в %L"
 
 #: fortran/io.c:732
 #, gcc-internal-format, gfc-internal-format
@@ -61298,22 +54729,19 @@
 msgstr "$ должен быть последним спецификатором в формате в %L"
 
 #: fortran/io.c:832 fortran/io.c:836
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Extension: Missing positive width after L descriptor at %L"
+#, gcc-internal-format, gfc-internal-format
 msgid "Extension: Zero width after L descriptor at %L"
-msgstr "Расширение: Отсутствует положительная ширина после L дескриптора в %L"
+msgstr "Расширение: Нулевая ширина после L дескриптора в %L"
 
 #: fortran/io.c:848
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Extension: Missing positive width after L descriptor at %L"
+#, gcc-internal-format, gfc-internal-format
 msgid "Missing positive width after L descriptor at %L"
-msgstr "Расширение: Отсутствует положительная ширина после L дескриптора в %L"
+msgstr "Отсутствует положительная ширина после L дескриптора в %L"
 
 #: fortran/io.c:879
-#, fuzzy, gcc-internal-format
-#| msgid "%s in format string at %L"
+#, gcc-internal-format
 msgid "%<G0%> in format at %L"
-msgstr "%s в форматной строке в %L"
+msgstr "%<G0%> в формате в %L"
 
 #: fortran/io.c:907
 #, gcc-internal-format, gfc-internal-format
@@ -61336,10 +54764,9 @@
 msgstr "H спецификатор формата в %L есть удаленная возможность Fortran 95"
 
 #: fortran/io.c:1162 fortran/io.c:1224
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Extension: Missing comma at %L"
+#, gcc-internal-format, gfc-internal-format
 msgid "Missing comma at %L"
-msgstr "Расширение: Отсутствует запятая в %L"
+msgstr "Отсутствует запятая в %L"
 
 #: fortran/io.c:1242
 #, gcc-internal-format, gfc-internal-format
@@ -61357,10 +54784,9 @@
 msgstr "Оператор формата в главном блоке модуля в %C"
 
 #: fortran/io.c:1311
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "ENTRY statement at %C cannot appear within an INTERFACE"
+#, gcc-internal-format, gfc-internal-format
 msgid "FORMAT statement at %C cannot appear within an INTERFACE"
-msgstr "ENTRY оператор в %C не может появляться внутри INTERFACE"
+msgstr "FORMAT оператор в %C не может появляться внутри INTERFACE"
 
 #: fortran/io.c:1317
 #, gcc-internal-format, gfc-internal-format
@@ -61370,12 +54796,12 @@
 #: fortran/io.c:1365
 #, gcc-internal-format, gfc-internal-format
 msgid "IOMSG must be a scalar-default-char-variable at %L"
-msgstr ""
+msgstr "IOMSG должна быть scalar-default-char-variable в %L"
 
 #: fortran/io.c:1379
 #, gcc-internal-format, gfc-internal-format
 msgid "%s requires a scalar-default-char-expr at %L"
-msgstr ""
+msgstr "%s требует scalar-default-char-expr в %L"
 
 #: fortran/io.c:1402 fortran/io.c:1433 fortran/io.c:1499
 #, gcc-internal-format, gfc-internal-format
@@ -61418,28 +54844,24 @@
 msgstr "FORMAT тег в %L должен быть типа default-kind CHARACTER или INTEGER"
 
 #: fortran/io.c:1681
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Deleted feature: ASSIGNED variable in FORMAT tag at %L"
+#, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED variable in FORMAT tag at %L"
-msgstr "Удаленная возможность: ASSIGNED переменная в FORMAT теге в %L"
+msgstr "ASSIGNED переменная в FORMAT теге в %L"
 
 #: fortran/io.c:1686
-#, fuzzy, gcc-internal-format
-#| msgid "Variable '%s' at %L has not been assigned a format label"
+#, gcc-internal-format
 msgid "Variable %qs at %L has not been assigned a format label"
-msgstr "Переменной '%s' в %L не была присвоена метка формата"
+msgstr "Переменной %qs в %L не была присвоена метка формата"
 
 #: fortran/io.c:1693
-#, fuzzy, gcc-internal-format
-#| msgid "Scalar '%s' in FORMAT tag at %L is not an ASSIGNED variable"
+#, gcc-internal-format
 msgid "Scalar %qs in FORMAT tag at %L is not an ASSIGNED variable"
-msgstr "Скаляр '%s' в FORMAT теге в %L не есть ASSIGNED переменная"
+msgstr "Скаляр %qs в FORMAT теге в %L не есть ASSIGNED переменная"
 
 #: fortran/io.c:1705
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Extension: Non-character in FORMAT tag at %L"
+#, gcc-internal-format, gfc-internal-format
 msgid "Non-character in FORMAT tag at %L"
-msgstr "Расширение: Non-character в FORMAT теге в %L"
+msgstr "Не-character в FORMAT теге в %L"
 
 #: fortran/io.c:1711
 #, gcc-internal-format, gfc-internal-format
@@ -61472,10 +54894,9 @@
 msgstr "%s тег в %L должен быть скаляром"
 
 #: fortran/io.c:1771
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2003: IOMSG tag at %L"
+#, gcc-internal-format, gfc-internal-format
 msgid "IOMSG tag at %L"
-msgstr "Fortran 2003: IOMSG тег в %L"
+msgstr "IOMSG тег в %L"
 
 #: fortran/io.c:1779
 #, gcc-internal-format, gfc-internal-format
@@ -61483,46 +54904,39 @@
 msgstr "Fortran 95 требует подразумеваемый INTEGER в %s теге в %L"
 
 #: fortran/io.c:1788
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2008: Nondefault LOGICAL in %s tag at %L"
+#, gcc-internal-format, gfc-internal-format
 msgid "Non-default LOGICAL kind in %s tag at %L"
-msgstr "Fortran 2008: Неподразумеваемый LOGICAL в %s теге в %L"
+msgstr "Неподразумеваемый LOGICAL вид в %s теге в %L"
 
 #: fortran/io.c:1795
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "UNIT not specified at %L"
+#, gcc-internal-format, gfc-internal-format
 msgid "NEWUNIT specifier at %L"
-msgstr "UNIT не специфицировано в %L"
+msgstr "NEWUNIT спецификатор в %L"
 
 #: fortran/io.c:1813
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Extension: CONVERT tag at %L"
+#, gcc-internal-format, gfc-internal-format
 msgid "CONVERT tag at %L"
-msgstr "Расширение: CONVERT тег в %L"
+msgstr "CONVERT тег в %L"
 
 #: fortran/io.c:2035
-#, fuzzy, gcc-internal-format
-#| msgid "Fortran 2003: %s specifier in %s statement at %C has value '%s'"
+#, gcc-internal-format
 msgid "Fortran 2003: %s specifier in %s statement at %C has value %qs"
-msgstr "Fortran 2003: %s спецификатор в %s операторе в %C имеет значение '%s'"
+msgstr "Fortran 2003: %s спецификатор в %s операторе в %C имеет значение %qs"
 
 #: fortran/io.c:2043 fortran/io.c:2070
-#, fuzzy, gcc-internal-format
-#| msgid "%s specifier in %s statement at %C has invalid value '%s'"
+#, gcc-internal-format
 msgid "%s specifier in %s statement at %C has value %qs"
-msgstr "%s спецификатор в %s операторе в %C имеет некорректное значение '%s'"
+msgstr "%s спецификатор в %s операторе в %C имеет значение %qs"
 
 #: fortran/io.c:2062
-#, fuzzy, gcc-internal-format
-#| msgid "Extension: %s specifier in %s statement at %C has value '%s'"
+#, gcc-internal-format
 msgid "Extension: %s specifier in %s statement at %C has value %qs"
-msgstr "Расширение: %s спецификатор в %s операторе в %C имеет значение '%s'"
+msgstr "Расширение: %s спецификатор в %s операторе в %C имеет значение %qs"
 
 #: fortran/io.c:2084 fortran/io.c:2092
-#, fuzzy, gcc-internal-format
-#| msgid "%s specifier in %s statement at %C has invalid value '%s'"
+#, gcc-internal-format
 msgid "%s specifier in %s statement at %C has invalid value %qs"
-msgstr "%s спецификатор в %s операторе в %C имеет некорректное значение '%s'"
+msgstr "%s спецификатор в %s операторе в %C имеет некорректное значение %qs"
 
 #: fortran/io.c:2145
 #, gcc-internal-format, gfc-internal-format
@@ -61547,43 +54961,37 @@
 #: fortran/io.c:2214
 #, gcc-internal-format, gfc-internal-format
 msgid "ACTION type conflicts with READONLY specifier at %C"
-msgstr ""
+msgstr "ACTION тип конфликтует с READONLY спецификатором в %C"
 
 #: fortran/io.c:2228
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2003: ASYNCHRONOUS= at %C not allowed in Fortran 95"
+#, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS= at %C not allowed in Fortran 95"
-msgstr "Fortran 2003: ASYNCHRONOUS= в %C не допускается в Fortran 95"
+msgstr "ASYNCHRONOUS= в %C не допускается в Fortran 95"
 
 #: fortran/io.c:2249 fortran/io.c:3848
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2003: BLANK= at %C not allowed in Fortran 95"
+#, gcc-internal-format, gfc-internal-format
 msgid "BLANK= at %C not allowed in Fortran 95"
-msgstr "Fortran 2003: BLANK= в %C не допускается в Fortran 95"
+msgstr "BLANK= в %C не допускается в Fortran 95"
 
 #: fortran/io.c:2286 fortran/io.c:3824
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2003: DECIMAL= at %C not allowed in Fortran 95"
+#, gcc-internal-format, gfc-internal-format
 msgid "DECIMAL= at %C not allowed in Fortran 95"
-msgstr "Fortran 2003: DECIMAL= в %C не допускается в Fortran 95"
+msgstr "DECIMAL= в %C не допускается в Fortran 95"
 
 #: fortran/io.c:2324
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2003: ENCODING= at %C not allowed in Fortran 95"
+#, gcc-internal-format, gfc-internal-format
 msgid "ENCODING= at %C not allowed in Fortran 95"
-msgstr "Fortran 2003: ENCODING= в %C не допускается в Fortran 95"
+msgstr "ENCODING= в %C не допускается в Fortran 95"
 
 #: fortran/io.c:2387 fortran/io.c:3897
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2003: ROUND= at %C not allowed in Fortran 95"
+#, gcc-internal-format, gfc-internal-format
 msgid "ROUND= at %C not allowed in Fortran 95"
-msgstr "Fortran 2003: ROUND= в %C не допускается в Fortran 95"
+msgstr "ROUND= в %C не допускается в Fortran 95"
 
 #: fortran/io.c:2426
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2003: SIGN= at %C not allowed in Fortran 95"
+#, gcc-internal-format, gfc-internal-format
 msgid "SIGN= at %C not allowed in Fortran 95"
-msgstr "Fortran 2003: SIGN= в %C не допускается в Fortran 95"
+msgstr "SIGN= в %C не допускается в Fortran 95"
 
 #: fortran/io.c:2647
 #, gcc-internal-format, gfc-internal-format
@@ -61606,10 +55014,9 @@
 msgstr "%s оператор не допускается в PURE процедуре в %C"
 
 #: fortran/io.c:2849
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "UNIT number in statement at %L must be non-negative"
+#, gcc-internal-format, gfc-internal-format
 msgid "UNIT number missing in statement at %L"
-msgstr "UNIT номер в операторе в %L должен быть неотрицательным"
+msgstr "UNIT номер отсутствует в операторе в %L"
 
 #: fortran/io.c:2857 fortran/io.c:3324
 #, gcc-internal-format, gfc-internal-format
@@ -61617,16 +55024,14 @@
 msgstr "UNIT номер в операторе в %L должен быть неотрицательным"
 
 #: fortran/io.c:2890
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2003: FLUSH statement at %C"
+#, gcc-internal-format, gfc-internal-format
 msgid "FLUSH statement at %C"
-msgstr "Fortran 2003: FLUSH оператор в %C"
+msgstr "FLUSH оператор в %C"
 
 #: fortran/io.c:2931
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Missing format label at %C"
+#, gcc-internal-format, gfc-internal-format
 msgid "Missing format with default unit at %C"
-msgstr "Отсутствует метка формата в %C"
+msgstr "Отсутствует формат с подразумеваемым устройством в %C"
 
 #: fortran/io.c:2951
 #, gcc-internal-format, gfc-internal-format
@@ -61639,10 +55044,9 @@
 msgstr "Повторная спецификация формата в %C"
 
 #: fortran/io.c:3066
-#, fuzzy, gcc-internal-format
-#| msgid "Symbol '%s' in namelist '%s' is INTENT(IN) at %C"
+#, gcc-internal-format
 msgid "Symbol %qs in namelist %qs is INTENT(IN) at %C"
-msgstr "Символ '%s' в списке имен '%s' является INTENT(IN) в %C"
+msgstr "Символ %qs в списке имен %qs является INTENT(IN) в %C"
 
 #: fortran/io.c:3102
 #, gcc-internal-format, gfc-internal-format
@@ -61650,10 +55054,9 @@
 msgstr "Повторная NML спецификация в %C"
 
 #: fortran/io.c:3111
-#, fuzzy, gcc-internal-format
-#| msgid "Symbol '%s' at %C must be a NAMELIST group name"
+#, gcc-internal-format
 msgid "Symbol %qs at %C must be a NAMELIST group name"
-msgstr "Символ '%s' в %C должен быть именем NAMELIST группы"
+msgstr "Символ %qs в %C должен быть именем NAMELIST группы"
 
 #: fortran/io.c:3181
 #, gcc-internal-format, gfc-internal-format
@@ -61686,34 +55089,29 @@
 msgstr "Внешняя IO UNIT не может быть массивом в %L"
 
 #: fortran/io.c:3347
-#, fuzzy, gcc-internal-format
-#| msgid "NAMELIST '%s' in READ statement at %L contains the symbol '%s' which may not appear in a variable definition context"
+#, gcc-internal-format
 msgid "NAMELIST %qs in READ statement at %L contains the symbol %qs which may not appear in a variable definition context"
-msgstr "NAMELIST '%s' в READ операторе в %L содержит символ '%s' который не может появляться в контексте определения переменной"
+msgstr "NAMELIST %qs в READ операторе в %L содержит символ %qs, который не может появляться в контексте определения переменной"
 
 #: fortran/io.c:3359
-#, fuzzy, gcc-internal-format
-#| msgid "NAMELIST object '%s' in namelist '%s' at %L is polymorphic and requires a defined input/output procedure"
+#, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
-msgstr "NAMELIST объект '%s' в списке имен '%s' в %L является полиморфным и требует определенную процедуру ввода/вывода"
+msgstr "NAMELIST объект %qs в списке имен %qs в %L является полиморфным и требует определенную процедуру ввода/вывода"
 
-#: fortran/io.c:3369 fortran/resolve.c:14263
-#, fuzzy, gcc-internal-format
-#| msgid "Fortran 2003: NAMELIST object '%s' in namelist '%s' at %L with ALLOCATABLE or POINTER components"
+#: fortran/io.c:3369 fortran/resolve.c:14283
+#, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
-msgstr "Fortran 2003: NAMELIST объект '%s' в списке имен '%s' в %L с ALLOCATABLE или POINTER компонентами"
+msgstr "NAMELIST объект %qs в списке имен %qs в %L с ALLOCATABLE или POINTER компонентами"
 
 #: fortran/io.c:3377
-#, fuzzy, gcc-internal-format
-#| msgid "NAMELIST object '%s' in namelist '%s' at %L has ALLOCATABLE or POINTER components and thus requires a defined input/output procedure"
+#, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L has ALLOCATABLE or POINTER components and thus requires a defined input/output procedure"
-msgstr "NAMELIST объект '%s' в списке имен '%s' в %L имеет ALLOCATABLE или POINTER компоненты и поэтому требует определенную процедуру ввода/вывода"
+msgstr "NAMELIST объект %qs в списке имен %qs в %L имеет ALLOCATABLE или POINTER компоненты и поэтому требует определенную процедуру ввода/вывода"
 
 #: fortran/io.c:3388
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Extension: Comma before i/o item list at %L"
+#, gcc-internal-format, gfc-internal-format
 msgid "Comma before i/o item list at %L"
-msgstr "Расширение: Запятая перед i/o списком элементов в %L"
+msgstr "Запятая перед списком элементов ввода/вывода в %L"
 
 #: fortran/io.c:3398
 #, gcc-internal-format, gfc-internal-format
@@ -61738,7 +55136,7 @@
 #: fortran/io.c:3463
 #, gcc-internal-format
 msgid "io_kind_name(): bad I/O-kind"
-msgstr ""
+msgstr "io_kind_name(): некорректный I/O-вид"
 
 #: fortran/io.c:3552
 #, gcc-internal-format, gfc-internal-format
@@ -61762,10 +55160,9 @@
 msgstr "синтаксическая ошибка в %s операторе в %C"
 
 #: fortran/io.c:3731
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2003: Internal file at %L with namelist"
+#, gcc-internal-format, gfc-internal-format
 msgid "Internal file at %L with namelist"
-msgstr "Fortran 2003: Внутренний файл в %L со списком имен"
+msgstr "Внутренний файл в %L со списком имен"
 
 #: fortran/io.c:3788
 #, gcc-internal-format, gfc-internal-format
@@ -61773,16 +55170,14 @@
 msgstr "ASYNCHRONOUS= спецификатор в %L должен быть инициализационным выражением"
 
 #: fortran/io.c:3873
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2003: PAD= at %C not allowed in Fortran 95"
+#, gcc-internal-format, gfc-internal-format
 msgid "PAD= at %C not allowed in Fortran 95"
-msgstr "Fortran 2003: PAD= в %C не допускается в Fortran 95"
+msgstr "PAD= в %C не допускается в Fortran 95"
 
 #: fortran/io.c:3949
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2003: DELIM= at %C not allowed in Fortran 95"
+#, gcc-internal-format, gfc-internal-format
 msgid "DELIM= at %C not allowed in Fortran 95"
-msgstr "Fortran 2003: DELIM= в %C не допускается в Fortran 95"
+msgstr "DELIM= в %C не допускается в Fortran 95"
 
 #: fortran/io.c:4101
 #, gcc-internal-format, gfc-internal-format
@@ -61820,10 +55215,9 @@
 msgstr "INQUIRE оператор в %L требует либо FILE либо UNIT спецификатор"
 
 #: fortran/io.c:4572
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "UNIT number in statement at %L must be non-negative"
+#, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in INQUIRE statement at %L can not be %d"
-msgstr "UNIT номер в операторе в %L должен быть неотрицательным"
+msgstr "UNIT номер в INQUIRE операторе в %L должен быть %d"
 
 #: fortran/io.c:4587
 #, gcc-internal-format, gfc-internal-format
@@ -61831,10 +55225,9 @@
 msgstr "INQUIRE оператор в %L требует PENDING= спецификатор с ID= спецификатором"
 
 #: fortran/io.c:4765
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2003: WAIT at %C not allowed in Fortran 95"
+#, gcc-internal-format, gfc-internal-format
 msgid "WAIT at %C not allowed in Fortran 95"
-msgstr "Fortran 2003: WAIT в %C не допускается в Fortran 95"
+msgstr "WAIT в %C не допускается в Fortran 95"
 
 #: fortran/io.c:4771
 #, gcc-internal-format, gfc-internal-format
@@ -61842,33 +55235,29 @@
 msgstr "WAIT оператор не допускается в PURE процедуре в %C"
 
 #: fortran/match.c:118
-#, fuzzy, gcc-internal-format
-#| msgid "gfc_trans_code(): Bad statement code"
+#, gcc-internal-format
 msgid "gfc_op2string(): Bad code"
-msgstr "gfc_trans_code(): Некорректный код оператора"
+msgstr "gfc_op2string(): Некорректный код"
 
 #: fortran/match.c:195
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Expected structure component name at %C"
+#, gcc-internal-format, gfc-internal-format
 msgid "Expected structure component or operator name after '.' at %C"
-msgstr "Ожидалось имя компонента структуры в %C"
+msgstr "Ожидалось имя компонента структуры или оператора после '.' в %C"
 
 #: fortran/match.c:227
 #, gcc-internal-format
 msgid "%qs is neither a defined operator nor a structure component in dotted string at %C"
-msgstr ""
+msgstr "%qs не есть определенный оператор или компонент структуры в точечной цепочке в %C"
 
 #: fortran/match.c:297
-#, fuzzy, gcc-internal-format
-#| msgid "Missing ')' in statement at or before %L"
+#, gcc-internal-format
 msgid "Missing %<)%> in statement at or before %L"
-msgstr "Отсутствует ')' в операторе в или до %L"
+msgstr "Отсутствует %<)%> в операторе в или до %L"
 
 #: fortran/match.c:302
-#, fuzzy, gcc-internal-format
-#| msgid "Missing '(' in statement at or before %L"
+#, gcc-internal-format
 msgid "Missing %<(%> in statement at or before %L"
-msgstr "Отсутствует '(' в операторе в или до %L"
+msgstr "Отсутствует %<(%> в операторе в или до %L"
 
 #: fortran/match.c:499
 #, gcc-internal-format, gfc-internal-format
@@ -61875,7 +55264,7 @@
 msgid "Integer too large at %C"
 msgstr "Целое слишком велико в %C"
 
-#: fortran/match.c:580 fortran/parse.c:1132
+#: fortran/match.c:580 fortran/parse.c:1136
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many digits in statement label at %C"
 msgstr "Слишком много цифр в метке оператора в %C"
@@ -61886,16 +55275,14 @@
 msgstr "Метка оператора в %C нулевая"
 
 #: fortran/match.c:619
-#, fuzzy, gcc-internal-format
-#| msgid "Label name '%s' at %C is ambiguous"
+#, gcc-internal-format
 msgid "Label name %qs at %C is ambiguous"
-msgstr "Имя метки '%s' в %C неоднозначно"
+msgstr "Имя метки %qs в %C неоднозначно"
 
 #: fortran/match.c:625
-#, fuzzy, gcc-internal-format
-#| msgid "Duplicate construct label '%s' at %C"
+#, gcc-internal-format
 msgid "Duplicate construct label %qs at %C"
-msgstr "Дублирование метки конструкции '%s' at %C"
+msgstr "Дублирование метки конструкции %qs at %C"
 
 #: fortran/match.c:659
 #, gcc-internal-format, gfc-internal-format
@@ -61908,10 +55295,9 @@
 msgstr "Имя в %C слишком длинное"
 
 #: fortran/match.c:683
-#, fuzzy, gcc-internal-format
-#| msgid "Invalid character '$' at %C. Use -fdollar-ok to allow it as an extension"
+#, gcc-internal-format
 msgid "Invalid character %<$%> at %L. Use %<-fdollar-ok%> to allow it as an extension"
-msgstr "Некорректный символ '$' в %C. Используйте -fdollar-ok чтобы допустить его как расширение"
+msgstr ""
 
 #: fortran/match.c:959
 #, gcc-internal-format, gfc-internal-format
@@ -61919,10 +55305,9 @@
 msgstr ""
 
 #: fortran/match.c:1014
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Loop variable at %C cannot be a coarray"
+#, gcc-internal-format, gfc-internal-format
 msgid "Loop variable at %C cannot be an array"
-msgstr "Переменная цикла в %C не может быть комассивом"
+msgstr "Переменная цикла в %C не может быть массивом"
 
 #: fortran/match.c:1021
 #, gcc-internal-format, gfc-internal-format
@@ -61945,10 +55330,9 @@
 msgstr "Синтаксическая ошибка в итераторе в %C"
 
 #: fortran/match.c:1241
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "gfc_trans_code(): Bad statement code"
+#, gcc-internal-format, gfc-internal-format
 msgid "gfc_match(): Bad match code %c"
-msgstr "gfc_trans_code(): Некорректный код оператора"
+msgstr "gfc_match(): Некорректный код соответствия %c"
 
 #: fortran/match.c:1315
 #, gcc-internal-format, gfc-internal-format
@@ -61956,10 +55340,9 @@
 msgstr "Некорректная форма PROGRAM оператора в %C"
 
 #: fortran/match.c:1445 fortran/match.c:1525
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Obsolescent feature: Arithmetic IF statement at %C"
+#, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %C"
-msgstr "Устаревшая возможность: Арифметический IF оператор в %C"
+msgstr "Арифметический IF оператор в %C"
 
 #: fortran/match.c:1500
 #, gcc-internal-format, gfc-internal-format
@@ -61997,10 +55380,9 @@
 msgstr "Неожиданный мусор после ELSE оператора в %C"
 
 #: fortran/match.c:1710 fortran/match.c:1745
-#, fuzzy, gcc-internal-format
-#| msgid "Label '%s' at %C doesn't match IF label '%s'"
+#, gcc-internal-format
 msgid "Label %qs at %C doesn't match IF label %qs"
-msgstr "Метка '%s' в %C не соответствует IF метке '%s'"
+msgstr "Метка %qs в %C не соответствует IF метке %qs"
 
 #: fortran/match.c:1739
 #, gcc-internal-format, gfc-internal-format
@@ -62018,10 +55400,9 @@
 msgstr "Оператор управления внешним видом CRITICAL в %C в DO CONCURRENT блоке"
 
 #: fortran/match.c:1816
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2008: CRITICAL statement at %C"
+#, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL statement at %C"
-msgstr "Fortran 2008: CRITICAL оператор в %C"
+msgstr "CRITICAL оператор в %C"
 
 #: fortran/match.c:1828
 #, gcc-internal-format, gfc-internal-format
@@ -62039,10 +55420,9 @@
 msgstr "Ожидалась ассоциация в %C"
 
 #: fortran/match.c:1909
-#, fuzzy, gcc-internal-format
-#| msgid "Duplicate name '%s' in association at %C"
+#, gcc-internal-format
 msgid "Duplicate name %qs in association at %C"
-msgstr "Повторение имени '%s' в ассоциации в %C"
+msgstr "Повторение имени %qs в ассоциации в %C"
 
 #: fortran/match.c:1917
 #, gcc-internal-format, gfc-internal-format
@@ -62050,10 +55430,9 @@
 msgstr "Цель ассоциации в %C не должна быть коиндексирована"
 
 #: fortran/match.c:1935
-#, fuzzy, gcc-internal-format
-#| msgid "Expected ')' or ',' at %C"
+#, gcc-internal-format
 msgid "Expected %<)%> or %<,%> at %C"
-msgstr "Ожидалась ')' или ',' в %C"
+msgstr "Ожидалась %<)%> или %<,%> в %C"
 
 #: fortran/match.c:1953
 #, gcc-internal-format, gfc-internal-format
@@ -62061,10 +55440,9 @@
 msgstr "Мусор после ASSOCIATE оператора в %C"
 
 #: fortran/match.c:2075
-#, fuzzy, gcc-internal-format
-#| msgid "Derived type '%s' at %L may not be ABSTRACT"
+#, gcc-internal-format
 msgid "Derived type %qs at %L may not be ABSTRACT"
-msgstr "Производный тип '%s' в %L не может быть ABSTRACT"
+msgstr "Производный тип %qs в %L не может быть ABSTRACT"
 
 #: fortran/match.c:2149 fortran/match.c:2215 fortran/match.c:2236
 #, gcc-internal-format, gfc-internal-format
@@ -62077,22 +55455,19 @@
 msgstr "Синтаксическая ошибка в FORALL итераторе в %C"
 
 #: fortran/match.c:2596
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2008: DO CONCURRENT construct at %C"
+#, gcc-internal-format, gfc-internal-format
 msgid "DO CONCURRENT construct at %C"
-msgstr "Fortran 2008: DO CONCURRENT конструкция в %C"
+msgstr "DO CONCURRENT конструкция в %C"
 
 #: fortran/match.c:2721
-#, fuzzy, gcc-internal-format
-#| msgid "Name '%s' in %s statement at %C is unknown"
+#, gcc-internal-format
 msgid "Name %qs in %s statement at %C is unknown"
-msgstr "Имя '%s' в %s операторе в %C неизвестно"
+msgstr "Имя %qs в %s операторе в %C неизвестно"
 
 #: fortran/match.c:2729
-#, fuzzy, gcc-internal-format
-#| msgid "Name '%s' in %s statement at %C is not a construct name"
+#, gcc-internal-format
 msgid "Name %qs in %s statement at %C is not a construct name"
-msgstr "Имя '%s' в %s операторе в %C не является именем конструкции"
+msgstr "Имя %qs в %s операторе в %C не является именем конструкции"
 
 #: fortran/match.c:2741
 #, gcc-internal-format, gfc-internal-format
@@ -62111,57 +55486,49 @@
 msgstr "%s оператор в %C не внутри конструкции"
 
 #: fortran/match.c:2764
-#, fuzzy, gcc-internal-format
-#| msgid "%s statement at %C is not within construct '%s'"
+#, gcc-internal-format
 msgid "%s statement at %C is not within construct %qs"
-msgstr "%s оператор в %C не внутри конструкции '%s'"
+msgstr "%s оператор в %C не внутри конструкции %qs"
 
 #: fortran/match.c:2789
-#, fuzzy, gcc-internal-format
-#| msgid "CYCLE statement at %C is not applicable to non-loop construct '%s'"
+#, gcc-internal-format
 msgid "CYCLE statement at %C is not applicable to non-loop construct %qs"
-msgstr "CYCLE оператор в %C не применим к нециклической конструкции '%s'"
+msgstr "CYCLE оператор в %C не применим к нециклической конструкции %qs"
 
 #: fortran/match.c:2794
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2008: EXIT statement with no do-construct-name at %C"
+#, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement with no do-construct-name at %C"
-msgstr "Fortran 2008: EXIT оператор без do-construct-name в %C"
+msgstr "EXIT оператор без имени do-конструкции в %C"
 
 #: fortran/match.c:2800
-#, fuzzy, gcc-internal-format
-#| msgid "%s statement at %C is not applicable to construct '%s'"
+#, gcc-internal-format
 msgid "%s statement at %C is not applicable to construct %qs"
-msgstr "%s оператор в %C не применим к конструкции '%s'"
+msgstr "%s оператор в %C не применим к конструкции %qs"
 
 #: fortran/match.c:2808
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "%s statement at %C leaving OpenMP structured block"
+#, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaving OpenACC structured block"
-msgstr "%s оператор в %C покидающий OpenMP структурный блок"
+msgstr "%s оператор в %C, покидающий OpenACC структурный блок"
 
 #: fortran/match.c:2809
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "%s statement at %C leaving OpenMP structured block"
+#, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C leaving OpenMP structured block"
-msgstr "%s оператор в %C покидающий OpenMP структурный блок"
+msgstr "%s оператор в %C, покидающий OpenMP структурный блок"
 
 #: fortran/match.c:2833
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "EXIT statement at %C terminating !$OMP DO loop"
+#, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement at %C terminating !$ACC LOOP loop"
-msgstr "EXIT оператор в %C терминирующий !$OMP DO цикл"
+msgstr "EXIT оператор в %C, терминирующий !$ACC LOOP цикл"
 
 #: fortran/match.c:2838
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "CYCLE statement at %C to non-innermost collapsed !$OMP DO loop"
+#, gcc-internal-format, gfc-internal-format
 msgid "CYCLE statement at %C to non-innermost collapsed !$ACC LOOP loop"
-msgstr "CYCLE оператор в %C для не самого внутреннего сжатого !$OMP DO цикла"
+msgstr "CYCLE оператор в %C для не самого внутреннего сжатого !$ACC LOOP цикла"
 
 #: fortran/match.c:2867
 #, gcc-internal-format, gfc-internal-format
 msgid "EXIT statement at %C terminating !$OMP DO loop"
-msgstr "EXIT оператор в %C терминирующий !$OMP DO цикл"
+msgstr "EXIT оператор в %C, терминирующий !$OMP DO цикл"
 
 #: fortran/match.c:2872
 #, gcc-internal-format, gfc-internal-format
@@ -62169,27 +55536,24 @@
 msgstr "CYCLE оператор в %C для не самого внутреннего сжатого !$OMP DO цикла"
 
 #: fortran/match.c:2959
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "lvalue required in asm statement"
+#, gcc-internal-format, gfc-internal-format
 msgid "Blank required in %s statement near %C"
-msgstr "в операторе asm требуется lvalue-выражение"
+msgstr "Пробел требуется в %s операторе около %C"
 
 #: fortran/match.c:2977
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "STOP code at %L must be scalar"
+#, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %C cannot be negative"
-msgstr "STOP код в %L должен быть скаляром"
+msgstr "STOP код в %C не может быть отрицательным"
 
 #: fortran/match.c:2983
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %C contains too many digits"
-msgstr ""
+msgstr "STOP код в %C содержит слишком много цифр"
 
 #: fortran/match.c:3004
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Image control statement %s at %C in PURE procedure"
+#, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C in PURE procedure"
-msgstr "Оператор управления внешним видом %s в %C в PURE процедуре"
+msgstr "%s оператор в %C в PURE процедуре"
 
 #: fortran/match.c:3020
 #, gcc-internal-format, gfc-internal-format
@@ -62204,7 +55568,7 @@
 #: fortran/match.c:3036
 #, gcc-internal-format, gfc-internal-format
 msgid "STOP code at %L must be a scalar CHARACTER constant or digit[digit[digit[digit[digit]]]]"
-msgstr ""
+msgstr "STOP код в %L должен быть скалярной CHARACTER константой или digit[digit[digit[digit[digit]]]]"
 
 #: fortran/match.c:3049
 #, gcc-internal-format, gfc-internal-format
@@ -62227,96 +55591,81 @@
 msgstr "STOP код в %L должен быть default integer KIND=%d"
 
 #: fortran/match.c:3118
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Unexpected CASE statement at %C"
+#, gcc-internal-format, gfc-internal-format
 msgid "PAUSE statement at %C"
-msgstr "Неожиданный CASE оператор в %C"
+msgstr "PAUSE оператор в %C"
 
 #: fortran/match.c:3139
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2008: ERROR STOP statement at %C"
+#, gcc-internal-format, gfc-internal-format
 msgid "ERROR STOP statement at %C"
-msgstr "Fortran 2008: ERROR STOP оператор в %C"
+msgstr "ERROR STOP оператор в %C"
 
 #: fortran/match.c:3165
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Image control statement %s at %C in PURE procedure"
+#, gcc-internal-format, gfc-internal-format
 msgid "Image control statement EVENT %s at %C in PURE procedure"
-msgstr "Оператор управления внешним видом %s в %C в PURE процедуре"
+msgstr "Оператор управления внешним видом EVENT %s в %C в PURE процедуре"
 
 #: fortran/match.c:3180
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Image control statement %s at %C in CRITICAL block"
+#, gcc-internal-format, gfc-internal-format
 msgid "Image control statement EVENT %s at %C in CRITICAL block"
-msgstr "Оператор управления внешним видом %s в %C в CRITICAL блоке"
+msgstr "Оператор управления внешним видом EVENT %s в %C в CRITICAL блоке"
 
 #: fortran/match.c:3187
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Image control statement %s at %C in DO CONCURRENT block"
+#, gcc-internal-format, gfc-internal-format
 msgid "Image control statement EVENT %s at %C in DO CONCURRENT block"
-msgstr "Оператор управления внешним видом %s в %C в DO CONCURRENT блоке"
+msgstr "Оператор управления внешним видом EVENT %s в %C в DO CONCURRENT блоке"
 
 #: fortran/match.c:3217 fortran/match.c:3559 fortran/match.c:3771
 #: fortran/match.c:4317 fortran/match.c:4659
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Redundant STAT tag found at %L "
+#, gcc-internal-format, gfc-internal-format
 msgid "Redundant STAT tag found at %L"
-msgstr "Избыточный STAT тег найден в %L "
+msgstr "Избыточный STAT тег найден в %L"
 
 #: fortran/match.c:3238 fortran/match.c:3580 fortran/match.c:3791
 #: fortran/match.c:4343 fortran/match.c:4684
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Redundant ERRMSG tag found at %L "
+#, gcc-internal-format, gfc-internal-format
 msgid "Redundant ERRMSG tag found at %L"
-msgstr "Избыточный ERRMSG тег найден в %L "
+msgstr "Избыточный ERRMSG тег найден в %L"
 
 #: fortran/match.c:3259
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Redundant STAT tag found at %L "
+#, gcc-internal-format, gfc-internal-format
 msgid "Redundant UNTIL_COUNT tag found at %L"
-msgstr "Избыточный STAT тег найден в %L "
+msgstr "Избыточный UNTIL_COUNT тег найден в %L"
 
 #: fortran/match.c:3325
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Empty IMPLICIT statement at %C"
+#, gcc-internal-format, gfc-internal-format
 msgid "EVENT POST statement at %C"
-msgstr "Пустой IMPLICIT оператор в %C"
+msgstr "EVENT POST оператор в %C"
 
 #: fortran/match.c:3335
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Empty IMPLICIT statement at %C"
+#, gcc-internal-format, gfc-internal-format
 msgid "EVENT WAIT statement at %C"
-msgstr "Пустой IMPLICIT оператор в %C"
+msgstr "EVENT WAIT оператор в %C"
 
 #: fortran/match.c:3347
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2003: VALUE statement at %C"
+#, gcc-internal-format, gfc-internal-format
 msgid "FAIL IMAGE statement at %C"
-msgstr "Fortran 2003: VALUE оператор в %C"
+msgstr "FAIL IMAGE оператор в %C"
 
 #: fortran/match.c:3371
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Empty IMPLICIT statement at %C"
+#, gcc-internal-format, gfc-internal-format
 msgid "FORM TEAM statement at %C"
-msgstr "Пустой IMPLICIT оператор в %C"
+msgstr "Оператор FROM TEAM в %C"
 
 #: fortran/match.c:3410
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2003: CLASS statement at %C"
+#, gcc-internal-format, gfc-internal-format
 msgid "CHANGE TEAM statement at %C"
-msgstr "Fortran 2003: CLASS оператор в %C"
+msgstr "Оператор CHANGE TEAM в %C"
 
 #: fortran/match.c:3440
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Empty IMPLICIT statement at %C"
+#, gcc-internal-format, gfc-internal-format
 msgid "END TEAM statement at %C"
-msgstr "Пустой IMPLICIT оператор в %C"
+msgstr ""
 
 #: fortran/match.c:3464
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2008: SYNC statement at %C"
+#, gcc-internal-format, gfc-internal-format
 msgid "SYNC TEAM statement at %C"
-msgstr "Fortran 2008: SYNC оператор в %C"
+msgstr ""
 
 #: fortran/match.c:3507
 #, gcc-internal-format, gfc-internal-format
@@ -62334,22 +55683,19 @@
 msgstr "Оператор управления внешним видом %s в %C в DO CONCURRENT блоке"
 
 #: fortran/match.c:3601
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Redundant ACQUIRED_LOCK tag found at %L "
+#, gcc-internal-format, gfc-internal-format
 msgid "Redundant ACQUIRED_LOCK tag found at %L"
-msgstr "Избыточный ACQUIRED_LOCK тег найден в %L "
+msgstr "Избыточный ACQUIRED_LOCK тег найден в %L"
 
 #: fortran/match.c:3666
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2008: LOCK statement at %C"
+#, gcc-internal-format, gfc-internal-format
 msgid "LOCK statement at %C"
-msgstr "Fortran 2008: LOCK оператор в %C"
+msgstr "LOCK оператор в %C"
 
 #: fortran/match.c:3676
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2008: UNLOCK statement at %C"
+#, gcc-internal-format, gfc-internal-format
 msgid "UNLOCK statement at %C"
-msgstr "Fortran 2008: UNLOCK оператор в %C"
+msgstr "UNLOCK оператор в %C"
 
 #: fortran/match.c:3701
 #, gcc-internal-format, gfc-internal-format
@@ -62357,10 +55703,9 @@
 msgstr "Оператор управления внешним видом SYNC в %C в PURE процедуре"
 
 #: fortran/match.c:3707
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2008: SYNC statement at %C"
+#, gcc-internal-format, gfc-internal-format
 msgid "SYNC statement at %C"
-msgstr "Fortran 2008: SYNC оператор в %C"
+msgstr "SYNC оператор в %C"
 
 #: fortran/match.c:3719
 #, gcc-internal-format, gfc-internal-format
@@ -62373,16 +55718,14 @@
 msgstr "Оператор управления внешним видом SYNC в %C в DO CONCURRENT блоке"
 
 #: fortran/match.c:3905
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Deleted feature: ASSIGN statement at %C"
+#, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %C"
-msgstr "Удаленная возможность: ASSIGN оператор в %C"
+msgstr "ASSIGN оператор в %C"
 
 #: fortran/match.c:3949
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Deleted feature: Assigned GOTO statement at %C"
+#, gcc-internal-format, gfc-internal-format
 msgid "Assigned GOTO statement at %C"
-msgstr "Удаленная возможность: Assigned GOTO оператор в %C"
+msgstr "Assigned GOTO оператор в %C"
 
 #: fortran/match.c:3993 fortran/match.c:4044
 #, gcc-internal-format, gfc-internal-format
@@ -62390,10 +55733,9 @@
 msgstr "Список меток операторов в GOTO в %C не может быть пустым"
 
 #: fortran/match.c:4054
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Obsolescent feature: Computed GOTO at %C"
+#, gcc-internal-format, gfc-internal-format
 msgid "Computed GOTO at %C"
-msgstr "Устаревшая возможность: Вычисляемый GOTO в %C"
+msgstr "Вычисляемый GOTO в %C"
 
 #: fortran/match.c:4129
 #, gcc-internal-format, gfc-internal-format
@@ -62401,10 +55743,9 @@
 msgstr "Ошибка в спецификации типа в %L"
 
 #: fortran/match.c:4142
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2003: typespec in ALLOCATE at %L"
+#, gcc-internal-format, gfc-internal-format
 msgid "typespec in ALLOCATE at %L"
-msgstr "Fortran 2003: typespec в ALLOCATE в %L"
+msgstr "typespec в ALLOCATE в %L"
 
 #: fortran/match.c:4165
 #, gcc-internal-format, gfc-internal-format
@@ -62417,10 +55758,9 @@
 msgstr "Некорректный allocate-object в %C для PURE процедуры"
 
 #: fortran/match.c:4214
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Illegal allocate-object at %C for a PURE procedure"
+#, gcc-internal-format, gfc-internal-format
 msgid "Incompatible allocate-object at %C for CHARACTER type-spec at %L"
-msgstr "Некорректный allocate-object в %C для PURE процедуры"
+msgstr ""
 
 #: fortran/match.c:4236
 #, gcc-internal-format, gfc-internal-format
@@ -62433,10 +55773,9 @@
 msgstr "ALLOCATE комассива в %C в CRITICAL блоке"
 
 #: fortran/match.c:4263
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Allocate-object at %L is not a nonprocedure pointer or an allocatable variable"
+#, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is neither a data pointer nor an allocatable variable"
-msgstr "Allocate-object в %L не есть непроцедурный указатель или размещаемая переменная"
+msgstr "Allocate-object в %L не есть ни указатель на данные ни размещаемая переменная"
 
 #: fortran/match.c:4275
 #, gcc-internal-format, gfc-internal-format
@@ -62454,22 +55793,19 @@
 msgstr "Спецификация формы для размещаемого скаляра в %C"
 
 #: fortran/match.c:4337
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2003: ERRMSG tag at %L"
+#, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG tag at %L"
-msgstr "Fortran 2003: ERRMSG тег в %L"
+msgstr "ERRMSG тег в %L"
 
 #: fortran/match.c:4360
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2003: SOURCE tag at %L"
+#, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L"
-msgstr "Fortran 2003: SOURCE тег в %L"
+msgstr "SOURCE тег в %L"
 
 #: fortran/match.c:4366
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Redundant SOURCE tag found at %L "
+#, gcc-internal-format, gfc-internal-format
 msgid "Redundant SOURCE tag found at %L"
-msgstr "Избыточный SOURCE тег найден в %L "
+msgstr "Избыточный SOURCE тег найден в %L"
 
 #: fortran/match.c:4373
 #, gcc-internal-format, gfc-internal-format
@@ -62477,22 +55813,19 @@
 msgstr "SOURCE тег в %L конфликтует с typespec в %L"
 
 #: fortran/match.c:4379
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2008: SOURCE tag at %L with more than a single allocate object"
+#, gcc-internal-format, gfc-internal-format
 msgid "SOURCE tag at %L with more than a single allocate object"
-msgstr "Fortran 2008: SOURCE тег в %L с более чем одним размещаемым объектом"
+msgstr "SOURCE тег в %L с более чем одним размещаемым объектом"
 
 #: fortran/match.c:4397
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2008: MOLD tag at %L"
+#, gcc-internal-format, gfc-internal-format
 msgid "MOLD tag at %L"
-msgstr "Fortran 2008: MOLD тег в %L"
+msgstr "MOLD тег в %L"
 
 #: fortran/match.c:4403
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Redundant MOLD tag found at %L "
+#, gcc-internal-format, gfc-internal-format
 msgid "Redundant MOLD tag found at %L"
-msgstr "Избыточный MOLD тег найден в %L "
+msgstr "Избыточный MOLD тег найден в %L"
 
 #: fortran/match.c:4410
 #, gcc-internal-format, gfc-internal-format
@@ -62510,10 +55843,9 @@
 msgstr "Allocate-object в %L с параметром отложенного типа требует либо type-spec либо SOURCE тег либо MOLD тег"
 
 #: fortran/match.c:4456
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Allocate-object at %L with a deferred type parameter requires either a type-spec or SOURCE tag or a MOLD tag"
+#, gcc-internal-format, gfc-internal-format
 msgid "Unlimited polymorphic allocate-object at %L requires either a type-spec or SOURCE tag or a MOLD tag"
-msgstr "Allocate-object в %L с параметром отложенного типа требует либо type-spec либо SOURCE тег либо MOLD тег"
+msgstr "Неограниченный полиморфный allocate-object в %L требует или спецификацию типа или SOURCE тег или MOLD тег"
 
 #: fortran/match.c:4523
 #, gcc-internal-format, gfc-internal-format
@@ -62536,16 +55868,14 @@
 msgstr "DEALLOCATE комассива в %C в CRITICAL блоке"
 
 #: fortran/match.c:4642
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Allocate-object at %C is not a nonprocedure pointer or an allocatable variable"
+#, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %C is not a nonprocedure pointer nor an allocatable variable"
 msgstr "Allocate-object в %C не есть непроцедурный указатель или размещаемая переменная"
 
 #: fortran/match.c:4679
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2003: ERRMSG at %L"
+#, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L"
-msgstr "Fortran 2003: ERRMSG в %L"
+msgstr "ERRMSG в %L"
 
 #: fortran/match.c:4736
 #, gcc-internal-format, gfc-internal-format
@@ -62563,10 +55893,9 @@
 msgstr "Alternate RETURN оператор в %C допускается только внутри SUBROUTINE"
 
 #: fortran/match.c:4782
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Extension: RETURN statement in main program at %C"
+#, gcc-internal-format, gfc-internal-format
 msgid "RETURN statement in main program at %C"
-msgstr "Расширение: RETURN оператор в главной программе в %C"
+msgstr "RETURN оператор в главной программе в %C"
 
 #: fortran/match.c:4810
 #, gcc-internal-format, gfc-internal-format
@@ -62592,64 +55921,54 @@
 #. cause it's just semantic, and we can see if there
 #. are more errors.
 #: fortran/match.c:5118
-#, fuzzy, gcc-internal-format
-#| msgid "Variable '%s' at %L in common block '%s' at %C must be declared with a C interoperable kind since common block '%s' is bind(c)"
+#, gcc-internal-format
 msgid "Variable %qs at %L in common block %qs at %C must be declared with a C interoperable kind since common block %qs is bind(c)"
-msgstr "Переменная '%s' в %L в common блоке '%s' at %C должна быть декларирована с C совместимым видом поскольку common блок '%s' есть bind(c)"
+msgstr "Переменная %qs в %L в common блоке %qs at %C должна быть декларирована с C совместимым видом, поскольку common блок %qs есть bind(c)"
 
 #: fortran/match.c:5127
-#, fuzzy, gcc-internal-format
-#| msgid "Variable '%s' in common block '%s' at %C can not be bind(c) since it is not global"
+#, gcc-internal-format
 msgid "Variable %qs in common block %qs at %C can not be bind(c) since it is not global"
-msgstr "Переменная '%s' в common блоке '%s' at %C не может быть bind(c) поскольку она не является глобальной"
+msgstr "Переменная %qs в common блоке %qs at %C не может быть bind(c), поскольку она не является глобальной"
 
 #: fortran/match.c:5134
-#, fuzzy, gcc-internal-format
-#| msgid "Symbol '%s' at %C is already in a COMMON block"
+#, gcc-internal-format
 msgid "Symbol %qs at %C is already in a COMMON block"
-msgstr "Символ '%s' в %C уже в COMMON блоке"
+msgstr "Символ %qs в %C уже в COMMON блоке"
 
 #: fortran/match.c:5142
-#, fuzzy, gcc-internal-format
-#| msgid "Initialized symbol '%s' at %C can only be COMMON in BLOCK DATA"
+#, gcc-internal-format
 msgid "Initialized symbol %qs at %C can only be COMMON in BLOCK DATA"
-msgstr "Инициализированный символ '%s' в %C может быть только COMMON в BLOCK DATA"
+msgstr "Инициализированный символ %qs в %C может быть только COMMON в BLOCK DATA"
 
 #: fortran/match.c:5158
-#, fuzzy, gcc-internal-format
-#| msgid "Array specification for symbol '%s' in COMMON at %C must be explicit"
+#, gcc-internal-format
 msgid "Array specification for symbol %qs in COMMON at %C must be explicit"
-msgstr "Спецификация массива для символа '%s' в COMMON в %C должна быть явной"
+msgstr "Спецификация массива для символа %qs в COMMON в %C должна быть явной"
 
 #: fortran/match.c:5168
-#, fuzzy, gcc-internal-format
-#| msgid "Symbol '%s' in COMMON at %C cannot be a POINTER array"
+#, gcc-internal-format
 msgid "Symbol %qs in COMMON at %C cannot be a POINTER array"
-msgstr "Символ '%s' в COMMON в %C не может быть POINTER массивом"
+msgstr "Символ %qs в COMMON в %C не может быть POINTER массивом"
 
 #: fortran/match.c:5214
-#, fuzzy, gcc-internal-format
-#| msgid "Symbol '%s', in COMMON block '%s' at %C is being indirectly equivalenced to another COMMON block '%s'"
+#, gcc-internal-format
 msgid "Symbol %qs, in COMMON block %qs at %C is being indirectly equivalenced to another COMMON block %qs"
-msgstr "Символ '%s' в COMMON блоке '%s' в %C становится косвенно эквивалентным другому COMMON блоку '%s'"
+msgstr "Символ %qs в COMMON блоке %qs в %C становится косвенно эквивалентным другому COMMON блоку %qs"
 
 #: fortran/match.c:5342
-#, fuzzy, gcc-internal-format
-#| msgid "Namelist group name '%s' at %C already has a basic type of %s"
+#, gcc-internal-format
 msgid "Namelist group name %qs at %C already has a basic type of %s"
-msgstr "Имя NAMELIST группы '%s' at %C уже имеет базовый тип %s"
+msgstr "Имя NAMELIST группы %qs в %C уже имеет базовый тип %s"
 
 #: fortran/match.c:5350
-#, fuzzy, gcc-internal-format
-#| msgid "Namelist group name '%s' at %C already is USE associated and cannot be respecified."
+#, gcc-internal-format
 msgid "Namelist group name %qs at %C already is USE associated and cannot be respecified."
-msgstr "Имя NAMELIST группы '%s' at %C уже USE ассоциировано и не может быть респецифицировано."
+msgstr "Имя NAMELIST группы %qs в %C уже USE ассоциировано и не может быть респецифицировано."
 
 #: fortran/match.c:5376
-#, fuzzy, gcc-internal-format
-#| msgid "Assumed size array '%s' in namelist '%s' at %C is not allowed"
+#, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %C is not allowed"
-msgstr "Массив предполагаемого размера '%s' в списке имен '%s' в %C не допускается"
+msgstr "Массив предполагаемого размера %qs в списке имен %qs в %C не допускается"
 
 #: fortran/match.c:5510
 #, gcc-internal-format, gfc-internal-format
@@ -62682,22 +56001,19 @@
 msgstr "Оператор функция в %L рекурсивна"
 
 #: fortran/match.c:5699
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "ENTRY statement at %C cannot appear within an INTERFACE"
+#, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %L cannot appear within an INTERFACE"
-msgstr "ENTRY оператор в %C не может появляться внутри INTERFACE"
+msgstr "Оператор функция в %L не может появляться внутри INTERFACE"
 
 #: fortran/match.c:5704
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Statement function at %L is recursive"
+#, gcc-internal-format, gfc-internal-format
 msgid "Statement function at %C"
-msgstr "Оператор функция в %L рекурсивна"
+msgstr "Оператор функция в %C"
 
 #: fortran/match.c:5829 fortran/match.c:5845
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Expression in CASE statement at %L must be scalar"
+#, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE selector at %L cannot be %s"
-msgstr "Выражение в CASE операторе в %L должно быть скаляром"
+msgstr "Выражение в CASE селекторе в %L не может быть %s"
 
 #: fortran/match.c:5867
 #, gcc-internal-format, gfc-internal-format
@@ -62705,79 +56021,74 @@
 msgstr "Ожидалось инициализационное выражение в CASE в %C"
 
 #: fortran/match.c:5899
-#, fuzzy, gcc-internal-format
-#| msgid "Expected block name '%s' of SELECT construct at %C"
+#, gcc-internal-format
 msgid "Expected block name %qs of SELECT construct at %C"
-msgstr "Ожидалось имя блока '%s' SELECT конструкции в %C"
+msgstr "Ожидалось имя блока %qs SELECT конструкции в %C"
 
-#: fortran/match.c:6186
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Syntax error in PROTECTED statement at %C"
+#: fortran/match.c:6201
+#, gcc-internal-format, gfc-internal-format
 msgid "parse error in SELECT TYPE statement at %C"
-msgstr "Синтаксическая ошибка в PROTECTED операторе в %C"
+msgstr "ошибка разбора в SELECT TYPE операторе в %C"
 
-#: fortran/match.c:6211
+#: fortran/match.c:6226
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr "Селектор в SELECT TYPE в %C не есть именованная переменная; используйте associate-name=>"
 
-#: fortran/match.c:6249
+#: fortran/match.c:6264
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr "Неожиданный CASE оператор в %C"
 
-#: fortran/match.c:6301
+#: fortran/match.c:6316
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CASE specification at %C"
 msgstr "Синтаксическая ошибка в CASE спецификации в %C"
 
-#: fortran/match.c:6319
+#: fortran/match.c:6334
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected TYPE IS statement at %C"
 msgstr "Неожиданный TYPE IS оператор в %C"
 
-#: fortran/match.c:6351
+#: fortran/match.c:6366
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
-msgstr ""
+msgstr "Спецификация типа не должна специфицировать sequence производный тип или тип с BIND атрибутом в SELECT TYPE в %C [F2003:C815]"
 
-#: fortran/match.c:6362
+#: fortran/match.c:6377
 #, gcc-internal-format, gfc-internal-format
 msgid "All the LEN type parameters in the TYPE IS statement at %C must be ASSUMED"
 msgstr ""
 
-#: fortran/match.c:6373
+#: fortran/match.c:6388
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr "Синтаксическая ошибка в TYPE IS спецификации в %C"
 
-#: fortran/match.c:6449
+#: fortran/match.c:6464
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr "Синтаксическая ошибка в CLASS IS спецификации в %C"
 
-#: fortran/match.c:6572
+#: fortran/match.c:6587
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr "ELSEWHERE оператор в %C не заключен в WHERE блок"
 
-#: fortran/match.c:6610
-#, fuzzy, gcc-internal-format
-#| msgid "Label '%s' at %C doesn't match WHERE label '%s'"
+#: fortran/match.c:6625
+#, gcc-internal-format
 msgid "Label %qs at %C doesn't match WHERE label %qs"
-msgstr "Метка '%s' в %C не соответствует WHERE метке '%s'"
+msgstr "Метка %qs в %C не соответствует WHERE метке %qs"
 
 #: fortran/matchexp.c:72
-#, fuzzy, gcc-internal-format
-#| msgid "Bad character '%c' in OPERATOR name at %C"
+#, gcc-internal-format
 msgid "Bad character %qc in OPERATOR name at %C"
-msgstr "Некорректный символ '%c' в OPERATOR имени в %C"
+msgstr "Некорректный символ %qc в OPERATOR имени в %C"
 
 #: fortran/matchexp.c:80
-#, fuzzy, gcc-internal-format
-#| msgid "The name '%s' cannot be used as a defined operator at %C"
+#, gcc-internal-format
 msgid "The name %qs cannot be used as a defined operator at %C"
-msgstr "Имя '%s' не может быть использовано как определенный оператор в %C"
+msgstr "Имя %qs не может быть использовано как определенный оператор в %C"
 
 #: fortran/matchexp.c:173
 #, gcc-internal-format, gfc-internal-format
@@ -62793,44 +56104,42 @@
 #: fortran/matchexp.c:433
 #, gcc-internal-format, gfc-internal-format
 msgid "Extension: Unary operator following arithmetic operator (use parentheses) at %C"
-msgstr "Расширение: Унарный оператор следущий за арифметическим оператором (используйте скобки) в %C"
+msgstr "Расширение: Унарный оператор, следующий за арифметическим оператором (используйте скобки) в %C"
 
 #: fortran/matchexp.c:665
 #, gcc-internal-format
 msgid "match_level_4(): Bad operator"
-msgstr ""
+msgstr "match_level_4(): Некорректный оператор"
 
 #: fortran/misc.c:110
 #, gcc-internal-format
 msgid "gfc_basic_typename(): Undefined type"
-msgstr ""
+msgstr "gfc_basic_typename(): Неопределенный тип"
 
 #: fortran/misc.c:176
 #, gcc-internal-format
 msgid "gfc_typename(): Undefined type"
-msgstr ""
+msgstr "gfc_typename(): Неопределенный тип"
 
 #: fortran/misc.c:196
-#, fuzzy, gcc-internal-format
-#| msgid "gfc_trans_code(): Bad statement code"
+#, gcc-internal-format
 msgid "gfc_code2string(): Bad code"
-msgstr "gfc_trans_code(): Некорректный код оператора"
+msgstr "gfc_code2string(): Некорректный код"
 
 #: fortran/module.c:236
 #, gcc-internal-format
 msgid "free_pi_tree(): Unresolved fixup"
-msgstr ""
+msgstr "free_pi_tree(): Неразрешенное исправление"
 
 #: fortran/module.c:453
 #, gcc-internal-format
 msgid "associate_integer_pointer(): Already associated"
-msgstr ""
+msgstr "associate_integer_pointer(): Уже ассоциировано"
 
 #: fortran/module.c:535
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2003: module nature in USE statement at %C"
+#, gcc-internal-format, gfc-internal-format
 msgid "module nature in USE statement at %C"
-msgstr "Fortran 2003: природа модуля в USE операторе в %C"
+msgstr "природа модуля в USE операторе в %C"
 
 #: fortran/module.c:547
 #, gcc-internal-format, gfc-internal-format
@@ -62840,13 +56149,12 @@
 #: fortran/module.c:560
 #, gcc-internal-format, gfc-internal-format
 msgid "\"::\" was expected after module nature at %C but was not found"
-msgstr "\"::\" ожидалось после природы модуля в %C но не было найдено"
+msgstr "\"::\" ожидалось после природы модуля в %C, но не было найдено"
 
 #: fortran/module.c:570
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2003: \"USE :: module\" at %C"
+#, gcc-internal-format, gfc-internal-format
 msgid "\"USE :: module\" at %C"
-msgstr "Fortran 2003: \"USE :: module\" в %C"
+msgstr "\"USE :: модуль\" в %C"
 
 #: fortran/module.c:629
 #, gcc-internal-format, gfc-internal-format
@@ -62854,57 +56162,49 @@
 msgstr "Отсутствует generic спецификация в USE операторе в %C"
 
 #: fortran/module.c:638
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2003: Renaming operators in USE statements at %C"
+#, gcc-internal-format, gfc-internal-format
 msgid "Renaming operators in USE statements at %C"
-msgstr "Fortran 2003: Операторы переименования в USE операторе в %C"
+msgstr "Операторы переименования в USE операторе в %C"
 
 #: fortran/module.c:679
-#, fuzzy, gcc-internal-format
-#| msgid "The name '%s' at %C has already been used as an external module name."
+#, gcc-internal-format
 msgid "The name %qs at %C has already been used as an external module name"
-msgstr "Имя '%s' в %C уже было использовано как имя внешнего модуля."
+msgstr "Имя %qs в %C уже было использовано как имя внешнего модуля"
 
 #: fortran/module.c:742
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "in declaration %q+D"
+#, gcc-internal-format, gfc-internal-format
 msgid "SUBMODULE declaration at %C"
-msgstr "в декларации %q+D"
+msgstr "SUBMODULE декларация в %C"
 
 #: fortran/module.c:747
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "ENTRY statement at %C cannot appear within a contained subprogram"
+#, gcc-internal-format, gfc-internal-format
 msgid "SUBMODULE declaration at %C cannot appear within another scoping unit"
-msgstr "ENTRY оператор в %C не может появляться внутри внутренней подпрограммы"
+msgstr "SUBMODULE декларация в %C не может появляться внутри другой области видимости"
 
 #: fortran/module.c:822
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Syntax error in SAVE statement at %C"
+#, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SUBMODULE statement at %C"
-msgstr "Синтаксическая ошибка в SAVE операторе в %C"
+msgstr "Синтаксическая ошибка в SUBMODULE операторе в %C"
 
 #: fortran/module.c:1167
-#, fuzzy, gcc-internal-format
-#| msgid "Reading module %s at line %d column %d: %s"
+#, gcc-internal-format
 msgid "Reading module %qs at line %d column %d: %s"
-msgstr "Чтение модуля %s в строке %d колонке %d: %s"
+msgstr "Чтение модуля %qs в строке %d колонке %d: %s"
 
 #: fortran/module.c:1171
-#, fuzzy, gcc-internal-format
-#| msgid "Writing module %s at line %d column %d: %s"
+#, gcc-internal-format
 msgid "Writing module %qs at line %d column %d: %s"
-msgstr "Запись модуля %s в строке %d колонке %d: %s"
+msgstr "Запись модуля %qs в строке %d колонке %d: %s"
 
 #: fortran/module.c:1175
-#, fuzzy, gcc-internal-format
-#| msgid "Module %s at line %d column %d: %s"
+#, gcc-internal-format
 msgid "Module %qs at line %d column %d: %s"
-msgstr "Модуль %s в строке %d колонке %d: %s"
+msgstr "Модуль %qs в строке %d колонке %d: %s"
 
 #: fortran/module.c:1568
 #, gcc-internal-format
 msgid "require_atom(): bad atom type required"
-msgstr ""
+msgstr "require_atom(): некорректный атомарный тип требуется"
 
 #: fortran/module.c:1617
 #, gcc-internal-format, gfc-internal-format
@@ -62914,224 +56214,200 @@
 #: fortran/module.c:1667
 #, gcc-internal-format
 msgid "write_atom(): Trying to write dab atom"
-msgstr ""
+msgstr "write_atom(): Попытка записи dab atom"
 
 #: fortran/module.c:1888
 #, gcc-internal-format
 msgid "unquote_string(): got bad string"
-msgstr ""
+msgstr "unquote_string(): получена некорректная цепочка"
 
 #: fortran/module.c:2724
 #, gcc-internal-format
 msgid "mio_array_ref(): Unknown array ref"
-msgstr ""
+msgstr "mio_array_ref(): Неизвестная массивная ссылка"
 
-#: fortran/module.c:3716
+#: fortran/module.c:3718
 #, gcc-internal-format, gfc-internal-format
 msgid "Namelist %s cannot be renamed by USE association to %s"
 msgstr "Список имен %s не может быть переименован путем USE ассоциации в %s"
 
-#: fortran/module.c:4832
+#: fortran/module.c:4834
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous !$OMP DECLARE REDUCTION from module %s at %L"
-msgstr ""
+msgstr "Неоднозначная !$OMP DECLARE REDUCTION из модуля %s в %L"
 
-#: fortran/module.c:4835
+#: fortran/module.c:4837
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION from module %s at %L"
-msgstr ""
+msgstr "Предыдущая !$OMP DECLARE REDUCTION из модуля %s в %L"
 
-#: fortran/module.c:5029
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' of module '%s', imported at %C, is also the name of the current program unit"
+#: fortran/module.c:5031
+#, gcc-internal-format
 msgid "%qs of module %qs, imported at %C, is also the name of the current program unit"
-msgstr "'%s' от модуля '%s', импортированного в %C, есть также имя текущей программной единицы"
+msgstr "%qs от модуля %qs, импортированного в %C, есть также имя текущей программной единицы"
 
-#: fortran/module.c:5381
-#, fuzzy, gcc-internal-format
-#| msgid "Symbol '%s' referenced at %L not found in module '%s'"
+#: fortran/module.c:5383
+#, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in module %qs"
-msgstr "Символ '%s' встречающийся в %L не найден в модуле '%s'"
+msgstr "Символ %qs, встречающийся в %L, не найден в модуле %qs"
 
-#: fortran/module.c:5388
-#, fuzzy, gcc-internal-format
-#| msgid "User operator '%s' referenced at %L not found in module '%s'"
+#: fortran/module.c:5390
+#, gcc-internal-format
 msgid "User operator %qs referenced at %L not found in module %qs"
-msgstr "Пользовательский оператор '%s' встречающийся в %L не найден в модуле '%s'"
+msgstr "Пользовательский оператор %qs, на который ссылаются в %L не найден в модуле %qs"
 
-#: fortran/module.c:5393
-#, fuzzy, gcc-internal-format
-#| msgid "Intrinsic operator '%s' referenced at %L not found in module '%s'"
+#: fortran/module.c:5395
+#, gcc-internal-format
 msgid "Intrinsic operator %qs referenced at %L not found in module %qs"
-msgstr "Встроенный оператор '%s' встречающийся в %L не найден в модуле '%s'"
+msgstr "Встроенный оператор %qs, на который ссылаются в %L не найден в модуле %qs"
 
-#: fortran/module.c:5628
+#: fortran/module.c:5630
 #, gcc-internal-format
 msgid "write_symbol(): bad module symbol %qs"
-msgstr ""
+msgstr "write_symbol(): некорректный символ модуля %qs"
 
-#: fortran/module.c:5961
+#: fortran/module.c:5963
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
-msgstr ""
+msgstr "write_symtree(): Символ не записан"
 
-#: fortran/module.c:6148
-#, fuzzy, gcc-internal-format
-#| msgid "Can't open module file '%s' for writing at %C: %s"
+#: fortran/module.c:6150
+#, gcc-internal-format
 msgid "Can't open module file %qs for writing at %C: %s"
-msgstr "Не удалось открыть файл модуля '%s' для записи в %C: %s"
+msgstr "Не удалось открыть файл модуля %qs для записи в %C: %s"
 
-#: fortran/module.c:6169
-#, fuzzy, gcc-internal-format
-#| msgid "Error writing module file '%s' for writing: %s"
+#: fortran/module.c:6171
+#, gcc-internal-format
 msgid "Error writing module file %qs for writing: %s"
-msgstr "Ошибка записи файла модуля '%s' для записи: %s"
+msgstr "Ошибка записи файла модуля %qs для записи: %s"
 
-#: fortran/module.c:6180
-#, fuzzy, gcc-internal-format
-#| msgid "Can't delete module file '%s': %s"
+#: fortran/module.c:6182
+#, gcc-internal-format
 msgid "Can't delete module file %qs: %s"
-msgstr "Не удалось удалить файл модуля '%s': %s"
+msgstr "Не удалось удалить файл модуля %qs: %s"
 
-#: fortran/module.c:6183
-#, fuzzy, gcc-internal-format
-#| msgid "Can't rename module file '%s' to '%s': %s"
+#: fortran/module.c:6185
+#, gcc-internal-format
 msgid "Can't rename module file %qs to %qs: %s"
-msgstr "Не удалось переименовать файл модуля '%s' в '%s': %s"
+msgstr "Не удалось переименовать файл модуля %qs в %qs: %s"
 
-#: fortran/module.c:6189
-#, fuzzy, gcc-internal-format
-#| msgid "Can't delete temporary module file '%s': %s"
+#: fortran/module.c:6191
+#, gcc-internal-format
 msgid "Can't delete temporary module file %qs: %s"
-msgstr "Не удалось удалить временный файл модуля '%s': %s"
+msgstr "Не удалось удалить временный файл модуля %qs: %s"
 
-#: fortran/module.c:6246
-#, fuzzy, gcc-internal-format
-#| msgid "Symbol '%s' already declared"
+#: fortran/module.c:6248
+#, gcc-internal-format
 msgid "Symbol %qs at %C already declared"
-msgstr "Символ '%s' уже декларирован"
+msgstr "Символ %qs в %C уже декларирован"
 
-#: fortran/module.c:6317
+#: fortran/module.c:6319
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
-msgstr ""
+msgstr "import_iso_c_binding_module(): невозможно создать символ для %s"
 
-#: fortran/module.c:6425 fortran/module.c:6769
-#, fuzzy, gcc-internal-format
-#| msgid "The symbol '%s', referenced at %L, is not in the selected standard"
+#: fortran/module.c:6427 fortran/module.c:6771
+#, gcc-internal-format
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
-msgstr "Символ '%s', встречающийся в %L, не содержится в выбранном стандарте"
+msgstr "Символ %qs, на который ссылаются в %L, не содержится в выбранном стандарте"
 
-#: fortran/module.c:6553
-#, fuzzy, gcc-internal-format
-#| msgid "Symbol '%s' referenced at %L not found in intrinsic module ISO_C_BINDING"
+#: fortran/module.c:6555
+#, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
-msgstr "Символ '%s' встречающийся в %L не найден во встроенном модуле ISO_C_BINDING"
+msgstr "Символ %qs, на который ссылаются в %L не найден во встроенном модуле ISO_C_BINDING"
 
-#: fortran/module.c:6574 fortran/module.c:6607 fortran/module.c:6649
-#, fuzzy, gcc-internal-format
-#| msgid "Symbol '%s' already declared"
+#: fortran/module.c:6576 fortran/module.c:6609 fortran/module.c:6651
+#, gcc-internal-format
 msgid "Symbol %qs already declared"
-msgstr "Символ '%s' уже декларирован"
+msgstr "Символ %qs уже декларирован"
 
-#: fortran/module.c:6754
-#, fuzzy, gcc-internal-format
-#| msgid "Use of intrinsic module '%s' at %C conflicts with non-intrinsic module name used previously"
+#: fortran/module.c:6756
+#, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
-msgstr "Использование встроенного модуля '%s' в %C конфликтует с именем невстроенного модуля использованным ранее"
+msgstr "Использование встроенного модуля %qs в %C конфликтует с именем невстроенного модуля использованного ранее"
 
-#: fortran/module.c:6776
-#, fuzzy, gcc-internal-format
-#| msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %s"
+#: fortran/module.c:6778
+#, gcc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
-msgstr "Использование NUMERIC_STORAGE_SIZE именованной константы из встроенного модуля ISO_FORTRAN_ENV в %L несовместимо с опцией %s"
+msgstr "Использование NUMERIC_STORAGE_SIZE именованной константы из встроенного модуля ISO_FORTRAN_ENV в %L несовместимо с опцией %qs"
 
-#: fortran/module.c:6844
+#: fortran/module.c:6846
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr "Использование NUMERIC_STORAGE_SIZE именованной константы из встроенного модуля ISO_FORTRAN_ENV в %C несовместимо с опцией %s"
 
-#: fortran/module.c:6898
-#, fuzzy, gcc-internal-format
-#| msgid "Symbol '%s' referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
+#: fortran/module.c:6900
+#, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
-msgstr "Символ '%s' встречающийся в %L не найден во встроенном модуле ISO_FORTRAN_ENV"
+msgstr "Символ %qs, на который ссылаются в %L не найден во встроенном модуле ISO_FORTRAN_ENV"
 
-#: fortran/module.c:6924
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "CLOSE statement at %L requires a UNIT number"
+#: fortran/module.c:6926
+#, gcc-internal-format, gfc-internal-format
 msgid "USE statement at %C has no ONLY qualifier"
-msgstr "CLOSE оператор в %L требует UNIT номер"
+msgstr "USE оператор в %C не имеет ONLY квалификатора"
 
-#: fortran/module.c:6953
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2003: ISO_FORTRAN_ENV intrinsic module at %C"
+#: fortran/module.c:6955
+#, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
-msgstr "Fortran 2003: ISO_FORTRAN_ENV встроенный модуль в %C"
+msgstr "ISO_FORTRAN_ENV встроенный модуль в %C"
 
-#: fortran/module.c:6965
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2003: ISO_C_BINDING module at %C"
+#: fortran/module.c:6967
+#, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
-msgstr "Fortran 2003: ISO_C_BINDING модуль в %C"
+msgstr "ISO_C_BINDING модуль в %C"
 
-#: fortran/module.c:6978
-#, fuzzy, gcc-internal-format
-#| msgid "Can't find an intrinsic module named '%s' at %C"
+#: fortran/module.c:6980
+#, gcc-internal-format
 msgid "Can't find an intrinsic module named %qs at %C"
-msgstr "Не удалось найти встроенный модуль с названный '%s' в %C"
+msgstr "Не удалось найти встроенный модуль названный %qs в %C"
 
-#: fortran/module.c:6984
+#: fortran/module.c:6986
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
-msgstr ""
+msgstr "IEEE_FEATURES модуль в %C"
 
-#: fortran/module.c:6990
+#: fortran/module.c:6992
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
-msgstr ""
+msgstr "IEEE_EXCEPTIONS модуль в %C"
 
-#: fortran/module.c:6996
+#: fortran/module.c:6998
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
-msgstr ""
+msgstr "IEEE_ARITHMETIC модуль в %C"
 
-#: fortran/module.c:7006
-#, fuzzy, gcc-internal-format
-#| msgid "Can't open module file '%s' for reading at %C: %s"
+#: fortran/module.c:7008
+#, gcc-internal-format
 msgid "Can't open module file %qs for reading at %C: %s"
-msgstr "Ошибка открытия файла модуля '%s' на чтение в %C: %s"
+msgstr "Ошибка открытия файла модуля %qs на чтение в %C: %s"
 
-#: fortran/module.c:7009
+#: fortran/module.c:7011
 #, gcc-internal-format
 msgid "Module file %qs has not been generated, either because the module does not contain a MODULE PROCEDURE or there is an error in the module."
-msgstr ""
+msgstr "Файл модуля %qs не сгенерирован, так как модуль или не содержит MODULE PROCEDURE или в модуле есть ошибки."
 
-#: fortran/module.c:7020
-#, fuzzy, gcc-internal-format
-#| msgid "Use of non-intrinsic module '%s' at %C conflicts with intrinsic module name used previously"
+#: fortran/module.c:7022
+#, gcc-internal-format
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
-msgstr "Использование невстроенного модуля '%s' в %C конфликтует с именем встроенного модуля использованным ранее"
+msgstr "Использование невстроенного модуля %qs в %C конфликтует с именем встроенного модуля использованного ранее"
 
-#: fortran/module.c:7043
-#, fuzzy, gcc-internal-format
-#| msgid "File '%s' opened at %C is not a GFORTRAN module file"
+#: fortran/module.c:7045
+#, gcc-internal-format
 msgid "File %qs opened at %C is not a GNU Fortran module file"
-msgstr "Файл '%s' открытый в %C не есть GFORTRAN файл модуля"
+msgstr "Файл %qs открытый в %C не есть файл GNU Fortran модуля"
 
-#: fortran/module.c:7051
+#: fortran/module.c:7053
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
-msgstr ""
+msgstr "Не читается файл модуля %qs открытый в %C, так как от был создан другой версией GNU Fortran"
 
-#: fortran/module.c:7066
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Can't USE the same module we're building!"
+#: fortran/module.c:7068
+#, gcc-internal-format, gfc-internal-format
 msgid "Can't USE the same %smodule we're building"
-msgstr "Невозможно USE тот же модуль что мы строим!"
+msgstr ""
 
 #: fortran/openmp.c:296 fortran/openmp.c:397 fortran/openmp.c:692
-#: fortran/openmp.c:3167
+#: fortran/openmp.c:3166
 #, gcc-internal-format, gfc-internal-format
 msgid "COMMON block /%s/ not found at %C"
 msgstr "COMMON блок /%s/ не найден в %C"
@@ -63142,40 +56418,34 @@
 msgstr "Синтаксическая ошибка в OpenMP списке переменных в %C"
 
 #: fortran/openmp.c:499
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Syntax error in OpenMP variable list at %C"
+#, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in OpenMP DEPEND SINK list at %C"
-msgstr "Синтаксическая ошибка в OpenMP списке переменных в %C"
+msgstr "Синтаксическая ошибка в OpenMP DEPEND SINK списке в %C"
 
 #: fortran/openmp.c:561
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Syntax error in expression at %C"
+#, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in OpenACC expression list at %C"
-msgstr "Синтаксическая ошибка в выражении в %C"
+msgstr "Синтаксическая ошибка в OpenACC списке выражений в %C"
 
 #: fortran/openmp.c:628
-#, fuzzy, gcc-internal-format
-#| msgid "Unexpected element"
+#, gcc-internal-format
 msgid "Unexpected OpenACC parallelism."
-msgstr "Неожиданный элемент"
+msgstr "Неожиданный OpenACC параллелизм."
 
 #: fortran/openmp.c:660
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Threadprivate variable at %C is an element of a COMMON block"
+#, gcc-internal-format, gfc-internal-format
 msgid "Variable at %C is an element of a COMMON block"
-msgstr "Threadprivate переменная в %C является элементом COMMON блока"
+msgstr "Переменная в %C является элементом COMMON блока"
 
 #: fortran/openmp.c:720
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Unexpected junk after $OMP ORDERED statement at %C"
+#, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after !$ACC DECLARE at %C"
-msgstr "Неожиданный мусор после $OMP ORDERED оператора в %C"
+msgstr "Неожиданный мусор после !$ACC DECLARE в %C"
 
 #: fortran/openmp.c:730
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Syntax error in !$OMP THREADPRIVATE list at %C"
+#, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$ACC DECLARE list at %C"
-msgstr "Синтаксическая ошибка в !$OMP THREADPRIVATE списке в %C"
+msgstr "Синтаксическая ошибка в !$ACC DECLARE списке в %C"
 
 #: fortran/openmp.c:1032
 #, gcc-internal-format, gfc-internal-format
@@ -63183,990 +56453,895 @@
 msgstr "Аргумент COLLAPSE клаузулы не есть положительная целая константа в %C"
 
 #: fortran/openmp.c:1492
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "COLLAPSE clause argument not constant positive integer at %C"
+#, gcc-internal-format, gfc-internal-format
 msgid "ORDERED clause argument not constant positive integer at %C"
-msgstr "Аргумент COLLAPSE клаузулы не есть положительная целая константа в %C"
+msgstr "Аргумент ORDERED клаузулы не есть положительная целая константа в %C"
 
 #: fortran/openmp.c:1675
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP DECLARE REDUCTION %s not found at %L"
-msgstr ""
+msgstr "!$OMP DECLARE REDUCTION %s не найдена в %L"
 
 #
 #: fortran/openmp.c:2067
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Invalid third argument of IBITS at %L"
+#, gcc-internal-format, gfc-internal-format
 msgid "Invalid clause in module with !$ACC DECLARE at %L"
-msgstr "Некорректный третий аргумент IBITS в %L"
+msgstr "Некорректная клаузула в модуле с !$ACC DECLARE в %L"
 
 #: fortran/openmp.c:2077
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Array section not permitted in '%s' call at %L"
+#, gcc-internal-format, gfc-internal-format
 msgid "Variable is USE-associated with !$ACC DECLARE at %L"
-msgstr "Секция массива не разрешена в '%s' вызове в %L"
+msgstr "Переменная USE-ассоциирована с !$ACC DECLARE at %L"
 
 #: fortran/openmp.c:2085
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Assumed size array '%s' in %s clause at %L"
+#, gcc-internal-format, gfc-internal-format
 msgid "Assumed-size dummy array with !$ACC DECLARE at %L"
-msgstr "Массив предполагаемого размера '%s' в %s клаузуле в %L"
+msgstr "Формальный массив предполагаемого размера с !$ACC DECLARE в %L"
 
 #: fortran/openmp.c:2132
 #, gcc-internal-format
 msgid "%<acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause at %L"
-msgstr ""
+msgstr "%<acc update%> должна содержать хотя бы одну %<device%> или %<host%> или %<self%> клаузулу в %L"
 
 #
 #: fortran/openmp.c:2180
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Invalid third argument of IBITS at %L"
-msgid "Invalid argument to !$ACC WAIT at %L"
-msgstr "Некорректный третий аргумент IBITS в %L"
+#, gcc-internal-format, gfc-internal-format
+msgid "Invalid argument to !$ACC WAIT at %C"
+msgstr "Недопустимый аргумент для !$ACC WAIT в %C"
 
-#: fortran/openmp.c:2188
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "NUM_THREADS clause at %L requires a scalar INTEGER expression"
+#: fortran/openmp.c:2187
+#, gcc-internal-format, gfc-internal-format
 msgid "WAIT clause at %L requires a scalar INTEGER expression"
-msgstr "NUM_THREADS клаузула в %L требует скалярное INTEGER выражение"
+msgstr "Для предложения WAIT %L требуется выражение INTEGER"
 
-#: fortran/openmp.c:2221
+#: fortran/openmp.c:2220
 #, gcc-internal-format, gfc-internal-format
 msgid "ACC CACHE directive must be inside of loop %C"
-msgstr ""
+msgstr "ACC CACHE директива должна быть внутри цикла %C"
 
-#: fortran/openmp.c:2252
-#, fuzzy, gcc-internal-format
-#| msgid "storage class specified for typename"
+#: fortran/openmp.c:2251
+#, gcc-internal-format
 msgid "Multiple loop axes specified for routine"
-msgstr "класс хранения задан для имени типа"
+msgstr "Несколько осей циклов задано для программы"
 
-#: fortran/openmp.c:2278
+#: fortran/openmp.c:2277
 #, gcc-internal-format, gfc-internal-format
 msgid "Only the !$ACC ROUTINE form without list is allowed in interface block at %C"
-msgstr ""
+msgstr "Только !$ACC ROUTINE форма без списка допустима в интерфейсном блоке в %C"
 
-#: fortran/openmp.c:2306
+#: fortran/openmp.c:2305
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$ACC ROUTINE ( NAME ) at %C, invalid function name %s"
-msgstr ""
+msgstr "Синтаксическая ошибка в !$ACC ROUTINE ( NAME ) в %C, некорректное имя функции %s"
 
-#: fortran/openmp.c:2315
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
+#: fortran/openmp.c:2314
+#, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$ACC ROUTINE ( NAME ) at %C"
-msgstr "Синтаксическая ошибка в !GCC$ ATTRIBUTES операторе в %C"
+msgstr "Синтаксическая ошибка в !$ACC ROUTINE ( NAME ) в %C"
 
-#: fortran/openmp.c:2322
+#: fortran/openmp.c:2321
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$ACC ROUTINE ( NAME ) at %C, expecting ')' after NAME"
-msgstr ""
+msgstr "Синтаксическая ошибка в !$ACC ROUTINE ( NAME ) в %C, ожидалась ')' после NAME"
 
-#: fortran/openmp.c:2457 fortran/openmp.c:2481
+#: fortran/openmp.c:2456 fortran/openmp.c:2480
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP CRITICAL statement at %C"
 msgstr "Неожиданный мусор после $OMP CRITICAL оператора в %C"
 
-#: fortran/openmp.c:2548
+#: fortran/openmp.c:2547
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP FLUSH statement at %C"
 msgstr "Неожиданный мусор после $OMP FLUSH оператора в %C"
 
-#: fortran/openmp.c:2942 fortran/openmp.c:6225
+#: fortran/openmp.c:2941 fortran/openmp.c:6230
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined %s !$OMP DECLARE REDUCTION at %L"
-msgstr ""
+msgstr "Переопределение предопределенной %s !$OMP DECLARE REDUCTION в %L"
 
-#: fortran/openmp.c:2946 fortran/openmp.c:6229
+#: fortran/openmp.c:2945 fortran/openmp.c:6234
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined !$OMP DECLARE REDUCTION at %L"
-msgstr ""
+msgstr "Переопределение предопределенной !$OMP DECLARE REDUCTION в %L"
 
-#: fortran/openmp.c:2951
+#: fortran/openmp.c:2950
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of !$OMP DECLARE REDUCTION at %L"
-msgstr ""
+msgstr "Переопределение !$OMP DECLARE REDUCTION в %L"
 
-#: fortran/openmp.c:2953
+#: fortran/openmp.c:2952
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION at %L"
-msgstr ""
+msgstr "Предыдущая !$OMP DECLARE REDUCTION в %L"
 
-#: fortran/openmp.c:2973
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Unexpected junk after $OMP ORDERED statement at %C"
+#: fortran/openmp.c:2972
+#, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after !$OMP DECLARE REDUCTION at %C"
-msgstr "Неожиданный мусор после $OMP ORDERED оператора в %C"
+msgstr "Неожиданный мусор после !$OMP DECLARE REDUCTION в %C"
 
-#: fortran/openmp.c:3010
+#: fortran/openmp.c:3009
 #, gcc-internal-format, gfc-internal-format
 msgid "Only the !$OMP DECLARE TARGET form without clauses is allowed in interface block at %C"
-msgstr ""
+msgstr "Только !$OMP DECLARE TARGET форма без клаузул допустима в интерфейсном блоке в %C"
 
-#: fortran/openmp.c:3025
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Unexpected junk after $OMP ORDERED statement at %C"
+#: fortran/openmp.c:3024
+#, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after !$OMP DECLARE TARGET at %C"
-msgstr "Неожиданный мусор после $OMP ORDERED оператора в %C"
+msgstr "Неожиданный мусор после !$OMP DECLARE TARGET в %C"
 
-#: fortran/openmp.c:3048
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Threadprivate variable at %C is an element of a COMMON block"
+#: fortran/openmp.c:3047
+#, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET variable at %L is an element of a COMMON block"
-msgstr "Threadprivate переменная в %C является элементом COMMON блока"
+msgstr "OMP DECLARE TARGET переменная в %L является элементом COMMON блока"
 
-#: fortran/openmp.c:3053
+#: fortran/openmp.c:3052
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET variable at %L previously mentioned in LINK clause and later in TO clause"
-msgstr ""
+msgstr "OMP DECLARE TARGET переменная в %L ранее упомянута в LINK клаузуле и позднее в TO клаузуле"
 
-#: fortran/openmp.c:3059
+#: fortran/openmp.c:3058
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET variable at %L previously mentioned in TO clause and later in LINK clause"
-msgstr ""
+msgstr "OMP DECLARE TARGET переменная в %L ранее упомянута в TO клаузуле и позднее в LINK клаузуле"
 
-#: fortran/openmp.c:3063
+#: fortran/openmp.c:3062
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable at %L mentioned multiple times in clauses of the same OMP DECLARE TARGET directive"
-msgstr ""
+msgstr "Переменная в %L упомянута несколько раз в клаузулах той же OMP DECLARE TARGET директивы"
 
-#: fortran/openmp.c:3078
+#: fortran/openmp.c:3077
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET COMMON at %L previously mentioned in LINK clause and later in TO clause"
-msgstr ""
+msgstr "OMP DECLARE TARGET COMMON в %L ранее упомянута в LINK клаузуле и позднее в TO клаузуле"
 
-#: fortran/openmp.c:3084
+#: fortran/openmp.c:3083
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET COMMON at %L previously mentioned in TO clause and later in LINK clause"
-msgstr ""
+msgstr "OMP DECLARE TARGET COMMON в %L ранее упомянута в TO клаузуле и позднее в LINK клаузуле"
 
-#: fortran/openmp.c:3088
+#: fortran/openmp.c:3087
 #, gcc-internal-format, gfc-internal-format
 msgid "COMMON at %L mentioned multiple times in clauses of the same OMP DECLARE TARGET directive"
-msgstr ""
+msgstr "COMMON в %L упомянута несколько раз в клаузулах той же OMP DECLARE TARGET директивы"
 
-#: fortran/openmp.c:3115
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Syntax error in !$OMP THREADPRIVATE list at %C"
+#: fortran/openmp.c:3114
+#, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$OMP DECLARE TARGET list at %C"
-msgstr "Синтаксическая ошибка в !$OMP THREADPRIVATE списке в %C"
+msgstr "Синтаксическая ошибка в !$OMP DECLARE TARGET списке в %C"
 
-#: fortran/openmp.c:3147
+#: fortran/openmp.c:3146
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate variable at %C is an element of a COMMON block"
 msgstr "Threadprivate переменная в %C является элементом COMMON блока"
 
-#: fortran/openmp.c:3184
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Unexpected junk after $OMP ORDERED statement at %C"
+#: fortran/openmp.c:3183
+#, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after OMP THREADPRIVATE at %C"
-msgstr "Неожиданный мусор после $OMP ORDERED оператора в %C"
+msgstr "Неожиданный мусор после OMP THREADPRIVATE в %C"
 
-#: fortran/openmp.c:3191
+#: fortran/openmp.c:3190
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$OMP THREADPRIVATE list at %C"
 msgstr "Синтаксическая ошибка в !$OMP THREADPRIVATE списке в %C"
 
-#: fortran/openmp.c:3405
+#: fortran/openmp.c:3404
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after TASKWAIT clause at %C"
 msgstr "Неожиданный мусор после TASKWAIT клаузулы в %C"
 
-#: fortran/openmp.c:3419
+#: fortran/openmp.c:3418
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after TASKYIELD clause at %C"
 msgstr "Неожиданный мусор после TASKYIELD клаузулы в %C"
 
-#: fortran/openmp.c:3478
+#: fortran/openmp.c:3477
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP WORKSHARE statement at %C"
 msgstr "Неожиданный мусор после $OMP WORKSHARE оператора в %C"
 
-#: fortran/openmp.c:3492
+#: fortran/openmp.c:3491
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP MASTER statement at %C"
 msgstr "Неожиданный мусор после $OMP MASTER оператора в %C"
 
-#: fortran/openmp.c:3551
+#: fortran/openmp.c:3550
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP ATOMIC statement at %C"
 msgstr "Неожиданный мусор после $OMP ATOMIC оператора в %C"
 
-#: fortran/openmp.c:3578
+#: fortran/openmp.c:3577
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP BARRIER statement at %C"
 msgstr "Неожиданный мусор после $OMP BARRIER оператора в %C"
 
-#: fortran/openmp.c:3592
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Unexpected junk after $OMP MASTER statement at %C"
+#: fortran/openmp.c:3591
+#, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP TASKGROUP statement at %C"
-msgstr "Неожиданный мусор после $OMP MASTER оператора в %C"
+msgstr "Неожиданный мусор после $OMP TASKGROUP оператора в %C"
 
-#: fortran/openmp.c:3642
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Unexpected junk after $OMP ATOMIC statement at %C"
+#: fortran/openmp.c:3641
+#, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP CANCELLATION POINT statement at %C"
-msgstr "Неожиданный мусор после $OMP ATOMIC оператора в %C"
+msgstr "Неожиданный мусор после $OMP CANCELLATION POINT оператора в %C"
 
-#: fortran/openmp.c:3662
+#: fortran/openmp.c:3661
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after NOWAIT clause at %C"
 msgstr "Неожиданный мусор после NOWAIT клаузулы в %C"
 
-#: fortran/openmp.c:3704
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "NUM_THREADS clause at %L requires a scalar INTEGER expression"
+#: fortran/openmp.c:3703
+#, gcc-internal-format, gfc-internal-format
 msgid "%s clause at %L requires a scalar INTEGER expression"
-msgstr "NUM_THREADS клаузула в %L требует скалярное INTEGER выражение"
+msgstr "%s клаузула в %L требует скалярное INTEGER выражение"
 
-#: fortran/openmp.c:3715
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "SIZE at %L must be positive"
+#: fortran/openmp.c:3714
+#, gcc-internal-format, gfc-internal-format
 msgid "INTEGER expression of %s clause at %L must be positive"
-msgstr "SIZE в %L должен быть положительным"
+msgstr "INTEGER выражение клаузулы %s в %L должен быть положительным"
 
-#: fortran/openmp.c:3726
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "SIZE at %L must be positive"
+#: fortran/openmp.c:3725
+#, gcc-internal-format, gfc-internal-format
 msgid "INTEGER expression of %s clause at %L must be non-negative"
-msgstr "SIZE в %L должен быть положительным"
+msgstr "INTEGER выражение клаузулы %s в %L должен быть неотрицательным"
 
-#: fortran/openmp.c:3737
-#, fuzzy, gcc-internal-format
-#| msgid "POINTER object '%s' in %s clause at %L"
+#: fortran/openmp.c:3736
+#, gcc-internal-format
 msgid "POINTER object %qs of derived type in %s clause at %L"
-msgstr "POINTER объект '%s' в %s клаузуле в %L"
+msgstr "POINTER объект %qs производного типа в %s клаузуле в %L"
 
-#: fortran/openmp.c:3740
-#, fuzzy, gcc-internal-format
-#| msgid "Cray pointer '%s' in %s clause at %L"
+#: fortran/openmp.c:3739
+#, gcc-internal-format
 msgid "Cray pointer object %qs of derived type in %s clause at %L"
-msgstr "Cray указатель '%s' в %s клаузуле в %L"
+msgstr "Cray pointer object %qs производного типа в %s клаузуле в %L"
 
-#: fortran/openmp.c:3743
-#, fuzzy, gcc-internal-format
-#| msgid "Cray pointee '%s' in %s clause at %L"
+#: fortran/openmp.c:3742
+#, gcc-internal-format
 msgid "Cray pointee object %qs of derived type in %s clause at %L"
-msgstr "Cray указуемое '%s' в %s клаузуле в %L"
+msgstr "Cray pointee object %qs производного типа в %s клаузуле в %L"
 
-#: fortran/openmp.c:3749 fortran/openmp.c:4687
-#, fuzzy, gcc-internal-format
-#| msgid "POINTER object '%s' in %s clause at %L"
+#: fortran/openmp.c:3748 fortran/openmp.c:4686
+#, gcc-internal-format
 msgid "POINTER object %qs of polymorphic type in %s clause at %L"
-msgstr "POINTER объект '%s' в %s клаузуле в %L"
+msgstr "POINTER объект %qs полиморфного типа в %s клаузуле в %L"
 
-#: fortran/openmp.c:3754
-#, fuzzy, gcc-internal-format
-#| msgid "Cray pointer '%s' in %s clause at %L"
+#: fortran/openmp.c:3753
+#, gcc-internal-format
 msgid "Cray pointer object %qs of polymorphic type in %s clause at %L"
-msgstr "Cray указатель '%s' в %s клаузуле в %L"
+msgstr "Cray pointer object %qs полиморфного типа в %s клаузуле в %L"
 
-#: fortran/openmp.c:3759
-#, fuzzy, gcc-internal-format
-#| msgid "Cray pointee '%s' in %s clause at %L"
+#: fortran/openmp.c:3758
+#, gcc-internal-format
 msgid "Cray pointee object %qs of polymorphic type in %s clause at %L"
-msgstr "Cray указуемое '%s' в %s клаузуле в %L"
+msgstr "Cray pointee object %qs полиморфного типа в %s клаузуле в %L"
 
-#: fortran/openmp.c:3769 fortran/openmp.c:4385 fortran/openmp.c:4490
-#, fuzzy, gcc-internal-format
-#| msgid "Assumed size array '%s' in %s clause at %L"
+#: fortran/openmp.c:3768 fortran/openmp.c:4384 fortran/openmp.c:4489
+#, gcc-internal-format
 msgid "Assumed size array %qs in %s clause at %L"
-msgstr "Массив предполагаемого размера '%s' в %s клаузуле в %L"
+msgstr "Массив предполагаемого размера %qs в %s клаузуле в %L"
 
-#: fortran/openmp.c:3772
-#, fuzzy, gcc-internal-format
-#| msgid "Assumed size array '%s' in %s clause at %L"
+#: fortran/openmp.c:3771
+#, gcc-internal-format
 msgid "Assumed rank array %qs in %s clause at %L"
-msgstr "Массив предполагаемого размера '%s' в %s клаузуле в %L"
+msgstr "Массив предполагаемого ранга %qs в %s клаузуле в %L"
 
-#: fortran/openmp.c:3776
-#, fuzzy, gcc-internal-format
-#| msgid "Assumed size array '%s' in %s clause at %L"
+#: fortran/openmp.c:3775
+#, gcc-internal-format
 msgid "Noncontiguous deferred shape array %qs in %s clause at %L"
-msgstr "Массив предполагаемого размера '%s' в %s клаузуле в %L"
+msgstr "Ненепрерывный массив отложенной формы %qs в %s клаузуле в %L"
 
-#: fortran/openmp.c:3784
-#, fuzzy, gcc-internal-format
-#| msgid "POINTER object '%s' in %s clause at %L"
+#: fortran/openmp.c:3783
+#, gcc-internal-format
 msgid "ALLOCATABLE object %qs of derived type in %s clause at %L"
-msgstr "POINTER объект '%s' в %s клаузуле в %L"
+msgstr "ALLOCATABLE объект %qs производного типа в %s клаузуле в %L"
 
-#: fortran/openmp.c:3789
-#, fuzzy, gcc-internal-format
-#| msgid "POINTER object '%s' in %s clause at %L"
+#: fortran/openmp.c:3788
+#, gcc-internal-format
 msgid "ALLOCATABLE object %qs of polymorphic type in %s clause at %L"
-msgstr "POINTER объект '%s' в %s клаузуле в %L"
+msgstr "ALLOCATABLE объект %qs полиморфного типа в %s клаузуле в %L"
 
-#: fortran/openmp.c:3801 fortran/openmp.c:4480
-#, fuzzy, gcc-internal-format
-#| msgid "POINTER object '%s' in %s clause at %L"
+#: fortran/openmp.c:3800 fortran/openmp.c:4479
+#, gcc-internal-format
 msgid "POINTER object %qs in %s clause at %L"
-msgstr "POINTER объект '%s' в %s клаузуле в %L"
+msgstr "POINTER объект %qs в %s клаузуле в %L"
 
-#: fortran/openmp.c:3806 fortran/openmp.c:4691
-#, fuzzy, gcc-internal-format
-#| msgid "Cray pointer '%s' in %s clause at %L"
+#: fortran/openmp.c:3805 fortran/openmp.c:4690
+#, gcc-internal-format
 msgid "Cray pointer object %qs in %s clause at %L"
-msgstr "Cray указатель '%s' в %s клаузуле в %L"
+msgstr "Cray pointer object %qs в %s клаузуле в %L"
 
-#: fortran/openmp.c:3811 fortran/openmp.c:4694
-#, fuzzy, gcc-internal-format
-#| msgid "Cray pointee '%s' in %s clause at %L"
+#: fortran/openmp.c:3810 fortran/openmp.c:4693
+#, gcc-internal-format
 msgid "Cray pointee object %qs in %s clause at %L"
-msgstr "Cray указуемое '%s' в %s клаузуле в %L"
+msgstr "Cray pointee object %qs в %s клаузуле в %L"
 
-#: fortran/openmp.c:3816 fortran/openmp.c:4682
-#, fuzzy, gcc-internal-format
-#| msgid "POINTER object '%s' in %s clause at %L"
+#: fortran/openmp.c:3815 fortran/openmp.c:4681
+#, gcc-internal-format
 msgid "ALLOCATABLE object %qs in %s clause at %L"
-msgstr "POINTER объект '%s' в %s клаузуле в %L"
+msgstr "ALLOCATABLE объект %qs в %s клаузуле в %L"
 
-#: fortran/openmp.c:3819
-#, fuzzy, gcc-internal-format
-#| msgid "POINTER object '%s' in %s clause at %L"
+#: fortran/openmp.c:3818
+#, gcc-internal-format
 msgid "VALUE object %qs in %s clause at %L"
-msgstr "POINTER объект '%s' в %s клаузуле в %L"
+msgstr "VALUE объект %qs в %s клаузуле в %L"
 
-#: fortran/openmp.c:3862
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Unexpected junk after $OMP ORDERED statement at %C"
+#: fortran/openmp.c:3861
+#, gcc-internal-format, gfc-internal-format
 msgid "Implicitly declared function %s used in !$OMP DECLARE REDUCTION at %L"
-msgstr "Неожиданный мусор после $OMP ORDERED оператора в %C"
+msgstr "Неявно декларированная функция %s использована в !$OMP DECLARE REDUCTION в %L"
 
-#: fortran/openmp.c:3911
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Unexpected junk after $OMP ORDERED statement at %C"
+#: fortran/openmp.c:3910
+#, gcc-internal-format, gfc-internal-format
 msgid "Implicitly declared subroutine %s used in !$OMP DECLARE REDUCTION at %L"
-msgstr "Неожиданный мусор после $OMP ORDERED оператора в %C"
+msgstr "Неявно декларированная подпрограмма %s использована в !$OMP DECLARE REDUCTION в %L"
 
-#: fortran/openmp.c:3944
+#: fortran/openmp.c:3943
 #, gcc-internal-format, gfc-internal-format
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
-msgstr ""
+msgstr "параметр ORDERED клаузулы меньше чем COLLAPSE в %L"
 
-#: fortran/openmp.c:3952 fortran/openmp.c:3963 fortran/resolve.c:10028
-#: fortran/resolve.c:11295
+#: fortran/openmp.c:3951 fortran/openmp.c:3962 fortran/resolve.c:10041
+#: fortran/resolve.c:11315
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "IF клаузула в %L требует скалярное LOGICAL выражение"
 
-#: fortran/openmp.c:3967
+#: fortran/openmp.c:3966
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause without modifier at %L used together with IF clauses with modifiers"
-msgstr ""
+msgstr "IF клаузула без модификатора в %L использованная вместе с IF клаузулами с модификаторами"
 
-#: fortran/openmp.c:4044
+#: fortran/openmp.c:4043
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause modifier %s at %L not appropriate for the current OpenMP construct"
-msgstr ""
+msgstr "модификатор IF клаузулы %s в %L не подходит для текущей OpenMP конструкции"
 
-#: fortran/openmp.c:4054
+#: fortran/openmp.c:4053
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL clause at %L requires a scalar LOGICAL expression"
 msgstr "FINAL клаузула в %L требует скалярное LOGICAL выражение"
 
-#: fortran/openmp.c:4064
+#: fortran/openmp.c:4063
 #, gcc-internal-format, gfc-internal-format
 msgid "SCHEDULE clause's chunk_size at %L requires a scalar INTEGER expression"
 msgstr "chunk_size SCHEDULE клаузулы в %L требует скалярное INTEGER выражение"
 
-#: fortran/openmp.c:4069
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "SIZE at %L must be positive"
+#: fortran/openmp.c:4068
+#, gcc-internal-format, gfc-internal-format
 msgid "INTEGER expression of SCHEDULE clause's chunk_size at %L must be positive"
-msgstr "SIZE в %L должен быть положительным"
+msgstr "INTEGER выражение для chunk_size из SCHEDULE клаузулы в %L должен быть положительным"
 
-#: fortran/openmp.c:4084
-#, fuzzy, gcc-internal-format
-#| msgid "Variable '%s' has not been assigned a target label at %L"
+#: fortran/openmp.c:4083
+#, gcc-internal-format
 msgid "Variable %qs is not a dummy argument at %L"
-msgstr "Переменной '%s' не присвоили целевую метку в %L"
+msgstr "Переменная %qs не есть формальный аргумент в %L"
 
-#: fortran/openmp.c:4116
-#, fuzzy, gcc-internal-format
-#| msgid "Object '%s' is not a variable at %L"
+#: fortran/openmp.c:4115 fortran/openmp.c:5998
+#, gcc-internal-format
 msgid "Object %qs is not a variable at %L"
-msgstr "Объект '%s' не есть переменная в %L"
+msgstr "Объект %qs не есть переменная в %L"
 
-#: fortran/openmp.c:4132 fortran/openmp.c:4143 fortran/openmp.c:4151
-#: fortran/openmp.c:4162 fortran/openmp.c:4174 fortran/openmp.c:4189
-#: fortran/openmp.c:6023
-#, fuzzy, gcc-internal-format
-#| msgid "Symbol '%s' present on multiple clauses at %L"
+#: fortran/openmp.c:4131 fortran/openmp.c:4142 fortran/openmp.c:4150
+#: fortran/openmp.c:4161 fortran/openmp.c:4173 fortran/openmp.c:4188
+#: fortran/openmp.c:6028
+#, gcc-internal-format
 msgid "Symbol %qs present on multiple clauses at %L"
-msgstr "Символ '%s' присутствует в нескольких клаузулах в %L"
+msgstr "Символ %qs присутствует в нескольких клаузулах в %L"
 
-#: fortran/openmp.c:4196
-#, fuzzy, gcc-internal-format
-#| msgid "Array section not permitted in '%s' call at %L"
+#: fortran/openmp.c:4195
+#, gcc-internal-format
 msgid "Array %qs is not permitted in reduction at %L"
-msgstr "Секция массива не разрешена в '%s' вызове в %L"
+msgstr "Массив %qs не разрешена в редукции в %L"
 
-#: fortran/openmp.c:4209
-#, fuzzy, gcc-internal-format
-#| msgid "Symbol '%s' present on multiple clauses at %L"
+#: fortran/openmp.c:4208
+#, gcc-internal-format
 msgid "Symbol %qs present on both FROM and TO clauses at %L"
-msgstr "Символ '%s' присутствует в нескольких клаузулах в %L"
+msgstr "Символ %qs присутствует и в FROM и в TO клаузулах в %L"
 
-#: fortran/openmp.c:4231
-#, fuzzy, gcc-internal-format
-#| msgid "Non-THREADPRIVATE object '%s' in COPYIN clause at %L"
+#: fortran/openmp.c:4230
+#, gcc-internal-format
 msgid "Non-THREADPRIVATE object %qs in COPYIN clause at %L"
-msgstr "Non-THREADPRIVATE объект '%s' в COPYIN клаузуле в %L"
+msgstr "Не-THREADPRIVATE объект %qs в COPYIN клаузуле в %L"
 
-#: fortran/openmp.c:4239
-#, fuzzy, gcc-internal-format
-#| msgid "Assumed size array '%s' in COPYPRIVATE clause at %L"
+#: fortran/openmp.c:4238
+#, gcc-internal-format
 msgid "Assumed size array %qs in COPYPRIVATE clause at %L"
-msgstr "Массив предполагаемого размера '%s' в COPYPRIVATE клаузуле в %L"
+msgstr "Массив предполагаемого размера %qs в COPYPRIVATE клаузуле в %L"
 
-#: fortran/openmp.c:4242
-#, fuzzy, gcc-internal-format
-#| msgid "Assumed size array '%s' in COPYPRIVATE clause at %L"
+#: fortran/openmp.c:4241
+#, gcc-internal-format
 msgid "INTENT(IN) POINTER %qs in COPYPRIVATE clause at %L"
-msgstr "Массив предполагаемого размера '%s' в COPYPRIVATE клаузуле в %L"
+msgstr "INTENT(IN) POINTER %qs в COPYPRIVATE клаузуле в %L"
 
-#: fortran/openmp.c:4250
-#, fuzzy, gcc-internal-format
-#| msgid "THREADPRIVATE object '%s' in SHARED clause at %L"
+#: fortran/openmp.c:4249
+#, gcc-internal-format
 msgid "THREADPRIVATE object %qs in SHARED clause at %L"
-msgstr "THREADPRIVATE объект '%s' в SHARED клаузуле в %L"
+msgstr "THREADPRIVATE объект %qs в SHARED клаузуле в %L"
 
-#: fortran/openmp.c:4253
-#, fuzzy, gcc-internal-format
-#| msgid "Cray pointee '%s' in SHARED clause at %L"
+#: fortran/openmp.c:4252
+#, gcc-internal-format
 msgid "Cray pointee %qs in SHARED clause at %L"
-msgstr "Cray указуемое '%s' в SHARED клаузуле в %L"
+msgstr "Cray pointee %qs в SHARED клаузуле в %L"
 
-#: fortran/openmp.c:4256
-#, fuzzy, gcc-internal-format
-#| msgid "THREADPRIVATE object '%s' in SHARED clause at %L"
+#: fortran/openmp.c:4255
+#, gcc-internal-format
 msgid "ASSOCIATE name %qs in SHARED clause at %L"
-msgstr "THREADPRIVATE объект '%s' в SHARED клаузуле в %L"
+msgstr "ASSOCIATE имя %qs в SHARED клаузуле в %L"
 
-#: fortran/openmp.c:4271
+#: fortran/openmp.c:4270
 #, gcc-internal-format
 msgid "%qs in ALIGNED clause must be POINTER, ALLOCATABLE, Cray pointer or C_PTR at %L"
-msgstr ""
+msgstr "%qs в ALIGNED клаузуле должен быть POINTER, ALLOCATABLE, Cray указатель или C_PTR в %L"
 
-#: fortran/openmp.c:4283
-#, fuzzy, gcc-internal-format
-#| msgid "collapse argument needs positive constant integer expression"
+#: fortran/openmp.c:4282
+#, gcc-internal-format
 msgid "%qs in ALIGNED clause at %L requires a scalar positive constant integer alignment expression"
-msgstr "collapse аргумент требует положительного константного целого выражения"
+msgstr "%qs в ALIGNED клаузуле в %L требует скалярного положительного константного целого выражения выравнивания"
 
-#: fortran/openmp.c:4302
+#: fortran/openmp.c:4301
 #, gcc-internal-format, gfc-internal-format
 msgid "SINK dependence type only allowed on ORDERED directive at %L"
-msgstr ""
+msgstr "тип SINK зависимости допустим только в ORDERED директиве в %L"
 
-#: fortran/openmp.c:4306
+#: fortran/openmp.c:4305
 #, gcc-internal-format, gfc-internal-format
 msgid "DEPEND SINK used together with DEPEND SOURCE on the same construct at %L"
-msgstr ""
+msgstr "DEPEND SINK использовано вместе с DEPEND SOURCE в той же конструкции в %L"
 
-#: fortran/openmp.c:4316
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "accumulator is not a constant integer"
+#: fortran/openmp.c:4315
+#, gcc-internal-format, gfc-internal-format
 msgid "SINK addend not a constant integer at %L"
-msgstr "номер сумматора не является целой константой"
+msgstr "SINK addend не является целой константой в %L"
 
-#: fortran/openmp.c:4322
+#: fortran/openmp.c:4321
 #, gcc-internal-format, gfc-internal-format
 msgid "Only SOURCE or SINK dependence types are allowed on ORDERED directive at %L"
-msgstr ""
+msgstr "Только типы SOURCE или SINK зависимостей допустимы в ORDERED директиве в %L"
 
-#: fortran/openmp.c:4333 fortran/openmp.c:4354
+#: fortran/openmp.c:4332 fortran/openmp.c:4353
 #, gcc-internal-format
 msgid "%qs in %s clause at %L is not a proper array section"
-msgstr ""
+msgstr "%qs в %s клаузуле в %L не является подходящей секцией массива"
 
-#: fortran/openmp.c:4337
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Cray pointee '%s' in %s clause at %L"
+#: fortran/openmp.c:4336
+#, gcc-internal-format, gfc-internal-format
 msgid "Coarrays not supported in %s clause at %L"
-msgstr "Cray указуемое '%s' в %s клаузуле в %L"
+msgstr "Комассивы не поддерживаются в %s клаузуле в %L"
 
-#: fortran/openmp.c:4346
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Assumed size array '%s' in %s clause at %L"
+#: fortran/openmp.c:4345
+#, gcc-internal-format, gfc-internal-format
 msgid "Stride should not be specified for array section in %s clause at %L"
-msgstr "Массив предполагаемого размера '%s' в %s клаузуле в %L"
+msgstr "Шаг не должен задаваться для секции массива в %s клаузуле в %L"
 
-#: fortran/openmp.c:4367
+#: fortran/openmp.c:4366
 #, gcc-internal-format
 msgid "%qs in DEPEND clause at %L is a zero size array section"
-msgstr ""
+msgstr "%qs в DEPEND клаузуле в %L есть секция массива нулевого размера"
 
-#: fortran/openmp.c:4403
+#: fortran/openmp.c:4402
 #, gcc-internal-format, gfc-internal-format
 msgid "TARGET%s with map-type other than TO, FROM, TOFROM, or ALLOC on MAP clause at %L"
-msgstr ""
+msgstr "TARGET%s с map-type отличным от TO, FROM, TOFROM или ALLOC в MAP клаузуле в %L"
 
-#: fortran/openmp.c:4419
+#: fortran/openmp.c:4418
 #, gcc-internal-format, gfc-internal-format
 msgid "TARGET ENTER DATA with map-type other than TO, or ALLOC on MAP clause at %L"
-msgstr ""
+msgstr "TARGET ENTER DATA с map-type отличным от TO или ALLOC в MAP клаузуле в %L"
 
-#: fortran/openmp.c:4434
+#: fortran/openmp.c:4433
 #, gcc-internal-format, gfc-internal-format
 msgid "TARGET EXIT DATA with map-type other than FROM, RELEASE, or DELETE on MAP clause at %L"
-msgstr ""
+msgstr "TARGET EXIT DATA с map-type отличным от FROM, RELEASE или DELETE в MAP клаузуле в %L"
 
-#: fortran/openmp.c:4450 fortran/openmp.c:4466
-#, fuzzy, gcc-internal-format
-#| msgid "THREADPRIVATE object '%s' in %s clause at %L"
+#: fortran/openmp.c:4449 fortran/openmp.c:4465
+#, gcc-internal-format
 msgid "THREADPRIVATE object %qs in %s clause at %L"
-msgstr "THREADPRIVATE объект '%s' в %s клаузуле в %L"
+msgstr "THREADPRIVATE объект %qs в %s клаузуле в %L"
 
-#: fortran/openmp.c:4453 fortran/openmp.c:4469
-#, fuzzy, gcc-internal-format
-#| msgid "Cray pointee '%s' in %s clause at %L"
+#: fortran/openmp.c:4452 fortran/openmp.c:4468
+#, gcc-internal-format
 msgid "Cray pointee %qs in %s clause at %L"
-msgstr "Cray указуемое '%s' в %s клаузуле в %L"
+msgstr "Cray pointee %qs в %s клаузуле в %L"
 
-#: fortran/openmp.c:4472
-#, fuzzy, gcc-internal-format
-#| msgid "POINTER object '%s' in %s clause at %L"
+#: fortran/openmp.c:4471
+#, gcc-internal-format
 msgid "ASSOCIATE name %qs in %s clause at %L"
-msgstr "POINTER объект '%s' в %s клаузуле в %L"
+msgstr "ASSOCIATE имя %qs в %s клаузуле в %L"
 
-#: fortran/openmp.c:4477
-#, fuzzy, gcc-internal-format
-#| msgid "Cray pointer '%s' in %s clause at %L"
+#: fortran/openmp.c:4476
+#, gcc-internal-format
 msgid "Procedure pointer %qs in %s clause at %L"
-msgstr "Cray указатель '%s' в %s клаузуле в %L"
+msgstr "Указатель на процедуру %qs в %s клаузуле в %L"
 
-#: fortran/openmp.c:4483
-#, fuzzy, gcc-internal-format
-#| msgid "Cray pointer '%s' in %s clause at %L"
+#: fortran/openmp.c:4482
+#, gcc-internal-format
 msgid "Cray pointer %qs in %s clause at %L"
-msgstr "Cray указатель '%s' в %s клаузуле в %L"
+msgstr "Cray pointer %qs в %s клаузуле в %L"
 
-#: fortran/openmp.c:4493
-#, fuzzy, gcc-internal-format
-#| msgid "Variable '%s' in %s clause is used in NAMELIST statement at %L"
+#: fortran/openmp.c:4492
+#, gcc-internal-format
 msgid "Variable %qs in %s clause is used in NAMELIST statement at %L"
-msgstr "Переменная '%s' в %s клаузуле используется в NAMELIST операторе в %L"
+msgstr "Переменная %qs в %s клаузуле используется в NAMELIST операторе в %L"
 
 #. case OMP_LIST_REDUCTION:
-#: fortran/openmp.c:4503
-#, fuzzy, gcc-internal-format
-#| msgid "POINTER object '%s' in %s clause at %L"
+#: fortran/openmp.c:4502
+#, gcc-internal-format
 msgid "INTENT(IN) POINTER %qs in %s clause at %L"
-msgstr "POINTER объект '%s' в %s клаузуле в %L"
+msgstr "INTENT(IN) POINTER %qs в %s клаузуле в %L"
 
-#: fortran/openmp.c:4596
+#: fortran/openmp.c:4595
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP DECLARE REDUCTION %s not found for type %s at %L"
-msgstr ""
+msgstr "!$OMP DECLARE REDUCTION %s не найден для типа %s в %L"
 
-#: fortran/openmp.c:4622
+#: fortran/openmp.c:4621
 #, gcc-internal-format, gfc-internal-format
 msgid "LINEAR clause modifier used on DO or SIMD construct at %L"
-msgstr ""
+msgstr "модификатор LINEAR клаузулы использован в DO или SIMD конструкции в %L"
 
-#: fortran/openmp.c:4627
+#: fortran/openmp.c:4626
 #, gcc-internal-format, gfc-internal-format
 msgid "LINEAR clause specified together with ORDERED clause with argument at %L"
-msgstr ""
+msgstr "LINEAR клаузула задана вместе с ORDERED клаузулой с аргументом в %L"
 
-#: fortran/openmp.c:4632
-#, fuzzy, gcc-internal-format
-#| msgid "%s REDUCTION variable '%s' must be INTEGER at %L"
+#: fortran/openmp.c:4631
+#, gcc-internal-format
 msgid "LINEAR variable %qs must be INTEGER at %L"
-msgstr "%s REDUCTION переменная '%s' должна быть INTEGER в %L"
+msgstr "LINEAR переменная %qs должна быть INTEGER в %L"
 
-#: fortran/openmp.c:4637
-#, fuzzy, gcc-internal-format
-#| msgid "Actual argument for '%s' must be a pointer at %L"
+#: fortran/openmp.c:4636
+#, gcc-internal-format
 msgid "LINEAR dummy argument %qs with VALUE attribute with %s modifier at %L"
-msgstr "Фактический аргумент для '%s' должен быть указателем в %L"
+msgstr "LINEAR формальный аргумент %qs с VALUE атрибутом с %s модификатором в %L"
 
-#: fortran/openmp.c:4648
-#, fuzzy, gcc-internal-format
-#| msgid "FINAL clause at %L requires a scalar LOGICAL expression"
+#: fortran/openmp.c:4647
+#, gcc-internal-format
 msgid "%qs in LINEAR clause at %L requires a scalar integer linear-step expression"
-msgstr "FINAL клаузула в %L требует скалярное LOGICAL выражение"
+msgstr "%qs в LINEAR клаузуле в %L требует скалярное integer выражение линейного шага"
 
-#: fortran/openmp.c:4665
-#, fuzzy, gcc-internal-format
-#| msgid "FINAL clause at %L requires a scalar LOGICAL expression"
+#: fortran/openmp.c:4664
+#, gcc-internal-format
 msgid "%qs in LINEAR clause at %L requires a constant integer linear-step expression or dummy argument specified in UNIFORM clause"
-msgstr "FINAL клаузула в %L требует скалярное LOGICAL выражение"
+msgstr "%qs в LINEAR клаузуле в %L требует скалярное integer выражение линейного шага или формальный аргумент заданный в UNIFORM клаузуле"
 
-#: fortran/openmp.c:4699
-#, fuzzy, gcc-internal-format
-#| msgid "type to vector delete is neither pointer or array type"
+#: fortran/openmp.c:4698
+#, gcc-internal-format
 msgid "%s clause variable %qs at %L is neither a POINTER nor an array"
-msgstr "тип, заданный в векторном delete, не является ни массивом, ни указателем"
+msgstr "переменная %s клаузулы %qs в %L не POINTER и не массив"
 
-#: fortran/openmp.c:4731
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "SCHEDULE clause's chunk_size at %L requires a scalar INTEGER expression"
+#: fortran/openmp.c:4730
+#, gcc-internal-format, gfc-internal-format
 msgid "DIST_SCHEDULE clause's chunk_size at %L requires a scalar INTEGER expression"
-msgstr "chunk_size SCHEDULE клаузулы в %L требует скалярное INTEGER выражение"
+msgstr "chunk_size из DIST_SCHEDULE клаузулы в %L требует скалярного INTEGER выражения"
 
-#: fortran/openmp.c:4763
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Incompatible ranks in %s (%d and %d) at %L"
+#: fortran/openmp.c:4762
+#, gcc-internal-format, gfc-internal-format
 msgid "Incompatible use of TILE and COLLAPSE at %L"
-msgstr "Несовместимые ранги в %s (%d и %d) в %L"
+msgstr "Несовместимое использование TILE и COLLAPSE в %L"
 
-#: fortran/openmp.c:4765
+#: fortran/openmp.c:4764
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE dependence type only allowed on ORDERED directive at %L"
-msgstr ""
+msgstr "тип SOURCE зависимости допустим только в ORDERED директиве в %L"
 
-#: fortran/openmp.c:4778
+#: fortran/openmp.c:4777
 #, gcc-internal-format, gfc-internal-format
 msgid "%s must contain at least one MAP clause at %L"
-msgstr ""
+msgstr "%s должен содержать хотя бы одну MAP клаузулу в %L"
 
-#: fortran/openmp.c:4875
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Unexpected junk after $OMP ATOMIC statement at %C"
+#: fortran/openmp.c:4874
+#, gcc-internal-format, gfc-internal-format
 msgid "unexpected !$OMP ATOMIC expression at %L"
-msgstr "Неожиданный мусор после $OMP ATOMIC оператора в %C"
+msgstr "Неожиданное !$OMP ATOMIC выражение в %L"
 
-#: fortran/openmp.c:4904
+#: fortran/openmp.c:4903
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC statement must set a scalar variable of intrinsic type at %L"
 msgstr "!$OMP ATOMIC оператор должен устанавливать скалярную переменную встроенного типа в %L"
 
-#: fortran/openmp.c:4929
+#: fortran/openmp.c:4928
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC READ statement must read from a scalar variable of intrinsic type at %L"
 msgstr "!$OMP ATOMIC READ оператор должен читать из скалярной переменной встроенного типа в %L"
 
-#: fortran/openmp.c:4934
+#: fortran/openmp.c:4933
 #, gcc-internal-format, gfc-internal-format
 msgid "expr in !$OMP ATOMIC WRITE assignment var = expr must be scalar and cannot reference var at %L"
 msgstr "expr в !$OMP ATOMIC WRITE присваивании var = expr должно быть скалярным и не может ссылаться на var в %L"
 
-#: fortran/openmp.c:4956 fortran/openmp.c:5247
+#: fortran/openmp.c:4955 fortran/openmp.c:5246
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE capture statement must read from a scalar variable of intrinsic type at %L"
 msgstr "!$OMP ATOMIC CAPTURE capture оператор должен читать из скалярной переменной встроенного типа в %L"
 
-#: fortran/openmp.c:4971
+#: fortran/openmp.c:4970
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE update statement must set a scalar variable of intrinsic type at %L"
 msgstr "!$OMP ATOMIC CAPTURE update оператор должен устанавливать скалярную переменную встроенного типа в %L"
 
-#: fortran/openmp.c:4978 fortran/openmp.c:5254
+#: fortran/openmp.c:4977 fortran/openmp.c:5253
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE capture statement reads from different variable than update statement writes into at %L"
-msgstr "!$OMP ATOMIC CAPTURE capture оператор читает не из той переменной в которую update оператор пишет в %L"
+msgstr "!$OMP ATOMIC CAPTURE capture оператор читает не из той переменной, в которую update оператор пишет в %L"
 
-#: fortran/openmp.c:4994
+#: fortran/openmp.c:4993
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC with ALLOCATABLE variable at %L"
-msgstr ""
+msgstr "!$OMP ATOMIC с ALLOCATABLE переменной в %L"
 
-#: fortran/openmp.c:5036
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "!$OMP ATOMIC assignment operator must be +, *, -, /, .AND., .OR., .EQV. or .NEQV. at %L"
+#: fortran/openmp.c:5035
+#, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment operator must be binary +, *, -, /, .AND., .OR., .EQV. or .NEQV. at %L"
-msgstr "!$OMP ATOMIC оператор присваивания должен быть +, *, -, /, .AND., .OR., .EQV. или .NEQV. в %L"
+msgstr ""
 
-#: fortran/openmp.c:5084
+#: fortran/openmp.c:5083
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment must be var = var op expr or var = expr op var at %L"
 msgstr "!$OMP ATOMIC присваивание должно быть var = var op expr или var = expr op var в %L"
 
-#: fortran/openmp.c:5098
+#: fortran/openmp.c:5097
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC var = var op expr not mathematically equivalent to var = var op (expr) at %L"
 msgstr "!$OMP ATOMIC var = var op expr не эквивалентно математически var = var op (expr) в %L"
 
-#: fortran/openmp.c:5130
+#: fortran/openmp.c:5129
 #, gcc-internal-format, gfc-internal-format
 msgid "expr in !$OMP ATOMIC assignment var = var op expr must be scalar and cannot reference var at %L"
 msgstr "expr в !$OMP ATOMIC присваивании var = var op expr должно быть скалярным и не может ссылаться на var в %L"
 
-#: fortran/openmp.c:5154
+#: fortran/openmp.c:5153
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment intrinsic IAND, IOR or IEOR must have two arguments at %L"
 msgstr "!$OMP ATOMIC присваивание встроенные IAND, IOR или IEOR должны иметь два аргумента в %L"
 
-#: fortran/openmp.c:5161
+#: fortran/openmp.c:5160
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment intrinsic must be MIN, MAX, IAND, IOR or IEOR at %L"
 msgstr "!$OMP ATOMIC присваивание встроенные должны быть MIN, MAX, IAND, IOR или IEOR в %L"
 
-#: fortran/openmp.c:5178
-#, fuzzy, gcc-internal-format
-#| msgid "!$OMP ATOMIC intrinsic arguments except one must not reference '%s' at %L"
+#: fortran/openmp.c:5177
+#, gcc-internal-format
 msgid "!$OMP ATOMIC intrinsic arguments except one must not reference %qs at %L"
-msgstr "!$OMP ATOMIC аргументы встроенных кроме одного не должны ссылаться на '%s' в %L"
+msgstr "!$OMP ATOMIC аргументы встроенных функций кроме одного не должны ссылаться на %qs в %L"
 
-#: fortran/openmp.c:5185
+#: fortran/openmp.c:5184
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC intrinsic arguments must be scalar at %L"
 msgstr "!$OMP ATOMIC аргументы встроенных должны быть скалярами в %L"
 
-#: fortran/openmp.c:5193
-#, fuzzy, gcc-internal-format
-#| msgid "First or last !$OMP ATOMIC intrinsic argument must be '%s' at %L"
+#: fortran/openmp.c:5192
+#, gcc-internal-format
 msgid "First or last !$OMP ATOMIC intrinsic argument must be %qs at %L"
-msgstr "Первый или последний !$OMP ATOMIC аргумент встроенных должен быть '%s' в %L"
+msgstr "Первый или последний !$OMP ATOMIC аргумент встроенной функции должен быть %qs в %L"
 
-#: fortran/openmp.c:5211
+#: fortran/openmp.c:5210
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment must have an operator or intrinsic on right hand side at %L"
 msgstr "!$OMP ATOMIC присваивание должно иметь оператор или встроенную в правой части в %L"
 
-#: fortran/openmp.c:5225
+#: fortran/openmp.c:5224
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE capture statement must set a scalar variable of intrinsic type at %L"
 msgstr "!$OMP ATOMIC CAPTURE capture оператор должен устанавливать скалярную переменную встроенного типа в %L"
 
-#: fortran/openmp.c:5544
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "!$OMP DO cannot be a DO WHILE or DO without loop control at %L"
+#: fortran/openmp.c:5543
+#, gcc-internal-format, gfc-internal-format
 msgid "%s cannot be a DO WHILE or DO without loop control at %L"
-msgstr "!$OMP DO не может быть DO WHILE или DO без управления циклом в %L"
+msgstr "%s не может быть DO WHILE или DO без управления циклом в %L"
 
-#: fortran/openmp.c:5550
+#: fortran/openmp.c:5549
 #, gcc-internal-format, gfc-internal-format
 msgid "%s cannot be a DO CONCURRENT loop at %L"
-msgstr ""
+msgstr "%s не может быть DO CONCURRENT циклом в %L"
 
-#: fortran/openmp.c:5556
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "!$OMP DO iteration variable must be of type integer at %L"
+#: fortran/openmp.c:5555
+#, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable must be of type integer at %L"
-msgstr "!$OMP DO итерационная переменная должна быть типа integer в %L"
+msgstr "%s итерационная переменная должна быть типа integer в %L"
 
-#: fortran/openmp.c:5560
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "!$OMP DO iteration variable must not be THREADPRIVATE at %L"
+#: fortran/openmp.c:5559
+#, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable must not be THREADPRIVATE at %L"
-msgstr "!$OMP DO итерационная переменная не должна быть THREADPRIVATE в %L"
+msgstr "%s итерационная переменная не должна быть THREADPRIVATE в %L"
 
-#: fortran/openmp.c:5573
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "!$OMP DO iteration variable present on clause other than PRIVATE or LASTPRIVATE at %L"
+#: fortran/openmp.c:5572
+#, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable present on clause other than PRIVATE or LASTPRIVATE at %L"
-msgstr "!$OMP DO итерационная переменная присутствует в клаузуле отличной от PRIVATE и LASTPRIVATE в %L"
+msgstr "%s итерационная переменная присутствует в клаузуле отличной от PRIVATE и LASTPRIVATE в %L"
 
-#: fortran/openmp.c:5577
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "!$OMP DO iteration variable present on clause other than PRIVATE or LASTPRIVATE at %L"
+#: fortran/openmp.c:5576
+#, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable present on clause other than LASTPRIVATE at %L"
-msgstr "!$OMP DO итерационная переменная присутствует в клаузуле отличной от PRIVATE и LASTPRIVATE в %L"
+msgstr "%s итерационная переменная присутствует в клаузуле отличной от LASTPRIVATE в %L"
 
-#: fortran/openmp.c:5581
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "!$OMP DO iteration variable present on clause other than PRIVATE or LASTPRIVATE at %L"
+#: fortran/openmp.c:5580
+#, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable present on clause other than LINEAR at %L"
-msgstr "!$OMP DO итерационная переменная присутствует в клаузуле отличной от PRIVATE и LASTPRIVATE в %L"
+msgstr "%s итерационная переменная присутствует в клаузуле отличной от LINEAR в %L"
 
-#: fortran/openmp.c:5599
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "!$OMP DO collapsed loops don't form rectangular iteration space at %L"
+#: fortran/openmp.c:5598
+#, gcc-internal-format, gfc-internal-format
 msgid "%s collapsed loops don't form rectangular iteration space at %L"
-msgstr "!$OMP DO сжатые циклы не образуют прямоугольное итерационное пространство в %L"
+msgstr "%s сжатые циклы не образуют прямоугольное итерационное пространство в %L"
 
-#: fortran/openmp.c:5611
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "collapsed !$OMP DO loops not perfectly nested at %L"
+#: fortran/openmp.c:5610
+#, gcc-internal-format, gfc-internal-format
 msgid "collapsed %s loops not perfectly nested at %L"
-msgstr "сжатые !$OMP DO циклы не вполне вложены в %L"
+msgstr "сжатые %s циклы не идеально вложены в %L"
 
-#: fortran/openmp.c:5620 fortran/openmp.c:5628
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "not enough DO loops for collapsed !$OMP DO at %L"
+#: fortran/openmp.c:5619 fortran/openmp.c:5627
+#, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for collapsed %s at %L"
-msgstr "недостаточно DO циклов для сжатого !$OMP DO в %L"
+msgstr "недостаточно DO циклов для сжатого %s в %L"
 
-#: fortran/openmp.c:5712 fortran/openmp.c:5725
+#: fortran/openmp.c:5711 fortran/openmp.c:5724
 #, gcc-internal-format, gfc-internal-format
 msgid "The %s directive cannot be specified within a %s region at %L"
-msgstr ""
+msgstr "Директива %s не может задаваться внутри %s области в %L"
 
-#: fortran/openmp.c:5744
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "!$OMP DO cannot be a DO WHILE or DO without loop control at %L"
+#: fortran/openmp.c:5743
+#, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP cannot be a DO WHILE or DO without loop control at %L"
-msgstr "!$OMP DO не может быть DO WHILE или DO без управления циклом в %L"
+msgstr "!$ACC LOOP не может быть DO WHILE или DO без управления циклом в %L"
 
-#: fortran/openmp.c:5750
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "!$OMP DO iteration variable must be of type integer at %L"
+#: fortran/openmp.c:5749
+#, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP iteration variable must be of type integer at %L"
-msgstr "!$OMP DO итерационная переменная должна быть типа integer в %L"
+msgstr "!$ACC LOOP итерационная переменная должна быть типа integer в %L"
 
-#: fortran/openmp.c:5766
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "!$OMP DO collapsed loops don't form rectangular iteration space at %L"
+#: fortran/openmp.c:5765
+#, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s loops don't form rectangular iteration space at %L"
-msgstr "!$OMP DO сжатые циклы не образуют прямоугольное итерационное пространство в %L"
+msgstr "!$ACC LOOP %s циклы не образуют прямоугольное итерационное пространство в %L"
 
-#: fortran/openmp.c:5778
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "collapsed !$OMP DO loops not perfectly nested at %L"
+#: fortran/openmp.c:5777
+#, gcc-internal-format, gfc-internal-format
 msgid "%s !$ACC LOOP loops not perfectly nested at %L"
-msgstr "сжатые !$OMP DO циклы не вполне вложены в %L"
+msgstr "%s !$ACC LOOP циклы не идеально вложены в %L"
 
-#: fortran/openmp.c:5788 fortran/openmp.c:5797
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "not enough DO loops for collapsed !$OMP DO at %L"
+#: fortran/openmp.c:5787 fortran/openmp.c:5796
+#, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for %s !$ACC LOOP at %L"
-msgstr "недостаточно DO циклов для сжатого !$OMP DO в %L"
+msgstr "недостаточно DO циклов для %s !$ACC LOOP в %L"
 
-#: fortran/openmp.c:5812 fortran/openmp.c:5819
+#: fortran/openmp.c:5811 fortran/openmp.c:5818
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s in PARALLEL region doesn't allow %s arguments at %L"
-msgstr ""
+msgstr "!$ACC LOOP %s в PARALLEL области не допускает %s аргументы в %L"
 
-#: fortran/openmp.c:5841
+#: fortran/openmp.c:5840
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside another loop parallelized across gangs at %L"
-msgstr ""
+msgstr "Цикл распараллеленный по совокупностям не допускается внутри другого цикла распараллеленного по совокупностям в %L"
 
-#: fortran/openmp.c:5845 fortran/openmp.c:5849
+#: fortran/openmp.c:5844 fortran/openmp.c:5848
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside loop parallelized across workers at %L"
-msgstr ""
+msgstr "Цикл распараллеленный по совокупностям не допускается внутри другого цикла распараллеленного по исполнителям в %L"
 
-#: fortran/openmp.c:5856
+#: fortran/openmp.c:5855
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across workers at %L"
-msgstr ""
+msgstr "Цикл распараллеленный по исполнителям не допускается внутри другого цикла распараллеленного по исполнителям в %L"
 
-#: fortran/openmp.c:5860
+#: fortran/openmp.c:5859
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across vectors at %L"
-msgstr ""
+msgstr "Цикл распараллеленный по исполнителям не допускается внутри другого цикла распараллеленного по векторам в %L"
 
-#: fortran/openmp.c:5866
+#: fortran/openmp.c:5865
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across vectors is not allowed inside another loop parallelized across vectors at %L"
-msgstr ""
+msgstr "Цикл распараллеленный по векторам не допускается внутри другого цикла распараллеленного по векторам в %L"
 
-#: fortran/openmp.c:5878
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
+#: fortran/openmp.c:5877
+#, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with INDEPENDENT at %L"
-msgstr "INTENT (%s)  конфликтует с INTENT(%s) в %L"
+msgstr "Клаузула SEQ конфликтует с INDEPENDENT в %L"
 
-#: fortran/openmp.c:5880
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "%s attribute conflicts with %s attribute at %L"
+#: fortran/openmp.c:5879
+#, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with GANG at %L"
-msgstr "%s атрибут конфликтует с %s атрибутом в %L"
+msgstr "Клаузула SEQ конфликтует с GANG в %L"
 
-#: fortran/openmp.c:5882
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "MOLD tag at %L conflicts with SOURCE tag at %L"
+#: fortran/openmp.c:5881
+#, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with WORKER at %L"
-msgstr "MOLD тег в %L конфликтует с SOURCE тегом в %L"
+msgstr "Клаузула SEQ конфликтует с WORKER в %L"
 
-#: fortran/openmp.c:5884
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "MOLD tag at %L conflicts with SOURCE tag at %L"
+#: fortran/openmp.c:5883
+#, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with VECTOR at %L"
-msgstr "MOLD тег в %L конфликтует с SOURCE тегом в %L"
+msgstr "Клаузула SEQ конфликтует с VECTOR в %L"
 
-#: fortran/openmp.c:5886
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "MOLD tag at %L conflicts with SOURCE tag at %L"
+#: fortran/openmp.c:5885
+#, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with AUTO at %L"
-msgstr "MOLD тег в %L конфликтует с SOURCE тегом в %L"
+msgstr "Клаузула SEQ конфликтует с AUTO в %L"
 
-#: fortran/openmp.c:5891
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "%s attribute conflicts with %s attribute at %L"
+#: fortran/openmp.c:5890
+#, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with GANG at %L"
-msgstr "%s атрибут конфликтует с %s атрибутом в %L"
+msgstr "Клаузула AUTO конфликтует с GANG в %L"
 
-#: fortran/openmp.c:5893
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "MOLD tag at %L conflicts with SOURCE tag at %L"
+#: fortran/openmp.c:5892
+#, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with WORKER at %L"
-msgstr "MOLD тег в %L конфликтует с SOURCE тегом в %L"
+msgstr "Клаузула AUTO конфликтует с WORKER в %L"
 
-#: fortran/openmp.c:5895
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "MOLD tag at %L conflicts with SOURCE tag at %L"
+#: fortran/openmp.c:5894
+#, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with VECTOR at %L"
-msgstr "MOLD тег в %L конфликтует с SOURCE тегом в %L"
+msgstr "Клаузула AUTO конфликтует с VECTOR в %L"
 
-#: fortran/openmp.c:5899
+#: fortran/openmp.c:5898
 #, gcc-internal-format, gfc-internal-format
 msgid "Tiled loop cannot be parallelized across gangs, workers and vectors at the same time at %L"
-msgstr ""
+msgstr "Мозаичный цикл не может быть распараллелен по совокупностям, исполнителям и векторам одновременно в %L"
 
-#: fortran/openmp.c:5934
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "%qE is not a constant expression"
+#: fortran/openmp.c:5933
+#, gcc-internal-format, gfc-internal-format
 msgid "TILE requires constant expression at %L"
-msgstr "%qE не есть константное выражение"
+msgstr "TILE требует константное выражение в %L"
 
-#: fortran/openmp.c:5999
-#, fuzzy, gcc-internal-format
-#| msgid "POINTER object '%s' in %s clause at %L"
+#: fortran/openmp.c:6004
+#, gcc-internal-format
 msgid "PARAMETER object %qs is not allowed at %L"
-msgstr "POINTER объект '%s' в %s клаузуле в %L"
+msgstr "PARAMETER объект %qs не допускается в %L"
 
-#: fortran/openmp.c:6006
-#, fuzzy, gcc-internal-format
-#| msgid "Array section not permitted in '%s' call at %L"
+#: fortran/openmp.c:6011
+#, gcc-internal-format
 msgid "Array sections: %qs not allowed in !$ACC DECLARE at %L"
-msgstr "Секция массива не разрешена в '%s' вызове в %L"
+msgstr "Секции массивов: %qs не допускается в !$ACC DECLARE в %L"
 
-#: fortran/openmp.c:6133
+#: fortran/openmp.c:6138
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP TARGET UPDATE at %L requires at least one TO or FROM clause"
-msgstr ""
+msgstr "OMP TARGET UPDATE в %L требует хотя бы одну TO или FROM клаузулу"
 
-#: fortran/openmp.c:6155
+#: fortran/openmp.c:6160
 #, gcc-internal-format
 msgid "!$OMP DECLARE SIMD should refer to containing procedure %qs at %L"
-msgstr ""
+msgstr "!$OMP DECLARE SIMD должна ссылаться на объемлющую процедуру %qs в %L"
 
-#: fortran/openmp.c:6179
+#: fortran/openmp.c:6184
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_PRIV or OMP_ORIG used in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
-msgstr ""
+msgstr "Переменная отличная от OMP_PRIV или OMP_ORIG использована в INITIALIZER клаузуле от !$OMP DECLARE REDUCTION в %L"
 
-#: fortran/openmp.c:6187
+#: fortran/openmp.c:6192
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_OUT or OMP_IN used in combiner of !$OMP DECLARE REDUCTION at %L"
-msgstr ""
+msgstr "Переменная отличная от OMP_OUT или OMP_IN использована в объединителе от !$OMP DECLARE REDUCTION в %L"
 
-#: fortran/openmp.c:6216
+#: fortran/openmp.c:6221
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid operator for !$OMP DECLARE REDUCTION %s at %L"
-msgstr ""
+msgstr "Некорректный оператор для !$OMP DECLARE REDUCTION %s в %L"
 
-#: fortran/openmp.c:6238
+#: fortran/openmp.c:6243
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER length in !$OMP DECLARE REDUCTION %s not constant at %L"
-msgstr ""
+msgstr "CHARACTER длина в !$OMP DECLARE REDUCTION %s не константа в %L"
 
-#: fortran/openmp.c:6254
+#: fortran/openmp.c:6259
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in combiner of !$OMP DECLARE REDUCTION at %L"
-msgstr ""
+msgstr "Вызов подпрограммы с альтернативными возвратами в объединителе от !$OMP DECLARE REDUCTION в %L"
 
-#: fortran/openmp.c:6269
+#: fortran/openmp.c:6274
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
-msgstr ""
+msgstr "Вызов подпрограммы с альтернативными возвратами в INITIALIZER клаузуле от !$OMP DECLARE REDUCTION в %L"
 
-#: fortran/openmp.c:6279
+#: fortran/openmp.c:6284
 #, gcc-internal-format, gfc-internal-format
 msgid "One of actual subroutine arguments in INITIALIZER clause of !$OMP DECLARE REDUCTION must be OMP_PRIV at %L"
-msgstr ""
+msgstr "Один из фактических аргументов подпрограммы в INITIALIZER клаузуле от !$OMP DECLARE REDUCTION должен быть OMP_PRIV в %L"
 
-#: fortran/openmp.c:6287
+#: fortran/openmp.c:6292
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing INITIALIZER clause for !$OMP DECLARE REDUCTION of derived type without default initializer at %L"
-msgstr ""
+msgstr "Отсутствует INITIALIZER клаузула для !$OMP DECLARE REDUCTION производного типа без подразумеваемого инициализатора в %L"
 
 #: fortran/options.c:227
 #, gcc-internal-format
@@ -64174,64 +57349,54 @@
 msgstr "-fexcess-precision=standard для Fortran"
 
 #: fortran/options.c:316
-#, fuzzy, gcc-internal-format
-#| msgid "Reading file '%s' as free form"
+#, gcc-internal-format
 msgid "Reading file %qs as free form"
-msgstr "Чтение файла '%s' как свободной формы"
+msgstr "Чтение файла %qs как свободной формы"
 
 #: fortran/options.c:326
-#, fuzzy, gcc-internal-format
-#| msgid "'-fd-lines-as-comments' has no effect in free form"
+#, gcc-internal-format
 msgid "%<-fd-lines-as-comments%> has no effect in free form"
-msgstr "'-fd-lines-as-comments' не действует в свободной форме"
+msgstr "%<-fd-lines-as-comments%> не имеет эффекта в свободной форме"
 
 #: fortran/options.c:329
-#, fuzzy, gcc-internal-format
-#| msgid "'-fd-lines-as-code' has no effect in free form"
+#, gcc-internal-format
 msgid "%<-fd-lines-as-code%> has no effect in free form"
-msgstr "'-fd-lines-as-code' не действует в свободной форме"
+msgstr "%<-fd-lines-as-code%> не имеет эффекта в свободной форме"
 
 #: fortran/options.c:367
-#, fuzzy, gcc-internal-format
-#| msgid "Flag -fno-automatic overwrites -fmax-stack-var-size=%d"
+#, gcc-internal-format
 msgid "Flag %<-fno-automatic%> overwrites %<-fmax-stack-var-size=%d%>"
-msgstr "Флаг -fno-automatic перебивает -fmax-stack-var-size=%d"
+msgstr "Флаг %<-fno-automatic%> перебивает %<-fmax-stack-var-size=%d%>"
 
 #: fortran/options.c:370
-#, fuzzy, gcc-internal-format
-#| msgid "Flag -fno-automatic overwrites -frecursive"
+#, gcc-internal-format
 msgid "Flag %<-fno-automatic%> overwrites %<-frecursive%>"
-msgstr "Флаг -fno-automatic перебивает -frecursive"
+msgstr "Флаг %<-fno-automatic%> перебивает %<-frecursive%>"
 
 #: fortran/options.c:372
-#, fuzzy, gcc-internal-format
-#| msgid "Flag -fno-automatic overwrites -frecursive implied by -fopenmp"
+#, gcc-internal-format
 msgid "Flag %<-fno-automatic%> overwrites %<-frecursive%> implied by %<-fopenmp%>"
-msgstr "Флаг -fno-automatic перебивает -frecursive следующий из -fopenmp"
+msgstr "Флаг %<-fno-automatic%> перебивает %<-frecursive%>, подразумеваемый %<-fopenmp%>"
 
 #: fortran/options.c:375
-#, fuzzy, gcc-internal-format
-#| msgid "Flag -frecursive overwrites -fmax-stack-var-size=%d"
+#, gcc-internal-format
 msgid "Flag %<-frecursive%> overwrites %<-fmax-stack-var-size=%d%>"
-msgstr "Флаг -frecursive перебивает -fmax-stack-var-size=%d"
+msgstr "Флаг %<-frecursive%> перебивает %<-fmax-stack-var-size=%d%>"
 
 #: fortran/options.c:378
-#, fuzzy, gcc-internal-format
-#| msgid "Flag -fmax-stack-var-size=%d overwrites -frecursive implied by -fopenmp"
+#, gcc-internal-format
 msgid "Flag %<-fmax-stack-var-size=%d%> overwrites %<-frecursive%> implied by %<-fopenmp%>"
-msgstr "Флаг -fmax-stack-var-size=%d перебивает -frecursive следующий из -fopenmp"
+msgstr "Флаг %<-fmax-stack-var-size=%d%> перебивает %<-frecursive%>, подразумеваемый %<-fopenmp%>"
 
 #: fortran/options.c:430
-#, fuzzy, gcc-internal-format
-#| msgid "Fixed line length must be at least seven."
+#, gcc-internal-format
 msgid "Fixed line length must be at least seven"
-msgstr "Фиксированная длина строки должна быть не менее семи."
+msgstr "Фиксированная длина строки должна быть по крайней мере семь"
 
 #: fortran/options.c:433
-#, fuzzy, gcc-internal-format
-#| msgid "Free line length must be at least three."
+#, gcc-internal-format
 msgid "Free line length must be at least three"
-msgstr "Свободная длина строки должна быть не менее трех."
+msgstr "Свободная длина строки должна быть по крайней мере три"
 
 #: fortran/options.c:436
 #, gcc-internal-format, gfc-internal-format
@@ -64239,34 +57404,29 @@
 msgstr "Максимальная длина подзаписи не может превышать %d"
 
 #: fortran/options.c:455
-#, fuzzy, gcc-internal-format
-#| msgid "gfortran: Only one -J option allowed"
+#, gcc-internal-format
 msgid "gfortran: Only one %<-J%> option allowed"
-msgstr "gfortran: Только одна -J опция допустима"
+msgstr "gfortran: Только одна %<-J>  опция допустима"
 
 #: fortran/options.c:527
-#, fuzzy, gcc-internal-format
-#| msgid "Argument to -ffpe-trap is not valid: %s"
+#, gcc-internal-format
 msgid "Argument to %<-ffpe-trap%> is not valid: %s"
-msgstr "Аргумент для -ffpe-trap некорректен: %s"
+msgstr "Аргумент для %<-ffpe-trap%> некорректен: %s"
 
 #: fortran/options.c:529
-#, fuzzy, gcc-internal-format
-#| msgid "Argument to -ffpe-trap is not valid: %s"
+#, gcc-internal-format
 msgid "Argument to %<-ffpe-summary%> is not valid: %s"
-msgstr "Аргумент для -ffpe-trap некорректен: %s"
+msgstr "Аргумент для %<-ffpe-summary%> некорректен: %s"
 
 #: fortran/options.c:578
-#, fuzzy, gcc-internal-format
-#| msgid "Argument to -fcheck is not valid: %s"
+#, gcc-internal-format
 msgid "Argument to %<-fcheck%> is not valid: %s"
-msgstr "Аргумент для -fcheck некорректен: %s"
+msgstr "Аргумент для %<-fcheck%> некорректен: %s"
 
 #: fortran/options.c:627
-#, fuzzy, gcc-internal-format
-#| msgid "-static-libgfortran is not supported in this configuration"
+#, gcc-internal-format
 msgid "%<-static-libgfortran%> is not supported in this configuration"
-msgstr "-static-libgfortran не поддерживается в этой конфигурации"
+msgstr "%<-static-libgfortran%> не поддерживается в этой конфигурации"
 
 #: fortran/options.c:650
 #, gcc-internal-format, gfc-internal-format
@@ -64274,16 +57434,14 @@
 msgstr "Максимальная поддерживаемая длина идентификатора есть %d"
 
 #: fortran/options.c:670
-#, fuzzy, gcc-internal-format
-#| msgid "Unrecognized option to -finit-logical: %s"
+#, gcc-internal-format
 msgid "Unrecognized option to %<-finit-logical%>: %s"
-msgstr "Неопознанная опция для -finit-logical: %s"
+msgstr "Неопознанная опция для %<-finit-logical%>: %s"
 
 #: fortran/options.c:686
-#, fuzzy, gcc-internal-format
-#| msgid "The value of n in -finit-character=n must be between 0 and 127"
+#, gcc-internal-format
 msgid "The value of n in %<-finit-character=n%> must be between 0 and 127"
-msgstr "Значение n в -finit-character=n должно быть между 0 и 127"
+msgstr "Значение n в %<-finit-character=n%> должно быть между 0 и 127"
 
 #: fortran/parse.c:593
 #, gcc-internal-format, gfc-internal-format
@@ -64290,536 +57448,492 @@
 msgid "Unclassifiable statement at %C"
 msgstr "Неклассифицируемый оператор в %C"
 
-#: fortran/parse.c:629
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "OpenMP directives at %C may not appear in PURE or ELEMENTAL procedures"
+#: fortran/parse.c:631
+#, gcc-internal-format, gfc-internal-format
 msgid "OpenACC directives at %C may not appear in PURE procedures"
-msgstr "OpenMP директивы в %C не могут появляться в PURE или ELEMENTAL процедурах"
+msgstr "OpenACC директивы в %C не могут появляться в PURE процедурах"
 
-#: fortran/parse.c:705
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Unclassifiable OpenMP directive at %C"
+#: fortran/parse.c:707
+#, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable OpenACC directive at %C"
-msgstr "Неклассифицируемая OpenMP директива в %C"
+msgstr "Неклассифицируемая OpenACC директива в %C"
 
-#: fortran/parse.c:831 fortran/parse.c:1040
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "OpenMP directives at %C may not appear in PURE or ELEMENTAL procedures"
+#: fortran/parse.c:835 fortran/parse.c:1044
+#, gcc-internal-format, gfc-internal-format
 msgid "OpenMP directives other than SIMD or DECLARE TARGET at %C may not appear in PURE or ELEMENTAL procedures"
-msgstr "OpenMP директивы в %C не могут появляться в PURE или ELEMENTAL процедурах"
+msgstr "OpenMP директивы отличные от SIMD и DECLARE TARGET в %C не могут появляться в PURE или ELEMENTAL процедурах"
 
-#: fortran/parse.c:1024
+#: fortran/parse.c:1028
 #, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable OpenMP directive at %C"
 msgstr "Неклассифицируемая OpenMP директива в %C"
 
-#: fortran/parse.c:1076
+#: fortran/parse.c:1080
 #, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable GCC directive at %C"
 msgstr "Неклассифицируемая GCC директива в %C"
 
-#: fortran/parse.c:1135 fortran/parse.c:1362
+#: fortran/parse.c:1139 fortran/parse.c:1366
 #, gcc-internal-format, gfc-internal-format
 msgid "Zero is not a valid statement label at %C"
 msgstr "Ноль не является корректной меткой оператора в %C"
 
-#: fortran/parse.c:1142 fortran/parse.c:1354
+#: fortran/parse.c:1146 fortran/parse.c:1358
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-numeric character in statement label at %C"
 msgstr "Нечисловой символ в метке оператора в %C"
 
-#: fortran/parse.c:1154 fortran/parse.c:1403
+#: fortran/parse.c:1158 fortran/parse.c:1407
 #, gcc-internal-format, gfc-internal-format
 msgid "Semicolon at %C needs to be preceded by statement"
 msgstr "Точке с запятой в %C должен предшествовать оператор"
 
-#: fortran/parse.c:1161 fortran/parse.c:1418
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Ignoring statement label in empty statement at %L"
+#: fortran/parse.c:1165 fortran/parse.c:1422
+#, gcc-internal-format, gfc-internal-format
 msgid "Statement label without statement at %L"
-msgstr "Игнорирование метки оператора в пустом операторе в %L"
+msgstr "Метка оператора без оператора в %L"
 
-#: fortran/parse.c:1224 fortran/parse.c:1405
+#: fortran/parse.c:1228 fortran/parse.c:1409
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Semicolon at %C without preceding statement"
 msgstr "Fortran 2008: Точка с запятой в %C без предшествующего оператора"
 
-#: fortran/parse.c:1247 fortran/parse.c:1381
+#: fortran/parse.c:1251 fortran/parse.c:1385
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad continuation line at %C"
 msgstr "Некорректная строка продолжения в %C"
 
-#: fortran/parse.c:1679
+#: fortran/parse.c:1683
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT statement at %L does not have a statement label"
 msgstr "FORMAT оператор в %L не имеет метки оператора"
 
-#: fortran/parse.c:2435
-#, fuzzy, gcc-internal-format
-#| msgid "gfc_trans_code(): Bad statement code"
+#: fortran/parse.c:2439
+#, gcc-internal-format
 msgid "gfc_ascii_statement(): Bad statement code"
-msgstr "gfc_trans_code(): Некорректный код оператора"
+msgstr "gfc_ascii_statement(): Некорректный код оператора"
 
-#: fortran/parse.c:2577
+#: fortran/parse.c:2581
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement at %C"
 msgstr "Неожиданный %s оператор в %C"
 
-#: fortran/parse.c:2732
+#: fortran/parse.c:2736
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot follow %s statement at %L"
 msgstr "%s оператор в %C не может следовать за %s оператором в %L"
 
-#: fortran/parse.c:2749
-#, fuzzy, gcc-internal-format
-#| msgid "Unexpected end of file in '%s'"
+#: fortran/parse.c:2753
+#, gcc-internal-format
 msgid "Unexpected end of file in %qs"
-msgstr "Неожиданный конец файла в '%s'"
+msgstr "Неожиданный конец файла в %qs"
 
-#: fortran/parse.c:2784
-#, fuzzy, gcc-internal-format
-#| msgid "Derived-type '%s' with SEQUENCE must not have a CONTAINS section at %C"
+#: fortran/parse.c:2788
+#, gcc-internal-format
 msgid "Derived-type %qs with SEQUENCE must not have a CONTAINS section at %C"
-msgstr "Производный тип '%s' с SEQUENCE не должен иметь CONTAINS секцию в %C"
+msgstr "Производный тип %qs с SEQUENCE не должен иметь CONTAINS секцию в %C"
 
-#: fortran/parse.c:2787
-#, fuzzy, gcc-internal-format
-#| msgid "Derived-type '%s' with BIND(C) must not have a CONTAINS section at %C"
+#: fortran/parse.c:2791
+#, gcc-internal-format
 msgid "Derived-type %qs with BIND(C) must not have a CONTAINS section at %C"
-msgstr "Производный тип '%s' с BIND(C)  не должен иметь CONTAINS секцию в %C"
+msgstr "Производный тип %qs с BIND(C) не должен иметь CONTAINS секцию в %C"
 
-#: fortran/parse.c:2807
+#: fortran/parse.c:2811
 #, gcc-internal-format, gfc-internal-format
 msgid "Components in TYPE at %C must precede CONTAINS"
 msgstr "Компоненты в TYPE в %C должны предшествовать CONTAINS"
 
-#: fortran/parse.c:2811
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2003:  Type-bound procedure at %C"
+#: fortran/parse.c:2815
+#, gcc-internal-format, gfc-internal-format
 msgid "Type-bound procedure at %C"
-msgstr "Fortran 2003:  Type-bound процедура в %C"
+msgstr "Type-bound процедура в %C"
 
-#: fortran/parse.c:2819
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Junk after GENERIC binding at %C"
+#: fortran/parse.c:2823
+#, gcc-internal-format, gfc-internal-format
 msgid "GENERIC binding at %C"
-msgstr "Мусор после GENERIC связывания в %C"
+msgstr "GENERIC связывание в %C"
 
-#: fortran/parse.c:2827
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2003:  FINAL procedure declaration at %C"
+#: fortran/parse.c:2831
+#, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure declaration at %C"
-msgstr "Fortran 2003:  FINAL декларация процедуры в %C"
+msgstr "FINAL декларация процедуры в %C"
 
-#: fortran/parse.c:2839
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2008: Derived type definition at %C with empty CONTAINS section"
+#: fortran/parse.c:2843
+#, gcc-internal-format, gfc-internal-format
 msgid "Derived type definition at %C with empty CONTAINS section"
-msgstr "Fortran 2008: Определение производного типа в %C с пустой CONTAINS секцией"
+msgstr "Определение производного типа в %C с пустой CONTAINS секцией"
 
-#: fortran/parse.c:2849 fortran/parse.c:3304
+#: fortran/parse.c:2853 fortran/parse.c:3308
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement in TYPE at %C must be inside a MODULE"
 msgstr "PRIVATE оператор в TYPE в %C должен быть внутри MODULE"
 
-#: fortran/parse.c:2856
+#: fortran/parse.c:2860
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede procedure bindings"
 msgstr "PRIVATE оператор в %C должен предшествовать связываниям процедур"
 
-#: fortran/parse.c:2863 fortran/parse.c:3317
+#: fortran/parse.c:2867 fortran/parse.c:3321
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PRIVATE statement at %C"
 msgstr "Повторный PRIVATE оператор в %C"
 
-#: fortran/parse.c:2873
+#: fortran/parse.c:2877
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede CONTAINS"
 msgstr "SEQUENCE оператор в %C должен предшествовать CONTAINS"
 
-#: fortran/parse.c:2877
+#: fortran/parse.c:2881
 #, gcc-internal-format, gfc-internal-format
 msgid "Already inside a CONTAINS block at %C"
 msgstr "Уже внутри CONTAINS блока в %C"
 
-#: fortran/parse.c:2996
+#: fortran/parse.c:3000
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s at %L of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray, which is not possible as the component has the pointer attribute"
-msgstr "Компонент %s в %L типа LOCK_TYPE должен иметь коизмерение или быть подкомпонентом комассива, что невозможно поскольку компонент имеет pointer атрибут"
+msgstr "Компонент %s в %L типа LOCK_TYPE должен иметь коизмерение или быть подкомпонентом комассива, что невозможно, поскольку компонент имеет pointer атрибут"
 
-#: fortran/parse.c:3002
+#: fortran/parse.c:3006
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer component %s at %L has a noncoarray subcomponent of type LOCK_TYPE, which must have a codimension or be a subcomponent of a coarray"
 msgstr "Pointer компонент %s в %L имеет некомассивный подкомпонент типа LOCK_TYPE, который должен иметь коизмерение или быть подкомпонентом комассива"
 
-#: fortran/parse.c:3007
+#: fortran/parse.c:3011
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L of type LOCK_TYPE must have a codimension"
 msgstr "Размещаемый компонент %s в %L типа LOCK_TYPE должен иметь коизмерение"
 
-#: fortran/parse.c:3011
+#: fortran/parse.c:3015
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L must have a codimension as it has a noncoarray subcomponent of type LOCK_TYPE"
-msgstr "Размещаемый компонент %s в %L должен иметь коизмерение поскольку он имеет некомассивный подкомпонент типа LOCK_TYPE"
+msgstr "Размещаемый компонент %s в %L должен иметь коизмерение, поскольку он имеет некомассивный подкомпонент типа LOCK_TYPE"
 
-#: fortran/parse.c:3016
+#: fortran/parse.c:3020
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as already a coarray subcomponent exists)"
-msgstr "Некомассивный компонент %s в %L типа LOCK_TYPE или с подкомпонентом типа LOCK_TYPE должен иметь коизмерение или быть подкомпонентом комассива. (Переменные типа %s не могут иметь коизмерение поскольку уже существует комассивный подкомпонент)"
+msgstr ""
 
-#: fortran/parse.c:3023
+#: fortran/parse.c:3027
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as %s at %L has a codimension or a coarray subcomponent)"
-msgstr "Некомассивный компонент %s в %L типа LOCK_TYPE или с подкомпонентом типа LOCK_TYPE должен иметь коизмерение или быть подкомпонентом комассива. (Переменные типа %s не могут иметь коизмерение поскольку %s в %L имеет коизмерение или комассивный подкомпонент)"
+msgstr ""
 
-#: fortran/parse.c:3033
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Component %s at %L of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray, which is not possible as the component has the pointer attribute"
+#: fortran/parse.c:3037
+#, gcc-internal-format, gfc-internal-format
 msgid "Component %s at %L of type EVENT_TYPE must have a codimension or be a subcomponent of a coarray, which is not possible as the component has the pointer attribute"
-msgstr "Компонент %s в %L типа LOCK_TYPE должен иметь коизмерение или быть подкомпонентом комассива, что невозможно поскольку компонент имеет pointer атрибут"
+msgstr "Компонент %s в %L типа EVENT_TYPE должен иметь коизмерение или быть подкомпонентом комассива, что невозможно, поскольку компонент имеет pointer атрибут"
 
-#: fortran/parse.c:3039
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Pointer component %s at %L has a noncoarray subcomponent of type LOCK_TYPE, which must have a codimension or be a subcomponent of a coarray"
+#: fortran/parse.c:3043
+#, gcc-internal-format, gfc-internal-format
 msgid "Pointer component %s at %L has a noncoarray subcomponent of type EVENT_TYPE, which must have a codimension or be a subcomponent of a coarray"
-msgstr "Pointer компонент %s в %L имеет некомассивный подкомпонент типа LOCK_TYPE, который должен иметь коизмерение или быть подкомпонентом комассива"
+msgstr "Pointer компонент %s в %L имеет некомассивный подкомпонент типа EVENT_TYPE, который должен иметь коизмерение или быть подкомпонентом комассива"
 
-#: fortran/parse.c:3044
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Allocatable component %s at %L of type LOCK_TYPE must have a codimension"
+#: fortran/parse.c:3048
+#, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L of type EVENT_TYPE must have a codimension"
-msgstr "Размещаемый компонент %s в %L типа LOCK_TYPE должен иметь коизмерение"
+msgstr "Размещаемый компонент %s в %L типа EVENT_TYPE должен иметь коизмерение"
 
-#: fortran/parse.c:3048
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Allocatable component %s at %L must have a codimension as it has a noncoarray subcomponent of type LOCK_TYPE"
+#: fortran/parse.c:3052
+#, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L must have a codimension as it has a noncoarray subcomponent of type EVENT_TYPE"
-msgstr "Размещаемый компонент %s в %L должен иметь коизмерение поскольку он имеет некомассивный подкомпонент типа LOCK_TYPE"
+msgstr "Размещаемый компонент %s в %L должен иметь коизмерение, поскольку он имеет некомассивный подкомпонент типа EVENT_TYPE"
 
-#: fortran/parse.c:3053
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as already a coarray subcomponent exists)"
+#: fortran/parse.c:3057
+#, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as already a coarray subcomponent exists)"
-msgstr "Некомассивный компонент %s в %L типа LOCK_TYPE или с подкомпонентом типа LOCK_TYPE должен иметь коизмерение или быть подкомпонентом комассива. (Переменные типа %s не могут иметь коизмерение поскольку уже существует комассивный подкомпонент)"
+msgstr ""
 
-#: fortran/parse.c:3060
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as %s at %L has a codimension or a coarray subcomponent)"
+#: fortran/parse.c:3064
+#, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as %s at %L has a codimension or a coarray subcomponent)"
-msgstr "Некомассивный компонент %s в %L типа LOCK_TYPE или с подкомпонентом типа LOCK_TYPE должен иметь коизмерение или быть подкомпонентом комассива. (Переменные типа %s не могут иметь коизмерение поскольку %s в %L имеет коизмерение или комассивный подкомпонент)"
+msgstr ""
 
-#: fortran/parse.c:3112
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "failed to write state trailer [%s]"
+#: fortran/parse.c:3116
+#, gcc-internal-format, gfc-internal-format
 msgid "failed to create map component '%s'"
-msgstr "не удалось записать трейлер состояния [%s]"
+msgstr "не удалось создать map компонент '%s'"
 
-#: fortran/parse.c:3145
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "failed to find class '%s'"
+#: fortran/parse.c:3149
+#, gcc-internal-format, gfc-internal-format
 msgid "failed to create union component '%s'"
-msgstr "не найден класс '%s'"
+msgstr "не удалось создать компонент объединения '%s'"
 
-#: fortran/parse.c:3200
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Syntax error in data declaration at %C"
+#: fortran/parse.c:3204
+#, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in nested structure declaration at %C"
-msgstr "Синтаксическая ошибка в декларации данных в %C"
+msgstr "Синтаксическая ошибка в декларации вложенной структуры в %C"
 
-#: fortran/parse.c:3287
+#: fortran/parse.c:3291
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside CONTAINS"
 msgstr "FINAL декларация в %C должна быть внутри CONTAINS"
 
-#: fortran/parse.c:3295
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2003: Derived type definition at %C without components"
+#: fortran/parse.c:3299
+#, gcc-internal-format, gfc-internal-format
 msgid "Derived type definition at %C without components"
-msgstr "Fortran 2003: Определение производного типа в %C без компонентов"
+msgstr "Определение производного типа в %C без компонентов"
 
-#: fortran/parse.c:3311
+#: fortran/parse.c:3315
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede structure components"
 msgstr "PRIVATE оператор в %C должен предшествовать компонентам структуры"
 
-#: fortran/parse.c:3328
+#: fortran/parse.c:3332
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede structure components"
 msgstr "SEQUENCE оператор в %C должен предшествовать компонентам структуры"
 
-#: fortran/parse.c:3334
+#: fortran/parse.c:3338
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE attribute at %C already specified in TYPE statement"
 msgstr "SEQUENCE атрибут в %C уже специфицирован в TYPE операторе"
 
-#: fortran/parse.c:3339
+#: fortran/parse.c:3343
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SEQUENCE statement at %C"
 msgstr "Повторный SEQUENCE оператор в %C"
 
-#: fortran/parse.c:3349
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2003:  CONTAINS block in derived type definition at %C"
+#: fortran/parse.c:3353
+#, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS block in derived type definition at %C"
-msgstr "Fortran 2003:  CONTAINS блок определении производного типа в %C"
+msgstr "CONTAINS блок в определении производного типа в %C"
 
-#: fortran/parse.c:3407
+#: fortran/parse.c:3411
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM declaration at %C has no ENUMERATORS"
 msgstr "ENUM декларация в %C не имеет ENUMERATORS"
 
-#: fortran/parse.c:3494
+#: fortran/parse.c:3498
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in INTERFACE block at %C"
 msgstr "Неожиданный %s оператор в INTERFACE блоке в %C"
 
-#: fortran/parse.c:3518
-#, fuzzy, gcc-internal-format
-#| msgid "Name '%s' of ABSTRACT INTERFACE at %C cannot be the same as an intrinsic type"
+#: fortran/parse.c:3522
+#, gcc-internal-format
 msgid "Name %qs of ABSTRACT INTERFACE at %C cannot be the same as an intrinsic type"
-msgstr "Имя '%s' от ABSTRACT INTERFACE в %C не может совпадать со встроенным типом"
+msgstr "Имя %qs от ABSTRACT INTERFACE в %C не может совпадать со встроенным типом"
 
-#: fortran/parse.c:3552
+#: fortran/parse.c:3556
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement at %C in INTERFACE body"
 msgstr "Неожиданный %s оператор в %C в INTERFACE теле"
 
-#: fortran/parse.c:3570
-#, fuzzy, gcc-internal-format
-#| msgid "INTERFACE procedure '%s' at %L has the same name as the enclosing procedure"
+#: fortran/parse.c:3574
+#, gcc-internal-format
 msgid "INTERFACE procedure %qs at %L has the same name as the enclosing procedure"
-msgstr "INTERFACE процедура '%s' в %L имеет то же имя что и объемлющая процедура"
+msgstr "INTERFACE процедура %qs в %L имеет то же имя, что и объемлющая процедура"
 
-#: fortran/parse.c:3700
+#: fortran/parse.c:3704
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement is not allowed inside of BLOCK at %C"
 msgstr "%s оператор не допускается внутри BLOCK в %C"
 
-#: fortran/parse.c:3732
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "%s statement is not allowed inside of BLOCK at %C"
+#: fortran/parse.c:3736
+#, gcc-internal-format, gfc-internal-format
 msgid "%s statement is not allowed inside of BLOCK DATA at %C"
-msgstr "%s оператор не допускается внутри BLOCK в %C"
+msgstr "%s оператор не допускается внутри BLOCK DATA в %C"
 
-#: fortran/parse.c:3822
+#: fortran/parse.c:3826
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement must appear in a MODULE"
 msgstr "%s оператор должен появляться в MODULE"
 
-#: fortran/parse.c:3830
+#: fortran/parse.c:3834
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C follows another accessibility specification"
 msgstr "%s оператор в %C следует за другой спецификацией доступности"
 
-#: fortran/parse.c:3882
-#, fuzzy, gcc-internal-format
-#| msgid "Bad kind expression for function '%s' at %L"
+#: fortran/parse.c:3886
+#, gcc-internal-format
 msgid "Bad kind expression for function %qs at %L"
-msgstr "Некорректное выражение вида для функции '%s' в %L"
+msgstr "Некорректное выражение вида для функции %qs в %L"
 
-#: fortran/parse.c:3886
-#, fuzzy, gcc-internal-format
-#| msgid "The type for function '%s' at %L is not accessible"
+#: fortran/parse.c:3890
+#, gcc-internal-format
 msgid "The type for function %qs at %L is not accessible"
-msgstr "Тип для функции '%s' в %L недоступен"
+msgstr "Тип для функции %qs в %L недоступен"
 
-#: fortran/parse.c:3946
+#: fortran/parse.c:3950
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C follows previous unmasked ELSEWHERE"
 msgstr "ELSEWHERE оператор в %C следует за предыдущим немаскированным ELSEWHERE"
 
-#: fortran/parse.c:3968
+#: fortran/parse.c:3972
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in WHERE block at %C"
 msgstr "Неожиданный %s оператор в WHERE блоке в %C"
 
-#: fortran/parse.c:4027
+#: fortran/parse.c:4031
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in FORALL block at %C"
 msgstr "Неожиданный %s оператор в FORALL блоке в %C"
 
-#: fortran/parse.c:4078
+#: fortran/parse.c:4082
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSE IF statement at %C cannot follow ELSE statement at %L"
 msgstr "ELSE IF оператор в %C не может следовать за ELSE оператором в %L"
 
-#: fortran/parse.c:4096
+#: fortran/parse.c:4100
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ELSE statements at %L and %C"
 msgstr "Повторные ELSE операторы в %L и %C"
 
-#: fortran/parse.c:4157
+#: fortran/parse.c:4161
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected a CASE or END SELECT statement following SELECT CASE at %C"
 msgstr "Ожидался CASE или END SELECT оператор следующий за SELECT CASE в %C"
 
-#: fortran/parse.c:4241
+#: fortran/parse.c:4245
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected TYPE IS, CLASS IS or END SELECT statement following SELECT TYPE at %C"
-msgstr "Ожидался TYPE IS, CLASS IS  или END SELECT оператор следующий за SELECT TYPE в %C"
+msgstr "Ожидался TYPE IS, CLASS IS  или END SELECT оператор, следующий за SELECT TYPE в %C"
 
-#: fortran/parse.c:4303
-#, fuzzy, gcc-internal-format
-#| msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
+#: fortran/parse.c:4307
+#, gcc-internal-format
 msgid "Variable %qs at %C cannot be redefined inside loop beginning at %L"
-msgstr "Переменная '%s' в %C не может быть переопределена внутри цикла начинающегося в %L"
+msgstr "Переменная %qs в %C не может быть переопределена внутри цикла начинающегося в %L"
 
-#: fortran/parse.c:4336
+#: fortran/parse.c:4340
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is within another block"
 msgstr "Конец неблочного DO оператора в %C находится внутри другого блока"
 
-#: fortran/parse.c:4346
+#: fortran/parse.c:4350
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is interwoven with another DO loop"
 msgstr "Конец неблочного DO оператора в %C перекрывается с другим DO циклом"
 
-#: fortran/parse.c:4372
+#: fortran/parse.c:4376
 #, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL block inside of OpenACC region at %C"
-msgstr ""
+msgstr "CRITICAL блок внутри OpenACC области в %C"
 
-#: fortran/parse.c:4373
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2003:  CONTAINS block in derived type definition at %C"
+#: fortran/parse.c:4377
+#, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL block inside of OpenMP region at %C"
-msgstr "Fortran 2003:  CONTAINS блок определении производного типа в %C"
+msgstr "CRITICAL блок внутри OpenMP области в %C"
 
-#: fortran/parse.c:4399
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Statement label in END CRITICAL at %C does not match CRITIAL label"
+#: fortran/parse.c:4403
+#, gcc-internal-format, gfc-internal-format
 msgid "Statement label in END CRITICAL at %C does not match CRITICAL label"
-msgstr "Метка оператора в END CRITICAL в %C не соответствует CRITIAL метке"
+msgstr "Метка оператора в END CRITICAL в %C не соответствует CRITICAL метке"
 
-#: fortran/parse.c:4468
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2008: BLOCK construct at %C"
+#: fortran/parse.c:4472
+#, gcc-internal-format, gfc-internal-format
 msgid "BLOCK construct at %C"
-msgstr "Fortran 2008: BLOCK конструкция в %C"
+msgstr "BLOCK конструкция в %C"
 
-#: fortran/parse.c:4502
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2003: ASSOCIATE construct at %C"
+#: fortran/parse.c:4506
+#, gcc-internal-format, gfc-internal-format
 msgid "ASSOCIATE construct at %C"
-msgstr "Fortran 2003: ASSOCIATE конструкция в %C"
+msgstr "ASSOCIATE конструкция в %C"
 
-#: fortran/parse.c:4690
+#: fortran/parse.c:4694
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label in ENDDO at %C doesn't match DO label"
 msgstr "Метка оператора в ENDDO в %C не соответствует DO метке"
 
-#: fortran/parse.c:4706
+#: fortran/parse.c:4710
 #, gcc-internal-format, gfc-internal-format
 msgid "Named block DO at %L requires matching ENDDO name"
 msgstr "Именованный блок DO в %L требует соответствующего ENDDO имени"
 
-#: fortran/parse.c:4897
+#: fortran/parse.c:4901
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing !$OMP END ATOMIC after !$OMP ATOMIC CAPTURE at %C"
 msgstr "Отсутствует !$OMP END ATOMIC после !$OMP ATOMIC CAPTURE в %C"
 
-#: fortran/parse.c:4913 fortran/parse.c:4972
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Nested CRITICAL block at %C"
+#: fortran/parse.c:4917 fortran/parse.c:4976
+#, gcc-internal-format, gfc-internal-format
 msgid "OpenACC directive inside of CRITICAL block at %C"
-msgstr "Вложенный CRITICAL блок в %C"
+msgstr "OpenACC директива внутри CRITICAL блока в %C"
 
-#: fortran/parse.c:4947
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Expecting %s statement at %C"
+#: fortran/parse.c:4951
+#, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s at %C"
-msgstr "Ожидается %s оператор в %C"
+msgstr "Ожидается %s в %C"
 
-#: fortran/parse.c:4991
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Expected '(' at %C"
+#: fortran/parse.c:4995
+#, gcc-internal-format, gfc-internal-format
 msgid "Expected DO loop at %C"
-msgstr "Ожидалась '(' в %C"
+msgstr "Ожидался DO цикл в %C"
 
-#: fortran/parse.c:5011
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Redundant ACQUIRED_LOCK tag found at %L "
+#: fortran/parse.c:5015
+#, gcc-internal-format, gfc-internal-format
 msgid "Redundant !$ACC END LOOP at %C"
-msgstr "Избыточный ACQUIRED_LOCK тег найден в %L "
+msgstr "Избыточный !$ACC END LOOP в %C"
 
-#: fortran/parse.c:5225
+#: fortran/parse.c:5229
 #, gcc-internal-format, gfc-internal-format
 msgid "Name after !$omp critical and !$omp end critical does not match at %C"
 msgstr "Имя после !$omp critical и !$omp end critical не соответствует в %C"
 
-#: fortran/parse.c:5283
+#: fortran/parse.c:5287
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot terminate a non-block DO loop"
 msgstr "%s оператор в %C не может завершать неблочный DO цикл"
 
-#: fortran/parse.c:5297
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "FORMAT statement at %L does not have a statement label"
+#: fortran/parse.c:5301
+#, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %C after the first executable statement"
-msgstr "FORMAT оператор в %L не имеет метки оператора"
+msgstr "DATA оператор в %C после первого выполняемого оператора"
 
-#: fortran/parse.c:5423
+#: fortran/parse.c:5427
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive does not commence a loop at %C"
-msgstr ""
+msgstr "%<GCC unroll%> директива не запускает цикл в %C"
 
-#: fortran/parse.c:5538
-#, fuzzy, gcc-internal-format
-#| msgid "Contained procedure '%s' at %C is already ambiguous"
+#: fortran/parse.c:5542
+#, gcc-internal-format
 msgid "Contained procedure %qs at %C is already ambiguous"
-msgstr "Внутренняя процедура '%s' в %C уже неоднозначна"
+msgstr "Внутренняя процедура %qs в %C уже неоднозначна"
 
-#: fortran/parse.c:5595
+#: fortran/parse.c:5599
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in CONTAINS section at %C"
 msgstr "Неожиданный %s оператор в CONTAINS секции в %C"
 
-#: fortran/parse.c:5620
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2008: CONTAINS statement without FUNCTION or SUBROUTINE statement at %C"
+#: fortran/parse.c:5624
+#, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS statement without FUNCTION or SUBROUTINE statement at %L"
-msgstr "Fortran 2008: CONTAINS оператор без FUNCTION или SUBROUTINE оператора в %C"
+msgstr "CONTAINS оператор без FUNCTION или SUBROUTINE оператора в %L"
 
-#: fortran/parse.c:5732
+#: fortran/parse.c:5736
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS statement at %C is already in a contained program unit"
 msgstr "CONTAINS оператор в %C уже во внутренней программной единице"
 
-#: fortran/parse.c:5784
-#, fuzzy, gcc-internal-format
-#| msgid "Global name '%s' at %L is already being used as a %s at %L"
+#: fortran/parse.c:5788
+#, gcc-internal-format
 msgid "Global binding name %qs at %L is already being used as a %s at %L"
-msgstr "Глобальное имя '%s' в %L уже используется как %s в %L"
+msgstr "Глобальное связывающее имя %qs в %L уже используется как %s в %L"
 
-#: fortran/parse.c:5788
-#, fuzzy, gcc-internal-format
-#| msgid "Global name '%s' at %L is already being used as a %s at %L"
+#: fortran/parse.c:5792
+#, gcc-internal-format
 msgid "Global name %qs at %L is already being used as a %s at %L"
-msgstr "Глобальное имя '%s' в %L уже используется как %s в %L"
+msgstr "Глобальное имя %qs в %L уже используется как %s в %L"
 
-#: fortran/parse.c:5794
-#, fuzzy, gcc-internal-format
-#| msgid "Global name '%s' at %L is already being used as a %s at %L"
+#: fortran/parse.c:5798
+#, gcc-internal-format
 msgid "Global binding name %qs at %L is already being used at %L"
-msgstr "Глобальное имя '%s' в %L уже используется как %s в %L"
+msgstr "Глобальное связывающее имя %qs в %L уже используется в %L"
 
-#: fortran/parse.c:5797
-#, fuzzy, gcc-internal-format
-#| msgid "Global name '%s' at %L is already being used as a %s at %L"
+#: fortran/parse.c:5801
+#, gcc-internal-format
 msgid "Global name %qs at %L is already being used at %L"
-msgstr "Глобальное имя '%s' в %L уже используется как %s в %L"
+msgstr "Глобальное имя %qs в %L уже используется в %L"
 
-#: fortran/parse.c:5819
+#: fortran/parse.c:5823
 #, gcc-internal-format, gfc-internal-format
 msgid "Blank BLOCK DATA at %C conflicts with prior BLOCK DATA at %L"
-msgstr "Blank BLOCK DATA в %C конфликтует с предыдущей BLOCK DATA в %L"
+msgstr "Пустой BLOCK DATA в %C конфликтует с предыдущим BLOCK DATA в %L"
 
-#: fortran/parse.c:5845
+#: fortran/parse.c:5849
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in BLOCK DATA at %C"
 msgstr "Неожиданный %s оператор в BLOCK DATA в %C"
 
-#: fortran/parse.c:5949
+#: fortran/parse.c:5953
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in MODULE at %C"
 msgstr "Неожиданный %s оператор в MODULE в %C"
@@ -64827,7 +57941,7 @@
 #. If we see a duplicate main program, shut down.  If the second
 #. instance is an implied main program, i.e. data decls or executable
 #. statements, we're in for lots of errors.
-#: fortran/parse.c:6333
+#: fortran/parse.c:6337
 #, gcc-internal-format, gfc-internal-format
 msgid "Two main PROGRAMs at %L and %C"
 msgstr "Две главные программы в %L и %C"
@@ -64840,7 +57954,7 @@
 #: fortran/primary.c:136
 #, gcc-internal-format
 msgid "gfc_check_digit(): bad radix"
-msgstr ""
+msgstr "gfc_check_digit(): Некорректное основание"
 
 #: fortran/primary.c:230
 #, gcc-internal-format, gfc-internal-format
@@ -64850,13 +57964,12 @@
 #: fortran/primary.c:239
 #, gcc-internal-format, gfc-internal-format
 msgid "Integer too big for its kind at %C. This check can be disabled with the option -fno-range-check"
-msgstr "Integer слишком велико для своего вида в %C. Эту проверку можно выключить опцией -fno-range-check"
+msgstr "Целое число слишком велико для своего вида в %C. Эту проверку можно выключить опцией -fno-range-check"
 
 #: fortran/primary.c:267
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Extension: Hollerith constant at %C"
+#, gcc-internal-format, gfc-internal-format
 msgid "Hollerith constant at %C"
-msgstr "Расширение: Холлеритова константа в %C"
+msgstr "Холлеритова константа в %C"
 
 #: fortran/primary.c:274
 #, gcc-internal-format, gfc-internal-format
@@ -64874,10 +57987,9 @@
 msgstr "Некорректная Холлеритова константа в %L содержит широкий символ"
 
 #: fortran/primary.c:386
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Extension: Hexadecimal constant at %C uses non-standard syntax"
+#, gcc-internal-format, gfc-internal-format
 msgid "Hexadecimal constant at %C uses non-standard syntax"
-msgstr "Расширение: Шестнадцатеричная константа в %C использует нестандартный синтаксис"
+msgstr "Шестнадцатеричная константа в %C использует нестандартный синтаксис"
 
 #: fortran/primary.c:395
 #, gcc-internal-format, gfc-internal-format
@@ -64890,10 +58002,9 @@
 msgstr "Некорректный символ в BOZ константе в %C"
 
 #: fortran/primary.c:424
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Extension: BOZ constant at %C uses non-standard postfix syntax"
+#, gcc-internal-format, gfc-internal-format
 msgid "BOZ constant at %C uses non-standard postfix syntax"
-msgstr "Расширение: BOZ константа в %C использует нестандартный постфиксный синтаксис"
+msgstr "BOZ константа в %C использует нестандартный постфиксный синтаксис"
 
 #: fortran/primary.c:454
 #, gcc-internal-format, gfc-internal-format
@@ -64901,22 +58012,19 @@
 msgstr "Integer слишком велико для integer вида %i в %C"
 
 #: fortran/primary.c:460
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2003: BOZ used outside a DATA statement at %C"
+#, gcc-internal-format, gfc-internal-format
 msgid "BOZ used outside a DATA statement at %C"
-msgstr "Fortran 2003: BOZ используется вне DATA оператора в %C"
+msgstr "BOZ используется вне DATA оператора в %C"
 
 #: fortran/primary.c:551
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Invalid exponent-letter 'q' in real-literal-constant at %C"
+#, gcc-internal-format, gfc-internal-format
 msgid "exponent-letter 'q' in real-literal-constant at %C"
-msgstr "Некорректная exponent-letter 'q' в real-literal-constant в %C"
+msgstr "exponent-letter 'q' в real-literal-constant в %C"
 
 #: fortran/primary.c:556
-#, fuzzy, gcc-internal-format
-#| msgid "Extension: exponent-letter 'q' in real-literal-constant at %C"
+#, gcc-internal-format
 msgid "Extension: exponent-letter %<q%> in real-literal-constant at %C"
-msgstr "Расширение: exponent-letter 'q' в real-literal-constant в %C"
+msgstr "Расширение: exponent-letter %<q%> в real-literal-constant в %C"
 
 #: fortran/primary.c:577
 #, gcc-internal-format, gfc-internal-format
@@ -64924,22 +58032,19 @@
 msgstr "Отсутствует экспонента в вещественном числе в %C"
 
 #: fortran/primary.c:636
-#, fuzzy, gcc-internal-format
-#| msgid "Real number at %C has a 'd' exponent and an explicit kind"
+#, gcc-internal-format
 msgid "Real number at %C has a %<d%> exponent and an explicit kind"
-msgstr "Вещественное число в %C имеет 'd' экспоненту и явный вид"
+msgstr "Вещественное число в %C имеет %<d%> экспоненту и явный вид"
 
 #: fortran/primary.c:666
-#, fuzzy, gcc-internal-format
-#| msgid "Real number at %C has a 'q' exponent and an explicit kind"
+#, gcc-internal-format
 msgid "Real number at %C has a %<q%> exponent and an explicit kind"
-msgstr "Вещественное число в %C имеет 'q' экспоненту и явный вид"
+msgstr "Вещественное число в %C имеет %<q%> экспоненту и явный вид"
 
 #: fortran/primary.c:680
-#, fuzzy, gcc-internal-format
-#| msgid "Invalid exponent-letter 'q' in real-literal-constant at %C"
+#, gcc-internal-format
 msgid "Invalid exponent-letter %<q%> in real-literal-constant at %C"
-msgstr "Некорректная exponent-letter 'q' в real-literal-constant в %C"
+msgstr "Некорректная exponent-letter %<q%> в real-literal-constant в %C"
 
 #: fortran/primary.c:713
 #, gcc-internal-format, gfc-internal-format
@@ -64959,12 +58064,12 @@
 #: fortran/primary.c:738
 #, gcc-internal-format
 msgid "gfc_range_check() returned bad value"
-msgstr ""
+msgstr "gfc_range_check() вернула некорректное значение"
 
 #: fortran/primary.c:785
 #, gcc-internal-format
 msgid "Non-significant digits in %qs number at %C, maybe incorrect KIND"
-msgstr ""
+msgstr "Незначащие цифры в %qs числе в %C, возможно, некорректный KIND"
 
 #: fortran/primary.c:877
 #, gcc-internal-format, gfc-internal-format
@@ -64979,18 +58084,17 @@
 #: fortran/primary.c:1106
 #, gcc-internal-format, gfc-internal-format
 msgid "Unterminated character constant beginning at %C"
-msgstr "Нетерминированная символьная константа начинающаяся в %C"
+msgstr "Нетерминированная символьная константа, начинающаяся в %C"
 
 #: fortran/primary.c:1136
-#, fuzzy, gcc-internal-format
-#| msgid "Character '%s' in string at %C is not representable in character kind %d"
+#, gcc-internal-format
 msgid "Character %qs in string at %C is not representable in character kind %d"
-msgstr "Символ '%s' в строке в %C непредставим в character виде %d"
+msgstr "Символ %qs в строке в %C непредставим в character виде %d"
 
 #: fortran/primary.c:1149
 #, gcc-internal-format
 msgid "match_string_constant(): Delimiter not found"
-msgstr ""
+msgstr "match_string_constant(): Разделитель не найден"
 
 #: fortran/primary.c:1219
 #, gcc-internal-format, gfc-internal-format
@@ -65013,15 +58117,14 @@
 msgstr "Скалярный PARAMETER требуется в complex константе в %C"
 
 #: fortran/primary.c:1284
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Expected PARAMETER symbol in complex constant at %C"
+#, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER symbol in complex constant at %C"
-msgstr "Ожидался PARAMETER символ в complex константе в %C"
+msgstr "PARAMETER символ в complex константе в %C"
 
 #: fortran/primary.c:1307
 #, gcc-internal-format
 msgid "gfc_match_sym_complex_part(): Bad type"
-msgstr ""
+msgstr "gfc_match_sym_complex_part(): Некорректный тип"
 
 #: fortran/primary.c:1314
 #, gcc-internal-format, gfc-internal-format
@@ -65034,22 +58137,19 @@
 msgstr "Синтаксическая ошибка в COMPLEX константе в %C"
 
 #: fortran/primary.c:1573
-#, fuzzy, gcc-internal-format
-#| msgid "Namelist %s cannot be renamed by USE association to %s"
+#, gcc-internal-format
 msgid "Namelist %qs can not be an argument at %L"
-msgstr "Список имен %s не может быть переименован путем USE ассоциации в %s"
+msgstr "Список имен %qs не может быть аргументом в %L"
 
 #: fortran/primary.c:1675
-#, fuzzy, gcc-internal-format
-#| msgid "Keyword '%s' at %C has already appeared in the current argument list"
+#, gcc-internal-format
 msgid "Keyword %qs at %C has already appeared in the current argument list"
-msgstr "Ключевое слово '%s' в %C уже появлялось в текущем списке аргументов"
+msgstr "Ключевое слово %qs в %C уже появлялось в текущем списке аргументов"
 
 #: fortran/primary.c:1742
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Unknown argument list function at %L"
+#, gcc-internal-format, gfc-internal-format
 msgid "argument list function at %C"
-msgstr "Неизвестная функция списка аргументов в %L"
+msgstr "функция списка аргументов в %C"
 
 #: fortran/primary.c:1816
 #, gcc-internal-format, gfc-internal-format
@@ -65069,7 +58169,7 @@
 #: fortran/primary.c:1930
 #, gcc-internal-format
 msgid "extend_ref(): Bad tail"
-msgstr ""
+msgstr "extend_ref(): Некорректный хвост"
 
 #: fortran/primary.c:1970
 #, gcc-internal-format, gfc-internal-format
@@ -65077,22 +58177,19 @@
 msgstr "Обозначение секции массива, например, '(:)', требуется помимо обозначения комассива '[...]' в %C"
 
 #: fortran/primary.c:1978
-#, fuzzy, gcc-internal-format
-#| msgid "Coarray designator at %C but '%s' is not a coarray"
+#, gcc-internal-format
 msgid "Coarray designator at %C but %qs is not a coarray"
-msgstr "Обозначение комассива в %C но '%s' не есть комассив"
+msgstr "Обозначение комассива в %C, но %qs не есть комассив"
 
 #: fortran/primary.c:2116
-#, fuzzy, gcc-internal-format
-#| msgid "Symbol '%s' at %L has no IMPLICIT type"
+#, gcc-internal-format
 msgid "Symbol %qs at %C has no IMPLICIT type"
-msgstr "Символ '%s' в %L не имеет IMPLICIT типа"
+msgstr "Символ %qs в %C не имеет IMPLICIT тип"
 
 #: fortran/primary.c:2123
-#, fuzzy, gcc-internal-format
-#| msgid "Unexpected character in variable list at %C"
+#, gcc-internal-format
 msgid "Unexpected %<%c%> for nonderived-type variable %qs at %C"
-msgstr "Неожиданный символ в списке переменных в %C"
+msgstr "Неожиданный %<%c%> для переменной непроизводного типа %qs в %C"
 
 #: fortran/primary.c:2141
 #, gcc-internal-format, gfc-internal-format
@@ -65105,16 +58202,14 @@
 msgstr "Ожидался список аргументов в %C"
 
 #: fortran/primary.c:2232
-#, fuzzy, gcc-internal-format
-#| msgid "Procedure pointer component '%s' requires an argument list at %C"
+#, gcc-internal-format
 msgid "Procedure pointer component %qs requires an argument list at %C"
-msgstr "Компонент указатель на процедуру '%s' требует список аргументов в %C"
+msgstr "Компонент указатель на процедуру %qs требует список аргументов в %C"
 
 #: fortran/primary.c:2321
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "forming reference to reference type %qT"
+#, gcc-internal-format, gfc-internal-format
 msgid "Nonpolymorphic reference to abstract type at %C"
-msgstr "формирование ссылки на ссылочный тип %qT"
+msgstr "Неполиморфная ссылка на абстрактный тип в %C"
 
 #: fortran/primary.c:2328
 #, gcc-internal-format, gfc-internal-format
@@ -65124,130 +58219,112 @@
 #: fortran/primary.c:2363
 #, gcc-internal-format
 msgid "gfc_variable_attr(): Expression isn't a variable"
-msgstr ""
+msgstr "gfc_variable_attr(): Выражение не является переменной"
 
 #: fortran/primary.c:2418
-#, fuzzy, gcc-internal-format
-#| msgid "creating array of references"
+#, gcc-internal-format
 msgid "gfc_variable_attr(): Bad array reference"
-msgstr "создание массива ссылок"
+msgstr "gfc_variable_attr(): Некорректная ссылка на массив"
 
 #: fortran/primary.c:2538
 #, gcc-internal-format
 msgid "gfc_caf_attr(): Expression isn't a variable"
-msgstr ""
+msgstr "gfc_caf_attr(): Выражение не является переменной"
 
 #: fortran/primary.c:2595
-#, fuzzy, gcc-internal-format
-#| msgid "creating array of references"
+#, gcc-internal-format
 msgid "gfc_caf_attr(): Bad array reference"
-msgstr "создание массива ссылок"
+msgstr "gfc_caf_attr(): Некорректная ссылка на массив"
 
 #: fortran/primary.c:2767
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2003: Structure constructor with missing optional arguments at %C"
+#, gcc-internal-format, gfc-internal-format
 msgid "Structure constructor with missing optional arguments at %C"
-msgstr "Fortran 2003: Конструктор структуры с отсутствующими необязательными аргументами в %C"
+msgstr "Конструктор структуры с отсутствующими необязательными аргументами в %C"
 
 #: fortran/primary.c:2776
-#, fuzzy, gcc-internal-format
-#| msgid "No initializer for component '%s' given in the structure constructor at %C!"
+#, gcc-internal-format
 msgid "No initializer for allocatable component %qs given in the structure constructor at %C"
-msgstr "Не задан инициализатор для компонента '%s' в конструкторе структуры в %C!"
+msgstr "Нет инициализатора для размещаемого компонента %qs данного в конструкторе структуры в %C"
 
 #: fortran/primary.c:2783
-#, fuzzy, gcc-internal-format
-#| msgid "No initializer for component '%s' given in the structure constructor at %C!"
+#, gcc-internal-format
 msgid "No initializer for component %qs given in the structure constructor at %C"
-msgstr "Не задан инициализатор для компонента '%s' в конструкторе структуры в %C!"
+msgstr "Нет инициализатора для компонента %qs данного в конструкторе структуры в %C"
 
 #: fortran/primary.c:2831
-#, fuzzy, gcc-internal-format
-#| msgid "Can't construct ABSTRACT type '%s' at %L"
+#, gcc-internal-format
 msgid "Can't construct ABSTRACT type %qs at %L"
-msgstr "Невозможно сконструировать ABSTRACT тип '%s' в %L"
+msgstr "Невозможно сконструировать ABSTRACT тип %qs в %L"
 
 #: fortran/primary.c:2851
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2003: Structure constructor with named arguments at %C"
+#, gcc-internal-format, gfc-internal-format
 msgid "Structure constructor with named arguments at %C"
-msgstr "Fortran 2003: Конструктор структуры с именованными аргументами в %C"
+msgstr "Конструктор структуры с именованными аргументами в %C"
 
 #: fortran/primary.c:2866
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Component initializer without name after component named %s at %L!"
+#, gcc-internal-format, gfc-internal-format
 msgid "Component initializer without name after component named %s at %L"
-msgstr "Инициализатор компонента без имени после компонента именуемого %s в %L!"
+msgstr "Инициализатор компонента без имени после компонента именуемого %s в %L"
 
 #: fortran/primary.c:2871
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Too many components in structure constructor at %L!"
+#, gcc-internal-format, gfc-internal-format
 msgid "Too many components in structure constructor at %L"
-msgstr "Слишком много компонентов в конструкторе структуры в %L!"
+msgstr "Слишком много компонентов в конструкторе структуры в %L"
 
 #: fortran/primary.c:2941
-#, fuzzy, gcc-internal-format
-#| msgid "Component '%s' is initialized twice in the structure constructor at %L!"
+#, gcc-internal-format
 msgid "Component %qs is initialized twice in the structure constructor at %L"
-msgstr "Компонент '%s' инициализирован дважды в конструкторе структуры в %L!"
+msgstr "Компонент %qs инициализирован дважды в конструкторе структуры в %L"
 
 #: fortran/primary.c:2953
-#, fuzzy, gcc-internal-format
-#| msgid "Coindexed expression to pointer component '%s' in structure constructor at %L!"
+#, gcc-internal-format
 msgid "Coindexed expression to pointer component %qs in structure constructor at %L"
-msgstr "Коиндексное выражение для компонента указателя '%s' в конструкторе структуры в %L!"
+msgstr "Коиндексное выражение для компонента указателя %qs в конструкторе структуры в %L"
 
 #: fortran/primary.c:3007
-#, fuzzy, gcc-internal-format
-#| msgid "component '%s' at %L has already been set by a parent derived type constructor"
+#, gcc-internal-format
 msgid "component %qs at %L has already been set by a parent derived type constructor"
-msgstr "компонент '%s' в %L уже установлен конструктором родительского производного типа"
+msgstr "компонент %qs в %L уже был установлен конструктором родительского производного типа"
 
 #: fortran/primary.c:3162
 #, gcc-internal-format, gfc-internal-format
 msgid "%%LOC() as an rvalue at %C"
-msgstr ""
+msgstr "%%LOC() как rvalue в %C"
 
 #: fortran/primary.c:3221
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' at %C is the name of a recursive function and so refers to the result variable. Use an explicit RESULT variable for direct recursion (12.5.2.1)"
+#, gcc-internal-format
 msgid "%qs at %C is the name of a recursive function and so refers to the result variable. Use an explicit RESULT variable for direct recursion (12.5.2.1)"
-msgstr "'%s' в %C есть имя рекурсивной функции и как таковое ссылается на результирующую переменную. Используйте явную RESULT переменную для прямой рекурсии (12.5.2.1)"
+msgstr "%qs в %C является именем рекурсивной функции и ссылается на результирующую переменную. Используйте явную переменную RESULT для прямой рекурсии (12.5.2.1)"
 
 #: fortran/primary.c:3345
-#, fuzzy, gcc-internal-format
-#| msgid "Unexpected use of subroutine name '%s' at %C"
+#, gcc-internal-format
 msgid "Unexpected use of subroutine name %qs at %C"
-msgstr "Неожиданное использование имени подпрограммы '%s' в %C"
+msgstr "Неожиданное использование имени подпрограммы %qs в %C"
 
 #: fortran/primary.c:3377
-#, fuzzy, gcc-internal-format
-#| msgid "Statement function '%s' requires argument list at %C"
+#, gcc-internal-format
 msgid "Statement function %qs requires argument list at %C"
-msgstr "Оператор функция '%s' требует список аргументов в %C"
+msgstr "Оператор функция %qs требует список аргументов в %C"
 
 #: fortran/primary.c:3380
-#, fuzzy, gcc-internal-format
-#| msgid "Function '%s' requires an argument list at %C"
+#, gcc-internal-format
 msgid "Function %qs requires an argument list at %C"
-msgstr "Функция '%s' требует список аргументов в %C"
+msgstr "Функция %qs требует список аргументов в %C"
 
 #: fortran/primary.c:3430
-#, fuzzy, gcc-internal-format
-#| msgid "Missing argument to '%s' at %C"
+#, gcc-internal-format
 msgid "Missing argument to %qs at %C"
-msgstr "Отсутствует аргумент для '%s' в %C"
+msgstr "Отсутствует аргумент для %qs в %C"
 
 #: fortran/primary.c:3443
 #, gcc-internal-format, gfc-internal-format
 msgid "The leftmost part-ref in a data-ref can not be a function reference at %C"
-msgstr ""
+msgstr "Самый левый part-ref в data-ref не может быть ссылкой на функцию в %C"
 
 #: fortran/primary.c:3597
-#, fuzzy, gcc-internal-format
-#| msgid "Missing argument list in function '%s' at %C"
+#, gcc-internal-format
 msgid "Missing argument list in function %qs at %C"
-msgstr "Отсутствует список аргументов в функции '%s' в %C"
+msgstr "Отсутствует список аргументов в функции %qs в %C"
 
 #: fortran/primary.c:3641
 #, gcc-internal-format, gfc-internal-format
@@ -65255,10 +58332,9 @@
 msgstr "Символ в %C не годится для выражения"
 
 #: fortran/primary.c:3711
-#, fuzzy, gcc-internal-format
-#| msgid "The name '%s' cannot be used as a defined operator at %C"
+#, gcc-internal-format
 msgid "Derived type %qs cannot be used as a variable at %C"
-msgstr "Имя '%s' не может быть использовано как определенный оператор в %C"
+msgstr "Производный тип %qs не может быть использован как переменная в %C"
 
 #: fortran/primary.c:3752
 #, gcc-internal-format, gfc-internal-format
@@ -65266,192 +58342,161 @@
 msgstr "Именованная константа в %C в EQUIVALENCE"
 
 #: fortran/primary.c:3787
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' at %C is not a variable"
+#, gcc-internal-format
 msgid "%qs at %C is not a variable"
-msgstr "'%s' в %C не есть переменная"
+msgstr "%qs в %C не является переменной"
 
 #: fortran/resolve.c:123
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' at %L is of the ABSTRACT type '%s'"
+#, gcc-internal-format
 msgid "%qs at %L is of the ABSTRACT type %qs"
-msgstr "'%s' в %L имеет ABSTRACT тип '%s'"
+msgstr "%qs в %L имеет ABSTRACT тип %qs"
 
 #: fortran/resolve.c:126
-#, fuzzy, gcc-internal-format
-#| msgid "ABSTRACT type '%s' used at %L"
+#, gcc-internal-format
 msgid "ABSTRACT type %qs used at %L"
-msgstr "ABSTRACT тип '%s' использован в %L"
+msgstr "ABSTRACT тип %qs использован в %L"
 
 #: fortran/resolve.c:143
-#, fuzzy, gcc-internal-format
-#| msgid "Interface '%s', used by procedure '%s' at %L, is declared in a later PROCEDURE statement"
+#, gcc-internal-format
 msgid "Interface %qs at %L is declared in a later PROCEDURE statement"
-msgstr "Интерфейс '%s', использованный процедурой '%s' at %L, декларирован в более позднем PROCEDURE операторе"
+msgstr "Интерфейс %qs в %L объявлен в более позднем PROCEDURE операторе"
 
 #: fortran/resolve.c:156
-#, fuzzy, gcc-internal-format
-#| msgid "Interface '%s' at %C may not be generic"
+#, gcc-internal-format
 msgid "Interface %qs at %L may not be generic"
-msgstr "Интерфейс '%s' в %C не может быть generic"
+msgstr "Интерфейс %qs в %L не может быть generic"
 
 #: fortran/resolve.c:163
-#, fuzzy, gcc-internal-format
-#| msgid "Interface '%s' at %C may not be a statement function"
+#, gcc-internal-format
 msgid "Interface %qs at %L may not be a statement function"
-msgstr "Интерфейс '%s' в %C не может быть оператором-функцией"
+msgstr "Интерфейс %qs в %L не может быть оператором-функцией"
 
 #: fortran/resolve.c:172
-#, fuzzy, gcc-internal-format
-#| msgid "Intrinsic procedure '%s' not allowed in PROCEDURE statement at %C"
+#, gcc-internal-format
 msgid "Intrinsic procedure %qs not allowed in PROCEDURE statement at %L"
-msgstr "Встроенная процедура '%s' не допускается в операторе PROCEDURE в %C"
+msgstr "Встроенная процедура %qs не допускается в операторе PROCEDURE в %L"
 
 #: fortran/resolve.c:178
-#, fuzzy, gcc-internal-format
-#| msgid "Interface '%s' of procedure '%s' at %L must be explicit"
+#, gcc-internal-format
 msgid "Interface %qs at %L must be explicit"
-msgstr "Интерфейс '%s' процедуры '%s' в %L должен быть явным"
+msgstr "Интерфейс %qs в %L должен быть явным"
 
 #: fortran/resolve.c:200
-#, fuzzy, gcc-internal-format
-#| msgid "PROCEDURE '%s' at %L may not be used as its own interface"
+#, gcc-internal-format
 msgid "PROCEDURE %qs at %L may not be used as its own interface"
-msgstr "PROCEDURE '%s' в %L не может быть использована в качестве своего собственного интерфейса"
+msgstr "PROCEDURE %qs в %L не может быть использована в качестве своего собственного интерфейса"
 
 #: fortran/resolve.c:300
-#, fuzzy, gcc-internal-format
-#| msgid "Alternate return specifier in elemental subroutine '%s' at %L is not allowed"
+#, gcc-internal-format
 msgid "Alternate return specifier in elemental subroutine %qs at %L is not allowed"
-msgstr "Спецификатор альтернативного возврата в элементной подпрограмме '%s' в %L не допускается"
+msgstr "Спецификатор альтернативного возврата в элементной подпрограмме %qs в %L не допускается"
 
 #: fortran/resolve.c:304
-#, fuzzy, gcc-internal-format
-#| msgid "Alternate return specifier in function '%s' at %L is not allowed"
+#, gcc-internal-format
 msgid "Alternate return specifier in function %qs at %L is not allowed"
-msgstr "Спецификатор альтернативного возврата в функции '%s' в %L не допускается"
+msgstr "Спецификатор альтернативного возврата в функции %qs в %L не допускается"
 
 #: fortran/resolve.c:315
-#, fuzzy, gcc-internal-format
-#| msgid "By-value argument at %L is not allowed in this context"
+#, gcc-internal-format
 msgid "Self-referential argument %qs at %L is not allowed"
-msgstr "Аргумент по значению в %L не допускается в этом контексте"
+msgstr "Ссылающийся на себя аргумент %qs в %L не допускается"
 
 #: fortran/resolve.c:387
-#, fuzzy, gcc-internal-format
-#| msgid "Dummy procedure '%s' of PURE procedure at %L must also be PURE"
+#, gcc-internal-format
 msgid "Dummy procedure %qs of PURE procedure at %L must also be PURE"
-msgstr "Формальная процедура '%s' PURE процедуры в %L должна также быть PURE"
+msgstr "Формальная процедура %qs PURE процедуры в %L должна также быть PURE"
 
 #: fortran/resolve.c:397
-#, fuzzy, gcc-internal-format
-#| msgid "Fortran 2008: Argument '%s' of pure function '%s' at %L with VALUE attribute but without INTENT(IN)"
+#, gcc-internal-format
 msgid "Argument %qs of pure function %qs at %L with VALUE attribute but without INTENT(IN)"
-msgstr "Fortran 2008: Аргумент '%s' pure функции '%s' в %L с VALUE атрибутом но без INTENT(IN)"
+msgstr "Аргумент %qs pure функции %qs в %L с VALUE атрибутом, но без INTENT(IN)"
 
 #: fortran/resolve.c:402
-#, fuzzy, gcc-internal-format
-#| msgid "Argument '%s' of pure function '%s' at %L must be INTENT(IN) or VALUE"
+#, gcc-internal-format
 msgid "Argument %qs of pure function %qs at %L must be INTENT(IN) or VALUE"
-msgstr "Аргумент '%s' pure функции '%s' в %L должен быть INTENT(IN) или VALUE"
+msgstr "Аргумент %qs pure функции %qs в %L должен быть INTENT(IN) или VALUE"
 
 #: fortran/resolve.c:410
-#, fuzzy, gcc-internal-format
-#| msgid "Fortran 2008: Argument '%s' of pure subroutine '%s' at %L with VALUE attribute but without INTENT"
+#, gcc-internal-format
 msgid "Argument %qs of pure subroutine %qs at %L with VALUE attribute but without INTENT"
-msgstr "Fortran 2008: Аргумент '%s' pure подпрограммы '%s' в %L с VALUE атрибутом но без INTENT"
+msgstr "Аргумент %qs pure подпрограммы %qs в %L с VALUE атрибутом, но без INTENT"
 
 #: fortran/resolve.c:415
-#, fuzzy, gcc-internal-format
-#| msgid "Argument '%s' of pure subroutine '%s' at %L must have its INTENT specified or have the VALUE attribute"
+#, gcc-internal-format
 msgid "Argument %qs of pure subroutine %qs at %L must have its INTENT specified or have the VALUE attribute"
-msgstr "Аргумент '%s' pure подпрограммы '%s' в %L должен иметь свой INTENT специфицированным или иметь VALUE атрибут"
+msgstr "Аргумент %qs pure подпрограммы %qs в %L должен иметь свой INTENT специфицированным или иметь VALUE атрибут"
 
 #: fortran/resolve.c:425
-#, fuzzy, gcc-internal-format
-#| msgid "Parameter '%s' to '%s' at %L must not be polymorphic"
+#, gcc-internal-format
 msgid "INTENT(OUT) argument %qs of pure procedure %qs at %L may not be polymorphic"
-msgstr "Параметр '%s' в '%s' в %L не должен быть полиморфным"
+msgstr "INTENT(OUT) argument %qs pure процедуры %qs в %L не может быть полиморфным"
 
 #: fortran/resolve.c:458
-#, fuzzy, gcc-internal-format
-#| msgid "Coarray dummy argument '%s' at %L to elemental procedure"
+#, gcc-internal-format
 msgid "Coarray dummy argument %qs at %L to elemental procedure"
-msgstr "Комассивный формальный аргумент '%s' в %L для элементной процедуры"
+msgstr "Комассивный формальный аргумент %qs в %L для элементной процедуры"
 
 #: fortran/resolve.c:466
-#, fuzzy, gcc-internal-format
-#| msgid "Argument '%s' of elemental procedure at %L must be scalar"
+#, gcc-internal-format
 msgid "Argument %qs of elemental procedure at %L must be scalar"
-msgstr "Аргумент '%s' элементной процедуры в %L должен быть скаляром"
+msgstr "Аргумент %qs элементной процедуры в %L должен быть скаляром"
 
 #: fortran/resolve.c:475
-#, fuzzy, gcc-internal-format
-#| msgid "Argument '%s' of elemental procedure at %L cannot have the ALLOCATABLE attribute"
+#, gcc-internal-format
 msgid "Argument %qs of elemental procedure at %L cannot have the ALLOCATABLE attribute"
-msgstr "Аргумент '%s' элементной процедуры в %L не может иметь ALLOCATABLE атрибут"
+msgstr "Аргумент %qs элементной процедуры в %L не может иметь ALLOCATABLE атрибут"
 
 #: fortran/resolve.c:485
-#, fuzzy, gcc-internal-format
-#| msgid "Argument '%s' of elemental procedure at %L cannot have the POINTER attribute"
+#, gcc-internal-format
 msgid "Argument %qs of elemental procedure at %L cannot have the POINTER attribute"
-msgstr "Аргумент '%s' элементной процедуры в %L не может иметь POINTER атрибут"
+msgstr "Аргумент %qs элементной процедуры в %L не может иметь POINTER атрибут"
 
 #: fortran/resolve.c:493
-#, fuzzy, gcc-internal-format
-#| msgid "Dummy procedure '%s' not allowed in elemental procedure '%s' at %L"
+#, gcc-internal-format
 msgid "Dummy procedure %qs not allowed in elemental procedure %qs at %L"
-msgstr "Формальная процедура '%s' не допускается в элементной процедуре '%s' в %L"
+msgstr "Формальная процедура %qs не допускается в элементной процедуре %qs в %L"
 
 #: fortran/resolve.c:502
-#, fuzzy, gcc-internal-format
-#| msgid "Argument '%s' of pure subroutine '%s' at %L must have its INTENT specified or have the VALUE attribute"
+#, gcc-internal-format
 msgid "Argument %qs of elemental procedure %qs at %L must have its INTENT specified or have the VALUE attribute"
-msgstr "Аргумент '%s' pure подпрограммы '%s' в %L должен иметь свой INTENT специфицированным или иметь VALUE атрибут"
+msgstr "Аргумент %qs pure подпрограммы %qs в %L должен иметь свой INTENT специфицированным или иметь VALUE атрибут"
 
 #. F03:C1263 (R1238) The function-name and each dummy-arg-name
 #. shall be specified, explicitly or implicitly, to be scalar.
 #: fortran/resolve.c:517
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Argument '%s' of statement function at %L must be scalar"
+#, gcc-internal-format, gfc-internal-format
 msgid "Argument '%s' of statement function '%s' at %L must be scalar"
-msgstr "Аргумент '%s' оператор функции в %L должен быть скаляром"
+msgstr "Аргумент '%s' функции-оператора '%s' в %L должен быть скаляром"
 
 #: fortran/resolve.c:528
-#, fuzzy, gcc-internal-format
-#| msgid "Character-valued argument '%s' of statement function at %L must have constant length"
+#, gcc-internal-format
 msgid "Character-valued argument %qs of statement function at %L must have constant length"
-msgstr "Аргумент с character значением '%s' оператор функции в %L должен иметь константную длину"
+msgstr "Аргумент с character значением %qs оператор функции в %L должен иметь константную длину"
 
 #: fortran/resolve.c:577
-#, fuzzy, gcc-internal-format
-#| msgid "INTERFACE procedure '%s' at %L has the same name as the enclosing procedure"
+#, gcc-internal-format
 msgid "Contained procedure %qs at %L has the same name as its encompassing procedure"
-msgstr "INTERFACE процедура '%s' в %L имеет то же имя что и объемлющая процедура"
+msgstr "Внутренняя процедура %qs в %L имеет то же имя, что и объемлющая процедура"
 
 #: fortran/resolve.c:594
-#, fuzzy, gcc-internal-format
-#| msgid "Contained function '%s' at %L has no IMPLICIT type"
+#, gcc-internal-format
 msgid "Contained function %qs at %L has no IMPLICIT type"
-msgstr "Внутренняя функция '%s' в %L не имеет IMPLICIT типа"
+msgstr "Внутренняя функция %qs в %L не имеет IMPLICIT тип"
 
 #: fortran/resolve.c:597
-#, fuzzy, gcc-internal-format
-#| msgid "Result '%s' of contained function '%s' at %L has no IMPLICIT type"
+#, gcc-internal-format
 msgid "Result %qs of contained function %qs at %L has no IMPLICIT type"
-msgstr "Результат '%s' внутренней функции '%s' в %L не имеет IMPLICIT типа"
+msgstr "Результат %qs внутренней функции %qs в %L не имеет IMPLICIT тип"
 
 #: fortran/resolve.c:622
-#, fuzzy, gcc-internal-format
-#| msgid "Character-valued %s '%s' at %L must not be assumed length"
+#, gcc-internal-format
 msgid "Character-valued module procedure %qs at %L must not be assumed length"
-msgstr "%s с character значением '%s' в %L не должен быть предполагаемой длины"
+msgstr "Процедура модуля с character значением %qs в %L не должна быть предполагаемой длины"
 
 #: fortran/resolve.c:624
-#, fuzzy, gcc-internal-format
-#| msgid "Character-valued %s '%s' at %L must not be assumed length"
+#, gcc-internal-format
 msgid "Character-valued internal function %qs at %L must not be assumed length"
-msgstr "%s с character значением '%s' в %L не должен быть предполагаемой длины"
+msgstr "Внутренняя функция с character значением %qs в %L не должна быть предполагаемой длины"
 
 #: fortran/resolve.c:796
 #, gcc-internal-format, gfc-internal-format
@@ -65459,10 +58504,9 @@
 msgstr "Функция %s в %L имеет входы с несоответствующими спецификациями массивов"
 
 #: fortran/resolve.c:813
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Extension: Function %s at %L with entries returning variables of different string lengths"
+#, gcc-internal-format, gfc-internal-format
 msgid "Function %s at %L with entries returning variables of different string lengths"
-msgstr "Расширение: Функция %s at %L с входами возвращающими переменные с разными длинами строк"
+msgstr "Функция %s at %L с входами, возвращающими переменные с разными длинами строк"
 
 #: fortran/resolve.c:840
 #, gcc-internal-format, gfc-internal-format
@@ -65495,96 +58539,84 @@
 msgstr "ENTRY результат %s не может быть типа %s в FUNCTION %s в %L"
 
 #: fortran/resolve.c:947
-#, fuzzy, gcc-internal-format
-#| msgid "Variable '%s' at %L is in COMMON but only in BLOCK DATA initialization is allowed"
+#, gcc-internal-format
 msgid "Variable %qs at %L is in COMMON but only in BLOCK DATA initialization is allowed"
-msgstr "Переменная '%s' в %L находится в COMMON но допустима только инициализация в BLOCK DATA"
+msgstr "Переменная %qs в %L находится в COMMON, но допустима только инициализация в BLOCK DATA"
 
 #: fortran/resolve.c:951
-#, fuzzy, gcc-internal-format
-#| msgid "Initialized variable '%s' at %L is in a blank COMMON but initialization is only allowed in named common blocks"
+#, gcc-internal-format
 msgid "Initialized variable %qs at %L is in a blank COMMON but initialization is only allowed in named common blocks"
-msgstr "Инициализированная переменная '%s' в %L находится в blank COMMON но инициализация допустима только в именованных common блоках"
+msgstr "Инициализированная переменная %qs в %L находится в безымянном COMMON, но инициализация допустима только в именованных common блоках"
 
 #: fortran/resolve.c:958
 #, gcc-internal-format
 msgid "%qs in cannot appear in COMMON at %L [F2008:C5100]"
-msgstr ""
+msgstr "%qs не может появляться в COMMON в %L [F2008:C5100]"
 
 #: fortran/resolve.c:966
-#, fuzzy, gcc-internal-format
-#| msgid "Derived type variable '%s' in COMMON at %L has neither the SEQUENCE nor the BIND(C) attribute"
+#, gcc-internal-format
 msgid "Derived type variable %qs in COMMON at %L has neither the SEQUENCE nor the BIND(C) attribute"
-msgstr "Переменная производного типа '%s' в COMMON в %L не имеет ни SEQUENCE ни BIND(C) атрибута"
+msgstr "Переменная производного типа %qs в COMMON в %L не имеет ни SEQUENCE ни BIND(C) атрибута"
 
 #: fortran/resolve.c:970
-#, fuzzy, gcc-internal-format
-#| msgid "Derived type variable '%s' in COMMON at %L has an ultimate component that is allocatable"
+#, gcc-internal-format
 msgid "Derived type variable %qs in COMMON at %L has an ultimate component that is allocatable"
-msgstr "Переменная производного типа '%s' в COMMON в %L имеет окончательный компонент который является размещаемым"
+msgstr "Переменная производного типа %qs в COMMON в %L имеет окончательный компонент, который является размещаемым"
 
 #: fortran/resolve.c:974
-#, fuzzy, gcc-internal-format
-#| msgid "Derived type variable '%s' in COMMON at %L may not have default initializer"
+#, gcc-internal-format
 msgid "Derived type variable %qs in COMMON at %L may not have default initializer"
-msgstr "Переменная производного типа '%s' в COMMON в %L не может иметь подразумеваемый инициализатор"
+msgstr "Переменная производного типа %qs в COMMON в %L не может иметь подразумеваемый инициализатор"
 
 #: fortran/resolve.c:1018
 #, gcc-internal-format
 msgid "In Fortran 2003 COMMON %qs block at %L is a global identifier and must thus have the same binding name as the same-named COMMON block at %L: %s vs %s"
-msgstr ""
+msgstr "В Fortran 2003 COMMON %qs блок в %L есть глобальный идентификатор и должен поэтому иметь то же связывающее имя, что и одноименный COMMON блок в %L: %s против %s"
 
 #: fortran/resolve.c:1032
-#, fuzzy, gcc-internal-format
-#| msgid "COMMON block '%s' at %L is used as PARAMETER at %L"
+#, gcc-internal-format
 msgid "COMMON block %qs at %L uses the same global identifier as entity at %L"
-msgstr "COMMON блок '%s' в %L использован как PARAMETER в %L"
+msgstr "COMMON блок %qs в %L использует тот же глобальный идентификатор, что и сущность в %L"
 
 #: fortran/resolve.c:1040
 #, gcc-internal-format
 msgid "Fortran 2008: COMMON block %qs with binding label at %L sharing the identifier with global non-COMMON-block entity at %L"
-msgstr ""
+msgstr "Fortran 2008: COMMON блок %qs со связывающей меткой в %L, разделяющий идентификатор с глобальной не-COMMON-блок сущностью в %L"
 
 #: fortran/resolve.c:1062
-#, fuzzy, gcc-internal-format
-#| msgid "Binding label '%s' at %L collides with the global entity '%s' at %L"
+#, gcc-internal-format
 msgid "COMMON block at %L with binding label %qs uses the same global identifier as entity at %L"
-msgstr "Связывающая метка '%s' в %L конфликтует с глобальной сущностью '%s' в %L"
+msgstr "COMMON блок в %L со связывающей меткой %qs использует тот же глобальный идентификатор, что и сущность в %L"
 
 #: fortran/resolve.c:1083
-#, fuzzy, gcc-internal-format
-#| msgid "COMMON block '%s' at %L is used as PARAMETER at %L"
+#, gcc-internal-format
 msgid "COMMON block %qs at %L is used as PARAMETER at %L"
-msgstr "COMMON блок '%s' в %L использован как PARAMETER в %L"
+msgstr "COMMON блок %qs в %L использован как PARAMETER в %L"
 
 #: fortran/resolve.c:1087
-#, fuzzy, gcc-internal-format
-#| msgid "COMMON block '%s' at %L can not have the EXTERNAL attribute"
+#, gcc-internal-format
 msgid "COMMON block %qs at %L can not have the EXTERNAL attribute"
-msgstr "COMMON блок '%s' в %L не может иметь EXTERNAL атрибут"
+msgstr "COMMON блок %qs в %L не может иметь EXTERNAL атрибут"
 
 #: fortran/resolve.c:1091
-#, fuzzy, gcc-internal-format
-#| msgid "COMMON block '%s' at %L is also an intrinsic procedure"
+#, gcc-internal-format
 msgid "COMMON block %qs at %L is also an intrinsic procedure"
-msgstr "COMMON блок '%s' в %L является также встроенной процедурой"
+msgstr "COMMON блок %qs в %L является также встроенной процедурой"
 
 #: fortran/resolve.c:1095
-#, fuzzy, gcc-internal-format
-#| msgid "Fortran 2003: COMMON block '%s' at %L that is also a function result"
+#, gcc-internal-format
 msgid "COMMON block %qs at %L that is also a function result"
-msgstr "Fortran 2003: COMMON блок '%s' в %L который является также результатом функции"
+msgstr "COMMON блок %qs в %L, который является также результатом функции"
 
 #: fortran/resolve.c:1100
-#, fuzzy, gcc-internal-format
-#| msgid "Fortran 2003: COMMON block '%s' at %L that is also a global procedure"
+#, gcc-internal-format
 msgid "COMMON block %qs at %L that is also a global procedure"
-msgstr "Fortran 2003: COMMON блок '%s' в %L который является также глобальной процедурой"
+msgstr "COMMON блок %qs в %L, который является также глобальной процедурой"
 
 #: fortran/resolve.c:1167
 #, gcc-internal-format
 msgid "The KIND parameter %qs in the PDT constructor at %C has no value"
-msgstr ""
+msgstr "У параметра KIND %qs в конструкторе PDT в %C отсутствует значение"
 
 #: fortran/resolve.c:1303
 #, gcc-internal-format, gfc-internal-format
@@ -65592,123 +58624,104 @@
 msgstr "Ранг элемента в конструкторе структуры в %L не соответствует рангу компонента (%d/%d)"
 
 #: fortran/resolve.c:1324
-#, fuzzy, gcc-internal-format
-#| msgid "The element in the structure constructor at %L, for pointer component '%s', is %s but should be %s"
+#, gcc-internal-format
 msgid "The element in the structure constructor at %L, for pointer component %qs, is %s but should be %s"
-msgstr "Элемент в конструкторе структуры в %L для компонента указателя '%s' есть %s но должен быть %s"
+msgstr "Элемент в конструкторе структуры в %L для компонента указателя %qs есть %s, но должен быть %s"
 
 #: fortran/resolve.c:1390
-#, fuzzy, gcc-internal-format
-#| msgid "The NULL in the structure constructor at %L is being applied to component '%s', which is neither a POINTER nor ALLOCATABLE"
+#, gcc-internal-format
 msgid "The NULL in the structure constructor at %L is being applied to component %qs, which is neither a POINTER nor ALLOCATABLE"
-msgstr "NULL в конструкторе структуры в %L применяется к компоненту '%s', который не является ни POINTER ни ALLOCATABLE"
+msgstr "NULL в конструкторе структуры в %L применяется к компоненту %qs, который не является ни POINTER ни ALLOCATABLE"
 
 #: fortran/resolve.c:1425
-#, fuzzy, gcc-internal-format
-#| msgid "Interface mismatch for procedure-pointer component '%s' in structure constructor at %L: %s"
+#, gcc-internal-format
 msgid "Interface mismatch for procedure-pointer component %qs in structure constructor at %L: %s"
-msgstr "Несоответствие интерфейса для компонента указателя на процедуру '%s' в конструкторе структуры в %L: %s"
+msgstr "Несоответствие интерфейса для компонента указателя на процедуру %qs в конструкторе структуры в %L: %s"
 
 #: fortran/resolve.c:1441
-#, fuzzy, gcc-internal-format
-#| msgid "The element in the structure constructor at %L, for pointer component '%s' should be a POINTER or a TARGET"
+#, gcc-internal-format
 msgid "The element in the structure constructor at %L, for pointer component %qs should be a POINTER or a TARGET"
-msgstr "Элемент в конструкторе структуры в %L для компонента указателя '%s' должен быть POINTER или TARGET"
+msgstr "Элемент в конструкторе структуры в %L для компонента указателя %qs должен быть POINTER или TARGET"
 
 #: fortran/resolve.c:1470
-#, fuzzy, gcc-internal-format
-#| msgid "Invalid expression in the structure constructor for pointer component '%s' at %L in PURE procedure"
+#, gcc-internal-format
 msgid "Invalid expression in the structure constructor for pointer component %qs at %L in PURE procedure"
-msgstr "Некорректное выражение в конструкторе структуры для компонента указателя '%s' в %L в PURE процедуре"
+msgstr "Некорректное выражение в конструкторе структуры для компонента указателя %qs в %L в PURE процедуре"
 
 #: fortran/resolve.c:1594
-#, fuzzy, gcc-internal-format
-#| msgid "The upper bound in the last dimension must appear in the reference to the assumed size array '%s' at %L"
+#, gcc-internal-format
 msgid "The upper bound in the last dimension must appear in the reference to the assumed size array %qs at %L"
-msgstr "Верхняя граница в последнем измерении должна появляться в ссылке на массив предполагаемого размера '%s' в %L"
+msgstr "Верхняя граница в последнем измерении должна появляться в ссылке на массив предполагаемого размера %qs в %L"
 
 #: fortran/resolve.c:1656
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' at %L is ambiguous"
+#, gcc-internal-format
 msgid "%qs at %L is ambiguous"
-msgstr "'%s' в %L неоднозначно"
+msgstr "%qs в %L неоднозначно"
 
 #: fortran/resolve.c:1660
-#, fuzzy, gcc-internal-format
-#| msgid "GENERIC procedure '%s' is not allowed as an actual argument at %L"
+#, gcc-internal-format
 msgid "GENERIC procedure %qs is not allowed as an actual argument at %L"
-msgstr "GENERIC процедура '%s' не допускается как фактический аргумент в %L"
+msgstr "GENERIC процедура %qs не допускается как фактический аргумент в %L"
 
 #: fortran/resolve.c:1781
-#, fuzzy, gcc-internal-format
-#| msgid "Type specified for intrinsic function '%s' at %L is ignored"
+#, gcc-internal-format
 msgid "Type specified for intrinsic function %qs at %L is ignored"
-msgstr "Тип специфицированный для встроенной функции '%s' в %L игнорируется"
+msgstr "Тип специфицированный для встроенной функции %qs в %L игнорируется"
 
 #: fortran/resolve.c:1794
-#, fuzzy, gcc-internal-format
-#| msgid "Intrinsic subroutine '%s' at %L shall not have a type specifier"
+#, gcc-internal-format
 msgid "Intrinsic subroutine %qs at %L shall not have a type specifier"
-msgstr "Встроенная подпрограмма '%s' в %L не должна иметь спецификатор типа"
+msgstr "Встроенная подпрограмма %qs в %L не должна иметь спецификатор типа"
 
 #: fortran/resolve.c:1805
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' declared INTRINSIC at %L does not exist"
+#, gcc-internal-format
 msgid "%qs declared INTRINSIC at %L does not exist"
-msgstr "'%s' декларированная INTRINSIC в %L не существует"
+msgstr "%qs декларированная INTRINSIC в %L не существует"
 
 #: fortran/resolve.c:1818
-#, fuzzy, gcc-internal-format
-#| msgid "The intrinsic '%s' declared INTRINSIC at %L is not available in the current standard settings but %s.  Use an appropriate -std=* option or enable -fall-intrinsics in order to use it."
+#, gcc-internal-format
 msgid "The intrinsic %qs declared INTRINSIC at %L is not available in the current standard settings but %s. Use an appropriate %<-std=*%> option or enable %<-fall-intrinsics%> in order to use it."
-msgstr "Встроенная '%s' декларированная INTRINSIC в %L недоступна в установках текущего стандарта кроме %s.  Используйте подходящую -std=* опцию или включите -fall-intrinsics чтобы использовать ее."
+msgstr "Встроенная %qs декларированная INTRINSIC в %L недоступна в установках текущего стандарта кроме %s. Используйте подходящую %<-std=*%> опцию или включите %<-fall-intrinsics%>, чтобы использовать её."
 
 #: fortran/resolve.c:1854
-#, fuzzy, gcc-internal-format
-#| msgid "Non-RECURSIVE procedure '%s' at %L is possibly calling itself recursively.  Declare it RECURSIVE or use -frecursive"
+#, gcc-internal-format
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
-msgstr "Non-RECURSIVE процедура '%s' в %L возможно вызывает себя рекурсивно.  Декларируйте ее RECURSIVE или используйте -frecursive"
+msgstr "Не-RECURSIVE процедура %qs в %L возможно вызывает себя рекурсивно.  Объявите её RECURSIVE или используйте %<-frecursive%>"
 
-#: fortran/resolve.c:1893 fortran/resolve.c:9560 fortran/resolve.c:11225
+#: fortran/resolve.c:1893 fortran/resolve.c:9573 fortran/resolve.c:11245
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "Метка %d используемая в %L нигде не определяется"
 
 #: fortran/resolve.c:1936
-#, fuzzy, gcc-internal-format
-#| msgid "Statement function '%s' at %L is not allowed as an actual argument"
+#, gcc-internal-format
 msgid "Statement function %qs at %L is not allowed as an actual argument"
-msgstr "Оператор функция '%s' в %L не допускается в качестве фактического аргумента"
+msgstr "Оператор функция %qs в %L не допускается в качестве фактического аргумента"
 
 #: fortran/resolve.c:1944
-#, fuzzy, gcc-internal-format
-#| msgid "Intrinsic '%s' at %L is not allowed as an actual argument"
+#, gcc-internal-format
 msgid "Intrinsic %qs at %L is not allowed as an actual argument"
-msgstr "Встроенная '%s' в %L не допускается в качестве фактического аргумента"
+msgstr "Встроенная %qs в %L не допускается в качестве фактического аргумента"
 
 #: fortran/resolve.c:1951
-#, fuzzy, gcc-internal-format
-#| msgid "Fortran 2008: Internal procedure '%s' is used as actual argument at %L"
+#, gcc-internal-format
 msgid "Internal procedure %qs is used as actual argument at %L"
-msgstr "Fortran 2008: Внутренняя процедура '%s' использована как фактический аргумент в %L"
+msgstr "Внутренняя процедура %qs использована как фактический аргумент в %L"
 
 #: fortran/resolve.c:1959
-#, fuzzy, gcc-internal-format
-#| msgid "ELEMENTAL non-INTRINSIC procedure '%s' is not allowed as an actual argument at %L"
+#, gcc-internal-format
 msgid "ELEMENTAL non-INTRINSIC procedure %qs is not allowed as an actual argument at %L"
-msgstr "ELEMENTAL non-INTRINSIC процедура '%s' не допускается в качестве фактического аргумента в %L"
+msgstr "ELEMENTAL не-INTRINSIC процедура %qs не допускается в качестве фактического аргумента в %L"
 
 #: fortran/resolve.c:1986
-#, fuzzy, gcc-internal-format
-#| msgid "Unable to find a specific INTRINSIC procedure for the reference '%s' at %L"
+#, gcc-internal-format
 msgid "Unable to find a specific INTRINSIC procedure for the reference %qs at %L"
-msgstr "Невозможно найти конкретную INTRINSIC процедуру для ссылки '%s' в %L"
+msgstr "Невозможно найти конкретную INTRINSIC процедуру для ссылки %qs в %L"
 
 #: fortran/resolve.c:2008
-#, fuzzy, gcc-internal-format
-#| msgid "Symbol '%s' at %L is ambiguous"
+#, gcc-internal-format
 msgid "Symbol %qs at %L is ambiguous"
-msgstr "Символ '%s' в %L неоднозначен"
+msgstr "Символ %qs в %L неоднозначен"
 
 #: fortran/resolve.c:2063
 #, gcc-internal-format, gfc-internal-format
@@ -65731,10 +58744,9 @@
 msgstr "Передача внутренней процедуры в %L по расположению не допускается"
 
 #: fortran/resolve.c:2107
-#, fuzzy, gcc-internal-format
-#| msgid "ELEMENTAL non-INTRINSIC procedure '%s' is not allowed as an actual argument at %L"
+#, gcc-internal-format
 msgid "ELEMENTAL procedure pointer component %qs is not allowed as an actual argument at %L"
-msgstr "ELEMENTAL non-INTRINSIC процедура '%s' не допускается в качестве фактического аргумента в %L"
+msgstr "Компонент указатель на ELEMENTAL процедуру %qs не допускается в качестве фактического аргумента в %L"
 
 #: fortran/resolve.c:2116
 #, gcc-internal-format, gfc-internal-format
@@ -65742,191 +58754,160 @@
 msgstr "Коиндексированный фактический аргумент в %L с окончательным компонентом указателем"
 
 #: fortran/resolve.c:2248
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' at %L is an array and OPTIONAL; IF IT IS MISSING, it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (12.4.1.5)"
+#, gcc-internal-format
 msgid "%qs at %L is an array and OPTIONAL; IF IT IS MISSING, it cannot be the actual argument of an ELEMENTAL procedure unless there is a non-optional argument with the same rank (12.4.1.5)"
-msgstr "'%s' в %L есть массив и OPTIONAL; ЕСЛИ ОН ОПУЩЕН, он не может быть фактическим аргументом ELEMENTAL процедуры кроме случая когда есть обязательный аргумент того же ранга (12.4.1.5)"
+msgstr "%qs в %L есть массив и OPTIONAL; ЕСЛИ ОН ОПУЩЕН, он не может быть фактическим аргументом ELEMENTAL процедуры кроме случая, когда есть обязательный аргумент того же ранга (12.4.1.5)"
 
 #: fortran/resolve.c:2285
-#, fuzzy, gcc-internal-format
-#| msgid "Actual argument at %L for INTENT(%s) dummy '%s' of ELEMENTAL subroutine '%s' is a scalar, but another actual argument is an array"
+#, gcc-internal-format
 msgid "Actual argument at %L for INTENT(%s) dummy %qs of ELEMENTAL subroutine %qs is a scalar, but another actual argument is an array"
-msgstr "Фактический аргумент в %L для INTENT(%s) формального параметра '%s' ELEMENTAL подпрограммы '%s' есть скаляр, но другой фактический аргумент является массивом"
+msgstr "Фактический аргумент в %L для INTENT(%s) формального параметра %qs ELEMENTAL подпрограммы %qs есть скаляр, но другой фактический аргумент является массивом"
 
 #: fortran/resolve.c:2557
-#, fuzzy, gcc-internal-format
-#| msgid "Return type mismatch of function '%s' at %L (%s/%s)"
+#, gcc-internal-format
 msgid "Return type mismatch of function %qs at %L (%s/%s)"
-msgstr "Несоответствие в возвращаемом типе функции '%s' в %L (%s/%s)"
+msgstr "Несоответствие возвращаемого типа функции %qs в %L (%s/%s)"
 
 #: fortran/resolve.c:2579
-#, fuzzy, gcc-internal-format
-#| msgid "Interface mismatch in dummy procedure '%s' at %L: %s"
+#, gcc-internal-format
 msgid "Interface mismatch in global procedure %qs at %L: %s"
-msgstr "Несоответствие интерфейса в формальной процедуре '%s' в %L: %s"
+msgstr "Несоответствие интерфейса в глобальной процедуре %qs в %L: %s"
 
 #: fortran/resolve.c:2692
-#, fuzzy, gcc-internal-format
-#| msgid "There is no specific function for the generic '%s' at %L"
+#, gcc-internal-format
 msgid "There is no specific function for the generic %qs at %L"
-msgstr "Нет конкретной функции для generic '%s' в %L"
+msgstr "Нет конкретной функции для generic %qs в %L"
 
 #: fortran/resolve.c:2712
-#, fuzzy, gcc-internal-format
-#| msgid "Generic function '%s' at %L is not consistent with a specific intrinsic interface"
+#, gcc-internal-format
 msgid "Generic function %qs at %L is not consistent with a specific intrinsic interface"
-msgstr "Generic функция '%s' в %L несовместима с конкретным встроенным интерфейсом"
+msgstr "Generic функция %qs в %L несовместима с конкретным встроенным интерфейсом"
 
 #: fortran/resolve.c:2750
-#, fuzzy, gcc-internal-format
-#| msgid "Function '%s' at %L is INTRINSIC but is not compatible with an intrinsic"
+#, gcc-internal-format
 msgid "Function %qs at %L is INTRINSIC but is not compatible with an intrinsic"
-msgstr "Функция '%s' в %L есть INTRINSIC но не является совместимой со встроенной"
+msgstr "Функция %qs в %L есть INTRINSIC, но не является совместимой со встроенной"
 
 #: fortran/resolve.c:2805
-#, fuzzy, gcc-internal-format
-#| msgid "Unable to resolve the specific function '%s' at %L"
+#, gcc-internal-format
 msgid "Unable to resolve the specific function %qs at %L"
-msgstr "Не удается разрешить конкретную функцию '%s' в %L"
+msgstr "Не удается разрешить конкретную функцию %qs в %L"
 
 #: fortran/resolve.c:2901
-#, fuzzy, gcc-internal-format
-#| msgid "Function '%s' at %L has no IMPLICIT type"
+#, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
-msgstr "Функция '%s' в %L не имеет IMPLICIT типа"
+msgstr "Функция %qs в %L не имеет IMPLICIT тип. Может имелось в виду %qs?"
 
-#: fortran/resolve.c:2905 fortran/resolve.c:16283
-#, fuzzy, gcc-internal-format
-#| msgid "Function '%s' at %L has no IMPLICIT type"
+#: fortran/resolve.c:2905 fortran/resolve.c:16310
+#, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
-msgstr "Функция '%s' в %L не имеет IMPLICIT типа"
+msgstr "Функция %qs в %L не имеет IMPLICIT тип"
 
 #: fortran/resolve.c:3014
-#, fuzzy, gcc-internal-format
-#| msgid "Reference to non-PURE function '%s' at %L inside a FORALL %s"
+#, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a FORALL %s"
-msgstr "Ссылка на non-PURE функцию '%s' в %L внутри FORALL %s"
+msgstr "Ссылка на impure функцию %qs в %L внутри FORALL %s"
 
 #: fortran/resolve.c:3021
-#, fuzzy, gcc-internal-format
-#| msgid "Reference to non-PURE function '%s' at %L inside a DO CONCURRENT %s"
+#, gcc-internal-format
 msgid "Reference to impure function %qs at %L inside a DO CONCURRENT %s"
-msgstr "Ссылка на non-PURE функцию '%s' в %L внутри DO CONCURRENT %s"
+msgstr "Ссылка на impure функцию %qs в %L внутри DO CONCURRENT %s"
 
 #: fortran/resolve.c:3028
-#, fuzzy, gcc-internal-format
-#| msgid "Reference to non-PURE function '%s' at %L inside a FORALL %s"
+#, gcc-internal-format
 msgid "Reference to impure function %qs at %L within a PURE procedure"
-msgstr "Ссылка на non-PURE функцию '%s' в %L внутри FORALL %s"
+msgstr "Ссылка на impure функцию %qs в %L внутри PURE процедуры"
 
 #: fortran/resolve.c:3098
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' at %L is not a function"
+#, gcc-internal-format
 msgid "%qs at %L is not a function"
-msgstr "'%s' в %L не есть функция"
+msgstr "%qs в %L не есть функция"
 
 #: fortran/resolve.c:3106 fortran/resolve.c:3576
-#, fuzzy, gcc-internal-format
-#| msgid "ABSTRACT INTERFACE '%s' must not be referenced at %L"
+#, gcc-internal-format
 msgid "ABSTRACT INTERFACE %qs must not be referenced at %L"
-msgstr "ABSTRACT INTERFACE '%s' не должна фигурировать в %L"
+msgstr "ABSTRACT INTERFACE %qs не должна фигурировать в %L"
 
 #. Internal procedures are taken care of in resolve_contained_fntype.
 #: fortran/resolve.c:3149
-#, fuzzy, gcc-internal-format
-#| msgid "Function '%s' is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
+#, gcc-internal-format
 msgid "Function %qs is declared CHARACTER(*) and cannot be used at %L since it is not a dummy argument"
-msgstr "Функция '%s' декларирована CHARACTER(*) и не может использоваться в %L поскольку это не формальный аргумент"
+msgstr "Функция %qs декларирована CHARACTER(*) и не может использоваться в %L, поскольку это не формальный аргумент"
 
 #: fortran/resolve.c:3183
-#, fuzzy, gcc-internal-format
-#| msgid "<unresolved overloaded function type>"
+#, gcc-internal-format
 msgid "resolve_function(): bad function type"
-msgstr "<неразрешенный тип перегруженной функции>"
+msgstr "resolve_function(): некорректный тип функции"
 
 #: fortran/resolve.c:3203
-#, fuzzy, gcc-internal-format
-#| msgid "User defined non-ELEMENTAL function '%s' at %L not allowed in WORKSHARE construct"
+#, gcc-internal-format
 msgid "User defined non-ELEMENTAL function %qs at %L not allowed in WORKSHARE construct"
-msgstr "Определенная пользователем non-ELEMENTAL функция '%s' в %L не допускается в WORKSHARE конструкции"
+msgstr "Определенная пользователем не-ELEMENTAL функция %qs в %L не допускается в WORKSHARE конструкции"
 
 #: fortran/resolve.c:3265
-#, fuzzy, gcc-internal-format
-#| msgid "ENTRY '%s' at %L cannot be called recursively, as function '%s' is not RECURSIVE"
+#, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as function %qs is not RECURSIVE"
-msgstr "ENTRY '%s' в %L не может вызываться рекурсивно, поскольку функция '%s' не есть RECURSIVE"
+msgstr "ENTRY %qs в %L не может вызываться рекурсивно, поскольку функция %qs не есть RECURSIVE"
 
 #: fortran/resolve.c:3269
-#, fuzzy, gcc-internal-format
-#| msgid "Function '%s' at %L cannot be called recursively, as it is not RECURSIVE"
+#, gcc-internal-format
 msgid "Function %qs at %L cannot be called recursively, as it is not RECURSIVE"
-msgstr "Функция '%s' в %L не может вызываться рекурсивно, поскольку она не есть RECURSIVE"
+msgstr "Функция %qs в %L не может вызываться рекурсивно, поскольку она не есть RECURSIVE"
 
 #: fortran/resolve.c:3320
-#, fuzzy, gcc-internal-format
-#| msgid "Subroutine call to '%s' in FORALL block at %L is not PURE"
+#, gcc-internal-format
 msgid "Subroutine call to %qs in FORALL block at %L is not PURE"
-msgstr "Вызов подпрограммы '%s' в FORALL блоке в %L не есть PURE"
+msgstr "Вызов подпрограммы %qs в FORALL блоке в %L не есть PURE"
 
 #: fortran/resolve.c:3326
-#, fuzzy, gcc-internal-format
-#| msgid "Subroutine call to '%s' in DO CONCURRENT block at %L is not PURE"
+#, gcc-internal-format
 msgid "Subroutine call to %qs in DO CONCURRENT block at %L is not PURE"
-msgstr "Вызов подпрограммы '%s' в DO CONCURRENT блоке в %L не есть PURE"
+msgstr "Вызов подпрограммы %qs в DO CONCURRENT блоке в %L не есть PURE"
 
 #: fortran/resolve.c:3332
-#, fuzzy, gcc-internal-format
-#| msgid "Subroutine call to '%s' at %L is not PURE"
+#, gcc-internal-format
 msgid "Subroutine call to %qs at %L is not PURE"
-msgstr "Вызов подпрограммы '%s' в %L не есть PURE"
+msgstr "Вызов подпрограммы %qs в %L не есть PURE"
 
 #: fortran/resolve.c:3400
-#, fuzzy, gcc-internal-format
-#| msgid "There is no specific subroutine for the generic '%s' at %L"
+#, gcc-internal-format
 msgid "There is no specific subroutine for the generic %qs at %L"
-msgstr "Нет конкретной подпрограммы для generic '%s' в %L"
+msgstr "Нет конкретной подпрограммы для generic %qs в %L"
 
 #: fortran/resolve.c:3409
-#, fuzzy, gcc-internal-format
-#| msgid "Generic subroutine '%s' at %L is not consistent with an intrinsic subroutine interface"
+#, gcc-internal-format
 msgid "Generic subroutine %qs at %L is not consistent with an intrinsic subroutine interface"
-msgstr "Generic подпрограмма '%s' в %L несовместима с интерфейсом встроенной подпрограммы"
+msgstr "Generic подпрограмма %qs в %L несовместима с интерфейсом встроенной подпрограммы"
 
 #: fortran/resolve.c:3444
-#, fuzzy, gcc-internal-format
-#| msgid "Subroutine '%s' at %L is INTRINSIC but is not compatible with an intrinsic"
+#, gcc-internal-format
 msgid "Subroutine %qs at %L is INTRINSIC but is not compatible with an intrinsic"
-msgstr "Подпрограмма '%s' в %L есть INTRINSIC но несовместима со встроенной"
+msgstr "Подпрограмма %qs в %L есть INTRINSIC, но несовместима со встроенной"
 
 #: fortran/resolve.c:3489
-#, fuzzy, gcc-internal-format
-#| msgid "Unable to resolve the specific subroutine '%s' at %L"
+#, gcc-internal-format
 msgid "Unable to resolve the specific subroutine %qs at %L"
-msgstr "Не удается разрешить конкретную подпрограмму '%s' в %L"
+msgstr "Не удается разрешить конкретную подпрограмму %qs в %L"
 
 #: fortran/resolve.c:3547
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' at %L has a type, which is not consistent with the CALL at %L"
+#, gcc-internal-format
 msgid "%qs at %L has a type, which is not consistent with the CALL at %L"
-msgstr "'%s' в %L имеет тип, который несовместим с CALL в %L"
+msgstr "%qs в %L имеет тип, который несовместим с CALL в %L"
 
 #: fortran/resolve.c:3586
-#, fuzzy, gcc-internal-format
-#| msgid "ENTRY '%s' at %L cannot be called recursively, as subroutine '%s' is not RECURSIVE"
+#, gcc-internal-format
 msgid "ENTRY %qs at %L cannot be called recursively, as subroutine %qs is not RECURSIVE"
-msgstr "ENTRY '%s' в %L не может вызываться рекурсивно, поскольку подпрограмма '%s' не есть RECURSIVE"
+msgstr "ENTRY %qs в %L не может вызываться рекурсивно, поскольку подпрограмма %qs не есть RECURSIVE"
 
 #: fortran/resolve.c:3590
-#, fuzzy, gcc-internal-format
-#| msgid "SUBROUTINE '%s' at %L cannot be called recursively, as it is not RECURSIVE"
+#, gcc-internal-format
 msgid "SUBROUTINE %qs at %L cannot be called recursively, as it is not RECURSIVE"
-msgstr "SUBROUTINE '%s' в %L не может вызываться рекурсивно, поскольку она не есть RECURSIVE"
+msgstr "SUBROUTINE %qs в %L не может вызываться рекурсивно, поскольку она не есть RECURSIVE"
 
 #: fortran/resolve.c:3635
-#, fuzzy, gcc-internal-format
-#| msgid "<unresolved overloaded function type>"
+#, gcc-internal-format
 msgid "resolve_subroutine(): bad function type"
-msgstr "<неразрешенный тип перегруженной функции>"
+msgstr "resolve_subroutine(): некорректный тип функции"
 
 #: fortran/resolve.c:3673
 #, gcc-internal-format, gfc-internal-format
@@ -65936,504 +58917,483 @@
 #: fortran/resolve.c:3725
 #, gcc-internal-format
 msgid "logical_to_bitwise(): Bad intrinsic"
-msgstr ""
+msgstr "logical_to_bitwise(): Некорректная встроенная функция"
 
-#: fortran/resolve.c:4059
+#: fortran/resolve.c:4065
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
-msgstr ""
+msgstr "resolve_operator(): Некорректная встроенная функция"
 
-#: fortran/resolve.c:4229 fortran/resolve.c:4252
+#: fortran/resolve.c:4235 fortran/resolve.c:4258
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
-msgstr ""
+msgstr "compare_bound_int(): Некорректное выражение"
 
-#: fortran/resolve.c:4347
+#: fortran/resolve.c:4353
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Ссылка на массив в %L вне диапазона (%ld < %ld) в измерении %d"
 
-#: fortran/resolve.c:4352
+#: fortran/resolve.c:4358
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr "Ссылка на массив в %L вне диапазона (%ld < %ld) в коизмерении %d"
 
-#: fortran/resolve.c:4362
+#: fortran/resolve.c:4368
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Ссылка на массив в %L вне диапазона (%ld > %ld) в измерении %d"
 
-#: fortran/resolve.c:4367
+#: fortran/resolve.c:4373
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr "Ссылка на массив в %L вне диапазона (%ld > %ld) в коизмерении %d"
 
-#: fortran/resolve.c:4387
+#: fortran/resolve.c:4393
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr "Некорректный нулевой шаг в %L"
 
-#: fortran/resolve.c:4404
+#: fortran/resolve.c:4410
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Нижняя ссылка на массив в %L вне диапазона (%ld < %ld) в измерении %d"
 
-#: fortran/resolve.c:4412
+#: fortran/resolve.c:4418
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Нижняя ссылка на массив в %L вне диапазона (%ld > %ld) в измерении %d"
 
-#: fortran/resolve.c:4428
+#: fortran/resolve.c:4434
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Верхняя ссылка на массив в %L вне диапазона (%ld < %ld) в измерении %d"
 
-#: fortran/resolve.c:4437
+#: fortran/resolve.c:4443
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Верхняя ссылка на массив в %L вне диапазона (%ld > %ld) в измерении %d"
 
-#: fortran/resolve.c:4453
-#, fuzzy, gcc-internal-format
-#| msgid "subscript missing in array reference"
+#: fortran/resolve.c:4459
+#, gcc-internal-format
 msgid "check_dimension(): Bad array reference"
-msgstr "отсутствует индекс массива"
+msgstr "check_dimension(): Некорректная ссылка на массив"
 
-#: fortran/resolve.c:4476
+#: fortran/resolve.c:4482
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr "Самая правая верхняя граница секции массива предполагаемой формы не задана в %L"
 
-#: fortran/resolve.c:4486
+#: fortran/resolve.c:4492
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr "Несоответствие рангов в ссылке на массив в %L (%d/%d)"
 
-#: fortran/resolve.c:4494
+#: fortran/resolve.c:4500
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr "Несоответствие коиндексных рангов в ссылке на массив в %L (%d/%d)"
 
-#: fortran/resolve.c:4510
+#: fortran/resolve.c:4516
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr "Коиндекс коразмерности %d должен быть скаляром в %L"
 
-#: fortran/resolve.c:4538
+#: fortran/resolve.c:4544
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr "Индекс массива в %L должен быть скаляром"
 
-#: fortran/resolve.c:4544
+#: fortran/resolve.c:4550
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr "Индекс массива в %L должен быть INTEGER типа, найдено %s"
 
-#: fortran/resolve.c:4550
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Extension: REAL array index at %L"
+#: fortran/resolve.c:4556
+#, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
-msgstr "Расширение: REAL индекс массива в %L"
+msgstr "REAL индекс массива в %L"
 
-#: fortran/resolve.c:4589
+#: fortran/resolve.c:4595
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr "Аргумент dim в %L должен быть скаляром"
 
-#: fortran/resolve.c:4596
+#: fortran/resolve.c:4602
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr "Аргумент dim в %L должен быть INTEGER типа"
 
-#: fortran/resolve.c:4641
+#: fortran/resolve.c:4647
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
-msgstr ""
+msgstr "find_array_spec(): Отсутствует спецификация"
 
-#: fortran/resolve.c:4652
+#: fortran/resolve.c:4658
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
-msgstr ""
+msgstr "find_array_spec(): неиспользуемый as(1)"
 
-#: fortran/resolve.c:4663
+#: fortran/resolve.c:4669
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
-msgstr ""
+msgstr "find_array_spec(): неиспользуемый as(2)"
 
-#: fortran/resolve.c:4706
+#: fortran/resolve.c:4712
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr "Индекс массива в %L является массивом ранга %d"
 
-#: fortran/resolve.c:4804
+#: fortran/resolve.c:4810
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr "Начальный индекс подстроки в %L должен быть типа INTEGER"
 
-#: fortran/resolve.c:4811
+#: fortran/resolve.c:4817
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr "Начальный индекс подстроки в %L должен быть скаляром"
 
-#: fortran/resolve.c:4820
+#: fortran/resolve.c:4826
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr "Начальный индекс подстроки в %L меньше единицы"
 
-#: fortran/resolve.c:4833
+#: fortran/resolve.c:4839
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr "Конечный индекс подстроки в %L должен быть типа INTEGER"
 
-#: fortran/resolve.c:4840
+#: fortran/resolve.c:4846
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr "Конечный индекс подстроки в %L должен быть скаляром"
 
-#: fortran/resolve.c:4850
+#: fortran/resolve.c:4856
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr "Конечный индекс подстроки в %L превышает длину строки"
 
-#: fortran/resolve.c:4860
+#: fortran/resolve.c:4866
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr "Конечный индекс подстроки в %L слишком велик"
 
-#: fortran/resolve.c:5013
-#, fuzzy, gcc-internal-format
-#| msgid "Bad array reference at %L"
+#: fortran/resolve.c:5019
+#, gcc-internal-format
 msgid "resolve_ref(): Bad array reference"
-msgstr "Некорректная ссылка на массив в %L"
+msgstr "resolve_ref(): Некорректная ссылка на массив"
 
-#: fortran/resolve.c:5027
+#: fortran/resolve.c:5033
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr "Компонент справа от частичной ссылки с ненулевым рангом не должен иметь POINTER атрибут в %L"
 
-#: fortran/resolve.c:5037
+#: fortran/resolve.c:5043
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr "Компонент справа от частичной ссылки с ненулевым рангом не должен иметь ALLOCATABLE атрибут в %L"
 
-#: fortran/resolve.c:5056
+#: fortran/resolve.c:5062
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr "Две или больше частичные ссылки с ненулевым рангом не должны быть заданы в %L"
 
-#: fortran/resolve.c:5154
+#: fortran/resolve.c:5160
 #, gcc-internal-format
 msgid "expression_rank(): Two array specs"
-msgstr ""
+msgstr "expression_rank(): Две спецификации массива"
 
-#: fortran/resolve.c:5236
+#: fortran/resolve.c:5242
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
-msgstr ""
+msgstr "Переменная %s в %L с NO_ARG_CHECK атрибутом может использоваться только как фактический аргумент"
 
-#: fortran/resolve.c:5246
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Assumed shape array at %L must be a dummy argument"
+#: fortran/resolve.c:5252
+#, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
-msgstr "Массив предполагаемой формы в %L должен быть формальным аргументом"
+msgstr "Переменная предполагаемого типа %s в %L может использоваться только как фактический аргумент"
 
 #. FIXME: It doesn't work reliably as inquiry_argument is not set
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5256
+#: fortran/resolve.c:5262
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
-msgstr ""
+msgstr "Переменная предполагаемого типа %s в %L как фактический аргумент для inquiry функции должна быть первым аргументом"
 
-#: fortran/resolve.c:5271
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Assumed shape array at %L must be a dummy argument"
+#: fortran/resolve.c:5277
+#, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
-msgstr "Массив предполагаемой формы в %L должен быть формальным аргументом"
+msgstr "Переменная предполагаемого ранга %s в %L может использоваться только как фактический аргумент"
 
 #. FIXME: It doesn't work reliably as inquiry_argument is not set
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5281
+#: fortran/resolve.c:5287
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
-msgstr ""
+msgstr "Переменная предполагаемого ранга %s в %L как фактический аргумент для inquiry функции должна быть первым аргументом"
 
-#: fortran/resolve.c:5292
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Procedure '%s' at %L with BIND(C) attribute must have an explicit interface"
+#: fortran/resolve.c:5298
+#, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
-msgstr "Процедура '%s' в %L с BIND(C) атрибутом должна иметь явный интерфейс"
+msgstr "Переменная %s в %L с NO_ARG_CHECK атрибутом не должна иметь ссылку на подобъект"
 
-#: fortran/resolve.c:5301
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Coarray variable '%s' at %L shall not have codimensions with deferred shape"
+#: fortran/resolve.c:5307
+#, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
-msgstr "Комассивная переменная '%s' в %L не должна иметь коизмерения с отложенной формой"
+msgstr "Переменная предполагаемого типа %s в %L не должна иметь ссылку на подобъект"
 
-#: fortran/resolve.c:5316
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Coarray variable '%s' at %L shall not have codimensions with deferred shape"
+#: fortran/resolve.c:5322
+#, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
-msgstr "Комассивная переменная '%s' в %L не должна иметь коизмерения с отложенной формой"
+msgstr "Переменная предполагаемого ранга %s в %L не должна иметь ссылку на подобъект"
 
-#: fortran/resolve.c:5478
-#, fuzzy, gcc-internal-format
-#| msgid "Variable '%s', used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
+#: fortran/resolve.c:5484
+#, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
-msgstr "Переменная '%s', использованная в спецификационном выражении, фигурирует в %L до ENTRY оператора в котором она является параметром"
+msgstr "Переменная %qs, использованная в спецификационном выражении, фигурирует в %L до ENTRY оператора, в котором она является параметром"
 
-#: fortran/resolve.c:5483
-#, fuzzy, gcc-internal-format
-#| msgid "Variable '%s' is used at %L before the ENTRY statement in which it is a parameter"
+#: fortran/resolve.c:5489
+#, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
-msgstr "Переменная '%s' используется в %L до оператора ENTRY, в котором она является параметром"
+msgstr "Переменная %qs используется в %L до оператора ENTRY, в котором она является параметром"
 
-#: fortran/resolve.c:5553
+#: fortran/resolve.c:5559
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr "Полиморфный подобъект коиндексированного объекта в %L"
 
-#: fortran/resolve.c:5566
+#: fortran/resolve.c:5572
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr "Коиндексированный объект с полиморфным размещаемым подкомпонентом в %L"
 
-#: fortran/resolve.c:5919
+#: fortran/resolve.c:5925
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "Передаваемый объект в %L должен быть скаляром"
 
-#: fortran/resolve.c:5926
-#, fuzzy, gcc-internal-format
-#| msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type '%s'"
+#: fortran/resolve.c:5932
+#, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
-msgstr "Базовый объект для вызова компонента указателя на процедуру в %L имеет ABSTRACT тип '%s'"
+msgstr "Базовый объект для вызова компонента указателя на процедуру в %L имеет ABSTRACT тип %qs'"
 
-#: fortran/resolve.c:5961
-#, fuzzy, gcc-internal-format
-#| msgid "Base object for type-bound procedure call at %L is of ABSTRACT type '%s'"
+#: fortran/resolve.c:5967
+#, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
-msgstr "Базовый объект для вызова type-bound процедуры в %L имеет ABSTRACT тип '%s'"
+msgstr "Базовый объект для вызова type-bound процедуры в %L имеет ABSTRACT тип %qs"
 
-#: fortran/resolve.c:5970
+#: fortran/resolve.c:5976
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr "Базовый объект для вызова NOPASS type-bound процедуры в %L должен быть скаляром"
 
 #. Nothing matching found!
-#: fortran/resolve.c:6158
-#, fuzzy, gcc-internal-format
-#| msgid "Found no matching specific binding for the call to the GENERIC '%s' at %L"
+#: fortran/resolve.c:6164
+#, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
-msgstr "Не найдено подходящего конкретного связывания для вызова GENERIC '%s' в %L"
+msgstr "Не найдено подходящего конкретного связывания для вызова GENERIC %qs в %L"
 
-#: fortran/resolve.c:6185
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' at %L should be a SUBROUTINE"
+#: fortran/resolve.c:6191
+#, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
-msgstr "'%s' в %L должна быть SUBROUTINE"
+msgstr "%qs в %L должна быть SUBROUTINE"
 
-#: fortran/resolve.c:6236
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' at %L should be a FUNCTION"
+#: fortran/resolve.c:6242
+#, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
-msgstr "'%s' в %L должна быть FUNCTION"
+msgstr "%qs в %L должна быть FUNCTION"
 
-#: fortran/resolve.c:6786
-#, fuzzy, gcc-internal-format
-#| msgid "Expected expression type"
+#: fortran/resolve.c:6792
+#, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
-msgstr "Ожидался тип выражения"
+msgstr "gfc_resolve_expr(): Некорректный тип выражения"
 
-#: fortran/resolve.c:6812
+#: fortran/resolve.c:6818
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "'%s' в %L должна быть скаляром"
 
-#: fortran/resolve.c:6822
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "'%s' at %L must be nonnegative"
+#: fortran/resolve.c:6828
+#, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
-msgstr "'%s' в %L должен быть неотрицательным"
+msgstr "%s в %L должен быть integer"
 
-#: fortran/resolve.c:6826 fortran/resolve.c:6833
+#: fortran/resolve.c:6832 fortran/resolve.c:6839
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s в %L должна быть INTEGER"
 
-#: fortran/resolve.c:6875
+#: fortran/resolve.c:6881
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "Шаговое выражение в DO цикле в %L не может быть нулевым"
 
-#: fortran/resolve.c:6911
+#: fortran/resolve.c:6917
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr "DO цикл в %L будет выполнен ноль раз"
 
-#: fortran/resolve.c:6928
+#: fortran/resolve.c:6934
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
-msgstr ""
+msgstr "DO цикл в %L является неопределенным, так как он переполняется"
 
-#: fortran/resolve.c:6934
+#: fortran/resolve.c:6940
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
-msgstr ""
+msgstr "DO цикл в %L является неопределенным, так как он теряет значимость"
 
-#: fortran/resolve.c:6995
+#: fortran/resolve.c:7001
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "FORALL индекс-имя в %L должно быть скалярным INTEGER"
 
-#: fortran/resolve.c:7000
+#: fortran/resolve.c:7006
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "FORALL стартовое выражение в %L должно быть скалярным INTEGER"
 
-#: fortran/resolve.c:7007
+#: fortran/resolve.c:7013
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "FORALL конечное выражение в %L должно быть скалярным INTEGER"
 
-#: fortran/resolve.c:7015
+#: fortran/resolve.c:7021
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "FORALL шаговое выражение в %L должно быть скаляром %s"
 
-#: fortran/resolve.c:7020
+#: fortran/resolve.c:7026
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "FORALL шаговое выражение в %L не может быть нулевым"
 
-#: fortran/resolve.c:7033
-#, fuzzy, gcc-internal-format
-#| msgid "FORALL index '%s' may not appear in triplet specification at %L"
+#: fortran/resolve.c:7039
+#, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
-msgstr "FORALL индекс '%s' не может появляться в спецификации триплета в %L"
+msgstr "FORALL индекс %qs не может появляться в спецификации триплета в %L"
 
-#: fortran/resolve.c:7136 fortran/resolve.c:7428
+#: fortran/resolve.c:7142 fortran/resolve.c:7434
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "Allocate-object в %L должен быть ALLOCATABLE или POINTER"
 
-#: fortran/resolve.c:7144 fortran/resolve.c:7393
+#: fortran/resolve.c:7150 fortran/resolve.c:7399
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr "Коиндексированный размещаемый объект в %L"
 
-#: fortran/resolve.c:7250
+#: fortran/resolve.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
-msgstr "Source-expr в %L должно быть скалярным или иметь тот же ранг что и allocate-object в %L"
+msgstr "Source-expr в %L должно быть скалярным или иметь тот же ранг, что и allocate-object в %L"
 
-#: fortran/resolve.c:7281
+#: fortran/resolve.c:7287
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr "Source-expr в %L и allocate-object в %L должны иметь одинаковую форму"
 
-#: fortran/resolve.c:7439
+#: fortran/resolve.c:7445
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr "Тип сущности в %L есть тип несовместимый с source-expr в %L"
 
-#: fortran/resolve.c:7451
+#: fortran/resolve.c:7457
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr "Allocate-object в %L и source-expr в %L должны иметь одинаковый вид параметра типа"
 
-#: fortran/resolve.c:7465
+#: fortran/resolve.c:7471
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
-msgstr "Source-expr в %L не должно быть типа LOCK_TYPE и не должно иметь LOCK_TYPE компонент если allocate-object в %L является комассивом"
+msgstr "Source-expr в %L не должно быть типа LOCK_TYPE и не должно иметь LOCK_TYPE компонент, если allocate-object в %L является комассивом"
 
-#: fortran/resolve.c:7480
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
+#: fortran/resolve.c:7486
+#, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
-msgstr "Source-expr в %L не должно быть типа LOCK_TYPE и не должно иметь LOCK_TYPE компонент если allocate-object в %L является комассивом"
+msgstr "Source-expr в %L не должно быть типа EVENT_TYPE и не должно иметь EVENT_TYPE компонент, если allocate-object в %L является комассивом"
 
-#: fortran/resolve.c:7493
+#: fortran/resolve.c:7499
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr "Размещение %s ABSTRACT базового типа в %L требует type-spec или source-expr"
 
-#: fortran/resolve.c:7511
+#: fortran/resolve.c:7517
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
-msgstr "Размещение %s в %L с type-spec требует того же character-length параметра что и в декларации"
+msgstr "Размещение %s в %L с type-spec требует того же character-length параметра, что и в декларации"
 
-#: fortran/resolve.c:7592 fortran/resolve.c:7607
+#: fortran/resolve.c:7598 fortran/resolve.c:7613
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "Спецификация массива требуется в ALLOCATE операторе в %L"
 
-#: fortran/resolve.c:7599
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Array specification required in ALLOCATE statement at %L"
+#: fortran/resolve.c:7605
+#, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
-msgstr "Спецификация массива требуется в ALLOCATE операторе в %L"
+msgstr "Спецификация массива или SOURCE= выражение со значением массивом требуется в ALLOCATE операторе в %L"
 
-#: fortran/resolve.c:7622
+#: fortran/resolve.c:7628
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "Спецификация комассива требуется в ALLOCATE операторе в %L"
 
-#: fortran/resolve.c:7649
+#: fortran/resolve.c:7655
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "Некорректная спецификация массива в ALLOCATE операторе в %L"
 
-#: fortran/resolve.c:7668
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
+#: fortran/resolve.c:7674
+#, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
-msgstr "'%s' не должно появляться в спецификации массива в %L в том же ALLOCATE операторе где оно само размещается"
+msgstr "%qs не должно появляться в спецификации массива в %L в том же ALLOCATE операторе где оно само размещается"
 
-#: fortran/resolve.c:7683
+#: fortran/resolve.c:7689
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr "Ожидалась '*' в спецификации коиндекса в ALLOCATE операторе в %L"
 
-#: fortran/resolve.c:7694
+#: fortran/resolve.c:7700
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "Некорректная спецификация комассива в ALLOCATE операторе в %L"
 
-#: fortran/resolve.c:7726
+#: fortran/resolve.c:7732
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "Stat-variable в %L должна быть скалярной INTEGER переменной"
 
-#: fortran/resolve.c:7749
+#: fortran/resolve.c:7755
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "Stat-variable в %L не должна быть %sd в том же %s операторе"
 
-#: fortran/resolve.c:7760
+#: fortran/resolve.c:7766
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr "ERRMSG в %L бесполезно без STAT тега"
 
-#: fortran/resolve.c:7771
+#: fortran/resolve.c:7782
 #, gcc-internal-format, gfc-internal-format
-msgid "Errmsg-variable at %L must be a scalar CHARACTER variable"
-msgstr "Errmsg-variable в %L должна быть скалярной CHARACTER переменной"
+msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
+msgstr "ERRMSG переменная в %L должна быть стандартной скалярной CHARACTER переменной"
 
-#: fortran/resolve.c:7794
+#: fortran/resolve.c:7805
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
-msgstr "Errmsg-variable в %L не должна быть %sd в том же %s операторе"
+msgstr "Переменная Errmsg в %L не должна быть %sd в том же операторе %s"
 
-#: fortran/resolve.c:7824
+#: fortran/resolve.c:7835
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr "Allocate-object в %L также появляется в %L"
 
-#: fortran/resolve.c:7830 fortran/resolve.c:7836
+#: fortran/resolve.c:7841 fortran/resolve.c:7847
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr "Allocate-object в %L есть подобъект объекта в %L"
@@ -66442,249 +59402,232 @@
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8064
+#: fortran/resolve.c:8075
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "CASE метка в %L перекрывается с CASE меткой в %L"
 
-#: fortran/resolve.c:8115
+#: fortran/resolve.c:8126
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "Выражение в CASE операторе в %L должно быть типа %s"
 
-#: fortran/resolve.c:8126
+#: fortran/resolve.c:8137
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "Выражение в CASE операторе в %L должно быть вида %d"
 
-#: fortran/resolve.c:8139
+#: fortran/resolve.c:8150
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "Выражение в CASE операторе в %L должно быть скаляром"
 
-#: fortran/resolve.c:8185
+#: fortran/resolve.c:8196
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "Выражение выбора в вычисляемом GOTO операторе в %L должно быть скалярным integer выражением"
 
-#: fortran/resolve.c:8204
+#: fortran/resolve.c:8215
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "Аргумент SELECT оператора в %L не может быть %s"
 
-#: fortran/resolve.c:8214
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Argument of SELECT statement at %L cannot be %s"
+#: fortran/resolve.c:8225
+#, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
-msgstr "Аргумент SELECT оператора в %L не может быть %s"
+msgstr "Аргумент SELECT оператора в %L не может быть скалярным выражением"
 
-#: fortran/resolve.c:8232 fortran/resolve.c:8240
+#: fortran/resolve.c:8243 fortran/resolve.c:8251
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "Выражение в CASE операторе в %L не находится в диапазоне %s"
 
-#: fortran/resolve.c:8302 fortran/resolve.c:8873
+#: fortran/resolve.c:8313 fortran/resolve.c:8884
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "За DEFAULT CASE в %L не может следовать второй DEFAULT CASE в %L"
 
-#: fortran/resolve.c:8328
+#: fortran/resolve.c:8339
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "Логический диапазон в CASE операторе в %L не допускается"
 
-#: fortran/resolve.c:8340
+#: fortran/resolve.c:8351
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "Константное логическое значение в CASE операторе повторяется в %L"
 
-#: fortran/resolve.c:8355
+#: fortran/resolve.c:8366
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "Спецификации диапазона в %L невозможно найти соответствие"
 
-#: fortran/resolve.c:8458
+#: fortran/resolve.c:8469
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "Логический SELECT CASE блок в %L имеет более двух случаев"
 
-#: fortran/resolve.c:8518
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Association target at %C must not be coindexed"
+#: fortran/resolve.c:8529
+#, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
-msgstr "Цель ассоциации в %C не должна быть коиндексирована"
+msgstr "Селектор в %L не может быть NULL()"
 
-#: fortran/resolve.c:8523
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Association target at %C must not be coindexed"
+#: fortran/resolve.c:8534
+#, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
-msgstr "Цель ассоциации в %C не должна быть коиндексирована"
+msgstr "Селектор в %L не имеет типа"
 
-#: fortran/resolve.c:8545
-#, fuzzy, gcc-internal-format
-#| msgid "Associate-name '%s' at %L is used as array"
+#: fortran/resolve.c:8556
+#, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
-msgstr "Associate-name '%s' в %L используется как массив"
+msgstr "Имя ассоциации %qs в %L используется как массив"
 
-#: fortran/resolve.c:8556
+#: fortran/resolve.c:8567
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
-msgstr ""
+msgstr "CLASS селектор в %L требует временной переменной, которая пока не реализована"
 
-#: fortran/resolve.c:8763
+#: fortran/resolve.c:8774
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "Селектор должен быть полиморфным в SELECT TYPE операторе в %L"
 
-#: fortran/resolve.c:8783 fortran/resolve.c:8795
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Association target at %C must not be coindexed"
+#: fortran/resolve.c:8794 fortran/resolve.c:8806
+#, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
-msgstr "Цель ассоциации в %C не должна быть коиндексирована"
+msgstr "Селектор в %L не должен быть коиндексирован"
 
-#: fortran/resolve.c:8824
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "CASE label at %L overlaps with CASE label at %L"
+#: fortran/resolve.c:8835
+#, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
-msgstr "CASE метка в %L перекрывается с CASE меткой в %L"
+msgstr "TYPE IS в %L перекрывается с TYPE IS в %L"
 
-#: fortran/resolve.c:8836
-#, fuzzy, gcc-internal-format
-#| msgid "Derived type '%s' at %L must be extensible"
+#: fortran/resolve.c:8847
+#, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
-msgstr "Производный тип '%s' в %L должен быть расширяемым"
+msgstr "Производный тип %qs в %L должен быть расширяемым"
 
-#: fortran/resolve.c:8848
-#, fuzzy, gcc-internal-format
-#| msgid "Derived type '%s' at %L must be an extension of '%s'"
+#: fortran/resolve.c:8859
+#, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
-msgstr "Производный тип '%s' в %L должен быть расширением '%s'"
+msgstr "Производный тип %qs в %L должен быть расширением %qs"
 
-#: fortran/resolve.c:8851
-#, fuzzy, gcc-internal-format
-#| msgid "Unexpected NULL() intrinsic at %L to dummy '%s'"
+#: fortran/resolve.c:8862
+#, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
-msgstr "Неожиданная NULL() встроенная в %L в формальный параметр '%s'"
+msgstr "Неожиданный встроенный тип %qs в %L"
 
-#: fortran/resolve.c:8861
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Type-spec at %L cannot contain a deferred type parameter"
+#: fortran/resolve.c:8872
+#, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
-msgstr "Type-spec в %L не может содержать параметр отложенного типа"
+msgstr "Спецификация типа в %L должна специфицировать, что каждый параметр длины типа является предполагаемым"
 
-#: fortran/resolve.c:9108
+#: fortran/resolve.c:9119
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr "Двойной CLASS IS блок в SELECT TYPE операторе в %L"
 
-#: fortran/resolve.c:9204
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Invalid context for NULL() pointer at %%L"
+#: fortran/resolve.c:9215
+#, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
-msgstr "Некорректный контекст для NULL() указателя в %%L"
+msgstr "Некорректный контекст для NULL () встроенной в %L"
 
-#: fortran/resolve.c:9257
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "STOP code at %L must be scalar"
+#: fortran/resolve.c:9268
+#, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
-msgstr "STOP код в %L должен быть скаляром"
+msgstr "DTIO %s процедура в %L должна быть рекурсивной"
 
-#: fortran/resolve.c:9267
+#: fortran/resolve.c:9278
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
-msgstr "Элемент передачи данных в %L не может быть полиморфным если только он не обрабатывается определенной процедурой ввода/вывода"
+msgstr "Элемент передачи данных в %L не может быть полиморфным, если только он не обрабатывается определенной процедурой ввода/вывода"
 
-#: fortran/resolve.c:9280
+#: fortran/resolve.c:9291
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
-msgstr "Элемент передачи данных в %L не может иметь POINTER компоненты если только он не обрабатывается определенной процедурой ввода/вывода"
+msgstr "Элемент передачи данных в %L не может иметь POINTER компоненты, если только он не обрабатывается определенной процедурой ввода/вывода"
 
-#: fortran/resolve.c:9289
+#: fortran/resolve.c:9300
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "Элемент передачи данных в %L не может иметь компоненты указатели на процедуру"
 
-#: fortran/resolve.c:9296
+#: fortran/resolve.c:9307
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "Элемент передачи данных в %L не может иметь ALLOCATABLE компоненты если только он не обрабатывается определенной процедурой ввода/вывода"
 
-#: fortran/resolve.c:9307
+#: fortran/resolve.c:9318
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "Элемент передачи данных в %L не может иметь PRIVATE компоненты"
 
-#: fortran/resolve.c:9313
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
+#: fortran/resolve.c:9324
+#, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
-msgstr "Элемент передачи данных в %L не может иметь POINTER компоненты если только он не обрабатывается определенной процедурой ввода/вывода"
+msgstr "Элемент передачи данных в %L не может иметь PRIVATE компоненты, если только он не обрабатывается определенной процедурой ввода/вывода"
 
-#: fortran/resolve.c:9328
+#: fortran/resolve.c:9339
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "Элемент передачи данных в %L не может быть полной ссылкой на массив предполагаемого размера"
 
-#: fortran/resolve.c:9388
+#: fortran/resolve.c:9399
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "Lock переменная в %L должна быть скаляром типа LOCK_TYPE"
 
-#: fortran/resolve.c:9398
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
+#: fortran/resolve.c:9409
+#, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
-msgstr "Lock переменная в %L должна быть скаляром типа LOCK_TYPE"
+msgstr "Event переменная в %L должна быть скаляром типа EVENT_TYPE"
 
-#: fortran/resolve.c:9402
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Actual argument to '%s' at %L must be a coarray"
+#: fortran/resolve.c:9413
+#, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
-msgstr "Фактический аргумент для '%s' в %L должен быть комассивом"
+msgstr "Аргумент event переменная в %L должен быть комассивом или коиндексированным"
 
-#: fortran/resolve.c:9405
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Actual argument to '%s' at %L must be a coarray"
+#: fortran/resolve.c:9416
+#, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
-msgstr "Фактический аргумент для '%s' в %L должен быть комассивом"
+msgstr "Аргумент event переменная в %L должен быть комассивом, но не коиндексированным"
 
-#: fortran/resolve.c:9412 fortran/resolve.c:9533
+#: fortran/resolve.c:9423 fortran/resolve.c:9545
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "STAT= аргумент в %L должна быть скалярной INTEGER переменной"
 
-#: fortran/resolve.c:9424 fortran/resolve.c:9540
+#: fortran/resolve.c:9435 fortran/resolve.c:9553
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "ERRMSG= аргумент в %L должна быть скалярной CHARACTER переменной"
 
-#: fortran/resolve.c:9436
+#: fortran/resolve.c:9447
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "ACQUIRED_LOCK= аргумент в %L должна быть скалярной LOGICAL переменной"
 
-#: fortran/resolve.c:9449
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
+#: fortran/resolve.c:9460
+#, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
-msgstr "Imageset аргумент в %L должен быть скалярным или ранга 1 INTEGER выражением"
+msgstr "UNTIL_COUNT= аргумент в %L должен быть скалярным INTEGER выражением"
 
-#: fortran/resolve.c:9510
+#: fortran/resolve.c:9521
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "Imageset аргумент в %L должен быть скалярным или ранга 1 INTEGER выражением"
 
-#: fortran/resolve.c:9514 fortran/resolve.c:9524
+#: fortran/resolve.c:9525 fortran/resolve.c:9535
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "Imageset аргумент в %L должен быть между 1 и num_images()"
 
-#: fortran/resolve.c:9567
+#: fortran/resolve.c:9580
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "Оператор в %L не есть корректный оператор цели перехода для оператора перехода в %L"
 
-#: fortran/resolve.c:9577
+#: fortran/resolve.c:9590
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr "Переход в %L может вызвать зацикливание"
@@ -66691,12 +59634,12 @@
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:9594 fortran/resolve.c:9617
+#: fortran/resolve.c:9607 fortran/resolve.c:9630
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr "GOTO оператор в %L покидает CRITICAL конструкцию для метки в %L"
 
-#: fortran/resolve.c:9598 fortran/resolve.c:9623
+#: fortran/resolve.c:9611 fortran/resolve.c:9636
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr "GOTO оператор в %L покидает DO CONCURRENT конструкцию для метки в %L"
@@ -66704,1315 +59647,1160 @@
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:9638
+#: fortran/resolve.c:9651
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
-msgstr "Метка в %L не находится в том же блоке что GOTO оператор в %L"
+msgstr "Метка в %L не находится в том же блоке, что GOTO оператор в %L"
 
-#: fortran/resolve.c:9710
+#: fortran/resolve.c:9723
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "WHERE маска в %L имеет противоречивую форму"
 
-#: fortran/resolve.c:9726
+#: fortran/resolve.c:9739
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "WHERE цель присваивания в %L имеет противоречивую форму"
 
-#: fortran/resolve.c:9734 fortran/resolve.c:9821
+#: fortran/resolve.c:9747 fortran/resolve.c:9834
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr "Non-ELEMENTAL определенное пользователем присваивание в WHERE в %L"
 
-#: fortran/resolve.c:9744 fortran/resolve.c:9831
+#: fortran/resolve.c:9757 fortran/resolve.c:9844
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "Неподдерживаемый оператор внутри WHERE в %L"
 
-#: fortran/resolve.c:9775
+#: fortran/resolve.c:9788
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "Присваивание FORALL индексной переменной в %L"
 
-#: fortran/resolve.c:9784
-#, fuzzy, gcc-internal-format
-#| msgid "The FORALL with index '%s' is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
+#: fortran/resolve.c:9797
+#, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
-msgstr "FORALL с индексом '%s' не используется в левой части присваивания в %L и поэтому может вызвать множественное присваивание этому объекту"
+msgstr "FORALL с индексом %qs не используется в левой части присваивания в %L и поэтому может вызвать множественное присваивание этому объекту"
 
-#: fortran/resolve.c:9949
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "FORALL index-name at %L must be a scalar INTEGER"
+#: fortran/resolve.c:9962
+#, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
-msgstr "FORALL индекс-имя в %L должно быть скалярным INTEGER"
+msgstr "FORALL имя индекса в %L должно быть скалярной переменной типа integer"
 
-#: fortran/resolve.c:9959
+#: fortran/resolve.c:9972
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "Внешняя FORALL конструкция уже имеет индекс с этим именем %L"
 
-#: fortran/resolve.c:10036
+#: fortran/resolve.c:10049
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "WHERE/ELSEWHERE клаузула в %L требует LOGICAL массив"
 
-#: fortran/resolve.c:10138
+#: fortran/resolve.c:10151
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
-msgstr ""
+msgstr "gfc_resolve_blocks(): Некорректный тип блока"
 
-#: fortran/resolve.c:10251
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "CHARACTER expression will be truncated in assignment (%d/%d) at %L"
+#: fortran/resolve.c:10264
+#, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
-msgstr "CHARACTER выражение будет усечено в присваивании (%d/%d) в %L"
+msgstr "CHARACTER выражение будет усечено в присваивании (%ld/%ld) в %L"
 
-#: fortran/resolve.c:10283
+#: fortran/resolve.c:10296
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "Коиндексированное выражение в %L присваивается переменной производного типа с POINTER компонентом в PURE процедуре"
 
-#: fortran/resolve.c:10288
+#: fortran/resolve.c:10301
 #, gcc-internal-format, gfc-internal-format
 msgid "The impure variable at %L is assigned to a derived type variable with a POINTER component in a PURE procedure (12.6)"
 msgstr "Impure переменная в %L присваивается переменной производного типа с POINTER компонентом в PURE процедуре (12.6)"
 
-#: fortran/resolve.c:10298
+#: fortran/resolve.c:10311
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "Присваивание коиндексированной переменной в %L в PURE процедуре"
 
-#: fortran/resolve.c:10330
+#: fortran/resolve.c:10343
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
-msgstr ""
+msgstr "Присваивание полиморфному комассиву в %L не допускается"
 
-#: fortran/resolve.c:10334
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Assignment to a FORALL index variable at %L"
+#: fortran/resolve.c:10347
+#, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
-msgstr "Присваивание FORALL индексной переменной в %L"
+msgstr "Присваивание размещаемой полиморфной переменной в %L"
 
-#: fortran/resolve.c:10339
+#: fortran/resolve.c:10352
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
-msgstr ""
+msgstr "Присваивание размещаемой полиморфной переменной в %L требует %<-frealloc-lhs%>"
 
-#: fortran/resolve.c:10346
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
+#: fortran/resolve.c:10359
+#, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
-msgstr "Переменная не должна быть полиморфной во встроенном присваивании в %L - проверьте что имеется соответствующая конкретная подпрограмма для '=' оператора"
+msgstr "Неразмещаемая переменная не должна быть полиморфной во встроенном присваивании в %L - проверьте, что имеется соответствующая конкретная подпрограмма для '=' оператора"
 
-#: fortran/resolve.c:10357
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Coindexed variable must not be have an allocatable ultimate component in assignment at %L"
+#: fortran/resolve.c:10370
+#, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr "Коиндексированная переменная не должна иметь размещаемых окончательных компонентов в присваивании в %L"
 
-#: fortran/resolve.c:10663
+#: fortran/resolve.c:10683
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
-msgstr ""
+msgstr "TODO: type-bound определенные присваивания в %L не выполнены, так как несколько ссылок на части массива появятся в промежуточных выражениях."
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:10905
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Invalid procedure pointer assignment at %L"
+#: fortran/resolve.c:10925
+#, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
-msgstr "Некорректное присваивание указателя на процедуру в %L"
+msgstr "Присваивание указателя на процедуру в %L"
 
-#: fortran/resolve.c:10917
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Target expression in pointer assignment at %L must deliver a pointer result"
+#: fortran/resolve.c:10937
+#, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
-msgstr "Целевое выражение в присваивании указателя в %L должна выдавать указательный результат"
+msgstr "Результат функции в левой части присваивания в %L должен иметь pointer атрибут."
 
-#: fortran/resolve.c:11157
+#: fortran/resolve.c:11177
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgstr "ASSIGNED GOTO оператор в %L требует INTEGER переменной"
 
-#: fortran/resolve.c:11160
-#, fuzzy, gcc-internal-format
-#| msgid "Variable '%s' has not been assigned a target label at %L"
+#: fortran/resolve.c:11180
+#, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
-msgstr "Переменной '%s' не присвоили целевую метку в %L"
+msgstr "Переменной %qs не присвоили целевую метку в %L"
 
-#: fortran/resolve.c:11171
+#: fortran/resolve.c:11191
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "Alternate RETURN оператор в %L требует SCALAR-INTEGER спецификатор возврата"
 
-#: fortran/resolve.c:11233
+#: fortran/resolve.c:11253
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "ASSIGN оператор в %L требует скалярную подразумеваемого INTEGER переменную"
 
-#: fortran/resolve.c:11278
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Invalid kind for %s at %L"
+#: fortran/resolve.c:11298
+#, gcc-internal-format, gfc-internal-format
 msgid "Invalid NULL at %L"
-msgstr "Некорректный вид для %s в %L"
+msgstr "Некорректный NULL в %L"
 
-#: fortran/resolve.c:11282
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Arithmetic IF statement at %L requires a numeric expression"
+#: fortran/resolve.c:11302
+#, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
-msgstr "Оператор арифметического IF в %L требует числовое выражение"
+msgstr "Оператор арифметического IF в %L требует скалярное REAL или INTEGER выражение"
 
-#: fortran/resolve.c:11339
+#: fortran/resolve.c:11359
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
-msgstr ""
+msgstr "gfc_resolve_code(): Нет выражения в DO WHILE"
 
-#: fortran/resolve.c:11344
+#: fortran/resolve.c:11364
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "Условие выхода из DO WHILE цикла в %L должно быть скалярным LOGICAL выражением"
 
-#: fortran/resolve.c:11428
+#: fortran/resolve.c:11448
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "FORALL клаузула маски в %L требует скалярное LOGICAL выражение"
 
-#: fortran/resolve.c:11507
-#, fuzzy, gcc-internal-format
-#| msgid "gfc_trans_code(): Bad statement code"
+#: fortran/resolve.c:11527
+#, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
-msgstr "gfc_trans_code(): Некорректный код оператора"
+msgstr "gfc_resolve_code(): Некорректный код оператора"
 
-#: fortran/resolve.c:11617
-#, fuzzy, gcc-internal-format
-#| msgid "Binding label '%s' at %L collides with the global entity '%s' at %L"
+#: fortran/resolve.c:11637
+#, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
-msgstr "Связывающая метка '%s' в %L конфликтует с глобальной сущностью '%s' в %L"
+msgstr "Переменная %qs со связывающей меткой %qs в %L использует тот же глобальный идентификатор, что и сущность в %L"
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:11630
-#, fuzzy, gcc-internal-format
-#| msgid "Binding label '%s' at %L collides with the global entity '%s' at %L"
+#: fortran/resolve.c:11650
+#, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
-msgstr "Связывающая метка '%s' в %L конфликтует с глобальной сущностью '%s' в %L"
+msgstr "Переменная %qs из модуля %qs со связывающей меткой %qs в %L использует тот же глобальный идентификатор, что и сущность в %L из модуля %qs"
 
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:11647
-#, fuzzy, gcc-internal-format
-#| msgid "Binding label '%s' at %L collides with the global entity '%s' at %L"
+#: fortran/resolve.c:11667
+#, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
-msgstr "Связывающая метка '%s' в %L конфликтует с глобальной сущностью '%s' в %L"
+msgstr "Процедура %qs со связывающей меткой %qs в %L использует тот же глобальный идентификатор, что и сущность в %L"
 
-#: fortran/resolve.c:11732
+#: fortran/resolve.c:11752
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "Длина строки в %L слишком велика"
 
-#: fortran/resolve.c:11961
-#, fuzzy, gcc-internal-format
-#| msgid "Allocatable array '%s' at %L must have a deferred shape"
+#: fortran/resolve.c:11981
+#, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
-msgstr "Размещаемый массив '%s' в %L должен иметь отложенную форму"
+msgstr "Размещаемый массив %qs в %L должен иметь отложенную форму или предполагаемый ранг"
 
-#: fortran/resolve.c:11965
-#, fuzzy, gcc-internal-format
-#| msgid "Scalar object '%s' at %L may not be ALLOCATABLE"
+#: fortran/resolve.c:11985
+#, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
-msgstr "Скалярный объект '%s' в %L не может быть ALLOCATABLE"
+msgstr "Скалярный объект %qs в %L не может быть ALLOCATABLE"
 
-#: fortran/resolve.c:11973
-#, fuzzy, gcc-internal-format
-#| msgid "Array pointer '%s' at %L must have a deferred shape"
+#: fortran/resolve.c:11993
+#, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
-msgstr "Указатель на массив '%s' at %L должен иметь отложенную форму"
+msgstr "Указатель на массив %qs at %L должен иметь отложенную форму или предполагаемый ранг"
 
-#: fortran/resolve.c:11983
-#, fuzzy, gcc-internal-format
-#| msgid "Array '%s' at %L cannot have a deferred shape"
+#: fortran/resolve.c:12003
+#, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
-msgstr "Массив '%s' at %L не может иметь отложенную форму"
+msgstr "Массив %qs at %L не может иметь отложенную форму"
 
-#: fortran/resolve.c:11998
-#, fuzzy, gcc-internal-format
-#| msgid "Type '%s' of CLASS variable '%s' at %L is not extensible"
+#: fortran/resolve.c:12018
+#, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
-msgstr "Тип '%s' CLASS переменной '%s' at %L не является расширяемым"
+msgstr "Тип %qs CLASS переменной %qs at %L не является расширяемым"
 
-#: fortran/resolve.c:12010
-#, fuzzy, gcc-internal-format
-#| msgid "CLASS variable '%s' at %L must be dummy, allocatable or pointer"
+#: fortran/resolve.c:12030
+#, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
-msgstr "CLASS переменная '%s' в %L должна быть формальным параметром, размещаемой или указателем"
+msgstr "CLASS переменная %qs в %L должна быть формальным параметром, размещаемой или указателем"
 
-#: fortran/resolve.c:12041
-#, fuzzy, gcc-internal-format
-#| msgid "The type '%s' cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
+#: fortran/resolve.c:12061
+#, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
-msgstr "Тип '%s' не может быть host ассоциированным в %L поскольку он блокирован несовместимым объектом с тем же именем декларированным в %L"
+msgstr "Тип %qs не может быть host ассоциированным в %L, поскольку он блокирован несовместимым объектом с тем же именем декларированным в %L"
 
-#: fortran/resolve.c:12063
-#, fuzzy, gcc-internal-format
-#| msgid "Fortran 2008: Implied SAVE for module variable '%s' at %L, needed due to the default initialization"
+#: fortran/resolve.c:12083
+#, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
-msgstr "Fortran 2008: Выведенный SAVE для переменной модуля '%s' в %L, необходим в силе подразумеваемой инициализации"
+msgstr "Выведенный SAVE для переменной модуля %qs в %L необходим из-за подразумеваемой инициализации"
 
-#: fortran/resolve.c:12090
-#, fuzzy, gcc-internal-format
-#| msgid "Entity '%s' at %L has a deferred type parameter and requires either the pointer or allocatable attribute"
+#: fortran/resolve.c:12110
+#, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
-msgstr "Сущность '%s' в %L имеет параметр отложенного типа и требует либо pointer либо allocatable атрибут"
+msgstr "Сущность %qs в %L имеет параметр отложенного типа и требует либо POINTER либо ALLOCATABLE атрибут"
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12131
-#, fuzzy, gcc-internal-format
-#| msgid "The module or main program array '%s' at %L must have constant shape"
+#: fortran/resolve.c:12151
+#, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
-msgstr "Массив из модуля или главной программы '%s' в %L должен иметь константную форму"
+msgstr "Массив из модуля или главной программы %qs в %L должен иметь константную форму"
 
-#: fortran/resolve.c:12150
+#: fortran/resolve.c:12170
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "Сущность с предполагаемой character длиной в %L должна быть формальным аргументом или PARAMETER"
 
-#: fortran/resolve.c:12171
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' at %L must have constant character length in this context"
+#: fortran/resolve.c:12191
+#, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
-msgstr "'%s' в %L должна иметь константную character длину в этом контексте"
+msgstr "%qs в %L должна иметь константную character длину в этом контексте"
 
-#: fortran/resolve.c:12178
-#, fuzzy, gcc-internal-format
-#| msgid "COMMON variable '%s' at %L must have constant character length"
+#: fortran/resolve.c:12198
+#, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
-msgstr "COMMON переменная '%s' в %L должна иметь константную character длину"
+msgstr "COMMON переменная %qs в %L должна иметь константную character длину"
 
-#: fortran/resolve.c:12225
-#, fuzzy, gcc-internal-format
-#| msgid "Allocatable '%s' at %L cannot have an initializer"
+#: fortran/resolve.c:12245
+#, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
-msgstr "Размещаемая '%s' в %L не может иметь инициализатор"
+msgstr "Размещаемая %qs в %L не может иметь инициализатор"
 
-#: fortran/resolve.c:12228
-#, fuzzy, gcc-internal-format
-#| msgid "External '%s' at %L cannot have an initializer"
+#: fortran/resolve.c:12248
+#, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
-msgstr "Внешняя '%s' в %L не может иметь инициализатор"
+msgstr "Внешняя %qs в %L не может иметь инициализатор"
 
-#: fortran/resolve.c:12232
-#, fuzzy, gcc-internal-format
-#| msgid "Dummy '%s' at %L cannot have an initializer"
+#: fortran/resolve.c:12252
+#, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
-msgstr "Формальный параметр '%s' в %L не может иметь инициализатор"
+msgstr "Формальный параметр %qs в %L не может иметь инициализатор"
 
-#: fortran/resolve.c:12235
-#, fuzzy, gcc-internal-format
-#| msgid "Intrinsic '%s' at %L cannot have an initializer"
+#: fortran/resolve.c:12255
+#, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
-msgstr "Встроенная '%s' в %L не может иметь инициализатор"
+msgstr "Встроенная %qs в %L не может иметь инициализатор"
 
-#: fortran/resolve.c:12238
-#, fuzzy, gcc-internal-format
-#| msgid "Function result '%s' at %L cannot have an initializer"
+#: fortran/resolve.c:12258
+#, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
-msgstr "Результат функции '%s' в %L не может иметь инициализатор"
+msgstr "Результат функции %qs в %L не может иметь инициализатор"
 
-#: fortran/resolve.c:12241
-#, fuzzy, gcc-internal-format
-#| msgid "Automatic array '%s' at %L cannot have an initializer"
+#: fortran/resolve.c:12261
+#, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
-msgstr "Автоматический массив '%s' в %L не может иметь инициализатор"
+msgstr "Автоматический массив %qs в %L не может иметь инициализатор"
 
-#: fortran/resolve.c:12283
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "in %s, at %s:%d"
+#: fortran/resolve.c:12303
+#, gcc-internal-format, gfc-internal-format
 msgid "%s at %L"
-msgstr "в %s, в %s:%d"
+msgstr "%s в %L"
 
-#: fortran/resolve.c:12310
-#, fuzzy, gcc-internal-format
-#| msgid "Character-valued statement function '%s' at %L must have constant length"
+#: fortran/resolve.c:12330
+#, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
-msgstr "Оператор функция с character значением '%s' в %L должна иметь константную длину"
+msgstr "Оператор функция с character значением %qs в %L должна иметь константную длину"
 
-#: fortran/resolve.c:12332
-#, fuzzy, gcc-internal-format
-#| msgid "Fortran 2003: '%s' is of a PRIVATE type and cannot be a dummy argument of '%s', which is PUBLIC at %L"
+#: fortran/resolve.c:12352
+#, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
-msgstr "Fortran 2003: '%s' имеет PRIVATE тип и не может быть формальным аргументом '%s', который PUBLIC в %L"
+msgstr "%qs имеет PRIVATE тип и не может быть формальным аргументом %qs, который PUBLIC в %L"
 
-#: fortran/resolve.c:12354
-#, fuzzy, gcc-internal-format
-#| msgid "Fortran 2003: Procedure '%s' in PUBLIC interface '%s' at %L takes dummy arguments of '%s' which is PRIVATE"
+#: fortran/resolve.c:12374
+#, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
-msgstr "Fortran 2003: Процедура '%s' в PUBLIC интерфейсе '%s' в %L берет формальные аргументы '%s' который PRIVATE"
+msgstr "Процедура %qs в PUBLIC интерфейсе %qs в %L берет формальные аргументы %qs, который PRIVATE"
 
-#: fortran/resolve.c:12372
-#, fuzzy, gcc-internal-format
-#| msgid "Function '%s' at %L cannot have an initializer"
+#: fortran/resolve.c:12392
+#, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
-msgstr "Функция '%s' в %L не может иметь инициализатор"
+msgstr "Функция %qs в %L не может иметь инициализатор"
 
-#: fortran/resolve.c:12381
-#, fuzzy, gcc-internal-format
-#| msgid "External object '%s' at %L may not have an initializer"
+#: fortran/resolve.c:12401
+#, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
-msgstr "Внешний объект '%s' в %L не может иметь инициализатор"
+msgstr "Внешний объект %qs в %L не может иметь инициализатор"
 
-#: fortran/resolve.c:12389
-#, fuzzy, gcc-internal-format
-#| msgid "ELEMENTAL function '%s' at %L must have a scalar result"
+#: fortran/resolve.c:12409
+#, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
-msgstr "ELEMENTAL функция '%s' в %L должна иметь скалярный результат"
+msgstr "ELEMENTAL функция %qs в %L должна иметь скалярный результат"
 
-#: fortran/resolve.c:12399
-#, fuzzy, gcc-internal-format
-#| msgid "Statement function '%s' at %L may not have pointer or allocatable attribute"
+#: fortran/resolve.c:12419
+#, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
-msgstr "Оператор функция '%s' в %L не может иметь pointer или allocatable атрибут"
+msgstr "Оператор функция %qs в %L не может иметь pointer или allocatable атрибут"
 
-#: fortran/resolve.c:12418
-#, fuzzy, gcc-internal-format
-#| msgid "CHARACTER(*) function '%s' at %L cannot be array-valued"
+#: fortran/resolve.c:12438
+#, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
-msgstr "CHARACTER(*) функция '%s' в %L не может иметь значение массив"
+msgstr "CHARACTER(*) функция %qs в %L не может иметь значение массив"
 
-#: fortran/resolve.c:12422
-#, fuzzy, gcc-internal-format
-#| msgid "CHARACTER(*) function '%s' at %L cannot be pointer-valued"
+#: fortran/resolve.c:12442
+#, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
-msgstr "CHARACTER(*) функция '%s' в %L не может иметь значение указатель"
+msgstr "CHARACTER(*) функция %qs в %L не может иметь значение указатель"
 
-#: fortran/resolve.c:12426
-#, fuzzy, gcc-internal-format
-#| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
+#: fortran/resolve.c:12446
+#, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
-msgstr "CHARACTER(*) функция '%s' в %L не может быть pure"
+msgstr "CHARACTER(*) функция %qs в %L не может быть pure"
 
-#: fortran/resolve.c:12430
-#, fuzzy, gcc-internal-format
-#| msgid "CHARACTER(*) function '%s' at %L cannot be recursive"
+#: fortran/resolve.c:12450
+#, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
-msgstr "CHARACTER(*) функция '%s' в %L не может быть рекурсивной"
+msgstr "CHARACTER(*) функция %qs в %L не может быть рекурсивной"
 
-#: fortran/resolve.c:12443
-#, fuzzy, gcc-internal-format
-#| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
+#: fortran/resolve.c:12463
+#, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
-msgstr "CHARACTER(*) функция '%s' в %L не может быть pure"
+msgstr "CHARACTER(*) функция %qs в %L"
 
-#: fortran/resolve.c:12452
-#, fuzzy, gcc-internal-format
-#| msgid "Procedure '%s' in %s at %L has no explicit interface"
+#: fortran/resolve.c:12472
+#, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
-msgstr "Процедура '%s' в %s в %L не имеет явного интерфейса"
+msgstr "Указатель на процедуру %qs в %L не должен быть элементным"
 
-#: fortran/resolve.c:12458
-#, fuzzy, gcc-internal-format
-#| msgid "Dummy procedure '%s' at %C cannot have a generic interface"
+#: fortran/resolve.c:12478
+#, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
-msgstr "Формальная процедура '%s' в %C не может иметь generic интерфейс"
+msgstr "Формальная процедура %qs в %L не должна быть элементной"
 
-#: fortran/resolve.c:12470
-#, fuzzy, gcc-internal-format
-#| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
+#: fortran/resolve.c:12490
+#, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
-msgstr "Переменная '%s' в %L не может иметь оба атрибута ALLOCATABLE и BIND(C)"
+msgstr "Переменная результата функции %s в %L элементной функции %qs не должна иметь атрибут ALLOCATABLE или POINTER"
 
-#: fortran/resolve.c:12527
-#, fuzzy, gcc-internal-format
-#| msgid "PROCEDURE attribute conflicts with SAVE attribute in '%s' at %L"
+#: fortran/resolve.c:12547
+#, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
-msgstr "PROCEDURE атрибут конфликтует с SAVE атрибутом в '%s' в %L"
+msgstr "PROCEDURE атрибут конфликтует с SAVE атрибутом в %qs в %L"
 
-#: fortran/resolve.c:12533
-#, fuzzy, gcc-internal-format
-#| msgid "PROCEDURE attribute conflicts with INTENT attribute in '%s' at %L"
+#: fortran/resolve.c:12553
+#, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
-msgstr "PROCEDURE атрибут конфликтует с INTENT атрибутом в '%s' в %L"
+msgstr "PROCEDURE атрибут конфликтует с INTENT атрибутом в %qs в %L"
 
-#: fortran/resolve.c:12539
-#, fuzzy, gcc-internal-format
-#| msgid "PROCEDURE attribute conflicts with RESULT attribute in '%s' at %L"
+#: fortran/resolve.c:12559
+#, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
-msgstr "PROCEDURE атрибут конфликтует с RESULT атрибутом в '%s' в %L"
+msgstr "PROCEDURE атрибут конфликтует с RESULT атрибутом в %qs в %L"
 
-#: fortran/resolve.c:12547
-#, fuzzy, gcc-internal-format
-#| msgid "EXTERNAL attribute conflicts with FUNCTION attribute in '%s' at %L"
+#: fortran/resolve.c:12567
+#, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
-msgstr "EXTERNAL атрибут конфликтует с FUNCTION атрибутом в '%s' в %L"
+msgstr "EXTERNAL атрибут конфликтует с FUNCTION атрибутом в %qs в %L"
 
-#: fortran/resolve.c:12553
-#, fuzzy, gcc-internal-format
-#| msgid "Procedure pointer result '%s' at %L is missing the pointer attribute"
+#: fortran/resolve.c:12573
+#, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
-msgstr "Результат указатель на процедуру '%s' в %L оказался без pointer атрибута"
+msgstr "Результат указатель на процедуру %qs в %L оказался без pointer атрибута"
 
-#: fortran/resolve.c:12596
+#: fortran/resolve.c:12616
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
-msgstr ""
+msgstr "Несоответствие в ELEMENTAL атрибуте между MODULE PROCEDURE в %L и ее интерфейсом в %s"
 
-#: fortran/resolve.c:12604
+#: fortran/resolve.c:12624
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
-msgstr ""
+msgstr "Несоответствие в PURE атрибуте между MODULE PROCEDURE в %L и ее интерфейсом в %s"
 
-#: fortran/resolve.c:12612
+#: fortran/resolve.c:12632
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
-msgstr ""
+msgstr "Несоответствие в RECURSIVE атрибуте между MODULE PROCEDURE в %L и ее интерфейсом в %s"
 
-#: fortran/resolve.c:12621
+#: fortran/resolve.c:12641
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
-msgstr ""
+msgstr "%s между MODULE PROCEDURE декларацией в MODULE %qs и декларацией в %L в (SUB)MODULE %qs"
 
-#: fortran/resolve.c:12705
-#, fuzzy, gcc-internal-format
-#| msgid "FINAL procedure '%s' at %L is not a SUBROUTINE"
+#: fortran/resolve.c:12725
+#, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
-msgstr "FINAL процедура '%s' в %L не есть SUBROUTINE"
+msgstr "FINAL процедура %qs в %L не есть SUBROUTINE"
 
-#: fortran/resolve.c:12714
+#: fortran/resolve.c:12734
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "FINAL процедура в %L должна иметь ровно один аргумент"
 
-#: fortran/resolve.c:12723
-#, fuzzy, gcc-internal-format
-#| msgid "Argument of FINAL procedure at %L must be of type '%s'"
+#: fortran/resolve.c:12743
+#, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
-msgstr "Аргумент FINAL процедуры в %L должен быть типа '%s'"
+msgstr "Аргумент FINAL процедуры в %L должен быть типа %qs"
 
-#: fortran/resolve.c:12731
+#: fortran/resolve.c:12751
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "Аргумент FINAL процедуры в %L не должен быть POINTER"
 
-#: fortran/resolve.c:12737
+#: fortran/resolve.c:12757
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "Аргумент FINAL процедуры в %L не должен быть ALLOCATABLE"
 
-#: fortran/resolve.c:12743
+#: fortran/resolve.c:12763
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "Аргумент FINAL процедуры в %L не должен быть OPTIONAL"
 
-#: fortran/resolve.c:12751
+#: fortran/resolve.c:12771
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "Аргумент FINAL процедуры в %L не должен быть INTENT(OUT)"
 
-#: fortran/resolve.c:12760
+#: fortran/resolve.c:12780
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "Нескалярная FINAL процедура в %L должна иметь аргумент предполагаемой формы"
 
-#: fortran/resolve.c:12782
-#, fuzzy, gcc-internal-format
-#| msgid "FINAL procedure '%s' declared at %L has the same rank (%d) as '%s'"
+#: fortran/resolve.c:12802
+#, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
-msgstr "FINAL процедура '%s' декларированная в %L имеет тот же ранг (%d) что и '%s'"
+msgstr "FINAL процедура %qs декларированная в %L имеет тот же ранг (%d), что и %qs"
 
-#: fortran/resolve.c:12819
-#, fuzzy, gcc-internal-format
-#| msgid "Only array FINAL procedures declared for derived type '%s' defined at %L, suggest also scalar one"
+#: fortran/resolve.c:12839
+#, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
-msgstr "Только массивные FINAL процедуры декларированные для производного типа '%s' определенного в %L, предлагают также скалярный тип"
+msgstr "Только массивные FINAL процедуры декларированные для производного типа %qs определенного в %L, предлагают также скалярный тип"
 
-#: fortran/resolve.c:12859
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' and '%s' can't be mixed FUNCTION/SUBROUTINE for GENERIC '%s' at %L"
+#: fortran/resolve.c:12879
+#, gcc-internal-format
 msgid "%qs and %qs can't be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
-msgstr "'%s' и '%s' не могут быть смешанными FUNCTION/SUBROUTINE для GENERIC '%s' в %L"
+msgstr "%qs и %qs не могут быть смешанными FUNCTION/SUBROUTINE для GENERIC %qs в %L"
 
-#: fortran/resolve.c:12895
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' and '%s' for GENERIC '%s' at %L are ambiguous"
+#: fortran/resolve.c:12915
+#, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
-msgstr "'%s' и '%s' для GENERIC '%s' в %L неоднозначны"
+msgstr "%qs и %qs для GENERIC %qs в %L неоднозначны"
 
-#: fortran/resolve.c:12954
-#, fuzzy, gcc-internal-format
-#| msgid "Undefined specific binding '%s' as target of GENERIC '%s' at %L"
+#: fortran/resolve.c:12974
+#, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
-msgstr "Неопределенное конкретное связывание '%s' как цели GENERIC '%s' в %L"
+msgstr "Неопределенное конкретное связывание %qs как цели GENERIC %qs в %L"
 
-#: fortran/resolve.c:12966
-#, fuzzy, gcc-internal-format
-#| msgid "GENERIC '%s' at %L must target a specific binding, '%s' is GENERIC, too"
+#: fortran/resolve.c:12986
+#, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
-msgstr "GENERIC '%s' в %L должен нацеливаться на конкретное связывание, '%s' также GENERIC"
+msgstr "GENERIC %qs в %L должен нацеливаться на конкретное связывание, %qs также GENERIC"
 
-#: fortran/resolve.c:12994
-#, fuzzy, gcc-internal-format
-#| msgid "GENERIC '%s' at %L can't overwrite specific binding with the same name"
+#: fortran/resolve.c:13014
+#, gcc-internal-format
 msgid "GENERIC %qs at %L can't overwrite specific binding with the same name"
-msgstr "GENERIC '%s' в %L не может перебить конкретное связывание с тем же именем"
+msgstr "GENERIC %qs в %L не может перебить конкретное связывание с тем же именем"
 
-#: fortran/resolve.c:13050
+#: fortran/resolve.c:13070
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L can't be NOPASS"
 msgstr "Type-bound оператор в %L не может быть NOPASS"
 
-#: fortran/resolve.c:13242
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' must be a module procedure or an external procedure with an explicit interface at %L"
+#: fortran/resolve.c:13262
+#, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
-msgstr "'%s' должна быть процедурой модуля или внешней процедурой с явным интерфейсом в %L"
+msgstr "%qs должна быть процедурой модуля или внешней процедурой с явным интерфейсом в %L"
 
-#: fortran/resolve.c:13284
-#, fuzzy, gcc-internal-format
-#| msgid "Procedure '%s' with PASS(%s) at %L has no argument '%s'"
+#: fortran/resolve.c:13304
+#, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
-msgstr "Процедура '%s' с PASS(%s) в %L не имеет аргумента '%s'"
+msgstr "Процедура %qs с PASS(%s) в %L не имеет аргумента %qs"
 
-#: fortran/resolve.c:13298
-#, fuzzy, gcc-internal-format
-#| msgid "Procedure '%s' with PASS at %L must have at least one argument"
+#: fortran/resolve.c:13318
+#, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
-msgstr "Процедура '%s' с PASS в %L должна иметь по крайней мере один аргумент"
+msgstr "Процедура %qs с PASS в %L должна иметь по крайней мере один аргумент"
 
-#: fortran/resolve.c:13312 fortran/resolve.c:13778
-#, fuzzy, gcc-internal-format
-#| msgid "Non-polymorphic passed-object dummy argument of '%s' at %L"
+#: fortran/resolve.c:13332 fortran/resolve.c:13798
+#, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
-msgstr "Неполиморфный passed-object формальный аргумент '%s' в %L"
+msgstr "Неполиморфный passed-object формальный аргумент %qs в %L"
 
-#: fortran/resolve.c:13320
-#, fuzzy, gcc-internal-format
-#| msgid "Argument '%s' of '%s' with PASS(%s) at %L must be of the derived-type '%s'"
+#: fortran/resolve.c:13340
+#, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
-msgstr "Аргумент '%s' от '%s' с PASS(%s) в %L должен быть производного типа '%s'"
+msgstr "Аргумент %qs от %qs с PASS(%s) в %L должен быть производного типа %qs"
 
-#: fortran/resolve.c:13329
-#, fuzzy, gcc-internal-format
-#| msgid "Passed-object dummy argument of '%s' at %L must be scalar"
+#: fortran/resolve.c:13349
+#, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
-msgstr "Passed-object формальный аргумент '%s' в %L должен быть скаляром"
+msgstr "Passed-object формальный аргумент %qs в %L должен быть скаляром"
 
-#: fortran/resolve.c:13335
-#, fuzzy, gcc-internal-format
-#| msgid "Passed-object dummy argument of '%s' at %L must not be ALLOCATABLE"
+#: fortran/resolve.c:13355
+#, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
-msgstr "Passed-object формальный аргумент '%s' в %L не должен быть ALLOCATABLE"
+msgstr "Passed-object формальный аргумент %qs в %L не должен быть ALLOCATABLE"
 
-#: fortran/resolve.c:13341
-#, fuzzy, gcc-internal-format
-#| msgid "Passed-object dummy argument of '%s' at %L must not be POINTER"
+#: fortran/resolve.c:13361
+#, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
-msgstr "Passed-object формальный аргумент '%s' в %L не должен быть POINTER"
+msgstr "Passed-object формальный аргумент %qs в %L не должен быть POINTER"
 
-#: fortran/resolve.c:13370
-#, fuzzy, gcc-internal-format
-#| msgid "Procedure '%s' at %L has the same name as a component of '%s'"
+#: fortran/resolve.c:13390
+#, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
-msgstr "Процедура '%s' в %L имеет то же имя что и компонент '%s'"
+msgstr "Процедура %qs в %L имеет то же имя, что и компонент %qs"
 
-#: fortran/resolve.c:13380
-#, fuzzy, gcc-internal-format
-#| msgid "Procedure '%s' at %L has the same name as an inherited component of '%s'"
+#: fortran/resolve.c:13400
+#, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
-msgstr "Процедура '%s' в %L имеет то же имя что и унаследованный компонент '%s'"
+msgstr "Процедура %qs в %L имеет то же имя, что и унаследованный компонент %qs"
 
-#: fortran/resolve.c:13472
-#, fuzzy, gcc-internal-format
-#| msgid "Derived-type '%s' declared at %L must be ABSTRACT because '%s' is DEFERRED and not overridden"
+#: fortran/resolve.c:13492
+#, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
-msgstr "Производный тип '%s' декларированный в %L должен быть ABSTRACT поскольку '%s' есть DEFERRED и не перебивается"
+msgstr "Производный тип %qs декларированный в %L должен быть ABSTRACT, поскольку %qs есть DEFERRED и не перебивается"
 
-#: fortran/resolve.c:13574
-#, fuzzy, gcc-internal-format
-#| msgid "Coarray component '%s' at %L must be allocatable with deferred shape"
+#: fortran/resolve.c:13594
+#, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
-msgstr "Комассивный компонент '%s' в %L должен быть размещаемым с отложенной формой"
+msgstr "Комассивный компонент %qs в %L должен быть размещаемым с отложенной формой"
 
-#: fortran/resolve.c:13583
-#, fuzzy, gcc-internal-format
-#| msgid "Component '%s' at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
+#: fortran/resolve.c:13603
+#, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
-msgstr "Компонент '%s' в %L типа TYPE(C_PTR) или TYPE(C_FUNPTR) не должен быть комассивом"
+msgstr "Компонент %qs в %L типа TYPE(C_PTR) или TYPE(C_FUNPTR) не должен быть комассивом"
 
-#: fortran/resolve.c:13593
-#, fuzzy, gcc-internal-format
-#| msgid "Component '%s' at %L with coarray component shall be a nonpointer, nonallocatable scalar"
+#: fortran/resolve.c:13613
+#, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
-msgstr "Компонент '%s' в %L с комассивным компонентом должен быть неуказательным, неразмещаемым скаляром"
+msgstr "Компонент %qs в %L с комассивным компонентом должен быть неуказательным, неразмещаемым скаляром"
 
-#: fortran/resolve.c:13602
-#, fuzzy, gcc-internal-format
-#| msgid "Component '%s' at %L has the CONTIGUOUS attribute but is not an array pointer"
+#: fortran/resolve.c:13622
+#, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
-msgstr "Компонент '%s' в %L имеет CONTIGUOUS атрибут но не является указателем на массив"
+msgstr "Компонент %qs в %L имеет CONTIGUOUS атрибут, но не является указателем на массив"
 
-#: fortran/resolve.c:13613
-#, fuzzy, gcc-internal-format
-#| msgid "Argument of ICHAR at %L must be of length one"
+#: fortran/resolve.c:13633
+#, gcc-internal-format
 msgid "Component %qs of BIND(C) type at %L must have length one"
-msgstr "Аргумент ICHAR в %L должен быть длины один"
+msgstr "Компонент %qs типа BIND(C) в %L должен иметь единичную длину"
 
-#: fortran/resolve.c:13711
-#, fuzzy, gcc-internal-format
-#| msgid "Procedure pointer component '%s' with PASS(%s) at %L has no argument '%s'"
+#: fortran/resolve.c:13731
+#, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
-msgstr "Компонент указатель на процедуру '%s' с PASS(%s) в %L не имеет аргумента '%s'"
+msgstr "Компонент указателя на процедуру %qs с PASS(%s) в %L не имеет аргумента %qs"
 
-#: fortran/resolve.c:13725
-#, fuzzy, gcc-internal-format
-#| msgid "Procedure pointer component '%s' with PASS at %L must have at least one argument"
+#: fortran/resolve.c:13745
+#, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
-msgstr "Компонент указатель на процедуру '%s' с PASS в %L должна иметь по крайней мере один аргумент"
+msgstr "Компонент указателя на процедуру %qs с PASS в %L должен иметь по крайней мере один аргумент"
 
-#: fortran/resolve.c:13741
-#, fuzzy, gcc-internal-format
-#| msgid "Argument '%s' of '%s' with PASS(%s) at %L must be of the derived type '%s'"
+#: fortran/resolve.c:13761
+#, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
-msgstr "Аргумент '%s' от '%s' с PASS(%s) в %L должна быть производного типа '%s'"
+msgstr "Аргумент %qs от %qs с PASS(%s) в %L должен быть производного типа %qs"
 
-#: fortran/resolve.c:13751
-#, fuzzy, gcc-internal-format
-#| msgid "Argument '%s' of '%s' with PASS(%s) at %L must be scalar"
+#: fortran/resolve.c:13771
+#, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
-msgstr "Аргумент '%s' от '%s' с PASS(%s) в %L должна быть скаляром"
+msgstr "Аргумент %qs от %qs с PASS(%s) в %L должен быть скаляром"
 
-#: fortran/resolve.c:13760
-#, fuzzy, gcc-internal-format
-#| msgid "Argument '%s' of '%s' with PASS(%s) at %L may not have the POINTER attribute"
+#: fortran/resolve.c:13780
+#, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
-msgstr "Аргумент '%s' от '%s' с PASS(%s) в %L не может иметь POINTER атрибут"
+msgstr "Аргумент %qs от %qs с PASS(%s) в %L не может иметь POINTER атрибут"
 
-#: fortran/resolve.c:13769
-#, fuzzy, gcc-internal-format
-#| msgid "Argument '%s' of '%s' with PASS(%s) at %L may not be ALLOCATABLE"
+#: fortran/resolve.c:13789
+#, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
-msgstr "Аргумент '%s' от '%s' с PASS(%s) в %L не может быть ALLOCATABLE"
+msgstr "Аргумент %qs от %qs с PASS(%s) в %L не может быть ALLOCATABLE"
 
-#: fortran/resolve.c:13811
-#, fuzzy, gcc-internal-format
-#| msgid "Component '%s' of '%s' at %L has the same name as an inherited type-bound procedure"
+#: fortran/resolve.c:13831
+#, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
-msgstr "Компонент '%s' от '%s' в %L имеет то же имя что и унаследованная type-bound процедура"
+msgstr "Компонент %qs от %qs в %L имеет то же имя, что и унаследованная type-bound процедура"
 
-#: fortran/resolve.c:13824
-#, fuzzy, gcc-internal-format
-#| msgid "Character length of component '%s' needs to be a constant specification expression at %L"
+#: fortran/resolve.c:13844
+#, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
-msgstr "Character длина компонента '%s' должна быть константным спецификационным выражением в %L"
+msgstr "Character длина компонента %qs должна быть константным спецификационным выражением в %L"
 
-#: fortran/resolve.c:13835
-#, fuzzy, gcc-internal-format
-#| msgid "Character component '%s' of '%s' at %L with deferred length must be a POINTER or ALLOCATABLE"
+#: fortran/resolve.c:13855
+#, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
-msgstr "Character компонент '%s' от '%s' в %L с отложенной длиной должен быть POINTER или ALLOCATABLE"
+msgstr "Character компонент %qs от %qs в %L с отложенной длиной должен быть POINTER или ALLOCATABLE"
 
-#: fortran/resolve.c:13868
-#, fuzzy, gcc-internal-format
-#| msgid "Fortran 2003: the component '%s' is a PRIVATE type and cannot be a component of '%s', which is PUBLIC at %L"
+#: fortran/resolve.c:13888
+#, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
-msgstr "Fortran 2003: компонент '%s' имеет PRIVATE тип и не может быть компонентом '%s', который PUBLIC в %L"
+msgstr "компонент %qs имеет PRIVATE тип и не может быть компонентом %qs, который PUBLIC в %L"
 
-#: fortran/resolve.c:13876
+#: fortran/resolve.c:13896
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr "Полиморфный компонент %s в %L в SEQUENCE или BIND(C) типе %s"
 
-#: fortran/resolve.c:13885
+#: fortran/resolve.c:13905
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "Компонент %s SEQUENCE типа декларированный в %L не имеет SEQUENCE атрибут"
 
-#: fortran/resolve.c:13903 fortran/resolve.c:13915
-#, fuzzy, gcc-internal-format
-#| msgid "The pointer component '%s' of '%s' at %L is a type that has not been declared"
+#: fortran/resolve.c:13923 fortran/resolve.c:13935
+#, gcc-internal-format
 msgid "The pointer component %qs of %qs at %L is a type that has not been declared"
-msgstr "Компонент указатель '%s' от '%s' в %L есть тип который не был декларирован"
+msgstr "Компонент указатель %qs от %qs в %L есть тип, который не был декларирован"
 
-#: fortran/resolve.c:13989
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Conflict in attributes of function argument at %C"
+#: fortran/resolve.c:14009
+#, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
-msgstr "Конфликт в атрибутах аргумента функции в %C"
+msgstr "Конфликтующие инициализаторы в объединении в %L и %L"
 
-#: fortran/resolve.c:14034
-#, fuzzy, gcc-internal-format
-#| msgid "As extending type '%s' at %L has a coarray component, parent type '%s' shall also have one"
+#: fortran/resolve.c:14054
+#, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
-msgstr "Поскольку расширяющий тип '%s' в %L имеет комассивный компонент, родительский тип '%s' должен также иметь его"
+msgstr "Поскольку расширяющий тип %qs в %L имеет комассивный компонент, родительский тип %qs должен также иметь его"
 
-#: fortran/resolve.c:14047
-#, fuzzy, gcc-internal-format
-#| msgid "Non-extensible derived-type '%s' at %L must not be ABSTRACT"
+#: fortran/resolve.c:14067
+#, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
-msgstr "Нерасширяемый производный тип '%s' в %L не должен быть ABSTRACT"
+msgstr "Нерасширяемый производный тип %qs в %L не должен быть ABSTRACT"
 
-#: fortran/resolve.c:14111
+#: fortran/resolve.c:14131
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
-msgstr ""
+msgstr "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 
-#: fortran/resolve.c:14144
-#, fuzzy, gcc-internal-format
-#| msgid "Fortran 2003: Generic name '%s' of function '%s' at %L being the same name as derived type at %L"
+#: fortran/resolve.c:14164
+#, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
-msgstr "Fortran 2003: Generic имя '%s' функции '%s' в %L то же что и имя производного типа в %L"
+msgstr "Generic имя %qs функции %qs в %L то же, что и имя производного типа в %L"
 
-#: fortran/resolve.c:14216
-#, fuzzy, gcc-internal-format
-#| msgid "Assumed size array '%s' in namelist '%s' at %L is not allowed"
+#: fortran/resolve.c:14236
+#, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
-msgstr "Массив предполагаемого размера '%s' в списке имен '%s' в %L не допускается"
+msgstr "Массив предполагаемого размера %qs в списке имен %qs в %L не допускается"
 
-#: fortran/resolve.c:14222
-#, fuzzy, gcc-internal-format
-#| msgid "Fortran 2003: NAMELIST array object '%s' with assumed shape in namelist '%s' at %L"
+#: fortran/resolve.c:14242
+#, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
-msgstr "Fortran 2003: NAMELIST массивный объект '%s' с предполагаемой формой в списке имен '%s' в %L"
+msgstr "NAMELIST массивный объект %qs с предполагаемой формой в списке имен %qs в %L"
 
-#: fortran/resolve.c:14228
-#, fuzzy, gcc-internal-format
-#| msgid "Fortran 2003: NAMELIST array object '%s' with nonconstant shape in namelist '%s' at %L"
+#: fortran/resolve.c:14248
+#, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
-msgstr "Fortran 2003: NAMELIST массивный объект  '%s' с неконстантной формой в списке имен '%s' в %L"
+msgstr "NAMELIST массивный объект %qs с неконстантной формой в списке имен %qs в %L"
 
-#: fortran/resolve.c:14236
-#, fuzzy, gcc-internal-format
-#| msgid "Fortran 2003: NAMELIST object '%s' with nonconstant character length in namelist '%s' at %L"
+#: fortran/resolve.c:14256
+#, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
-msgstr "Fortran 2003: NAMELIST объект '%s' с неконстантной character длиной в списке имен '%s' в %L"
+msgstr "NAMELIST объект %qs с неконстантной character длиной в списке имен %qs в %L"
 
-#: fortran/resolve.c:14253
-#, fuzzy, gcc-internal-format
-#| msgid "NAMELIST object '%s' was declared PRIVATE and cannot be member of PUBLIC namelist '%s' at %L"
+#: fortran/resolve.c:14273
+#, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
-msgstr "NAMELIST объект '%s' был декларирован PRIVATE и не может быть членом PUBLIC списка имен '%s' в %L"
+msgstr "NAMELIST объект %qs был декларирован PRIVATE и не может быть членом PUBLIC списка имен %qs в %L"
 
-#: fortran/resolve.c:14275
-#, fuzzy, gcc-internal-format
-#| msgid "NAMELIST object '%s' has use-associated PRIVATE components and cannot be member of namelist '%s' at %L"
+#: fortran/resolve.c:14295
+#, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
-msgstr "NAMELIST объект '%s' имеет use-associated PRIVATE компоненты и не может быть членом списка имен '%s' в %L"
+msgstr "NAMELIST объект %qs имеет use-associated PRIVATE компоненты и не может быть членом списка имен %qs в %L"
 
-#: fortran/resolve.c:14286
-#, fuzzy, gcc-internal-format
-#| msgid "NAMELIST object '%s' has PRIVATE components and cannot be a member of PUBLIC namelist '%s' at %L"
+#: fortran/resolve.c:14306
+#, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
-msgstr "NAMELIST объект '%s' имеет PRIVATE компоненты и не может быть членом PUBLIC списка имен '%s' в %L"
+msgstr "NAMELIST объект %qs имеет PRIVATE компоненты и не может быть членом PUBLIC списка имен %qs в %L"
 
-#: fortran/resolve.c:14313
-#, fuzzy, gcc-internal-format
-#| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
+#: fortran/resolve.c:14333
+#, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
-msgstr "PROCEDURE атрибут конфликтует с NAMELIST атрибутом в '%s' в %L"
+msgstr "PROCEDURE атрибут конфликтует с NAMELIST атрибутом в %qs в %L"
 
-#: fortran/resolve.c:14337
-#, fuzzy, gcc-internal-format
-#| msgid "Parameter array '%s' at %L cannot be automatic or of deferred shape"
+#: fortran/resolve.c:14357
+#, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
-msgstr "Parameter массив '%s' at %L не может быть автоматическим или отложенной формы"
+msgstr "Parameter массив %qs at %L не может быть автоматическим или отложенной формы"
 
-#: fortran/resolve.c:14353
-#, fuzzy, gcc-internal-format
-#| msgid "Implicitly typed PARAMETER '%s' at %L doesn't match a later IMPLICIT type"
+#: fortran/resolve.c:14373
+#, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
-msgstr "Неявно типизированный PARAMETER '%s' в %L не соотвествует более позднему IMPLICIT типу"
+msgstr "Неявно типизированный PARAMETER %qs в %L не соответствует более позднему IMPLICIT типу"
 
-#: fortran/resolve.c:14364
+#: fortran/resolve.c:14384
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "Несовместимый производный тип в PARAMETER в %L"
 
-#: fortran/resolve.c:14372
-#, fuzzy, gcc-internal-format
-#| msgid "COMMON block '%s' at %L can not have the EXTERNAL attribute"
+#: fortran/resolve.c:14392
+#, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
-msgstr "COMMON блок '%s' в %L не может иметь EXTERNAL атрибут"
+msgstr "CLASS переменная %qs в %L не может иметь PARAMETER атрибут"
 
-#: fortran/resolve.c:14423
-#, fuzzy, gcc-internal-format
-#| msgid "Entity '%s' at %L has a deferred type parameter and requires either the pointer or allocatable attribute"
+#: fortran/resolve.c:14443
+#, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
-msgstr "Сущность '%s' в %L имеет параметр отложенного типа и требует либо pointer либо allocatable атрибут"
+msgstr ""
 
-#: fortran/resolve.c:14434
+#: fortran/resolve.c:14454
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.c:14441
+#: fortran/resolve.c:14461
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.c:14480
+#: fortran/resolve.c:14500
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
-msgstr ""
+msgstr "Простите, размещаемые/указательные компоненты в комассивах полиморфных (CLASS) типов в %L не поддерживаются"
 
-#: fortran/resolve.c:14544
+#: fortran/resolve.c:14564
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "PROTECTED атрибут конфликтует с EXTERNAL атрибутом в %L"
 
-#: fortran/resolve.c:14547
+#: fortran/resolve.c:14567
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "PROCEDURE атрибут конфликтует с PROTECTED атрибутом в %L"
 
-#: fortran/resolve.c:14643
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape array"
+#: fortran/resolve.c:14663
+#, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
-msgstr "'%s' в %L имеет CONTIGUOUS атрибут но не является указателем на массив или массивом предполагаемой формы"
+msgstr "%qs в %L имеет CONTIGUOUS атрибут, но не является указателем на массив или массивом предполагаемой формы или предполагаемого ранга"
 
-#: fortran/resolve.c:14664
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Bad specification for assumed size array at %C"
+#: fortran/resolve.c:14684
+#, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
-msgstr "Некорректная спецификация для массива предполагаемого размера в %C"
+msgstr ""
 
-#: fortran/resolve.c:14677
+#: fortran/resolve.c:14697
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "Массив предполагаемого размера в %L должен быть формальным аргументом"
 
-#: fortran/resolve.c:14680
+#: fortran/resolve.c:14700
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "Массив предполагаемой формы в %L должен быть формальным аргументом"
 
-#: fortran/resolve.c:14688
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Assumed shape array at %L must be a dummy argument"
+#: fortran/resolve.c:14708
+#, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "Массив предполагаемой формы в %L должен быть формальным аргументом"
 
-#: fortran/resolve.c:14695
+#: fortran/resolve.c:14715
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
-msgstr ""
+msgstr "Массив предполагаемого ранга в %L не может иметь VALUE или CODIMENSION атрибут"
 
-#: fortran/resolve.c:14708
+#: fortran/resolve.c:14728
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "Символ в %L не является DUMMY переменной"
 
-#: fortran/resolve.c:14714
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' at %L cannot have the VALUE attribute because it is not a dummy argument"
+#: fortran/resolve.c:14734
+#, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
-msgstr "'%s' в %L не может иметь VALUE атрибут поскольку он не является формальным аргументом"
+msgstr "%qs в %L не может иметь VALUE атрибут, поскольку он не является формальным аргументом"
 
-#: fortran/resolve.c:14724
-#, fuzzy, gcc-internal-format
-#| msgid "Character dummy variable '%s' at %L with VALUE attribute must have constant length"
+#: fortran/resolve.c:14744
+#, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
-msgstr "Character формальная переменная '%s' в %L с VALUE атрибутом должна иметь константную длину"
+msgstr "Character формальная переменная %qs в %L с VALUE атрибутом должна иметь константную длину"
 
-#: fortran/resolve.c:14733
-#, fuzzy, gcc-internal-format
-#| msgid "C interoperable character dummy variable '%s' at %L with VALUE attribute must have length one"
+#: fortran/resolve.c:14753
+#, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
-msgstr "C совместимая character формальная переменная '%s' в %L с VALUE атрибутом должна иметь длину один"
+msgstr "C совместимая character формальная переменная %qs в %L с VALUE атрибутом должна иметь длину один"
 
-#: fortran/resolve.c:14746 fortran/resolve.c:14923
-#, fuzzy, gcc-internal-format
-#| msgid "The derived type '%s' at %L is of type '%s', which has not been defined"
+#: fortran/resolve.c:14766 fortran/resolve.c:14943
+#, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
-msgstr "Производный тип '%s' в %L имеет тип '%s', который не был определен"
+msgstr "Производный тип %qs в %L имеет тип %qs, который не был определен"
 
-#: fortran/resolve.c:14760
+#: fortran/resolve.c:14780
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
-msgstr ""
+msgstr "Переменная %s в %L с NO_ARG_CHECK атрибутов должна быть формальным аргументом"
 
-#: fortran/resolve.c:14769
+#: fortran/resolve.c:14789
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
-msgstr ""
+msgstr "Переменная %s в %L с NO_ARG_CHECK атрибутом должна быть типа TYPE(*) или числового встроенного типа"
 
-#: fortran/resolve.c:14778
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
+#: fortran/resolve.c:14798
+#, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
-msgstr "Переменная '%s' в %L не может иметь оба атрибута ALLOCATABLE и BIND(C)"
+msgstr "Переменная %s в %L с NO_ARG_CHECK атрибутом не может иметь ALLOCATABLE, CODIMENSION, POINTER или VALUE атрибут"
 
-#: fortran/resolve.c:14786
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
+#: fortran/resolve.c:14806
+#, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
-msgstr "Переменная '%s' в %L не может иметь оба атрибута POINTER и BIND(C)"
+msgstr "Переменная %s в %L с NO_ARG_CHECK атрибутом не может иметь INTENT(OUT) атрибут"
 
-#: fortran/resolve.c:14793
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "'%s' at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape array"
+#: fortran/resolve.c:14813
+#, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
-msgstr "'%s' в %L имеет CONTIGUOUS атрибут но не является указателем на массив или массивом предполагаемой формы"
+msgstr "Переменная %s в %L с NO_ARG_CHECK атрибутом должна быть или скаляром или массивом предполагаемого размера"
 
-#: fortran/resolve.c:14813
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Assumed shape array '%s' at %L is not permitted in an initialization expression"
+#: fortran/resolve.c:14833
+#, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
-msgstr "Массив предполагаемой формы '%s' в %L не разрешен в инициализационном выражении"
+msgstr "Предполагаемый тип переменной %s в %L разрешен только для формальных переменных"
 
-#: fortran/resolve.c:14820
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
+#: fortran/resolve.c:14840
+#, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
-msgstr "Переменная '%s' в %L не может иметь оба атрибута ALLOCATABLE и BIND(C)"
+msgstr "Переменная предполагаемого типа %s в %L не может иметь ALLOCATABLE, CODIMENSION, POINTER или VALUE атрибут"
 
-#: fortran/resolve.c:14827
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
+#: fortran/resolve.c:14847
+#, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
-msgstr "Переменная '%s' в %L не может иметь оба атрибута POINTER и BIND(C)"
+msgstr "Переменная предполагаемого типа %s в %L не может иметь INTENT(OUT) атрибут"
 
-#: fortran/resolve.c:14834
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Loop variable at %C cannot be a coarray"
+#: fortran/resolve.c:14854
+#, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
-msgstr "Переменная цикла в %C не может быть комассивом"
+msgstr "Переменная предполагаемого типа %s в %L не должна быть массивом явной формы"
 
-#: fortran/resolve.c:14860
-#, fuzzy, gcc-internal-format
-#| msgid "Variable '%s' at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
+#: fortran/resolve.c:14880
+#, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
-msgstr "Переменная '%s' at %L не может быть BIND(C) поскольку она не COMMON блок и не декларирована на уровне модуля"
+msgstr "Переменная %qs at %L не может быть BIND(C), поскольку она не COMMON блок и не декларирована на уровне модуля"
 
-#: fortran/resolve.c:14870
-#, fuzzy, gcc-internal-format
-#| msgid "COMMON variable '%s' at %L must have constant character length"
+#: fortran/resolve.c:14890
+#, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
-msgstr "COMMON переменная '%s' в %L должна иметь константную character длину"
+msgstr ""
 
-#: fortran/resolve.c:14949
-#, fuzzy, gcc-internal-format
-#| msgid "Fortran 2003: PUBLIC %s '%s' at %L of PRIVATE derived type '%s'"
+#: fortran/resolve.c:14969
+#, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
-msgstr "Fortran 2003: PUBLIC %s '%s' в %L PRIVATE производного типа '%s'"
+msgstr "PUBLIC %s %qs в %L PRIVATE производного типа %qs"
 
-#: fortran/resolve.c:14964
+#: fortran/resolve.c:14984
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr "Переменная %s в %L типа LOCK_TYPE или с подкомпонентом типа LOCK_TYPE должна быть комассивом"
 
-#: fortran/resolve.c:14977
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
+#: fortran/resolve.c:14997
+#, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
-msgstr "Переменная %s в %L типа LOCK_TYPE или с подкомпонентом типа LOCK_TYPE должна быть комассивом"
+msgstr ""
 
-#: fortran/resolve.c:14995
-#, fuzzy, gcc-internal-format
-#| msgid "The INTENT(OUT) dummy argument '%s' at %L is ASSUMED SIZE and so cannot have a default initializer"
+#: fortran/resolve.c:15015
+#, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
-msgstr "The INTENT(OUT) формальный аргумент '%s' в %L имеет ASSUMED SIZE и поэтому не может иметь подразумеваемый инициализатор"
+msgstr "INTENT(OUT) формальный аргумент %qs в %L имеет ASSUMED SIZE и поэтому не может иметь подразумеваемый инициализатор"
 
-#: fortran/resolve.c:15007
-#, fuzzy, gcc-internal-format
-#| msgid "Dummy argument '%s' at %L of LOCK_TYPE shall not be INTENT(OUT)"
+#: fortran/resolve.c:15027
+#, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
-msgstr "Формальный аргумент '%s' в %L типа LOCK_TYPE не должен быть INTENT(OUT)"
+msgstr "Формальный аргумент %qs в %L типа LOCK_TYPE не должен быть INTENT(OUT)"
 
-#: fortran/resolve.c:15016
-#, fuzzy, gcc-internal-format
-#| msgid "Dummy argument '%s' at %L of LOCK_TYPE shall not be INTENT(OUT)"
+#: fortran/resolve.c:15036
+#, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
-msgstr "Формальный аргумент '%s' в %L типа LOCK_TYPE не должен быть INTENT(OUT)"
+msgstr "Формальный аргумент %qs в %L типа EVENT_TYPE не должен быть INTENT(OUT)"
 
-#: fortran/resolve.c:15028
-#, fuzzy, gcc-internal-format
-#| msgid "Function result '%s' at %L shall not be a coarray or have a coarray component"
+#: fortran/resolve.c:15048
+#, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
-msgstr "Результат функции '%s' в %L не должен быть комассивом или иметь комассивный компонент"
+msgstr "Результат функции %qs в %L не должен быть комассивом или иметь комассивный компонент"
 
-#: fortran/resolve.c:15037
-#, fuzzy, gcc-internal-format
-#| msgid "Variable '%s' at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
+#: fortran/resolve.c:15057
+#, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
-msgstr "Переменная '%s' в %L типа TYPE(C_PTR) или TYPE(C_FUNPTR) не должна быть комассивом"
+msgstr "Переменная %qs в %L типа TYPE(C_PTR) или TYPE(C_FUNPTR) не должна быть комассивом"
 
-#: fortran/resolve.c:15049
-#, fuzzy, gcc-internal-format
-#| msgid "Variable '%s' at %L with coarray component shall be a nonpointer, nonallocatable scalar"
+#: fortran/resolve.c:15069
+#, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
-msgstr "Переменная '%s' в %L с комассивным компонентом должна быть неуказательным, неразмещаемым скаляром"
+msgstr "Переменная %qs в %L с комассивным компонентом должна быть неуказательным, неразмещаемым скаляром, который не есть комассив"
 
-#: fortran/resolve.c:15065
-#, fuzzy, gcc-internal-format
-#| msgid "Variable '%s' at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
+#: fortran/resolve.c:15085
+#, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
-msgstr "Переменная '%s' в %L является комассивом и не является ни ALLOCATABLE, ни SAVE, ни формальным аргументом"
+msgstr "Переменная %qs в %L является комассивом и не является ни ALLOCATABLE, ни SAVE, ни формальным аргументом"
 
-#: fortran/resolve.c:15073
-#, fuzzy, gcc-internal-format
-#| msgid "Coarray variable '%s' at %L shall not have codimensions with deferred shape"
+#: fortran/resolve.c:15093
+#, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
-msgstr "Комассивная переменная '%s' в %L не должна иметь коизмерения с отложенной формой"
+msgstr "Комассивная переменная %qs в %L не должна иметь коизмерения с отложенной формой"
 
-#: fortran/resolve.c:15080
-#, fuzzy, gcc-internal-format
-#| msgid "Allocatable coarray variable '%s' at %L must have deferred shape"
+#: fortran/resolve.c:15100
+#, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
-msgstr "Размещаемая комассивная переменная '%s' в %L должна иметь отложенную форму"
+msgstr "Размещаемая комассивная переменная %qs в %L должна иметь отложенную форму"
 
-#: fortran/resolve.c:15092
-#, fuzzy, gcc-internal-format
-#| msgid "Variable '%s' at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
+#: fortran/resolve.c:15112
+#, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
-msgstr "Переменная '%s' в %L является INTENT(OUT) и может поэтому не быть размещаемым комассивом или иметь комассивные компоненты"
+msgstr "Переменная %qs в %L является INTENT(OUT) и может поэтому не быть размещаемым комассивом или иметь комассивные компоненты"
 
-#: fortran/resolve.c:15101
-#, fuzzy, gcc-internal-format
-#| msgid "Coarray dummy variable '%s' at %L not allowed in BIND(C) procedure '%s'"
+#: fortran/resolve.c:15121
+#, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
-msgstr "Комассивная формальная переменная '%s' в %L не допускается в BIND(C) процедуре '%s'"
+msgstr "Комассивная формальная переменная %qs в %L не допускается в BIND(C) процедуре %qs"
 
-#: fortran/resolve.c:15117
-#, fuzzy, gcc-internal-format
-#| msgid "Coarray dummy variable '%s' at %L not allowed in BIND(C) procedure '%s'"
+#: fortran/resolve.c:15137
+#, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
-msgstr "Комассивная формальная переменная '%s' в %L не допускается в BIND(C) процедуре '%s'"
+msgstr "LOGICAL формальная переменная %qs в %L с не-C_Bool видом в BIND(C) процедуре %qs"
 
-#: fortran/resolve.c:15123
-#, fuzzy, gcc-internal-format
-#| msgid "Coarray dummy variable '%s' at %L not allowed in BIND(C) procedure '%s'"
+#: fortran/resolve.c:15143
+#, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
-msgstr "Комассивная формальная переменная '%s' в %L не допускается в BIND(C) процедуре '%s'"
+msgstr "LOGICAL результирующая переменная %qs в %L с не-C_Bool видом в BIND(C) процедуре %qs"
 
-#: fortran/resolve.c:15148
-#, fuzzy, gcc-internal-format
-#| msgid "Namelist %s cannot be renamed by USE association to %s"
+#: fortran/resolve.c:15168
+#, gcc-internal-format
 msgid "Namelist %qs can not be an argument to subroutine or function at %L"
-msgstr "Список имен %s не может быть переименован путем USE ассоциации в %s"
+msgstr "Список имен %qs не может быть аргументом для подпрограммы или функции в %L"
 
-#: fortran/resolve.c:15218
+#: fortran/resolve.c:15238
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "Threadprivate в %L не является SAVEd"
 
-#: fortran/resolve.c:15229
+#: fortran/resolve.c:15249
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
-msgstr ""
+msgstr "!$OMP DECLARE TARGET переменная %qs в %L не есть SAVEd"
 
-#: fortran/resolve.c:15333
+#: fortran/resolve.c:15353
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
-msgstr ""
+msgstr "check_data_variable(): Некорректное выражение"
 
-#: fortran/resolve.c:15339
-#, fuzzy, gcc-internal-format
-#| msgid "BLOCK DATA element '%s' at %L must be in COMMON"
+#: fortran/resolve.c:15359
+#, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
-msgstr "BLOCK DATA элемент '%s' в %L должен быть в COMMON"
+msgstr "BLOCK DATA элемент %qs в %L должен быть в COMMON"
 
-#: fortran/resolve.c:15345
-#, fuzzy, gcc-internal-format
-#| msgid "DATA array '%s' at %L must be specified in a previous declaration"
+#: fortran/resolve.c:15365
+#, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
-msgstr "DATA массив '%s' в %L должен быть специфицирован в предшествующей декларации"
+msgstr "DATA массив %qs в %L должен быть специфицирован в предшествующей декларации"
 
-#: fortran/resolve.c:15354
-#, fuzzy, gcc-internal-format
-#| msgid "DATA element '%s' at %L cannot have a coindex"
+#: fortran/resolve.c:15374
+#, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
-msgstr "DATA элемент '%s' в %L не может иметь коиндекс"
+msgstr "DATA элемент %qs в %L не может иметь коиндекс"
 
-#: fortran/resolve.c:15368
-#, fuzzy, gcc-internal-format
-#| msgid "DATA element '%s' at %L is a pointer and so must be a full array"
+#: fortran/resolve.c:15388
+#, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
-msgstr "DATA элемент '%s' в %L является указателем и поэтому должен быть полным массивом"
+msgstr "DATA элемент %qs в %L является указателем и поэтому должен быть полным массивом"
 
-#: fortran/resolve.c:15414
+#: fortran/resolve.c:15434
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "Неконстантная секция массива в %L в DATA операторе"
 
-#: fortran/resolve.c:15427
+#: fortran/resolve.c:15447
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "DATA оператор в %L имеет больше переменных чем значений"
 
-#: fortran/resolve.c:15526
+#: fortran/resolve.c:15546
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr "начало implied-do цикла в %L не может быть упрощено до константного значения"
 
-#: fortran/resolve.c:15534
+#: fortran/resolve.c:15554
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr "окончание implied-do цикла в %L не может быть упрощено до константного значения"
 
-#: fortran/resolve.c:15542
+#: fortran/resolve.c:15562
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr "шаг implied-do цикла в %L не может быть упрощен до константного значения"
 
-#: fortran/resolve.c:15667
+#: fortran/resolve.c:15687
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "DATA оператор в %L имеет больше значений чем переменных"
 
-#: fortran/resolve.c:15832
+#: fortran/resolve.c:15852
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
-msgstr "Метка %d в %L определена но не используется"
+msgstr "Метка %d в %L определена, но не используется"
 
-#: fortran/resolve.c:15838
+#: fortran/resolve.c:15858
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
-msgstr "Метка %d в %L определена но не может быть использована"
+msgstr "Метка %d в %L определена, но не может быть использована"
 
-#: fortran/resolve.c:15922
-#, fuzzy, gcc-internal-format
-#| msgid "Derived type variable '%s' at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
+#: fortran/resolve.c:15942
+#, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
-msgstr "Переменная производного типа '%s' в %L должна иметь SEQUENCE атрибут чтобы быть EQUIVALENCE объектом"
+msgstr "Переменная производного типа %qs в %L должна иметь SEQUENCE атрибут, чтобы быть EQUIVALENCE объектом"
 
-#: fortran/resolve.c:15931
-#, fuzzy, gcc-internal-format
-#| msgid "Derived type variable '%s' at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
+#: fortran/resolve.c:15951
+#, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
-msgstr "Переменная производного типа '%s' в %L не может иметь ALLOCATABLE компоненты чтобы быть EQUIVALENCE объектом"
+msgstr "Переменная производного типа %qs в %L не может иметь ALLOCATABLE компоненты, чтобы быть EQUIVALENCE объектом"
 
-#: fortran/resolve.c:15939
-#, fuzzy, gcc-internal-format
-#| msgid "Derived type variable '%s' at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
+#: fortran/resolve.c:15959
+#, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
-msgstr "Переменная производного типа '%s' в %L с подразумеваемой инициализацией не может быть в EQUIVALENCE с переменной в COMMON"
+msgstr "Переменная производного типа %qs в %L с подразумеваемой инициализацией не может быть в EQUIVALENCE с переменной в COMMON"
 
-#: fortran/resolve.c:15955
-#, fuzzy, gcc-internal-format
-#| msgid "Derived type variable '%s' at %L with pointer component(s) cannot be an EQUIVALENCE object"
+#: fortran/resolve.c:15975
+#, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
-msgstr "Переменная производного типа '%s' в %L с указательными компонентами не может быть EQUIVALENCE объектом"
+msgstr "Переменная производного типа %qs в %L с указательным(и) компонент(ами) не может быть EQUIVALENCE объектом"
 
-#: fortran/resolve.c:16058
+#: fortran/resolve.c:16078
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "Синтаксическая ошибка в EQUIVALENCE операторе в %L"
 
-#: fortran/resolve.c:16073
+#: fortran/resolve.c:16093
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
-msgstr "Все или никакие объекты в EQUIVALENCE множестве в %L должны иметь PROTECTED атрибут"
+msgstr "Все или никакие объекты в EQUIVALENCE установленной в %L должны иметь PROTECTED атрибут"
 
-#: fortran/resolve.c:16098
-#, fuzzy, gcc-internal-format
-#| msgid "Common block member '%s' at %L cannot be an EQUIVALENCE object in the pure procedure '%s'"
+#: fortran/resolve.c:16118
+#, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
-msgstr "Член common блока '%s' в %L не может быть EQUIVALENCE объектом в pure процедуре '%s'"
+msgstr ""
 
-#: fortran/resolve.c:16107
-#, fuzzy, gcc-internal-format
-#| msgid "Named constant '%s' at %L cannot be an EQUIVALENCE object"
+#: fortran/resolve.c:16127
+#, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
-msgstr "Именованная константа '%s' at %L не может быть EQUIVALENCE объектом"
+msgstr "Именованная константа %qs at %L не может быть EQUIVALENCE объектом"
 
-#: fortran/resolve.c:16180
-#, fuzzy, gcc-internal-format
-#| msgid "Array '%s' at %L with non-constant bounds cannot be an EQUIVALENCE object"
+#: fortran/resolve.c:16200
+#, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
-msgstr "Массив '%s' at %L с неконстантными границами не может быть EQUIVALENCE объектом"
+msgstr "Массив %qs at %L с неконстантными границами не может быть EQUIVALENCE объектом"
 
-#: fortran/resolve.c:16191
-#, fuzzy, gcc-internal-format
-#| msgid "Structure component '%s' at %L cannot be an EQUIVALENCE object"
+#: fortran/resolve.c:16211
+#, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
-msgstr "Компонент структуры '%s' at %L не может быть EQUIVALENCE объектом"
+msgstr "Компонент структуры %qs at %L не может быть EQUIVALENCE объектом"
 
-#: fortran/resolve.c:16202
+#: fortran/resolve.c:16222
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "Подстрока в %L имеет нулевую длину"
 
-#: fortran/resolve.c:16293
-#, fuzzy, gcc-internal-format
-#| msgid "Fortran 2003: PUBLIC function '%s' at %L of PRIVATE type '%s'"
+#: fortran/resolve.c:16253
+#, gcc-internal-format
+msgid "Self reference in character length expression for %qs at %L"
+msgstr ""
+
+#: fortran/resolve.c:16320
+#, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
-msgstr "Fortran 2003: PUBLIC функция '%s' в %L PRIVATE типа '%s'"
+msgstr "PUBLIC функция %qs в %L PRIVATE типа %qs"
 
-#: fortran/resolve.c:16306
-#, fuzzy, gcc-internal-format
-#| msgid "ENTRY '%s' at %L has no IMPLICIT type"
+#: fortran/resolve.c:16333
+#, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
-msgstr "ENTRY '%s' в %L не имеет IMPLICIT типа"
+msgstr "ENTRY %qs в %L не имеет IMPLICIT тип"
 
-#: fortran/resolve.c:16326
-#, fuzzy, gcc-internal-format
-#| msgid "User operator procedure '%s' at %L must be a FUNCTION"
+#: fortran/resolve.c:16353
+#, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
-msgstr "Процедура пользовательского оператора '%s' в %L должна быть FUNCTION"
+msgstr "Процедура пользовательского оператора %qs в %L должна быть FUNCTION"
 
-#: fortran/resolve.c:16336
-#, fuzzy, gcc-internal-format
-#| msgid "User operator procedure '%s' at %L cannot be assumed character length"
+#: fortran/resolve.c:16363
+#, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
-msgstr "Процедура пользовательского оператора '%s' в %L не может быть character предполагаемой длины"
+msgstr "Процедура пользовательского оператора %qs в %L не может быть предполагаемой character длиной"
 
-#: fortran/resolve.c:16344
-#, fuzzy, gcc-internal-format
-#| msgid "User operator procedure '%s' at %L must have at least one argument"
+#: fortran/resolve.c:16371
+#, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
-msgstr "Процедура пользовательского оператора '%s' в %L должна иметь по крайней мере один аргумент"
+msgstr "Процедура пользовательского оператора %qs в %L должна иметь по крайней мере один аргумент"
 
-#: fortran/resolve.c:16358
+#: fortran/resolve.c:16385
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "Первый аргумент интерфейса оператора в %L не может быть необязательным"
 
-#: fortran/resolve.c:16376
+#: fortran/resolve.c:16403
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "Второй аргумент интерфейса оператора в %L не может быть необязательным"
 
-#: fortran/resolve.c:16383
+#: fortran/resolve.c:16410
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "Интерфейс оператора в %L должен иметь не более двух аргументов"
 
-#: fortran/resolve.c:16461
-#, fuzzy, gcc-internal-format
-#| msgid "Contained procedure '%s' at %L of a PURE procedure must also be PURE"
+#: fortran/resolve.c:16488
+#, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
-msgstr "Внутренняя процедура '%s' в %L PURE процедуры должна также быть PURE"
+msgstr "Внутренняя процедура %qs в %L PURE процедуры должна также быть PURE"
 
 #
 #: fortran/scanner.c:332
-#, fuzzy, gcc-internal-format
-#| msgid "can't create directory %s: %m"
+#, gcc-internal-format
 msgid "Include directory %qs: %s"
-msgstr "ошибка создания каталога %s: %m"
+msgstr "Include каталог %qs: %s"
 
 #: fortran/scanner.c:336
-#, fuzzy, gcc-internal-format
-#| msgid "ignoring nonexistent directory \"%s\"\n"
+#, gcc-internal-format
 msgid "Nonexistent include directory %qs"
-msgstr "несуществующий каталог \"%s\" проигнорирован\n"
+msgstr "Несуществующий include каталог %qs"
 
 #: fortran/scanner.c:341
-#, fuzzy, gcc-internal-format
-#| msgid "%qD is not a type"
+#, gcc-internal-format
 msgid "%qs is not a directory"
-msgstr "%qD не является типом"
+msgstr "%qs не есть каталог"
 
 #: fortran/scanner.c:744
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "!$OMP at %C starts a commented line as it neither is followed by a space nor is a continuation line"
+#, gcc-internal-format, gfc-internal-format
 msgid "!$ACC at %C starts a commented line as it neither is followed by a space nor is a continuation line"
-msgstr "!$OMP в %C начинает закомментированную строку поскольку за ним не следует пробел и это не строка продолжения"
+msgstr "!$ACC в %C начинает закомментированную строку, поскольку за ним не следует пробел и это не строка продолжения"
 
 #: fortran/scanner.c:784
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP at %C starts a commented line as it neither is followed by a space nor is a continuation line"
-msgstr "!$OMP в %C начинает закомментированную строку поскольку за ним не следует пробел и это не строка продолжения"
+msgstr "!$OMP в %C начинает закомментированную строку, поскольку за ним не следует пробел и это не строка продолжения"
 
 #: fortran/scanner.c:1277 fortran/scanner.c:1470
 #, gcc-internal-format, gfc-internal-format
@@ -68027,18 +60815,17 @@
 #: fortran/scanner.c:1412 fortran/scanner.c:1509
 #, gcc-internal-format, gfc-internal-format
 msgid "Wrong OpenACC continuation at %C: expected !$ACC, got !$OMP"
-msgstr ""
+msgstr "Некорректное OpenACC продолжение в %C: ожидалось !$ACC, получено !$OMP"
 
 #: fortran/scanner.c:1414 fortran/scanner.c:1511
 #, gcc-internal-format, gfc-internal-format
 msgid "Wrong OpenMP continuation at %C: expected !$OMP, got !$ACC"
-msgstr ""
+msgstr "Некорректное OpenMP продолжение в %C: ожидалось !$OMP, получено !$ACC"
 
 #: fortran/scanner.c:1425
-#, fuzzy, gcc-internal-format
-#| msgid "Missing '&' in continued character constant at %C"
+#, gcc-internal-format
 msgid "Missing %<&%> in continued character constant at %C"
-msgstr "Отсутствует '&' в продолженной символьной константе в %C"
+msgstr "Отсутствует %<&%> в продолженной символьной константе в %C"
 
 #: fortran/scanner.c:1699
 #, gcc-internal-format, gfc-internal-format
@@ -68046,16 +60833,14 @@
 msgstr "Неподходящий символ табуляции в %C"
 
 #: fortran/scanner.c:1710
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Invalid character in name at %C"
+#, gcc-internal-format, gfc-internal-format
 msgid "Invalid character 0x%s at %C"
-msgstr "Некорректный символ в имени в %C"
+msgstr ""
 
 #: fortran/scanner.c:1795 fortran/scanner.c:1798
-#, fuzzy, gcc-internal-format
-#| msgid "'&' not allowed by itself in line %d"
+#, gcc-internal-format
 msgid "%<&%> not allowed by itself in line %d"
-msgstr "'&' не допускается сам по себе в строке %d"
+msgstr "%<&%> не допускается сам по себе в строке %d"
 
 #: fortran/scanner.c:1857
 #, gcc-internal-format, gfc-internal-format
@@ -68063,22 +60848,19 @@
 msgstr "Неподходящий символ табуляции в колонке %d строки %d"
 
 #: fortran/scanner.c:2086
-#, fuzzy, gcc-internal-format
-#| msgid "%s:%d: file %s left but not entered"
+#, gcc-internal-format
 msgid "file %qs left but not entered"
-msgstr "%s:%d: файл %s покидается без входа"
+msgstr "файл %qs покидается без входа"
 
 #: fortran/scanner.c:2124
-#, fuzzy, gcc-internal-format
-#| msgid "%s:%d: Illegal preprocessor directive"
+#, gcc-internal-format
 msgid "Illegal preprocessor directive"
-msgstr "%s:%d: Некорректная директива препроцессора"
+msgstr "Некорректная директива препроцессора"
 
 #: fortran/scanner.c:2251
-#, fuzzy, gcc-internal-format
-#| msgid "Can't open file '%s'"
+#, gcc-internal-format
 msgid "Can't open file %qs"
-msgstr "Ошибка открытия входного файла '%s'"
+msgstr "Ошибка открытия файла %qs"
 
 #: fortran/simplify.c:92
 #, gcc-internal-format, gfc-internal-format
@@ -68113,7 +60895,7 @@
 #: fortran/simplify.c:747
 #, gcc-internal-format
 msgid "gfc_simplify_abs(): Bad type"
-msgstr ""
+msgstr "gfc_simplify_abs(): Некорректный тип"
 
 #: fortran/simplify.c:768
 #, gcc-internal-format, gfc-internal-format
@@ -68138,7 +60920,7 @@
 #: fortran/simplify.c:844
 #, gcc-internal-format
 msgid "in gfc_simplify_acos(): Bad type"
-msgstr ""
+msgstr "в gfc_simplify_acos(): Некорректный тип"
 
 #: fortran/simplify.c:863
 #, gcc-internal-format, gfc-internal-format
@@ -68148,7 +60930,7 @@
 #: fortran/simplify.c:878
 #, gcc-internal-format
 msgid "in gfc_simplify_acosh(): Bad type"
-msgstr ""
+msgstr "в gfc_simplify_acosh(): Некорректный тип"
 
 #: fortran/simplify.c:1107
 #, gcc-internal-format, gfc-internal-format
@@ -68158,17 +60940,17 @@
 #: fortran/simplify.c:1121
 #, gcc-internal-format
 msgid "in gfc_simplify_asin(): Bad type"
-msgstr ""
+msgstr "в gfc_simplify_asin(): Некорректный тип"
 
 #: fortran/simplify.c:1149
 #, gcc-internal-format
 msgid "in gfc_simplify_asinh(): Bad type"
-msgstr ""
+msgstr "в gfc_simplify_asinh(): Некорректный тип"
 
 #: fortran/simplify.c:1177
 #, gcc-internal-format
 msgid "in gfc_simplify_atan(): Bad type"
-msgstr ""
+msgstr "в gfc_simplify_atan(): Некорректный тип"
 
 #: fortran/simplify.c:1198
 #, gcc-internal-format, gfc-internal-format
@@ -68178,7 +60960,7 @@
 #: fortran/simplify.c:1212
 #, gcc-internal-format
 msgid "in gfc_simplify_atanh(): Bad type"
-msgstr ""
+msgstr "в gfc_simplify_atanh(): Некорректный тип"
 
 #: fortran/simplify.c:1229
 #, gcc-internal-format, gfc-internal-format
@@ -68193,55 +60975,52 @@
 #: fortran/simplify.c:1690
 #, gcc-internal-format
 msgid "gfc_simplify_dcmplx(): Bad type (x)"
-msgstr ""
+msgstr "gfc_simplify_dcmplx(): Некорректный тип (x)"
 
 #: fortran/simplify.c:1709
 #, gcc-internal-format
 msgid "gfc_simplify_dcmplx(): Bad type (y)"
-msgstr ""
+msgstr "gfc_simplify_dcmplx(): Некорректный тип (y)"
 
 #: fortran/simplify.c:1790
 #, gcc-internal-format
 msgid "in simplify_trig_call(): Bad intrinsic"
-msgstr ""
+msgstr "в simplify_trig_call(): Некорректная встроенная функция"
 
 #: fortran/simplify.c:1850
-#, fuzzy, gcc-internal-format
-#| msgid "gfc_trans_code(): Bad statement code"
+#, gcc-internal-format
 msgid "in gfc_simplify_trigd(): Bad type"
-msgstr "gfc_trans_code(): Некорректный код оператора"
+msgstr "в gfc_simplify_trigd(): Некорректный тип"
 
 #: fortran/simplify.c:1868
-#, fuzzy, gcc-internal-format
-#| msgid "gfc_trans_code(): Bad statement code"
+#, gcc-internal-format
 msgid "in gfc_simplify_atrigd(): Bad type"
-msgstr "gfc_trans_code(): Некорректный код оператора"
+msgstr "в gfc_simplify_atrigd(): Некорректный тип"
 
 #: fortran/simplify.c:1892
-#, fuzzy, gcc-internal-format
-#| msgid "gfc_trans_code(): Bad statement code"
+#, gcc-internal-format
 msgid "in gfc_simplify_atan2d(): Bad type"
-msgstr "gfc_trans_code(): Некорректный код оператора"
+msgstr "в gfc_simplify_atan2d(): Некорректный тип"
 
 #: fortran/simplify.c:1930
 #, gcc-internal-format
 msgid "in gfc_simplify_cos(): Bad type"
-msgstr ""
+msgstr "в gfc_simplify_cos(): Некорректный тип"
 
 #: fortran/simplify.c:2289
 #, gcc-internal-format
 msgid "gfc_simplify_dim(): Bad type"
-msgstr ""
+msgstr "gfc_simplify_dim(): Некорректный тип"
 
 #: fortran/simplify.c:2859
 #, gcc-internal-format
 msgid "in gfc_simplify_exp(): Bad type"
-msgstr ""
+msgstr "в gfc_simplify_exp(): Некорректный тип"
 
 #: fortran/simplify.c:3081
 #, gcc-internal-format
 msgid "gfc_simplify_floor(): Bad kind"
-msgstr ""
+msgstr "gfc_simplify_floor(): Некорректный вид"
 
 #: fortran/simplify.c:3231
 #, gcc-internal-format, gfc-internal-format
@@ -68261,7 +61040,7 @@
 #: fortran/simplify.c:3378
 #, gcc-internal-format
 msgid "IBITS: Bad bit"
-msgstr ""
+msgstr "IBITS: Некорректный бит"
 
 #: fortran/simplify.c:3429
 #, gcc-internal-format, gfc-internal-format
@@ -68280,16 +61059,14 @@
 msgstr "Абсолютная величина второго аргумента %s превышает битовый размер в %L"
 
 #: fortran/simplify.c:3939
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Magnitude of second argument of ISHFTC exceeds BIT_SIZE of first argument at %L"
+#, gcc-internal-format, gfc-internal-format
 msgid "Magnitude of second argument of ISHFTC exceeds BIT_SIZE of first argument at %C"
-msgstr "Абсолютная величина второго аргумента ISHFTC превышает BIT_SIZE первого аргумента в %L"
+msgstr "Абсолютная величина второго аргумента ISHFTC превышает BIT_SIZE первого аргумента в %C"
 
 #: fortran/simplify.c:3942
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "The absolute value of SHIFT at %L must be less than or equal to SIZE at %L"
+#, gcc-internal-format, gfc-internal-format
 msgid "Absolute value of SHIFT shall be less than or equal to SIZE at %C"
-msgstr "Абсолютная величина SHIFT в %L должна быть меньше или равна SIZE в %L"
+msgstr "Абсолютная величина SHIFT должна быть меньше или равна SIZE в %C"
 
 #: fortran/simplify.c:4262 fortran/simplify.c:4394
 #, gcc-internal-format, gfc-internal-format
@@ -68309,7 +61086,7 @@
 #: fortran/simplify.c:4601
 #, gcc-internal-format
 msgid "gfc_simplify_log: bad type"
-msgstr ""
+msgstr "gfc_simplify_log: некорректный тип"
 
 #: fortran/simplify.c:4618
 #, gcc-internal-format, gfc-internal-format
@@ -68319,149 +61096,131 @@
 #: fortran/simplify.c:4941
 #, gcc-internal-format
 msgid "simplify_min_max(): Bad type in arglist"
+msgstr "simplify_min_max(): Некорректный тип в списке аргументов"
+
+#: fortran/simplify.c:5470 fortran/simplify.c:5478
+#, gcc-internal-format
+msgid "Argument %qs of MOD at %L shall not be zero"
 msgstr ""
 
-#. Result is processor-dependent.
-#: fortran/simplify.c:5472
-#, gcc-internal-format, gfc-internal-format
-msgid "Second argument MOD at %L is zero"
-msgstr "Второй аргумент MOD в %L нулевой"
-
-#. Result is processor-dependent.
-#: fortran/simplify.c:5483
-#, gcc-internal-format, gfc-internal-format
-msgid "Second argument of MOD at %L is zero"
-msgstr "Второй аргумент MOD в %L нулевой"
-
-#: fortran/simplify.c:5494
-#, fuzzy, gcc-internal-format
-#| msgid "gfc_trans_code(): Bad statement code"
+#: fortran/simplify.c:5484
+#, gcc-internal-format
 msgid "gfc_simplify_mod(): Bad arguments"
-msgstr "gfc_trans_code(): Некорректный код оператора"
+msgstr "gfc_simplify_mod(): Некорректные аргументы"
 
 #. Result is processor-dependent. This processor just opts
 #. to not handle it at all.
 #. Result is processor-dependent.
-#: fortran/simplify.c:5520 fortran/simplify.c:5532
+#: fortran/simplify.c:5525 fortran/simplify.c:5537
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of MODULO at %L is zero"
 msgstr "Второй аргумент MODULO в %L нулевой"
 
-#: fortran/simplify.c:5552
+#: fortran/simplify.c:5557
 #, gcc-internal-format
 msgid "gfc_simplify_modulo(): Bad arguments"
-msgstr ""
+msgstr "gfc_simplify_modulo(): Некорректные аргументы"
 
-#: fortran/simplify.c:5600
+#: fortran/simplify.c:5605
 #, gcc-internal-format, gfc-internal-format
 msgid "Result of NEAREST is NaN at %L"
 msgstr "Результат NEAREST есть NaN в %L"
 
-#: fortran/simplify.c:6081
+#: fortran/simplify.c:6086
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative at %L"
 msgstr "Аргумент NCOPIES встроенной функции REPEAT отрицателен в %L"
 
-#: fortran/simplify.c:6137
+#: fortran/simplify.c:6142
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument NCOPIES of REPEAT intrinsic is too large at %L"
 msgstr "Аргумент NCOPIES встроенной функции REPEAT слишком велик в %L"
 
-#: fortran/simplify.c:6174
+#: fortran/simplify.c:6179
 #, gcc-internal-format, gfc-internal-format
 msgid "Evaluation of string longer than 2**28 at %L deferred to runtime, expect bugs"
 msgstr ""
 
-#: fortran/simplify.c:6302
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Integer too large at %C"
+#: fortran/simplify.c:6307
+#, gcc-internal-format, gfc-internal-format
 msgid "Reshaped array too large at %C"
-msgstr "Целое слишком велико в %C"
+msgstr "Переформированный массив слишком велик в %C"
 
-#: fortran/simplify.c:6416
+#: fortran/simplify.c:6421
 #, gcc-internal-format, gfc-internal-format
 msgid "Result of SCALE overflows its kind at %L"
 msgstr "Результат SCALE переполняет свой вид в %L"
 
-#: fortran/simplify.c:6995
-#, fuzzy, gcc-internal-format
-#| msgid "Bad type in constant expression"
+#: fortran/simplify.c:7000
+#, gcc-internal-format
 msgid "Bad type in gfc_simplify_sign"
-msgstr "Некорректный тип в константном выражении"
+msgstr "Некорректный тип в gfc_simplify_sign"
 
-#: fortran/simplify.c:7024
+#: fortran/simplify.c:7029
 #, gcc-internal-format
 msgid "in gfc_simplify_sin(): Bad type"
-msgstr ""
+msgstr "в gfc_simplify_sin(): Некорректный тип"
 
-#: fortran/simplify.c:7151 fortran/simplify.c:7431
+#: fortran/simplify.c:7156 fortran/simplify.c:7436
 #, gcc-internal-format
 msgid "Failure getting length of a constant array."
-msgstr ""
+msgstr "Неудача при получении длины константного массива."
 
-#: fortran/simplify.c:7161
-#, fuzzy, gcc-internal-format
-#| msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit.   See -fmax-array-constructor option"
+#: fortran/simplify.c:7166
+#, gcc-internal-format
 msgid "The number of elements (%d) in the array constructor at %L requires an increase of the allowed %d upper limit.  See %<-fmax-array-constructor%> option."
-msgstr "Число элементов в конструкторе массива в %L требует увеличения допустимой %d верхней границы. См. опцию -fmax-array-constructor"
+msgstr "Число элементов (%d) в конструкторе массива в %L требует увеличения допустимой %d верхней границы.  См. опцию %<-fmax-array-constructor%>"
 
-#: fortran/simplify.c:7227
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Finalization at %L is not yet implemented"
+#: fortran/simplify.c:7232
+#, gcc-internal-format, gfc-internal-format
 msgid "Simplification of SPREAD at %C not yet implemented"
-msgstr "Финализация в %L пока не реализована"
+msgstr "Упрощение SPREAD в %C пока не реализовано"
 
-#: fortran/simplify.c:7251
+#: fortran/simplify.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SQRT at %L has a negative value"
 msgstr "Аргумент SQRT в %L имеет отрицательное значение"
 
 #
-#: fortran/simplify.c:7267
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Invalid second argument of IBSET at %L"
+#: fortran/simplify.c:7272
+#, gcc-internal-format, gfc-internal-format
 msgid "invalid argument of SQRT at %L"
-msgstr "Некорректный второй аргумент IBSET в %L"
+msgstr "Некорректный аргумент SQRT в %L"
 
-#: fortran/simplify.c:7598
+#: fortran/simplify.c:7603
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY lower bound is %ld)"
 msgstr "Вне границ в IMAGE_INDEX в %L для измерения %d, SUB имеет %ld и COARRAY нижняя граница есть %ld)"
 
-#: fortran/simplify.c:7621
+#: fortran/simplify.c:7626
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY upper bound is %ld)"
 msgstr "Вне границ в IMAGE_INDEX в %L для измерения %d, SUB имеет %ld и COARRAY верхняя граница есть %ld)"
 
-#: fortran/simplify.c:7993
-#, fuzzy, gcc-internal-format
-#| msgid "gfc_conv_constant_to_tree(): invalid type: %s"
+#: fortran/simplify.c:7998
+#, gcc-internal-format
 msgid "gfc_convert_constant(): Unexpected type"
-msgstr "gfc_conv_constant_to_tree(): некорректный тип: %s"
+msgstr "gfc_convert_constant(): Неожиданный тип"
 
-#: fortran/simplify.c:8078
-#, fuzzy, gcc-internal-format
-#| msgid "Character '%s' in string at %L cannot be converted into character kind %d"
+#: fortran/simplify.c:8083
+#, gcc-internal-format
 msgid "Character %qs in string at %L cannot be converted into character kind %d"
-msgstr "Символ '%s' в строке в %L не может быть преобразован в символьный вид %d"
+msgstr "Символ %qs в строке в %L не может быть преобразован в символьный вид %d"
 
 #: fortran/st.c:277
-#, fuzzy, gcc-internal-format
-#| msgid "gfc_trans_code(): Bad statement code"
+#, gcc-internal-format
 msgid "gfc_free_statement(): Bad statement"
-msgstr "gfc_trans_code(): Некорректный код оператора"
+msgstr "gfc_free_statement(): Некорректный оператор"
 
 #: fortran/symbol.c:141
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "SAVE statement at %C follows blanket SAVE statement"
+#, gcc-internal-format, gfc-internal-format
 msgid "IMPLICIT NONE (type) statement at %L following an IMPLICIT statement"
-msgstr "SAVE оператор в %C следует за общим SAVE оператором"
+msgstr "IMPLICIT NONE (тип) оператор в %L следует за IMPLICIT оператором"
 
 #: fortran/symbol.c:178
-#, fuzzy, gcc-internal-format
-#| msgid "Letter '%c' already set in IMPLICIT statement at %C"
+#, gcc-internal-format
 msgid "Letter %qc already set in IMPLICIT statement at %C"
-msgstr "Буква '%c' уже установлена в IMPLICIT операторе в %C"
+msgstr "Буква %qc уже установлена в IMPLICIT операторе в %C"
 
 #: fortran/symbol.c:200
 #, gcc-internal-format, gfc-internal-format
@@ -68469,58 +61228,52 @@
 msgstr "Невозможно специфицировать IMPLICIT в %C после IMPLICIT NONE"
 
 #: fortran/symbol.c:210
-#, fuzzy, gcc-internal-format
-#| msgid "Letter %c already has an IMPLICIT type at %C"
+#, gcc-internal-format
 msgid "Letter %qc already has an IMPLICIT type at %C"
-msgstr "Буква '%c' уже имеет IMPLICIT тип в %C"
+msgstr "Буква %qc уже имеет IMPLICIT тип в %C"
 
 #: fortran/symbol.c:234
 #, gcc-internal-format
 msgid "Option %<-fallow-leading-underscore%> is for use only by gfortran developers, and should not be used for implicitly typed variables"
-msgstr ""
+msgstr "Опция %<-fallow-leading-underscore%> предназначена только для использования разработчиками gfortran и не должна использоваться для неявно типизированных переменных"
 
 #: fortran/symbol.c:239
 #, gcc-internal-format
 msgid "gfc_get_default_type(): Bad symbol %qs"
-msgstr ""
+msgstr "gfc_get_default_type(): Некорректный символ %qs"
 
 #: fortran/symbol.c:296
 #, gcc-internal-format
 msgid "gfc_set_default_type(): symbol already has a type"
-msgstr ""
+msgstr "gfc_set_default_type(): символ уже имеет тип"
 
 #: fortran/symbol.c:306
-#, fuzzy, gcc-internal-format
-#| msgid "Symbol '%s' at %L has no IMPLICIT type"
+#, gcc-internal-format
 msgid "Symbol %qs at %L has no IMPLICIT type; did you mean %qs?"
-msgstr "Символ '%s' в %L не имеет IMPLICIT типа"
+msgstr "Символ %qs в %L не имеет IMPLICIT тип. Может имелось в виду %qs?"
 
 #: fortran/symbol.c:310
-#, fuzzy, gcc-internal-format
-#| msgid "Symbol '%s' at %L has no IMPLICIT type"
+#, gcc-internal-format
 msgid "Symbol %qs at %L has no IMPLICIT type"
-msgstr "Символ '%s' в %L не имеет IMPLICIT типа"
+msgstr "Символ %qs в %L не имеет IMPLICIT тип"
 
 #. BIND(C) variables should not be implicitly declared.
 #: fortran/symbol.c:330
-#, fuzzy, gcc-internal-format
-#| msgid "Implicitly declared BIND(C) variable '%s' at %L may not be C interoperable"
+#, gcc-internal-format
 msgid "Implicitly declared BIND(C) variable %qs at %L may not be C interoperable"
-msgstr "Неявно декларированная BIND(C) переменная '%s' в %L может не быть C совместимой"
+msgstr "Неявно декларированная BIND(C) переменная %qs в %L может не быть C совместимой"
 
 #. Dummy args to a BIND(C) routine may not be interoperable if
 #. they are implicitly typed.
 #: fortran/symbol.c:346
-#, fuzzy, gcc-internal-format
-#| msgid "Implicitly declared variable '%s' at %L may not be C interoperable but it is a dummy argument to the BIND(C) procedure '%s' at %L"
+#, gcc-internal-format
 msgid "Implicitly declared variable %qs at %L may not be C interoperable but it is a dummy argument to the BIND(C) procedure %qs at %L"
-msgstr "Неявно декларированная переменная '%s' в %L может не быть C совместимой но это формальный аргумент для BIND(C) процедуры '%s' в %L"
+msgstr "Неявно декларированная переменная %qs в %L может не быть C совместимой, но это формальный аргумент для BIND(C) процедуры %qs в %L"
 
 #: fortran/symbol.c:387
-#, fuzzy, gcc-internal-format
-#| msgid "Function result '%s' at %L has no IMPLICIT type"
+#, gcc-internal-format
 msgid "Function result %qs at %L has no IMPLICIT type"
-msgstr "Результат функции '%s' в %L не имеет IMPLICIT типа"
+msgstr "Результат функции %qs в %L не имеет IMPLICIT тип"
 
 #: fortran/symbol.c:485
 #, gcc-internal-format, gfc-internal-format
@@ -68535,13 +61288,12 @@
 #: fortran/symbol.c:529
 #, gcc-internal-format
 msgid "internal procedure %qs at %L conflicts with DUMMY argument"
-msgstr ""
+msgstr "внутренняя процедура %qs в %L конфликтует с DUMMY аргументом"
 
 #: fortran/symbol.c:562
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2003: Procedure pointer at %C"
+#, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer at %C"
-msgstr "Fortran 2003: Указатель на процедуру в %C"
+msgstr "Указатель на процедуру в %C"
 
 #: fortran/symbol.c:773
 #, gcc-internal-format, gfc-internal-format
@@ -68553,16 +61305,15 @@
 msgid "BIND(C) applied to %s %s at %L"
 msgstr "BIND(C) применен к %s %s в %L"
 
-#: fortran/symbol.c:901 fortran/symbol.c:912 fortran/symbol.c:1762
+#: fortran/symbol.c:901 fortran/symbol.c:912 fortran/symbol.c:1776
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute conflicts with %s attribute at %L"
 msgstr "%s атрибут конфликтует с %s атрибутом в %L"
 
 #: fortran/symbol.c:904 fortran/symbol.c:918
-#, fuzzy, gcc-internal-format
-#| msgid "%s attribute conflicts with %s attribute in '%s' at %L"
+#, gcc-internal-format
 msgid "%s attribute conflicts with %s attribute in %qs at %L"
-msgstr "%s атрибут конфликтует с %s атрибутом в '%s' в %L"
+msgstr "%s атрибут конфликтует с %s атрибутом в %qs в %L"
 
 #: fortran/symbol.c:962
 #, gcc-internal-format, gfc-internal-format
@@ -68585,22 +61336,19 @@
 msgstr "ALLOCATABLE специфицирован вне INTERFACE тела в %L"
 
 #: fortran/symbol.c:1040
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Duplicate VOLATILE attribute specified at %L"
+#, gcc-internal-format, gfc-internal-format
 msgid "Duplicate AUTOMATIC attribute specified at %L"
-msgstr "Повторный VOLATILE атрибут специфицирован в %L"
+msgstr "Повторный AUTOMATIC атрибут специфицирован в %L"
 
 #: fortran/symbol.c:1064
-#, fuzzy, gcc-internal-format
-#| msgid "CODIMENSION specified for '%s' outside its INTERFACE body at %L"
+#, gcc-internal-format
 msgid "CODIMENSION specified for %qs outside its INTERFACE body at %L"
-msgstr "CODIMENSION специфицирован для '%s' вне своего INTERFACE тела в %L"
+msgstr "CODIMENSION специфицирован для %qs вне своего INTERFACE тела в %L"
 
 #: fortran/symbol.c:1090
-#, fuzzy, gcc-internal-format
-#| msgid "DIMENSION specified for '%s' outside its INTERFACE body at %L"
+#, gcc-internal-format
 msgid "DIMENSION specified for %qs outside its INTERFACE body at %L"
-msgstr "DIMENSION специфицирован для '%s' вне своего INTERFACE тела в %L"
+msgstr "DIMENSION специфицирован для %qs вне своего INTERFACE тела в %L"
 
 #: fortran/symbol.c:1246
 #, gcc-internal-format, gfc-internal-format
@@ -68632,273 +61380,250 @@
 msgid "Duplicate VOLATILE attribute specified at %L"
 msgstr "Повторный VOLATILE атрибут специфицирован в %L"
 
-#: fortran/symbol.c:1367
+#: fortran/symbol.c:1360
 #, gcc-internal-format, gfc-internal-format
+msgid "VOLATILE attribute at %L cannot be specified in a PURE procedure"
+msgstr "Атрибут VOLATILE в %L нельзя указать в процедуре PURE"
+
+#: fortran/symbol.c:1381
+#, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ASYNCHRONOUS attribute specified at %L"
-msgstr "Повторный ASYNCHRONOUS атрибут специфицирован в %L"
+msgstr "Повторный атрибут ASYNCHRONOUS указан в %L"
 
-#: fortran/symbol.c:1758
-#, fuzzy, gcc-internal-format
-#| msgid "%s attribute of '%s' conflicts with %s attribute at %L"
+#: fortran/symbol.c:1772
+#, gcc-internal-format
 msgid "%s attribute of %qs conflicts with %s attribute at %L"
-msgstr "%s атрибут '%s' конфликтует с %s атрибутом в %L"
+msgstr "Атрибут %s %qs конфликтует с атрибутом %s в %L"
 
-#: fortran/symbol.c:1794
+#: fortran/symbol.c:1808
 #, gcc-internal-format, gfc-internal-format
 msgid ""
 "%s procedure at %L is already declared as %s procedure. \n"
 "F2008: A pointer function assignment is ambiguous if it is the first executable statement after the specification block. Please add any other kind of executable statement before it. FIXME"
 msgstr ""
+"Процедура %s в %L уже объявлена как процедура %s \n"
+"F2008: присваивание указательной функции неоднозначно, если оно является первым выполняемым оператором блока спецификаций. Добавьте перед ним выполняемый оператор любого другого. ИСПРАВИТЬ"
 
-#: fortran/symbol.c:1802
+#: fortran/symbol.c:1816
 #, gcc-internal-format, gfc-internal-format
 msgid "%s procedure at %L is already declared as %s procedure"
-msgstr "%s процедура в %L уже декларирована как %s процедура"
+msgstr "Процедура %s в %L уже объявлена как процедура %s"
 
-#: fortran/symbol.c:1837
+#: fortran/symbol.c:1851
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgstr "INTENT (%s)  конфликтует с INTENT(%s) в %L"
 
-#: fortran/symbol.c:1861
+#: fortran/symbol.c:1875
 #, gcc-internal-format, gfc-internal-format
 msgid "ACCESS specification at %L was already specified"
 msgstr "ACCESS спецификация в %L уже была специфицирована"
 
-#: fortran/symbol.c:1878
+#: fortran/symbol.c:1892
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate BIND attribute specified at %L"
 msgstr "Повторный BIND атрибут специфицирован в %L"
 
-#: fortran/symbol.c:1885
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2003: BIND(C) at %L"
+#: fortran/symbol.c:1899
+#, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) at %L"
-msgstr "Fortran 2003: BIND(C) в %L"
+msgstr "BIND(C) в %L"
 
-#: fortran/symbol.c:1901
+#: fortran/symbol.c:1915
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate EXTENDS attribute specified at %L"
 msgstr "Повторный EXTENDS атрибут специфицирован в %L"
 
-#: fortran/symbol.c:1905
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Fortran 2003: EXTENDS at %L"
+#: fortran/symbol.c:1919
+#, gcc-internal-format, gfc-internal-format
 msgid "EXTENDS at %L"
-msgstr "Fortran 2003: EXTENDS в %L"
+msgstr "EXTENDS в %L"
 
-#: fortran/symbol.c:1931
-#, fuzzy, gcc-internal-format
-#| msgid "Symbol '%s' at %L already has an explicit interface"
+#: fortran/symbol.c:1945
+#, gcc-internal-format
 msgid "Symbol %qs at %L already has an explicit interface"
-msgstr "Символ '%s' в %L уже имеет явный интерфейс"
+msgstr "Символ %qs в %L уже имеет явный интерфейс"
 
-#: fortran/symbol.c:1938
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' at %L has attributes specified outside its INTERFACE body"
+#: fortran/symbol.c:1952
+#, gcc-internal-format
 msgid "%qs at %L has attributes specified outside its INTERFACE body"
-msgstr "'%s' в %L имеет атрибуты специфицированные вне своего INTERFACE тела"
+msgstr "%qs в %L имеет атрибуты специфицированные вне своего INTERFACE тела"
 
-#: fortran/symbol.c:1976
-#, fuzzy, gcc-internal-format
-#| msgid "Symbol '%s' at %L conflicts with symbol from module '%s', use-associated at %L"
+#: fortran/symbol.c:1990
+#, gcc-internal-format
 msgid "Symbol %qs at %L conflicts with symbol from module %qs, use-associated at %L"
-msgstr "Символ '%s' в %L конфликтует с символом из модуля '%s', use-associated в %L"
+msgstr "Символ %qs в %L конфликтует с символом из модуля %qs, use-associated в %L"
 
-#: fortran/symbol.c:1980
-#, fuzzy, gcc-internal-format
-#| msgid "Symbol '%s' at %L already has basic type of %s"
+#: fortran/symbol.c:1994
+#, gcc-internal-format
 msgid "Symbol %qs at %L already has basic type of %s"
-msgstr "Символ '%s' в %L уже имеет базовый тип %s"
+msgstr "Символ %qs в %L уже имеет базовый тип %s"
 
-#: fortran/symbol.c:1987
-#, fuzzy, gcc-internal-format
-#| msgid "Procedure '%s' at %L may not have basic type of %s"
+#: fortran/symbol.c:2001
+#, gcc-internal-format
 msgid "Procedure %qs at %L may not have basic type of %s"
-msgstr "Процедура '%s' в %L не может иметь базовый тип %s"
+msgstr "Процедура %qs в %L не может иметь базовый тип %s"
 
-#: fortran/symbol.c:1999
-#, fuzzy, gcc-internal-format
-#| msgid "Symbol '%s' at %L cannot have a type"
+#: fortran/symbol.c:2013
+#, gcc-internal-format
 msgid "Symbol %qs at %L cannot have a type"
-msgstr "Символ '%s' в %L не может иметь тип"
+msgstr "Символ %qs в %L не может иметь тип"
 
-#: fortran/symbol.c:2242
-#, fuzzy, gcc-internal-format
-#| msgid "Component '%s' at %C already in the parent type at %L"
+#: fortran/symbol.c:2256
+#, gcc-internal-format
 msgid "Component %qs at %C already in the parent type at %L"
-msgstr "Компонент '%s' в %C уже в родительском типе в %L"
+msgstr "Компонент %qs в %C уже в родительском типе в %L"
 
-#: fortran/symbol.c:2327
-#, fuzzy, gcc-internal-format
-#| msgid "Symbol '%s' at %C is ambiguous"
+#: fortran/symbol.c:2341
+#, gcc-internal-format
 msgid "Symbol %qs at %C is ambiguous"
-msgstr "Символ '%s' в %C неоднозначен"
+msgstr "Символ %qs в %C неоднозначен"
 
-#: fortran/symbol.c:2359
-#, fuzzy, gcc-internal-format
-#| msgid "Derived type '%s' at %C is being used before it is defined"
+#: fortran/symbol.c:2373
+#, gcc-internal-format
 msgid "Derived type %qs at %C is being used before it is defined"
-msgstr "Производный тип '%s' в %C используется до своего определения"
+msgstr "Производный тип %qs в %C используется до своего определения"
 
-#: fortran/symbol.c:2508
-#, fuzzy, gcc-internal-format
-#| msgid "Component '%s' at %C is a PRIVATE component of '%s'"
+#: fortran/symbol.c:2522
+#, gcc-internal-format
 msgid "Component %qs at %C is a PRIVATE component of %qs"
-msgstr "Компонент '%s' в %C есть PRIVATE компонент '%s'"
+msgstr "Компонент %qs в %C есть PRIVATE компонент %qs"
 
-#: fortran/symbol.c:2529
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' at %C is not a member of the '%s' structure"
+#: fortran/symbol.c:2543
+#, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure; did you mean %qs?"
-msgstr "'%s' в %C не является членом '%s' структуры"
+msgstr "%qs в %C не является элементом структуры %qs. Может имелось в виду %qs?"
 
-#: fortran/symbol.c:2533
-#, fuzzy, gcc-internal-format
-#| msgid "'%s' at %C is not a member of the '%s' structure"
+#: fortran/symbol.c:2547
+#, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure"
-msgstr "'%s' в %C не является членом '%s' структуры"
+msgstr "%qs в %C не является элементом структуры %qs"
 
-#: fortran/symbol.c:2697
+#: fortran/symbol.c:2711
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr "Повторная метка оператора %d в %L и %L"
 
-#: fortran/symbol.c:2708
+#: fortran/symbol.c:2722
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr "Метка %d в %C уже фигурирует как цель перехода"
 
-#: fortran/symbol.c:2718
+#: fortran/symbol.c:2732
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr "Метка %d в %C уже фигурирует как метка формата"
 
-#: fortran/symbol.c:2724
+#: fortran/symbol.c:2738
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
-msgstr ""
+msgstr "завершающий оператор DO цикла не END DO или CONTINUE с меткой %d в %C"
 
-#: fortran/symbol.c:2766
+#: fortran/symbol.c:2780
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr "Метка %d в %C ранее использована как FORMAT метка"
 
-#: fortran/symbol.c:2775
+#: fortran/symbol.c:2789
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr "Метка %d в %C ранее использована как цель перехода"
 
-#: fortran/symbol.c:2781
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Expected terminating name at %C"
+#: fortran/symbol.c:2795
+#, gcc-internal-format, gfc-internal-format
 msgid "Shared DO termination label %d at %C"
-msgstr "Ожидалось завершающее имя в %C"
+msgstr "Разделяемая DO терминирующая метка %d в %C"
 
-#: fortran/symbol.c:3110
+#: fortran/symbol.c:3124
 #, gcc-internal-format
 msgid "new_symbol(): Symbol name too long"
-msgstr ""
+msgstr "new_symbol(): Имя символа слишком длинное"
 
-#: fortran/symbol.c:3135
-#, fuzzy, gcc-internal-format
-#| msgid "Name '%s' at %C is an ambiguous reference to '%s' from module '%s'"
+#: fortran/symbol.c:3149
+#, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
-msgstr "Имя '%s' в %C является неоднозначной ссылкой на '%s' из модуля '%s'"
+msgstr "Имя %qs в %C является неоднозначной ссылкой на %qs из модуля %qs"
 
-#: fortran/symbol.c:3138
-#, fuzzy, gcc-internal-format
-#| msgid "Name '%s' at %C is an ambiguous reference to '%s' from current program unit"
+#: fortran/symbol.c:3152
+#, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
-msgstr "Имя '%s' в %C является неоднозначной ссылкой на '%s' из текущей программной единицы"
+msgstr "Имя %qs в %C является неоднозначной ссылкой на %qs из текущей программной единицы"
 
 #. Symbol is from another namespace.
-#: fortran/symbol.c:3381
-#, fuzzy, gcc-internal-format
-#| msgid "Symbol '%s' at %C has already been host associated"
+#: fortran/symbol.c:3395
+#, gcc-internal-format
 msgid "Symbol %qs at %C has already been host associated"
-msgstr "Символ '%s' в %C уже был host ассоциирован"
+msgstr "Символ %qs в %C уже был host ассоциирован"
 
-#: fortran/symbol.c:4397
+#: fortran/symbol.c:4411
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
-msgstr ""
+msgstr "verify_bind_c_derived_type(): Данный символ неожиданно оказался NULL"
 
-#: fortran/symbol.c:4410
-#, fuzzy, gcc-internal-format
-#| msgid "Derived type '%s' declared at %L must have the BIND attribute to be C interoperable"
+#: fortran/symbol.c:4424
+#, gcc-internal-format
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
-msgstr "Производный тип '%s' декларированный в %L должен иметь BIND атрибут чтобы быть C совместимым"
+msgstr "Производный тип %qs декларированный в %L должен иметь BIND атрибут, чтобы быть C совместимым"
 
-#: fortran/symbol.c:4428
-#, fuzzy, gcc-internal-format
-#| msgid "Derived type '%s' with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
+#: fortran/symbol.c:4442
+#, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
-msgstr "Производный тип '%s' с BIND(C) атрибутом в %L пуст и может быть недоступен для C парного процессора"
+msgstr "Производный тип %qs с BIND(C) атрибутом в %L пуст и может быть недоступен для C парного процессора"
 
-#: fortran/symbol.c:4449
-#, fuzzy, gcc-internal-format
-#| msgid "Component '%s' at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type '%s' at %L"
+#: fortran/symbol.c:4463
+#, gcc-internal-format
 msgid "Component %qs at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type %qs at %L"
-msgstr "Компонент '%s' в %L не может иметь POINTER атрибут поскольку он является членом BIND(C) производного типа '%s' в %L"
+msgstr "Компонент %qs в %L не может иметь POINTER атрибут, поскольку он является элементом BIND(C) производного типа %qs в %L"
 
-#: fortran/symbol.c:4459
-#, fuzzy, gcc-internal-format
-#| msgid "Procedure pointer component '%s' at %L cannot be a member of the BIND(C) derived type '%s' at %L"
+#: fortran/symbol.c:4473
+#, gcc-internal-format
 msgid "Procedure pointer component %qs at %L cannot be a member of the BIND(C) derived type %qs at %L"
-msgstr "Компонент указатель на процедуру'%s' в %L не может быть членом BIND(C) производного типа '%s' в %L"
+msgstr "Компонент указатель на процедуру %qs в %L не может быть элементом BIND(C) производного типа %qs в %L"
 
-#: fortran/symbol.c:4470
-#, fuzzy, gcc-internal-format
-#| msgid "Component '%s' at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type '%s' at %L"
+#: fortran/symbol.c:4484
+#, gcc-internal-format
 msgid "Component %qs at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type %qs at %L"
-msgstr "Компонент '%s' в %L не может иметь ALLOCATABLE атрибут поскольку он является членом BIND(C) производного типа '%s' в %L"
+msgstr "Компонент %qs в %L не может иметь ALLOCATABLE атрибут, поскольку он является элементом BIND(C) производного типа %qs в %L"
 
-#: fortran/symbol.c:4509
-#, fuzzy, gcc-internal-format
-#| msgid "Component '%s' in derived type '%s' at %L may not be C interoperable, even though derived type '%s' is BIND(C)"
+#: fortran/symbol.c:4523
+#, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
-msgstr "Компонент '%s' в производном типе '%s' в %L может не быть C совместимым хотя производный тип '%s' есть BIND(C)"
+msgstr "Компонент %qs в производном типе %qs в %L может не быть C совместимым хотя производный тип %qs есть BIND(C)"
 
-#: fortran/symbol.c:4519
-#, fuzzy, gcc-internal-format
-#| msgid "Component '%s' in derived type '%s' at %L may not be C interoperable"
+#: fortran/symbol.c:4533
+#, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
-msgstr "Компонент '%s' в производном типе '%s' в %L может не быть C совместимым"
+msgstr "Компонент %qs в производном типе %qs в %L может не быть C совместимым"
 
-#: fortran/symbol.c:4533
-#, fuzzy, gcc-internal-format
-#| msgid "Derived type '%s' at %L cannot be declared with both PRIVATE and BIND(C) attributes"
+#: fortran/symbol.c:4547
+#, gcc-internal-format
 msgid "Derived type %qs at %L cannot be declared with both PRIVATE and BIND(C) attributes"
-msgstr "Производный тип '%s' в %L не может быть декларирован с обоими PRIVATE и BIND(C) атрибутами"
+msgstr "Производный тип %qs в %L не может быть декларирован и с PRIVATE и с BIND(C) атрибутами"
 
-#: fortran/symbol.c:4541
-#, fuzzy, gcc-internal-format
-#| msgid "Derived type '%s' at %L cannot have the SEQUENCE attribute because it is BIND(C)"
+#: fortran/symbol.c:4555
+#, gcc-internal-format
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
-msgstr "Производный тип '%s' в %L не может иметь SEQUENCE атрибут поскольку он есть BIND(C)"
+msgstr "Производный тип %qs в %L не может иметь SEQUENCE атрибут, поскольку он есть BIND(C)"
 
-#: fortran/symbol.c:5018 fortran/symbol.c:5023
-#, fuzzy, gcc-internal-format
-#| msgid "Symbol '%s' is used before it is typed at %L"
+#: fortran/symbol.c:5032 fortran/symbol.c:5037
+#, gcc-internal-format
 msgid "Symbol %qs is used before it is typed at %L"
-msgstr "Символ '%s' используется до своего типизирования в %L"
+msgstr "Символ %qs используется до своего типизирования в %L"
 
 #: fortran/target-memory.c:126
-#, fuzzy, gcc-internal-format
-#| msgid "invalid expression for min lvalue"
+#, gcc-internal-format
 msgid "Invalid expression in gfc_element_size."
-msgstr "некорректное выражение в левой части операции min"
+msgstr "некорректное выражение в gfc_element_size."
 
 #: fortran/target-memory.c:345
 #, gcc-internal-format
 msgid "Invalid expression in gfc_target_encode_expr."
-msgstr ""
+msgstr "Некорректное выражение в gfc_target_encode_expr."
 
 #: fortran/target-memory.c:614
 #, gcc-internal-format
 msgid "Invalid expression in gfc_target_interpret_expr."
-msgstr ""
+msgstr "Некорректное выражение в gfc_target_interpret_expr."
 
 #: fortran/target-memory.c:687
 #, gcc-internal-format, gfc-internal-format
@@ -68906,10 +61631,9 @@
 msgstr "Перекрывающиеся неравные инициализаторы в EQUIVALENCE в %L"
 
 #: fortran/target-memory.c:690
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Overlapping unequal initializers in EQUIVALENCE at %L"
+#, gcc-internal-format, gfc-internal-format
 msgid "Overlapping unequal initializers in EQUIVALENCE at %C"
-msgstr "Перекрывающиеся неравные инициализаторы в EQUIVALENCE в %L"
+msgstr "Перекрывающиеся неравные инициализаторы в EQUIVALENCE в %C"
 
 #: fortran/target-memory.c:778
 #, gcc-internal-format, gfc-internal-format
@@ -68919,38 +61643,34 @@
 #. Problems occur when we get something like
 #. integer :: a(lots) = (/(i, i=1, lots)/)
 #: fortran/trans-array.c:5927
-#, fuzzy, gcc-internal-format
-#| msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit.   See -fmax-array-constructor option"
+#, gcc-internal-format
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit. See %<-fmax-array-constructor%> option"
-msgstr "Число элементов в конструкторе массива в %L требует увеличения допустимой %d верхней границы. См. опцию -fmax-array-constructor"
+msgstr ""
 
 #: fortran/trans-array.c:7860
-#, fuzzy, gcc-internal-format
-#| msgid "Creating array temporary at %L for argument '%s'"
+#, gcc-internal-format
 msgid "Creating array temporary at %L for argument %qs"
-msgstr "Создание временного массива в %L для аргумента '%s'"
+msgstr "Создание временного массива в %L для аргумента %qs"
 
-#: fortran/trans-array.c:10693
+#: fortran/trans-array.c:10724
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr "Некорректный тип выражения при проходе (%d)"
 
 #: fortran/trans-common.c:401
-#, fuzzy, gcc-internal-format
-#| msgid "Named COMMON block '%s' at %L shall be of the same size as elsewhere (%lu vs %lu bytes)"
+#, gcc-internal-format
 msgid "Named COMMON block %qs at %L shall be of the same size as elsewhere (%lu vs %lu bytes)"
-msgstr "Именованный COMMON блок '%s' at %L везде должен быть одного размера (%lu против %lu байт)"
+msgstr "Именованный COMMON блок %qs at %L везде должен быть одного размера (%lu против %lu байт)"
 
 #: fortran/trans-common.c:782
-#, fuzzy, gcc-internal-format
-#| msgid "requested position is not an integer constant"
+#, gcc-internal-format
 msgid "get_mpz(): Not an integer constant"
-msgstr "заданная позиция не является целой константой"
+msgstr "get_mpz(): Не целая константа"
 
 #: fortran/trans-common.c:810
 #, gcc-internal-format
 msgid "element_number(): Bad dimension type"
-msgstr ""
+msgstr "element_number(): Некорректный тип размерности"
 
 #: fortran/trans-common.c:880
 #, gcc-internal-format, gfc-internal-format
@@ -68963,59 +61683,50 @@
 msgstr "Некорректный тип ссылки в %L как EQUIVALENCE объект"
 
 #: fortran/trans-common.c:928
-#, fuzzy, gcc-internal-format
-#| msgid "Inconsistent equivalence rules involving '%s' at %L and '%s' at %L"
+#, gcc-internal-format
 msgid "Inconsistent equivalence rules involving %qs at %L and %qs at %L"
-msgstr "Противоречивые правила эквивалентности включающие %s' в %L и '%s' в %L"
+msgstr "Противоречивые правила эквивалентности включающие %qs в %L и %qs в %L"
 
 #. Aligning this field would misalign a previous field.
 #: fortran/trans-common.c:1061
-#, fuzzy, gcc-internal-format
-#| msgid "The equivalence set for variable '%s' declared at %L violates alignment requirements"
+#, gcc-internal-format
 msgid "The equivalence set for variable %qs declared at %L violates alignment requirements"
-msgstr "Множество эквивалентности для переменной '%s' декларированной в %L нарушает требования выравнивания"
+msgstr "Эквивалентность установленная для переменной %qs декларированной в %L нарушает требования выравнивания"
 
 #: fortran/trans-common.c:1126
-#, fuzzy, gcc-internal-format
-#| msgid "Equivalence for '%s' does not match ordering of COMMON '%s' at %L"
+#, gcc-internal-format
 msgid "Equivalence for %qs does not match ordering of COMMON %qs at %L"
-msgstr "Эквивалентность для '%s' не соответствует упорядочению COMMON'%s' at %L"
+msgstr "Эквивалентность для %qs не соответствует упорядочению COMMON %qs в %L"
 
 #: fortran/trans-common.c:1141
-#, fuzzy, gcc-internal-format
-#| msgid "The equivalence set for '%s' cause an invalid extension to COMMON '%s' at %L"
+#, gcc-internal-format
 msgid "The equivalence set for %qs cause an invalid extension to COMMON %qs at %L"
-msgstr "Множество эквивалентности для '%s' вызывает некорректное расширение COMMON '%s' at %L"
+msgstr "Эквивалентность установленная для %qs вызывает некорректное расширение COMMON %qs at %L"
 
 #: fortran/trans-common.c:1157
-#, fuzzy, gcc-internal-format
-#| msgid "Padding of %d bytes required before '%s' in COMMON '%s' at %L; reorder elements or use -fno-align-commons"
+#, gcc-internal-format
 msgid "Padding of %d bytes required before %qs in COMMON %qs at %L; reorder elements or use -fno-align-commons"
-msgstr "Заполнитель в %d байт требуется перед '%s' в COMMON '%s' в %L; измените порядок элементов или используйте -fno-align-commons"
+msgstr "Заполнитель в %d байт требуется перед %qs в COMMON %qs в %L; измените порядок элементов или используйте -fno-align-commons"
 
 #: fortran/trans-common.c:1163
-#, fuzzy, gcc-internal-format
-#| msgid "Padding of %d bytes required before '%s' in COMMON at %L; reorder elements or use -fno-align-commons"
+#, gcc-internal-format
 msgid "Padding of %d bytes required before %qs in COMMON at %L; reorder elements or use -fno-align-commons"
-msgstr "Заполнитель в %d байт требуется перед '%s' в COMMON в %L; измените порядок элементов или используйте -fno-align-commons"
+msgstr "Заполнитель в %d байт требуется перед %qs в COMMON в %L; измените порядок элементов или используйте -fno-align-commons"
 
 #: fortran/trans-common.c:1184
-#, fuzzy, gcc-internal-format
-#| msgid "COMMON '%s' at %L does not exist"
+#, gcc-internal-format
 msgid "COMMON %qs at %L does not exist"
-msgstr "COMMON '%s' в %L не существует"
+msgstr "COMMON %qs в %L не существует"
 
 #: fortran/trans-common.c:1193
-#, fuzzy, gcc-internal-format
-#| msgid "COMMON '%s' at %L requires %d bytes of padding; reorder elements or use -fno-align-commons"
+#, gcc-internal-format
 msgid "COMMON %qs at %L requires %d bytes of padding; reorder elements or use %<-fno-align-commons%>"
-msgstr "COMMON '%s' в %L требует %d байт заполнителя; измените порядок элементов или используйте -fno-align-commons"
+msgstr "COMMON %qs в %L требует %d байт заполнителя; измените порядок элементов или используйте %<-fno-align-commons%>"
 
 #: fortran/trans-common.c:1198
-#, fuzzy, gcc-internal-format
-#| msgid "COMMON at %L requires %d bytes of padding; reorder elements or use -fno-align-commons"
+#, gcc-internal-format
 msgid "COMMON at %L requires %d bytes of padding; reorder elements or use %<-fno-align-commons%>"
-msgstr "COMMON в %L требует %d байт заполнителя; измените порядок элементов или используйте -fno-align-commons"
+msgstr "COMMON в %L требует %d байт заполнителя; измените порядок элементов или используйте %<-fno-align-commons%>"
 
 #: fortran/trans-const.c:335
 #, gcc-internal-format, gfc-internal-format
@@ -69035,13 +61746,12 @@
 #: fortran/trans-decl.c:1702
 #, gcc-internal-format
 msgid "intrinsic variable which isn't a procedure"
-msgstr "встроенная переменная которая не есть процедура"
+msgstr "встроенная переменная, которая не является процедурой"
 
 #: fortran/trans-decl.c:4284 fortran/trans-decl.c:6585
-#, fuzzy, gcc-internal-format
-#| msgid "Return value of function '%s' at %L not set"
+#, gcc-internal-format
 msgid "Return value of function %qs at %L not set"
-msgstr "Возвращаемое значение функции '%s' в %L не установлено"
+msgstr "Возвращаемое значение функции %qs в %L не установлено"
 
 #: fortran/trans-decl.c:4765
 #, gcc-internal-format
@@ -69049,91 +61759,79 @@
 msgstr "Параметр отложенного типа пока не поддерживается"
 
 #: fortran/trans-decl.c:4994
-#, fuzzy, gcc-internal-format
-#| msgid "backend decl for module variable %s already exists"
+#, gcc-internal-format
 msgid "backend decl for module variable %qs already exists"
-msgstr "backend декларация для переменной модуля %s уже существует"
+msgstr "backend декларация для переменной модуля %qs уже существует"
 
 #: fortran/trans-decl.c:5007
-#, fuzzy, gcc-internal-format
-#| msgid "Unused variable '%s' declared at %L"
+#, gcc-internal-format
 msgid "Unused PRIVATE module variable %qs declared at %L"
-msgstr "Неиспользуемая переменная '%s' декларирована в %L"
+msgstr "Неиспользуемая PRIVATE переменная модуля %qs декларирована в %L"
 
 #: fortran/trans-decl.c:5605
-#, fuzzy, gcc-internal-format
-#| msgid "Dummy argument '%s' at %L was declared INTENT(OUT) but was not set"
+#, gcc-internal-format
 msgid "Dummy argument %qs at %L was declared INTENT(OUT) but was not set"
-msgstr "Формальный аргумент '%s' в %L был декларирован INTENT(OUT) но не был установлен"
+msgstr "Формальный аргумент %qs в %L был декларирован INTENT(OUT), но не был установлен"
 
 #: fortran/trans-decl.c:5611
-#, fuzzy, gcc-internal-format
-#| msgid "Derived-type dummy argument '%s' at %L was declared INTENT(OUT) but was not set and does not have a default initializer"
+#, gcc-internal-format
 msgid "Derived-type dummy argument %qs at %L was declared INTENT(OUT) but was not set and does not have a default initializer"
-msgstr "Формальный аргумент производного типа '%s' в %L был декларирован INTENT(OUT) но не был установлен и не имеет подразумеваемого инициализатора"
+msgstr "Формальный аргумент производного типа %qs в %L был декларирован INTENT(OUT), но не был установлен и не имеет подразумеваемого инициализатора"
 
 #: fortran/trans-decl.c:5621 fortran/trans-decl.c:5762
-#, fuzzy, gcc-internal-format
-#| msgid "Unused dummy argument '%s' at %L"
+#, gcc-internal-format
 msgid "Unused dummy argument %qs at %L"
-msgstr "Неиспользуемый формальный аргумент '%s' в %L"
+msgstr "Неиспользуемый формальный аргумент %qs в %L"
 
 #: fortran/trans-decl.c:5636
-#, fuzzy, gcc-internal-format
-#| msgid "Unused module variable '%s' which has been explicitly imported at %L"
+#, gcc-internal-format
 msgid "Unused module variable %qs which has been explicitly imported at %L"
-msgstr "Неиспользуемая переменная модуля '%s' которая была явно импортирована в %L"
+msgstr "Неиспользуемая переменная модуля %qs, которая была явно импортирована в %L"
 
 #: fortran/trans-decl.c:5655
-#, fuzzy, gcc-internal-format
-#| msgid "Unused variable '%s' declared at %L"
+#, gcc-internal-format
 msgid "Unused variable %qs declared at %L"
-msgstr "Неиспользуемая переменная '%s' декларирована в %L"
+msgstr "Неиспользуемая переменная %qs декларирована в %L"
 
 #: fortran/trans-decl.c:5704
-#, fuzzy, gcc-internal-format
-#| msgid "Unused parameter '%s' declared at %L"
+#, gcc-internal-format
 msgid "Unused parameter %qs declared at %L"
-msgstr "Неиспользуемый параметр '%s' декларирован в %L"
+msgstr "Неиспользуемый параметр %qs декларирован в %L"
 
 #: fortran/trans-decl.c:5708
-#, fuzzy, gcc-internal-format
-#| msgid "Unused parameter '%s' which has been explicitly imported at %L"
+#, gcc-internal-format
 msgid "Unused parameter %qs which has been explicitly imported at %L"
-msgstr "Неиспользуемый параметр '%s' который был явно импортирован в %L"
+msgstr "Неиспользуемый параметр %qs, который был явно импортирован в %L"
 
 #: fortran/trans-decl.c:5734
-#, fuzzy, gcc-internal-format
-#| msgid "Return value '%s' of function '%s' declared at %L not set"
+#, gcc-internal-format
 msgid "Return value %qs of function %qs declared at %L not set"
-msgstr "Возвращаемое значение '%s' функции '%s' декларированное в %L не установлено"
+msgstr "Возвращаемое значение %qs функции %qs декларированное в %L не установлено"
 
 #: fortran/trans-decl.c:6311
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, !$ACC DECLARE at %L is not allowed in BLOCK construct"
-msgstr ""
+msgstr "Извините, !$ACC DECLARE в %L не допускается в конструкции BLOCK"
 
 #: fortran/trans-expr.c:926
 #, gcc-internal-format, gfc-internal-format
 msgid "Can't compute the length of the char array at %L."
-msgstr ""
+msgstr "Не могу вычислить длину char массива в %L."
 
 #: fortran/trans-expr.c:1585
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable variable at %L will be added"
-msgstr ""
+msgstr "Код для переразмещения размещаемой переменной в %L будет добавлен"
 
 #: fortran/trans-expr.c:1883
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Unlimited polymorphism at %C not yet supported"
+#, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic object at %L is not supported"
-msgstr "Неограниченный полиморфизм в %C пока не поддерживается"
+msgstr "Простите, коиндексированный доступ к неограниченному полиморфному объекту в %L не поддерживается"
 
 #: fortran/trans-expr.c:1892
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Unlimited polymorphism at %C not yet supported"
+#, gcc-internal-format, gfc-internal-format
 msgid "Sorry, coindexed access to an unlimited polymorphic component at %L is not supported"
-msgstr "Неограниченный полиморфизм в %C пока не поддерживается"
+msgstr "Простите, коиндексированный доступ к неограниченному полиморфному компоненту в %L не поддерживается"
 
 #: fortran/trans-expr.c:3412
 #, gcc-internal-format
@@ -69146,34 +61844,30 @@
 msgstr "Неизвестная функция списка аргументов в %L"
 
 #: fortran/trans-intrinsic.c:855
-#, fuzzy, gcc-internal-format
-#| msgid "Intrinsic function %s(%d) not recognized"
+#, gcc-internal-format
 msgid "Intrinsic function %qs (%d) not recognized"
-msgstr "Встроенная операция %s(%d) не опознана"
+msgstr "Встроенная функция %qs (%d) не опознана"
 
 #: fortran/trans-intrinsic.c:2360 fortran/trans-intrinsic.c:2825
 #: fortran/trans-intrinsic.c:3022
-#, fuzzy, gcc-internal-format
-#| msgid "'dim' argument of %s intrinsic at %L is not a valid dimension index"
+#, gcc-internal-format
 msgid "%<dim%> argument of %s intrinsic at %L is not a valid dimension index"
-msgstr "'dim' аргумент встроенной функции %s в %L не есть корректный индекс измерения"
+msgstr "%<dim%> аргумент встроенной функции %s в %L не есть корректный индекс измерения"
 
-#: fortran/trans-intrinsic.c:10572 fortran/trans-stmt.c:1050
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Deferred-length character component '%s' at %L is not yet supported"
+#: fortran/trans-intrinsic.c:10574 fortran/trans-stmt.c:1050
+#, gcc-internal-format, gfc-internal-format
 msgid "Sorry, the event component of derived type at %L is not yet supported"
-msgstr "Character компонент с отложенной длиной '%s' в %L пока не поддерживается"
+msgstr "Простите, event компонент производного типа в %L пока не поддерживается"
 
-#: fortran/trans-intrinsic.c:10579
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Pointer object at %C shall not be coindexed"
+#: fortran/trans-intrinsic.c:10581
+#, gcc-internal-format, gfc-internal-format
 msgid "The event variable at %L shall not be coindexed"
-msgstr "Указательный объект в %C не должен быть коиндексирован"
+msgstr "event переменная в %L не должен быть коиндексирована"
 
 #: fortran/trans-io.c:1967
 #, gcc-internal-format
 msgid "build_dt: format with namelist"
-msgstr ""
+msgstr "build_dt: формат со списком имен"
 
 #: fortran/trans-io.c:2510
 #, gcc-internal-format, gfc-internal-format
@@ -69181,10 +61875,9 @@
 msgstr "Некорректный базовый тип ввода-вывода (%d)"
 
 #: fortran/trans-openmp.c:1058
-#, fuzzy, gcc-internal-format
-#| msgid "Bad specification for assumed size array at %C"
+#, gcc-internal-format
 msgid "implicit mapping of assumed size array %qD"
-msgstr "Некорректная спецификация для массива предполагаемого размера в %C"
+msgstr "неявное отображение массива предполагаемого размера %qD"
 
 #: fortran/trans-openmp.c:4997
 #, gcc-internal-format
@@ -69197,10 +61890,9 @@
 msgstr "Альтернативный возврат в %L без * формального аргумента"
 
 #: fortran/trans-stmt.c:853
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "Deferred-length character component '%s' at %L is not yet supported"
+#, gcc-internal-format, gfc-internal-format
 msgid "Sorry, the lock component of derived type at %L is not yet supported"
-msgstr "Character компонент с отложенной длиной '%s' в %L пока не поддерживается"
+msgstr "Простите, lock компонент производного типа в %L пока не поддерживается"
 
 #: fortran/trans-stmt.c:1312
 #, gcc-internal-format, gfc-internal-format
@@ -69207,87 +61899,75 @@
 msgid "Sorry, only support for integer kind %d implemented for image-set at %L"
 msgstr "Извините, поддержка только для integer вида %d реализована для image-set в %L"
 
-#: fortran/trans-stmt.c:3346
-#, fuzzy, gcc-internal-format
-#| msgid "gfc_trans_code(): Bad statement code"
+#: fortran/trans-stmt.c:3343
+#, gcc-internal-format
 msgid "gfc_trans_select(): Bad type for case expr."
-msgstr "gfc_trans_code(): Некорректный код оператора"
+msgstr "gfc_trans_select(): Некорректный тип для case выражения."
 
 #: fortran/trans-types.c:555
-#, fuzzy, gcc-internal-format
-#| msgid "INTEGER(KIND=8) is not available for -fdefault-integer-8 option"
+#, gcc-internal-format
 msgid "INTEGER(KIND=8) is not available for %<-fdefault-integer-8%> option"
-msgstr "INTEGER(KIND=8) недоступно для -fdefault-integer-8 опции"
+msgstr "INTEGER(KIND=8) недоступно для %<-fdefault-integer-8%> опции"
 
 #: fortran/trans-types.c:564
-#, fuzzy, gcc-internal-format
-#| msgid "INTEGER(KIND=8) is not available for -finteger-4-integer-8 option"
+#, gcc-internal-format
 msgid "INTEGER(KIND=8) is not available for %<-finteger-4-integer-8%> option"
-msgstr "INTEGER(KIND=8) недоступно для -finteger-4-integer-8 опции"
+msgstr "INTEGER(KIND=8) недоступно для %<-finteger-4-integer-8%> опции"
 
 #: fortran/trans-types.c:583
-#, fuzzy, gcc-internal-format
-#| msgid "REAL(KIND=8) is not available for -fdefault-real-8 option"
+#, gcc-internal-format
 msgid "REAL(KIND=8) is not available for %<-fdefault-real-8%> option"
-msgstr "REAL(KIND=8) недоступно для -fdefault-real-8 опции"
+msgstr "REAL(KIND=8) недоступно для %<-fdefault-real-8%> опции"
 
 #: fortran/trans-types.c:591
-#, fuzzy, gcc-internal-format
-#| msgid "REAL(KIND=8) is not available for -fdefault-real-8 option"
+#, gcc-internal-format
 msgid "REAL(KIND=10) is not available for %<-fdefault-real-10%> option"
-msgstr "REAL(KIND=8) недоступно для -fdefault-real-8 опции"
+msgstr ""
 
 #: fortran/trans-types.c:599
-#, fuzzy, gcc-internal-format
-#| msgid "REAL(KIND=8) is not available for -fdefault-real-8 option"
+#, gcc-internal-format
 msgid "REAL(KIND=16) is not available for %<-fdefault-real-16%> option"
-msgstr "REAL(KIND=8) недоступно для -fdefault-real-8 опции"
+msgstr ""
 
 #: fortran/trans-types.c:607
-#, fuzzy, gcc-internal-format
-#| msgid "REAL(KIND=8) is not available for -freal-4-real-8 option"
+#, gcc-internal-format
 msgid "REAL(KIND=8) is not available for %<-freal-4-real-8%> option"
-msgstr "REAL(KIND=8) недоступно для -freal-4-real-8 опции"
+msgstr "REAL(KIND=8) недоступно для %<-freal-4-real-8%> опции"
 
 #: fortran/trans-types.c:615
-#, fuzzy, gcc-internal-format
-#| msgid "REAL(KIND=10) is not available for -freal-4-real-10 option"
+#, gcc-internal-format
 msgid "REAL(KIND=10) is not available for %<-freal-4-real-10%> option"
-msgstr "REAL(KIND=10) недоступно для -freal-4-real-10 опции"
+msgstr "REAL(KIND=10) недоступно для %<-freal-4-real-10%> опции"
 
 #: fortran/trans-types.c:623
-#, fuzzy, gcc-internal-format
-#| msgid "REAL(KIND=16) is not available for -freal-4-real-16 option"
+#, gcc-internal-format
 msgid "REAL(KIND=16) is not available for %<-freal-4-real-16%> option"
-msgstr "REAL(KIND=16) недоступно для -freal-4-real-16 опции"
+msgstr "REAL(KIND=16) недоступно для %<-freal-4-real-16%> опции"
 
 #: fortran/trans-types.c:654
-#, fuzzy, gcc-internal-format
-#| msgid "REAL(KIND=4) is not available for -freal-8-real-4 option"
+#, gcc-internal-format
 msgid "REAL(KIND=4) is not available for %<-freal-8-real-4%> option"
-msgstr "REAL(KIND=4) недоступно для -freal-8-real-4 опции"
+msgstr "REAL(KIND=4) недоступно для %<-freal-8-real-4%> опции"
 
 #: fortran/trans-types.c:662
-#, fuzzy, gcc-internal-format
-#| msgid "REAL(KIND=10) is not available for -freal-8-real-10 option"
+#, gcc-internal-format
 msgid "REAL(KIND=10) is not available for %<-freal-8-real-10%> option"
-msgstr "REAL(KIND=10) недоступно для -freal-8-real-10 опции"
+msgstr "REAL(KIND=10) недоступно для %<-freal-8-real-10%> опции"
 
 #: fortran/trans-types.c:670
-#, fuzzy, gcc-internal-format
-#| msgid "REAL(KIND=10) is not available for -freal-8-real-16 option"
+#, gcc-internal-format
 msgid "REAL(KIND=10) is not available for %<-freal-8-real-16%> option"
-msgstr "REAL(KIND=10) недоступно для -freal-8-real-16 опции"
+msgstr "REAL(KIND=10) недоступно для %<-freal-8-real-16%> опции"
 
 #: fortran/trans-types.c:810
 #, gcc-internal-format
 msgid "gfc_validate_kind(): Got bad type"
-msgstr ""
+msgstr "gfc_validate_kind(): Получен некорректный тип"
 
 #: fortran/trans-types.c:814
 #, gcc-internal-format
 msgid "gfc_validate_kind(): Got bad kind"
-msgstr ""
+msgstr "gfc_validate_kind(): Получен некорректный вид"
 
 #: fortran/trans.c:2120
 #, gcc-internal-format
@@ -69295,28 +61975,24 @@
 msgstr "gfc_trans_code(): Некорректный код оператора"
 
 #: jit/docs/examples/tut05-bf.c:242
-#, fuzzy, gcc-internal-format
-#| msgid "too many arguments"
+#, gcc-internal-format
 msgid "too many open parens"
-msgstr "слишком много аргументов"
+msgstr "слишком много открытых скобок"
 
 #: jit/docs/examples/tut05-bf.c:275
-#, fuzzy, gcc-internal-format
-#| msgid "mismatched arguments"
+#, gcc-internal-format
 msgid "mismatching parens"
-msgstr "несовпадающие аргументы"
+msgstr "несоответствие скобок"
 
 #: jit/docs/examples/tut05-bf.c:310
-#, fuzzy, gcc-internal-format
-#| msgid "failed to open %s"
+#, gcc-internal-format
 msgid "unable to open file"
-msgstr "не удалось открыть %s"
+msgstr "не удалось открыть файл"
 
 #: lto/lto-lang.c:305
-#, fuzzy, gcc-internal-format
-#| msgid "%s: %s: %s"
+#, gcc-internal-format
 msgid "%s:%s: %E: %E"
-msgstr "%s: %s: %s"
+msgstr ""
 
 #: lto/lto-lang.c:864
 #, gcc-internal-format
@@ -69349,22 +62025,20 @@
 msgid "two or more sections for %s"
 msgstr "две или более секции для %s"
 
-#: lto/lto-partition.c:516
+#: lto/lto-partition.c:570
 #, gcc-internal-format
 msgid "min partition size cannot be greater than max partition size"
-msgstr ""
+msgstr "минимальный размер раздела не может быть больше чем максимальный размер раздела"
 
 #: lto/lto-symtab.c:176
-#, fuzzy, gcc-internal-format
-#| msgid "%qD is initialized with itself"
+#, gcc-internal-format
 msgid "%qD is defined with tls model %s"
-msgstr "%qD инициализируется самим собой"
+msgstr "%qD определен с tls моделью %s"
 
 #: lto/lto-symtab.c:178
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "previously defined here"
+#, gcc-internal-format, gfc-internal-format
 msgid "previously defined here as %s"
-msgstr "предыдущее определение здесь"
+msgstr "ранее определен здесь как %s"
 
 #: lto/lto-symtab.c:480
 #, gcc-internal-format
@@ -69397,21 +62071,19 @@
 msgstr "выравнивание %qD больше чем в исходной декларации"
 
 #: lto/lto-symtab.c:748
-#, fuzzy, gcc-internal-format
-#| msgid "type of %qD does not match original declaration"
+#, gcc-internal-format
 msgid "size of %qD differ from the size of original declaration"
-msgstr "тип %qD не соответствует исходной декларации"
+msgstr "размер %qD отличается от размера в исходной декларации"
 
 #: lto/lto-symtab.c:753
-#, fuzzy, gcc-internal-format
-#| msgid "%q#T was previously declared here"
+#, gcc-internal-format
 msgid "%qD was previously declared here"
-msgstr "%q#T был ранее декларирован здесь"
+msgstr "%qD был ранее декларирован здесь"
 
 #: lto/lto-symtab.c:756
 #, gcc-internal-format
 msgid "code may be misoptimized unless -fno-strict-aliasing is used"
-msgstr ""
+msgstr "код может быть неверно оптимизирован, если -fno-strict-aliasing не используется"
 
 #: lto/lto-symtab.c:842
 #, gcc-internal-format
@@ -69441,7 +62113,7 @@
 #: lto/lto.c:1949
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected file name %s in linker resolution file. Expected %s"
-msgstr "неожиданное имя файла %s в файле разрешений линкера. Ожидалось %s"
+msgstr ""
 
 #: lto/lto.c:1958
 #, gcc-internal-format
@@ -69464,10 +62136,9 @@
 msgstr "некорректное разрешение в файле разрешений"
 
 #: lto/lto.c:2000
-#, fuzzy, gcc-internal-format
-#| msgid "resolution sub id "
+#, gcc-internal-format
 msgid "resolution sub id %wx not in object file"
-msgstr "разрешения sub id "
+msgstr "разрешение sub id %wx не в объектном файле"
 
 #: lto/lto.c:2117
 #, gcc-internal-format, gfc-internal-format
@@ -69489,60 +62160,57 @@
 msgid "Cannot read %s"
 msgstr "Ошибка чтения %s"
 
-#: lto/lto.c:2369
+#: lto/lto.c:2337
 #, gcc-internal-format
 msgid "lto_obj_file_open() failed"
 msgstr "ошибка lto_obj_file_open()"
 
-#: lto/lto.c:2394
-#, fuzzy, gcc-internal-format
-#| msgid "atexit failed"
+#: lto/lto.c:2362
+#, gcc-internal-format
 msgid "waitpid failed"
-msgstr "ошибка в atexit"
+msgstr "ошибка waitpid"
 
-#: lto/lto.c:2397
-#, fuzzy, gcc-internal-format
-#| msgid "renaming .rpo file: %m"
+#: lto/lto.c:2365
+#, gcc-internal-format
 msgid "streaming subprocess failed"
-msgstr "переименование файла .rpo: %m"
+msgstr "ошибка потокового подпроцесса"
 
-#: lto/lto.c:2400
+#: lto/lto.c:2368
 #, gcc-internal-format
 msgid "streaming subprocess was killed by signal"
-msgstr ""
+msgstr "потоковый подпроцесс был уничтожен сигналом"
 
-#: lto/lto.c:2476
+#: lto/lto.c:2445
 #, gcc-internal-format
 msgid "no LTRANS output list filename provided"
 msgstr "Не задано LTRANS имя файла выходного списка"
 
-#: lto/lto.c:2564
+#: lto/lto.c:2525
 #, gcc-internal-format
 msgid "opening LTRANS output list %s: %m"
 msgstr "открытие LTRANS выходного списка %s: %m"
 
-#: lto/lto.c:2570
+#: lto/lto.c:2532
 #, gcc-internal-format
 msgid "writing to LTRANS output list %s: %m"
 msgstr "запись в LTRANS выходной список %s: %m"
 
-#: lto/lto.c:2581
+#: lto/lto.c:2542
 #, gcc-internal-format
 msgid "closing LTRANS output list %s: %m"
 msgstr "закрытие LTRANS выходного списка %s: %m"
 
-#: lto/lto.c:2833
+#: lto/lto.c:2794
 #, gcc-internal-format
 msgid "could not open symbol resolution file: %m"
 msgstr "ошибка открытия файла разрешения символов: %m"
 
-#: lto/lto.c:2954
-#, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "missing braces around initializer for %qT"
+#: lto/lto.c:2915
+#, gcc-internal-format, gfc-internal-format
 msgid "missing resolution data for %s"
-msgstr "отсутствуют фигурные скобки вокруг инициализатора %qT"
+msgstr ""
 
-#: lto/lto.c:2986
+#: lto/lto.c:2947
 #, gcc-internal-format
 msgid "errors during merging of translation units"
 msgstr "ошибки при слиянии единиц трансляции"
@@ -69595,7 +62263,7 @@
 #: objc/objc-act.c:707
 #, gcc-internal-format
 msgid "%<@package%> presently has the same effect as %<@public%>"
-msgstr "%<@package%> в настоящее время имеет тот же эффект что и %<@public%>"
+msgstr "%<@package%> в настоящее время имеет тот же эффект, что и %<@public%>"
 
 #: objc/objc-act.c:718
 #, gcc-internal-format
@@ -69682,7 +62350,7 @@
 #: objc/objc-act.c:963
 #, gcc-internal-format
 msgid "%<assign%> can be unsafe for Objective-C objects; please state explicitly if you need it"
-msgstr "%<assign%> может быть небезопасным для Objective-C объектов; пожалуйста укажите явно если вам это нужно"
+msgstr "%<assign%> может быть небезопасным для Objective-C объектов; пожалуйста укажите явно, если вам это нужно"
 
 #: objc/objc-act.c:970
 #, gcc-internal-format
@@ -70316,7 +62984,7 @@
 #: objc/objc-act.c:7668
 #, gcc-internal-format
 msgid "property %qs is using the same instance variable as property %qs"
-msgstr "свойство %qs использует ту же instance переменную что и свойство %qs"
+msgstr "свойство %qs использует ту же instance переменную, что и свойство %qs"
 
 #: objc/objc-act.c:7709
 #, gcc-internal-format
@@ -70340,7 +63008,7 @@
 #: objc/objc-act.c:7735
 #, gcc-internal-format
 msgid "%<@synthesize%> requires the @interface of the class to be available"
-msgstr "%<@synthesize%> требует чтобы @interface класса был доступен"
+msgstr "%<@synthesize%> требует, чтобы @interface класса был доступен"
 
 #: objc/objc-act.c:7818
 #, gcc-internal-format
@@ -70359,7 +63027,7 @@
 #: objc/objc-act.c:7851
 #, gcc-internal-format
 msgid "%<@dynamic%> requires the @interface of the class to be available"
-msgstr "%<@dynamic%> требует чтобы @interface класса был доступен"
+msgstr "%<@dynamic%> требует, чтобы @interface класса был доступен"
 
 #: objc/objc-act.c:8049
 #, gcc-internal-format
@@ -70465,10 +63133,9 @@
 
 #: objc/objc-gnu-runtime-abi-01.c:2171 objc/objc-next-runtime-abi-01.c:2817
 #: objc/objc-next-runtime-abi-02.c:3589
-#, fuzzy, gcc-internal-format
-#| msgid "non-objective-c type '%T' cannot be caught"
+#, gcc-internal-format
 msgid "non-objective-c type %qT cannot be caught"
-msgstr "non-objective-c тип '%T' не может быть перехвачен"
+msgstr ""
 
 #: objc/objc-next-runtime-abi-01.c:152
 #, gcc-internal-format
@@ -70478,7 +63145,7 @@
 #: objc/objc-next-runtime-abi-02.c:244
 #, gcc-internal-format
 msgid "%<-fobjc-sjlj-exceptions%> is ignored for %<-fnext-runtime%> when %<-fobjc-abi-version%> >= 2"
-msgstr "%<-fobjc-sjlj-exceptions%> игнорируется для %<-fnext-runtime%> если %<-fobjc-abi-version%> >= 2"
+msgstr "%<-fobjc-sjlj-exceptions%> игнорируется для %<-fnext-runtime%>, если %<-fobjc-abi-version%> >= 2"
 
 #: objc/objc-runtime-shared-support.c:425
 #, gcc-internal-format
@@ -70485,22 +63152,21 @@
 msgid "creating selector for nonexistent method %qE"
 msgstr "создается селектор для несуществующего метода %qE"
 
-#, fuzzy
 #~| msgid "Support MMX and SSE built-in functions and code generation"
 #~ msgid "Support Control-flow  Enforcment Technology (CET) built-in functions and code generation."
 #~ msgstr "Включить поддержку внутренних функций и генерацию команд MMX и SSE"
 
-#, fuzzy
+#~ msgid "Warn if the loop cannot be optimized due to nontrivial assumptions."
+#~ msgstr "Предупреждать, если оптимизация цикла невозможна из-за нетривиальных предположений"
+
 #~| msgid "%q+#D invalid; an anonymous struct can only have non-static data members"
 #~ msgid "%q#D invalid; an anonymous struct can only have non-static data members"
 #~ msgstr "%q+#D некорректно; анонимная структура может иметь только нестатические элементы данных"
 
-#, fuzzy
 #~| msgid "private member %q+#D in anonymous struct"
 #~ msgid "private member %q#D in anonymous struct"
 #~ msgstr "private-элемент %q+#D в анонимной структуре"
 
-#, fuzzy
 #~| msgid "protected member %q+#D in anonymous struct"
 #~ msgid "protected member %q#D in anonymous struct"
 #~ msgstr "protected-элемент %q+#D в анонимной структуре"
@@ -70517,12 +63183,10 @@
 #~ msgid "range-based %<for%> expression of type %qT has a %<begin%> member but not an %<end%>"
 #~ msgstr "range-based %<for%> выражение типа %qT имеет %<begin%> элемент без %<end%>"
 
-#, fuzzy
 #~| msgid "ISO C forbids forward parameter declarations"
 #~ msgid "ISO C++ forbids use of %<auto%> in parameter declaration"
 #~ msgstr "в ISO C упреждающие декларации параметров запрещены"
 
-#, fuzzy
 #~| msgid "partial specialization %qT does not specialize any template arguments"
 #~ msgid "partial specialization %q+D does not specialize any template arguments"
 #~ msgstr "частичная специализация %qT не специализирует никакие аргументы шаблона"
@@ -70530,7 +63194,6 @@
 #~ msgid "provided for %q+D"
 #~ msgstr "задано для %q+D"
 
-#, fuzzy
 #~| msgid "  overriding %q+#D"
 #~ msgid "  overriding %q#D"
 #~ msgstr "  отменяющий %q+#D"
@@ -70550,16 +63213,27 @@
 #~ msgid "overriding final function %q+D"
 #~ msgstr "перебивание финальной функции %q+D"
 
-#, fuzzy
 #~| msgid "cannot convert %qT to %qT for argument %qP to %qD"
 #~ msgid "cannot convert %qH to %qI for argument %qP to %qD"
 #~ msgstr "ошибка преобразования %qT в %qT для аргумента %qP функции %qD"
 
-#, fuzzy
+#~| msgid "nonconstant array index in initializer"
+#~ msgid "Expected constant array-spec in initializer list at %L"
+#~ msgstr "неконстантный индекс массива в инициализаторе"
+
 #~| msgid "Function name '%s' not allowed at %C"
 #~ msgid "Function name %qs not allowed at %C"
 #~ msgstr "Имя функции '%s' не допускается в %C"
 
+#~ msgid "Errmsg-variable at %L must be a scalar CHARACTER variable"
+#~ msgstr "Errmsg-variable в %L должна быть скалярной CHARACTER переменной"
+
+#~ msgid "Second argument MOD at %L is zero"
+#~ msgstr "Второй аргумент MOD в %L нулевой"
+
+#~ msgid "Second argument of MOD at %L is zero"
+#~ msgstr "Второй аргумент MOD в %L нулевой"
+
 #~ msgid "%s:unknown function '%u'\n"
 #~ msgstr "%s:неизвестная функция '%u'\n"
 
@@ -70576,17 +63250,14 @@
 #~ msgstr "невозможно оптимизировать циклы, в которых счётчик выходит за границы"
 
 #
-#, fuzzy
 #~| msgid "invalid function in call statement"
 #~ msgid "caller function contains cilk spawn"
 #~ msgstr "некорректная функция в операторе вызова"
 
-#, fuzzy
 #~| msgid "maximum number of basic blocks per function to be analyzed by Graphite"
 #~ msgid "maximum number of basic blocks per function to be analyzed by Graphite."
 #~ msgstr "максимальное число базовых блоков в функции, при котором применяются средства Graphite"
 
-#, fuzzy
 #~| msgid "maximum number of basic blocks per function to be analyzed by Graphite"
 #~ msgid "minimal number of loops per function to be analyzed by Graphite."
 #~ msgstr "максимальное число базовых блоков в функции, при котором применяются средства Graphite"
@@ -70606,7 +63277,6 @@
 #~ msgid "invalid %%L code"
 #~ msgstr "недопустимый код %%L"
 
-#, fuzzy
 #~| msgid "expression %qE of abstract class type %qT cannot be used in throw-expression"
 #~ msgid "Cilk array notation cannot be used for a throw expression"
 #~ msgstr "выражение %qE, имеющее тип абстрактного класса %qT, нельзя использовать в throw-выражении"
@@ -70737,7 +63407,6 @@
 #~ msgid "Conform to the ISO 1998 C++ standard revised by the 2003 technical"
 #~ msgstr "Компилировать в соответствии с ISO 1998 C++ с учетом технических поправок 2003 года"
 
-#, fuzzy
 #~| msgid "Support MMX built-in functions"
 #~ msgid "Support PCOMMIT instruction."
 #~ msgstr "Включить поддержку внутренних функций MMX"
@@ -70745,42 +63414,34 @@
 #~ msgid "Set the branch costs for conditional branch instructions.  Reasonable"
 #~ msgstr "Установить (разумные) стоимости условных переходов"
 
-#, fuzzy
 #~| msgid "Pass FP arguments in FP registers"
 #~ msgid "Pass FP arguments in FP registers."
 #~ msgstr "Передавать плавающие аргументы в FP-регистрах"
 
-#, fuzzy
 #~| msgid "Generate 32-bit SHmedia code"
 #~ msgid "Generate 32-bit SHmedia code."
 #~ msgstr "Генерировать 32-битный код для SHmedia"
 
-#, fuzzy
 #~| msgid "Generate 32-bit FPU-less SHmedia code"
 #~ msgid "Generate 32-bit FPU-less SHmedia code."
 #~ msgstr "Генерировать код 32-битный код без плавающий инструкций для SHmedia"
 
-#, fuzzy
 #~| msgid "Generate 64-bit SHmedia code"
 #~ msgid "Generate 64-bit SHmedia code."
 #~ msgstr "Генерировать 64-битный код для SHmedia"
 
-#, fuzzy
 #~| msgid "Generate 64-bit FPU-less SHmedia code"
 #~ msgid "Generate 64-bit FPU-less SHmedia code."
 #~ msgstr "Генерировать 64-битный SHmedia код без FPU"
 
-#, fuzzy
 #~| msgid "Generate SHcompact code"
 #~ msgid "Generate SHcompact code."
 #~ msgstr "Генерировать код SHcompact"
 
-#, fuzzy
 #~| msgid "Generate FPU-less SHcompact code"
 #~ msgid "Generate FPU-less SHcompact code."
 #~ msgstr "Генерировать SHcompact код без FPU"
 
-#, fuzzy
 #~| msgid "Enable cbranchdi4 pattern"
 #~ msgid "Enable cbranchdi4 pattern."
 #~ msgstr "Включить cbranchdi4 шаблон"
@@ -70788,27 +63449,22 @@
 #~ msgid "Emit cmpeqdi_t pattern even when -mcbranchdi is in effect."
 #~ msgstr "Выдавать cmpeqdi_t шаблон даже если -mcbranchdi действует."
 
-#, fuzzy
 #~| msgid "Enable SH5 cut2 workaround"
 #~ msgid "Enable SH5 cut2 workaround."
 #~ msgstr "Включить SH5 cut2 обход"
 
-#, fuzzy
 #~| msgid "Division strategy, one of: call, call2, fp, inv, inv:minlat, inv20u, inv20l, inv:call, inv:call2, inv:fp, call-div1, call-fp, call-table"
 #~ msgid "Division strategy, one of: call, call2, fp, inv, inv:minlat, inv20u, inv20l, inv:call, inv:call2, inv:fp, call-div1, call-fp, call-table."
 #~ msgstr "Стратегии деления, одна из: call, call2, fp, inv, inv:minlat, inv20u, inv20l, inv:call, inv:call2, inv:fp, call-div1, call-fp, call-table"
 
-#, fuzzy
 #~| msgid "Cost to assume for gettr insn"
 #~ msgid "Cost to assume for gettr insn."
 #~ msgstr "Цена для инструкции gettr"
 
-#, fuzzy
 #~| msgid "Enable the use of the indexed addressing mode for SHmedia32/SHcompact"
 #~ msgid "Enable the use of the indexed addressing mode for SHmedia32/SHcompact."
 #~ msgstr "Включить использование режима индексной адресации для SHmedia32/SHcompact"
 
-#, fuzzy
 #~| msgid "Assume symbols might be invalid"
 #~ msgid "Assume symbols might be invalid."
 #~ msgstr "Предполагать, что символы могут быть неправильными"
@@ -70816,312 +63472,250 @@
 #~ msgid "Assume pt* instructions won't trap"
 #~ msgstr "Предполагать, что команды pt* не вызывают прерываний"
 
-#, fuzzy
 #~| msgid "Deprecated.  Use -Os instead"
 #~ msgid "Deprecated.  Use -Os instead."
 #~ msgstr "Устарело.  Используйте -Os взамен"
 
-#, fuzzy
 #~| msgid "Enable absolute difference instructions"
 #~ msgid "Enable absolute difference instructions."
 #~ msgstr "Включить инструкции вычитания абсолютных величин"
 
-#, fuzzy
 #~| msgid "Enable all optional instructions"
 #~ msgid "Enable all optional instructions."
 #~ msgstr "Включить все необязательные инструкции"
 
-#, fuzzy
 #~| msgid "Enable average instructions"
 #~ msgid "Enable average instructions."
 #~ msgstr "Включить инструкции усреднения"
 
-#, fuzzy
 #~| msgid "Variables this size and smaller go in the based section. (default 0)"
 #~ msgid "Variables this size and smaller go in the based section. (default 0)."
 #~ msgstr "Переменные этого и меньшего размера отправляются в базированную секцию. (по умолчанию 0)"
 
-#, fuzzy
 #~| msgid "Enable bit manipulation instructions"
 #~ msgid "Enable bit manipulation instructions."
 #~ msgstr "Включить инструкции манипуляций с битами"
 
-#, fuzzy
 #~| msgid "Section to put all const variables in (tiny, near, far) (no default)"
 #~ msgid "Section to put all const variables in (tiny, near, far) (no default)."
 #~ msgstr "Секция куда помещать все const переменные (tiny, near, far) (нет умолчанию)"
 
-#, fuzzy
 #~| msgid "Configuration name"
 #~ msgid "Configuration name."
 #~ msgstr "Имя конфигурации"
 
-#, fuzzy
 #~| msgid "Enable MeP Coprocessor"
 #~ msgid "Enable MeP Coprocessor."
 #~ msgstr "Включить MeP сопроцессор"
 
-#, fuzzy
 #~| msgid "Enable MeP Coprocessor with 32-bit registers"
 #~ msgid "Enable MeP Coprocessor with 32-bit registers."
 #~ msgstr "Включить MeP сопроцессор с 32-битными регистрами"
 
-#, fuzzy
 #~| msgid "Enable MeP Coprocessor with 64-bit registers"
 #~ msgid "Enable MeP Coprocessor with 64-bit registers."
 #~ msgstr "Включить MeP сопроцессор с 64-битными регистрами"
 
-#, fuzzy
 #~| msgid "Enable IVC2 scheduling"
 #~ msgid "Enable IVC2 scheduling."
 #~ msgstr "Включить IVC2 планирование"
 
-#, fuzzy
 #~| msgid "Const variables default to the near section"
 #~ msgid "Const variables default to the near section."
 #~ msgstr "Const переменные по умолчанию помещаются в near секцию"
 
-#, fuzzy
 #~| msgid "Enable 32-bit divide instructions"
 #~ msgid "Enable 32-bit divide instructions."
 #~ msgstr "Включить инструкции 32-битного деления"
 
-#, fuzzy
 #~| msgid "__io vars are volatile by default"
 #~ msgid "__io vars are volatile by default."
 #~ msgstr "__io переменные volatile по умолчанию"
 
-#, fuzzy
 #~| msgid "All variables default to the far section"
 #~ msgid "All variables default to the far section."
 #~ msgstr "Все переменные по умолчанию в far секцию"
 
-#, fuzzy
 #~| msgid "Enable leading zero instructions"
 #~ msgid "Enable leading zero instructions."
 #~ msgstr "Включить инструкции с ведущим нулем"
 
-#, fuzzy
 #~| msgid "All variables default to the near section"
 #~ msgid "All variables default to the near section."
 #~ msgstr "Все переменные по умолчанию в near секцию"
 
-#, fuzzy
 #~| msgid "Enable 32-bit multiply instructions"
 #~ msgid "Enable 32-bit multiply instructions."
 #~ msgstr "Включить инструкции 32-битного умножения"
 
-#, fuzzy
 #~| msgid "Disable all optional instructions"
 #~ msgid "Disable all optional instructions."
 #~ msgstr "Выключить все необязательные инструкции"
 
-#, fuzzy
 #~| msgid "Allow gcc to use the repeat/erepeat instructions"
 #~ msgid "Allow gcc to use the repeat/erepeat instructions."
 #~ msgstr "Разрешить gcc использовать repeat/erepeat инструкции"
 
-#, fuzzy
 #~| msgid "All variables default to the tiny section"
 #~ msgid "All variables default to the tiny section."
 #~ msgstr "Все переменные по умолчанию в tiny секцию"
 
-#, fuzzy
 #~| msgid "Enable saturation instructions"
 #~ msgid "Enable saturation instructions."
 #~ msgstr "Включить инструкции насыщения"
 
-#, fuzzy
 #~| msgid "Use sdram version of runtime"
 #~ msgid "Use sdram version of runtime."
 #~ msgstr "Использовать sdram версию поддержки времени выполнения"
 
-#, fuzzy
 #~| msgid "Use simulator runtime without vectors"
 #~ msgid "Use simulator runtime without vectors."
 #~ msgstr "Использовать поддержку времени выполнения симулятора без векторов"
 
-#, fuzzy
 #~| msgid "All functions default to the far section"
 #~ msgid "All functions default to the far section."
 #~ msgstr "Все функции по умолчанию в far секцию"
 
-#, fuzzy
 #~| msgid "Variables this size and smaller go in the tiny section. (default 4)"
 #~ msgid "Variables this size and smaller go in the tiny section. (default 4)."
 #~ msgstr "Переменные этого и меньшего размера отправляются в tiny секцию. (по умолчанию 4)"
 
-#, fuzzy
 #~| msgid "Warn if deprecated empty statements are found"
 #~ msgid "Warn if deprecated empty statements are found."
 #~ msgstr "Предупреждать при употреблении устаревших пустых выражений"
 
-#, fuzzy
 #~| msgid "Warn if .class files are out of date"
 #~ msgid "Warn if .class files are out of date."
 #~ msgstr "Предупреждать, если файл .class устарел"
 
-#, fuzzy
 #~| msgid "Warn if modifiers are specified when not necessary"
 #~ msgid "Warn if modifiers are specified when not necessary."
 #~ msgstr "Уведомлять, когда модификаторы употребляются без необходимости"
 
-#, fuzzy
 #~| msgid "--CLASSPATH\tDeprecated; use --classpath instead"
 #~ msgid "--CLASSPATH\tDeprecated; use --classpath instead."
 #~ msgstr "--CLASSPATH\tЭтот ключ устарел, используйте --classpath"
 
-#, fuzzy
 #~| msgid "Permit the use of the assert keyword"
 #~ msgid "Permit the use of the assert keyword."
 #~ msgstr "Разрешить использование ключевого слова assert"
 
-#, fuzzy
 #~| msgid "--bootclasspath=<path>\tReplace system path"
 #~ msgid "--bootclasspath=<path>\tReplace system path."
 #~ msgstr "--bootclasspath=<path>\tЗамена для системного пути"
 
-#, fuzzy
 #~| msgid "Generate checks for references to NULL"
 #~ msgid "Generate checks for references to NULL."
 #~ msgstr "Генерировать код проверки ссылок по NULL-указателям"
 
-#, fuzzy
 #~| msgid "--classpath=<path>\tSet class path"
 #~ msgid "--classpath=<path>\tSet class path."
 #~ msgstr "--classpath=<path>\tПуть поиска классов"
 
-#, fuzzy
 #~| msgid "Output a class file"
 #~ msgid "Output a class file."
 #~ msgstr "Выводить файл класса"
 
-#, fuzzy
 #~| msgid "Alias for -femit-class-file"
 #~ msgid "Alias for -femit-class-file."
 #~ msgstr "Замена для -femit-class-file"
 
-#, fuzzy
 #~| msgid "--encoding=<encoding>\tChoose input encoding (defaults from your locale)"
 #~ msgid "--encoding=<encoding>\tChoose input encoding (defaults from your locale)."
 #~ msgstr "--encoding=<encoding>\tВыбрать кодировку входных файлов (по умолчанию из locale)"
 
-#, fuzzy
 #~| msgid "--extdirs=<path>\tSet the extension directory path"
 #~ msgid "--extdirs=<path>\tSet the extension directory path."
 #~ msgstr "--extdirs=<путь>\tЗадать путь к каталогу расширений"
 
-#, fuzzy
 #~| msgid "Input file is a file with a list of filenames to compile"
 #~ msgid "Input file is a file with a list of filenames to compile."
 #~ msgstr "Входной файл - файл со списком модулей для компиляции"
 
-#, fuzzy
 #~| msgid "Always check for non gcj generated classes archives"
 #~ msgid "Always check for non gcj generated classes archives."
 #~ msgstr "Всегда проверять, что архивы классов сгенерированы gcj"
 
-#, fuzzy
 #~| msgid "Assume the runtime uses a hash table to map an object to its synchronization structure"
 #~ msgid "Assume the runtime uses a hash table to map an object to its synchronization structure."
 #~ msgstr "Предполагать, что среда запуска использует хэш-таблицу для отображения объекта на его структуру синхронизации"
 
-#, fuzzy
 #~| msgid "Generate instances of Class at runtime"
 #~ msgid "Generate instances of Class at runtime."
 #~ msgstr "Создавать элементы класса во время выполнения"
 
-#, fuzzy
 #~| msgid "Use offset tables for virtual method calls"
 #~ msgid "Use offset tables for virtual method calls."
 #~ msgstr "Использовать таблицы смещений для вызова виртуальных методов"
 
-#, fuzzy
 #~| msgid "Assume native functions are implemented using JNI"
 #~ msgid "Assume native functions are implemented using JNI."
 #~ msgstr "Предполагать, что функции платформы используют JNI"
 
-#, fuzzy
 #~| msgid "Enable optimization of static class initialization code"
 #~ msgid "Enable optimization of static class initialization code."
 #~ msgstr "Включить оптимизацию кода инициализации статических классов"
 
-#, fuzzy
 #~| msgid "Reduce the amount of reflection meta-data generated"
 #~ msgid "Reduce the amount of reflection meta-data generated."
 #~ msgstr "Уменьшить количество создаваемых метаданных об объектах для использования в Java reflection"
 
-#, fuzzy
 #~| msgid "Enable assignability checks for stores into object arrays"
 #~ msgid "Enable assignability checks for stores into object arrays."
 #~ msgstr "Включить проверку корректности присваивания для элементов массива"
 
-#, fuzzy
 #~| msgid "Generate code for the Boehm GC"
 #~ msgid "Generate code for the Boehm GC."
 #~ msgstr "Генерировать код для сборщика мусора Boehm"
 
-#, fuzzy
 #~| msgid "Call a library routine to do integer divisions"
 #~ msgid "Call a library routine to do integer divisions."
 #~ msgstr "Вызывать функцию библиотеки для деления целых"
 
-#, fuzzy
 #~| msgid "Generate code for built-in atomic operations"
 #~ msgid "Generate code for built-in atomic operations."
 #~ msgstr "Генерировать код для встроенных атомарных операций"
 
-#, fuzzy
 #~| msgid "Generated should be loaded by bootstrap loader"
 #~ msgid "Generated should be loaded by bootstrap loader."
 #~ msgstr "Сгенерированный файл должен загружаться стартовым загрузчиком"
 
-#, fuzzy
 #~| msgid "Set the source language version"
 #~ msgid "Set the source language version."
 #~ msgstr "Задать версию входного языка"
 
-#, fuzzy
 #~| msgid "Set the target VM version"
 #~ msgid "Set the target VM version."
 #~ msgstr "Задать версию целевой VM"
 
-#, fuzzy
 #~| msgid "Enable user-defined instructions"
 #~ msgid "Enable coverage-guided fuzzing code instrumentation."
 #~ msgstr "Включить определяемые пользователем инструкции"
 
-#, fuzzy
 #~| msgid "Perform DWARF2 duplicate elimination"
 #~ msgid "Perform DWARF duplicate elimination."
 #~ msgstr "Исключить дублирование информации DWARF2"
 
-#, fuzzy
 #~| msgid "Also if-convert conditional jumps containing memory writes"
 #~ msgid "Also if-convert conditional jumps containing memory writes."
 #~ msgstr "Применить if-конверсию к условным переходам, включающим запись в память"
 
-#, fuzzy
 #~| msgid "Perform cloning to make Interprocedural constant propagation stronger"
 #~ msgid "Perform alignment discovery and propagation to make Interprocedural constant propagation stronger."
 #~ msgstr "Выполнить клонирование для усиления межпроцедурного распространения констант"
 
-#, fuzzy
 #~| msgid "Allow loop optimizations to assume that the loops behave in normal way"
 #~ msgid "Allow loop optimizations to assume that the loops behave in normal way."
 #~ msgstr "При оптимизации циклов предполагать нормальное поведение цикла"
 
-#, fuzzy
 #~| msgid "Enable use of cost model in vectorization"
 #~ msgid "Specifies the cost model for vectorization."
 #~ msgstr "Использовать команду стоимостную модель при векторизации"
 
-#, fuzzy
 #~| msgid "Does nothing.  Preserved for backward compatibility."
 #~ msgid "Enables the unlimited vectorizer cost model.  Preserved for backward compatibility."
 #~ msgstr "Игнорируется. Сохранен для обратной совместимости"
 
-#, fuzzy
 #~| msgid "Generate debug information in COFF format"
 #~ msgid "Generate debug information in COFF format."
 #~ msgstr "Генерировать отладочную информацию в формате COFF"
@@ -71129,12 +63723,10 @@
 #~ msgid "Don't record gcc command line switches in DWARF DW_AT_producer."
 #~ msgstr "Не записывать ключи командной строки gcc в DWARF DW_AT_producer."
 
-#, fuzzy
 #~| msgid "Generate debug information in default format"
 #~ msgid "Don't generate debug information in separate .dwo files."
 #~ msgstr "Генерировать отладочную информацию в формате по умолчанию"
 
-#, fuzzy
 #~| msgid "Emit DWARF additions beyond selected version"
 #~ msgid "Emit DWARF additions beyond selected version."
 #~ msgstr "Генерировать дополнения DWARF, не входящие в выбранную версию"
@@ -71169,7 +63761,6 @@
 #~ msgid "invalid argument %qs to -fdebug-prefix-map"
 #~ msgstr "некорректный аргумент %qs ключа -fdebug-prefix-map"
 
-#, fuzzy
 #~| msgid "assuming signed overflow does not occur when changing X +- C1 cmp C2 to X cmp C1 +- C2"
 #~ msgid "assuming signed overflow does not occur when changing X +- C1 cmp C2 to X cmp C2 -+ C1"
 #~ msgstr "предполагается что при замене X +- C1 cmp C2 на X cmp C1 +- C2 не произошло переполнение"
@@ -71177,27 +63768,22 @@
 #~ msgid "%s (program %s)"
 #~ msgstr "%s (программа %s)"
 
-#, fuzzy
 #~| msgid "expected %<}%> before %<else%>"
 #~ msgid "expected %<_Cilk_spawn%> before %<_Cilk_sync%>"
 #~ msgstr "ожидалось %<}%> перед %<else%>"
 
-#, fuzzy
 #~| msgid "%q+D declared here, later in the translation unit"
 #~ msgid "virtual table layout differs in another translation unit"
 #~ msgstr "%q+D декларировано здесь, позднее в единице компиляции"
 
-#, fuzzy
 #~| msgid "attribute(target(\"%s\")) is unknown"
 #~ msgid "attribute(target_clones(\"%s\")) is not valid for current target"
 #~ msgstr "attribute(target(\"%s\")) неизвестен"
 
-#, fuzzy
 #~| msgid "-pipe not supported"
 #~ msgid "Clause not supported yet"
 #~ msgstr "ключ -pipe не поддерживается"
 
-#, fuzzy
 #~| msgid "-falign-loops=%d is not supported"
 #~ msgid "-fsanitize-recover=thread is not supported"
 #~ msgstr "-falign-loops=%d не поддерживается"
@@ -71208,39 +63794,32 @@
 #~ msgid "tree bytecode streams do not support machine specific builtin functions on this target"
 #~ msgstr "потоки байткода деревьев не поддерживают специфические встроенные функции для этой целевой платформы"
 
-#, fuzzy
 #~| msgid "case label is not an integer constant expression"
 #~ msgid "__sec_implicit_index parameter must be an integer constant expression"
 #~ msgstr "case-метка не является целочисленным константным выражением"
 
 #
-#, fuzzy
 #~| msgid "type mismatch in not expression"
 #~ msgid "length mismatch in expression"
 #~ msgstr "несоответствие типов в not выражении"
 
-#, fuzzy
 #~| msgid "  mismatched types %qT and %qT"
 #~ msgid "rank mismatch between %qE and %qE"
 #~ msgstr "  несоответствие типов %qT и %qT"
 
 #
-#, fuzzy
 #~| msgid "type mismatch in not expression"
 #~ msgid "rank mismatch in expression %qE"
 #~ msgstr "несоответствие типов в not выражении"
 
-#, fuzzy
 #~| msgid "iteration variable %qE should be private"
 #~ msgid "iteration variable cannot be volatile"
 #~ msgstr "итерационная переменная %qE должна быть private"
 
-#, fuzzy
 #~| msgid "%qE appears more than once in data clauses"
 #~ msgid "variable appears in more than one clause"
 #~ msgstr "%qE встречается более одного раза в конструкции данных"
 
-#, fuzzy
 #~| msgid "struct defined here"
 #~ msgid "other clause defined here"
 #~ msgstr "структура определена здесь"
@@ -71272,90 +63851,73 @@
 #~ msgid "unknown conversion type character 0x%x in format"
 #~ msgstr "неопознанный символ преобразования 0x%x в формате"
 
-#, fuzzy
 #~| msgid "%<friend%> can only be specified inside a class"
 #~ msgid "%<_Cilk_spawn%> may only be used inside a function"
 #~ msgstr "%<friend%> может быть задан только внутри класса"
 
-#, fuzzy
 #~| msgid "only one -flto-partition value can be specified"
 #~ msgid "only function calls can be spawned"
 #~ msgstr "можно задать только значение -flto-partition"
 
-#, fuzzy
 #~| msgid "invalid use of %<auto%>"
 #~ msgid "invalid use of %<_Cilk_spawn%>"
 #~ msgstr "недопустимое использование %<auto%>"
 
-#, fuzzy
 #~| msgid "address of explicit register variable %qD requested"
 #~ msgid "explicit register variable %qD may not be modified in spawn"
 #~ msgstr "запрошен адрес явной регистровой переменной %qD"
 
-#, fuzzy
 #~| msgid "invalid use of %qD in linkage specification"
 #~ msgid "invalid use of label %q+D in %<_Cilk_spawn%>"
 #~ msgstr "некорректное использование %qD в спецификации привязки"
 
 #
-#, fuzzy
 #~| msgid "unknown value %s for -mfpu"
 #~ msgid "unknown value %qs for 'arch' target %s"
 #~ msgstr "неизвестное значение %s для ключа -mfpu"
 
-#, fuzzy
 #~| msgid "missing makefile target after %qs"
 #~ msgid "missing cpu name in 'cpu' target %s"
 #~ msgstr "не задана цель после %qs"
 
 #
-#, fuzzy
 #~| msgid "unknown value %s for -mfpu"
 #~ msgid "unknown value %qs for 'cpu' target %s"
 #~ msgstr "неизвестное значение %s для ключа -mfpu"
 
 #
-#, fuzzy
 #~| msgid "unknown value %s for -mfpu"
 #~ msgid "unknown value %qs for 'tune' target %s"
 #~ msgstr "неизвестное значение %s для ключа -mfpu"
 
-#, fuzzy
 #~| msgid "missing makefile target after %qs"
 #~ msgid "missing feature modifier in target %s %qs"
 #~ msgstr "не задана цель после %qs"
 
-#, fuzzy
 #~| msgid "malformed spec function arguments"
 #~ msgid "malformed target %s"
 #~ msgstr "некорректные аргументы spec-функции"
 
-#, fuzzy
 #~| msgid "%s\"%s\"%s is invalid"
 #~ msgid "target %s %s=%s is not valid"
 #~ msgstr "%s\"%s\"%s некорректно"
 
-#, fuzzy
 #~| msgid "%s\"%s\"%s is invalid"
 #~ msgid "target %s %qs is invalid"
 #~ msgstr "%s\"%s\"%s некорректно"
 
-#, fuzzy
 #~| msgid "class extensions are not available in Objective-C 1.0"
 #~ msgid "FPX extensions not available on pre-ARC600 cores"
 #~ msgstr "расширения класса недоступны в Objective-C 1.0"
 
-#, fuzzy
 #~| msgid "this builtin function is only available on the fr450"
 #~ msgid "This multiplier configuration is not available for HS cores"
 #~ msgstr "эта встроенная функция доступна только на fr450"
 
-#, fuzzy
 #~| msgid "-mrelax is only supported for RTP PIC"
 #~ msgid "-matomic is only supported for ARC700 or ARC HS cores"
 #~ msgstr "-mrelax поддерживается только для RTP PIC"
 
-#, fuzzy
 #~| msgid "-mrelax is only supported for RTP PIC"
 #~ msgid "-mll64 is only supported for ARC HS cores"
 #~ msgstr "-mrelax поддерживается только для RTP PIC"
@@ -71363,7 +63925,6 @@
 #~ msgid "passing floating point arguments in fp regs not yet supported"
 #~ msgstr "передача плавающих аргументов на регистрах пока не поддерживается"
 
-#, fuzzy
 #~| msgid "-fpic is not supported"
 #~ msgid "devices natively supported:%s"
 #~ msgstr "ключ -fpic не поддерживается"
@@ -71371,32 +63932,26 @@
 #~ msgid "function attributes %qs and %qs have no effect on %qs function"
 #~ msgstr "атрибуты функций %qs и %qs не воздействуют на %qs функцию"
 
-#, fuzzy
 #~| msgid "%qT uses address space %qs beyond flash of %qs"
 #~ msgid "%qT uses address space %qs beyond flash of %d KiB"
 #~ msgstr "%qT использует адресное пространство %qs после сброса %qs"
 
-#, fuzzy
 #~| msgid "%s %q+D uses address space %qs beyond flash of %qs"
 #~ msgid "%s %q+D uses address space %qs beyond flash of %d KiB"
 #~ msgstr "%s %q+D использует адресное пространство %qs после сброса %qs"
 
-#, fuzzy
 #~| msgid "variable %q+D located in address space %qs beyond flash of %qs"
 #~ msgid "variable %q+D located in address space %qs beyond flash of %d KiB"
 #~ msgstr "переменная %q+D расположена в адресном пространстве %qs после сброса %qs"
 
-#, fuzzy
 #~| msgid "variable %q+D located in address space %qs beyond flash of %qs"
 #~ msgid "variable %q+D located in address space %qs which is not supported for architecture %qs"
 #~ msgstr "переменная %q+D расположена в адресном пространстве %qs после сброса %qs"
 
-#, fuzzy
 #~| msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 #~ msgid "calling %qD with SSE caling convention without SSE/SSE2 enabled"
 #~ msgstr "вызов %qD с атрибутом sseregparm без включения SSE/SSE2"
 
-#, fuzzy
 #~| msgid "previous declaration of %q+D"
 #~ msgid "previous declaration of %D"
 #~ msgstr "предыдущая декларация %q+D"
@@ -71550,7 +64105,6 @@
 #~ msgid "unexpected %d byte cop instruction"
 #~ msgstr "неожиданная инструкция с %d-байтным кодом операции"
 
-#, fuzzy
 #~| msgid "%s does not support split_block"
 #~ msgid "not support -fpic"
 #~ msgstr "%s не поддерживает split_block"
@@ -71567,33 +64121,27 @@
 #~ msgid "unimplemented-shmedia profiling"
 #~ msgstr "unimplemented-shmedia профилирование"
 
-#, fuzzy
 #~| msgid "invalid PHI argument"
 #~ msgid "Invalid builtin arguments"
 #~ msgstr "некорректный аргумент PHI"
 
 #
-#, fuzzy
 #~| msgid "%qD cannot be declared as constexpr"
 #~ msgid "%qE cannot be scalar when %qE is not"
 #~ msgstr "%qD не может быть декларировано как constexpr"
 
-#, fuzzy
 #~| msgid "type mismatch between an SSA_NAME and its symbol"
 #~ msgid "length mismatch between LHS and RHS"
 #~ msgstr "несоответствие типа между SSA_NAME и символом"
 
-#, fuzzy
 #~| msgid "array subscript is not an integer"
 #~ msgid "start-index of array notation triplet is not an integer"
 #~ msgstr "индекс массива не является целым значением"
 
-#, fuzzy
 #~| msgid "array subscript is not an integer"
 #~ msgid "length of array notation triplet is not an integer"
 #~ msgstr "индекс массива не является целым значением"
 
-#, fuzzy
 #~| msgid "array subscript is not an integer"
 #~ msgid "stride of array notation triplet is not an integer"
 #~ msgstr "индекс массива не является целым значением"
@@ -71604,12 +64152,10 @@
 #~ msgid "flexible array member in otherwise empty struct"
 #~ msgstr "регулируемый элемент-массив в структуре, которая иначе была бы пустой"
 
-#, fuzzy
 #~| msgid "Warn for obsolescent usage in a declaration"
 #~ msgid "array notations cannot be used in declaration"
 #~ msgstr "Предупреждать об использовании устаревшего синтаксиса деклараций"
 
-#, fuzzy
 #~| msgid "%<#pragma omp barrier%> may only be used in compound statements"
 #~ msgid "%<#pragma acc update%> may only be used in compound statements"
 #~ msgstr "%<#pragma omp barrier%> может использоваться только в составных операторах"
@@ -71623,47 +64169,38 @@
 #~ msgid "%<#pragma omp taskyield%> may only be used in compound statements"
 #~ msgstr "%<#pragma omp taskyield%> может использоваться только в составных операторах"
 
-#, fuzzy
 #~| msgid "%<#pragma omp taskyield%> may only be used in compound statements"
 #~ msgid "%<#pragma omp cancel%> may only be used in compound statements"
 #~ msgstr "%<#pragma omp taskyield%> может использоваться только в составных операторах"
 
-#, fuzzy
 #~| msgid "%<#pragma omp taskwait%> may only be used in compound statements"
 #~ msgid "%<#pragma omp cancellation point%> may only be used in compound statements"
 #~ msgstr "%<#pragma omp taskwait%> может использоваться только в составных операторах"
 
-#, fuzzy
 #~| msgid "#pragma GCC optimize is not allowed inside functions"
 #~ msgid "%<#pragma grainsize%> must be inside a function"
 #~ msgstr "#pragma GCC optimize не допускается внутри функций"
 
-#, fuzzy
 #~| msgid "%q#D is not const"
 #~ msgid "%qD is not a constant"
 #~ msgstr "%q#D не есть const"
 
-#, fuzzy
 #~| msgid "expected %<new%>"
 #~ msgid "expected %<none%>"
 #~ msgstr "ожидалось %<new%>"
 
-#, fuzzy
 #~| msgid "%<num_threads%> value must be positive"
 #~ msgid "%<num_gangs%> value must be positive"
 #~ msgstr "значение %<num_threads%> должно быть положительным"
 
-#, fuzzy
 #~| msgid "%<num_threads%> value must be positive"
 #~ msgid "%<num_workers%> value must be positive"
 #~ msgstr "значение %<num_threads%> должно быть положительным"
 
-#, fuzzy
 #~| msgid "%<num_threads%> value must be positive"
 #~ msgid "%<%s%> value must be positive"
 #~ msgstr "значение %<num_threads%> должно быть положительным"
 
-#, fuzzy
 #~| msgid "%<num_threads%> value must be positive"
 #~ msgid "%<tile%> value must be positive"
 #~ msgstr "значение %<num_threads%> должно быть положительным"
@@ -71671,103 +64208,83 @@
 #~ msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or %<max%>"
 #~ msgstr "ожидалось %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> или %<max%>"
 
-#, fuzzy
 #~| msgid "%<num_threads%> value must be positive"
 #~ msgid "%<vector_length%> value must be positive"
 #~ msgstr "значение %<num_threads%> должно быть положительным"
 
 #
-#, fuzzy
 #~| msgid "code model %<large%> not supported yet"
 #~ msgid "using parameters for %<linear%> step is not supported yet"
 #~ msgstr "модель кода %<large%> пока не поддерживается"
 
-#, fuzzy
 #~| msgid "invalid #pragma %s"
 #~ msgid "invalid pragma"
 #~ msgstr "некорректная директива #pragma %s"
 
-#, fuzzy
 #~| msgid "for statement expected"
 #~ msgid "_Cilk_for statement expected"
 #~ msgstr "ожидался оператор for"
 
-#, fuzzy
 #~| msgid "%<#pragma omp barrier%> may only be used in compound statements"
 #~ msgid "%<#pragma omp ordered%> with %<depend> clause may only be used in compound statements"
 #~ msgstr "%<#pragma omp barrier%> может использоваться только в составных операторах"
 
-#, fuzzy
 #~| msgid "%<#pragma omp taskwait%> may only be used in compound statements"
 #~ msgid "%<#pragma omp target update%> may only be used in compound statements"
 #~ msgstr "%<#pragma omp taskwait%> может использоваться только в составных операторах"
 
-#, fuzzy
 #~| msgid "%<#pragma omp barrier%> may only be used in compound statements"
 #~ msgid "%<#pragma omp target enter data%> may only be used in compound statements"
 #~ msgstr "%<#pragma omp barrier%> может использоваться только в составных операторах"
 
-#, fuzzy
 #~| msgid "%<#pragma omp taskwait%> may only be used in compound statements"
 #~ msgid "%<#pragma omp target exit data%> may only be used in compound statements"
 #~ msgstr "%<#pragma omp taskwait%> может использоваться только в составных операторах"
 
-#, fuzzy
 #~| msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or %<max%>"
 #~ msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or identifier"
 #~ msgstr "ожидалось %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> или %<max%>"
 
-#, fuzzy
 #~| msgid "#pragma GCC optimize is not allowed inside functions"
 #~ msgid "pragma simd must be inside a function"
 #~ msgstr "#pragma GCC optimize не допускается внутри функций"
 
-#, fuzzy
 #~| msgid "stack size must be an exact power of 2"
 #~ msgid "vectorlength must be a power of 2"
 #~ msgstr "размер стека должен быть точной степенью 2"
 
-#, fuzzy
 #~| msgid "selector must be an integer constant in the range 0..%wi"
 #~ msgid "step size must be an integer constant expression or an integer variable"
 #~ msgstr "селектор должен быть целой константой в диапазоне 0..%wi"
 
-#, fuzzy
 #~| msgid "expected %<#pragma omp%> clause"
 #~ msgid "expected %<#pragma simd%> clause"
 #~ msgstr "ожидалась конструкция %<#pragma omp%>"
 
-#, fuzzy
 #~| msgid "%<#pragma%> is not allowed here"
 #~ msgid "%<#pragma cilk grainsize%> is not followed by %<_Cilk_for%>"
 #~ msgstr "некорректно употреблять %<#pragma%>"
 
-#, fuzzy
 #~| msgid "size in array new must have integral type"
 #~ msgid "base of array section must be pointer or array type"
 #~ msgstr "размер в new для массива должен иметь целочисленный тип"
 
-#, fuzzy
 #~| msgid "expected %<:%> before numeric constant"
 #~ msgid "expected %<:%> or numeral"
 #~ msgstr "ожидалось %<:%> перед числовой константой"
 
-#, fuzzy
 #~| msgid "new cannot be applied to a function type"
 #~ msgid "array notations cannot be used with function type"
 #~ msgstr "new нельзя применять к типу функции"
 
-#, fuzzy
 #~| msgid "expected boolean expression"
 #~ msgid "expected array notation expression"
 #~ msgstr "ожидалось boolean выражение"
 
-#, fuzzy
 #~| msgid "alignment of array elements is greater than element size"
 #~ msgid "rank of the array's index is greater than 1"
 #~ msgstr "выравнивание элементов массива превышает их размер"
 
-#, fuzzy
 #~| msgid "a function call cannot appear in a constant-expression"
 #~ msgid "spawned function call cannot be part of a comma expression"
 #~ msgstr "вызов функции не может присутствовать в константном выражении"
@@ -71787,12 +64304,10 @@
 #~ msgid "unknown field %qE specified in initializer"
 #~ msgstr "неизвестное поле %qE в инициализаторе"
 
-#, fuzzy
 #~| msgid "a transaction expression cannot appear in a constant-expression"
 #~ msgid "array notation expression cannot be used as a return value"
 #~ msgstr "транзакционное выражение не может присутствовать в константном выражении"
 
-#, fuzzy
 #~| msgid "Logical range in CASE statement at %L is not allowed"
 #~ msgid "use of %<_Cilk_spawn%> in a return statement is not allowed"
 #~ msgstr "Логический диапазон в CASE операторе в %L не допускается"
@@ -71812,7 +64327,6 @@
 #~ msgid "Java class %qT cannot have an implicit non-trivial destructor"
 #~ msgstr "Java-класс %qT не может иметь нетривиальный неявный деструктор"
 
-#, fuzzy
 #~| msgid "  %qT is not derived from %qT"
 #~ msgid "%q#D inherited from %qT"
 #~ msgstr "  %qT не является производным от %qT"
@@ -71820,22 +64334,18 @@
 #~ msgid "with %q+#D"
 #~ msgstr "с %q+#D"
 
-#, fuzzy
 #~| msgid "%q+D may not have reference type %qT because it is a member of a union"
 #~ msgid "in C++98 %q+D may not have reference type %qT because it is a member of a union"
 #~ msgstr "%q+D может не иметь ссылочного типа %qT, поскольку это элемент объединения"
 
-#, fuzzy
 #~| msgid "new cannot be applied to a function type"
 #~ msgid "array notation cannot be used with function type"
 #~ msgstr "new нельзя применять к типу функции"
 
-#, fuzzy
 #~| msgid "statement-expressions are not allowed outside functions nor in template-argument lists"
 #~ msgid "throw expressions are not allowed inside loops marked with pragma simd"
 #~ msgstr "операторы-выражения не допустимы вне функций и списков аргументов шаблона"
 
-#, fuzzy
 #~| msgid "%s statement is not allowed inside of BLOCK at %C"
 #~ msgid "try statements are not allowed inside loops marked with #pragma simd"
 #~ msgstr "%s оператор не допускается внутри BLOCK в %C"
@@ -71843,32 +64353,26 @@
 #~ msgid "from previous declaration %q+D"
 #~ msgstr "из предыдущей декларации %q+D"
 
-#, fuzzy
 #~| msgid "function %q+D redeclared as inline"
 #~ msgid "function %qD redeclared as inline"
 #~ msgstr "функция %q+D повторно декларирована как inline"
 
-#, fuzzy
 #~| msgid "previous declaration of %q+D with attribute noinline"
 #~ msgid "previous declaration of %qD with attribute noinline"
 #~ msgstr "предыдущая декларация %q+D с атрибутом noinline"
 
-#, fuzzy
 #~| msgid "function %q+D redeclared with attribute noinline"
 #~ msgid "function %qD redeclared with attribute noinline"
 #~ msgstr "функция %q+D повторно декларирована с атрибутом noinline"
 
-#, fuzzy
 #~| msgid "previous declaration of %q+D was inline"
 #~ msgid "previous declaration of %qD was inline"
 #~ msgstr "функция %q+D была ранее декларирована как inline"
 
-#, fuzzy
 #~| msgid "conflicting declaration %q#D"
 #~ msgid "conflicting declaration of namespace %q+D"
 #~ msgstr "противоречивая декларация %q#D"
 
-#, fuzzy
 #~| msgid "previous declaration of namespace %q+D here"
 #~ msgid "previous declaration of namespace %qD here"
 #~ msgstr "предыдущая декларация namespace %q+D здесь"
@@ -71936,7 +64440,6 @@
 #~ msgid "%qD should never be overloaded"
 #~ msgstr "%qD не может быть перегружен(о/а)"
 
-#, fuzzy
 #~| msgid "not a valid Java .class file"
 #~ msgid "%qT isn%'t a valid Java class type"
 #~ msgstr "некорректный Java .class файл"
@@ -71944,7 +64447,6 @@
 #~ msgid "call to Java constructor with %qs undefined"
 #~ msgstr "вызов Java-конструктора с неопределенным %qs"
 
-#, fuzzy
 #~| msgid "%qD is not a function template"
 #~ msgid "%qD is not a function returning a pointer"
 #~ msgstr "%qD не является шаблоном функции"
@@ -71979,7 +64481,6 @@
 #~ msgid "type mismatch with previous external decl of %q#D"
 #~ msgstr "несоответствие типов с предшествующей внешней декларацией %q#D"
 
-#, fuzzy
 #~| msgid "previous external decl of %q+#D"
 #~ msgid "previous external decl of %q#D"
 #~ msgstr "предыдущая внешняя декларация %q+#D"
@@ -72008,7 +64509,6 @@
 #~ msgid "argument dependent lookup finds %q+D"
 #~ msgstr "зависимый от аргумента просмотр находит %q+D"
 
-#, fuzzy
 #~| msgid "-client_name not allowed with -dynamiclib"
 #~ msgid "braced list index is not allowed with array notation"
 #~ msgstr "-client_name нельзя использовать с -dynamiclib"
@@ -72016,17 +64516,14 @@
 #~ msgid "%qE does not have class type"
 #~ msgstr "%qE не класс"
 
-#, fuzzy
 #~| msgid "break statement used with OpenMP for loop"
 #~ msgid "break statement used with Cilk Plus for loop"
 #~ msgstr "оператор break использован с OpenMP для цикла"
 
-#, fuzzy
 #~| msgid "expected identifier before %qE"
 #~ msgid "nested identifier required"
 #~ msgstr "ожидался идентификатор перед %qE"
 
-#, fuzzy
 #~| msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 #~ msgid "parenthesized initialization is not allowed in for-loop"
 #~ msgstr "скобочная инициализация не допускается в OpenMP %<for%> цикле"
@@ -72034,42 +64531,34 @@
 #~ msgid "not enough collapsed for loops"
 #~ msgstr "недостаточно сжато для циклов"
 
-#, fuzzy
 #~| msgid "attributes are not allowed on a function-definition"
 #~ msgid "vector attribute not immediately followed by a single function declaration or definition"
 #~ msgstr "атрибуты не допускаются при определении функции"
 
-#, fuzzy
 #~| msgid "%<#pragma GCC option%> is not a string"
 #~ msgid "%<#pragma acc routine%> does not refer to a function"
 #~ msgstr "%<#pragma GCC option%> не является строковым литералом"
 
-#, fuzzy
 #~| msgid "invalid constraints for operand"
 #~ msgid "invalid grainsize for _Cilk_for"
 #~ msgstr "некорректные ограничения для операнда"
 
-#, fuzzy
 #~| msgid "#pragma GCC optimize is not allowed inside functions"
 #~ msgid "%<#pragma simd%> must be inside a function"
 #~ msgstr "#pragma GCC optimize не допускается внутри функций"
 
-#, fuzzy
 #~| msgid "#pragma GCC optimize is not allowed inside functions"
 #~ msgid "%<#pragma cilk grainsize%> must be inside a function"
 #~ msgstr "#pragma GCC optimize не допускается внутри функций"
 
-#, fuzzy
 #~| msgid "Expected variable name at %C"
 #~ msgid "expected variable-name"
 #~ msgstr "Ожидалось имя переменной в %C"
 
-#, fuzzy
 #~| msgid "expected %<,%> or %<)%> before %qE"
 #~ msgid "expected %<,%> or %<)%> after %qE"
 #~ msgstr "ожидалась %<,%> или %<)%> перед %qE"
 
-#, fuzzy
 #~| msgid "candidate is: %+#D"
 #~ msgid "candidate is: %#D"
 #~ msgstr "претендент: %+#D"
@@ -72086,7 +64575,6 @@
 #~ msgid "type mismatch in nontype parameter pack"
 #~ msgstr "несоответствие типов в нетиповом parameter pack"
 
-#, fuzzy
 #~| msgid "constructors may not be cv-qualified"
 #~ msgid "constraints for %qD not satisfied"
 #~ msgstr "конструкторы не могут быть cv-квалифицированы"
@@ -72097,7 +64585,6 @@
 #~ msgid "%qE is obsolete; g++ vtables are now COM-compatible by default"
 #~ msgstr "%qE устарело; g++ vtables теперь COM-совместимы по умолчанию"
 
-#, fuzzy
 #~| msgid "alignment of array elements is greater than element size"
 #~ msgid "rank of the array%'s index is greater than 1"
 #~ msgstr "выравнивание элементов массива превышает их размер"
@@ -72114,7 +64601,6 @@
 #~ msgid "Extension: Tab character in format at %C"
 #~ msgstr "Расширение: Tab символ в формате в %C"
 
-#, fuzzy
 #~| msgid "Unexpected junk after TASKWAIT clause at %C"
 #~ msgid "Unexpected junk in !$ACC WAIT at %C"
 #~ msgstr "Неожиданный мусор после TASKWAIT клаузулы в %C"
@@ -72125,27 +64611,22 @@
 #~ msgid "NUM_THREADS clause at %L requires a scalar INTEGER expression"
 #~ msgstr "NUM_THREADS клаузула в %L требует скалярное INTEGER выражение"
 
-#, fuzzy
 #~| msgid "NUM_THREADS clause at %L requires a scalar INTEGER expression"
 #~ msgid "SAFELEN clause at %L requires a scalar INTEGER expression"
 #~ msgstr "NUM_THREADS клаузула в %L требует скалярное INTEGER выражение"
 
-#, fuzzy
 #~| msgid "NUM_THREADS clause at %L requires a scalar INTEGER expression"
 #~ msgid "SIMDLEN clause at %L requires a scalar INTEGER expression"
 #~ msgstr "NUM_THREADS клаузула в %L требует скалярное INTEGER выражение"
 
-#, fuzzy
 #~| msgid "NUM_THREADS clause at %L requires a scalar INTEGER expression"
 #~ msgid "NUM_TEAMS clause at %L requires a scalar INTEGER expression"
 #~ msgstr "NUM_THREADS клаузула в %L требует скалярное INTEGER выражение"
 
-#, fuzzy
 #~| msgid "NUM_THREADS clause at %L requires a scalar INTEGER expression"
 #~ msgid "DEVICE clause at %L requires a scalar INTEGER expression"
 #~ msgstr "NUM_THREADS клаузула в %L требует скалярное INTEGER выражение"
 
-#, fuzzy
 #~| msgid "NUM_THREADS clause at %L requires a scalar INTEGER expression"
 #~ msgid "THREAD_LIMIT clause at %L requires a scalar INTEGER expression"
 #~ msgstr "NUM_THREADS клаузула в %L требует скалярное INTEGER выражение"
@@ -72153,17 +64634,14 @@
 #~ msgid "Pointer initialization target at %L must not be ALLOCATABLE "
 #~ msgstr "Цель инициализации указателя в %L не должна быть ALLOCATABLE "
 
-#, fuzzy
 #~| msgid "%s attribute conflicts with %s attribute at %L"
 #~ msgid "%s attribute with %s attribute at %L"
 #~ msgstr "%s атрибут конфликтует с %s атрибутом в %L"
 
-#, fuzzy
 #~| msgid "%s attribute conflicts with %s attribute in '%s' at %L"
 #~ msgid "%s attribute with %s attribute in %qs at %L"
 #~ msgstr "%s атрибут конфликтует с %s атрибутом в '%s' в %L"
 
-#, fuzzy
 #~| msgid "Use of -fdefault-double-8 requires -fdefault-real-8"
 #~ msgid "Use of %<-fdefault-double-8%> requires %<-fdefault-real-8%>"
 #~ msgstr "Использование -fdefault-double-8 требует -fdefault-real-8"
Index: gcc/po/sv.po
===================================================================
--- gcc/po/sv.po	(.../tags/gcc_8_2_0_release)
+++ gcc/po/sv.po	(.../branches/gcc-8-branch)
@@ -21,10 +21,10 @@
 # thunk			snutt
 msgid ""
 msgstr ""
-"Project-Id-Version: gcc 8.1.0\n"
+"Project-Id-Version: gcc 8.2.0\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2018-05-01 20:30+0000\n"
-"PO-Revision-Date: 2018-07-22 12:51+0200\n"
+"POT-Creation-Date: 2018-07-25 14:25+0000\n"
+"PO-Revision-Date: 2018-07-29 13:05+0200\n"
 "Last-Translator: Göran Uddeborg <goeran@uddeborg.se>\n"
 "Language-Team: Swedish <tp-sv@listor.tp-sv.se>\n"
 "Language: sv\n"
@@ -55,12 +55,12 @@
 msgid "[cannot find %s]"
 msgstr "[kan inte hitta %s]"
 
-#: collect2.c:1557
+#: collect2.c:1585
 #, c-format
 msgid "collect2 version %s\n"
 msgstr "collect2 version %s\n"
 
-#: collect2.c:1664
+#: collect2.c:1692
 #, c-format
 msgid "%d constructor found\n"
 msgid_plural "%d constructors found\n"
@@ -67,7 +67,7 @@
 msgstr[0] "%d konstruerare hittad\n"
 msgstr[1] "%d konstruerare hittade\n"
 
-#: collect2.c:1668
+#: collect2.c:1696
 #, c-format
 msgid "%d destructor found\n"
 msgid_plural "%d destructors found\n"
@@ -74,7 +74,7 @@
 msgstr[0] "%d destruerare hittad\n"
 msgstr[1] "%d destruerare hittade\n"
 
-#: collect2.c:1672
+#: collect2.c:1700
 #, c-format
 msgid "%d frame table found\n"
 msgid_plural "%d frame tables found\n"
@@ -81,12 +81,12 @@
 msgstr[0] "%d ramtabell hittad\n"
 msgstr[1] "%d ramtabeller hittade\n"
 
-#: collect2.c:1836
+#: collect2.c:1864
 #, c-format
 msgid "[Leaving %s]\n"
 msgstr "[Lämnar %s]\n"
 
-#: collect2.c:2068
+#: collect2.c:2094
 #, c-format
 msgid ""
 "\n"
@@ -95,7 +95,7 @@
 "\n"
 "write_c_file - utdatanamn är %s, prefix är %s\n"
 
-#: collect2.c:2584
+#: collect2.c:2610
 #, c-format
 msgid ""
 "\n"
@@ -118,7 +118,7 @@
 msgid "%s: some warnings being treated as errors"
 msgstr "%s: några varningar behandlas som fel"
 
-#: diagnostic.c:324 input.c:222 input.c:1834 c-family/c-opts.c:1377
+#: diagnostic.c:324 input.c:222 input.c:1834 c-family/c-opts.c:1392
 #: fortran/cpp.c:576 fortran/error.c:1008 fortran/error.c:1028
 msgid "<built-in>"
 msgstr "<inbyggd>"
@@ -210,13 +210,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:4164 config/arc/arc.c:5784 config/i386/i386.c:17302
+#: final.c:4164 config/arc/arc.c:5775 config/i386/i386.c:17305
 #: config/pdp11/pdp11.c:1715
 #, c-format
 msgid "floating constant misused"
 msgstr "flyttalskonstant felanvänd"
 
-#: final.c:4222 config/arc/arc.c:5881 config/i386/i386.c:17393
+#: final.c:4222 config/arc/arc.c:5872 config/i386/i386.c:17396
 #: config/pdp11/pdp11.c:1756
 #, c-format
 msgid "invalid expression as operand"
@@ -1130,7 +1130,7 @@
 msgid "GCSE disabled"
 msgstr "GCSE avslagen"
 
-#: gimple-ssa-isolate-paths.c:542 c/c-typeck.c:10240
+#: gimple-ssa-isolate-paths.c:542 c/c-typeck.c:10245
 #, gcc-internal-format
 msgid "function returns address of local variable"
 msgstr "funktionen returnerar adress till en lokal variabel"
@@ -1431,7 +1431,7 @@
 msgid "options enabled: "
 msgstr "aktiverade flaggor: "
 
-#: tree-diagnostic.c:299 c/c-decl.c:5419 c/c-typeck.c:7259 cp/error.c:1042
+#: tree-diagnostic.c:299 c/c-decl.c:5439 c/c-typeck.c:7264 cp/error.c:1042
 #: c-family/c-pretty-print.c:413
 #, gcc-internal-format
 msgid "<anonymous>"
@@ -2887,64 +2887,64 @@
 msgstr "längdmodifierare i strfmon-format"
 
 #. Handle deferred options from command-line.
-#: c-family/c-opts.c:1402 fortran/cpp.c:590
+#: c-family/c-opts.c:1417 fortran/cpp.c:590
 msgid "<command-line>"
 msgstr "<kommandorad>"
 
-#: config/aarch64/aarch64.c:6613
+#: config/aarch64/aarch64.c:6629
 #, c-format
 msgid "unsupported operand for code '%c'"
 msgstr "ej stödd operand för kod ”%c”"
 
-#: config/aarch64/aarch64.c:6624 config/aarch64/aarch64.c:6640
-#: config/aarch64/aarch64.c:6652 config/aarch64/aarch64.c:6663
-#: config/aarch64/aarch64.c:6673 config/aarch64/aarch64.c:6694
-#: config/aarch64/aarch64.c:6764 config/aarch64/aarch64.c:6775
-#: config/aarch64/aarch64.c:6789 config/aarch64/aarch64.c:7011
-#: config/aarch64/aarch64.c:7029
+#: config/aarch64/aarch64.c:6640 config/aarch64/aarch64.c:6656
+#: config/aarch64/aarch64.c:6668 config/aarch64/aarch64.c:6679
+#: config/aarch64/aarch64.c:6689 config/aarch64/aarch64.c:6710
+#: config/aarch64/aarch64.c:6780 config/aarch64/aarch64.c:6791
+#: config/aarch64/aarch64.c:6805 config/aarch64/aarch64.c:7027
+#: config/aarch64/aarch64.c:7045
 #, c-format
 msgid "invalid operand for '%%%c'"
 msgstr "ogiltig operand för ”%%%c”"
 
-#: config/aarch64/aarch64.c:6709 config/aarch64/aarch64.c:6720
-#: config/aarch64/aarch64.c:6871 config/aarch64/aarch64.c:6882
+#: config/aarch64/aarch64.c:6725 config/aarch64/aarch64.c:6736
+#: config/aarch64/aarch64.c:6887 config/aarch64/aarch64.c:6898
 #, c-format
 msgid "invalid vector constant"
 msgstr "ogiltig vektorkonstant"
 
-#: config/aarch64/aarch64.c:6732 config/aarch64/aarch64.c:6744
-#: config/aarch64/aarch64.c:6755
+#: config/aarch64/aarch64.c:6748 config/aarch64/aarch64.c:6760
+#: config/aarch64/aarch64.c:6771
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr "inkompatibla flyttals-/vektorregisteroperander för ”%%%c”"
 
-#: config/aarch64/aarch64.c:6823 config/arm/arm.c:22704
+#: config/aarch64/aarch64.c:6839 config/arm/arm.c:22704
 #, c-format
 msgid "missing operand"
 msgstr "operand saknas"
 
-#: config/aarch64/aarch64.c:6908
+#: config/aarch64/aarch64.c:6924
 #, c-format
 msgid "invalid constant"
 msgstr "ogiltig konstant"
 
-#: config/aarch64/aarch64.c:6911
+#: config/aarch64/aarch64.c:6927
 #, c-format
 msgid "invalid operand"
 msgstr "ogiltig operand"
 
-#: config/aarch64/aarch64.c:7040 config/aarch64/aarch64.c:7045
+#: config/aarch64/aarch64.c:7056 config/aarch64/aarch64.c:7061
 #, c-format
 msgid "invalid operand prefix '%%%c'"
 msgstr "ogiltig operandprefix ”%%%c”"
 
-#: config/aarch64/aarch64.c:7062
+#: config/aarch64/aarch64.c:7078
 #, c-format
 msgid "invalid address mode"
 msgstr "ogiltigt adressläge"
 
-#: config/alpha/alpha.c:5125 config/i386/i386.c:18558
-#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21798
+#: config/alpha/alpha.c:5125 config/i386/i386.c:18561
+#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21875
 #: config/sparc/sparc.c:9290
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
@@ -2961,7 +2961,7 @@
 msgstr "ogiltigt %%r-värde"
 
 #: config/alpha/alpha.c:5223 config/ia64/ia64.c:5534
-#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21506
+#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21583
 #: config/xtensa/xtensa.c:2429
 #, c-format
 msgid "invalid %%R value"
@@ -2968,13 +2968,13 @@
 msgstr "ogiltigt %%R-värde"
 
 #: config/alpha/alpha.c:5229 config/powerpcspe/powerpcspe.c:23933
-#: config/rs6000/rs6000.c:21426 config/xtensa/xtensa.c:2396
+#: config/rs6000/rs6000.c:21503 config/xtensa/xtensa.c:2396
 #, c-format
 msgid "invalid %%N value"
 msgstr "ogiltigt %%N-värde"
 
 #: config/alpha/alpha.c:5237 config/powerpcspe/powerpcspe.c:23961
-#: config/rs6000/rs6000.c:21454
+#: config/rs6000/rs6000.c:21531
 #, c-format
 msgid "invalid %%P value"
 msgstr "ogiltigt %%P-värde"
@@ -3005,7 +3005,7 @@
 msgstr "ogiltigt %%U-värde"
 
 #: config/alpha/alpha.c:5323 config/powerpcspe/powerpcspe.c:24021
-#: config/rs6000/rs6000.c:21514
+#: config/rs6000/rs6000.c:21591
 #, c-format
 msgid "invalid %%s value"
 msgstr "ogiltigt %%s-värde"
@@ -3016,7 +3016,7 @@
 msgstr "ogiltigt %%C-värde"
 
 #: config/alpha/alpha.c:5371 config/powerpcspe/powerpcspe.c:23797
-#: config/rs6000/rs6000.c:21290
+#: config/rs6000/rs6000.c:21367
 #, c-format
 msgid "invalid %%E value"
 msgstr "ogiltigt %%E-värde"
@@ -3027,7 +3027,7 @@
 msgstr "okänd avspecifikation av omlokalisering"
 
 #: config/alpha/alpha.c:5405 config/cr16/cr16.c:1569
-#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21803
+#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21880
 #: config/spu/spu.c:1458
 #, c-format
 msgid "invalid %%xn code"
@@ -3038,57 +3038,57 @@
 msgid "invalid operand address"
 msgstr "ogiltig operandadress"
 
-#: config/arc/arc.c:3810
+#: config/arc/arc.c:3808
 #, c-format
 msgid "invalid operand to %%Z code"
 msgstr "ogiltig operand till %%Z-kod"
 
-#: config/arc/arc.c:3818
+#: config/arc/arc.c:3816
 #, c-format
 msgid "invalid operand to %%z code"
 msgstr "ogiltig operand till %%z-kod"
 
-#: config/arc/arc.c:3826
+#: config/arc/arc.c:3824
 #, c-format
 msgid "invalid operands to %%c code"
 msgstr "ogiltig operand till %%c-kod"
 
-#: config/arc/arc.c:3834
+#: config/arc/arc.c:3832
 #, c-format
 msgid "invalid operand to %%M code"
 msgstr "ogiltig operand till %%M-kod"
 
-#: config/arc/arc.c:3842 config/m32r/m32r.c:2100
+#: config/arc/arc.c:3840 config/m32r/m32r.c:2100
 #, c-format
 msgid "invalid operand to %%p code"
 msgstr "ogiltig operand till %%p-kod"
 
-#: config/arc/arc.c:3853 config/m32r/m32r.c:2093
+#: config/arc/arc.c:3851 config/m32r/m32r.c:2093
 #, c-format
 msgid "invalid operand to %%s code"
 msgstr "ogiltig operand till %%s-kod"
 
-#: config/arc/arc.c:4001 config/m32r/m32r.c:2126
+#: config/arc/arc.c:3999 config/m32r/m32r.c:2126
 #, c-format
 msgid "invalid operand to %%R code"
 msgstr "ogiltig operand för %%R-kod"
 
-#: config/arc/arc.c:4077 config/m32r/m32r.c:2149
+#: config/arc/arc.c:4075 config/m32r/m32r.c:2149
 #, c-format
 msgid "invalid operand to %%H/%%L code"
 msgstr "ogiltig operand för %%H/%%L-kod"
 
-#: config/arc/arc.c:4145 config/m32r/m32r.c:2220
+#: config/arc/arc.c:4143 config/m32r/m32r.c:2220
 #, c-format
 msgid "invalid operand to %%U code"
 msgstr "ogiltig operand för %%U-kod"
 
-#: config/arc/arc.c:4157
+#: config/arc/arc.c:4155
 #, c-format
 msgid "invalid operand to %%V code"
 msgstr "ogiltig operand till %%V-kod"
 
-#: config/arc/arc.c:4214
+#: config/arc/arc.c:4212
 #, c-format
 msgid "invalid operand to %%O code"
 msgstr "ogiltig operand till %%O-kod"
@@ -3095,18 +3095,18 @@
 
 #. Unknown flag.
 #. Undocumented flag.
-#: config/arc/arc.c:4240 config/epiphany/epiphany.c:1305
-#: config/m32r/m32r.c:2247 config/nds32/nds32.c:3079 config/sparc/sparc.c:9569
+#: config/arc/arc.c:4238 config/epiphany/epiphany.c:1305
+#: config/m32r/m32r.c:2247 config/nds32/nds32.c:3080 config/sparc/sparc.c:9569
 #, c-format
 msgid "invalid operand output code"
 msgstr "ogiltig operand i utmatningskod"
 
-#: config/arc/arc.c:5869
+#: config/arc/arc.c:5860
 #, c-format
 msgid "invalid UNSPEC as operand: %d"
 msgstr "ogiltig UNSPEC som operand: %d"
 
-#: config/arc/arc.c:6158 config/cris/cris.c:2568
+#: config/arc/arc.c:6149 config/cris/cris.c:2568
 msgid "unrecognized supposed constant"
 msgstr "okänd förmodad konstant"
 
@@ -3141,7 +3141,7 @@
 #: config/arm/arm.c:22685 config/arm/arm.c:22692 config/bfin/bfin.c:1441
 #: config/bfin/bfin.c:1448 config/bfin/bfin.c:1455 config/bfin/bfin.c:1462
 #: config/bfin/bfin.c:1471 config/bfin/bfin.c:1478 config/bfin/bfin.c:1485
-#: config/bfin/bfin.c:1492 config/nds32/nds32.c:3098
+#: config/bfin/bfin.c:1492 config/nds32/nds32.c:3099
 #, c-format
 msgid "invalid operand for code '%c'"
 msgstr "ogiltig operand för kod ”%c”"
@@ -3482,97 +3482,97 @@
 msgid "bad output_condmove_single operand"
 msgstr "felaktig operand till output_condmove_single"
 
-#: config/i386/i386.c:17387
+#: config/i386/i386.c:17390
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "ogiltig UNSPEC som operand"
 
-#: config/i386/i386.c:17925
+#: config/i386/i386.c:17928
 #, c-format
 msgid "invalid use of register '%s'"
 msgstr "ogiltigt användning av register ”%s”"
 
-#: config/i386/i386.c:17930
+#: config/i386/i386.c:17933
 #, c-format
 msgid "invalid use of asm flag output"
 msgstr "felaktig användning av asm-flaggutdata"
 
-#: config/i386/i386.c:18160
+#: config/i386/i386.c:18163
 #, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr "ogiltig operandstorlek för operandkod ”O”"
 
-#: config/i386/i386.c:18195
+#: config/i386/i386.c:18198
 #, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr "ogiltig operandstorlek för operandkod ”z”"
 
-#: config/i386/i386.c:18264
+#: config/i386/i386.c:18267
 #, c-format
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "ogiltig operandtyp vid operandkod ”Z”"
 
-#: config/i386/i386.c:18269
+#: config/i386/i386.c:18272
 #, c-format
 msgid "invalid operand size for operand code 'Z'"
 msgstr "ogiltig operandstorlek för operandkod ”Z”"
 
-#: config/i386/i386.c:18346
+#: config/i386/i386.c:18349
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "operanden är inte en villkorskod, ogiltig operandkod ”Y”"
 
-#: config/i386/i386.c:18425
+#: config/i386/i386.c:18428
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "operand är inte en villkorskod, ogiltig operandkod ”D”"
 
-#: config/i386/i386.c:18443
+#: config/i386/i386.c:18446
 #, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "operand är inte en villkorskod, ogiltig operandkod ”%c”"
 
-#: config/i386/i386.c:18456
+#: config/i386/i386.c:18459
 #, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "operand är inte en justerbar minnesreferens, ogiltig operandkod ”H”"
 
-#: config/i386/i386.c:18471
+#: config/i386/i386.c:18474
 #, c-format
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr "operanden är inte ett heltal, ogiltig operandkod ”K”"
 
-#: config/i386/i386.c:18499
+#: config/i386/i386.c:18502
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr "operanden är inte ett specifikt heltal, ogiltig operandkod ”r”"
 
-#: config/i386/i386.c:18517
+#: config/i386/i386.c:18520
 #, c-format
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr "operanden är inte ett heltal, ogiltig operandkod ”R”"
 
-#: config/i386/i386.c:18540
+#: config/i386/i386.c:18543
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "operanden är inte ett specifikt heltal, ogiltig operandkod ”R”"
 
-#: config/i386/i386.c:18626
+#: config/i386/i386.c:18629
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "ogiltig operandkod ”%c”"
 
-#: config/i386/i386.c:18688
+#: config/i386/i386.c:18691
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "ogiltig begränsning för operand"
 
-#: config/i386/i386.c:18738
+#: config/i386/i386.c:18741
 #, c-format
 msgid "invalid vector immediate"
 msgstr "ogiltig vektoromedelbar"
 
-#: config/i386/i386.c:29572
+#: config/i386/i386.c:29575
 msgid "unknown insn mode"
 msgstr "okänt instruktionsläge"
 
@@ -3610,7 +3610,7 @@
 msgstr "ogiltig %%P-operand"
 
 #: config/iq2000/iq2000.c:3185 config/powerpcspe/powerpcspe.c:23951
-#: config/rs6000/rs6000.c:21444
+#: config/rs6000/rs6000.c:21521
 #, c-format
 msgid "invalid %%p value"
 msgstr "ogiltigt %%p-värde"
@@ -3664,7 +3664,7 @@
 msgstr "efterinkrementeringsadress är inte ett register"
 
 #: config/m32r/m32r.c:2350 config/m32r/m32r.c:2365
-#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33292
+#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33348
 msgid "bad address"
 msgstr "felaktig adress"
 
@@ -3783,185 +3783,185 @@
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr "Försök köra ”%s” i skalet för att öka dess gräns.\n"
 
-#: config/powerpcspe/powerpcspe.c:4411 config/rs6000/rs6000.c:4258
+#: config/powerpcspe/powerpcspe.c:4411 config/rs6000/rs6000.c:4278
 msgid "-maltivec=le not allowed for big-endian targets"
 msgstr "-maltivec=le är inte tillåtet för mål med rak byteordning"
 
-#: config/powerpcspe/powerpcspe.c:4423 config/rs6000/rs6000.c:4273
+#: config/powerpcspe/powerpcspe.c:4423 config/rs6000/rs6000.c:4293
 msgid "-mvsx requires hardware floating point"
 msgstr "-mvsx kräver hårdvaruflyttal"
 
-#: config/powerpcspe/powerpcspe.c:4431 config/rs6000/rs6000.c:4281
+#: config/powerpcspe/powerpcspe.c:4431 config/rs6000/rs6000.c:4301
 msgid "-mvsx and -mpaired are incompatible"
 msgstr "-mvsx och -mpaired är inkompatibla"
 
-#: config/powerpcspe/powerpcspe.c:4433 config/rs6000/rs6000.c:4283
+#: config/powerpcspe/powerpcspe.c:4433 config/rs6000/rs6000.c:4303
 msgid "-mvsx needs indexed addressing"
 msgstr "-mvsx behöver indexerad adressering"
 
-#: config/powerpcspe/powerpcspe.c:4438 config/rs6000/rs6000.c:4288
+#: config/powerpcspe/powerpcspe.c:4438 config/rs6000/rs6000.c:4308
 msgid "-mvsx and -mno-altivec are incompatible"
 msgstr "-mvsx och -mno-altivec är inkompatibla"
 
-#: config/powerpcspe/powerpcspe.c:4440 config/rs6000/rs6000.c:4290
+#: config/powerpcspe/powerpcspe.c:4440 config/rs6000/rs6000.c:4310
 msgid "-mno-altivec disables vsx"
 msgstr "-mno-altivec avaktiverar vsx"
 
-#: config/powerpcspe/powerpcspe.c:4648 config/rs6000/rs6000.c:4416
+#: config/powerpcspe/powerpcspe.c:4648 config/rs6000/rs6000.c:4436
 msgid "-mquad-memory requires 64-bit mode"
 msgstr "--mquad-memory kräver 64-bitarsläge"
 
-#: config/powerpcspe/powerpcspe.c:4651 config/rs6000/rs6000.c:4419
+#: config/powerpcspe/powerpcspe.c:4651 config/rs6000/rs6000.c:4439
 msgid "-mquad-memory-atomic requires 64-bit mode"
 msgstr "-mquad-memory-atomic förutsätter 64-bitarsläge"
 
-#: config/powerpcspe/powerpcspe.c:4663 config/rs6000/rs6000.c:4431
+#: config/powerpcspe/powerpcspe.c:4663 config/rs6000/rs6000.c:4451
 msgid "-mquad-memory is not available in little endian mode"
 msgstr "-mquad-memory är inte tillgängligt i läget med omvänd byteordning"
 
-#: config/powerpcspe/powerpcspe.c:4735 config/rs6000/rs6000.c:4512
+#: config/powerpcspe/powerpcspe.c:4735 config/rs6000/rs6000.c:4532
 msgid "-mtoc-fusion requires 64-bit"
 msgstr "--mtoc-fusion kräver 64-bitar"
 
-#: config/powerpcspe/powerpcspe.c:4742 config/rs6000/rs6000.c:4519
+#: config/powerpcspe/powerpcspe.c:4742 config/rs6000/rs6000.c:4539
 msgid "-mtoc-fusion requires medium/large code model"
 msgstr "-mtoc-fusion behöver medium/stor kodmodell"
 
-#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10915
+#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10947
 msgid "bad move"
 msgstr "felaktig förflyttning"
 
-#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21087
+#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21164
 msgid "Bad 128-bit move"
 msgstr "Felaktig 128-bitsförflyttning"
 
-#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21278
+#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21355
 #, c-format
 msgid "invalid %%e value"
 msgstr "ogiltigt %%e-värde"
 
-#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21299
+#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21376
 #, c-format
 msgid "invalid %%f value"
 msgstr "ogiltigt %%f-värde"
 
-#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21308
+#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21385
 #, c-format
 msgid "invalid %%F value"
 msgstr "ogiltigt %%F-värde"
 
-#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21317
+#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21394
 #, c-format
 msgid "invalid %%G value"
 msgstr "ogiltigt %%G-värde"
 
-#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21352
+#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21429
 #, c-format
 msgid "invalid %%j code"
 msgstr "ogiltig %%j-kod"
 
-#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21362
+#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21439
 #, c-format
 msgid "invalid %%J code"
 msgstr "ogiltig %%J-kod"
 
-#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21372
+#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21449
 #, c-format
 msgid "invalid %%k value"
 msgstr "ogiltigt %%k-värde"
 
-#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21387
+#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21464
 #: config/xtensa/xtensa.c:2415
 #, c-format
 msgid "invalid %%K value"
 msgstr "ogiltigt %%K-värde"
 
-#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21434
+#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21511
 #, c-format
 msgid "invalid %%O value"
 msgstr "ogiltigt %%O-värde"
 
-#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21481
+#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21558
 #, c-format
 msgid "invalid %%q value"
 msgstr "ogiltigt %%q-värde"
 
-#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21534
+#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21611
 #, c-format
 msgid "invalid %%T value"
 msgstr "ogiltigt %%T-värde"
 
-#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21546
+#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21623
 #, c-format
 msgid "invalid %%u value"
 msgstr "ogiltigt %%u-värde"
 
-#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21560
+#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21637
 #: config/xtensa/xtensa.c:2384
 #, c-format
 msgid "invalid %%v value"
 msgstr "ogiltig %%v-kod"
 
-#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21627
+#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21704
 #: config/xtensa/xtensa.c:2436
 #, c-format
 msgid "invalid %%x value"
 msgstr "ogiltigt %%x-värde"
 
-#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21747
+#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21824
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "ogiltigt %%y-värde, försök använda ”Z”-begränsningen"
 
-#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22282
+#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22359
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr "__float128 och __ibm128 kan inte användas i samma uttryck"
 
-#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22288
+#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22365
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr "__ibm128 och long double inte användas i samma uttryck"
 
-#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22294
+#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22371
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr "__float128 och long double kan inte användas i samma uttryck"
 
-#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36572
+#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36628
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "AltiVec-argument skickat till funktion utan prototyp"
 
-#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38739
+#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38795
 msgid "Could not generate addis value for fusion"
 msgstr "Kunde inte generera addis-värde för sammanslagning"
 
-#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38809
+#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38865
 msgid "Unable to generate load/store offset for fusion"
 msgstr "Kan inte generera ladda/lagra-avstånd för sammanslagning"
 
-#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38908
+#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38964
 msgid "Bad GPR fusion"
 msgstr "Felaktig GPR-sammanslagning"
 
-#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39126
+#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39182
 msgid "emit_fusion_p9_load, bad reg #1"
 msgstr "emit_fusion_p9_load, felaktigt register nr. 1"
 
-#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39172
+#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39228
 msgid "emit_fusion_p9_load, bad reg #2"
 msgstr "emit_fusion_p9_load, felaktigt register nr. 2"
 
-#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39175
+#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39231
 msgid "emit_fusion_p9_load not MEM"
 msgstr "emit_fusion_p9_load inte MEM"
 
-#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39213
+#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39269
 msgid "emit_fusion_p9_store, bad reg #1"
 msgstr "emit_fusion_p9_store, felaktigt register nr. 1"
 
-#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39259
+#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39315
 msgid "emit_fusion_p9_store, bad reg #2"
 msgstr "emit_fusion_p9_store, felaktigt register nr. 2"
 
-#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39262
+#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39318
 msgid "emit_fusion_p9_store not MEM"
 msgstr "emit_fusion_p9_store inte MEM"
 
@@ -4340,14 +4340,14 @@
 #: c/gimple-parser.c:188 c/gimple-parser.c:197 c/gimple-parser.c:226
 #: c/gimple-parser.c:1375 c/gimple-parser.c:1404 c/gimple-parser.c:1484
 #: c/gimple-parser.c:1511 c/c-parser.c:3204 c/c-parser.c:9967
-#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27841
-#: cp/parser.c:28430
+#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27838
+#: cp/parser.c:28427
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "%<;%> förväntades"
 
 #: c/c-parser.c:2431 c/c-parser.c:7573 c/c-parser.c:8015 c/c-parser.c:8058
-#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27839 cp/parser.c:28448
+#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27836 cp/parser.c:28445
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "%<,%> förväntades"
@@ -4362,7 +4362,7 @@
 #: c/gimple-parser.c:821 c/gimple-parser.c:837 c/gimple-parser.c:853
 #: c/gimple-parser.c:880 c/gimple-parser.c:915 c/gimple-parser.c:1038
 #: c/gimple-parser.c:1209 c/gimple-parser.c:1220 c/gimple-parser.c:1342
-#: c/gimple-parser.c:1441 cp/parser.c:28478
+#: c/gimple-parser.c:1441 cp/parser.c:28475
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "%<)%> förväntades"
@@ -4370,7 +4370,7 @@
 #: c/c-parser.c:3824 c/c-parser.c:4733 c/c-parser.c:4769 c/c-parser.c:6441
 #: c/c-parser.c:8125 c/c-parser.c:8983 c/c-parser.c:9127 c/c-parser.c:11588
 #: c/c-parser.c:18220 c/c-parser.c:18222 c/gimple-parser.c:1015
-#: cp/parser.c:28442
+#: cp/parser.c:28439
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "%<]%> förväntades"
@@ -4384,7 +4384,7 @@
 #: c/c-parser.c:17792 c/gimple-parser.c:363 c/gimple-parser.c:811
 #: c/gimple-parser.c:873 c/gimple-parser.c:911 c/gimple-parser.c:1198
 #: c/gimple-parser.c:1339 c/gimple-parser.c:1438 c/c-parser.c:11911
-#: cp/parser.c:28433
+#: cp/parser.c:28430
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "%<(%> förväntades"
@@ -4391,7 +4391,7 @@
 
 #: c/c-parser.c:4903 c/c-parser.c:10310 c/c-parser.c:16212 c/c-parser.c:18449
 #: c/gimple-parser.c:141 c/gimple-parser.c:1444 c/c-parser.c:3018
-#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18155 cp/parser.c:28439
+#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18152 cp/parser.c:28436
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "%<{%> förväntades"
@@ -4401,13 +4401,13 @@
 #: c/c-parser.c:12351 c/c-parser.c:12493 c/c-parser.c:12864 c/c-parser.c:12957
 #: c/c-parser.c:13566 c/c-parser.c:17636 c/c-parser.c:17695
 #: c/gimple-parser.c:431 c/gimple-parser.c:1492 c/gimple-parser.c:1519
-#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28472 cp/parser.c:29597
-#: cp/parser.c:32279
+#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28469 cp/parser.c:29594
+#: cp/parser.c:32276
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "%<:%> förväntades"
 
-#: c/c-parser.c:5974 cp/parser.c:28365
+#: c/c-parser.c:5974 cp/parser.c:28362
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "%<while%> förväntades"
@@ -4416,18 +4416,18 @@
 msgid "expected %<.%>"
 msgstr "%<.%> förväntades"
 
-#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30172
-#: cp/parser.c:30246
+#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30169
+#: cp/parser.c:30243
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "%<@end%> förväntades"
 
-#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28457
+#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28454
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "%<>%> förväntades"
 
-#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28481
+#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28478
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "%<,%> eller %<)%> förväntades"
@@ -4435,32 +4435,32 @@
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15190 c/c-parser.c:15234 c/c-parser.c:15466 c/c-parser.c:15701
 #: c/c-parser.c:17833 c/gimple-parser.c:286 c/c-parser.c:4792
-#: cp/parser.c:28460
+#: cp/parser.c:28457
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "%<=%> förväntades"
 
-#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28436
-#: cp/parser.c:30389
+#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28433
+#: cp/parser.c:30386
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "%<}%> förväntades"
 
-#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35674
+#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35671
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "%<#pragma omp section%> eller %<}%> förväntades"
 
-#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28445 cp/parser.c:31535
+#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28442 cp/parser.c:31532
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "%<[%> förväntades"
 
-#: c/c-typeck.c:7847
+#: c/c-typeck.c:7852
 msgid "(anonymous)"
 msgstr "(anonym)"
 
-#: c/gimple-parser.c:795 cp/parser.c:15791 cp/parser.c:28454
+#: c/gimple-parser.c:795 cp/parser.c:15788 cp/parser.c:28451
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "%<<%> förväntades"
@@ -4714,11 +4714,11 @@
 msgid "%r%s:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr "%r%s:%d:%R   i expansion av %<constexpr%> i %qs"
 
-#: cp/pt.c:1949 cp/semantics.c:5268
+#: cp/pt.c:1949 cp/semantics.c:5271
 msgid "candidates are:"
 msgstr "kandidater är:"
 
-#: cp/pt.c:1951 cp/pt.c:22975
+#: cp/pt.c:1951 cp/pt.c:23053
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "kandidat är:"
@@ -4764,27 +4764,27 @@
 msgid "source type is not polymorphic"
 msgstr "källtypen är inte polymorfisk"
 
-#: cp/typeck.c:6083 c/c-typeck.c:4261
+#: cp/typeck.c:6083 c/c-typeck.c:4266
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "fel typ på argument till unärt minus"
 
-#: cp/typeck.c:6084 c/c-typeck.c:4248
+#: cp/typeck.c:6084 c/c-typeck.c:4253
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "fel typ på argument till unärt plus"
 
-#: cp/typeck.c:6111 c/c-typeck.c:4302
+#: cp/typeck.c:6111 c/c-typeck.c:4307
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "fel typ på argument till bitkomplement"
 
-#: cp/typeck.c:6128 c/c-typeck.c:4310
+#: cp/typeck.c:6128 c/c-typeck.c:4315
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "fel typ på argument till abs"
 
-#: cp/typeck.c:6140 c/c-typeck.c:4322
+#: cp/typeck.c:6140 c/c-typeck.c:4327
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "fel typ på argument till konjunktion"
@@ -5024,67 +5024,67 @@
 msgid "Expected attribute bit name"
 msgstr "Attributbitnamn förväntades"
 
-#: fortran/module.c:3223
+#: fortran/module.c:3225
 msgid "Expected integer string"
 msgstr "Heltalssträng förväntades"
 
-#: fortran/module.c:3227
+#: fortran/module.c:3229
 msgid "Error converting integer"
 msgstr "Fel vid konvertering av heltal"
 
-#: fortran/module.c:3249
+#: fortran/module.c:3251
 msgid "Expected real string"
 msgstr "Förväntade reell sträng"
 
-#: fortran/module.c:3474
+#: fortran/module.c:3476
 msgid "Expected expression type"
 msgstr "Uttryckstyp förväntades"
 
-#: fortran/module.c:3554
+#: fortran/module.c:3556
 msgid "Bad operator"
 msgstr "Felaktig operator"
 
-#: fortran/module.c:3671
+#: fortran/module.c:3673
 msgid "Bad type in constant expression"
 msgstr "Felaktig typ i konstant uttryck"
 
-#: fortran/module.c:7038
+#: fortran/module.c:7040
 msgid "Unexpected end of module"
 msgstr "Oväntat modulslut"
 
-#: fortran/parse.c:1757
+#: fortran/parse.c:1761
 msgid "arithmetic IF"
 msgstr "aritmetiskt IF"
 
-#: fortran/parse.c:1766
+#: fortran/parse.c:1770
 msgid "attribute declaration"
 msgstr "attributdeklaration"
 
-#: fortran/parse.c:1802
+#: fortran/parse.c:1806
 msgid "data declaration"
 msgstr "datadeklaration"
 
-#: fortran/parse.c:1820
+#: fortran/parse.c:1824
 msgid "derived type declaration"
 msgstr "härledd typdeklaration"
 
-#: fortran/parse.c:1947
+#: fortran/parse.c:1951
 msgid "block IF"
 msgstr "block-IF"
 
-#: fortran/parse.c:1956
+#: fortran/parse.c:1960
 msgid "implied END DO"
 msgstr "implicerat END DO"
 
-#: fortran/parse.c:2050 fortran/resolve.c:11199
+#: fortran/parse.c:2054 fortran/resolve.c:11219
 msgid "assignment"
 msgstr "tilldelning"
 
-#: fortran/parse.c:2053 fortran/resolve.c:11250 fortran/resolve.c:11253
+#: fortran/parse.c:2057 fortran/resolve.c:11270 fortran/resolve.c:11273
 msgid "pointer assignment"
 msgstr "pekartilldelning"
 
-#: fortran/parse.c:2071
+#: fortran/parse.c:2075
 msgid "simple IF"
 msgstr "enkelt IF"
 
@@ -5176,106 +5176,111 @@
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr "Operand till unär numerisk operator %%<%s%%> vid %%L är %s"
 
-#: fortran/resolve.c:3878
+#: fortran/resolve.c:3879
 #, c-format
+msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
+msgstr "Oväntade entiteter av härledd typ i binär inbyggd numerisk operator %%<%s%%> vid %%L"
+
+#: fortran/resolve.c:3884
+#, c-format
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr "Operander till binär numerisk operator %%<%s%%> vid %%L är %s/%s"
 
-#: fortran/resolve.c:3893
+#: fortran/resolve.c:3899
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr "Operanderna till strängkonkateneringsoperatorn vid %%L är %s/%s"
 
-#: fortran/resolve.c:3926
+#: fortran/resolve.c:3932
 #, c-format
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr "Operanderna till logiska operatorn %%<%s%%> vid %%L är %s/%s"
 
-#: fortran/resolve.c:3949
+#: fortran/resolve.c:3955
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr "Operand till operatorn .not. vid %%L är %s"
 
-#: fortran/resolve.c:3963
+#: fortran/resolve.c:3969
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "COMPLEX-kvantiteter kan inte jämföras vid %L"
 
-#: fortran/resolve.c:4015
+#: fortran/resolve.c:4021
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr "Logiska vid %%L måste jämföras med %s istället för %s"
 
-#: fortran/resolve.c:4021
+#: fortran/resolve.c:4027
 #, c-format
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr "Operanderna till jämförelseoperatorn %%<%s%%> vid %%L är %s/%s"
 
-#: fortran/resolve.c:4034
+#: fortran/resolve.c:4040
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L; did you mean '%s'?"
 msgstr "Okänd operator %%<%s%%> vid %%L; menade du ”%s”?"
 
-#: fortran/resolve.c:4037
+#: fortran/resolve.c:4043
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr "Okänd operator %%<%s%%> vid %%L"
 
-#: fortran/resolve.c:4040
+#: fortran/resolve.c:4046
 #, c-format
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr "Operanderna till användaroperatorn %%<%s%%> vid %%L är %s"
 
-#: fortran/resolve.c:4044
+#: fortran/resolve.c:4050
 #, c-format
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr "Operanderna till användaroperatorn %%<%s%%> vid %%L är %s/%s"
 
-#: fortran/resolve.c:4132
+#: fortran/resolve.c:4138
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "Inkonsistenta ordningar för operator vid %%L och %%L"
 
-#: fortran/resolve.c:6849
+#: fortran/resolve.c:6855
 msgid "Loop variable"
 msgstr "Slingvariabel"
 
-#: fortran/resolve.c:6853
+#: fortran/resolve.c:6859
 msgid "iterator variable"
 msgstr "iteratorvariabel"
 
-#: fortran/resolve.c:6857
+#: fortran/resolve.c:6863
 msgid "Start expression in DO loop"
 msgstr "Startuttryck i DO-slinga"
 
-#: fortran/resolve.c:6861
+#: fortran/resolve.c:6867
 msgid "End expression in DO loop"
 msgstr "Slututtryck i DO-slinga"
 
-#: fortran/resolve.c:6865
+#: fortran/resolve.c:6871
 msgid "Step expression in DO loop"
 msgstr "Steguttryck i DO-slinga"
 
-#: fortran/resolve.c:7150 fortran/resolve.c:7153
+#: fortran/resolve.c:7156 fortran/resolve.c:7159
 msgid "DEALLOCATE object"
 msgstr "DEALLOCATE-objekt"
 
-#: fortran/resolve.c:7525 fortran/resolve.c:7528
+#: fortran/resolve.c:7531 fortran/resolve.c:7534
 msgid "ALLOCATE object"
 msgstr "ALLOCATE-objekt"
 
-#: fortran/resolve.c:7720 fortran/resolve.c:9417
+#: fortran/resolve.c:7726 fortran/resolve.c:9428
 msgid "STAT variable"
 msgstr "STAT-variabel"
 
-#: fortran/resolve.c:7764 fortran/resolve.c:9429
+#: fortran/resolve.c:7770 fortran/resolve.c:9440
 msgid "ERRMSG variable"
 msgstr "ERRMSG-variabel"
 
-#: fortran/resolve.c:9219
+#: fortran/resolve.c:9230
 msgid "item in READ"
 msgstr "objekt i READ"
 
-#: fortran/resolve.c:9441
+#: fortran/resolve.c:9452
 msgid "ACQUIRED_LOCK variable"
 msgstr "ACQUIRED_LOCK-variabel"
 
@@ -5308,7 +5313,7 @@
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr "Målet för återavbildning av ordning är för litet (%ld < %ld)"
 
-#: fortran/trans-expr.c:10154
+#: fortran/trans-expr.c:10157
 msgid "Assignment of scalar to unallocated array"
 msgstr "Tilldelning av skalär till en oallokerad vektor"
 
@@ -5317,12 +5322,12 @@
 msgid "Unequal character lengths (%ld/%ld) in %s"
 msgstr "Olika teckenlängder (%ld/%ld) i %s"
 
-#: fortran/trans-intrinsic.c:8088
+#: fortran/trans-intrinsic.c:8090
 #, c-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative (its value is %ld)"
 msgstr "Argument NCOPIES till inbyggd REPEAT är negativt (dess värde är %ld)"
 
-#: fortran/trans-intrinsic.c:8120
+#: fortran/trans-intrinsic.c:8122
 msgid "Argument NCOPIES of REPEAT intrinsic is too large"
 msgstr "Argumentet NCOPIES till inbyggd REPEAT är för stort"
 
@@ -5343,15 +5348,15 @@
 msgid "Invalid image number %d in SYNC IMAGES"
 msgstr "Ogiltigt bildnummer %d i SYNC IMAGES"
 
-#: fortran/trans-stmt.c:2180
+#: fortran/trans-stmt.c:2177
 msgid "Loop iterates infinitely"
 msgstr "Slingan itererar oändligt"
 
-#: fortran/trans-stmt.c:2200 fortran/trans-stmt.c:2456
+#: fortran/trans-stmt.c:2197 fortran/trans-stmt.c:2453
 msgid "Loop variable has been modified"
 msgstr "Slingvariabel har modifierats"
 
-#: fortran/trans-stmt.c:2309
+#: fortran/trans-stmt.c:2306
 msgid "DO step value is zero"
 msgstr "DO-stegvärdet är noll"
 
@@ -5924,10 +5929,10 @@
 msgid "Allow dollar signs in entity names."
 msgstr "Tillåt dollartecken i entitetsnamn."
 
-#: fortran/lang.opt:485 config/alpha/alpha.opt:31 common.opt:783
-#: common.opt:985 common.opt:989 common.opt:993 common.opt:997 common.opt:1532
-#: common.opt:1588 common.opt:1712 common.opt:1716 common.opt:1946
-#: common.opt:2116 common.opt:2792
+#: fortran/lang.opt:485 config/alpha/alpha.opt:31 common.opt:649
+#: common.opt:783 common.opt:989 common.opt:993 common.opt:997 common.opt:1001
+#: common.opt:1536 common.opt:1592 common.opt:1716 common.opt:1720
+#: common.opt:1950 common.opt:2120 common.opt:2796
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr "Gör ingenting.  Bevarad för bakåtkompatibilitet."
 
@@ -6146,12 +6151,12 @@
 msgstr "Lägg till understrykningstecken till externt synliga namn."
 
 #: fortran/lang.opt:751 c-family/c.opt:1356 c-family/c.opt:1384
-#: c-family/c.opt:1634 config/pa/pa.opt:42 config/pa/pa.opt:70 common.opt:1154
-#: common.opt:1333 common.opt:1408 common.opt:1676 common.opt:1799
-#: common.opt:2169 common.opt:2205 common.opt:2298 common.opt:2302
-#: common.opt:2407 common.opt:2498 common.opt:2506 common.opt:2514
-#: common.opt:2522 common.opt:2623 common.opt:2675 common.opt:2755
-#: common.opt:2893 common.opt:2897 common.opt:2901 common.opt:2905
+#: c-family/c.opt:1634 config/pa/pa.opt:42 config/pa/pa.opt:70 common.opt:1158
+#: common.opt:1337 common.opt:1412 common.opt:1680 common.opt:1803
+#: common.opt:2173 common.opt:2209 common.opt:2302 common.opt:2306
+#: common.opt:2411 common.opt:2502 common.opt:2510 common.opt:2518
+#: common.opt:2526 common.opt:2627 common.opt:2679 common.opt:2759
+#: common.opt:2897 common.opt:2901 common.opt:2905 common.opt:2909
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr "Gör ingenting.  Bevarad för bakåtkompatibilitet."
 
@@ -6201,7 +6206,7 @@
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:220 c-family/c.opt:224
 #: c-family/c.opt:236 c-family/c.opt:1855 c-family/c.opt:1863 brig/lang.opt:39
-#: config/darwin.opt:56 common.opt:338 common.opt:341 common.opt:3046
+#: config/darwin.opt:56 common.opt:338 common.opt:341 common.opt:3050
 #, c-format
 msgid "missing filename after %qs"
 msgstr "filnamn saknas efter %qs"
@@ -6777,7 +6782,7 @@
 #: c-family/c.opt:1525 c-family/c.opt:1528 c-family/c.opt:1569
 #: c-family/c.opt:1704 c-family/c.opt:1731 c-family/c.opt:1771
 #: c-family/c.opt:1802 c-family/c.opt:1806 c-family/c.opt:1822
-#: config/ia64/ia64.opt:167 config/ia64/ia64.opt:170 c-family/c-opts.c:434
+#: config/ia64/ia64.opt:167 config/ia64/ia64.opt:170 c-family/c-opts.c:432
 #, gcc-internal-format
 msgid "switch %qs is no longer supported"
 msgstr "flaggan %qs stödjs inte längre"
@@ -13831,10 +13836,6 @@
 msgid "Warn if dereferencing a NULL pointer may lead to erroneous or undefined behavior."
 msgstr "Varna om dereferering av en NULL-pekare kan leda till felaktigt eller odefinierat beteende."
 
-#: common.opt:649
-msgid "Warn if the loop cannot be optimized due to nontrivial assumptions."
-msgstr "Varna för slingan inte kan optimeras på grund av icketriviala antaganden."
-
 #: common.opt:656
 msgid "Warn about some C++ One Definition Rule violations during link time optimization."
 msgstr "Varna för några brott mot C++ endefinitionsregel under optimeringar vid länktillfället."
@@ -14003,1676 +14004,1676 @@
 msgid "-dumpdir <dir>\tSet the directory name to be used for dumps."
 msgstr "-dumpdir <kat>\tAnge katalognamn att användas för dumpar."
 
-#: common.opt:946
+#: common.opt:950
 msgid "The version of the C++ ABI in use."
 msgstr "Versionen av C++-ABI:et som används."
 
-#: common.opt:950
+#: common.opt:954
 msgid "Aggressively optimize loops using language constraints."
 msgstr "Optimera aggressivt slingor med användning av språkbegränsningar."
 
-#: common.opt:954
+#: common.opt:958
 msgid "Align the start of functions."
 msgstr "Justera starten av funktioner."
 
-#: common.opt:964
+#: common.opt:968
 msgid "Align labels which are only reached by jumping."
 msgstr "Justera etiketter som bara nås via hopp."
 
-#: common.opt:971
+#: common.opt:975
 msgid "Align all labels."
 msgstr "Justera alla etiketter."
 
-#: common.opt:978
+#: common.opt:982
 msgid "Align the start of loops."
 msgstr "Justera starten av slingor."
 
-#: common.opt:1001
+#: common.opt:1005
 msgid "Select what to sanitize."
 msgstr "Välj vad som skall saneras."
 
-#: common.opt:1005
+#: common.opt:1009
 msgid "Select type of coverage sanitization."
 msgstr "Välj typ av täckningssanering."
 
-#: common.opt:1009
+#: common.opt:1013
 msgid "-fasan-shadow-offset=<number>\tUse custom shadow memory offset."
 msgstr "-fasan-shadow-offset=<tal>\tAnvänd anpassat avstånd till skuggminne."
 
-#: common.opt:1013
+#: common.opt:1017
 msgid "-fsanitize-sections=<sec1,sec2,...>\tSanitize global variables in user-defined sections."
 msgstr "-fsanitize-sections=<sek1,sek2,…>\tSanera globala variabler i användardefinierade sektioner."
 
-#: common.opt:1018
+#: common.opt:1022
 msgid "After diagnosing undefined behavior attempt to continue execution."
 msgstr "Efter att diagnosticera odefinierat beteende, försök fortsätta körningen."
 
-#: common.opt:1022
+#: common.opt:1026
 msgid "This switch is deprecated; use -fsanitize-recover= instead."
 msgstr "Denna flagga bör undvikas, använd -fsanitize-recover= istället."
 
-#: common.opt:1029
+#: common.opt:1033
 msgid "Use trap instead of a library function for undefined behavior sanitization."
 msgstr "Använd trap istället för en biblioteksfunktion för sanering av odefinierat beteende."
 
-#: common.opt:1033
+#: common.opt:1037
 msgid "Generate unwind tables that are exact at each instruction boundary."
 msgstr "Generera tabeller för upprullning som är exakta vid varje instruktionsgräns."
 
-#: common.opt:1037
+#: common.opt:1041
 msgid "Generate auto-inc/dec instructions."
 msgstr "Generera auto-inc/dec-instruktioner."
 
-#: common.opt:1041
+#: common.opt:1045
 msgid "Use sample profile information for call graph node weights. The default profile file is fbdata.afdo in 'pwd'."
 msgstr "Använd samplingprofilinformation till anropsgrafers nodvikter.  Standard profilfil är fbdata.afdo i ”pwd”."
 
-#: common.opt:1046
+#: common.opt:1050
 msgid "Use sample profile information for call graph node weights. The profile file is specified in the argument."
 msgstr "Använd samplingsprofilinformation till anropsgrafers nodvikter.  Profilen är angiven i argumentet."
 
-#: common.opt:1055
+#: common.opt:1059
 msgid "Generate code to check bounds before indexing arrays."
 msgstr "Generera kod för att kontrollera gränser före indexering i vektorer."
 
-#: common.opt:1059
+#: common.opt:1063
 msgid "Replace add, compare, branch with branch on count register."
 msgstr "Ersätt addition, jämförelse, grena med gren vid räknarregister."
 
-#: common.opt:1063
+#: common.opt:1067
 msgid "Use profiling information for branch probabilities."
 msgstr "Använd profileringsinformation för grensannolikheter."
 
-#: common.opt:1067
+#: common.opt:1071
 msgid "Perform branch target load optimization before prologue / epilogue threading."
 msgstr "Utför optimering av grenmålsladdning före prolog-/epilogtrådning."
 
-#: common.opt:1071
+#: common.opt:1075
 msgid "Perform branch target load optimization after prologue / epilogue threading."
 msgstr "Utför optimering av grenmålsladdning efter prolog-/epilogtrådning."
 
-#: common.opt:1075
+#: common.opt:1079
 msgid "Restrict target load migration not to re-use registers in any basic block."
 msgstr "Begränsa migration av målladdning till att inte återanvända register i något grundblock."
 
-#: common.opt:1079
+#: common.opt:1083
 msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions."
 msgstr "-fcall-saved-<register>\tMarkera att <register> bevaras mellan funktioner."
 
-#: common.opt:1083
+#: common.opt:1087
 msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls."
 msgstr "-fcall-used-<register>\tMarkera att <register> förstörs av funktionsanrop."
 
-#: common.opt:1090
+#: common.opt:1094
 msgid "Save registers around function calls."
 msgstr "Spara register runt funktionsanrop."
 
-#: common.opt:1094
+#: common.opt:1098
 msgid "This switch is deprecated; do not use."
 msgstr "Denna flagga bör undvikas, använd den inte."
 
-#: common.opt:1098
+#: common.opt:1102
 msgid "Check the return value of new in C++."
 msgstr "Kontrollera returvärdet av new i C++."
 
-#: common.opt:1102 common.opt:1106
+#: common.opt:1106 common.opt:1110
 msgid "Perform internal consistency checkings."
 msgstr "Utför interna konsistenskontroller."
 
-#: common.opt:1110
+#: common.opt:1114
 msgid "Enable code hoisting."
 msgstr "Aktivera kodhissning."
 
-#: common.opt:1114
+#: common.opt:1118
 msgid "Looks for opportunities to reduce stack adjustments and stack references."
 msgstr "Söker efter möjligheter att minska stackjusteringar och stackreferenser."
 
-#: common.opt:1118
+#: common.opt:1122
 msgid "Do not put uninitialized globals in the common section."
 msgstr "Lägg inte oinitierade globala i den gemensamma sektionen."
 
-#: common.opt:1126
+#: common.opt:1130
 msgid "-fcompare-debug[=<opts>]\tCompile with and without e.g. -gtoggle, and compare the final-insns dump."
 msgstr "-fcompare-debug[=<flgr>]\tKompilera med och utan t.ex. -gtoggle, och jämför slutinstruktionsdumpen."
 
-#: common.opt:1130
+#: common.opt:1134
 msgid "Run only the second compilation of -fcompare-debug."
 msgstr "Kör endast den andra kompileringen av -fcompare-debug."
 
-#: common.opt:1134
+#: common.opt:1138
 msgid "Perform comparison elimination after register allocation has finished."
 msgstr "Utför eliminering av jämförelser efter registertilldelningen har avslutats."
 
-#: common.opt:1138
+#: common.opt:1142
 msgid "Do not perform optimizations increasing noticeably stack usage."
 msgstr "Utför inte optimeringar som märkbart ökar stackanvändningen."
 
-#: common.opt:1142
+#: common.opt:1146
 msgid "Perform a register copy-propagation optimization pass."
 msgstr "Utför ett optimeringspass för kopieringspropagering av register."
 
-#: common.opt:1146
+#: common.opt:1150
 msgid "Perform cross-jumping optimization."
 msgstr "Utför optimering för korshopp."
 
-#: common.opt:1150
+#: common.opt:1154
 msgid "When running CSE, follow jumps to their targets."
 msgstr "När CSE körs, följ hopp till deras mål."
 
-#: common.opt:1158
+#: common.opt:1162
 msgid "Omit range reduction step when performing complex division."
 msgstr "Uteslut intervallreduktionssteget när komplex division görs."
 
-#: common.opt:1162
+#: common.opt:1166
 msgid "Complex multiplication and division follow Fortran rules."
 msgstr "Komplex multiplikation och division följer Fortranregler."
 
-#: common.opt:1166
+#: common.opt:1170
 msgid "Place data items into their own section."
 msgstr "Placera dataobjekt i sin egen sektion."
 
-#: common.opt:1170
+#: common.opt:1174
 msgid "List all available debugging counters with their limits and counts."
 msgstr "Lista alla tillgängliga felsökningsräknare med deras gränser och värden."
 
-#: common.opt:1174
+#: common.opt:1178
 msgid "-fdbg-cnt=<counter>:<limit>[,<counter>:<limit>,...]\tSet the debug counter limit."
 msgstr "-fdbg-cnt=<räknare>:<gräns>[,<räknare>:<gräns>,...]\tSätt gränsen för felsökningsräknare."
 
-#: common.opt:1178
+#: common.opt:1182
 msgid "-fdebug-prefix-map=<old>=<new> Map one directory name to another in debug information."
 msgstr "-fdebug-prefix-map=<gammalt>=<nytt> Översätt ett katalognamn till ett annat i felsökningsinformation."
 
-#: common.opt:1182
+#: common.opt:1186
 msgid "-ffile-prefix-map=<old>=<new> Map one directory name to another in compilation result."
 msgstr "-ffile-prefix-map=<gammalt>=<nytt> Översätt ett katalognamn till ett annat i kompileringsresultatet."
 
-#: common.opt:1186
+#: common.opt:1190
 msgid "Output .debug_types section when using DWARF v4 debuginfo."
 msgstr "Mata ut en .debug_types-sektion när DWARF v4 felsökningsinformation används."
 
-#: common.opt:1192
+#: common.opt:1196
 msgid "Defer popping functions args from stack until later."
 msgstr "Senarelägg borttagandet av funktionsargument från stacken."
 
-#: common.opt:1196
+#: common.opt:1200
 msgid "Attempt to fill delay slots of branch instructions."
 msgstr "Försök fylla fördröjningsfack av greninstruktioner."
 
-#: common.opt:1200
+#: common.opt:1204
 msgid "Delete dead instructions that may throw exceptions."
 msgstr "Ta bort döda instruktioner som kan kasta undantag."
 
-#: common.opt:1204
+#: common.opt:1208
 msgid "Delete useless null pointer checks."
 msgstr "Ta bort onödiga nollpekarkontroller."
 
-#: common.opt:1208
+#: common.opt:1212
 msgid "Stream extra data to support more aggressive devirtualization in LTO local transformation mode."
 msgstr "Strömma extra data för att stödja mer aggressiv avvirtualisering i lokaltransformationsläge i LTO."
 
-#: common.opt:1212
+#: common.opt:1216
 msgid "Perform speculative devirtualization."
 msgstr "Utför spekulativ avvirtualisering."
 
-#: common.opt:1216
+#: common.opt:1220
 msgid "Try to convert virtual calls to direct ones."
 msgstr "Försök att konvertera virtuella anrop till direkta."
 
-#: common.opt:1220
+#: common.opt:1224
 msgid "-fdiagnostics-show-location=[once|every-line]\tHow often to emit source location at the beginning of line-wrapped diagnostics."
 msgstr "-fdiagnostics-show-location=[once|every-line]\tAnger hur ofta källkodspositioner skall skrivas ut i början av utskrift vid radbrytning."
 
-#: common.opt:1237
+#: common.opt:1241
 msgid "Show the source line with a caret indicating the column."
 msgstr "Visa källkodsrader med en cirkumflex som indikerar kolumnen."
 
-#: common.opt:1245
+#: common.opt:1249
 msgid "-fdiagnostics-color=[never|always|auto]\tColorize diagnostics."
 msgstr "-fdiagnostics-color=[never|always|auto]\tFärglägg felmeddelanden."
 
-#: common.opt:1265
+#: common.opt:1269
 msgid "Print fix-it hints in machine-readable form."
 msgstr "Skriv fixit-tips i maskinläsbar form."
 
-#: common.opt:1269
+#: common.opt:1273
 msgid "Print fix-it hints to stderr in unified diff format."
 msgstr "Skriv fix-it-tips till standard fel i unifierat diff-format."
 
-#: common.opt:1273
+#: common.opt:1277
 msgid "Amend appropriate diagnostic messages with the command line option that controls them."
 msgstr "Lägg till lämpliga diagnostiska meddelanden till kommandoradsflaggan som styr dem."
 
-#: common.opt:1277
+#: common.opt:1281
 msgid "-fdisable-[tree|rtl|ipa]-<pass>=range1+range2 disables an optimization pass."
 msgstr "-fdisable-[tree|rtl|ipa]-<pass>=intrvl1+intrvl2 avaktiverar ett optimeringspass."
 
-#: common.opt:1281
+#: common.opt:1285
 msgid "-fenable-[tree|rtl|ipa]-<pass>=range1+range2 enables an optimization pass."
 msgstr "-fenable-[tree|rtl|ipa]-<pass>=intrvl1+intrvl2 aktiverar ett optimeringspass."
 
-#: common.opt:1285
+#: common.opt:1289
 msgid "-fdump-<type>\tDump various compiler internals to a file."
 msgstr "-fdump-<typ>\tSkriv ut diverse intern kompilatorinformation till en fil."
 
-#: common.opt:1292
+#: common.opt:1296
 msgid "-fdump-final-insns=filename\tDump to filename the insns at the end of translation."
 msgstr "-fdump-final-insns=filnamn\tSkriv instruktionerna vid slutet av översättningen till filnamn."
 
-#: common.opt:1296
+#: common.opt:1300
 msgid "-fdump-go-spec=filename\tWrite all declarations to file as Go code."
 msgstr "-fdump-go-spec=filnamn\tSkriv alla deklarationer till fil som Go-kod."
 
-#: common.opt:1300
+#: common.opt:1304
 msgid "Suppress output of addresses in debugging dumps."
 msgstr "Undertryck utskrift av adresser i felsökningsutskrifter."
 
-#: common.opt:1304
+#: common.opt:1308
 msgid "Collect and dump debug information into temporary file if ICE in C/C++ compiler occurred."
 msgstr "Samla och skriv ut felsökningsinformation till en temporärfil om ICE sker i C/C++-kompilatorn."
 
-#: common.opt:1309
+#: common.opt:1313
 msgid "Dump detailed information on GCC's internal representation of source code locations."
 msgstr "Skriv ut detaljerad information om GCC:s interna representation av källkodsplatser."
 
-#: common.opt:1313
+#: common.opt:1317
 msgid "Dump optimization passes."
 msgstr "Dumpa optimeringspass."
 
-#: common.opt:1317
+#: common.opt:1321
 msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps."
 msgstr "Undertryck utskrift av instruktionsantal, radnummernoteringar och -adresser i felsökningsutskrifter."
 
-#: common.opt:1321
+#: common.opt:1325
 msgid "Suppress output of previous and next insn numbers in debugging dumps."
 msgstr "Undertryck utskrift av föregående och nästa instruktionsnummer i felsökningsutskrifter."
 
-#: common.opt:1325
+#: common.opt:1329
 msgid "Enable CFI tables via GAS assembler directives."
 msgstr "Aktivera CFI-tabeller via GAS-assemblerdirektiv."
 
-#: common.opt:1329
+#: common.opt:1333
 msgid "Perform early inlining."
 msgstr "Utför tidig inline:ing."
 
-#: common.opt:1337
+#: common.opt:1341
 msgid "Perform interprocedural reduction of aggregates."
 msgstr "Utför interprocedurell reduktion av aggregat."
 
-#: common.opt:1341
+#: common.opt:1345
 msgid "Perform unused symbol elimination in debug info."
 msgstr "Utför eliminering av oanvända symboler i felsökningsinformation."
 
-#: common.opt:1345
+#: common.opt:1349
 msgid "Perform unused type elimination in debug info."
 msgstr "Utför eliminering av oanvända typer i felsökningsinformation."
 
-#: common.opt:1349
+#: common.opt:1353
 msgid "Do not suppress C++ class debug information."
 msgstr "Undertryck inte felsökningsinformation för C++-klasser."
 
-#: common.opt:1353
+#: common.opt:1357
 msgid "Enable exception handling."
 msgstr "Aktivera undantagshantering."
 
-#: common.opt:1357
+#: common.opt:1361
 msgid "Perform a number of minor, expensive optimizations."
 msgstr "Utför ett antal smärre, dyra optimeringar."
 
-#: common.opt:1361
+#: common.opt:1365
 msgid "-fexcess-precision=[fast|standard]\tSpecify handling of excess floating-point precision."
 msgstr "-fexcess-precision=[fast|standard]\tAnge hantering av överskjutande precision på flyttal."
 
-#: common.opt:1364
+#: common.opt:1368
 #, c-format
 msgid "unknown excess precision style %qs"
 msgstr "okänd stil för överskjutande precision %qs"
 
-#: common.opt:1376
+#: common.opt:1380
 msgid "-fpermitted-flt-eval-methods=[c11|ts-18661]\tSpecify which values of FLT_EVAL_METHOD are permitted."
 msgstr "-fpermitted-flt-eval-methods=[c11|ts-18661]\tAnge vilka värden på FLT_EVAL_METHOD som är tillåtna."
 
-#: common.opt:1379
+#: common.opt:1383
 #, c-format
 msgid "unknown specification for the set of FLT_EVAL_METHOD values to permit %qs"
 msgstr "okänd specifikation för uppsättningen av värden på FLT_EVAL_METHOD att tillåta %qs"
 
-#: common.opt:1392
+#: common.opt:1396
 msgid "Output lto objects containing both the intermediate language and binary output."
 msgstr "Mata ut lto-objekt som innehåller både mellanspråket och binärutdata."
 
-#: common.opt:1396
+#: common.opt:1400
 msgid "Assume no NaNs or infinities are generated."
 msgstr "Anta att inga NaN:er eller oändligheter genereras."
 
-#: common.opt:1400
+#: common.opt:1404
 msgid "-ffixed-<register>\tMark <register> as being unavailable to the compiler."
 msgstr "-ffixed-<register>\tMarkera <register> som ej tillgängligt för kompilatorn."
 
-#: common.opt:1404
+#: common.opt:1408
 msgid "Don't allocate floats and doubles in extended-precision registers."
 msgstr "Allokera inte float och double i register med utökad precision."
 
-#: common.opt:1412
+#: common.opt:1416
 msgid "Perform a forward propagation pass on RTL."
 msgstr "Utför ett framåtpropageringspass på RTL."
 
-#: common.opt:1416
+#: common.opt:1420
 msgid "-ffp-contract=[off|on|fast]\tPerform floating-point expression contraction."
 msgstr "-ffp-contract=[off|on|fast]\tUtför kontraktion av flyttalsuttryck."
 
-#: common.opt:1419
+#: common.opt:1423
 #, c-format
 msgid "unknown floating point contraction style %qs"
 msgstr "okänd stil för flyttalssammandragning %qs"
 
-#: common.opt:1433
+#: common.opt:1437
 msgid "Allow built-in functions ceil, floor, round, trunc to raise \"inexact\" exceptions."
 msgstr "Tillåt de inbyggda funktionerna ceil, floor, round, trunc att höja ”oexakt”-undantag."
 
-#: common.opt:1440
+#: common.opt:1444
 msgid "Allow function addresses to be held in registers."
 msgstr "Tillåt att funktionsadresser läggs i register."
 
-#: common.opt:1444
+#: common.opt:1448
 msgid "Place each function into its own section."
 msgstr "Placera varje funktion i sin egen sektion."
 
-#: common.opt:1448
+#: common.opt:1452
 msgid "Perform global common subexpression elimination."
 msgstr "Utför global eliminering av gemensamma deluttryck."
 
-#: common.opt:1452
+#: common.opt:1456
 msgid "Perform enhanced load motion during global common subexpression elimination."
 msgstr "Utför förbättrad förflyttning av laddning under global eliminering av gemensamma deluttryck."
 
-#: common.opt:1456
+#: common.opt:1460
 msgid "Perform store motion after global common subexpression elimination."
 msgstr "Utför förflyttning av lagring efter global eliminering av gemensamma deluttryck."
 
-#: common.opt:1460
+#: common.opt:1464
 msgid "Perform redundant load after store elimination in global common subexpression elimination."
 msgstr "Utför eliminering av överflödig laddning efter lagring i globala gemensamma deluttryck."
 
-#: common.opt:1465
+#: common.opt:1469
 msgid "Perform global common subexpression elimination after register allocation has finished."
 msgstr "Utför global eliminering av gemensamma deluttryck efter att registertilldelning har avslutats."
 
-#: common.opt:1482
+#: common.opt:1486
 msgid "-fgnat-encodings=[all|gdb|minimal]\tSelect the balance between GNAT encodings and standard DWARF emitted in the debug information"
 msgstr "-fgnat-encodings=[all|gdb|minimal]\tVälj balansen mellan GNAT-kodningar och standard DWARF som skrivs ut i felsökningsinformationen"
 
-#: common.opt:1487
+#: common.opt:1491
 msgid "Enable in and out of Graphite representation."
 msgstr "Aktivera in och ut från Graphite-representation."
 
-#: common.opt:1491
+#: common.opt:1495
 msgid "Enable Graphite Identity transformation."
 msgstr "Aktivera Graphite-identitetstransformation."
 
-#: common.opt:1495
+#: common.opt:1499
 msgid "Enable hoisting adjacent loads to encourage generating conditional move instructions."
 msgstr "Aktivera närliggande lyftningsladdning för att uppmuntra generering av villkorliga move-instruktioner."
 
-#: common.opt:1504
+#: common.opt:1508
 msgid "Mark all loops as parallel."
 msgstr "Markera alla slingor som parallella."
 
-#: common.opt:1508 common.opt:1516 common.opt:2587
+#: common.opt:1512 common.opt:1520 common.opt:2591
 msgid "Enable loop nest transforms.  Same as -floop-nest-optimize."
 msgstr "Aktivera transformationer av slingutbyten.  Samma som -floop-nest-optimize."
 
-#: common.opt:1512
+#: common.opt:1516
 msgid "Enable loop interchange on trees."
 msgstr "Aktivera slingutbyten i träd."
 
-#: common.opt:1520
+#: common.opt:1524
 msgid "Perform unroll-and-jam on loops."
 msgstr "Utför unroll-and-jam på slingor."
 
-#: common.opt:1524
+#: common.opt:1528
 msgid "Enable support for GNU transactional memory."
 msgstr "Aktivera stöd för GNU:s transaktionsminne."
 
-#: common.opt:1528
+#: common.opt:1532
 msgid "Use STB_GNU_UNIQUE if supported by the assembler."
 msgstr "Använd STB_GNU_UNIQUE om det stödjs av assemblern."
 
-#: common.opt:1536
+#: common.opt:1540
 msgid "Enable the loop nest optimizer."
 msgstr "Aktivera optimeraren av slingnästning."
 
-#: common.opt:1540
+#: common.opt:1544
 msgid "Force bitfield accesses to match their type width."
 msgstr "Tvinga bitfältsåtkomster att matcha sin typbredd."
 
-#: common.opt:1544
+#: common.opt:1548
 msgid "Merge adjacent stores."
 msgstr "Slå samman intilliggande lagringar."
 
-#: common.opt:1548
+#: common.opt:1552
 msgid "Enable guessing of branch probabilities."
 msgstr "Aktivera att grensannolikheter gissas."
 
-#: common.opt:1556
+#: common.opt:1560
 msgid "Process #ident directives."
 msgstr "Hantera #ident-direktiv."
 
-#: common.opt:1560
+#: common.opt:1564
 msgid "Perform conversion of conditional jumps to branchless equivalents."
 msgstr "Utför konvertering av villkorliga hopp till grenlösa motsvarigheter."
 
-#: common.opt:1564
+#: common.opt:1568
 msgid "Perform conversion of conditional jumps to conditional execution."
 msgstr "Utför konvertering av villkorliga hopp till villkorlig exekvering."
 
-#: common.opt:1568
+#: common.opt:1572
 msgid "-fstack-reuse=[all|named_vars|none]\tSet stack reuse level for local variables."
 msgstr "-fstack-reuse=[all|named_vars|none]\tStäll in stackåteranvändningsnivån för lokala variabler."
 
-#: common.opt:1571
+#: common.opt:1575
 #, c-format
 msgid "unknown Stack Reuse Level %qs"
 msgstr "okänd stackåteranvändningsmodell %qs"
 
-#: common.opt:1584
+#: common.opt:1588
 msgid "Convert conditional jumps in innermost loops to branchless equivalents."
 msgstr "Konvertera villkorliga hopp i innersta slingor till grenlösa motsvarigheter."
 
-#: common.opt:1596
+#: common.opt:1600
 msgid "Do not generate .size directives."
 msgstr "Generera inte .size-direktiv."
 
-#: common.opt:1600
+#: common.opt:1604
 msgid "Perform indirect inlining."
 msgstr "Utför indirekt inline:ing."
 
-#: common.opt:1606
+#: common.opt:1610
 msgid "Enable inlining of function declared \"inline\", disabling disables all inlining."
 msgstr "Aktivera inline:ing av funktioner deklarerade ”inline”, avslaget avaktiveras all inline:ing."
 
-#: common.opt:1610
+#: common.opt:1614
 msgid "Integrate functions into their callers when code size is known not to grow."
 msgstr "Integrera funktioner i deras anropare när det är klart att kodstorleken inte växer."
 
-#: common.opt:1614
+#: common.opt:1618
 msgid "Integrate functions not declared \"inline\" into their callers when profitable."
 msgstr "Integrera funktioner deklarerade ”inline” i deras anropare när det lönar sig."
 
-#: common.opt:1618
+#: common.opt:1622
 msgid "Integrate functions only required by their single caller."
 msgstr "Integrera funktioner som endast behövs av deras enda anropare."
 
-#: common.opt:1625
+#: common.opt:1629
 msgid "-finline-limit=<number>\tLimit the size of inlined functions to <number>."
 msgstr "-finline-limit=<tal>\tBegränsa storlek på inline-funktioner till <tal>."
 
-#: common.opt:1629
+#: common.opt:1633
 msgid "Inline __atomic operations when a lock free instruction sequence is available."
 msgstr "Inline:a __atomic-operationer när en låsningsfri instruktionssekvens är tillgänglig."
 
-#: common.opt:1636
+#: common.opt:1640
 msgid "-fcf-protection=[full|branch|return|none]\tInstrument functions with checks to verify jump/call/return control-flow transfer instructions have valid targets."
 msgstr "-fcf-protection=[full|branch|return|none]\tInstrumentera funktioner med kontroller för att verifiera att jump/call/return-instruktioner för styrflödesövergångar har giltiga mål."
 
-#: common.opt:1640
+#: common.opt:1644
 #, c-format
 msgid "unknown Control-Flow Protection Level %qs"
 msgstr "okänd nivå för kontrollflödesskydd %qs"
 
-#: common.opt:1656
+#: common.opt:1660
 msgid "Instrument function entry and exit with profiling calls."
 msgstr "Instrumentera funktionsingång och -utgång med profileringsanrop."
 
-#: common.opt:1660
+#: common.opt:1664
 msgid "-finstrument-functions-exclude-function-list=name,...  Do not instrument listed functions."
 msgstr "-finstrument-functions-exclude-function-list=namn,...  Instrumentera inte uppräknade funktioner."
 
-#: common.opt:1664
+#: common.opt:1668
 msgid "-finstrument-functions-exclude-file-list=filename,...  Do not instrument functions listed in files."
 msgstr "-finstrument-functions-exclude-file-list=filenamn,...  Instrumentera inte funktioner uppräknade i filerna."
 
-#: common.opt:1668
+#: common.opt:1672
 msgid "Perform interprocedural constant propagation."
 msgstr "Utför konstantpropagering mellan procedurer."
 
-#: common.opt:1672
+#: common.opt:1676
 msgid "Perform cloning to make Interprocedural constant propagation stronger."
 msgstr "Utför kloning för att göra konstantpropagering mellan procedurer starkare."
 
-#: common.opt:1680
+#: common.opt:1684
 msgid "Perform interprocedural bitwise constant propagation."
 msgstr "Utför bitvis konstantpropagering mellan procedurer."
 
-#: common.opt:1684
+#: common.opt:1688
 msgid "Perform interprocedural profile propagation."
 msgstr "Utför profileringspropagering mellan procedurer."
 
-#: common.opt:1688
+#: common.opt:1692
 msgid "Perform interprocedural points-to analysis."
 msgstr "Utför pekar-på-analyser mellan procedurer."
 
-#: common.opt:1692
+#: common.opt:1696
 msgid "Discover pure and const functions."
 msgstr "Upptäck pure- och const-funktioner."
 
-#: common.opt:1696
+#: common.opt:1700
 msgid "Perform Identical Code Folding for functions and read-only variables."
 msgstr "Fäll ihop identisk kod för funktioner och endast läsbara variabler."
 
-#: common.opt:1700
+#: common.opt:1704
 msgid "Perform Identical Code Folding for functions."
 msgstr "Fäll ihop identisk kod för funktioner."
 
-#: common.opt:1704
+#: common.opt:1708
 msgid "Perform Identical Code Folding for variables."
 msgstr "Utför ihopfällning av identiskt kod för variabler."
 
-#: common.opt:1708
+#: common.opt:1712
 msgid "Discover readonly and non addressable static variables."
 msgstr "Upptäck endast läsbara och icke adresserbara statiska variabler."
 
-#: common.opt:1720
+#: common.opt:1724
 msgid "Perform IPA Value Range Propagation."
 msgstr "Utför IPA-propagering av värdeintervall."
 
-#: common.opt:1724
+#: common.opt:1728
 msgid "-fira-algorithm=[CB|priority]\tSet the used IRA algorithm."
 msgstr "-fira-algorithm=[CB|priority]\tBestäm den använda IRA-algoritmen."
 
-#: common.opt:1727
+#: common.opt:1731
 #, c-format
 msgid "unknown IRA algorithm %qs"
 msgstr "okänd IRA-algoritm %qs"
 
-#: common.opt:1737
+#: common.opt:1741
 msgid "-fira-region=[one|all|mixed]\tSet regions for IRA."
 msgstr "-fira-region=[one|all|mixed]\tSätt regioner för IRA."
 
-#: common.opt:1740
+#: common.opt:1744
 #, c-format
 msgid "unknown IRA region %qs"
 msgstr "okänd IRA-region %qs"
 
-#: common.opt:1753
+#: common.opt:1757
 msgid "Use IRA based register pressure calculation in RTL hoist optimizations."
 msgstr "Använd IRA-baserad registertryckberäkning i RTL-hissningsoptimeringar."
 
-#: common.opt:1758
+#: common.opt:1762
 msgid "Use IRA based register pressure calculation in RTL loop optimizations."
 msgstr "Använd IRA-baserad registertryckberäkning i RTL-slingeoptimeringar."
 
-#: common.opt:1763
+#: common.opt:1767
 msgid "Share slots for saving different hard registers."
 msgstr "Dela fack för att spara olika hårda register."
 
-#: common.opt:1767
+#: common.opt:1771
 msgid "Share stack slots for spilled pseudo-registers."
 msgstr "Dela stackfack för spillda pseudoregister."
 
-#: common.opt:1771
+#: common.opt:1775
 msgid "-fira-verbose=<number>\tControl IRA's level of diagnostic messages."
 msgstr "-fira-verbose=<tal>\tStyr IRA:ns nivå på diagnostikmeddelanden."
 
-#: common.opt:1775
+#: common.opt:1779
 msgid "Optimize induction variables on trees."
 msgstr "Optimera induktionsvariabler på träd."
 
-#: common.opt:1779
+#: common.opt:1783
 msgid "Use jump tables for sufficiently large switch statements."
 msgstr "Använd hopptabeller för tillräckligt stora switch-satser."
 
-#: common.opt:1783
+#: common.opt:1787
 msgid "Generate code for functions even if they are fully inlined."
 msgstr "Generera kod för funktioner även om de är fullständigt inline:ade."
 
-#: common.opt:1787
+#: common.opt:1791
 msgid "Generate code for static functions even if they are never called."
 msgstr "Generera kod för statiska funktioner även om de aldrig anropas."
 
-#: common.opt:1791
+#: common.opt:1795
 msgid "Emit static const variables even if they are not used."
 msgstr "Mata ut static const-variabler även om de inte används."
 
-#: common.opt:1795
+#: common.opt:1799
 msgid "Give external symbols a leading underscore."
 msgstr "Ge externa symboler ett inledande understrykningstecken."
 
-#: common.opt:1803
+#: common.opt:1807
 msgid "Do CFG-sensitive rematerialization in LRA."
 msgstr "Gör CFG-känsliga återmaterialiseringar i LRA."
 
-#: common.opt:1807
+#: common.opt:1811
 msgid "Enable link-time optimization."
 msgstr "Aktivera länkningsoptimeringar."
 
-#: common.opt:1811
+#: common.opt:1815
 msgid "Link-time optimization with number of parallel jobs or jobserver."
 msgstr "Optimeringar vid länktillfället med flera parallella jobb eller jobbserver."
 
-#: common.opt:1814
+#: common.opt:1818
 #, c-format
 msgid "unknown LTO partitioning model %qs"
 msgstr "okänd LTO-partitioneringsmodell %qs"
 
-#: common.opt:1833
+#: common.opt:1837
 msgid "Specify the algorithm to partition symbols and vars at linktime."
 msgstr "Ange algoritmen för att dela upp symboler och variabler vid länktillfället."
 
-#: common.opt:1838
+#: common.opt:1842
 msgid "-flto-compression-level=<number>\tUse zlib compression level <number> for IL."
 msgstr "-flto-compression-level=<tal>\tAnvänd zlib-komprimering på nivå <tal> för IL."
 
-#: common.opt:1842
+#: common.opt:1846
 msgid "Merge C++ types using One Definition Rule."
 msgstr "Slå samman C++-typer med endefinitionsregeln."
 
-#: common.opt:1846
+#: common.opt:1850
 msgid "Report various link-time optimization statistics."
 msgstr "Rapportera diverse optimeringsstatistik från länkningen."
 
-#: common.opt:1850
+#: common.opt:1854
 msgid "Report various link-time optimization statistics for WPA only."
 msgstr "Rapportera diverse optimeringsstatistik från länkningen endast för WPA."
 
-#: common.opt:1854
+#: common.opt:1858
 msgid "Set errno after built-in math functions."
 msgstr "Sätt errno efter inbyggda matematikfunktioner."
 
-#: common.opt:1858
+#: common.opt:1862
 msgid "-fmax-errors=<number>\tMaximum number of errors to report."
 msgstr "-fmax-errors=<antal>\tMaximalt antal fel som skall rapporteras."
 
-#: common.opt:1862
+#: common.opt:1866
 msgid "Report on permanent memory allocation."
 msgstr "Rapportera om permanent minnesallokering."
 
-#: common.opt:1866
+#: common.opt:1870
 msgid "Report on permanent memory allocation in WPA only."
 msgstr "Rapportera bara om permanent minnesallokering i WPA."
 
-#: common.opt:1873
+#: common.opt:1877
 msgid "Attempt to merge identical constants and constant variables."
 msgstr "Försök slå samman identiska konstanter och konstanta variabler."
 
-#: common.opt:1877
+#: common.opt:1881
 msgid "Attempt to merge identical constants across compilation units."
 msgstr "Försök slå samman identiska konstanter mellan kompileringsenheter."
 
-#: common.opt:1881
+#: common.opt:1885
 msgid "Attempt to merge identical debug strings across compilation units."
 msgstr "Försök slå samman identiska felsökningssträngar mellan kompileringsenheter."
 
-#: common.opt:1885
+#: common.opt:1889
 msgid "-fmessage-length=<number>\tLimit diagnostics to <number> characters per line.  0 suppresses line-wrapping."
 msgstr "-fmessage-length=<antal>\tBegränsa felmeddelandens längd till <antal> tecken per rad.  0 stänger av radbrytning."
 
-#: common.opt:1889
+#: common.opt:1893
 msgid "Perform SMS based modulo scheduling before the first scheduling pass."
 msgstr "Utför SMS-baserad modulo-schemaläggning före det första schemaläggningspasset."
 
-#: common.opt:1893
+#: common.opt:1897
 msgid "Perform SMS based modulo scheduling with register moves allowed."
 msgstr "Utför SMS-baserad modulo-schemaläggning med tillåten registerförflyttning."
 
-#: common.opt:1897
+#: common.opt:1901
 msgid "Move loop invariant computations out of loops."
 msgstr "Flytta slinginvarianta beräkningar ut från slingor."
 
-#: common.opt:1901
+#: common.opt:1905
 msgid "Use the RTL dead code elimination pass."
 msgstr "Använd passet på RTL för eliminering av död kod."
 
-#: common.opt:1905
+#: common.opt:1909
 msgid "Use the RTL dead store elimination pass."
 msgstr "Använd passet på RTL för eliminering av död lagring."
 
-#: common.opt:1909
+#: common.opt:1913
 msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling."
 msgstr "Aktivera/deaktivera den traditionella schemaläggningen i slingor som redan passerat modulo-schemaläggning."
 
-#: common.opt:1913
+#: common.opt:1917
 msgid "Support synchronous non-call exceptions."
 msgstr "Stöd synkrona icke-anropsundantag."
 
-#: common.opt:1916
+#: common.opt:1920
 #, c-format
 msgid "options or targets missing after %qs"
 msgstr "flaggor eller mål saknas efter %qs"
 
-#: common.opt:1917
+#: common.opt:1921
 msgid "-foffload=<targets>=<options>  Specify offloading targets and options for them."
 msgstr "-foffload=<mål>=<flaggor>  Ange mål att lasta av till och flaggor för dem."
 
-#: common.opt:1921
+#: common.opt:1925
 msgid "-foffload-abi=[lp64|ilp32]     Set the ABI to use in an offload compiler."
 msgstr "-foffload-abi=[lp64|ilp32]     Ange ABI:et att använda i en avlastningskompilator."
 
-#: common.opt:1924
+#: common.opt:1928
 #, c-format
 msgid "unknown offload ABI %qs"
 msgstr "okänd avlastnings-ABI %qs"
 
-#: common.opt:1934
+#: common.opt:1938
 msgid "When possible do not generate stack frames."
 msgstr "Låt bli att generera stackramar när det är möjligt."
 
-#: common.opt:1938
+#: common.opt:1942
 msgid "Enable all optimization info dumps on stderr."
 msgstr "Aktivera alla optimeringsinformationsdumpar på standard fel."
 
-#: common.opt:1942
+#: common.opt:1946
 msgid "-fopt-info[-<type>=filename]\tDump compiler optimization details."
 msgstr "-fopt-info[-<type>=filenamn]\tSkriv ut kompilatoroptimeringsdetaljer."
 
-#: common.opt:1950
+#: common.opt:1954
 msgid "Optimize sibling and tail recursive calls."
 msgstr "Optimera syskon- och svansrekursiva anrop."
 
-#: common.opt:1954
+#: common.opt:1958
 msgid "Perform partial inlining."
 msgstr "Utför partiell inline:ing."
 
-#: common.opt:1958 common.opt:1962
+#: common.opt:1962 common.opt:1966
 msgid "Report on memory allocation before interprocedural optimization."
 msgstr "Rapportera minnesallokering för interprocedurella optimeringar."
 
-#: common.opt:1966
+#: common.opt:1970
 msgid "Pack structure members together without holes."
 msgstr "Packa ihop postmedlemmar utan hål."
 
-#: common.opt:1970
+#: common.opt:1974
 msgid "-fpack-struct=<number>\tSet initial maximum structure member alignment."
 msgstr "-fpack-struct=<tal>\tAnge initial maximal justering för postmedlemmar."
 
-#: common.opt:1974
+#: common.opt:1978
 msgid "Return small aggregates in memory, not registers."
 msgstr "Returnera små aggregat i minne, inte register."
 
-#: common.opt:1978
+#: common.opt:1982
 msgid "Perform loop peeling."
 msgstr "Utför slingavskalning."
 
-#: common.opt:1982
+#: common.opt:1986
 msgid "Enable machine specific peephole optimizations."
 msgstr "Aktivera maskinspecifika nyckelhålsoptimeringar."
 
-#: common.opt:1986
+#: common.opt:1990
 msgid "Enable an RTL peephole pass before sched2."
 msgstr "Aktivera ett RTL-nyckelhålspass före sched2."
 
-#: common.opt:1990
+#: common.opt:1994
 msgid "Generate position-independent code if possible (large mode)."
 msgstr "Generera positionsoberoende kod om möjligt (stort läge)."
 
-#: common.opt:1994
+#: common.opt:1998
 msgid "Generate position-independent code for executables if possible (large mode)."
 msgstr "Generera positionsoberoende kod för körbara program om möjligt (stort läge)."
 
-#: common.opt:1998
+#: common.opt:2002
 msgid "Generate position-independent code if possible (small mode)."
 msgstr "Generera positionsoberoende kod om möjligt (litet läge)."
 
-#: common.opt:2002
+#: common.opt:2006
 msgid "Generate position-independent code for executables if possible (small mode)."
 msgstr "Generera positionsoberoende kod för körbara program om möjligt (litet läge)."
 
-#: common.opt:2006
+#: common.opt:2010
 msgid "Use PLT for PIC calls (-fno-plt: load the address from GOT at call site)."
 msgstr "Använd PLT för PIC-anrop (-fno-plt: läs adressen från GOT på anropsplatsen)."
 
-#: common.opt:2010
+#: common.opt:2014
 msgid "Specify a plugin to load."
 msgstr "Ange en insticksmodul att läsa in."
 
-#: common.opt:2014
+#: common.opt:2018
 msgid "-fplugin-arg-<name>-<key>[=<value>]\tSpecify argument <key>=<value> for plugin <name>."
 msgstr "-fplugin-arg-<namn>-<nyckel>[=<värde>]\tAnge argument <nyckel>=<värde> för insticksmodul <namn>."
 
-#: common.opt:2018
+#: common.opt:2022
 msgid "Run predictive commoning optimization."
 msgstr "Kör optimeringar för predikativ gemensamning."
 
-#: common.opt:2022
+#: common.opt:2026
 msgid "Generate prefetch instructions, if available, for arrays in loops."
 msgstr "Generera förhandshämtningsinstruktioner (prefetch), om tillgängliga, för vektorer i slingor."
 
-#: common.opt:2026
+#: common.opt:2030
 msgid "Enable basic program profiling code."
 msgstr "Aktivera grundläggande programprofileringskod."
 
-#: common.opt:2030
+#: common.opt:2034
 msgid "Generate absolute source path names for gcov."
 msgstr "Generera absoluta källkodssökvägar för gcov."
 
-#: common.opt:2034
+#: common.opt:2038
 msgid "Insert arc-based program profiling code."
 msgstr "Lägg in bågbaserad programprofileringskod."
 
-#: common.opt:2038
+#: common.opt:2042
 msgid "Set the top-level directory for storing the profile data. The default is 'pwd'."
 msgstr "Sätt toppnivåkatalogen för att spara profildata.  Standard är ”pwd”."
 
-#: common.opt:2043
+#: common.opt:2047
 msgid "Enable correction of flow inconsistent profile data input."
 msgstr "Aktivera korrigering av profilindata med inkonsistent flöde."
 
-#: common.opt:2047
+#: common.opt:2051
 msgid "-fprofile-update=[single|atomic|prefer-atomic]\tSet the profile update method."
 msgstr "-fprofile-update=[single|atomic|prefer-atomic]\tAnge metoden för profiluppdatering."
 
-#: common.opt:2050
+#: common.opt:2054
 #, c-format
 msgid "unknown profile update method %qs"
 msgstr "okänd profiluppdateringsmetod %qs"
 
-#: common.opt:2063
+#: common.opt:2067
 msgid "Enable common options for generating profile info for profile feedback directed optimizations."
 msgstr "Aktivera vanliga flaggor för att generera profileringsinformation för optimeringar styrda av återmatad profil."
 
-#: common.opt:2067
+#: common.opt:2071
 msgid "Enable common options for generating profile info for profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr "Aktivera vanliga flaggor för att generera profileringsinformation för optimeringar styrda av återmatad profil, och sätt -fprofile-dir=."
 
-#: common.opt:2071
+#: common.opt:2075
 msgid "Enable common options for performing profile feedback directed optimizations."
 msgstr "Aktivera vanliga flaggor för att utföra optimeringar styrda av återmatad profil."
 
-#: common.opt:2075
+#: common.opt:2079
 msgid "Enable common options for performing profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr "Aktivera vanliga flaggor för att utföra optimeringar styrda av återmatad profil, och sätt -fprofile-dir=."
 
-#: common.opt:2079
+#: common.opt:2083
 msgid "Insert code to profile values of expressions."
 msgstr "Lägg in kod för att profilera värden av uttryck."
 
-#: common.opt:2083
+#: common.opt:2087
 msgid "Report on consistency of profile."
 msgstr "Rapportera om intern konsistens hos profilen."
 
-#: common.opt:2087
+#: common.opt:2091
 msgid "Enable function reordering that improves code placement."
 msgstr "Aktivera omflyttning av funktioner för att förbättra kodplacering."
 
-#: common.opt:2091
+#: common.opt:2095
 msgid "Insert NOP instructions at each function entry."
 msgstr "Infoga NOP-instruktioner vid varje funktionsingång."
 
-#: common.opt:2098
+#: common.opt:2102
 msgid "-frandom-seed=<string>\tMake compile reproducible using <string>."
 msgstr "-frandom-seed=<sträng>\tGör kompileringen reproducerbar med <sträng>."
 
-#: common.opt:2108
+#: common.opt:2112
 msgid "Record gcc command line switches in the object file."
 msgstr "Notera gcc:s kommandoradsflaggor i objektfilen."
 
-#: common.opt:2112
+#: common.opt:2116
 msgid "Return small aggregates in registers."
 msgstr "Returnera små poster i register."
 
-#: common.opt:2120
+#: common.opt:2124
 msgid "Tell DSE that the storage for a C++ object is dead when the constructor starts and when the destructor finishes."
 msgstr "Berätta för DSE att lagringen för ett C++-objekt är dött när konstrueraren börjar och när destrueraren avslutar."
 
-#: common.opt:2128
+#: common.opt:2132
 msgid "Relief of register pressure through live range shrinkage."
 msgstr "Lättnad av registertryck genom minskning av aktivt intervall."
 
-#: common.opt:2132
+#: common.opt:2136
 msgid "Perform a register renaming optimization pass."
 msgstr "Utför ett optimeringspass med registernamnbyten."
 
-#: common.opt:2136
+#: common.opt:2140
 msgid "Perform a target dependent instruction fusion optimization pass."
 msgstr "Utför ett optimeringspass med målberoende instruktionssammanslagning."
 
-#: common.opt:2140
+#: common.opt:2144
 msgid "Reorder basic blocks to improve code placement."
 msgstr "Flytta om grundblock för att förbättra kodplacering."
 
-#: common.opt:2144
+#: common.opt:2148
 msgid "-freorder-blocks-algorithm=[simple|stc]\tSet the used basic block reordering algorithm."
 msgstr "-freorder-blocks-algorithm=[simple|stc]\tSätt algoritmen att användas för ordningsändring av grundblock."
 
-#: common.opt:2147
+#: common.opt:2151
 #, c-format
 msgid "unknown basic block reordering algorithm %qs"
 msgstr "okänd algoritm for omordning av grundblock %qs"
 
-#: common.opt:2157
+#: common.opt:2161
 msgid "Reorder basic blocks and partition into hot and cold sections."
 msgstr "Flytta om grundblock och partitioner till varma och kalla sektioner."
 
-#: common.opt:2161
+#: common.opt:2165
 msgid "Reorder functions to improve code placement."
 msgstr "Flytta om funktioner för att förbättra kodplacering."
 
-#: common.opt:2165
+#: common.opt:2169
 msgid "Add a common subexpression elimination pass after loop optimizations."
 msgstr "Lägg till ett pass för eliminering av gemensamma deluttryck efter slingoptimeringar."
 
-#: common.opt:2173
+#: common.opt:2177
 msgid "Disable optimizations that assume default FP rounding behavior."
 msgstr "Avaktivera optimeringar som antar standardmässigt avrundningsbeteende för FP."
 
-#: common.opt:2177
+#: common.opt:2181
 msgid "Enable scheduling across basic blocks."
 msgstr "Aktivera schemaläggning mellan grundblock."
 
-#: common.opt:2181
+#: common.opt:2185
 msgid "Enable register pressure sensitive insn scheduling."
 msgstr "Aktivera registertryckskänslig instruktionsschemaläggning."
 
-#: common.opt:2185
+#: common.opt:2189
 msgid "Allow speculative motion of non-loads."
 msgstr "Tillåt spekulativ förflyttning av icke-laddningar."
 
-#: common.opt:2189
+#: common.opt:2193
 msgid "Allow speculative motion of some loads."
 msgstr "Tillåt spekulativ förflyttning av några laddningar."
 
-#: common.opt:2193
+#: common.opt:2197
 msgid "Allow speculative motion of more loads."
 msgstr "Tillåt spekulativ förflyttning av fler laddningar."
 
-#: common.opt:2197
+#: common.opt:2201
 msgid "-fsched-verbose=<number>\tSet the verbosity level of the scheduler."
 msgstr "-fsched-verbose=<tal>\tAnge hur mångordig schemaläggaren skall vara."
 
-#: common.opt:2201
+#: common.opt:2205
 msgid "If scheduling post reload, do superblock scheduling."
 msgstr "Om schemaläggning efter omläsning, gör superblockschemaläggning."
 
-#: common.opt:2209
+#: common.opt:2213
 msgid "Reschedule instructions before register allocation."
 msgstr "Schemalägg om instruktioner före registertilldelning."
 
-#: common.opt:2213
+#: common.opt:2217
 msgid "Reschedule instructions after register allocation."
 msgstr "Schemalägg om instruktioner efter registertilldelning."
 
-#: common.opt:2220
+#: common.opt:2224
 msgid "Schedule instructions using selective scheduling algorithm."
 msgstr "Använd selektive schemaläggningsalgoritm för schemaläggning av instruktioner."
 
-#: common.opt:2224
+#: common.opt:2228
 msgid "Run selective scheduling after reload."
 msgstr "Kör selektiv schemaläggning efter omläsning."
 
-#: common.opt:2228
+#: common.opt:2232
 msgid "Run self-tests, using the given path to locate test files."
 msgstr "Kör självtester, använd den angivna sökvägen för att hitta testfiler."
 
-#: common.opt:2232
+#: common.opt:2236
 msgid "Perform software pipelining of inner loops during selective scheduling."
 msgstr "Utför programvarurörläggning av inre slingor under selektiv schemaläggning."
 
-#: common.opt:2236
+#: common.opt:2240
 msgid "Perform software pipelining of outer loops during selective scheduling."
 msgstr "Utför programvarurörläggning av yttre slingor under selektiv schemaläggning."
 
-#: common.opt:2240
+#: common.opt:2244
 msgid "Reschedule pipelined regions without pipelining."
 msgstr "Schemalägg om rörlagda regioner utan rörläggning."
 
-#: common.opt:2244
+#: common.opt:2248
 msgid "Allow interposing function (or variables) by ones with different semantics (or initializer) respectively by dynamic linker."
 msgstr "Tillåt funktioner (eller variabler) som står emellan för sådana med annan semantik (respektive initierare) i den dynamiska länkaren."
 
-#: common.opt:2250
+#: common.opt:2254
 msgid "Allow premature scheduling of queued insns."
 msgstr "Tillåt förtida schemaläggning av köade instruktioner."
 
-#: common.opt:2254
+#: common.opt:2258
 msgid "-fsched-stalled-insns=<number>\tSet number of queued insns that can be prematurely scheduled."
 msgstr "-fsched-stalled-insns=<antal>\tAnge antalet köade instruktioner som kan schemaläggas i förtid."
 
-#: common.opt:2262
+#: common.opt:2266
 msgid "Set dependence distance checking in premature scheduling of queued insns."
 msgstr "Sätt beroendeavståndet som kontrolleras i förtida schemaläggning av köade instruktioner."
 
-#: common.opt:2266
+#: common.opt:2270
 msgid "-fsched-stalled-insns-dep=<number>\tSet dependence distance checking in premature scheduling of queued insns."
 msgstr "-fsched-stalled-insns-dep=<antal>\tSätt beroendeavståndet som kontrolleras i förtida schemaläggning av köade instruktioner."
 
-#: common.opt:2270
+#: common.opt:2274
 msgid "Enable the group heuristic in the scheduler."
 msgstr "Aktivera gruppheuristiken i schemaläggaren."
 
-#: common.opt:2274
+#: common.opt:2278
 msgid "Enable the critical path heuristic in the scheduler."
 msgstr "Aktivera heuristiken för kritisk väg i schemaläggaren."
 
-#: common.opt:2278
+#: common.opt:2282
 msgid "Enable the speculative instruction heuristic in the scheduler."
 msgstr "Aktivera den spekulativa instruktionsheuristiken i schemaläggaren."
 
-#: common.opt:2282
+#: common.opt:2286
 msgid "Enable the rank heuristic in the scheduler."
 msgstr "Aktivera ordningsheuristiken i schemaläggaren."
 
-#: common.opt:2286
+#: common.opt:2290
 msgid "Enable the last instruction heuristic in the scheduler."
 msgstr "Aktivera heuristiken för sista instruktion i schemaläggaren."
 
-#: common.opt:2290
+#: common.opt:2294
 msgid "Enable the dependent count heuristic in the scheduler."
 msgstr "Aktivera heuristiken för beroende antal i schemaläggaren."
 
-#: common.opt:2294
+#: common.opt:2298
 msgid "Access data in the same section from shared anchor points."
 msgstr "Nå data i samma sektion från delade förankringspunkter."
 
-#: common.opt:2306
+#: common.opt:2310
 msgid "Turn on Redundant Extensions Elimination pass."
 msgstr "Slå på passet för eliminering av redundanta utökningar."
 
-#: common.opt:2310
+#: common.opt:2314
 msgid "Show column numbers in diagnostics, when available.  Default on."
 msgstr "Visa kolumnnummer i felmeddelanden, när de är tillgängliga.  Normalt på."
 
-#: common.opt:2314
+#: common.opt:2318
 msgid "Emit function prologues only before parts of the function that need it, rather than at the top of the function."
 msgstr "Mata ut funktionsprologer bara före delar av funktionen som behöver det, istället för i början av funktionen."
 
-#: common.opt:2319
+#: common.opt:2323
 msgid "Shrink-wrap parts of the prologue and epilogue separately."
 msgstr "Kapsla in delar av prologen och epilogen separat."
 
-#: common.opt:2323
+#: common.opt:2327
 msgid "Disable optimizations observable by IEEE signaling NaNs."
 msgstr "Avaktivera optimeringar som kan observeras av IEEE signalerande NAN:ar."
 
-#: common.opt:2327
+#: common.opt:2331
 msgid "Disable floating point optimizations that ignore the IEEE signedness of zero."
 msgstr "Avaktivera flyttalsoptimeringar som ignorerar IEEE:s tecken på noll."
 
-#: common.opt:2331
+#: common.opt:2335
 msgid "Convert floating point constants to single precision constants."
 msgstr "Konvertera flyttalskonstanter till konstanter med enkel precision."
 
-#: common.opt:2335
+#: common.opt:2339
 msgid "Split lifetimes of induction variables when loops are unrolled."
 msgstr "Dela livstiden på induktionsvariabler när slingor rullas ut."
 
-#: common.opt:2339
+#: common.opt:2343
 msgid "Generate discontiguous stack frames."
 msgstr "Generera osammanhängande stackramar."
 
-#: common.opt:2343
+#: common.opt:2347
 msgid "Split wide types into independent registers."
 msgstr "Dela upp breda typer i oberoende register."
 
-#: common.opt:2347
+#: common.opt:2351
 msgid "Enable backward propagation of use properties at the SSA level."
 msgstr "Aktivera bakåtpropagering av användningsegenskaper på SSA-nivån."
 
-#: common.opt:2351
+#: common.opt:2355
 msgid "Optimize conditional patterns using SSA PHI nodes."
 msgstr "Optimera villkorliga mönster med SSA PHI-noder."
 
-#: common.opt:2355
+#: common.opt:2359
 msgid "Optimize amount of stdarg registers saved to stack at start of function."
 msgstr "Optimera mängden stdarg-register som sparas på stacken vid starten av en funktion."
 
-#: common.opt:2359
+#: common.opt:2363
 msgid "Apply variable expansion when loops are unrolled."
 msgstr "Tillämpa variabelexpansion när slingor rullas ut."
 
-#: common.opt:2363
+#: common.opt:2367
 msgid "-fstack-check=[no|generic|specific]\tInsert stack checking code into the program."
 msgstr "-fstack-check=[no|generic|specific]\tLägg in stackkontrollkod i programmet."
 
-#: common.opt:2367
+#: common.opt:2371
 msgid "Insert stack checking code into the program.  Same as -fstack-check=specific."
 msgstr "Lägg in stackkontrollkod i programmet.  Samma som -fstack-check=specific."
 
-#: common.opt:2371
+#: common.opt:2375
 msgid "Insert code to probe each page of stack space as it is allocated to protect from stack-clash style attacks."
 msgstr "Infoga kod för att prova varje sida av stackutrymme när den allokeras för att skydda från attacker av typen stackkollision."
 
-#: common.opt:2379
+#: common.opt:2383
 msgid "-fstack-limit-register=<register>\tTrap if the stack goes past <register>."
 msgstr "-fstack-limit-register=<register>\tFånga om stacken går förbi <register>."
 
-#: common.opt:2383
+#: common.opt:2387
 msgid "-fstack-limit-symbol=<name>\tTrap if the stack goes past symbol <name>."
 msgstr "-fstack-limit-symbol=<namn>\tFånga om stacken går förbi symbolen <namn>."
 
-#: common.opt:2387
+#: common.opt:2391
 msgid "Use propolice as a stack protection method."
 msgstr "Använd propolice som en metod att skydda stacken."
 
-#: common.opt:2391
+#: common.opt:2395
 msgid "Use a stack protection method for every function."
 msgstr "Använd en metod att skydda stacken för varje funktion."
 
-#: common.opt:2395
+#: common.opt:2399
 msgid "Use a smart stack protection method for certain functions."
 msgstr "Använd en smart metod att skydda stacken för vissa funktioner."
 
-#: common.opt:2399
+#: common.opt:2403
 msgid "Use stack protection method only for functions with the stack_protect attribute."
 msgstr "Använd en metod att skydda stacken endast för funktioner med attributet stack_protect."
 
-#: common.opt:2403
+#: common.opt:2407
 msgid "Output stack usage information on a per-function basis."
 msgstr "Skriv ut information om stackanvändning för varje funktion."
 
-#: common.opt:2415
+#: common.opt:2419
 msgid "Assume strict aliasing rules apply."
 msgstr "Anta att strikta aliasregler gäller."
 
-#: common.opt:2419
+#: common.opt:2423
 msgid "Treat signed overflow as undefined.  Negated as -fwrapv -fwrapv-pointer."
 msgstr "Behandla spill med tecken som odefinierat.  Negeras som -fwrapv -fwrapv-pointer."
 
-#: common.opt:2423
+#: common.opt:2427
 msgid "Implement __atomic operations via libcalls to legacy __sync functions."
 msgstr "Implementera __atomic-operationer med biblioteksanrop till äldre __sync-funktioner."
 
-#: common.opt:2427
+#: common.opt:2431
 msgid "Check for syntax errors, then stop."
 msgstr "Leta efter syntaxfel, stoppa sedan."
 
-#: common.opt:2431
+#: common.opt:2435
 msgid "Create data files needed by \"gcov\"."
 msgstr "Skapa datafiler som behövs av ”gcov”."
 
-#: common.opt:2435
+#: common.opt:2439
 msgid "Perform jump threading optimizations."
 msgstr "Utför hopptrådningsoptimeringar."
 
-#: common.opt:2439
+#: common.opt:2443
 msgid "Report the time taken by each compiler pass."
 msgstr "Rapportera tiden som går åt för varje kompilatorpass."
 
-#: common.opt:2443
+#: common.opt:2447
 msgid "Record times taken by sub-phases separately."
 msgstr "Spela in tiden som går åt till underfaser separat."
 
-#: common.opt:2447
+#: common.opt:2451
 msgid "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tSet the default thread-local storage code generation model."
 msgstr "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tAnge normal kodgenereringsmodell för trådlokal lagring."
 
-#: common.opt:2450
+#: common.opt:2454
 #, c-format
 msgid "unknown TLS model %qs"
 msgstr "okänd TLS-modell %qs"
 
-#: common.opt:2466
+#: common.opt:2470
 msgid "Reorder top level functions, variables, and asms."
 msgstr "Ordna om toppnivåfunktioner, variabler och asm:ar."
 
-#: common.opt:2470
+#: common.opt:2474
 msgid "Perform superblock formation via tail duplication."
 msgstr "Utför superblockformering via svansduplicering."
 
-#: common.opt:2474
+#: common.opt:2478
 msgid "For targets that normally need trampolines for nested functions, always generate them instead of using descriptors."
 msgstr "För mål som normalt använder trampoliner för nästade funktioner, generera dem alltid istället för att använda deskriptorer."
 
-#: common.opt:2482
+#: common.opt:2486
 msgid "Assume floating-point operations can trap."
 msgstr "Anta att flyttalsoperationer kan utlösa fällor."
 
-#: common.opt:2486
+#: common.opt:2490
 msgid "Trap for signed overflow in addition, subtraction and multiplication."
 msgstr "Fånga teckenspill i addition, subtraktion och multiplikation."
 
-#: common.opt:2490
+#: common.opt:2494
 msgid "Enable SSA-CCP optimization on trees."
 msgstr "Aktivera SSA-CCP-optimering av träd."
 
-#: common.opt:2494
+#: common.opt:2498
 msgid "Enable SSA-BIT-CCP optimization on trees."
 msgstr "Aktivera SSA-BIT-CCP-optimering av träd."
 
-#: common.opt:2502
+#: common.opt:2506
 msgid "Enable loop header copying on trees."
 msgstr "Aktivera slinghuvudkopiering av träd."
 
-#: common.opt:2510
+#: common.opt:2514
 msgid "Enable SSA coalescing of user variables."
 msgstr "Aktivera SSA-sammanläggning av användarvariabler."
 
-#: common.opt:2518
+#: common.opt:2522
 msgid "Enable copy propagation on trees."
 msgstr "Aktivera kopiepropagering i träd."
 
-#: common.opt:2526
+#: common.opt:2530
 msgid "Transform condition stores into unconditional ones."
 msgstr "Transformera villkorliga lagringar till ovillkorliga."
 
-#: common.opt:2530
+#: common.opt:2534
 msgid "Perform conversions of switch initializations."
 msgstr "Utför konvertering av switch-initieringar."
 
-#: common.opt:2534
+#: common.opt:2538
 msgid "Enable SSA dead code elimination optimization on trees."
 msgstr "Aktivera eliminering av död kod i SSA-optimeringen i träd."
 
-#: common.opt:2538
+#: common.opt:2542
 msgid "Enable dominator optimizations."
 msgstr "Aktivera dominatoroptimeringar."
 
-#: common.opt:2542
+#: common.opt:2546
 msgid "Enable tail merging on trees."
 msgstr "Aktivera svanssammanslagning av träd."
 
-#: common.opt:2546
+#: common.opt:2550
 msgid "Enable dead store elimination."
 msgstr "Aktivera eliminering av död lagring."
 
-#: common.opt:2550
+#: common.opt:2554
 msgid "Enable forward propagation on trees."
 msgstr "Aktivera framåtpropagering på träd."
 
-#: common.opt:2554
+#: common.opt:2558
 msgid "Enable Full Redundancy Elimination (FRE) on trees."
 msgstr "Aktivera fullständig överflödseliminering (FRE) i träd."
 
-#: common.opt:2558
+#: common.opt:2562
 msgid "Enable string length optimizations on trees."
 msgstr "Aktivera stränglängdsoptimering av träd."
 
-#: common.opt:2562
+#: common.opt:2566
 msgid "Detect paths that trigger erroneous or undefined behavior due to dereferencing a null pointer.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr "Detektera vägar som utlöser felaktigt eller odefinierat beteende på grund av dereferering av nollpekare.  Isolera dessa vägar från huvudsakliga styrflödet och gör om satsen med det felaktiga eller odefinierade beteendet till en fälla."
 
-#: common.opt:2568
+#: common.opt:2572
 msgid "Detect paths that trigger erroneous or undefined behavior due to a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr "Detektera vägar som utlöser felaktigt eller odefinierat beteende på grund av att ett nollvärde används på ett sätt som förbjuds av ett returns_nonnull- eller nonnull-attribut.  Isolera dessa vägar från huvudsakliga styrflödet och gör om satsen med det felaktiga eller odefinierade beteendet till en fälla."
 
-#: common.opt:2575
+#: common.opt:2579
 msgid "Enable loop distribution on trees."
 msgstr "Aktivera slingdistribution i träd."
 
-#: common.opt:2579
+#: common.opt:2583
 msgid "Enable loop distribution for patterns transformed into a library call."
 msgstr "Aktivera slingdistribution för mönster transformerade till biblioteksanrop."
 
-#: common.opt:2583
+#: common.opt:2587
 msgid "Enable loop invariant motion on trees."
 msgstr "Aktivera förflyttning av slingoberoende delar i träd."
 
-#: common.opt:2591
+#: common.opt:2595
 msgid "Create canonical induction variables in loops."
 msgstr "Skapa kanoniska induktionsvariabler i slingor."
 
-#: common.opt:2595
+#: common.opt:2599
 msgid "Enable loop optimizations on tree level."
 msgstr "Aktivera slingoptimeringar på trädnivå."
 
-#: common.opt:2599
+#: common.opt:2603
 msgid "-ftree-parallelize-loops=<number>\tEnable automatic parallelization of loops."
 msgstr "-ftree-parallelize-loops=<antal>\tAktivera automatisk parallellisering av slingor."
 
-#: common.opt:2603
+#: common.opt:2607
 msgid "Enable hoisting loads from conditional pointers."
 msgstr "Aktivera lyftningsladdning från villkorliga pekare."
 
-#: common.opt:2607
+#: common.opt:2611
 msgid "Enable SSA-PRE optimization on trees."
 msgstr "Aktivera SSA-PRE-optimeringar i träd."
 
-#: common.opt:2611
+#: common.opt:2615
 msgid "In SSA-PRE optimization on trees, enable partial-partial redundancy elimination."
 msgstr "I SSA-PRE-optimering på träd, aktivera eliminering av partiell-partiell redundans."
 
-#: common.opt:2615
+#: common.opt:2619
 msgid "Perform function-local points-to analysis on trees."
 msgstr "Utför funktionslokala pekar-på-analyser i träd."
 
-#: common.opt:2619
+#: common.opt:2623
 msgid "Enable reassociation on tree level."
 msgstr "Aktivera återassociering på trädnivå."
 
-#: common.opt:2627
+#: common.opt:2631
 msgid "Enable SSA code sinking on trees."
 msgstr "Aktivera SSA-kodsänkning i träd."
 
-#: common.opt:2631
+#: common.opt:2635
 msgid "Perform straight-line strength reduction."
 msgstr "Utför rätlinjig styrkereduktion."
 
-#: common.opt:2635
+#: common.opt:2639
 msgid "Perform scalar replacement of aggregates."
 msgstr "Utför skalärersättning av aggregat."
 
-#: common.opt:2639
+#: common.opt:2643
 msgid "Replace temporary expressions in the SSA->normal pass."
 msgstr "Ersätt tillfälliga uttryck i passet SSA->normal."
 
-#: common.opt:2643
+#: common.opt:2647
 msgid "Perform live range splitting during the SSA->normal pass."
 msgstr "Utför livstidsuppdelning under passet SSA->normal."
 
-#: common.opt:2647
+#: common.opt:2651
 msgid "Perform Value Range Propagation on trees."
 msgstr "Utför propagering av värdeintervall i träd."
 
-#: common.opt:2651
+#: common.opt:2655
 msgid "Split paths leading to loop backedges."
 msgstr "Dela sökvägar som leder till bakåtbågar i slingor."
 
-#: common.opt:2655
+#: common.opt:2659
 msgid "Assume common declarations may be overridden with ones with a larger trailing array."
 msgstr "Anta att gemensamma deklarationer kan åsidosättas med sådana med en större avslutande vektor."
 
-#: common.opt:2660
+#: common.opt:2664
 msgid "Compile whole compilation unit at a time."
 msgstr "Kompilera en hel kompileringsenhet åt gången."
 
-#: common.opt:2664
+#: common.opt:2668
 msgid "Perform loop unrolling when iteration count is known."
 msgstr "Utför slingutrullning när iterationsantalet är känt."
 
-#: common.opt:2668
+#: common.opt:2672
 msgid "Perform loop unrolling for all loops."
 msgstr "Utför slingutrullning för alla slingor."
 
-#: common.opt:2679
+#: common.opt:2683
 msgid "Allow optimization for floating-point arithmetic which may change the result of the operation due to rounding."
 msgstr "Tillåt optimeringar för flyttalsaritmetik som kan ändra resultatet av operationen på grund av avrundning."
 
-#: common.opt:2684
+#: common.opt:2688
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr "Samma som -fassociative-math för uttryck som inkluderar division."
 
-#: common.opt:2692
+#: common.opt:2696
 msgid "Allow math optimizations that may violate IEEE or ISO standards."
 msgstr "Tillåt matematikoptimeringar som kan strida mot IEEE- eller ISO-standarder."
 
-#: common.opt:2696
+#: common.opt:2700
 msgid "Perform loop unswitching."
 msgstr "Utför slingavväxling."
 
-#: common.opt:2700
+#: common.opt:2704
 msgid "Perform loop splitting."
 msgstr "Utför slingdelning."
 
-#: common.opt:2704
+#: common.opt:2708
 msgid "Just generate unwind tables for exception handling."
 msgstr "Generera bara upprullningstabeller för undantagshantering."
 
-#: common.opt:2708
+#: common.opt:2712
 msgid "Use the bfd linker instead of the default linker."
 msgstr "Använd bfd-länkaren istället för standardlänkaren."
 
-#: common.opt:2712
+#: common.opt:2716
 msgid "Use the gold linker instead of the default linker."
 msgstr "Använd gold-länkaren istället för standardlänkaren."
 
-#: common.opt:2724
+#: common.opt:2728
 msgid "Perform variable tracking."
 msgstr "Utför variabelspårning."
 
-#: common.opt:2732
+#: common.opt:2736
 msgid "Perform variable tracking by annotating assignments."
 msgstr "Utför variabelspårning genom att annotera tilldelningar."
 
-#: common.opt:2738
+#: common.opt:2742
 msgid "Toggle -fvar-tracking-assignments."
 msgstr "Växla -fvar-tracking-assignments."
 
-#: common.opt:2746
+#: common.opt:2750
 msgid "Perform variable tracking and also tag variables that are uninitialized."
 msgstr "Utför variabelspårning och tagga också variabler som är oinitierade."
 
-#: common.opt:2751
+#: common.opt:2755
 msgid "Enable vectorization on trees."
 msgstr "Aktivera vektorisering av träd."
 
-#: common.opt:2759
+#: common.opt:2763
 msgid "Enable loop vectorization on trees."
 msgstr "Aktivera slingvektorisering i träd."
 
-#: common.opt:2763
+#: common.opt:2767
 msgid "Enable basic block vectorization (SLP) on trees."
 msgstr "Aktivera grundblocksvektorisering (SLP) i träd."
 
-#: common.opt:2767
+#: common.opt:2771
 msgid "Specifies the cost model for vectorization. -fvect-cost-model=[unlimited|dynamic|cheap]\tSpecifies the cost model for vectorization."
 msgstr "Anger kostnadsmodellen för vektorisering.  -fvect-cost-model=[unlimited|dynamic|cheap]\tAnger kostnadsmodellen för vektorisering."
 
-#: common.opt:2772
+#: common.opt:2776
 msgid "-fsimd-cost-model=[unlimited|dynamic|cheap]\tSpecifies the vectorization cost model for code marked with a simd directive."
 msgstr "-fsimd-cost-model=[unlimited|dynamic|cheap]\tAnger kostnadsmodellen för vektorisering för kod markerad med ett simd-direktiv."
 
-#: common.opt:2775
+#: common.opt:2779
 #, c-format
 msgid "unknown vectorizer cost model %qs"
 msgstr "okänd kostnadsmodell för vektorisering %qs"
 
-#: common.opt:2788
+#: common.opt:2792
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr "Aktivera den dynamiska kostnadsmodellen för vektoriseraren.  Bevarad för bakåtkompatibilitet."
 
-#: common.opt:2796
+#: common.opt:2800
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr "Aktivera kopiepropagering av skalärutvecklingsinformation."
 
-#: common.opt:2806
+#: common.opt:2810
 msgid "Add extra commentary to assembler output."
 msgstr "Lägg till extra kommentarer till assemblerutdata."
 
-#: common.opt:2810
+#: common.opt:2814
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility."
 msgstr "-fvisibility=[default|internal|hidden|protected]\tAnge standardvärde för symbolsynlighet."
 
-#: common.opt:2813
+#: common.opt:2817
 #, c-format
 msgid "unrecognized visibility value %qs"
 msgstr "okänt synlighetsvärde %qs"
 
-#: common.opt:2829
+#: common.opt:2833
 msgid "Validate vtable pointers before using them."
 msgstr "Validera vtable-pekare före de används."
 
-#: common.opt:2832
+#: common.opt:2836
 #, c-format
 msgid "unknown vtable verify initialization priority %qs"
 msgstr "okänd initieringsprioritet för vtable-verifiering %qs"
 
-#: common.opt:2845
+#: common.opt:2849
 msgid "Output vtable verification counters."
 msgstr "Mata ut verifieringsräknare för vtable."
 
-#: common.opt:2849
+#: common.opt:2853
 msgid "Output vtable verification pointer sets information."
 msgstr "Mata ut information om verifieringspekaruppsättningar för vtable."
 
-#: common.opt:2853
+#: common.opt:2857
 msgid "Use expression value profiles in optimizations."
 msgstr "Använd uttrycksvärdeprofiler i optimeringar."
 
-#: common.opt:2857
+#: common.opt:2861
 msgid "Construct webs and split unrelated uses of single variable."
 msgstr "Konstruera nät och dela orelaterade användningar av en enskild variabel."
 
-#: common.opt:2861
+#: common.opt:2865
 msgid "Enable conditional dead code elimination for builtin calls."
 msgstr "Aktivera villkorlig eliminering av död för inbyggda anrop."
 
-#: common.opt:2865
+#: common.opt:2869
 msgid "Perform whole program optimizations."
 msgstr "Utför optimering av hela program."
 
-#: common.opt:2869
+#: common.opt:2873
 msgid "Assume pointer overflow wraps around."
 msgstr "Anta att pekarspill slår runt."
 
-#: common.opt:2873
+#: common.opt:2877
 msgid "Assume signed arithmetic overflow wraps around."
 msgstr "Anta att spill vid teckenaritmetik slår runt."
 
-#: common.opt:2877
+#: common.opt:2881
 msgid "Put zero initialized data in the bss section."
 msgstr "Lägg nollinitierad data i bss-sektionen."
 
-#: common.opt:2881
+#: common.opt:2885
 msgid "Generate debug information in default format."
 msgstr "Generera felsökningsinformation i standardformat."
 
-#: common.opt:2885
+#: common.opt:2889
 msgid "Assume assembler support for (DWARF2+) .loc directives"
 msgstr "Anta att assemblern stödjer .loc-direktiv (DWARF2+)"
 
-#: common.opt:2889
+#: common.opt:2893
 msgid "Assume assembler support for view in (DWARF2+) .loc directives"
 msgstr "Anta att assemblern stödjer vyer i .loc-direktiv (DWARF2+)"
 
-#: common.opt:2892 common.opt:2896 common.opt:2900 common.opt:2904
+#: common.opt:2896 common.opt:2900 common.opt:2904 common.opt:2908
 #, c-format
 msgid "switch %qs no longer supported"
 msgstr "flaggan %qs stödjs inte längre"
 
-#: common.opt:2909
+#: common.opt:2913
 msgid "Record DW_AT_decl_column and DW_AT_call_column in DWARF."
 msgstr "Spara DW_AT_decl_column och DW_AT_call_column i DWARF."
 
-#: common.opt:2913
+#: common.opt:2917
 msgid "Generate debug information in default version of DWARF format."
 msgstr "Generera felsökningsinformation i standardversion av DWARF-formatet."
 
-#: common.opt:2917
+#: common.opt:2921
 msgid "Generate debug information in DWARF v2 (or later) format."
 msgstr "Generera felsökningsinformation i DWARF v2-format (eller senare)."
 
-#: common.opt:2921
+#: common.opt:2925
 msgid "Generate debug information in default extended format."
 msgstr "Generera felsökningsinformation i normalt utökat format."
 
-#: common.opt:2925
+#: common.opt:2929
 msgid "Generate extended entry point information for inlined functions"
 msgstr "Generera utökad information om ingångspunkt för inline:ade funktioner"
 
-#: common.opt:2929
+#: common.opt:2933
 msgid "Compute locview reset points based on insn length estimates"
 msgstr "Beräkna locview-återställningspunkter baserat på uppskattningar av instruktionslängd"
 
-#: common.opt:2937
+#: common.opt:2941
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr "Generera inte DWARF-sektionerna pubnames och pubtypes."
 
-#: common.opt:2941
+#: common.opt:2945
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr "Generera DWARF-sektionerna pubnames och pubtypes."
 
-#: common.opt:2945
+#: common.opt:2949
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr "Generera DWARF-sektionerna pubnames och pubtypes med GNU-utvidgningar."
 
-#: common.opt:2949
+#: common.opt:2953
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr "Notera gcc:s kommandoradsflaggor i DWARF DW_AT_producer."
 
-#: common.opt:2953
+#: common.opt:2957
 msgid "Generate debug information in separate .dwo files."
 msgstr "Generera felsökningsinformation i separata .dwo-filer."
 
-#: common.opt:2957
+#: common.opt:2961
 msgid "Generate debug information in STABS format."
 msgstr "Generera felsökningsinformation i STABS-format."
 
-#: common.opt:2961
+#: common.opt:2965
 msgid "Generate debug information in extended STABS format."
 msgstr "Generera felsökningsinformation i utökat STABS-format."
 
-#: common.opt:2965
+#: common.opt:2969
 msgid "Emit progressive recommended breakpoint locations."
 msgstr "Mata ut progressiva rekommenderade brytpunktsplatser."
 
-#: common.opt:2969
+#: common.opt:2973
 msgid "Don't emit DWARF additions beyond selected version."
 msgstr "Mata inte ut DWARF-tillägg utöver vald version."
 
-#: common.opt:2973
+#: common.opt:2977
 msgid "Toggle debug information generation."
 msgstr "Växla generering av felsökningsinformation."
 
-#: common.opt:2977
+#: common.opt:2981
 msgid "Augment variable location lists with progressive views."
 msgstr "Utöka variabelplatslistor med progressiva vyer."
 
-#: common.opt:2984
+#: common.opt:2988
 msgid "Generate debug information in VMS format."
 msgstr "Generera felsökningsinformation i VMS-format."
 
-#: common.opt:2988
+#: common.opt:2992
 msgid "Generate debug information in XCOFF format."
 msgstr "Generera felsökningsinformation i XCOFF-format."
 
-#: common.opt:2992
+#: common.opt:2996
 msgid "Generate debug information in extended XCOFF format."
 msgstr "Generera felsökningsinformation i utökat XCOFF-format."
 
-#: common.opt:3010
+#: common.opt:3014
 msgid "Generate compressed debug sections."
 msgstr "Generera komprimerade felsökningssektioner."
 
-#: common.opt:3014
+#: common.opt:3018
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>."
 msgstr "-gz=<format>\tGenerera komprimerade felsökningssektioner i formatet <format>."
 
-#: common.opt:3021
+#: common.opt:3025
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory."
 msgstr "-iplugindir=<kat>\tSätt <kat> att vara standardbibliotek för insticksmoduler."
 
-#: common.opt:3025
+#: common.opt:3029
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory."
 msgstr "-imultiarch <kat>\tSätt <kat> att vara inkluderingsunderbiblioteket för multiarkitekturer."
 
-#: common.opt:3047
+#: common.opt:3051
 msgid "-o <file>\tPlace output into <file>."
 msgstr "-o <fil>\tSkriv utdata i <fil>."
 
-#: common.opt:3051
+#: common.opt:3055
 msgid "Enable function profiling."
 msgstr "Aktivera funktionsprofilering."
 
-#: common.opt:3061
+#: common.opt:3065
 msgid "Like -pedantic but issue them as errors."
 msgstr "Som -pedantic men ange dem som fel."
 
-#: common.opt:3101
+#: common.opt:3105
 msgid "Do not display functions compiled or elapsed time."
 msgstr "Visa inte kompilerade funktioner eller tiden som förbrukats."
 
-#: common.opt:3133
+#: common.opt:3137
 msgid "Enable verbose output."
 msgstr "Aktivera utförlig utskrift."
 
-#: common.opt:3137
+#: common.opt:3141
 msgid "Display the compiler's version."
 msgstr "Visa kompilatorns version."
 
-#: common.opt:3141
+#: common.opt:3145
 msgid "Suppress warnings."
 msgstr "Undertryck varningar."
 
-#: common.opt:3151
+#: common.opt:3155
 msgid "Create a shared library."
 msgstr "Skapa ett delat bibliotek."
 
-#: common.opt:3196
+#: common.opt:3200
 msgid "Don't create a dynamically linked position independent executable."
 msgstr "Skapa inte ett dynamiskt länkat positionsoberoende körbart program."
 
-#: common.opt:3200
+#: common.opt:3204
 msgid "Create a dynamically linked position independent executable."
 msgstr "Skapa ett dynamiskt länkat positionsoberoende körbart program."
 
-#: common.opt:3204
+#: common.opt:3208
 msgid "Create a static position independent executable."
 msgstr "Skapa ett statiskt positionsoberoende körbart program."
 
-#: common.opt:3211
+#: common.opt:3215
 msgid "Use caller save register across calls if possible."
 msgstr "Använd anroparens sparregister mellan anrop om möjligt."
 
-#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:598 cp/cvt.c:1308
+#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:599 cp/cvt.c:1308
 #: cp/cvt.c:1561
 #, gcc-internal-format
 msgid "value computed is not used"
@@ -15699,7 +15700,7 @@
 msgstr "boolesk typ förväntades"
 
 #: go/gofrontend/expressions.cc:4331 c/c-parser.c:13477 c/c-parser.c:13484
-#: cp/parser.c:33264 cp/parser.c:33271
+#: cp/parser.c:33261 cp/parser.c:33268
 #, gcc-internal-format
 msgid "expected integer"
 msgstr "heltal förväntades"
@@ -16114,14 +16115,14 @@
 msgid "ignoring attribute %qE because it conflicts with attribute %qs"
 msgstr "ignorerar attributet %qE eftersom det står i konflikt med attributet %qs"
 
-#: attribs.c:449 c-family/c-attribs.c:1894 cp/decl.c:13690 cp/friend.c:302
-#: cp/tree.c:4559
+#: attribs.c:449 c-family/c-attribs.c:1905 cp/decl.c:13714 cp/friend.c:302
+#: cp/tree.c:4607
 #, gcc-internal-format
 msgid "previous declaration here"
 msgstr "tidigare deklaration här"
 
 #. Warn about and ignore all others for now, but store them.
-#: attribs.c:564 c-family/c-attribs.c:2717 objc/objc-act.c:4963
+#: attribs.c:564 c-family/c-attribs.c:2728 objc/objc-act.c:4963
 #: objc/objc-act.c:6932 objc/objc-act.c:8119 objc/objc-act.c:8170
 #, gcc-internal-format
 msgid "%qE attribute directive ignored"
@@ -16140,17 +16141,17 @@
 #. This is a c++11 attribute that appertains to a
 #. type-specifier, outside of the definition of, a class
 #. type.  Ignore it.
-#: attribs.c:590 cp/decl.c:10999
+#: attribs.c:590 cp/decl.c:11023
 #, gcc-internal-format
 msgid "attribute ignored"
 msgstr "attributet ignorerat"
 
-#: attribs.c:592 cp/decl.c:11000
+#: attribs.c:592 cp/decl.c:11024
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr "Ett attribut som gäller en viss typspecificerare ignoreras"
 
-#: attribs.c:610 c-family/c-attribs.c:3219
+#: attribs.c:610 c-family/c-attribs.c:3230
 #, gcc-internal-format
 msgid "%qE attribute does not apply to types"
 msgstr "attributet %qE är inte applicerbart på typer"
@@ -16166,40 +16167,40 @@
 msgstr "typattribut ignoreras efter att typen redan är definierad"
 
 #: attribs.c:691 attribs.c:1622 attribs.c:1632 attribs.c:1642
-#: c-family/c-attribs.c:540 c-family/c-attribs.c:559 c-family/c-attribs.c:577
-#: c-family/c-attribs.c:607 c-family/c-attribs.c:628 c-family/c-attribs.c:649
-#: c-family/c-attribs.c:690 c-family/c-attribs.c:717 c-family/c-attribs.c:733
-#: c-family/c-attribs.c:750 c-family/c-attribs.c:766 c-family/c-attribs.c:792
-#: c-family/c-attribs.c:807 c-family/c-attribs.c:835 c-family/c-attribs.c:852
-#: c-family/c-attribs.c:870 c-family/c-attribs.c:893 c-family/c-attribs.c:931
-#: c-family/c-attribs.c:954 c-family/c-attribs.c:971 c-family/c-attribs.c:1000
-#: c-family/c-attribs.c:1021 c-family/c-attribs.c:1042
-#: c-family/c-attribs.c:1069 c-family/c-attribs.c:1099
-#: c-family/c-attribs.c:1136 c-family/c-attribs.c:1189
-#: c-family/c-attribs.c:1255 c-family/c-attribs.c:1313
-#: c-family/c-attribs.c:1402 c-family/c-attribs.c:1432
-#: c-family/c-attribs.c:1483 c-family/c-attribs.c:1998
-#: c-family/c-attribs.c:2035 c-family/c-attribs.c:2096
-#: c-family/c-attribs.c:2152 c-family/c-attribs.c:2230
-#: c-family/c-attribs.c:2312 c-family/c-attribs.c:2371
-#: c-family/c-attribs.c:2390 c-family/c-attribs.c:2498
-#: c-family/c-attribs.c:2514 c-family/c-attribs.c:2530
-#: c-family/c-attribs.c:2551 c-family/c-attribs.c:2608
-#: c-family/c-attribs.c:2635 c-family/c-attribs.c:2690
-#: c-family/c-attribs.c:2870 c-family/c-attribs.c:2891
-#: c-family/c-attribs.c:3004 c-family/c-attribs.c:3031
-#: c-family/c-attribs.c:3221 c-family/c-attribs.c:3239
-#: c-family/c-attribs.c:3262 c-family/c-attribs.c:3301
-#: c-family/c-attribs.c:3383 c-family/c-attribs.c:3439
-#: c-family/c-attribs.c:3455 c-family/c-attribs.c:3549
-#: c-family/c-common.c:5600 config/darwin.c:2072 config/arm/arm.c:6868
+#: c-family/c-attribs.c:547 c-family/c-attribs.c:566 c-family/c-attribs.c:584
+#: c-family/c-attribs.c:614 c-family/c-attribs.c:635 c-family/c-attribs.c:656
+#: c-family/c-attribs.c:697 c-family/c-attribs.c:728 c-family/c-attribs.c:744
+#: c-family/c-attribs.c:761 c-family/c-attribs.c:777 c-family/c-attribs.c:803
+#: c-family/c-attribs.c:818 c-family/c-attribs.c:846 c-family/c-attribs.c:863
+#: c-family/c-attribs.c:881 c-family/c-attribs.c:904 c-family/c-attribs.c:942
+#: c-family/c-attribs.c:965 c-family/c-attribs.c:982 c-family/c-attribs.c:1011
+#: c-family/c-attribs.c:1032 c-family/c-attribs.c:1053
+#: c-family/c-attribs.c:1080 c-family/c-attribs.c:1110
+#: c-family/c-attribs.c:1147 c-family/c-attribs.c:1200
+#: c-family/c-attribs.c:1266 c-family/c-attribs.c:1324
+#: c-family/c-attribs.c:1413 c-family/c-attribs.c:1443
+#: c-family/c-attribs.c:1494 c-family/c-attribs.c:2009
+#: c-family/c-attribs.c:2046 c-family/c-attribs.c:2107
+#: c-family/c-attribs.c:2163 c-family/c-attribs.c:2241
+#: c-family/c-attribs.c:2323 c-family/c-attribs.c:2382
+#: c-family/c-attribs.c:2401 c-family/c-attribs.c:2509
+#: c-family/c-attribs.c:2525 c-family/c-attribs.c:2541
+#: c-family/c-attribs.c:2562 c-family/c-attribs.c:2619
+#: c-family/c-attribs.c:2646 c-family/c-attribs.c:2701
+#: c-family/c-attribs.c:2881 c-family/c-attribs.c:2902
+#: c-family/c-attribs.c:3015 c-family/c-attribs.c:3042
+#: c-family/c-attribs.c:3232 c-family/c-attribs.c:3250
+#: c-family/c-attribs.c:3273 c-family/c-attribs.c:3312
+#: c-family/c-attribs.c:3394 c-family/c-attribs.c:3450
+#: c-family/c-attribs.c:3466 c-family/c-attribs.c:3560
+#: c-family/c-common.c:5598 config/darwin.c:2072 config/arm/arm.c:6868
 #: config/arm/arm.c:6896 config/arm/arm.c:6913 config/avr/avr.c:9698
-#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6497
-#: config/i386/i386.c:41520 config/ia64/ia64.c:788
-#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33056
-#: config/spu/spu.c:3743 ada/gcc-interface/utils.c:6244
-#: ada/gcc-interface/utils.c:6261 ada/gcc-interface/utils.c:6277
-#: ada/gcc-interface/utils.c:6303 brig/brig-lang.c:476 lto/lto-lang.c:283
+#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6500
+#: config/i386/i386.c:41514 config/ia64/ia64.c:788
+#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33112
+#: config/spu/spu.c:3743 ada/gcc-interface/utils.c:6249
+#: ada/gcc-interface/utils.c:6266 ada/gcc-interface/utils.c:6282
+#: ada/gcc-interface/utils.c:6308 brig/brig-lang.c:476 lto/lto-lang.c:283
 #, gcc-internal-format
 msgid "%qE attribute ignored"
 msgstr "attributet %qE ignorerat"
@@ -16567,87 +16568,102 @@
 msgid "%Kattempt to free a non-heap object"
 msgstr "%Kförsök att frigöra ett icke-heap-objekt"
 
-#: calls.c:1434
+#: calls.c:1291 file-prefix-map.c:50
 #, gcc-internal-format
+msgid "invalid argument %qs to %qs"
+msgstr "ogiltigt argument %qs till %qs"
+
+#: calls.c:1452
+#, gcc-internal-format
 msgid "%Kargument %i value %qE is negative"
 msgstr "%Kargument %i:s värde %qE är negativt"
 
-#: calls.c:1452
+#: calls.c:1470
 #, gcc-internal-format
 msgid "%Kargument %i value is zero"
 msgstr "%Kargument %i:s värde är noll"
 
-#: calls.c:1469
+#: calls.c:1487
 #, gcc-internal-format
 msgid "%Kargument %i value %qE exceeds maximum object size %E"
 msgstr "%Kargument %i:s värde %qE överskrider maximal objektstorlek %E"
 
-#: calls.c:1483
+#: calls.c:1501
 #, gcc-internal-format
 msgid "%Kargument %i range [%E, %E] is negative"
 msgstr "%Kargument %i:s intervall [%E, %E] är negativt"
 
-#: calls.c:1490
+#: calls.c:1508
 #, gcc-internal-format
 msgid "%Kargument %i range [%E, %E] exceeds maximum object size %E"
 msgstr "%Kargument %i:s intervall [%E, %E] överskrider maximal objektstorlek %E"
 
-#: calls.c:1520
+#: calls.c:1538
 #, gcc-internal-format
 msgid "%Kproduct %<%E * %E%> of arguments %i and %i exceeds %<SIZE_MAX%>"
 msgstr "%Kprodukten %<%E * %E%> av argument %i och %i överskrider %<SIZE_MAX%>"
 
-#: calls.c:1526
+#: calls.c:1544
 #, gcc-internal-format
 msgid "%Kproduct %<%E * %E%> of arguments %i and %i exceeds maximum object size %E"
 msgstr "%Kprodukten %<%E * %E%> av argument %i och %i överskrider maximal objektstorlek %E"
 
-#: calls.c:1537 calls.c:1540
+#: calls.c:1555 calls.c:1558
 #, gcc-internal-format
 msgid "argument %i in the range [%E, %E]"
 msgstr "argument %i i intervallet [%E, %E]"
 
-#: calls.c:1551
+#: calls.c:1569
 #, gcc-internal-format
 msgid "in a call to built-in allocation function %qD"
 msgstr "i ett anrop av den inbyggda allokeringsfunktionen %qD"
 
-#: calls.c:1554
+#: calls.c:1572
 #, gcc-internal-format
 msgid "in a call to allocation function %qD declared here"
 msgstr "i ett anrop av allokeringsfunktionen %qD deklarerad här"
 
-#: calls.c:1711
+#: calls.c:1835
 #, gcc-internal-format
-msgid "%qD argument %i declared attribute %<nonstring%> is smaller than the specified bound %E"
-msgstr "Argument %2$i till %1$qD som är deklarerad med attributet %<nonstring%> är mindre än den angivna gränsen %3$E"
+msgid "%qD argument %i declared attribute %<nonstring%> is smaller than the specified bound %wu"
+msgstr "Argument %2$i till %1$qD som är deklarerad med attributet %<nonstring%> är mindre än den angivna gränsen %3$wu"
 
-#: calls.c:1716
+#: calls.c:1841
 #, gcc-internal-format
+msgid "%qD argument %i declared attribute %<nonstring%> is smaller than the specified bound [%E, %E]"
+msgstr "Argument %2$i till %1$qD som är deklarerad med attributet %<nonstring%> är mindre än den angivna gränsen [%3$E, %4$E]"
+
+#: calls.c:1847
+#, gcc-internal-format
+msgid "%qD argument %i declared attribute %<nonstring%> may be smaller than the specified bound [%E, %E]"
+msgstr "Argument %2$i till %1$qD som är deklarerad med attributet %<nonstring%> kan vara mindre än den angivna gränsen [%3$E, %4$E]"
+
+#: calls.c:1857
+#, gcc-internal-format
 msgid "%qD argument %i declared attribute %<nonstring%>"
 msgstr "%qD argument %i deklarerades med attributet %<nonstring%>"
 
-#: calls.c:1721
+#: calls.c:1862
 #, gcc-internal-format
 msgid "argument %qD declared here"
 msgstr "argumentet %qD är deklarerat här"
 
-#: calls.c:1735
+#: calls.c:1876
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot tail-call: %s"
 msgstr "kan inte göra svansanrop: %s"
 
-#: calls.c:3365
+#: calls.c:3506
 #, gcc-internal-format
 msgid "function call has aggregate value"
 msgstr "funktionsanrop har sammansatt värde"
 
-#: calls.c:4059
+#: calls.c:4200
 #, gcc-internal-format
 msgid "passing too large argument on stack"
 msgstr "skickar för många argument på stacken"
 
-#: cfgexpand.c:1665 function.c:1002 varasm.c:2231
+#: cfgexpand.c:1665 function.c:1002 varasm.c:2242
 #, gcc-internal-format
 msgid "size of variable %q+D is too large"
 msgstr "storleken på variabeln %q+D är för stor"
@@ -17219,237 +17235,237 @@
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr "antal gb-noter i instruktionskedjan (%d) != n_basic_blocks (%d)"
 
-#: cgraph.c:3051
+#: cgraph.c:3056
 #, gcc-internal-format
 msgid "caller edge count invalid"
 msgstr "antal anropande bågar är felaktigt"
 
-#: cgraph.c:3135
+#: cgraph.c:3140
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr "aux-fält satt för båge %s->%s"
 
-#: cgraph.c:3142
+#: cgraph.c:3147
 #, gcc-internal-format
 msgid "cgraph count invalid"
 msgstr "cgraph-antalet är felaktigt"
 
-#: cgraph.c:3147
+#: cgraph.c:3152
 #, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr "inline-klon i samma comdat-grupplista"
 
-#: cgraph.c:3152
+#: cgraph.c:3157
 #, gcc-internal-format
 msgid "local symbols must be defined"
 msgstr "lokala symboler måste vara definierade"
 
-#: cgraph.c:3157
+#: cgraph.c:3162
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr "externt synlig inline-klon"
 
-#: cgraph.c:3162
+#: cgraph.c:3167
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr "inline-klon som man tar adressen till"
 
-#: cgraph.c:3167
+#: cgraph.c:3172
 #, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr "inline-klon tvingas till utdata"
 
-#: cgraph.c:3174
+#: cgraph.c:3179
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for indirect edge from %s"
 msgstr "aux-fält satt för indirekt båge från %s"
 
-#: cgraph.c:3181
+#: cgraph.c:3186
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr "En indirektbåge från %s är inte markerad som indirekt eller har associerad indirect_info, motsvarande sats är: "
 
-#: cgraph.c:3196
+#: cgraph.c:3201
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr "comdat-lokal funktion anropad av %s utanför dess comdat"
 
-#: cgraph.c:3206
+#: cgraph.c:3211
 #, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr "inlined_to-pekare är fel"
 
-#: cgraph.c:3211
+#: cgraph.c:3216
 #, gcc-internal-format
 msgid "multiple inline callers"
 msgstr "flera inline-anropare"
 
-#: cgraph.c:3218
+#: cgraph.c:3223
 #, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr "inlined_to-pekare angiven för noninline-anropare"
 
-#: cgraph.c:3239
+#: cgraph.c:3244
 #, gcc-internal-format
 msgid "caller edge count does not match BB count"
 msgstr "anropsbågantal stämmer inte med GB-antal"
 
-#: cgraph.c:3261
+#: cgraph.c:3266
 #, gcc-internal-format
 msgid "indirect call count does not match BB count"
 msgstr "indirekta anropsantal stämmer inte med GB-antal"
 
-#: cgraph.c:3272
+#: cgraph.c:3277
 #, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr "inlined_to-pekare är angivet men inga företrädare finns"
 
-#: cgraph.c:3277
+#: cgraph.c:3282
 #, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr "inlined_to-pekare refererar till sig själv"
 
-#: cgraph.c:3289
+#: cgraph.c:3294
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr "cgraph_node har fel clone_of"
 
-#: cgraph.c:3301
+#: cgraph.c:3306
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr "cgraph_node har fel klonlista"
 
-#: cgraph.c:3307
+#: cgraph.c:3312
 #, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr "cgraph_node är i klonlistan men den är inte en klon"
 
-#: cgraph.c:3312
+#: cgraph.c:3317
 #, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr "cgraph_node har fel prev_clone-pekare"
 
-#: cgraph.c:3317
+#: cgraph.c:3322
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr "dubbellänkad lista av kloner trasig"
 
-#: cgraph.c:3329
+#: cgraph.c:3334
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr "Alias har anropsbågar"
 
-#: cgraph.c:3337
+#: cgraph.c:3342
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr "Alias har icke-alias-referens"
 
-#: cgraph.c:3342
+#: cgraph.c:3347
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr "Alias har mer än en aliasreferens"
 
-#: cgraph.c:3349
+#: cgraph.c:3354
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr "Analyserat alias har ingen referens"
 
-#: cgraph.c:3358
+#: cgraph.c:3363
 #, gcc-internal-format
 msgid "Instrumentation clone does not reference original node"
 msgstr "Instrumenteringsklonen refererar inte originalnoden"
 
-#: cgraph.c:3365
+#: cgraph.c:3370
 #, gcc-internal-format
 msgid "Not instrumented node has non-NULL original declaration"
 msgstr "Oinstrumenterad nod har en originaldeklaration som inte är NULL"
 
-#: cgraph.c:3375
+#: cgraph.c:3380
 #, gcc-internal-format
 msgid "Instrumented node has wrong original declaration"
 msgstr "Instrumenterad not har felaktig originaldeklaration"
 
-#: cgraph.c:3393
+#: cgraph.c:3398
 #, gcc-internal-format
 msgid "Node has more than one chkp reference"
 msgstr "Noden har mer än en chkp-referens"
 
-#: cgraph.c:3398
+#: cgraph.c:3403
 #, gcc-internal-format
 msgid "Wrong node is referenced with chkp reference"
 msgstr "Fel nod refereras med en chkp-referens"
 
-#: cgraph.c:3406
+#: cgraph.c:3411
 #, gcc-internal-format
 msgid "Analyzed node has no reference to instrumented version"
 msgstr "Analyserad nod har ingen referens till en instrumenterad version"
 
-#: cgraph.c:3420
+#: cgraph.c:3425
 #, gcc-internal-format
 msgid "Alias chain for instrumented node is broken"
 msgstr "En aliaskedja för en instrumenterad not är bruten"
 
-#: cgraph.c:3429
+#: cgraph.c:3434
 #, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr "Ingen båge ut från snuttnod"
 
-#: cgraph.c:3434
+#: cgraph.c:3439
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr "Mer än en båge ut från en snuttnod"
 
-#: cgraph.c:3439
+#: cgraph.c:3444
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr "Snuttar får inte ha en kropp"
 
-#: cgraph.c:3445
+#: cgraph.c:3450
 #, gcc-internal-format
 msgid "Instrumentation thunk has wrong edge callee"
 msgstr "Instrumenteringssnutten har fel anropande båge"
 
-#: cgraph.c:3481
+#: cgraph.c:3486
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr "delat anropssats:"
 
-#: cgraph.c:3489
+#: cgraph.c:3494
 #, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr "bågpekare till fel deklaration:"
 
-#: cgraph.c:3498
+#: cgraph.c:3503
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr "ett indirekt båge med okänd anropsmål motsvarande ett call_stmt med en känd deklaration:"
 
-#: cgraph.c:3508
+#: cgraph.c:3513
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr "anropsgrafsbåge saknas för anropssats:"
 
-#: cgraph.c:3518
+#: cgraph.c:3523
 #, gcc-internal-format
 msgid "reference to dead statement"
 msgstr "referens till död sats"
 
-#: cgraph.c:3531
+#: cgraph.c:3536
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr "båge %s->%s har ingen motsvarande anropssats"
 
-#: cgraph.c:3543
+#: cgraph.c:3548
 #, gcc-internal-format, gfc-internal-format
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr "en indirekt båge från %s har inget motsvarande call_stmt"
 
-#: cgraph.c:3554
+#: cgraph.c:3559
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr "verify_cgraph_node misslyckades"
 
-#: cgraph.c:3661 varpool.c:306
+#: cgraph.c:3666 varpool.c:306
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: section %s is missing"
 msgstr "%s sektion %s saknas"
@@ -17480,12 +17496,12 @@
 msgstr "attributet %<weakref%> ignorerat för att variabeln är initierad"
 
 #. include_self=
-#: cgraphunit.c:981 c/c-decl.c:11282
+#: cgraphunit.c:981 c/c-decl.c:11302
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F är använd men inte definierad"
 
-#: cgraphunit.c:983 c/c-decl.c:11291
+#: cgraphunit.c:983 c/c-decl.c:11311
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "%q+F är deklarerad %<static%> men definieras aldrig"
@@ -17600,12 +17616,12 @@
 msgid "cannot find '%s'"
 msgstr "kan inte hitta ”%s”"
 
-#: collect-utils.c:183 collect2.c:2361 collect2.c:2560 gcc.c:3080 gcc.c:6856
+#: collect-utils.c:183 collect2.c:2387 collect2.c:2586 gcc.c:3080 gcc.c:6856
 #, gcc-internal-format
 msgid "pex_init failed: %m"
 msgstr "pex_init misslyckades: %m"
 
-#: collect-utils.c:192 collect2.c:2370 collect2.c:2568 gcc.c:8498
+#: collect-utils.c:192 collect2.c:2396 collect2.c:2594 gcc.c:8498
 #, gcc-internal-format
 msgid "%s: %m"
 msgstr "%s: %m"
@@ -17615,93 +17631,93 @@
 msgid "COLLECT_LTO_WRAPPER must be set"
 msgstr "COLLECT_LTO_WRAPPER måste vara satt"
 
-#: collect2.c:966 gcc.c:7382 lto-wrapper.c:1666
+#: collect2.c:969 gcc.c:7382 lto-wrapper.c:1692
 #: config/i386/intelmic-mkoffload.c:556 config/nvptx/mkoffload.c:405
 #, gcc-internal-format
 msgid "atexit failed"
 msgstr "atexit misslyckades"
 
-#: collect2.c:1064
+#: collect2.c:1067
 #, gcc-internal-format
 msgid "no arguments"
 msgstr "inga argument"
 
-#: collect2.c:1303 opts.c:904
+#: collect2.c:1311 opts.c:904
 #, gcc-internal-format
 msgid "LTO support has not been enabled in this configuration"
 msgstr "LTO-stöd har inte aktiverats i denna konfiguration"
 
-#: collect2.c:1344
+#: collect2.c:1352
 #, gcc-internal-format
 msgid "can't open %s: %m"
 msgstr "det går inte att öppna %s: %m"
 
-#: collect2.c:1450
+#: collect2.c:1472
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown demangling style '%s'"
 msgstr "okänd avmanglingsstil ”%s”"
 
-#: collect2.c:1546 collect2.c:1729 collect2.c:1769
+#: collect2.c:1574 collect2.c:1757 collect2.c:1797
 #, gcc-internal-format
 msgid "fopen %s: %m"
 msgstr "fopen %s: %m"
 
-#: collect2.c:1549 collect2.c:1734 collect2.c:1772
+#: collect2.c:1577 collect2.c:1762 collect2.c:1800
 #, gcc-internal-format
 msgid "fclose %s: %m"
 msgstr "fclose %s: %m"
 
-#: collect2.c:2335
+#: collect2.c:2361
 #, gcc-internal-format
 msgid "cannot find 'nm'"
 msgstr "kan inte hitta ”nm”"
 
-#: collect2.c:2383
+#: collect2.c:2409
 #, gcc-internal-format
 msgid "can't open nm output: %m"
 msgstr "kan inte öppna nm-utdata: %m"
 
-#: collect2.c:2467
+#: collect2.c:2493
 #, gcc-internal-format, gfc-internal-format
 msgid "init function found in object %s"
 msgstr "init-funktion funnen i objekt %s"
 
-#: collect2.c:2478
+#: collect2.c:2504
 #, gcc-internal-format, gfc-internal-format
 msgid "fini function found in object %s"
 msgstr "fini-funktion funnen i objekt %s"
 
-#: collect2.c:2535
+#: collect2.c:2561
 #, gcc-internal-format
 msgid "cannot find 'ldd'"
 msgstr "kan inte hitta ”ldd”"
 
-#: collect2.c:2581
+#: collect2.c:2607
 #, gcc-internal-format
 msgid "can't open ldd output: %m"
 msgstr "kan inte öppna ldd-utdata: %m"
 
-#: collect2.c:2599
+#: collect2.c:2625
 #, gcc-internal-format, gfc-internal-format
 msgid "dynamic dependency %s not found"
 msgstr "dynamiskt beroende %s inte funnet"
 
-#: collect2.c:2611
+#: collect2.c:2637
 #, gcc-internal-format, gfc-internal-format
 msgid "unable to open dynamic dependency '%s'"
 msgstr "kan inte öppna dynamiskt beroende ”%s”"
 
-#: collect2.c:2765
+#: collect2.c:2791
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: not a COFF file"
 msgstr "%s: är inte en COFF-fil"
 
-#: collect2.c:2930
+#: collect2.c:2961
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: cannot open as COFF file"
 msgstr "%s: kan inte öppna som COFF-fil"
 
-#: collect2.c:2989
+#: collect2.c:3020
 #, gcc-internal-format, gfc-internal-format
 msgid "library lib%s not found"
 msgstr "biblioteket lib%s finns inte"
@@ -17911,12 +17927,12 @@
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr "multipla EH-personligheter stödjs endast med assemblerare som stödjer direktivet .cfi.personality."
 
-#: dwarf2out.c:10901
+#: dwarf2out.c:10909
 #, gcc-internal-format
 msgid "-gdwarf-6 is output as version 5 with incompatibilities"
 msgstr "-gdwarf-6 matas ut som version 5 med inkompatibiliteter"
 
-#: dwarf2out.c:14415
+#: dwarf2out.c:14423
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr "odelegitimerad UNSPEC %s (%d) funnen på variabelplats"
@@ -18036,11 +18052,6 @@
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr "%K anrop av %qs deklarerad med attributet warning: %s"
 
-#: file-prefix-map.c:50
-#, gcc-internal-format
-msgid "invalid argument %qs to %qs"
-msgstr "ogiltigt argument %qs till %qs"
-
 #: final.c:1868
 #, gcc-internal-format
 msgid "the frame size of %wd bytes is larger than %wd bytes"
@@ -18061,42 +18072,42 @@
 msgid "large fixed-point constant implicitly truncated to fixed-point type"
 msgstr "stor fixdecimalskonstant implicit trunkerad till fixdecimaltyp"
 
-#: fold-const.c:4151 fold-const.c:4161
+#: fold-const.c:4157 fold-const.c:4167
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d due to width of bit-field"
 msgstr "jämförelsen är alltid %d på grund av bredd på bitfält"
 
-#: fold-const.c:5478 tree-ssa-reassoc.c:2374 tree-ssa-reassoc.c:3214
+#: fold-const.c:5484 tree-ssa-reassoc.c:2379 tree-ssa-reassoc.c:3219
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr "antar att teckenspill inte förekommer vid förenkling av intervalltest"
 
-#: fold-const.c:5928 fold-const.c:5942
+#: fold-const.c:5934 fold-const.c:5948
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr "jämförelsen är alltid %d"
 
-#: fold-const.c:6085
+#: fold-const.c:6091
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr "%<or%> mellan omatchade olikhetstester är alltid 1"
 
-#: fold-const.c:6090
+#: fold-const.c:6096
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr "%<and%> mellan ömsesidigt uteslutande likhetstester är alltid 0"
 
-#: fold-const.c:8310
+#: fold-const.c:8316
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr "antar att teckenspill inte förekommer vid reduktion av konstant i jämförelse"
 
-#: fold-const.c:8710
+#: fold-const.c:8716
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr "antar att teckenspill inte förekommer vid kombination av konstanter runt en jämförelse"
 
-#: fold-const.c:12063
+#: fold-const.c:12069
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr "vikningskontroll: originalträdet ändrat av vikning"
@@ -18106,7 +18117,7 @@
 msgid "total size of local objects too large"
 msgstr "total storlek på lokala objekt är för stor"
 
-#: function.c:1776 gimplify.c:6270
+#: function.c:1776 gimplify.c:6273
 #, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr "omöjlig begränsning i %<asm%>"
@@ -18411,7 +18422,7 @@
 msgid "%s: linker input file unused because linking not done"
 msgstr "%s: infil till länkaren oanvänd eftersom ingen länkning gjordes"
 
-#: gcc.c:8420 c-family/c-opts.c:770
+#: gcc.c:8420 c-family/c-opts.c:768
 #, gcc-internal-format
 msgid "cannot use %<-%> as input filename for a precompiled header"
 msgstr "det går inte att använda %<-%> som indatafilnamn för förkompilerade huvuden"
@@ -18646,7 +18657,7 @@
 msgid "%G%qD destination unchanged after copying no bytes"
 msgstr "%G%qD destinationen är oförändrad efter att inga byte kopierades"
 
-#: gimple-fold.c:2052 tree-ssa-strlen.c:2050
+#: gimple-fold.c:2052 tree-ssa-strlen.c:2074
 msgid "%G%qD specified bound %E equals destination size"
 msgstr "%G%qD angiven gräns %E är lika med destinationsstorleken"
 
@@ -18668,12 +18679,12 @@
 msgid "null pointer dereference"
 msgstr "nollpekardereferens"
 
-#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12451
-#: tree.c:12488 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10147
-#: c/c-typeck.c:10164 c/gimple-parser.c:1616 c/gimple-parser.c:1624
+#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12455
+#: tree.c:12492 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10152
+#: c/c-typeck.c:10169 c/gimple-parser.c:1616 c/gimple-parser.c:1624
 #: cp/call.c:6493 cp/call.c:8098 cp/constexpr.c:820 cp/constexpr.c:2309
-#: cp/cvt.c:1015 cp/cvt.c:1042 cp/decl.c:7334 cp/decl2.c:5256 cp/pt.c:8334
-#: cp/semantics.c:1836 cp/semantics.c:4053 cp/typeck.c:1700 cp/typeck.c:1895
+#: cp/cvt.c:1015 cp/cvt.c:1042 cp/decl.c:7355 cp/decl2.c:5246 cp/pt.c:8348
+#: cp/semantics.c:1836 cp/semantics.c:4056 cp/typeck.c:1700 cp/typeck.c:1895
 #: cp/typeck.c:3837
 #, gcc-internal-format
 msgid "declared here"
@@ -18684,27 +18695,27 @@
 msgid "nonnull argument %qD compared to NULL"
 msgstr "icke-null-argument %qD jämfört med NULL"
 
-#: gimple-ssa-sprintf.c:2517 gimple-ssa-sprintf.c:2637
+#: gimple-ssa-sprintf.c:2555 gimple-ssa-sprintf.c:2675
 #, gcc-internal-format
 msgid "%qE output may be truncated before the last format character"
 msgstr "%qE-utdata kan ha trunkerats före det sista formattecknet"
 
-#: gimple-ssa-sprintf.c:2519 gimple-ssa-sprintf.c:2639
+#: gimple-ssa-sprintf.c:2557 gimple-ssa-sprintf.c:2677
 #, gcc-internal-format
 msgid "%qE output truncated before the last format character"
 msgstr "%qE-utdata trunkerades före det sista formattecknet"
 
-#: gimple-ssa-sprintf.c:2522 gimple-ssa-sprintf.c:2642
+#: gimple-ssa-sprintf.c:2560 gimple-ssa-sprintf.c:2680
 #, gcc-internal-format
 msgid "%qE may write a terminating nul past the end of the destination"
 msgstr "%qE kan skriva en avslutande nolla efter slutet på destinationen"
 
-#: gimple-ssa-sprintf.c:2524 gimple-ssa-sprintf.c:2644
+#: gimple-ssa-sprintf.c:2562 gimple-ssa-sprintf.c:2682
 #, gcc-internal-format
 msgid "%qE writing a terminating nul past the end of the destination"
 msgstr "%qE skriver en avslutande nolla efter slutet på destinationen"
 
-#: gimple-ssa-sprintf.c:2534
+#: gimple-ssa-sprintf.c:2572
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size %wu"
@@ -18711,7 +18722,7 @@
 msgstr[0] "direktivet %<%.*s%> skrev %wu byte till en region av storlek %wu"
 msgstr[1] "direktivet %<%.*s%> skrev %wu byte till en region av storlek %wu"
 
-#: gimple-ssa-sprintf.c:2541
+#: gimple-ssa-sprintf.c:2579
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size %wu"
@@ -18718,7 +18729,7 @@
 msgstr[0] "utdata från direktivet %<%.*s%> kan ha huggits av när %wu byte skrevs till en region av storlek %wu"
 msgstr[1] "utdata från direktivet %<%.*s%> kan ha huggits av när %wu byte skrevs till en region av storlek %wu"
 
-#: gimple-ssa-sprintf.c:2548
+#: gimple-ssa-sprintf.c:2586
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size %wu"
@@ -18725,67 +18736,67 @@
 msgstr[0] "utdata från direktivet %<%.*s%> avhugget när %wu byte skrevs till en region av storlek %wu"
 msgstr[1] "utdata från direktivet %<%.*s%> avhugget när %wu byte skrevs till en region av storlek %wu"
 
-#: gimple-ssa-sprintf.c:2559
+#: gimple-ssa-sprintf.c:2597
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size %wu"
 msgstr "utdata från direktivet %<%.*s%> kan ha huggits av när upp till %wu byte skrevs till en region av storlek %wu"
 
-#: gimple-ssa-sprintf.c:2562
+#: gimple-ssa-sprintf.c:2600
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size %wu"
 msgstr "utdata från direktivet %<%.*s%> avhugget när upp till %wu byte skrevs till en region av storlek %wu"
 
-#: gimple-ssa-sprintf.c:2564
+#: gimple-ssa-sprintf.c:2602
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size %wu"
 msgstr "direktivet %<%.*s%> skrev upp till %wu byte till en region av storlek %wu"
 
-#: gimple-ssa-sprintf.c:2576
+#: gimple-ssa-sprintf.c:2614
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr "utdata från direktivet %<%.*s%> kan ha huggits av när antagligen %wu eller fler byte skrevs till en region av storlek %wu"
 
-#: gimple-ssa-sprintf.c:2579
+#: gimple-ssa-sprintf.c:2617
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr "utdata från direktivet %<%.*s%> avhugget när antagligen %wu eller fler byte skrevs till en region av storlek %wu"
 
-#: gimple-ssa-sprintf.c:2582
+#: gimple-ssa-sprintf.c:2620
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size %wu"
 msgstr "direktivet %<%.*s%> skrev antagligen %wu eller fler byte till en region av storlek %wu"
 
-#: gimple-ssa-sprintf.c:2591
+#: gimple-ssa-sprintf.c:2629
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr "utdata från direktivet %<%.*s%> kan ha huggits av när mellan %wu och %wu byte skrevs till en region av storlek %wu"
 
-#: gimple-ssa-sprintf.c:2594
+#: gimple-ssa-sprintf.c:2632
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr "utdata från direktivet %<%.*s%> avhugget när mellan %wu och %wu byte skrevs till en region av storlek %wu"
 
-#: gimple-ssa-sprintf.c:2597
+#: gimple-ssa-sprintf.c:2635
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size %wu"
 msgstr "direktivet %<%.*s%> skrev mellan %wu och %wu byte till en region av storlek %wu"
 
-#: gimple-ssa-sprintf.c:2606
+#: gimple-ssa-sprintf.c:2644
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size %wu"
 msgstr "utdata från direktivet %<%.*s%> kan ha huggits av när %wu eller fler byte skrevs till en region med storlek %wu"
 
-#: gimple-ssa-sprintf.c:2609
+#: gimple-ssa-sprintf.c:2647
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size %wu"
 msgstr "utdata från direktivet %<%.*s%> avhugget när %wu eller fler byte skrevs till en region av storlek %wu"
 
-#: gimple-ssa-sprintf.c:2611
+#: gimple-ssa-sprintf.c:2649
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size %wu"
 msgstr "direktivet %<%.*s%> skrev %wu eller fler byte till en region av storlek %wu"
 
-#: gimple-ssa-sprintf.c:2653
+#: gimple-ssa-sprintf.c:2691
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size between %wu and %wu"
@@ -18792,7 +18803,7 @@
 msgstr[0] "direktivet %<%.*s%> skrev %wu byte till en region av storlek mellan %wu och %wu"
 msgstr[1] "direktivet %<%.*s%> skrev %wu byte till en region av storlek mellan %wu och %wu"
 
-#: gimple-ssa-sprintf.c:2660
+#: gimple-ssa-sprintf.c:2698
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size between %wu and %wu"
@@ -18799,7 +18810,7 @@
 msgstr[0] "utdata från direktivet %<%.*s%> kan ha huggits av när %wu byte skrevs till en region av storlek mellan %wu och %wu"
 msgstr[1] "utdata från direktivet %<%.*s%> kan ha huggits av när %wu byte skrevs till en region av storlek mellan %wu och %wu"
 
-#: gimple-ssa-sprintf.c:2668
+#: gimple-ssa-sprintf.c:2706
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size between %wu and %wu"
@@ -18806,102 +18817,102 @@
 msgstr[0] "utdata från direktivet %<%.*s%> avhugget när %wu byte skrevs till en region av storlek mellan %wu och %wu"
 msgstr[1] "utdata från direktivet %<%.*s%> avhugget när %wu byte skrevs till en region av storlek mellan %wu och %wu"
 
-#: gimple-ssa-sprintf.c:2680
+#: gimple-ssa-sprintf.c:2718
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr "utdata från direktivet %<%.*s%> kan ha huggits av när upp till %wu byte skrevs till en region med storlek mellan %wu och %wu"
 
-#: gimple-ssa-sprintf.c:2683
+#: gimple-ssa-sprintf.c:2721
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr "utdata från direktivet %<%.*s%> avhugget när upp till %wu byte skrevs till en region med storlek mellan %wu och %wu"
 
-#: gimple-ssa-sprintf.c:2686
+#: gimple-ssa-sprintf.c:2724
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr "direktivet %<%.*s%> skrev upp till %wu byte till en region med storlek mellan %wu och %wu"
 
-#: gimple-ssa-sprintf.c:2699
+#: gimple-ssa-sprintf.c:2737
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr "utdata från direktivet %<%.*s%> kan ha huggits av när antagligen %wu eller fler byte skrevs till en region med storlek mellan %wu och %wu"
 
-#: gimple-ssa-sprintf.c:2702
+#: gimple-ssa-sprintf.c:2740
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr "utdata från direktivet %<%.*s%> höggs av när antagligen %wu eller fler byte skrevs till en region med storlek mellan %wu och %wu"
 
-#: gimple-ssa-sprintf.c:2705
+#: gimple-ssa-sprintf.c:2743
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr "direktivet %<%.*s%> skrev antagligen %wu eller fler byte till en region med storlek mellan %wu och %wu"
 
-#: gimple-ssa-sprintf.c:2715
+#: gimple-ssa-sprintf.c:2753
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr "utdata från direktivet %<%.*s%> kan ha huggits av när mellan %wu och %wu byte skrevs till en region med storlek mellan %wu och %wu"
 
-#: gimple-ssa-sprintf.c:2718
+#: gimple-ssa-sprintf.c:2756
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr "utdata från direktivet %<%.*s%> höggs av när mellan %wu och %wu byte skrevs till en region med storlek mellan %wu och %wu"
 
-#: gimple-ssa-sprintf.c:2721
+#: gimple-ssa-sprintf.c:2759
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr "direktivet %<%.*s%> skrev mellan %wu och %wu byte till en region med storlek mellan %wu och %wu"
 
-#: gimple-ssa-sprintf.c:2730
+#: gimple-ssa-sprintf.c:2768
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr "utdata från direktivet %<%.*s%> kan ha huggits av när %wu eller fler byte skrevs till en region med storlek mellan %wu och %wu"
 
-#: gimple-ssa-sprintf.c:2733
+#: gimple-ssa-sprintf.c:2771
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr "utdata från direktivet %<%.*s%> höggs av när %wu eller fler byte skrevs till en region med storlek mellan %wu och %wu"
 
-#: gimple-ssa-sprintf.c:2736
+#: gimple-ssa-sprintf.c:2774
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr "direktivet %<%.*s%> skrev %wu eller fler byte till en region med storlek mellan %wu och %wu"
 
-#: gimple-ssa-sprintf.c:2825
+#: gimple-ssa-sprintf.c:2863
 #, gcc-internal-format
 msgid "%<%.*s%> directive argument is null"
 msgstr "direktivargumentet %<%.*s%> är null"
 
-#: gimple-ssa-sprintf.c:2890
+#: gimple-ssa-sprintf.c:2928
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes exceeds minimum required size of 4095"
 msgstr "utdata från direktivet %<%.*s%> på %wu byte överskrider minsta nödvändiga storlek på 4095"
 
-#: gimple-ssa-sprintf.c:2897
+#: gimple-ssa-sprintf.c:2935
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may exceed minimum required size of 4095"
 msgstr "utdata från direktivet %<%.*s%> mellan %wu och %wu byte kan överskrida minsta nödvändiga storlek på 4095"
 
-#: gimple-ssa-sprintf.c:2900
+#: gimple-ssa-sprintf.c:2938
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes exceeds minimum required size of 4095"
 msgstr "utdata från direktivet %<%.*s%> mellan %wu och %wu byte överskrider minsta nödvändiga storlek på 4095"
 
-#: gimple-ssa-sprintf.c:2929
+#: gimple-ssa-sprintf.c:2967
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr "utdata från direktivet %<%.*s%> på %wu byte får resultatet att överskrida %<INT_MAX%>"
 
-#: gimple-ssa-sprintf.c:2936
+#: gimple-ssa-sprintf.c:2974
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr "utdata från direktivet %<%.*s%> mellan %wu och %wu byte får resultatet att överskrida %<INT_MAX%>"
 
-#: gimple-ssa-sprintf.c:2939
+#: gimple-ssa-sprintf.c:2977
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may cause result to exceed %<INT_MAX%>"
 msgstr "utdata från direktivet %<%.*s%> mellan %wu och %wu byte kan få resultatet att överskrida %<INT_MAX%>"
 
-#: gimple-ssa-sprintf.c:2949
+#: gimple-ssa-sprintf.c:2987
 #, gcc-internal-format
 msgid "assuming directive output of %wu byte"
 msgid_plural "assuming directive output of %wu bytes"
@@ -18908,77 +18919,77 @@
 msgstr[0] "antar direktivutdata på %wu byte"
 msgstr[1] "antar direktivutdata på %wu byte"
 
-#: gimple-ssa-sprintf.c:2956
+#: gimple-ssa-sprintf.c:2994
 #, gcc-internal-format
 msgid "directive argument %qE"
 msgstr "direktivargument %qE"
 
-#: gimple-ssa-sprintf.c:2958
+#: gimple-ssa-sprintf.c:2996
 #, gcc-internal-format
 msgid "directive argument in the range [%E, %E]"
 msgstr "direktivargument i intervallet [%E, %E]"
 
-#: gimple-ssa-sprintf.c:2962
+#: gimple-ssa-sprintf.c:3000
 #, gcc-internal-format
 msgid "using the range [%E, %E] for directive argument"
 msgstr "använder intervallet [%E, %E] som direktivargument"
 
-#: gimple-ssa-sprintf.c:2982
+#: gimple-ssa-sprintf.c:3020
 #, gcc-internal-format
 msgid "%qE output %wu byte into a destination of size %wu"
 msgstr "%qE-utdata på %wu byte in i en destination med storlek %wu"
 
-#: gimple-ssa-sprintf.c:2983
+#: gimple-ssa-sprintf.c:3021
 #, gcc-internal-format
 msgid "%qE output %wu bytes into a destination of size %wu"
 msgstr "%qE-utdata på %wu byte in i en destination med storlek %wu"
 
-#: gimple-ssa-sprintf.c:2987
+#: gimple-ssa-sprintf.c:3025
 #, gcc-internal-format
 msgid "%qE output between %wu and %wu bytes into a destination of size %wu"
 msgstr "%qE-utdata mellan %wu och %wu byte in i en destination med storlek %wu"
 
-#: gimple-ssa-sprintf.c:2992
+#: gimple-ssa-sprintf.c:3030
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes (assuming %wu) into a destination of size %wu"
 msgstr "%qE-utdata på %wu eller fler byte (antar %wu) in i en destination med storlek %wu"
 
-#: gimple-ssa-sprintf.c:2997
+#: gimple-ssa-sprintf.c:3035
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes into a destination of size %wu"
 msgstr "%qE-utdata på %wu eller fler byte in i en destination med storlek %wu"
 
-#: gimple-ssa-sprintf.c:3368
+#: gimple-ssa-sprintf.c:3406
 #, gcc-internal-format
 msgid "%<%.*s%> directive width out of range"
 msgstr "direktivbredden %<%.*s%> är utanför intervallet"
 
-#: gimple-ssa-sprintf.c:3402
+#: gimple-ssa-sprintf.c:3440
 #, gcc-internal-format
 msgid "%<%.*s%> directive precision out of range"
 msgstr "direktivprecisionen %<%.*s%> är utanför intervallet"
 
-#: gimple-ssa-sprintf.c:3893
+#: gimple-ssa-sprintf.c:3931
 #, gcc-internal-format
 msgid "specified bound %wu exceeds maximum object size %wu"
 msgstr "angiven gräns på %wu överskrider maximal objektstorlek %wu"
 
-#: gimple-ssa-sprintf.c:3899
+#: gimple-ssa-sprintf.c:3937
 #, gcc-internal-format
 msgid "specified bound %wu exceeds %<INT_MAX%>"
 msgstr "angiven gräns på %wu överskrider %<INT_MAX%>"
 
-#: gimple-ssa-sprintf.c:3949
+#: gimple-ssa-sprintf.c:3987
 #, gcc-internal-format
 msgid "null destination pointer"
 msgstr "nolldestinationspekare"
 
-#: gimple-ssa-sprintf.c:3966
+#: gimple-ssa-sprintf.c:4004
 #, gcc-internal-format
 msgid "specified bound %wu exceeds the size %wu of the destination object"
 msgstr "angiven gräns på %wu överskrider storleken %wu på destinationsobjektet"
 
-#: gimple-ssa-sprintf.c:3978
+#: gimple-ssa-sprintf.c:4016
 #, gcc-internal-format
 msgid "null format string"
 msgstr "nollformatsträng"
@@ -19191,10 +19202,10 @@
 msgstr "%G%qD på avståndet %s är utanför gränserna för objekt %qD med typen %qT"
 
 #: gimple-ssa-warn-restrict.c:1678 c/c-decl.c:3603 c/c-decl.c:3874
-#: c/c-typeck.c:8345 cp/class.c:1346 cp/class.c:3098 cp/decl.c:3979
-#: cp/decl.c:10753 cp/decl.c:11151 cp/decl.c:11160 cp/friend.c:384
+#: c/c-typeck.c:8350 cp/class.c:1346 cp/class.c:3102 cp/decl.c:3979
+#: cp/decl.c:10777 cp/decl.c:11175 cp/decl.c:11184 cp/friend.c:384
 #: cp/friend.c:393 cp/parser.c:3275 cp/parser.c:3372 cp/parser.c:3422
-#: cp/parser.c:6327 cp/parser.c:21027
+#: cp/parser.c:6330 cp/parser.c:21024
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD är deklarerad här"
@@ -19262,217 +19273,217 @@
 msgid "using result of function returning %<void%>"
 msgstr "använder resultat från funktion som returnerar %<void%>"
 
-#: gimplify.c:6128
+#: gimplify.c:6131
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid lvalue in asm output %d"
 msgstr "ogiltigt l-värde i asm-utdata %d"
 
-#: gimplify.c:6271
+#: gimplify.c:6274
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr "icke-minnesindata %d måste stanna i minnet"
 
-#: gimplify.c:6311 gimplify.c:6320
+#: gimplify.c:6314 gimplify.c:6323
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr "minnesindata %d är inte direkt adresserbar"
 
-#: gimplify.c:6928
+#: gimplify.c:6931
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in target region"
 msgstr "trådprivat variabel %qE använd i målregion"
 
-#: gimplify.c:6930
+#: gimplify.c:6933
 #, gcc-internal-format
 msgid "enclosing target region"
 msgstr "omgivande målregion"
 
-#: gimplify.c:6942
+#: gimplify.c:6945
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in untied task"
 msgstr "trådprivat variabel %qE använd i obunden uppgift"
 
-#: gimplify.c:6944
+#: gimplify.c:6947
 #, gcc-internal-format
 msgid "enclosing task"
 msgstr "omgivande uppgift"
 
-#: gimplify.c:7016
+#: gimplify.c:7019
 #, gcc-internal-format
 msgid "%qE not specified in enclosing %qs"
 msgstr "%qE inte angiven i omgivande %qs"
 
-#: gimplify.c:7018
+#: gimplify.c:7021
 #, gcc-internal-format
 msgid "enclosing %qs"
 msgstr "omgivande %qs"
 
-#: gimplify.c:7143
+#: gimplify.c:7146
 #, gcc-internal-format
 msgid "%qE not specified in enclosing OpenACC %qs construct"
 msgstr "%qE inte angiven i omgivande OpenACC %qs-konstruktion"
 
-#: gimplify.c:7145
+#: gimplify.c:7148
 #, gcc-internal-format
 msgid "enclosing OpenACC %qs construct"
 msgstr "omgivande OpenACC %qs-konstruktion"
 
-#: gimplify.c:7198
+#: gimplify.c:7201
 #, gcc-internal-format
 msgid "%qE with %<link%> clause used in %<routine%> function"
 msgstr "%qE med %<link%>-klausul använd i %<routine%>-funktion"
 
-#: gimplify.c:7206
+#: gimplify.c:7209
 #, gcc-internal-format
 msgid "%qE requires a %<declare%> directive for use in a %<routine%> function"
 msgstr "%qE behöver ett %<declare%>-direktiv att användas i en %<routine%>-funktion"
 
-#: gimplify.c:7272 gimplify.c:7872
+#: gimplify.c:7275 gimplify.c:7875
 #, gcc-internal-format
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr "variabeln %qE deklarerad i omgivande %<host_data%>-region"
 
-#: gimplify.c:7293
+#: gimplify.c:7296
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr "%qD refererad i målregion som inte har en avbildbar typ"
 
-#: gimplify.c:7411 gimplify.c:7443
+#: gimplify.c:7414 gimplify.c:7446
 #, gcc-internal-format
 msgid "iteration variable %qE is predetermined linear"
 msgstr "iterationsvariabel %qE är förutbestämt linjär"
 
-#: gimplify.c:7414
+#: gimplify.c:7417
 #, gcc-internal-format
 msgid "iteration variable %qE should be private"
 msgstr "instansvariabel %qE skall vara privat"
 
-#: gimplify.c:7428
+#: gimplify.c:7431
 #, gcc-internal-format
 msgid "iteration variable %qE should not be firstprivate"
 msgstr "iterationsvariabel %qE får inte vara firstprivate"
 
-#: gimplify.c:7431
+#: gimplify.c:7434
 #, gcc-internal-format
 msgid "iteration variable %qE should not be reduction"
 msgstr "iterationsvariabel %qE får inte vara reduction"
 
-#: gimplify.c:7434
+#: gimplify.c:7437
 #, gcc-internal-format
 msgid "iteration variable %qE should not be linear"
 msgstr "instansvariabel %qE får inte vara linjär"
 
-#: gimplify.c:7437
+#: gimplify.c:7440
 #, gcc-internal-format
 msgid "iteration variable %qE should not be lastprivate"
 msgstr "iterationsvariabel %qE får inte vara lastprivate"
 
-#: gimplify.c:7440
+#: gimplify.c:7443
 #, gcc-internal-format
 msgid "iteration variable %qE should not be private"
 msgstr "instansvariabel %qE får inte vara privat"
 
-#: gimplify.c:7742
+#: gimplify.c:7745
 #, gcc-internal-format
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr "%<linear%>-klausul för en annan variabel än en slingiterator angiven vid konstruktion kombinerad med %<distribute%>"
 
-#: gimplify.c:7949
+#: gimplify.c:7952
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr "avbildningsfältet %qE med variabel längds post"
 
-#: gimplify.c:8160
+#: gimplify.c:8163
 #, gcc-internal-format
 msgid "%qE appears more than once in map clauses"
 msgstr "%qE förekommer mer än en gång i avbildningsklausuler"
 
-#: gimplify.c:8464
+#: gimplify.c:8467
 #, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr "copyprivate-variabel %qE är inte privat threadprivate eller private i yttre sammanhang"
 
-#: gimplify.c:8484
+#: gimplify.c:8487
 #, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr "%s-variabel %qE är privat i yttre sammanhang"
 
-#: gimplify.c:8510
+#: gimplify.c:8513
 #, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr "%qs %<if%>-klausulmodifierare förväntades snarare än %qs"
 
-#: gimplify.c:8775
+#: gimplify.c:8778
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr "%<_Atomic%> %qD i implicit %<map%>-klausul"
 
-#: gimplify.c:8808
+#: gimplify.c:8811
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr "%<_Atomic%> %qD i implicit %<firstprivate%>-klausul vid %<target%>-konstruktion"
 
-#: gimplify.c:9000
+#: gimplify.c:9003
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr "%<_Atomic%> %qD i %<firstprivate%>-klausul vid %<target%>-konstruktion"
 
-#: gimplify.c:9051
+#: gimplify.c:9054
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr "samma variabel använd i %<firstprivate%>- och %<lastprivate%>-klausuler vid %<distribute%>-konstruktion"
 
-#: gimplify.c:9133
+#: gimplify.c:9136
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to present_or_copy"
 msgstr "inkompatibel dataklausul med reduktion på %qE; befordrar till present_or_copy"
 
-#: gimplify.c:9278
+#: gimplify.c:9281
 #, gcc-internal-format
 msgid "invalid private reduction on %qE"
 msgstr "ogiltig privat reduktion av %qE"
 
-#: gimplify.c:11103 omp-low.c:2791
+#: gimplify.c:11106 omp-low.c:2791
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr "%<ordered%>-konstruktion med %<depend%>-klausul måste vara nära innesluten inuti en slinga med %<ordered%>-klausul med en parameter"
 
-#: gimplify.c:11121
+#: gimplify.c:11124
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr "variabeln %qE är inte en iterator av den yttersta slingan %d, %qE förväntades"
 
-#: gimplify.c:11134
+#: gimplify.c:11137
 #, gcc-internal-format
 msgid "number of variables in %<depend(sink)%> clause does not match number of iteration variables"
 msgstr "antalet variabler i %<depend(sink)%>-klausulen stämmer inte med antalet iterationsvariabler"
 
-#: gimplify.c:11147
+#: gimplify.c:11150
 #, gcc-internal-format
 msgid "more than one %<depend(source)%> clause on an %<ordered%> construct"
 msgstr "mer än en %<depend(source)%>-klausul på en %<ordered%>-konstruktion"
 
-#: gimplify.c:11158
+#: gimplify.c:11161
 #, gcc-internal-format
 msgid "%<depend(source)%> clause specified together with %<depend(sink:)%> clauses on the same construct"
 msgstr "%<depend(source)%>-klausul angiven tillsammans med %<depend(sink:)%>-klausuler på samma konstruktion"
 
-#: gimplify.c:12393
+#: gimplify.c:12396
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr "gimplification misslyckades"
 
-#: gimplify.c:12936
+#: gimplify.c:12939
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr "%qT konverteras till %qT när det skickas via %<...%>"
 
-#: gimplify.c:12941
+#: gimplify.c:12944
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr "(alltså skall du skicka %qT och inte %qT till %<va_arg%>)"
 
-#: gimplify.c:12948
+#: gimplify.c:12951
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr "om denna kod nås, kommer programmet att avbryta"
@@ -19945,47 +19956,47 @@
 msgid "Max. number of generated reload insns per insn is achieved (%d)\n"
 msgstr "Maximalt antal genererade omladdningsinstruktioner per instruktion uppnått (%d)\n"
 
-#: lto-cgraph.c:1294
+#: lto-cgraph.c:1296
 #, gcc-internal-format, gfc-internal-format
 msgid "bytecode stream: found multiple instances of cgraph node with uid %d"
 msgstr "bytekodström: hittade multipla instanser av cgraph-nod med uid %d"
 
-#: lto-cgraph.c:1472
+#: lto-cgraph.c:1474
 #, gcc-internal-format
 msgid "bytecode stream: no caller found while reading edge"
 msgstr "bytekodström: ingen anropare funnen när båge lästes"
 
-#: lto-cgraph.c:1478
+#: lto-cgraph.c:1480
 #, gcc-internal-format
 msgid "bytecode stream: no callee found while reading edge"
 msgstr "bytekodström: ingen anropad funnen när båge lästes"
 
-#: lto-cgraph.c:1552
+#: lto-cgraph.c:1554
 #, gcc-internal-format
 msgid "bytecode stream: found empty cgraph node"
 msgstr "bytekodström: tom cgraph-nod funnen"
 
-#: lto-cgraph.c:1730
+#: lto-cgraph.c:1732
 #, gcc-internal-format, gfc-internal-format
 msgid "At most %i profile runs is supported. Perhaps corrupted profile?"
 msgstr "Som mest %i profilkörningar stödjs.  Kanske en skadad profil?"
 
-#: lto-cgraph.c:1817
+#: lto-cgraph.c:1819
 #, gcc-internal-format, gfc-internal-format
 msgid "Profile information in %s corrupted"
 msgstr "Profilinformation i %s är skadad"
 
-#: lto-cgraph.c:1855
+#: lto-cgraph.c:1857
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO cgraph in %s"
 msgstr "det går inte att hitta LTO-cgraph %s"
 
-#: lto-cgraph.c:1865
+#: lto-cgraph.c:1867
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO section refs in %s"
 msgstr "det går inte att hitta LTO-avsnittsreferenser i %s"
 
-#: lto-cgraph.c:1946
+#: lto-cgraph.c:1948
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid offload table in %s"
 msgstr "ogiltig avlastningstabell i %s"
@@ -20056,81 +20067,86 @@
 msgid "bytecode stream in file %qs generated with LTO version %d.%d instead of the expected %d.%d"
 msgstr "bytekodströmmen i filen %qs är genererad med LTO-version %d.%d istället för den förväntade %d.%d"
 
-#: lto-wrapper.c:117
+#: lto-wrapper.c:118
 #, gcc-internal-format
 msgid "deleting LTRANS file %s: %m"
 msgstr "raderar LTRANS-filen %s: %m"
 
-#: lto-wrapper.c:154
+#: lto-wrapper.c:155
 #, gcc-internal-format
 msgid "malformed COLLECT_GCC_OPTIONS"
 msgstr "felformaterad COLLECT_GCC_OPTIONS"
 
-#: lto-wrapper.c:308
+#: lto-wrapper.c:309
 #, gcc-internal-format, gfc-internal-format
 msgid "Option %s with different values"
 msgstr "Flaggan %s med olika värden"
 
-#: lto-wrapper.c:392
+#: lto-wrapper.c:393
 #, gcc-internal-format, gfc-internal-format
 msgid "Option %s not used consistently in all LTO input files"
 msgstr "Flaggan %s inte konsekvent använd i alla LTO-indatafiler"
 
-#: lto-wrapper.c:832
+#: lto-wrapper.c:833
 #, gcc-internal-format, gfc-internal-format
 msgid "problem with building target image for %s\n"
 msgstr "problem med att bygga målavbild för %s\n"
 
-#: lto-wrapper.c:852
+#: lto-wrapper.c:853
 #, gcc-internal-format
 msgid "reading input file"
 msgstr "läser indatafiler"
 
-#: lto-wrapper.c:857
+#: lto-wrapper.c:858
 #, gcc-internal-format
 msgid "writing output file"
 msgstr "skriver utdatafil"
 
-#: lto-wrapper.c:889
+#: lto-wrapper.c:890
 #, gcc-internal-format
 msgid "installation error, can't find crtoffloadtable.o"
 msgstr "installationsfel, kan inte hitta crtoffloadtable.o"
 
-#: lto-wrapper.c:1000 lto-wrapper.c:1012
+#: lto-wrapper.c:1001 lto-wrapper.c:1013
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: %s\n"
 msgstr "%s: %s\n"
 
-#: lto-wrapper.c:1056
+#: lto-wrapper.c:1064
 #, gcc-internal-format
 msgid "environment variable COLLECT_GCC must be set"
 msgstr "miljövariabeln COLLECT_GCC måste vara satt"
 
-#: lto-wrapper.c:1060 config/nvptx/mkoffload.c:363
+#: lto-wrapper.c:1068 config/nvptx/mkoffload.c:363
 #, gcc-internal-format
 msgid "environment variable COLLECT_GCC_OPTIONS must be set"
 msgstr "miljövariabeln COLLECT_GCC_OPTIONS måste vara satt"
 
-#: lto-wrapper.c:1229 lto-wrapper.c:1285
+#: lto-wrapper.c:1237 lto-wrapper.c:1293
 #, gcc-internal-format
 msgid "cannot open %s: %m"
 msgstr "det går inte att öppna %s: %m"
 
-#: lto-wrapper.c:1232 lto-wrapper.c:1291
+#: lto-wrapper.c:1240 lto-wrapper.c:1299
 #, gcc-internal-format
 msgid "cannot read %s: %m"
 msgstr "kan inte läsa %s: %m"
 
-#: lto-wrapper.c:1259
+#: lto-wrapper.c:1267
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid format of %s"
 msgstr "felaktigt format på %s"
 
-#: lto-wrapper.c:1482
+#: lto-wrapper.c:1491
 #, gcc-internal-format
 msgid "fopen: %s: %m"
 msgstr "fopen: %s: %m"
 
+#: lto-wrapper.c:1508
+#, gcc-internal-format, gfc-internal-format
+msgid "Corrupted ltrans output file %s"
+msgstr "Trasig ltrans-utdatafil %s"
+
 #: multiple_target.c:76
 #, gcc-internal-format
 msgid "the call requires ifunc, which is not supported by this target"
@@ -20482,12 +20498,12 @@
 msgid "unrecognized argument in option %qs"
 msgstr "okänt argument till flaggan %qs"
 
-#: opts-common.c:1198 config/i386/i386.c:3206
+#: opts-common.c:1198 config/i386/i386.c:3209
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "giltiga argument till %qs är: %s; menade du %qs?"
 
-#: opts-common.c:1201 config/i386/i386.c:3209
+#: opts-common.c:1201 config/i386/i386.c:3212
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "giltiga argument till %qs är: %s"
@@ -21082,22 +21098,22 @@
 msgid "output operand %d must use %<&%> constraint"
 msgstr "utdataoperand %d måste använda %<&%>-begränsning"
 
-#: regcprop.c:1187
+#: regcprop.c:1193
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad next_regno for empty chain (%u)"
 msgstr "validate_value_data: [%u] Felaktigt next_regno för tom kedja (%u)"
 
-#: regcprop.c:1199
+#: regcprop.c:1205
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: Loop in regno chain (%u)"
 msgstr "validate_value_data: Slinga i regno-kedja (%u)"
 
-#: regcprop.c:1202
+#: regcprop.c:1208
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad oldest_regno (%u)"
 msgstr "validate_value_data: [%u] Felaktig oldest_regno (%u)"
 
-#: regcprop.c:1214
+#: regcprop.c:1220
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Non-empty reg in chain (%s %u %i)"
 msgstr "validate_value_data: [%u] Ej tomt reg i kedja (%s %u %i)"
@@ -21141,7 +21157,7 @@
 msgstr "register för %qD använt till flera globala registervariabler"
 
 #: reginfo.c:789 config/powerpcspe/powerpcspe.c:32259
-#: config/rs6000/rs6000.c:29453
+#: config/rs6000/rs6000.c:29530
 #, gcc-internal-format
 msgid "conflicts with %qD"
 msgstr "står i konflikt med %qD"
@@ -21386,152 +21402,157 @@
 msgid "function symbol is not function"
 msgstr "funktionssymbol som inte är en funktion"
 
-#: symtab.c:1006
+#: symtab.c:1005
 #, gcc-internal-format
+msgid "inconsistent `ifunc' attribute"
+msgstr "inkonsistent ”ifunc”-attribut"
+
+#: symtab.c:1013
+#, gcc-internal-format
 msgid "variable symbol is not variable"
 msgstr "variabelsymbol är inte en variabel"
 
-#: symtab.c:1012
+#: symtab.c:1019
 #, gcc-internal-format
 msgid "node has unknown type"
 msgstr "noden har okänd typ"
 
-#: symtab.c:1021
+#: symtab.c:1028
 #, gcc-internal-format
 msgid "node not found node->decl->decl_with_vis.symtab_node"
 msgstr "nod ej funnen found node->decl->decl_with_vis.symtab_node"
 
-#: symtab.c:1029
+#: symtab.c:1036
 #, gcc-internal-format
 msgid "node differs from node->decl->decl_with_vis.symtab_node"
 msgstr "noden skiljer från node->decl->decl_with_vis.symtab_node"
 
-#: symtab.c:1038
+#: symtab.c:1045
 #, gcc-internal-format
 msgid "assembler name hash list corrupted"
 msgstr "hashlistan över assemblernamn trasig"
 
-#: symtab.c:1051
+#: symtab.c:1058
 #, gcc-internal-format
 msgid "node not found in symtab assembler name hash"
 msgstr "nod finns inte i hashen av symboltabellassemblernamn"
 
-#: symtab.c:1058
+#: symtab.c:1065
 #, gcc-internal-format
 msgid "double linked list of assembler names corrupted"
 msgstr "dubbellänkad lista av assemblernamn är trasig"
 
-#: symtab.c:1063
+#: symtab.c:1070
 #, gcc-internal-format
 msgid "node has body_removed but is definition"
 msgstr "noden har body_removed men är en definition"
 
-#: symtab.c:1068
+#: symtab.c:1075
 #, gcc-internal-format
 msgid "node is analyzed but it is not a definition"
 msgstr "noden är analyserad men den är inte en definition"
 
-#: symtab.c:1073
+#: symtab.c:1080
 #, gcc-internal-format
 msgid "node is alias but not implicit alias"
 msgstr "noden är ett alias men inte ett implicit alias"
 
-#: symtab.c:1078
+#: symtab.c:1085
 #, gcc-internal-format
 msgid "node is alias but not definition"
 msgstr "noden är ett alias men inte en definition"
 
-#: symtab.c:1083
+#: symtab.c:1090
 #, gcc-internal-format
 msgid "node is weakref but not an transparent_alias"
 msgstr "noden är weakref men inte ett transparent_alias"
 
-#: symtab.c:1088
+#: symtab.c:1095
 #, gcc-internal-format
 msgid "node is transparent_alias but not an alias"
 msgstr "noden är transparent_alias men inte ett alias"
 
-#: symtab.c:1097
+#: symtab.c:1104
 #, gcc-internal-format
 msgid "node is in same_comdat_group list but has no comdat_group"
 msgstr "noden är i same_comdat_group-listan men den har ingen comdat_group"
 
-#: symtab.c:1102
+#: symtab.c:1109
 #, gcc-internal-format
 msgid "same_comdat_group list across different groups"
 msgstr "same_comdat_group-lista över olika grupper"
 
-#: symtab.c:1107
+#: symtab.c:1114
 #, gcc-internal-format
 msgid "mixing different types of symbol in same comdat groups is not supported"
 msgstr "blandning av olika typer av symboler i samma comdat-grupper stödjs inte"
 
-#: symtab.c:1112
+#: symtab.c:1119
 #, gcc-internal-format
 msgid "node is alone in a comdat group"
 msgstr "noden är ensam i en comdat-grupp"
 
-#: symtab.c:1119
+#: symtab.c:1126
 #, gcc-internal-format
 msgid "same_comdat_group is not a circular list"
 msgstr "same_comdat_group är inte en cirkulär lista"
 
-#: symtab.c:1134
+#: symtab.c:1141
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local symbol referred to by %s outside its comdat"
 msgstr "comdat-lokal symbol refererad till av %s utanför dess comdat"
 
-#: symtab.c:1144
+#: symtab.c:1151
 #, gcc-internal-format
 msgid "implicit_section flag is set but section isn't"
 msgstr "flaggan implicit_section är satt men sektionen är inte det"
 
-#: symtab.c:1151
+#: symtab.c:1158
 #, gcc-internal-format
 msgid "Both section and comdat group is set"
 msgstr "både sektion och comdat-grupp är satt"
 
-#: symtab.c:1163
+#: symtab.c:1170
 #, gcc-internal-format
 msgid "Alias and target's section differs"
 msgstr "Aliasets och målets sektion skiljer"
 
-#: symtab.c:1170
+#: symtab.c:1177
 #, gcc-internal-format
 msgid "Alias and target's comdat groups differs"
 msgstr "Aliasets och målets comdat-grupper skiljer"
 
-#: symtab.c:1185
+#: symtab.c:1192
 #, gcc-internal-format
 msgid "Transparent alias and target's assembler names differs"
 msgstr "Transparent alias och målets assemblernamn skiljer"
 
-#: symtab.c:1193
+#: symtab.c:1200
 #, gcc-internal-format
 msgid "Chained transparent aliases"
 msgstr "Kedjade genomskinliga alias"
 
-#: symtab.c:1216 symtab.c:1253
+#: symtab.c:1223 symtab.c:1260
 #, gcc-internal-format
 msgid "symtab_node::verify failed"
 msgstr "symtab_node::verify misslyckades"
 
-#: symtab.c:1249
+#: symtab.c:1256
 #, gcc-internal-format
 msgid "Two symbols with same comdat_group are not linked by the same_comdat_group list."
 msgstr "Två symboler med samma comdat_group är inte länkade av listan same_comdat_group."
 
-#: symtab.c:1658
+#: symtab.c:1665
 #, gcc-internal-format
 msgid "function %q+D part of alias cycle"
 msgstr "funktionen %q+D är en del av en aliascykel"
 
-#: symtab.c:1660
+#: symtab.c:1667
 #, gcc-internal-format
 msgid "variable %q+D part of alias cycle"
 msgstr "variabeln %q+D är del i en aliascykel"
 
-#: symtab.c:1688
+#: symtab.c:1695
 #, gcc-internal-format
 msgid "section of alias %q+D must match section of its target"
 msgstr "sektionen för aliaset %q+D måste stämma med sektionen för dess mål"
@@ -22332,7 +22353,7 @@
 msgid "the first argument of a VEC_COND_EXPR must be of a boolean vector type of the same number of elements as the result"
 msgstr "första argumentet till en VEC_COND_EXPR måste vara av boolesk vektortyp med samma antal element som resultatet"
 
-#: tree-cfg.c:4395 c/c-typeck.c:5212
+#: tree-cfg.c:4395 c/c-typeck.c:5217
 #, gcc-internal-format
 msgid "type mismatch in conditional expression"
 msgstr "typer stämmer inte i villkorsuttryck"
@@ -22684,22 +22705,22 @@
 msgid "missing edge %i->%i"
 msgstr "båge saknas %i->%i"
 
-#: tree-cfg.c:9379
+#: tree-cfg.c:9388
 #, gcc-internal-format
 msgid "%<noreturn%> function does return"
 msgstr "%<noreturn%>-funktion returnerar"
 
-#: tree-cfg.c:9400 tree-cfg.c:9432
+#: tree-cfg.c:9409 tree-cfg.c:9441
 #, gcc-internal-format
 msgid "control reaches end of non-void function"
 msgstr "flödet når slutet på en icke-void-funktion"
 
-#: tree-cfg.c:9498 cp/cvt.c:1039
+#: tree-cfg.c:9507 cp/cvt.c:1039
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgstr "ignorerar returvärdet av %qD, deklarerad med attributet warn_unused_result"
 
-#: tree-cfg.c:9503 cp/cvt.c:1046
+#: tree-cfg.c:9512 cp/cvt.c:1046
 #, gcc-internal-format
 msgid "ignoring return value of function declared with attribute warn_unused_result"
 msgstr "ignorerar returvärdet av funktion deklarerad med attributet warn_unused_result"
@@ -22964,46 +22985,46 @@
 msgid "stmt volatile flag not up-to-date"
 msgstr "satsens volatile-flagga är inte aktuell"
 
-#: tree-ssa-strlen.c:1975
+#: tree-ssa-strlen.c:1999
 msgid "%G%qD output truncated before terminating nul copying %E byte from a string of the same length"
 msgid_plural "%G%qD output truncated before terminating nul copying %E bytes from a string of the same length"
 msgstr[0] "Utdata för %G%qD avhuggen före avslutande null vid kopiering av %E byte från en sträng av samma längd"
 msgstr[1] "Utdata för %G%qD avhuggen före avslutande null vid kopiering av %E byte från en sträng av samma längd"
 
-#: tree-ssa-strlen.c:1989
+#: tree-ssa-strlen.c:2013
 msgid "%G%qD output truncated copying %E byte from a string of length %wu"
 msgid_plural "%G%qD output truncated copying %E bytes from a string of length %wu"
 msgstr[0] "utdata från %G%qD avhuggen vid kopiering av %E byte från en sträng med längden %wu"
 msgstr[1] "utdata från %G%qD avhuggen vid kopiering av %E byte från en sträng med längden %wu"
 
-#: tree-ssa-strlen.c:1996
+#: tree-ssa-strlen.c:2020
 msgid "%G%qD output truncated copying between %wu and %wu bytes from a string of length %wu"
 msgstr "utdata från %G%qD avhuggen vid kopiering mellan %wu och %wu byte från en sträng med längden %wu"
 
-#: tree-ssa-strlen.c:2008
+#: tree-ssa-strlen.c:2032
 msgid "%G%qD output may be truncated copying %E byte from a string of length %wu"
 msgid_plural "%G%qD output may be truncated copying %E bytes from a string of length %wu"
 msgstr[0] "utdata från %G%qD kan ha huggits av vid kopiering av %E byte från en sträng med längden %wu"
 msgstr[1] "utdata från %G%qD kan ha huggits av vid kopiering av %E byte från en sträng med längden %wu"
 
-#: tree-ssa-strlen.c:2015 tree-ssa-strlen.c:2029
+#: tree-ssa-strlen.c:2039 tree-ssa-strlen.c:2053
 msgid "%G%qD output may be truncated copying between %wu and %wu bytes from a string of length %wu"
 msgstr "utdata från %G%qD kan ha huggits av vid kopiering mellan %wu och %wu byte från en sträng med längden %wu"
 
-#: tree-ssa-strlen.c:2150
+#: tree-ssa-strlen.c:2174
 msgid "%G%qD output truncated before terminating nul copying as many bytes from a string as its length"
 msgstr "utdata från %G%qD höggs av före avslutande nolla vid kopiering av så många byte från en sträng som dess längd"
 
-#: tree-ssa-strlen.c:2156
+#: tree-ssa-strlen.c:2180
 msgid "%G%qD specified bound depends on the length of the source argument"
 msgstr "%G%qD den angivna gränsen beror på längden av källargumentet"
 
-#: tree-ssa-strlen.c:2163
+#: tree-ssa-strlen.c:2187
 #, gcc-internal-format
 msgid "length computed here"
 msgstr "längden beräknad här"
 
-#: tree-ssa-uninit.c:191 varasm.c:331
+#: tree-ssa-uninit.c:191 varasm.c:342
 #, gcc-internal-format
 msgid "%qD was declared here"
 msgstr "%qD deklarerades här"
@@ -23178,27 +23199,27 @@
 msgid "target specific builtin not available"
 msgstr "målspecifik inbyggd funktion är inte tillgänglig"
 
-#: tree-vect-generic.c:287
+#: tree-vect-generic.c:283
 #, gcc-internal-format
 msgid "vector operation will be expanded piecewise"
 msgstr "vektoroperationen kommer expanderas bitvis"
 
-#: tree-vect-generic.c:290
+#: tree-vect-generic.c:286
 #, gcc-internal-format
 msgid "vector operation will be expanded in parallel"
 msgstr "vektoroperationen kommer expanderas parallellt"
 
-#: tree-vect-generic.c:341
+#: tree-vect-generic.c:337
 #, gcc-internal-format
 msgid "vector operation will be expanded with a single scalar operation"
 msgstr "vektoroperationen kommer expanderas med en ensam skalär operation"
 
-#: tree-vect-generic.c:941
+#: tree-vect-generic.c:937
 #, gcc-internal-format
 msgid "vector condition will be expanded piecewise"
 msgstr "vektorvillkor kommer expanderas bitvis"
 
-#: tree-vect-generic.c:1373
+#: tree-vect-generic.c:1369
 #, gcc-internal-format
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr "vektorblandningsoperationen kommer expanderas bitvis"
@@ -23208,27 +23229,27 @@
 msgid "vectorization did not happen for a simd loop"
 msgstr "vektorisering hände inte för en simd-slinga"
 
-#: tree-vrp.c:4930 tree-vrp.c:4974
+#: tree-vrp.c:4931 tree-vrp.c:4975
 #, gcc-internal-format
 msgid "array subscript %E is above array bounds of %qT"
 msgstr "vektorindex %E är ovanför vektorgränsen för %qT"
 
-#: tree-vrp.c:4956
+#: tree-vrp.c:4957
 #, gcc-internal-format
 msgid "array subscript [%E, %E] is outside array bounds of %qT"
 msgstr "vektorindexen [%E, %E] är utanför vektorgränserna för %qT"
 
-#: tree-vrp.c:4988
+#: tree-vrp.c:4989
 #, gcc-internal-format
 msgid "array subscript %E is below array bounds of %qT"
 msgstr "vektorindex %E är under vektorgränsen för %qT"
 
-#: tree-vrp.c:5046
+#: tree-vrp.c:5047
 #, gcc-internal-format
 msgid "array subscript %wi is below array bounds of %qT"
 msgstr "vektorindex %wi är under vektorgränsen för %qT"
 
-#: tree-vrp.c:5060
+#: tree-vrp.c:5061
 #, gcc-internal-format
 msgid "array subscript %wu is above array bounds of %qT"
 msgstr "vektorindex %wu är ovanför vektorgränsen för %qT"
@@ -23243,92 +23264,92 @@
 msgid "side-effects element in no-side-effects CONSTRUCTOR"
 msgstr "sidoeffektselement i icke sidoeffekts-CONSTRUCTOR"
 
-#: tree.c:7852
+#: tree.c:7856
 #, gcc-internal-format
 msgid "arrays of functions are not meaningful"
 msgstr "vektorer av funktioner är inte meningsfulla"
 
-#: tree.c:8019
+#: tree.c:8023
 #, gcc-internal-format
 msgid "function return type cannot be function"
 msgstr "funktionsreturtyp kan inte vara funktion"
 
-#: tree.c:9327 tree.c:9412 tree.c:9473
+#: tree.c:9331 tree.c:9416 tree.c:9477
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: %s, have %s in %s, at %s:%d"
 msgstr "trädkontroll: %s, har %s i %s, vid %s:%d"
 
-#: tree.c:9364
+#: tree.c:9368
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected none of %s, have %s in %s, at %s:%d"
 msgstr "trädkontroll: förväntade ingen av %s, har %s i %s, vid %s:%d"
 
-#: tree.c:9377
+#: tree.c:9381
 #, gcc-internal-format
 msgid "tree check: expected class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "trädkontroll: förväntade klass %qs, har %qs (%s) i %s, vid %s:%d"
 
-#: tree.c:9426
+#: tree.c:9430
 #, gcc-internal-format
 msgid "tree check: did not expect class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "trädkontroll: klass %qs förväntades inte, har %qs (%s) i %s, vid %s:%d"
 
-#: tree.c:9439
+#: tree.c:9443
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected omp_clause %s, have %s in %s, at %s:%d"
 msgstr "trädkontroll: omp_clause %s förväntades, har %s i %s, vid %s:%d"
 
-#: tree.c:9499
+#: tree.c:9503
 #, gcc-internal-format
 msgid "tree check: expected tree that contains %qs structure, have %qs in %s, at %s:%d"
 msgstr "trädkontroll: förväntade träd som innehåller posten %qs, har %qs i %s, vid %s:%d"
 
-#: tree.c:9513
+#: tree.c:9517
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_int_cst with %d elts in %s, at %s:%d"
 msgstr "trädkontroll: använde element %d av tree_int_cst med %d element i %s, vid %s:%d"
 
-#: tree.c:9525
+#: tree.c:9529
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_vec with %d elts in %s, at %s:%d"
 msgstr "trädkontroll: använde element %d av tree_vec med %d element i %s, vid %s:%d"
 
-#: tree.c:9538
+#: tree.c:9542
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of %s with %d operands in %s, at %s:%d"
 msgstr "trädkontroll: använde operand %d av %s med %d operander i %s, vid %s:%d"
 
-#: tree.c:9551
+#: tree.c:9555
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of omp_clause %s with %d operands in %s, at %s:%d"
 msgstr "trädkontroll: använde operand %d av omp_clause %s med %d operander i %s, vid %s:%d"
 
-#: tree.c:12446
+#: tree.c:12450
 #, gcc-internal-format
 msgid "%qD is deprecated: %s"
 msgstr "%qD bör undvikas: %s"
 
-#: tree.c:12449
+#: tree.c:12453
 #, gcc-internal-format
 msgid "%qD is deprecated"
 msgstr "%qD bör undvikas"
 
-#: tree.c:12473 tree.c:12495
+#: tree.c:12477 tree.c:12499
 #, gcc-internal-format
 msgid "%qE is deprecated: %s"
 msgstr "%qE bör undvikas: %s"
 
-#: tree.c:12476 tree.c:12498
+#: tree.c:12480 tree.c:12502
 #, gcc-internal-format
 msgid "%qE is deprecated"
 msgstr "%qE bör undvikas"
 
-#: tree.c:12482 tree.c:12503
+#: tree.c:12486 tree.c:12507
 #, gcc-internal-format, gfc-internal-format
 msgid "type is deprecated: %s"
 msgstr "typen bör undvikas: %s"
 
-#: tree.c:12485 tree.c:12506
+#: tree.c:12489 tree.c:12510
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr "typen bör undvikas"
@@ -23353,242 +23374,242 @@
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.c:13043
+#: tree.c:13047
 #, gcc-internal-format, gfc-internal-format
 msgid "type variant differs by %s"
 msgstr "typvarianter skiljer i %s"
 
-#: tree.c:13084
+#: tree.c:13088
 #, gcc-internal-format
 msgid "type variant has different TYPE_SIZE_UNIT"
 msgstr "typvariant har en annan TYPE_SIZE_UNIT"
 
-#: tree.c:13086
+#: tree.c:13090
 #, gcc-internal-format
 msgid "type variant's TYPE_SIZE_UNIT"
 msgstr "typvariantens TYPE_SIZE_UNIT"
 
-#: tree.c:13088
+#: tree.c:13092
 #, gcc-internal-format
 msgid "type's TYPE_SIZE_UNIT"
 msgstr "typens TYPE_SIZE_UNIT"
 
-#: tree.c:13108
+#: tree.c:13112
 #, gcc-internal-format
 msgid "type variant with TYPE_ALIAS_SET_KNOWN_P"
 msgstr "typvariant med TYPE_ALIAS_SET_KNOWN_P"
 
-#: tree.c:13121
+#: tree.c:13125
 #, gcc-internal-format
 msgid "type variant has different TYPE_VFIELD"
 msgstr "typvariant har en annan TYPE_VFIELD"
 
-#: tree.c:13157
+#: tree.c:13161
 #, gcc-internal-format
 msgid "type variant has different TYPE_BINFO"
 msgstr "typvariant har en annan TYPE_BINFO"
 
-#: tree.c:13159
+#: tree.c:13163
 #, gcc-internal-format
 msgid "type variant's TYPE_BINFO"
 msgstr "typvariantens TYPE_BINFO"
 
-#: tree.c:13161
+#: tree.c:13165
 #, gcc-internal-format
 msgid "type's TYPE_BINFO"
 msgstr "typens TYPE_BINFO"
 
-#: tree.c:13199
+#: tree.c:13203
 #, gcc-internal-format
 msgid "type variant has different TYPE_FIELDS"
 msgstr "typvariant har andra TYPE_FIELDS"
 
-#: tree.c:13201
+#: tree.c:13205
 #, gcc-internal-format
 msgid "first mismatch is field"
 msgstr "första som inte stämmer är fält"
 
-#: tree.c:13203
+#: tree.c:13207
 #, gcc-internal-format
 msgid "and field"
 msgstr "och fält"
 
-#: tree.c:13220
+#: tree.c:13224
 #, gcc-internal-format
 msgid "type variant has different TREE_TYPE"
 msgstr "typvariant har en annan TREE_TYPE"
 
-#: tree.c:13222 tree.c:13233
+#: tree.c:13226 tree.c:13237
 #, gcc-internal-format
 msgid "type variant's TREE_TYPE"
 msgstr "typvariantens TREE_TYPE"
 
-#: tree.c:13224 tree.c:13235
+#: tree.c:13228 tree.c:13239
 #, gcc-internal-format
 msgid "type's TREE_TYPE"
 msgstr "typens TREE_TYPE"
 
-#: tree.c:13231
+#: tree.c:13235
 #, gcc-internal-format
 msgid "type is not compatible with its variant"
 msgstr "typen är inte kompatibel med sin variant"
 
-#: tree.c:13534
+#: tree.c:13538
 #, gcc-internal-format
 msgid "Main variant is not defined"
 msgstr "Huvudvariant är inte definierad"
 
-#: tree.c:13539
+#: tree.c:13543
 #, gcc-internal-format
 msgid "TYPE_MAIN_VARIANT has different TYPE_MAIN_VARIANT"
 msgstr "TYPE_MAIN_VARIANT har en annan TYPE_MAIN_VARIANT"
 
-#: tree.c:13551
+#: tree.c:13555
 #, gcc-internal-format
 msgid "TYPE_CANONICAL has different TYPE_CANONICAL"
 msgstr "TYPE_CANONICAL har en annan TYPE_CANONICAL"
 
-#: tree.c:13569
+#: tree.c:13573
 #, gcc-internal-format
 msgid "TYPE_CANONICAL is not compatible"
 msgstr "TYPE_CANONICAL är inte kompatibla"
 
-#: tree.c:13577
+#: tree.c:13581
 #, gcc-internal-format
 msgid "TYPE_MODE of TYPE_CANONICAL is not compatible"
 msgstr "TYPE_MODE av TYPE_CANONICAL är inte kompatibla"
 
-#: tree.c:13583
+#: tree.c:13587
 #, gcc-internal-format
 msgid "TYPE_CANONICAL of main variant is not main variant"
 msgstr "TYPE_CANONICAL av huvudvarianten är inte en huvudvariant"
 
-#: tree.c:13599
+#: tree.c:13603
 #, gcc-internal-format
 msgid "TYPE_VFIELD is not FIELD_DECL nor TREE_LIST"
 msgstr "TYPE_VFIELD är varken FIELD_DECL eller TREE_LIST"
 
-#: tree.c:13609
+#: tree.c:13613
 #, gcc-internal-format
 msgid "TYPE_NEXT_PTR_TO is not POINTER_TYPE"
 msgstr "TYPE_NEXT_PTR_TO är inte POINTER_TYPE"
 
-#: tree.c:13619
+#: tree.c:13623
 #, gcc-internal-format
 msgid "TYPE_NEXT_REF_TO is not REFERENCE_TYPE"
 msgstr "TYPE_NEXT_REF_TO är inte REFERENCE_TYPE"
 
-#: tree.c:13640
+#: tree.c:13644
 #, gcc-internal-format
 msgid "TYPE_BINFO is not TREE_BINFO"
 msgstr "TYPE_BINFO är inte TREE_BINFO"
 
-#: tree.c:13646
+#: tree.c:13650
 #, gcc-internal-format
 msgid "TYPE_BINFO type is not TYPE_MAIN_VARIANT"
 msgstr "TYPE_BINFO-typ är inte TYPE_MAIN_VARIANT"
 
-#: tree.c:13657
+#: tree.c:13661
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not record nor union"
 msgstr "TYPE_METHOD_BASETYPE är inte en post eller union"
 
-#: tree.c:13668
+#: tree.c:13672
 #, gcc-internal-format
 msgid "TYPE_OFFSET_BASETYPE is not record nor union"
 msgstr "TYPE_OFFSET_BASETYPE är inte en post eller union"
 
-#: tree.c:13686
+#: tree.c:13690
 #, gcc-internal-format
 msgid "TYPE_ARRAY_MAX_SIZE not INTEGER_CST"
 msgstr "TYPE_ARRAY_MAX_SIZE inte INTEGER_CST"
 
-#: tree.c:13693
+#: tree.c:13697
 #, gcc-internal-format
 msgid "TYPE_MAX_VALUE_RAW non-NULL"
 msgstr "TYPE_MAX_VALUE_RAW icke-NULL"
 
-#: tree.c:13700
+#: tree.c:13704
 #, gcc-internal-format
 msgid "TYPE_LANG_SLOT_1 (binfo) field is non-NULL"
 msgstr "TYPE_LANG_SLOT_1 (binfo) fält är icke-NULL"
 
-#: tree.c:13716
+#: tree.c:13720
 #, gcc-internal-format
 msgid "Enum value is not CONST_DECL or INTEGER_CST"
 msgstr "Enum-värde är inte CONST_DECL eller INTEGER_CST"
 
-#: tree.c:13724
+#: tree.c:13728
 #, gcc-internal-format
 msgid "Enum value type is not INTEGER_TYPE nor convertible to the enum"
 msgstr "Enum-värdetyp är varken INTEGER_TYPE eller konvertibel till enum"
 
-#: tree.c:13731
+#: tree.c:13735
 #, gcc-internal-format
 msgid "Enum value name is not IDENTIFIER_NODE"
 msgstr "Enum-värdenamn är inte IDENTIFIER_NODE"
 
-#: tree.c:13741
+#: tree.c:13745
 #, gcc-internal-format
 msgid "Array TYPE_DOMAIN is not integer type"
 msgstr "Vektorn TYPE_DOMAIN är inte av heltalstyp"
 
-#: tree.c:13750
+#: tree.c:13754
 #, gcc-internal-format
 msgid "TYPE_FIELDS defined in incomplete type"
 msgstr "TYPE_FIELDS definierad i ofullständig typ"
 
-#: tree.c:13772
+#: tree.c:13776
 #, gcc-internal-format
 msgid "Wrong tree in TYPE_FIELDS list"
 msgstr "Fel träd i TYPE_FIELDS-lista"
 
-#: tree.c:13787
+#: tree.c:13791
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is %i while TYPE_CACHED_VALUES is %p"
 msgstr "TYPE_CACHED_VALUES_P är %i medan TYPE_CACHED_VALUES är %p"
 
-#: tree.c:13793
+#: tree.c:13797
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES is not TREE_VEC"
 msgstr "TYPE_CACHED_VALUES är inte TREE_VEC"
 
-#: tree.c:13806
+#: tree.c:13810
 #, gcc-internal-format
 msgid "wrong TYPE_CACHED_VALUES entry"
 msgstr "fel TYPE_CACHED_VALUES-post"
 
-#: tree.c:13819
+#: tree.c:13823
 #, gcc-internal-format
 msgid "TREE_PURPOSE is non-NULL in TYPE_ARG_TYPES list"
 msgstr "TREE_PURPOSE är icke-NULL i TYPE_ARG_TYPES-lista"
 
-#: tree.c:13825
+#: tree.c:13829
 #, gcc-internal-format
 msgid "Wrong entry in TYPE_ARG_TYPES list"
 msgstr "Fel post i TYPE_ARG_TYPES-lista"
 
-#: tree.c:13832
+#: tree.c:13836
 #, gcc-internal-format
 msgid "TYPE_VALUES_RAW field is non-NULL"
 msgstr "TYPE_VALUES_RAW-fält är icke-NULL"
 
-#: tree.c:13844
+#: tree.c:13848
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is set while it should not"
 msgstr "TYPE_CACHED_VALUES_P är satt när det inte skulle vara det"
 
-#: tree.c:13850
+#: tree.c:13854
 #, gcc-internal-format
 msgid "TYPE_STRING_FLAG is set on wrong type code"
 msgstr "TYPE_STRING_FLAG är satt på fel typkod"
 
-#: tree.c:13860
+#: tree.c:13864
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not main variant"
 msgstr "TYPE_METHOD_BASETYPE är inte en huvudvariant"
 
-#: tree.c:13867
+#: tree.c:13871
 #, gcc-internal-format
 msgid "verify_type failed"
 msgstr "verify_type misslyckades"
@@ -23613,182 +23634,182 @@
 msgid "corrupted value profile: %s profile counter (%d out of %d) inconsistent with basic-block count (%d)"
 msgstr "trasig värdeprofil: profileringsräknaren %s (%d av %d) stämmer inte med GB-antal (%d)"
 
-#: var-tracking.c:7166
+#: var-tracking.c:7184
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded with -fvar-tracking-assignments, retrying without"
 msgstr "storleksgräns på variabelspårning överskriden med -fvar-tracking-assignments, försöker igen utan"
 
-#: var-tracking.c:7170
+#: var-tracking.c:7188
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded"
 msgstr "storleksgräns på variabelspårning överskriden"
 
-#: varasm.c:326
+#: varasm.c:337
 #, gcc-internal-format
 msgid "%+qD causes a section type conflict with %qD"
 msgstr "%+qD orsakar en sektionstypkonflikt med %qD"
 
-#: varasm.c:329
+#: varasm.c:340
 #, gcc-internal-format
 msgid "section type conflict with %qD"
 msgstr "sektionstypen står i konflikt med %qD"
 
-#: varasm.c:334
+#: varasm.c:345
 #, gcc-internal-format
 msgid "%+qD causes a section type conflict"
 msgstr "%+qD orsakar en sektionstypkonflikt"
 
-#: varasm.c:336
+#: varasm.c:347
 #, gcc-internal-format
 msgid "section type conflict"
 msgstr "sektionstypskonflikt"
 
-#: varasm.c:1019
+#: varasm.c:1030
 #, gcc-internal-format
 msgid "alignment of %q+D is greater than maximum object file alignment %d"
 msgstr "justeringen av %q+D är större än den objektfilers maximala justering %d"
 
-#: varasm.c:1172
+#: varasm.c:1183
 #, gcc-internal-format
 msgid "only zero initializers are allowed in section %qs"
 msgstr "endast nollinitierare är tillåtna i sektionen %qs"
 
-#: varasm.c:1378 varasm.c:1387
+#: varasm.c:1389 varasm.c:1398
 #, gcc-internal-format
 msgid "register name not specified for %q+D"
 msgstr "inget registernamn angivet för %q+D"
 
-#: varasm.c:1389
+#: varasm.c:1400
 #, gcc-internal-format
 msgid "invalid register name for %q+D"
 msgstr "ogiltig registernamn för %q+D"
 
-#: varasm.c:1391
+#: varasm.c:1402
 #, gcc-internal-format
 msgid "data type of %q+D isn%'t suitable for a register"
 msgstr "datatyp %q+D passar inte för ett register"
 
-#: varasm.c:1394
+#: varasm.c:1405
 #, gcc-internal-format
 msgid "the register specified for %q+D cannot be accessed by the current target"
 msgstr "registret angivet för %q+D kan inte nås av det aktuella målet"
 
-#: varasm.c:1397
+#: varasm.c:1408
 #, gcc-internal-format
 msgid "the register specified for %q+D is not general enough to be used as a register variable"
 msgstr "registret angivet för %q+D är inte tillräckligt generellt för att användas som en registervariabel"
 
-#: varasm.c:1400
+#: varasm.c:1411
 #, gcc-internal-format
 msgid "register specified for %q+D isn%'t suitable for data type"
 msgstr "registret angivet för %q+D passar inte för datatypen"
 
-#: varasm.c:1410
+#: varasm.c:1421
 #, gcc-internal-format
 msgid "global register variable has initial value"
 msgstr "global registervariabel har startvärde"
 
-#: varasm.c:1414
+#: varasm.c:1425
 #, gcc-internal-format
 msgid "optimization may eliminate reads and/or writes to register variables"
 msgstr "optimering kan eliminera läsningar och/eller skrivningar till registervariabler"
 
-#: varasm.c:1460
+#: varasm.c:1471
 #, gcc-internal-format
 msgid "register name given for non-register variable %q+D"
 msgstr "registernamn angivet icke-registervariabel %q+D"
 
-#: varasm.c:1870
+#: varasm.c:1881
 #, gcc-internal-format
 msgid "Patchable function entry > size"
 msgstr "Patchbar funktionsingång > storlek"
 
-#: varasm.c:2069
+#: varasm.c:2080
 #, gcc-internal-format
 msgid "thread-local COMMON data not implemented"
 msgstr "trådlokal COMMON-data är inte implementerat"
 
-#: varasm.c:2102
+#: varasm.c:2113
 #, gcc-internal-format
 msgid "requested alignment for %q+D is greater than implemented alignment of %wu"
 msgstr "begärd justering för %q+D är större än implementerad justering av %wu"
 
-#: varasm.c:2205 c/c-decl.c:5027 c/c-parser.c:1534
+#: varasm.c:2216 c/c-decl.c:5027 c/c-parser.c:1534
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t known"
 msgstr "lagringsstorlek på %q+D är okänd"
 
-#: varasm.c:4910
+#: varasm.c:4921
 #, gcc-internal-format
 msgid "initializer for integer/fixed-point value is too complicated"
 msgstr "initierare för heltals-/fixdecimalvärde är för komplicerad"
 
-#: varasm.c:4915
+#: varasm.c:4926
 #, gcc-internal-format
 msgid "initializer for floating value is not a floating constant"
 msgstr "initierare för flyttalsvärde är inte en flyttalskonstant"
 
-#: varasm.c:5227
+#: varasm.c:5238
 #, gcc-internal-format
 msgid "invalid initial value for member %qE"
 msgstr "ogiltigt startvärde för medlem %qE"
 
-#: varasm.c:5487
+#: varasm.c:5498
 #, gcc-internal-format
 msgid "%+qD declared weak after being used"
 msgstr "%+qD deklarerad svag efter att ha använts"
 
-#: varasm.c:5539
+#: varasm.c:5550
 #, gcc-internal-format
 msgid "weak declaration of %q+D being applied to a already existing, static definition"
 msgstr "svag deklaration av %q+D tillämpad på en redan befintlig, statisk definition"
 
-#: varasm.c:5575
+#: varasm.c:5586
 #, gcc-internal-format
 msgid "weak declaration of %q+D must be public"
 msgstr "svagdeklaration av %q+D måste vara publik"
 
-#: varasm.c:5579
+#: varasm.c:5590
 #, gcc-internal-format
 msgid "weak declaration of %q+D not supported"
 msgstr "svagdeklaration av %q+D stödjs inte"
 
-#: varasm.c:5608 varasm.c:5912
+#: varasm.c:5619 varasm.c:5926
 #, gcc-internal-format
 msgid "only weak aliases are supported in this configuration"
 msgstr "bara svaga alias stödjs i denna konfiguration"
 
-#: varasm.c:5802
+#: varasm.c:5813
 #, gcc-internal-format
 msgid "weakref is not supported in this configuration"
 msgstr "weakref stödjs inte i denna konfiguration"
 
-#: varasm.c:5834
+#: varasm.c:5846
 #, gcc-internal-format
 msgid "ifunc is not supported on this target"
 msgstr "ifunc stödjs inte på denna målarkitektur"
 
-#: varasm.c:5892
+#: varasm.c:5904
 #, gcc-internal-format
 msgid "weakref %q+D ultimately targets itself"
 msgstr "weakref %q+D är ytterst sitt eget mål"
 
-#: varasm.c:5894
+#: varasm.c:5906
 #, gcc-internal-format
 msgid "weakref %q+D must have static linkage"
 msgstr "weakref %q+D måste ha statisk länkklass"
 
-#: varasm.c:5901
+#: varasm.c:5913
 #, gcc-internal-format
 msgid "alias definitions not supported in this configuration"
 msgstr "aliasdefinitioner stödjs inte i denna konfiguration"
 
-#: varasm.c:5909
+#: varasm.c:5923
 #, gcc-internal-format
 msgid "ifunc is not supported in this configuration"
 msgstr "ifunc stödjs inte i denna konfiguration"
 
-#: varasm.c:6127 config/sol2.c:159 config/i386/winnt.c:265
+#: varasm.c:6141 config/sol2.c:159 config/i386/winnt.c:265
 #, gcc-internal-format
 msgid "visibility attribute not supported in this configuration; ignored"
 msgstr "synlighetsattribut stödjs inte för denna konfiguration, ignoreras"
@@ -23864,466 +23885,471 @@
 msgid "bytecode stream: tag %s is not in the expected range [%s, %s]"
 msgstr "bytekodström: taggen %s ligger inte i det förväntade intervallet [%s, %s]"
 
-#: c-family/c-attribs.c:529
+#: c-family/c-attribs.c:524
 #, gcc-internal-format
+msgid "%qE attribute ignored for type %qT"
+msgstr "attributet %qE ignorerat för typen %qT"
+
+#: c-family/c-attribs.c:536
+#, gcc-internal-format
 msgid "%qE attribute ignored for field of type %qT"
 msgstr "attributet %qE ignorerat för fält av typen %qT"
 
-#: c-family/c-attribs.c:696
+#: c-family/c-attribs.c:706
 #, gcc-internal-format
 msgid "no_sanitize argument not a string"
 msgstr "argument till no_sanitize är inte en sträng"
 
-#: c-family/c-attribs.c:826 ada/gcc-interface/utils.c:6235
+#: c-family/c-attribs.c:837 ada/gcc-interface/utils.c:6240
 #, gcc-internal-format
 msgid "%qE attribute ignored due to conflict with attribute %qs"
 msgstr "attributet %qE ignoreras eftersom det står i konflikt med attributet %qs"
 
-#: c-family/c-attribs.c:875
+#: c-family/c-attribs.c:886
 #, gcc-internal-format
 msgid "%qE attribute ignored. Use -fcf-protection option to enable it"
 msgstr "attributet %qE ignorerat.  Använd flaggan -fcf-protection för att aktivera det"
 
-#: c-family/c-attribs.c:914 c-family/c-attribs.c:920 c-family/c-attribs.c:3388
-#: c-family/c-attribs.c:3423 c-family/c-attribs.c:3429
+#: c-family/c-attribs.c:925 c-family/c-attribs.c:931 c-family/c-attribs.c:3399
+#: c-family/c-attribs.c:3434 c-family/c-attribs.c:3440
 #, gcc-internal-format
 msgid "%qE attribute ignored due to conflict with %qs attribute"
 msgstr "attributet %qE ignoreras eftersom det står i konflikt med attributet %qs"
 
-#: c-family/c-attribs.c:976 brig/brig-lang.c:482 lto/lto-lang.c:288
+#: c-family/c-attribs.c:987 brig/brig-lang.c:482 lto/lto-lang.c:288
 #, gcc-internal-format
 msgid "%qE attribute has no effect on unit local functions"
 msgstr "attributet %qE har ingen effekt på enhetslokala funktioner"
 
-#: c-family/c-attribs.c:1130
+#: c-family/c-attribs.c:1141
 #, gcc-internal-format
 msgid "%qE attribute have effect only on public objects"
 msgstr "attributet %qE har bara effekt på publika objekt"
 
-#: c-family/c-attribs.c:1159
+#: c-family/c-attribs.c:1170
 #, gcc-internal-format
 msgid "%qE attribute only affects top level objects"
 msgstr "attributet %qE påverkar bara toppnivåobjekt"
 
-#: c-family/c-attribs.c:1198 c-family/c-attribs.c:2682
+#: c-family/c-attribs.c:1209 c-family/c-attribs.c:2693
 #, gcc-internal-format
 msgid "%qE attribute on function returning %<void%>"
 msgstr "attributet %qE på en funktion som returnerar %<void%>"
 
-#: c-family/c-attribs.c:1221 c-family/c-pragma.c:419
+#: c-family/c-attribs.c:1232 c-family/c-pragma.c:419
 #, gcc-internal-format
 msgid "scalar_storage_order is not supported because endianness is not uniform"
 msgstr "scalar_storage_order stödjs inte för att byteordningen inte är enhetlig"
 
-#: c-family/c-attribs.c:1238
+#: c-family/c-attribs.c:1249
 #, gcc-internal-format
 msgid "scalar_storage_order argument must be one of \"big-endian\" or \"little-endian\""
 msgstr "scalar_storage_order-argument måste vara ett av ”big-endian” eller ”little-endian”"
 
-#: c-family/c-attribs.c:1334
+#: c-family/c-attribs.c:1345
 #, gcc-internal-format
 msgid "destructor priorities are not supported"
 msgstr "destruerarprioriteter stödjs ej"
 
-#: c-family/c-attribs.c:1336
+#: c-family/c-attribs.c:1347
 #, gcc-internal-format
 msgid "constructor priorities are not supported"
 msgstr "konstruerarprioriteter stödjs ej"
 
-#: c-family/c-attribs.c:1358
+#: c-family/c-attribs.c:1369
 #, gcc-internal-format, gfc-internal-format
 msgid "destructor priorities from 0 to %d are reserved for the implementation"
 msgstr "destruerarprioriteter från 0 till %d är reserverade för implementationen"
 
-#: c-family/c-attribs.c:1363
+#: c-family/c-attribs.c:1374
 #, gcc-internal-format, gfc-internal-format
 msgid "constructor priorities from 0 to %d are reserved for the implementation"
 msgstr "konstruerarprioriteter från 0 till %d är reserverade för implementationen"
 
-#: c-family/c-attribs.c:1371
+#: c-family/c-attribs.c:1382
 #, gcc-internal-format, gfc-internal-format
 msgid "destructor priorities must be integers from 0 to %d inclusive"
 msgstr "destruerarprioriteter måste vara heltal från 0 till och med %d"
 
-#: c-family/c-attribs.c:1374
+#: c-family/c-attribs.c:1385
 #, gcc-internal-format, gfc-internal-format
 msgid "constructor priorities must be integers from 0 to %d inclusive"
 msgstr "konstruerarprioriteter måste vara heltal från 0 till och med %d"
 
-#: c-family/c-attribs.c:1527
+#: c-family/c-attribs.c:1538
 #, gcc-internal-format
 msgid "unknown machine mode %qE"
 msgstr "okänt maskinläge %qE"
 
-#: c-family/c-attribs.c:1557
+#: c-family/c-attribs.c:1568
 #, gcc-internal-format
 msgid "specifying vector types with __attribute__ ((mode)) is deprecated"
 msgstr "att ange vektortyper med __attribute__ ((sätt)) bör undvikas"
 
-#: c-family/c-attribs.c:1560
+#: c-family/c-attribs.c:1571
 #, gcc-internal-format
 msgid "use __attribute__ ((vector_size)) instead"
 msgstr "använd __attribute__ ((vector_size)) istället"
 
-#: c-family/c-attribs.c:1569
+#: c-family/c-attribs.c:1580
 #, gcc-internal-format
 msgid "unable to emulate %qs"
 msgstr "kan inte emulera %qs"
 
-#: c-family/c-attribs.c:1582
+#: c-family/c-attribs.c:1593
 #, gcc-internal-format
 msgid "invalid pointer mode %qs"
 msgstr "ogiltigt pekarläge %qs"
 
-#: c-family/c-attribs.c:1599
+#: c-family/c-attribs.c:1610
 #, gcc-internal-format
 msgid "signedness of type and machine mode %qs don%'t match"
 msgstr "tecken på typ och maskinläge %qs passar inte ihop"
 
-#: c-family/c-attribs.c:1610
+#: c-family/c-attribs.c:1621
 #, gcc-internal-format
 msgid "no data type for mode %qs"
 msgstr "ingen datatyp för läge %qs"
 
-#: c-family/c-attribs.c:1620
+#: c-family/c-attribs.c:1631
 #, gcc-internal-format
 msgid "cannot use mode %qs for enumeral types"
 msgstr "kan inte använda läge %qs för uppräkningstyper"
 
-#: c-family/c-attribs.c:1647
+#: c-family/c-attribs.c:1658
 #, gcc-internal-format
 msgid "mode %qs applied to inappropriate type"
 msgstr "läge %qs applicerat på olämplig typ"
 
-#: c-family/c-attribs.c:1669
+#: c-family/c-attribs.c:1680
 #, gcc-internal-format
 msgid "section attributes are not supported for this target"
 msgstr "attributet ”section” stödjs inte för denna målarkitektur"
 
-#: c-family/c-attribs.c:1675
+#: c-family/c-attribs.c:1686
 #, gcc-internal-format
 msgid "section attribute not allowed for %q+D"
 msgstr "attributet ”section” är inte tillåten för %q+D"
 
-#: c-family/c-attribs.c:1681
+#: c-family/c-attribs.c:1692
 #, gcc-internal-format
 msgid "section attribute argument not a string constant"
 msgstr "argument till sektionsattributet är inte en strängkonstant"
 
-#: c-family/c-attribs.c:1690
+#: c-family/c-attribs.c:1701
 #, gcc-internal-format
 msgid "section attribute cannot be specified for local variables"
 msgstr "attributet ”section” kan inte anges för lokala variabler"
 
-#: c-family/c-attribs.c:1700 config/bfin/bfin.c:4806 config/bfin/bfin.c:4857
+#: c-family/c-attribs.c:1711 config/bfin/bfin.c:4806 config/bfin/bfin.c:4857
 #: config/bfin/bfin.c:4883 config/bfin/bfin.c:4896
 #, gcc-internal-format
 msgid "section of %q+D conflicts with previous declaration"
 msgstr "sektion %q+D står i konflikt med tidigare deklaration"
 
-#: c-family/c-attribs.c:1708
+#: c-family/c-attribs.c:1719
 #, gcc-internal-format
 msgid "section of %q+D cannot be overridden"
 msgstr "sektion i %q+D kan inte åsidosättas"
 
-#: c-family/c-attribs.c:1773
+#: c-family/c-attribs.c:1784
 #, gcc-internal-format, gfc-internal-format
 msgid "requested alignment %d is larger than %d"
 msgstr "begärd minnesjustering %d är större än %d"
 
-#: c-family/c-attribs.c:1866
+#: c-family/c-attribs.c:1877
 #, gcc-internal-format
 msgid "alignment may not be specified for %q+D"
 msgstr "minnesjustering kan inte anges för %q+D"
 
-#: c-family/c-attribs.c:1886
+#: c-family/c-attribs.c:1897
 #, gcc-internal-format
 msgid "ignoring attribute %<%E (%u)%> because it conflicts with attribute %<%E (%u)%>"
 msgstr "ignorerar attributet %<%E (%u)%> för att det står i konflikt med attributet %<%E (%u)%>"
 
 #. Do not error out for attribute warn_if_not_aligned.
-#: c-family/c-attribs.c:1891 c-family/c-attribs.c:1920
+#: c-family/c-attribs.c:1902 c-family/c-attribs.c:1931
 #, gcc-internal-format
 msgid "alignment for %q+D must be at least %d"
 msgstr "justering för %q+D måste vara åtminstone %d"
 
-#: c-family/c-attribs.c:1916
+#: c-family/c-attribs.c:1927
 #, gcc-internal-format
 msgid "alignment for %q+D was previously specified as %d and may not be decreased"
 msgstr "justering för %q+D angavs tidigare som %d och får inte minska"
 
-#: c-family/c-attribs.c:1943
+#: c-family/c-attribs.c:1954
 #, gcc-internal-format
 msgid "%<warn_if_not_aligned%> may not be specified for %q+D"
 msgstr "%<warn_if_not_aligned%> kan inte anges för %q+D"
 
-#: c-family/c-attribs.c:1986
+#: c-family/c-attribs.c:1997
 #, gcc-internal-format
 msgid "inline function %q+D declared weak"
 msgstr "inline-funktionen %q+D deklarerad svag"
 
-#: c-family/c-attribs.c:1991
+#: c-family/c-attribs.c:2002
 #, gcc-internal-format
 msgid "indirect function %q+D cannot be declared weak"
 msgstr "indirekt funktion %q+D kan inte deklareras svag"
 
-#: c-family/c-attribs.c:2015
+#: c-family/c-attribs.c:2026
 #, gcc-internal-format
 msgid "%qE attribute is only applicable on functions"
 msgstr "attributet %qE är bara tillämpligt på funktioner"
 
-#: c-family/c-attribs.c:2046
+#: c-family/c-attribs.c:2057
 #, gcc-internal-format
 msgid "%q+D defined both normally and as %qE attribute"
 msgstr "%q+D är definierad både normalt och som ett attribut %qE"
 
-#: c-family/c-attribs.c:2054
+#: c-family/c-attribs.c:2065
 #, gcc-internal-format
 msgid "weak %q+D cannot be defined %qE"
 msgstr "svag %q+D kan inte definieras %qE"
 
-#: c-family/c-attribs.c:2071 c-family/c-attribs.c:2582
+#: c-family/c-attribs.c:2082 c-family/c-attribs.c:2593
 #, gcc-internal-format
 msgid "attribute %qE argument not a string"
 msgstr "argument till attribut %qE är inte en sträng"
 
-#: c-family/c-attribs.c:2106
+#: c-family/c-attribs.c:2117
 #, gcc-internal-format
 msgid "%+qD declared alias after being used"
 msgstr "%+qD deklarerad som alias efter att ha använts"
 
-#: c-family/c-attribs.c:2108
+#: c-family/c-attribs.c:2119
 #, gcc-internal-format
 msgid "%+qD declared ifunc after being used"
 msgstr "%+qD deklarerad ifunc efter att ha använts"
 
-#: c-family/c-attribs.c:2159
+#: c-family/c-attribs.c:2170
 #, gcc-internal-format
 msgid "indirect function %q+D cannot be declared weakref"
 msgstr "indirekt funktion %q+D kan inte deklareras weakref"
 
-#: c-family/c-attribs.c:2181
+#: c-family/c-attribs.c:2192
 #, gcc-internal-format
 msgid "weakref attribute must appear before alias attribute"
 msgstr "attributet weakref måste vara före attributet alias"
 
-#: c-family/c-attribs.c:2193
+#: c-family/c-attribs.c:2204
 #, gcc-internal-format
 msgid "%+qD declared weakref after being used"
 msgstr "%+qD deklarerad weakref efter att ha använts"
 
-#: c-family/c-attribs.c:2217
+#: c-family/c-attribs.c:2228
 #, gcc-internal-format
 msgid "%qE attribute ignored on non-class types"
 msgstr "attributet %qE ignorerat typer som inte är klasser"
 
-#: c-family/c-attribs.c:2223
+#: c-family/c-attribs.c:2234
 #, gcc-internal-format
 msgid "%qE attribute ignored because %qT is already defined"
 msgstr "attributet %qE ignorerat för att %qT redan är definierat"
 
-#: c-family/c-attribs.c:2236
+#: c-family/c-attribs.c:2247
 #, gcc-internal-format
 msgid "visibility argument not a string"
 msgstr "synlighetsargumentet är inte en sträng"
 
-#: c-family/c-attribs.c:2248
+#: c-family/c-attribs.c:2259
 #, gcc-internal-format
 msgid "%qE attribute ignored on types"
 msgstr "attributet %qE ignorerat för typer"
 
-#: c-family/c-attribs.c:2264
+#: c-family/c-attribs.c:2275
 #, gcc-internal-format
 msgid "visibility argument must be one of \"default\", \"hidden\", \"protected\" or \"internal\""
 msgstr "visibility-argument måste vara ett av ”default”, ”hidden”, ”protected” eller ”internal”"
 
-#: c-family/c-attribs.c:2275
+#: c-family/c-attribs.c:2286
 #, gcc-internal-format
 msgid "%qD redeclared with different visibility"
 msgstr "%qD omdeklarerad med annan synlighet"
 
-#: c-family/c-attribs.c:2278 c-family/c-attribs.c:2282
+#: c-family/c-attribs.c:2289 c-family/c-attribs.c:2293
 #, gcc-internal-format
 msgid "%qD was declared %qs which implies default visibility"
 msgstr "%qD deklarerades %qs vilket medför standardsynlighet"
 
-#: c-family/c-attribs.c:2320
+#: c-family/c-attribs.c:2331
 #, gcc-internal-format
 msgid "tls_model argument not a string"
 msgstr "tls_model-argument är inte en sträng"
 
-#: c-family/c-attribs.c:2333
+#: c-family/c-attribs.c:2344
 #, gcc-internal-format
 msgid "tls_model argument must be one of \"local-exec\", \"initial-exec\", \"local-dynamic\" or \"global-dynamic\""
 msgstr "tls_model-argument måste vara ett av ”local-exec”, ”initial-exec”, ”local-dynamic” eller ”global-dynamic”"
 
-#: c-family/c-attribs.c:2353 c-family/c-attribs.c:2656
-#: c-family/c-attribs.c:3497 config/m32c/m32c.c:2944
+#: c-family/c-attribs.c:2364 c-family/c-attribs.c:2667
+#: c-family/c-attribs.c:3508 config/m32c/m32c.c:2944
 #, gcc-internal-format
 msgid "%qE attribute applies only to functions"
 msgstr "attributet %qE är bara tillämpligt på funktioner"
 
-#: c-family/c-attribs.c:2417
+#: c-family/c-attribs.c:2428
 #, gcc-internal-format
 msgid "alloc_size parameter outside range"
 msgstr "alloc_size-parameter utanför giltigt intervall"
 
-#: c-family/c-attribs.c:2443
+#: c-family/c-attribs.c:2454
 #, gcc-internal-format
 msgid "alloc_align parameter outside range"
 msgstr "alloc_align-parameter utanför giltigt intervall"
 
-#: c-family/c-attribs.c:2467
+#: c-family/c-attribs.c:2478
 #, gcc-internal-format
 msgid "assume_aligned parameter not integer constant"
 msgstr "assume_aligned-parameter är inte en heltalskonstant"
 
-#: c-family/c-attribs.c:2595
+#: c-family/c-attribs.c:2606
 #, gcc-internal-format
 msgid "only %<inbranch%> and %<notinbranch%> flags are allowed for %<__simd__%> attribute"
 msgstr "endast %<inbranch%>- och %<notinbranch%>-flaggor är tillåtna för %<__simd__%>-attributet"
 
-#: c-family/c-attribs.c:2662 c-family/c-attribs.c:3503
+#: c-family/c-attribs.c:2673 c-family/c-attribs.c:3514
 #, gcc-internal-format
 msgid "can%'t set %qE attribute after definition"
 msgstr "kan inte sätta attributet %qE efter definitionen"
 
-#: c-family/c-attribs.c:2727
+#: c-family/c-attribs.c:2738
 #, gcc-internal-format
 msgid "%qE attribute duplicated"
 msgstr "attributet %qE dubblerat"
 
-#: c-family/c-attribs.c:2729
+#: c-family/c-attribs.c:2740
 #, gcc-internal-format
 msgid "%qE attribute follows %qE"
 msgstr "attributet %qE följer %qE"
 
-#: c-family/c-attribs.c:2828
+#: c-family/c-attribs.c:2839
 #, gcc-internal-format
 msgid "type was previously declared %qE"
 msgstr "typen var tidigare deklarerad %qE"
 
-#: c-family/c-attribs.c:2841 cp/class.c:4397
+#: c-family/c-attribs.c:2852 cp/class.c:4401
 #, gcc-internal-format
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
 msgstr "%<transaction_safe_dynamic%> kan endast anges för en virtuell funktion"
 
-#: c-family/c-attribs.c:2899
+#: c-family/c-attribs.c:2910
 #, gcc-internal-format
 msgid "%qE argument not an identifier"
 msgstr "argument till %qE är inte en identifierare"
 
-#: c-family/c-attribs.c:2910
+#: c-family/c-attribs.c:2921
 #, gcc-internal-format
 msgid "%qD is not compatible with %qD"
 msgstr "%qD är inte kompatibel med %qD"
 
-#: c-family/c-attribs.c:2913
+#: c-family/c-attribs.c:2924
 #, gcc-internal-format
 msgid "%qE argument is not a function"
 msgstr "argumentet %qE är inte en funktion"
 
-#: c-family/c-attribs.c:2961
+#: c-family/c-attribs.c:2972
 #, gcc-internal-format
 msgid "deprecated message is not a string"
 msgstr "deprecated-meddelande är inte en sträng"
 
-#: c-family/c-attribs.c:3002
+#: c-family/c-attribs.c:3013
 #, gcc-internal-format
 msgid "%qE attribute ignored for %qE"
 msgstr "attributet %qE ignorerat för %qE"
 
-#: c-family/c-attribs.c:3065
+#: c-family/c-attribs.c:3076
 #, gcc-internal-format
 msgid "invalid vector type for attribute %qE"
 msgstr "ogiltig vektortyp för attributet %qE"
 
-#: c-family/c-attribs.c:3071 ada/gcc-interface/utils.c:3896
+#: c-family/c-attribs.c:3082 ada/gcc-interface/utils.c:3899
 #, gcc-internal-format
 msgid "vector size not an integral multiple of component size"
 msgstr "vektorstorleken är inte en hel multipel av komponentstorleken"
 
-#: c-family/c-attribs.c:3077 ada/gcc-interface/utils.c:3903
+#: c-family/c-attribs.c:3088 ada/gcc-interface/utils.c:3906
 #, gcc-internal-format
 msgid "zero vector size"
 msgstr "vektorstorlek noll"
 
-#: c-family/c-attribs.c:3085
+#: c-family/c-attribs.c:3096
 #, gcc-internal-format
 msgid "number of components of the vector not a power of two"
 msgstr "antal komponenter i vektorn inte en tvåpotens"
 
-#: c-family/c-attribs.c:3118 ada/gcc-interface/utils.c:6092
+#: c-family/c-attribs.c:3129 ada/gcc-interface/utils.c:6098
 #, gcc-internal-format
 msgid "nonnull attribute without arguments on a non-prototype"
 msgstr "attributet nonnull utan argument på en icke-prototyp"
 
-#: c-family/c-attribs.c:3137 ada/gcc-interface/utils.c:6106
+#: c-family/c-attribs.c:3148 ada/gcc-interface/utils.c:6112
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument has invalid operand number (argument %lu)"
 msgstr "argument till nonnull har ett ogiltigt värde (argument %lu)"
 
-#: c-family/c-attribs.c:3159 ada/gcc-interface/utils.c:6128
+#: c-family/c-attribs.c:3170 ada/gcc-interface/utils.c:6134
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument with out-of-range operand number (argument %lu, operand %lu)"
 msgstr "nonnull-argument med felaktigt operandnummer (argument %lu, operand %lu)"
 
-#: c-family/c-attribs.c:3168 ada/gcc-interface/utils.c:6137
+#: c-family/c-attribs.c:3179 ada/gcc-interface/utils.c:6143
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument references non-pointer operand (argument %lu, operand %lu)"
 msgstr "nonnull-argument refererar icke-pekar-operand (argument %lu, operand %lu)"
 
-#: c-family/c-attribs.c:3208
+#: c-family/c-attribs.c:3219
 #, gcc-internal-format
 msgid "%qE attribute ignored on objects of type %qT"
 msgstr "attributet %qE ignorerat på objekt av typen %qT"
 
-#: c-family/c-attribs.c:3216
+#: c-family/c-attribs.c:3227
 #, gcc-internal-format
 msgid "%qE attribute does not apply to functions"
 msgstr "attributet %qE är inte tillämpligt på funktioner"
 
-#: c-family/c-attribs.c:3273
+#: c-family/c-attribs.c:3284
 #, gcc-internal-format
 msgid "cleanup argument not an identifier"
 msgstr "argumentet till cleanup är inte en identifierare"
 
-#: c-family/c-attribs.c:3280
+#: c-family/c-attribs.c:3291
 #, gcc-internal-format
 msgid "cleanup argument not a function"
 msgstr "argumentet till cleanup är inte en funktion"
 
-#: c-family/c-attribs.c:3317
+#: c-family/c-attribs.c:3328
 #, gcc-internal-format
 msgid "%qE attribute requires prototypes with named arguments"
 msgstr "attributet %qE kräver prototyper med namngivna argument"
 
-#: c-family/c-attribs.c:3325
+#: c-family/c-attribs.c:3336
 #, gcc-internal-format
 msgid "%qE attribute only applies to variadic functions"
 msgstr "attributet %qE är bara tillämplig på funktioner med variabelt antal argument"
 
-#: c-family/c-attribs.c:3341 ada/gcc-interface/utils.c:6179
+#: c-family/c-attribs.c:3352 ada/gcc-interface/utils.c:6185
 #, gcc-internal-format
 msgid "requested position is not an integer constant"
 msgstr "den begärda positionen är inte en heltalskonstant"
 
-#: c-family/c-attribs.c:3349 ada/gcc-interface/utils.c:6186
+#: c-family/c-attribs.c:3360 ada/gcc-interface/utils.c:6192
 #, gcc-internal-format
 msgid "requested position is less than zero"
 msgstr "begärd position är mindre än noll"
 
-#: c-family/c-attribs.c:3404
+#: c-family/c-attribs.c:3415
 #, gcc-internal-format
 msgid "empty string in attribute %<target%>"
 msgstr "tom sträng i attributet %<target%>"
 
-#: c-family/c-attribs.c:3520
+#: c-family/c-attribs.c:3531
 #, gcc-internal-format
 msgid "returns_nonnull attribute on a function not returning a pointer"
 msgstr "attributet returns_nonnull på en funktion som inte returnerar en pekare"
 
-#: c-family/c-attribs.c:3535
+#: c-family/c-attribs.c:3546
 #, gcc-internal-format
 msgid "%qE attribute is only valid on %<struct%> type"
 msgstr "attributet %qE är bara tillämpligt på %<struct%>-typer"
@@ -24368,12 +24394,12 @@
 msgid "__builtin_shuffle argument vector(s) inner type must have the same size as inner type of the mask"
 msgstr "__builtin_shuffle argumentvektorns inre typ måste ha samma storlek som den inre typen för masken"
 
-#: c-family/c-common.c:1262 c-family/c-warn.c:1194
+#: c-family/c-common.c:1262 c-family/c-warn.c:1202
 #, gcc-internal-format
 msgid "unsigned conversion from %qT to %qT changes value from %qE to %qE"
 msgstr "teckenlös konvertering från %qT till %qT ändrar värdet från %qE till %qE"
 
-#: c-family/c-common.c:1267 c-family/c-warn.c:1202
+#: c-family/c-common.c:1267 c-family/c-warn.c:1210
 #, gcc-internal-format
 msgid "unsigned conversion from %qT to %qT changes the value of %qE"
 msgstr "teckenlös konvertering från %qT till %qT ändrar värdet på %qE"
@@ -24503,7 +24529,7 @@
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "föreslår parenteser runt tilldelning som används som sanningsvärde"
 
-#: c-family/c-common.c:3518 c/c-decl.c:4325 c/c-decl.c:6430 c/c-typeck.c:14177
+#: c-family/c-common.c:3518 c/c-decl.c:4325 c/c-decl.c:6450 c/c-typeck.c:14182
 #, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr "ogiltigt användning av %<restrict%>"
@@ -24583,7 +24609,7 @@
 msgid "duplicate case value"
 msgstr "upprepat case-värde"
 
-#: c-family/c-common.c:4867 c-family/c-warn.c:2216
+#: c-family/c-common.c:4867 c-family/c-warn.c:2225
 #, gcc-internal-format
 msgid "previously used here"
 msgstr "tidigare använt här"
@@ -24628,193 +24654,193 @@
 msgid "missing sentinel in function call"
 msgstr "vaktpost saknas i funktionsanrop"
 
-#: c-family/c-common.c:5411
+#: c-family/c-common.c:5409
 #, gcc-internal-format, gfc-internal-format
 msgid "null argument where non-null required (argument %lu)"
 msgstr "noll-argument där icke-noll krävs (argument %lu)"
 
-#: c-family/c-common.c:5506 c-family/c-common.c:5553
+#: c-family/c-common.c:5504 c-family/c-common.c:5551
 #, gcc-internal-format
 msgid "bad option %qs to attribute %<optimize%>"
 msgstr "felaktig flagga %qs till attributet %<optimize%>"
 
-#: c-family/c-common.c:5509 c-family/c-common.c:5557
+#: c-family/c-common.c:5507 c-family/c-common.c:5555
 #, gcc-internal-format
 msgid "bad option %qs to pragma %<optimize%>"
 msgstr "felaktig flagga %qs till pragmat %<optimize%>"
 
-#: c-family/c-common.c:5589
+#: c-family/c-common.c:5587
 #, gcc-internal-format
 msgid "%<fallthrough%> attribute specified multiple times"
 msgstr "attributet %<fallthrough%> angivet flera gånger"
 
-#: c-family/c-common.c:5593
+#: c-family/c-common.c:5591
 #, gcc-internal-format
 msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr "attributet %<fallthrough%> angivet med en parameter"
 
-#: c-family/c-common.c:5733 c-family/c-common.c:6485 c-family/c-common.c:6558
+#: c-family/c-common.c:5731 c-family/c-common.c:6477 c-family/c-common.c:6550
 #: c/c-typeck.c:3555
 #, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr "för få argument till funktionen %qE"
 
-#: c-family/c-common.c:5738 c-family/c-common.c:6584 c/c-typeck.c:3284
+#: c-family/c-common.c:5736 c-family/c-common.c:6576 c/c-typeck.c:3284
 #, gcc-internal-format
 msgid "too many arguments to function %qE"
 msgstr "för många argument till funktionen %qE"
 
-#: c-family/c-common.c:5769
+#: c-family/c-common.c:5767
 #, gcc-internal-format
 msgid "third argument to function %qE must be a constant integer"
 msgstr "tredje argumentet till funktionen %qE måste vara ett konstant heltal"
 
-#: c-family/c-common.c:5794
+#: c-family/c-common.c:5792
 #, gcc-internal-format
 msgid "second argument to function %qE must be a constant integer power of 2 between %qi and %qu bits"
 msgstr "andra argumentet till funktionen %qE måste vara en konstant heltalsexponent till 2 mellan %qi och %qu bitar"
 
-#: c-family/c-common.c:5815 c-family/c-common.c:5859
+#: c-family/c-common.c:5813 c-family/c-common.c:5857
 #, gcc-internal-format
 msgid "non-floating-point argument in call to function %qE"
 msgstr "argument som inte är flyttal i anrop till funktionen %qE"
 
-#: c-family/c-common.c:5838
+#: c-family/c-common.c:5836
 #, gcc-internal-format
 msgid "non-floating-point arguments in call to function %qE"
 msgstr "argument som inte är flyttal i anrop till funktionen %qE"
 
-#: c-family/c-common.c:5852
+#: c-family/c-common.c:5850
 #, gcc-internal-format
 msgid "non-const integer argument %u in call to function %qE"
 msgstr "heltalsargument %u som inte är konstant i anrop till funktionen %qE"
 
-#: c-family/c-common.c:5872
+#: c-family/c-common.c:5870
 #, gcc-internal-format
 msgid "non-integer argument 3 in call to function %qE"
 msgstr "argument 3 som inte är ett heltal i anrop till funktionen %qE"
 
-#: c-family/c-common.c:5889 c-family/c-common.c:5925
+#: c-family/c-common.c:5887 c-family/c-common.c:5923
 #, gcc-internal-format
 msgid "argument %u in call to function %qE does not have integral type"
 msgstr "argument %u i anrop av funktionen %qE har inte heltalstyp"
 
-#: c-family/c-common.c:5896
+#: c-family/c-common.c:5894
 #, gcc-internal-format
 msgid "argument 3 in call to function %qE does not have pointer to integral type"
 msgstr "argument 3 i anropet av funktionen %qE har inte typen pekare till heltal"
 
-#: c-family/c-common.c:5902
+#: c-family/c-common.c:5900
 #, gcc-internal-format
 msgid "argument 3 in call to function %qE has pointer to enumerated type"
 msgstr "argument 3 i anropet av funktionen %qE har typen pekare till uppräkningstyp"
 
-#: c-family/c-common.c:5908
+#: c-family/c-common.c:5906
 #, gcc-internal-format
 msgid "argument 3 in call to function %qE has pointer to boolean type"
 msgstr "argument 3 i anropet av funktionen %qE har typen pekare till boolean"
 
-#: c-family/c-common.c:5931
+#: c-family/c-common.c:5929
 #, gcc-internal-format
 msgid "argument 3 in call to function %qE has enumerated type"
 msgstr "argument 3 i anrop av funktionen %qE har uppräkningstyp"
 
-#: c-family/c-common.c:5937
+#: c-family/c-common.c:5935
 #, gcc-internal-format
 msgid "argument 3 in call to function %qE has boolean type"
 msgstr "argument 3 i anrop av funktionen %qE har boolesk typ"
 
-#: c-family/c-common.c:6184
+#: c-family/c-common.c:6183
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to static data member %qD"
 msgstr "det går inte att använda %<offsetof%> på en statisk datamedlem %qD"
 
-#: c-family/c-common.c:6189
+#: c-family/c-common.c:6188
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> when %<operator[]%> is overloaded"
 msgstr "går inte att applicera %<offsetof%> när %<operator[]%> är överlagrad"
 
-#: c-family/c-common.c:6196
+#: c-family/c-common.c:6195
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to a non constant address"
 msgstr "det går inte att använda %<offsetof%> på en icke-konstant adress"
 
-#: c-family/c-common.c:6209
+#: c-family/c-common.c:6208
 #, gcc-internal-format
 msgid "attempt to take address of bit-field structure member %qD"
 msgstr "försök att ta adressen till en medlem %qD i en bitfältspost"
 
-#: c-family/c-common.c:6261
+#: c-family/c-common.c:6260
 #, gcc-internal-format
 msgid "index %E denotes an offset greater than size of %qT"
 msgstr "index %E anger ett avstånd större än storleken på %qT"
 
-#: c-family/c-common.c:6427 cp/init.c:3004 cp/init.c:3023
+#: c-family/c-common.c:6419 cp/init.c:3020 cp/init.c:3039
 #, gcc-internal-format
 msgid "size of array is too large"
 msgstr "storleken på vektorn är för stor"
 
-#: c-family/c-common.c:6517
+#: c-family/c-common.c:6509
 #, gcc-internal-format
 msgid "operand type %qT is incompatible with argument %d of %qE"
 msgstr "operandtypen %qT är inkompatibel med argument %d till %qE"
 
-#: c-family/c-common.c:6651
+#: c-family/c-common.c:6643
 #, gcc-internal-format
 msgid "incorrect number of arguments to function %qE"
 msgstr "felaktigt antal argument till funktionen %qE"
 
-#: c-family/c-common.c:6665
+#: c-family/c-common.c:6657
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a non-void pointer type"
 msgstr "argument 1 till %qE måste vara pekartyp som inte pekar på void"
 
-#: c-family/c-common.c:6674
+#: c-family/c-common.c:6666
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a constant size type"
 msgstr "argument 1 till %qE måste vara en pekare till en typ med konstant storlek"
 
-#: c-family/c-common.c:6685
+#: c-family/c-common.c:6677
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a nonzero size object"
 msgstr "argument 1 till %qE måste vara en pekare till ett objekt av storlek större än noll"
 
-#: c-family/c-common.c:6706
+#: c-family/c-common.c:6698
 #, gcc-internal-format
 msgid "argument %d of %qE must be a pointer type"
 msgstr "argument %d till %qE måste vara en pekartyp"
 
-#: c-family/c-common.c:6714
+#: c-family/c-common.c:6706
 #, gcc-internal-format
 msgid "argument %d of %qE must be a pointer to a constant size type"
 msgstr "argument %d till %qE måste vara en pekare till en typ med konstant storlek"
 
-#: c-family/c-common.c:6720
+#: c-family/c-common.c:6712
 #, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a function"
 msgstr "argument %d till %qE får inte vara en pekare till en funktion"
 
-#: c-family/c-common.c:6728
+#: c-family/c-common.c:6720
 #, gcc-internal-format
 msgid "size mismatch in argument %d of %qE"
 msgstr "storleken stämmer inte i argument %d till %qE"
 
-#: c-family/c-common.c:6740
+#: c-family/c-common.c:6732
 #, gcc-internal-format
 msgid "non-integer memory model argument %d of %qE"
 msgstr "minnesmodellsargument %d som inte är heltal till %qE"
 
-#: c-family/c-common.c:6753
+#: c-family/c-common.c:6745
 #, gcc-internal-format
 msgid "invalid memory model argument %d of %qE"
 msgstr "ogiltig minnesmodellsargument %d till %qE"
 
-#: c-family/c-common.c:7672
+#: c-family/c-common.c:7664
 #, gcc-internal-format
 msgid "index value is out of bound"
 msgstr "indexvärdet är utanför gränsen"
 
-#: c-family/c-common.c:7714 c-family/c-common.c:7763 c-family/c-common.c:7779
+#: c-family/c-common.c:7706 c-family/c-common.c:7755 c-family/c-common.c:7771
 #, gcc-internal-format
 msgid "conversion of scalar %qT to vector %qT involves truncation"
 msgstr "konvertering av skalären %qT till vektorn %qT innebär avhuggning"
@@ -24821,22 +24847,22 @@
 
 #. Reject arguments that are built-in functions with
 #. no library fallback.
-#: c-family/c-common.c:7867
+#: c-family/c-common.c:7859
 #, gcc-internal-format
 msgid "built-in function %qE must be directly called"
 msgstr "inbyggd funktion %qE måste anropas direkt"
 
-#: c-family/c-common.c:7889 c/c-decl.c:6177
+#: c-family/c-common.c:7881 c/c-decl.c:6197
 #, gcc-internal-format
 msgid "size of array %qE is too large"
 msgstr "storleken på vektorn %qE är för stor"
 
-#: c-family/c-common.c:7891 c/c-decl.c:6180
+#: c-family/c-common.c:7883 c/c-decl.c:6200
 #, gcc-internal-format
 msgid "size of unnamed array is too large"
 msgstr "storleken på en namnlös vektor är för stor"
 
-#: c-family/c-common.c:7921
+#: c-family/c-common.c:7913
 #, gcc-internal-format
 msgid "environment variable SOURCE_DATE_EPOCH must expand to a non-negative integer less than or equal to %wd"
 msgstr "miljövariabeln SOURCE_DATE_EPOCH måste expandera till ett ickenegativt heltal mindre än eller lika med %wd"
@@ -25357,7 +25383,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr "%<#pragma omp atomic capture%> använder två olika variabler till minne"
 
-#: c-family/c-omp.c:557 cp/semantics.c:8186
+#: c-family/c-omp.c:557 cp/semantics.c:8189
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "ogiltig typ för iterationsvariabeln %qE"
@@ -25372,22 +25398,22 @@
 msgid "%qE is not initialized"
 msgstr "%qE är inte initierad"
 
-#: c-family/c-omp.c:599 cp/semantics.c:8076
+#: c-family/c-omp.c:599 cp/semantics.c:8079
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "styrpredikat saknas"
 
-#: c-family/c-omp.c:704 cp/semantics.c:7732
+#: c-family/c-omp.c:704 cp/semantics.c:7735
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "ogiltigt styrpredikat"
 
-#: c-family/c-omp.c:711 cp/semantics.c:8082
+#: c-family/c-omp.c:711 cp/semantics.c:8085
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "utelämnat ökningsuttryck"
 
-#: c-family/c-omp.c:775 cp/semantics.c:7847
+#: c-family/c-omp.c:775 cp/semantics.c:7850
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "ogiltigt ökningsuttryck"
@@ -25442,112 +25468,127 @@
 msgid "%<-Wabi=1%> is not supported, using =2"
 msgstr "%<-Wabi=1%> stödjs inte, använder =2"
 
-#: c-family/c-opts.c:612 fortran/cpp.c:350
+#: c-family/c-opts.c:610 fortran/cpp.c:350
 #, gcc-internal-format
 msgid "output filename specified twice"
 msgstr "utdatafilnamn angivet två gånger"
 
-#: c-family/c-opts.c:799
+#: c-family/c-opts.c:797
 #, gcc-internal-format
 msgid "-fexcess-precision=standard for C++"
 msgstr "-fexcess-precision=standard för C++"
 
-#: c-family/c-opts.c:834
+#: c-family/c-opts.c:832
 #, gcc-internal-format
 msgid "-fno-gnu89-inline is only supported in GNU99 or C99 mode"
 msgstr "-fno-gnu89-inline stödjs endast i GNU99- C99-läge"
 
-#: c-family/c-opts.c:880
+#: c-family/c-opts.c:878
 #, gcc-internal-format
 msgid "-Wformat-y2k ignored without -Wformat"
 msgstr "-Wformat-y2k ignorerad utan -Wformat"
 
-#: c-family/c-opts.c:882
+#: c-family/c-opts.c:880
 #, gcc-internal-format
 msgid "-Wformat-extra-args ignored without -Wformat"
 msgstr "-Wformat-extra-args ignorerad utan -Wformat"
 
-#: c-family/c-opts.c:884
+#: c-family/c-opts.c:882
 #, gcc-internal-format
 msgid "-Wformat-zero-length ignored without -Wformat"
 msgstr "-Wformat-zero-length ignoreras utan -Wformat"
 
-#: c-family/c-opts.c:886
+#: c-family/c-opts.c:884
 #, gcc-internal-format
 msgid "-Wformat-nonliteral ignored without -Wformat"
 msgstr "-Wformat-nonliteral ignorerad utan -Wformat"
 
-#: c-family/c-opts.c:888
+#: c-family/c-opts.c:886
 #, gcc-internal-format
 msgid "-Wformat-contains-nul ignored without -Wformat"
 msgstr "-Wformat-contains-nul ignoreras utan -Wformat"
 
-#: c-family/c-opts.c:890
+#: c-family/c-opts.c:888
 #, gcc-internal-format
 msgid "-Wformat-security ignored without -Wformat"
 msgstr "-Wformat-security ignorerad utan -Wformat"
 
-#: c-family/c-opts.c:928
+#: c-family/c-opts.c:918
 #, gcc-internal-format
 msgid "%<-fabi-compat-version=1%> is not supported, using =2"
 msgstr "%<-fabi-compat-version=1%> stödjs inte, använder =2"
 
-#: c-family/c-opts.c:988
+#: c-family/c-opts.c:944
 #, gcc-internal-format
+msgid "-Wabi won't warn about anything"
+msgstr "-Wabi kommer inte att varna om något"
+
+#: c-family/c-opts.c:946
+#, gcc-internal-format
+msgid "-Wabi warns about differences from the most up-to-date ABI, which is also used by default"
+msgstr "-Wabi varnar om skillnader mot den mest aktuella ABI:et, vilket även används som standard"
+
+#: c-family/c-opts.c:949
+#, gcc-internal-format
+msgid "use e.g. -Wabi=11 to warn about changes from GCC 7"
+msgstr "använd t.ex. -Wabi=11 för att varna om ändringar sedan GCC 7"
+
+#: c-family/c-opts.c:1003
+#, gcc-internal-format
 msgid "external TLS initialization functions not supported on this target"
 msgstr "externa TLS-initieringsfunktioner stödjs inte på denna målarkitektur"
 
-#: c-family/c-opts.c:1001
+#: c-family/c-opts.c:1016
 #, gcc-internal-format, gfc-internal-format
 msgid "too many filenames given.  Type %s --help for usage"
 msgstr "för många filnamn angivna.  Skriv %s --help för användningsinformation"
 
-#: c-family/c-opts.c:1016
+#: c-family/c-opts.c:1031
 #, gcc-internal-format
 msgid "opening output file %s: %m"
 msgstr "vid öppnandet av utdatafil %s: %m"
 
-#: c-family/c-opts.c:1036
+#: c-family/c-opts.c:1051
 #, gcc-internal-format, gfc-internal-format
 msgid "the \"%s\" debug format cannot be used with pre-compiled headers"
 msgstr "felsökningsformatet ”%s” kan inte användas med förkompilerade huvuden"
 
-#: c-family/c-opts.c:1190
+#: c-family/c-opts.c:1205
 #, gcc-internal-format
 msgid "opening dependency file %s: %m"
 msgstr "när beroendefil %s öppnades: %m"
 
-#: c-family/c-opts.c:1201
+#: c-family/c-opts.c:1216
 #, gcc-internal-format
 msgid "closing dependency file %s: %m"
 msgstr "när beroendefil %s stängdes: %m"
 
-#: c-family/c-opts.c:1204
+#: c-family/c-opts.c:1219
 #, gcc-internal-format
 msgid "when writing output to %s: %m"
 msgstr "när utdata skrevs till %s: %m"
 
-#: c-family/c-opts.c:1284
+#: c-family/c-opts.c:1299
 #, gcc-internal-format
 msgid "to generate dependencies you must specify either -M or -MM"
 msgstr "för att generera beroenden måste du ange antingen -M eller -MM"
 
-#: c-family/c-opts.c:1307
+#: c-family/c-opts.c:1322
 #, gcc-internal-format
 msgid "-MG may only be used with -M or -MM"
 msgstr "-MG kan endast används med -M eller -MM"
 
-#: c-family/c-opts.c:1340
+#: c-family/c-opts.c:1355
 #, gcc-internal-format
 msgid "-fdirectives-only is incompatible with -Wunused_macros"
 msgstr "-fdirectives-only är inkompatibel med -Wunused_macros"
 
-#: c-family/c-opts.c:1342
+#: c-family/c-opts.c:1357
 #, gcc-internal-format
 msgid "-fdirectives-only is incompatible with -traditional"
 msgstr "-fdirectives-only är inkompatibel med -traditional"
 
-#: c-family/c-opts.c:1534
+#: c-family/c-opts.c:1549
 #, gcc-internal-format
 msgid "too late for # directive to set debug directory"
 msgstr "för sent för #-direktiv att ange felsökningskatalog"
@@ -25932,725 +25973,725 @@
 msgid "wrong type argument to %s"
 msgstr "fel typ på argument till %s"
 
-#: c-family/c-warn.c:53 c-family/c-warn.c:66 cp/constexpr.c:1847
+#: c-family/c-warn.c:54 c-family/c-warn.c:67 cp/constexpr.c:1847
 #: cp/constexpr.c:4099
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "spill i konstant uttryck"
 
-#: c-family/c-warn.c:93
+#: c-family/c-warn.c:94
 #, gcc-internal-format
 msgid "integer overflow in expression %qE of type %qT results in %qE"
 msgstr "heltalsspill i uttrycket %qE av typen %qT resulterar i %qE"
 
-#: c-family/c-warn.c:95
+#: c-family/c-warn.c:96
 #, gcc-internal-format
 msgid "integer overflow in expression of type %qT results in %qE"
 msgstr "heltalsspill i ett uttryck av typen %qT resulterar i %qE"
 
-#: c-family/c-warn.c:101
+#: c-family/c-warn.c:102
 #, gcc-internal-format
 msgid "floating point overflow in expression %qE of type %qT results in %qE"
 msgstr "flyttalsspill i uttrycket %qE av typen %qT resulterar i %qE"
 
-#: c-family/c-warn.c:103
+#: c-family/c-warn.c:104
 #, gcc-internal-format
 msgid "floating point overflow in expression of type %qT results in %qE"
 msgstr "flyttalsspill i ett uttryck av typen %qT resulterar i %qE"
 
-#: c-family/c-warn.c:109
+#: c-family/c-warn.c:110
 #, gcc-internal-format
 msgid "fixed-point overflow in expression %qE of type %qT results in %qE"
 msgstr "fixdecimalspill i uttrycket %qE av typen %qT resulterar i %qE"
 
-#: c-family/c-warn.c:111
+#: c-family/c-warn.c:112
 #, gcc-internal-format
 msgid "fixed-point overflow in expression of type %qT results in %qE"
 msgstr "fixdecimalspill i ett uttryck av typen %qT resulterar i %qE"
 
-#: c-family/c-warn.c:117
+#: c-family/c-warn.c:118
 #, gcc-internal-format
 msgid "vector overflow in expression %qE of type %qT results in %qE"
 msgstr "vektorspill i uttrycket %qE av typen %qT resulterar i %qE"
 
-#: c-family/c-warn.c:119
+#: c-family/c-warn.c:120
 #, gcc-internal-format
 msgid "vector overflow in expression of type %qT results in %qE"
 msgstr "vektorspill i ett uttryck av typen %qT resulterar i %qE"
 
-#: c-family/c-warn.c:126
+#: c-family/c-warn.c:127
 #, gcc-internal-format
 msgid "complex integer overflow in expression %qE of type %qT results in %qE"
 msgstr "spill i komplext heltal i uttrycket %qE av typen %qT resulterar i %qE"
 
-#: c-family/c-warn.c:128
+#: c-family/c-warn.c:129
 #, gcc-internal-format
 msgid "complex integer overflow in expression of type %qT results in %qE"
 msgstr "spill i komplext heltal i ett uttryck av typen %qT resulterar i %qE"
 
-#: c-family/c-warn.c:132
+#: c-family/c-warn.c:133
 #, gcc-internal-format
 msgid "complex floating point overflow in expression %qE of type %qT results in %qE"
 msgstr "spill i komplext flyttal i uttrycket %qE av typen %qT resulterar i %qE"
 
-#: c-family/c-warn.c:134
+#: c-family/c-warn.c:135
 #, gcc-internal-format
 msgid "complex floating point overflow in expression of type %qT results in %qE"
 msgstr "spill i komplext flyttal i ett uttryck av typen %qT resulterar i %qE"
 
-#: c-family/c-warn.c:216
+#: c-family/c-warn.c:217
 #, gcc-internal-format
 msgid "logical %<or%> applied to non-boolean constant"
 msgstr "logiskt %<or%> använt på en icke-boolesk konstant"
 
-#: c-family/c-warn.c:219
+#: c-family/c-warn.c:220
 #, gcc-internal-format
 msgid "logical %<and%> applied to non-boolean constant"
 msgstr "logiskt %<and%> använt på en icke-boolesk konstant"
 
-#: c-family/c-warn.c:289
+#: c-family/c-warn.c:290
 #, gcc-internal-format
 msgid "logical %<or%> of collectively exhaustive tests is always true"
 msgstr "logiskt %<or%> av tillsammans uttömmande tester är alltid sant"
 
-#: c-family/c-warn.c:293
+#: c-family/c-warn.c:294
 #, gcc-internal-format
 msgid "logical %<and%> of mutually exclusive tests is always false"
 msgstr "logiskt %<and%> mellan ömsesidigt uteslutande tester är alltid falskt"
 
-#: c-family/c-warn.c:303
+#: c-family/c-warn.c:304
 #, gcc-internal-format
 msgid "logical %<or%> of equal expressions"
 msgstr "logiskt %<or%> mellan lika uttryck"
 
-#: c-family/c-warn.c:306
+#: c-family/c-warn.c:307
 #, gcc-internal-format
 msgid "logical %<and%> of equal expressions"
 msgstr "logiskt %<and%> mellan lika uttryck"
 
-#: c-family/c-warn.c:384
+#: c-family/c-warn.c:385
 #, gcc-internal-format
 msgid "bitwise comparison always evaluates to false"
 msgstr "bitvis jämförelse beräknas alltid till falskt"
 
-#: c-family/c-warn.c:387
+#: c-family/c-warn.c:388
 #, gcc-internal-format
 msgid "bitwise comparison always evaluates to true"
 msgstr "bitvis jämförelse beräknas alltid till sant"
 
-#: c-family/c-warn.c:441
+#: c-family/c-warn.c:442
 #, gcc-internal-format
 msgid "self-comparison always evaluates to true"
 msgstr "självjämförelse beräknas alltid till sant"
 
-#: c-family/c-warn.c:444
+#: c-family/c-warn.c:445
 #, gcc-internal-format
 msgid "self-comparison always evaluates to false"
 msgstr "självjämförelse beräknas alltid till falskt"
 
-#: c-family/c-warn.c:494
+#: c-family/c-warn.c:495
 #, gcc-internal-format
 msgid "logical not is only applied to the left hand side of comparison"
 msgstr "logiskt icke tillämpas endast på vänstersidan av jämförelsen"
 
-#: c-family/c-warn.c:502
+#: c-family/c-warn.c:503
 #, gcc-internal-format
 msgid "add parentheses around left hand side expression to silence this warning"
 msgstr "lägg till parenteser runt uttrycket på vänster hand för att tysta denna varning"
 
-#: c-family/c-warn.c:636
+#: c-family/c-warn.c:637
 #, gcc-internal-format
 msgid "type-punning to incomplete type might break strict-aliasing rules"
 msgstr "typstampning till ofullständig typ kan bryta strikta aliasregler"
 
-#: c-family/c-warn.c:654
+#: c-family/c-warn.c:655
 #, gcc-internal-format
 msgid "dereferencing type-punned pointer will break strict-aliasing rules"
 msgstr "dereferering av en typstampad pekare kommer bryta strikta aliasregler"
 
-#: c-family/c-warn.c:662 c-family/c-warn.c:680
+#: c-family/c-warn.c:663 c-family/c-warn.c:681
 #, gcc-internal-format
 msgid "dereferencing type-punned pointer might break strict-aliasing rules"
 msgstr "dereferering av en typstampad pekare kan bryta strikta aliasregler"
 
-#: c-family/c-warn.c:803
+#: c-family/c-warn.c:811
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to use the size of the destination?"
 msgstr "argumentet till %<sizeof%> i %qD-anrop är samma uttryck som källan; hade du tänkt använda storleken på destinationen?"
 
-#: c-family/c-warn.c:834
+#: c-family/c-warn.c:842
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the destination; did you mean to remove the addressof?"
 msgstr "argumentet till %<sizeof%> i %qD-anrop är samma uttryck som destinationen; hade du tänkt att ta bort addressof?"
 
-#: c-family/c-warn.c:841
+#: c-family/c-warn.c:849
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the destination; did you mean to provide an explicit length?"
 msgstr "argumentet till %<sizeof%> i %qD call-anrop är samma uttryck som destinationen; hade du tänkt ange en explicit längd?"
 
-#: c-family/c-warn.c:846
+#: c-family/c-warn.c:854
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the destination; did you mean to dereference it?"
 msgstr "argumentet till %<sizeof%> i %qD-anropet är samma uttryck som destinationen; hade du tänkt dereferera det?"
 
-#: c-family/c-warn.c:858
+#: c-family/c-warn.c:866
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the destination; expected %qT or an explicit length"
 msgstr "argumentet till %<sizeof%> i %qD-anrop är samma pekartyp %qT som destinationen; %qT eller en explicit längd förväntades"
 
-#: c-family/c-warn.c:874
+#: c-family/c-warn.c:882
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to remove the addressof?"
 msgstr "argumentet till %<sizeof%> i %qD-anrop är samma uttryck som källan; hade du tänkt ta bort addressof?"
 
-#: c-family/c-warn.c:881
+#: c-family/c-warn.c:889
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to provide an explicit length?"
 msgstr "argumentet till %<sizeof%> i %qD-anrop är samma uttryck som källan; hade du tänkt ange en explicit längd?"
 
-#: c-family/c-warn.c:886
+#: c-family/c-warn.c:894
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to dereference it?"
 msgstr "argumentet till %<sizeof%> i %qD-anrop är samma uttryck som källan; hade du tänkt dereferera det?"
 
-#: c-family/c-warn.c:898
+#: c-family/c-warn.c:906
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the source; expected %qT or an explicit length"
 msgstr "argumentet till %<sizeof%> i %qD-anrop är samma pekartyp %qT som källan; %qT eller en explicit längd förväntades"
 
-#: c-family/c-warn.c:914
+#: c-family/c-warn.c:922
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the first source; did you mean to remove the addressof?"
 msgstr "argumentet till %<sizeof%> i %qD-anrop är samma uttryck som den första källan; hade du tänkt ta bort addressof?"
 
-#: c-family/c-warn.c:921
+#: c-family/c-warn.c:929
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the first source; did you mean to provide an explicit length?"
 msgstr "argumentet till %<sizeof%> i %qD-anrop är samma uttryck som den första källan; hade du tänkt ange en explicit längd?"
 
-#: c-family/c-warn.c:926
+#: c-family/c-warn.c:934
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the first source; did you mean to dereference it?"
 msgstr "argumentet till %<sizeof%> i %qD-anrop är samma uttryck som den första källan; hade du tänkt dereferera det?"
 
-#: c-family/c-warn.c:938
+#: c-family/c-warn.c:946
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the first source; expected %qT or an explicit length"
 msgstr "argumentet till %<sizeof%> i %qD-anrop är samma pekartyp %qT som den första källan; %qT eller en explicit längd förväntades"
 
-#: c-family/c-warn.c:954
+#: c-family/c-warn.c:962
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the second source; did you mean to remove the addressof?"
 msgstr "argumentet till %<sizeof%> i %qD-anrop är samma uttryck som den andra källan; hade du tänkt ta bort addressof?"
 
-#: c-family/c-warn.c:961
+#: c-family/c-warn.c:969
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the second source; did you mean to provide an explicit length?"
 msgstr "argumentet till %<sizeof%> i %qD-anrop är samma uttryck som den andra källan; hade du tänkt ange en explicit längd?"
 
-#: c-family/c-warn.c:966
+#: c-family/c-warn.c:974
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the second source; did you mean to dereference it?"
 msgstr "argumentet till %<sizeof%> i %qD-anrop är samma uttryck som den andra källan; hade du tänkt dereferera det?"
 
-#: c-family/c-warn.c:978
+#: c-family/c-warn.c:986
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the second source; expected %qT or an explicit length"
 msgstr "argumentet till %<sizeof%> i %qD-anrop är samma pekartyp %qT som den andra källan; %qT eller en explicit längd förväntades"
 
-#: c-family/c-warn.c:1007 c-family/c-warn.c:1014
+#: c-family/c-warn.c:1015 c-family/c-warn.c:1022
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified parameter type %qT of %q+D"
 msgstr "%<_Atomic%>-kvalificerad parametertyp %qT till %q+D"
 
-#: c-family/c-warn.c:1024
+#: c-family/c-warn.c:1032
 #, gcc-internal-format
 msgid "first argument of %q+D should be %<int%>"
 msgstr "första argumentet till %q+D skall vara %<int%>"
 
-#: c-family/c-warn.c:1033
+#: c-family/c-warn.c:1041
 #, gcc-internal-format
 msgid "second argument of %q+D should be %<char **%>"
 msgstr "andra argumentet till %q+D skall vara %<char **%>"
 
-#: c-family/c-warn.c:1042
+#: c-family/c-warn.c:1050
 #, gcc-internal-format
 msgid "third argument of %q+D should probably be %<char **%>"
 msgstr "tredje argumentet till %q+D skall förmodligen vara %<char **%>"
 
-#: c-family/c-warn.c:1053
+#: c-family/c-warn.c:1061
 #, gcc-internal-format
 msgid "%q+D takes only zero or two arguments"
 msgstr "%q+D tar bara noll eller två argument"
 
-#: c-family/c-warn.c:1057
+#: c-family/c-warn.c:1065
 #, gcc-internal-format
 msgid "%q+D declared as variadic function"
 msgstr "%q+D deklarerat som en variadisk funktion"
 
-#: c-family/c-warn.c:1099
+#: c-family/c-warn.c:1107
 #, gcc-internal-format
 msgid "conversion to %qT from boolean expression"
 msgstr "konvertering till %qT från booleskt uttryck"
 
-#: c-family/c-warn.c:1117 c-family/c-warn.c:1192
+#: c-family/c-warn.c:1125 c-family/c-warn.c:1200
 #, gcc-internal-format
 msgid "conversion from %qT to %qT changes value from %qE to %qE"
 msgstr "konvertering från %qT till %qT ändrar värdet från %qE till %qE"
 
-#: c-family/c-warn.c:1121 c-family/c-warn.c:1200
+#: c-family/c-warn.c:1129 c-family/c-warn.c:1208
 #, gcc-internal-format
 msgid "conversion from %qT to %qT changes the value of %qE"
 msgstr "konvertering från %qT till %qT ändrar värdet på %qE"
 
-#: c-family/c-warn.c:1141
+#: c-family/c-warn.c:1149
 #, gcc-internal-format
 msgid "conversion from %qT to %qT discards imaginary component"
 msgstr "konvertering från %qT till %qT kastar imaginär komponent"
 
-#: c-family/c-warn.c:1153
+#: c-family/c-warn.c:1161
 #, gcc-internal-format
 msgid "conversion from %qT to %qT may change value"
 msgstr "konvertering från %qT till %qT kan ändra dess värde"
 
-#: c-family/c-warn.c:1213 c-family/c-warn.c:1230 c-family/c-warn.c:1247
+#: c-family/c-warn.c:1221 c-family/c-warn.c:1238 c-family/c-warn.c:1255
 #, gcc-internal-format
 msgid "overflow in conversion from %qT to %qT changes value from %qE to %qE"
 msgstr "spill vid konvertering från %qT till %qT som ändrar värde från %qE till %qE"
 
-#: c-family/c-warn.c:1218 c-family/c-warn.c:1235 c-family/c-warn.c:1252
+#: c-family/c-warn.c:1226 c-family/c-warn.c:1243 c-family/c-warn.c:1260
 #, gcc-internal-format
 msgid "overflow in conversion from %qT to %qT changes the value of %qE"
 msgstr "spill vid konvertering från %qT till %qT ändrar värdet på %qE"
 
-#: c-family/c-warn.c:1282
+#: c-family/c-warn.c:1290
 #, gcc-internal-format
 msgid "case value %qs not in enumerated type"
 msgstr "case-värde %qs är inte i en uppräkningstyp"
 
-#: c-family/c-warn.c:1287
+#: c-family/c-warn.c:1295
 #, gcc-internal-format
 msgid "case value %qs not in enumerated type %qT"
 msgstr "case-värde %qs är inte i uppräkningstypen %qT"
 
-#: c-family/c-warn.c:1348
+#: c-family/c-warn.c:1356
 #, gcc-internal-format
 msgid "switch missing default case"
 msgstr "switch saknar default-fall"
 
-#: c-family/c-warn.c:1393
+#: c-family/c-warn.c:1401
 #, gcc-internal-format
 msgid "switch condition has boolean value"
 msgstr "switch-villkor har booleskt värde"
 
-#: c-family/c-warn.c:1466
+#: c-family/c-warn.c:1474
 #, gcc-internal-format
 msgid "enumeration value %qE not handled in switch"
 msgstr "uppräkningsvärdet %qE hanteras inte i switch"
 
-#: c-family/c-warn.c:1494
+#: c-family/c-warn.c:1502
 #, gcc-internal-format
 msgid "the omitted middle operand in ?: will always be %<true%>, suggest explicit middle operand"
 msgstr "den utelämnade mittoperanden i ?: kommer alltid att vara %<true%>, föreslår explicit mittoperand"
 
-#: c-family/c-warn.c:1515
+#: c-family/c-warn.c:1523
 #, gcc-internal-format
 msgid "assignment of member %qD in read-only object"
 msgstr "tilldelning av medlem %qD i endast läsbart objekt"
 
-#: c-family/c-warn.c:1517
+#: c-family/c-warn.c:1525
 #, gcc-internal-format
 msgid "increment of member %qD in read-only object"
 msgstr "ökning av medlem %qD i endast läsbart objekt"
 
-#: c-family/c-warn.c:1519
+#: c-family/c-warn.c:1527
 #, gcc-internal-format
 msgid "decrement of member %qD in read-only object"
 msgstr "minskning av medlem %qD i endast läsbart objekt"
 
-#: c-family/c-warn.c:1521
+#: c-family/c-warn.c:1529
 #, gcc-internal-format
 msgid "member %qD in read-only object used as %<asm%> output"
 msgstr "medlem %qD i endast läsbart objekt använt som %<asm%>-utdata"
 
-#: c-family/c-warn.c:1525
+#: c-family/c-warn.c:1533
 #, gcc-internal-format
 msgid "assignment of read-only member %qD"
 msgstr "tilldelning till endast läsbar medlem %qD"
 
-#: c-family/c-warn.c:1526
+#: c-family/c-warn.c:1534
 #, gcc-internal-format
 msgid "increment of read-only member %qD"
 msgstr "ökning av endast läsbar medlem %qD"
 
-#: c-family/c-warn.c:1527
+#: c-family/c-warn.c:1535
 #, gcc-internal-format
 msgid "decrement of read-only member %qD"
 msgstr "minskning av endast läsbar medlem %qD"
 
-#: c-family/c-warn.c:1528
+#: c-family/c-warn.c:1536
 #, gcc-internal-format
 msgid "read-only member %qD used as %<asm%> output"
 msgstr "endast läsbar medlem %qD använd som %<asm%>-utdata"
 
-#: c-family/c-warn.c:1532
+#: c-family/c-warn.c:1540
 #, gcc-internal-format
 msgid "assignment of read-only variable %qD"
 msgstr "tilldelning till endast läsbar variabel %qD"
 
-#: c-family/c-warn.c:1533
+#: c-family/c-warn.c:1541
 #, gcc-internal-format
 msgid "increment of read-only variable %qD"
 msgstr "ökning av endast läsbar variabel %qD"
 
-#: c-family/c-warn.c:1534
+#: c-family/c-warn.c:1542
 #, gcc-internal-format
 msgid "decrement of read-only variable %qD"
 msgstr "minskning av endast läsbar variabel %qD"
 
-#: c-family/c-warn.c:1535
+#: c-family/c-warn.c:1543
 #, gcc-internal-format
 msgid "read-only variable %qD used as %<asm%> output"
 msgstr "endast läsbar variabel %qD använd som %<asm%>-utdata"
 
-#: c-family/c-warn.c:1538
+#: c-family/c-warn.c:1546
 #, gcc-internal-format
 msgid "assignment of read-only parameter %qD"
 msgstr "tilldelning till endast läsbar parameter %qD"
 
-#: c-family/c-warn.c:1539
+#: c-family/c-warn.c:1547
 #, gcc-internal-format
 msgid "increment of read-only parameter %qD"
 msgstr "ökning av endast läsbar parameter %qD"
 
-#: c-family/c-warn.c:1540
+#: c-family/c-warn.c:1548
 #, gcc-internal-format
 msgid "decrement of read-only parameter %qD"
 msgstr "minskning av endast läsbar parameter %qD"
 
-#: c-family/c-warn.c:1541
+#: c-family/c-warn.c:1549
 #, gcc-internal-format
 msgid "read-only parameter %qD use as %<asm%> output"
 msgstr "endast läsbar parameter %qD använd som %<asm%>-utdata"
 
-#: c-family/c-warn.c:1546
+#: c-family/c-warn.c:1554
 #, gcc-internal-format
 msgid "assignment of read-only named return value %qD"
 msgstr "tilldelning av endast läsbart namngivet returvärde %qD"
 
-#: c-family/c-warn.c:1548
+#: c-family/c-warn.c:1556
 #, gcc-internal-format
 msgid "increment of read-only named return value %qD"
 msgstr "ökning av endast läsbart namngivet returvärde %qD"
 
-#: c-family/c-warn.c:1550
+#: c-family/c-warn.c:1558
 #, gcc-internal-format
 msgid "decrement of read-only named return value %qD"
 msgstr "minskning av endast läsbart namngivet returvärde %qD"
 
-#: c-family/c-warn.c:1552
+#: c-family/c-warn.c:1560
 #, gcc-internal-format
 msgid "read-only named return value %qD used as %<asm%>output"
 msgstr "endast läsbar namngiven returvariabel %qD använd som %<asm%>-utdata"
 
-#: c-family/c-warn.c:1557
+#: c-family/c-warn.c:1565
 #, gcc-internal-format
 msgid "assignment of function %qD"
 msgstr "tilldelning av funktion %qD"
 
-#: c-family/c-warn.c:1558
+#: c-family/c-warn.c:1566
 #, gcc-internal-format
 msgid "increment of function %qD"
 msgstr "ökning av funktion %qD"
 
-#: c-family/c-warn.c:1559
+#: c-family/c-warn.c:1567
 #, gcc-internal-format
 msgid "decrement of function %qD"
 msgstr "minskning av funktion %qD"
 
-#: c-family/c-warn.c:1560
+#: c-family/c-warn.c:1568
 #, gcc-internal-format
 msgid "function %qD used as %<asm%> output"
 msgstr "funktionen %qD använd som %<asm%>-utdata"
 
-#: c-family/c-warn.c:1563 c/c-typeck.c:4762
+#: c-family/c-warn.c:1571 c/c-typeck.c:4767
 #, gcc-internal-format
 msgid "assignment of read-only location %qE"
 msgstr "tilldelning till endast läsbar plats %qE"
 
-#: c-family/c-warn.c:1564 c/c-typeck.c:4765
+#: c-family/c-warn.c:1572 c/c-typeck.c:4770
 #, gcc-internal-format
 msgid "increment of read-only location %qE"
 msgstr "ökning av endast läsbar plats %qE"
 
-#: c-family/c-warn.c:1565 c/c-typeck.c:4768
+#: c-family/c-warn.c:1573 c/c-typeck.c:4773
 #, gcc-internal-format
 msgid "decrement of read-only location %qE"
 msgstr "minskning av endast läsbar plats %qE"
 
-#: c-family/c-warn.c:1566
+#: c-family/c-warn.c:1574
 #, gcc-internal-format
 msgid "read-only location %qE used as %<asm%> output"
 msgstr "endast läsbar plats %qE använd som %<asm%>-utdata"
 
-#: c-family/c-warn.c:1580
+#: c-family/c-warn.c:1588
 #, gcc-internal-format
 msgid "lvalue required as left operand of assignment"
 msgstr "l-värde krävs som vänstra operand i tilldelning"
 
-#: c-family/c-warn.c:1583
+#: c-family/c-warn.c:1591
 #, gcc-internal-format
 msgid "lvalue required as increment operand"
 msgstr "l-värde krävs som operand till ökning"
 
-#: c-family/c-warn.c:1586
+#: c-family/c-warn.c:1594
 #, gcc-internal-format
 msgid "lvalue required as decrement operand"
 msgstr "l-värde krävs som operand till minskning"
 
-#: c-family/c-warn.c:1589
+#: c-family/c-warn.c:1597
 #, gcc-internal-format
 msgid "lvalue required as unary %<&%> operand"
 msgstr "l-värde krävs som operand till unär %<&%>"
 
-#: c-family/c-warn.c:1592
+#: c-family/c-warn.c:1600
 #, gcc-internal-format
 msgid "lvalue required in asm statement"
 msgstr "l-värde krävs i asm-sats"
 
-#: c-family/c-warn.c:1609
+#: c-family/c-warn.c:1617
 #, gcc-internal-format
 msgid "invalid type argument (have %qT)"
 msgstr "ogiltigt typargument (har %qT)"
 
-#: c-family/c-warn.c:1613
+#: c-family/c-warn.c:1621
 #, gcc-internal-format
 msgid "invalid type argument of array indexing (have %qT)"
 msgstr "ogiltigt typargument i vektorindexering (har %qT)"
 
-#: c-family/c-warn.c:1618
+#: c-family/c-warn.c:1626
 #, gcc-internal-format
 msgid "invalid type argument of unary %<*%> (have %qT)"
 msgstr "ogiltigt typargument till unär %<*%> (har %qT)"
 
-#: c-family/c-warn.c:1623
+#: c-family/c-warn.c:1631
 #, gcc-internal-format
 msgid "invalid type argument of %<->%> (have %qT)"
 msgstr "ogiltigt typargument till %<->%> (har %qT)"
 
-#: c-family/c-warn.c:1628
+#: c-family/c-warn.c:1636
 #, gcc-internal-format
 msgid "invalid type argument of %<->*%> (have %qT)"
 msgstr "ogiltigt typargument till %<->*%> (har %qT)"
 
-#: c-family/c-warn.c:1633
+#: c-family/c-warn.c:1641
 #, gcc-internal-format
 msgid "invalid type argument of implicit conversion (have %qT)"
 msgstr "ogiltigt typargument till implicit konvertering (har %qT)"
 
-#: c-family/c-warn.c:1654
+#: c-family/c-warn.c:1662
 #, gcc-internal-format
 msgid "array subscript has type %<char%>"
 msgstr "vektorindex har typen %<char%>"
 
-#: c-family/c-warn.c:1689 c-family/c-warn.c:1692
+#: c-family/c-warn.c:1697 c-family/c-warn.c:1700
 #, gcc-internal-format
 msgid "suggest parentheses around %<+%> inside %<<<%>"
 msgstr "föreslår parenteser runt %<+%> inuti %<<<%>"
 
-#: c-family/c-warn.c:1695 c-family/c-warn.c:1698
+#: c-family/c-warn.c:1703 c-family/c-warn.c:1706
 #, gcc-internal-format
 msgid "suggest parentheses around %<-%> inside %<<<%>"
 msgstr "föreslår parenteser runt %<-%> inuti %<<<%>"
 
-#: c-family/c-warn.c:1704 c-family/c-warn.c:1707
+#: c-family/c-warn.c:1712 c-family/c-warn.c:1715
 #, gcc-internal-format
 msgid "suggest parentheses around %<+%> inside %<>>%>"
 msgstr "föreslår parenteser runt %<+%> inuti %<>>%>"
 
-#: c-family/c-warn.c:1710 c-family/c-warn.c:1713
+#: c-family/c-warn.c:1718 c-family/c-warn.c:1721
 #, gcc-internal-format
 msgid "suggest parentheses around %<-%> inside %<>>%>"
 msgstr "föreslår parenteser runt %<-%> inuti %<>>%>"
 
-#: c-family/c-warn.c:1719 c-family/c-warn.c:1722
+#: c-family/c-warn.c:1727 c-family/c-warn.c:1730
 #, gcc-internal-format
 msgid "suggest parentheses around %<&&%> within %<||%>"
 msgstr "föreslår parenteser runt %<&&%> inuti %<||%>"
 
-#: c-family/c-warn.c:1729 c-family/c-warn.c:1733
+#: c-family/c-warn.c:1737 c-family/c-warn.c:1741
 #, gcc-internal-format
 msgid "suggest parentheses around arithmetic in operand of %<|%>"
 msgstr "föreslår parenteser runt aritmetik i operanden till %<|%>"
 
-#: c-family/c-warn.c:1737 c-family/c-warn.c:1740
+#: c-family/c-warn.c:1745 c-family/c-warn.c:1748
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<|%>"
 msgstr "föreslår parenteser runt jämförelse i operanden till %<|%>"
 
-#: c-family/c-warn.c:1745
+#: c-family/c-warn.c:1753
 #, gcc-internal-format
 msgid "suggest parentheses around operand of %<!%> or change %<|%> to %<||%> or %<!%> to %<~%>"
 msgstr "föreslår parenteser runt operanden till %<!%> eller ändra %<|%> till %<||%> eller %<!%> till %<~%>"
 
-#: c-family/c-warn.c:1753 c-family/c-warn.c:1757
+#: c-family/c-warn.c:1761 c-family/c-warn.c:1765
 #, gcc-internal-format
 msgid "suggest parentheses around arithmetic in operand of %<^%>"
 msgstr "föreslår parenteser runt aritmetik i operanden till %<^%>"
 
-#: c-family/c-warn.c:1761 c-family/c-warn.c:1764
+#: c-family/c-warn.c:1769 c-family/c-warn.c:1772
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<^%>"
 msgstr "föreslår parenteser runt jämförelse i operanden till %<^%>"
 
-#: c-family/c-warn.c:1770 c-family/c-warn.c:1773
+#: c-family/c-warn.c:1778 c-family/c-warn.c:1781
 #, gcc-internal-format
 msgid "suggest parentheses around %<+%> in operand of %<&%>"
 msgstr "föreslår parenteser runt %<+%> i operanden till %<&%>"
 
-#: c-family/c-warn.c:1776 c-family/c-warn.c:1779
+#: c-family/c-warn.c:1784 c-family/c-warn.c:1787
 #, gcc-internal-format
 msgid "suggest parentheses around %<-%> in operand of %<&%>"
 msgstr "föreslår parenteser runt %<-%> i operanden till %<&%>"
 
-#: c-family/c-warn.c:1783 c-family/c-warn.c:1786
+#: c-family/c-warn.c:1791 c-family/c-warn.c:1794
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<&%>"
 msgstr "föreslår parenteser runt jämförelser i operanden till %<&%>"
 
-#: c-family/c-warn.c:1791
+#: c-family/c-warn.c:1799
 #, gcc-internal-format
 msgid "suggest parentheses around operand of %<!%> or change %<&%> to %<&&%> or %<!%> to %<~%>"
 msgstr "föreslår parenteser runt operanden till %<!%> eller ändra %<&%> till %<&&%> eller %<!%> till %<~%>"
 
-#: c-family/c-warn.c:1798 c-family/c-warn.c:1801
+#: c-family/c-warn.c:1806 c-family/c-warn.c:1809
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<==%>"
 msgstr "föreslår parenteser runt jämförelse i operanden till %<==%>"
 
-#: c-family/c-warn.c:1806 c-family/c-warn.c:1809
+#: c-family/c-warn.c:1814 c-family/c-warn.c:1817
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<!=%>"
 msgstr "föreslår parenteser runt jämförelse i operanden till %<!=%>"
 
-#: c-family/c-warn.c:1819 c-family/c-warn.c:1825
+#: c-family/c-warn.c:1827 c-family/c-warn.c:1833
 #, gcc-internal-format
 msgid "comparisons like %<X<=Y<=Z%> do not have their mathematical meaning"
 msgstr "jämförelser som %<X<=Y<=Z%> har inte sin matematiska mening"
 
-#: c-family/c-warn.c:1841
+#: c-family/c-warn.c:1849
 #, gcc-internal-format
 msgid "label %q+D defined but not used"
 msgstr "etikett %q+D är definierad men inte använd"
 
-#: c-family/c-warn.c:1843
+#: c-family/c-warn.c:1851
 #, gcc-internal-format
 msgid "label %q+D declared but not defined"
 msgstr "etikett %q+D är deklarerad men inte definierad"
 
-#: c-family/c-warn.c:1866
+#: c-family/c-warn.c:1874
 #, gcc-internal-format
 msgid "division by zero"
 msgstr "division med noll"
 
-#: c-family/c-warn.c:1886
+#: c-family/c-warn.c:1894
 #, gcc-internal-format
 msgid "%<memset%> used with constant zero length parameter; this could be due to transposed parameters"
 msgstr "%<memset%> använd med konstant parameter med längd noll; detta kan bero på omkastade parametrar"
 
-#: c-family/c-warn.c:1909
+#: c-family/c-warn.c:1918
 #, gcc-internal-format
 msgid "%<memset%> used with length equal to number of elements without multiplication by element size"
 msgstr "%<memset%> använt med en längd lika med antalet element utan att multiplicera med elementstorleken"
 
-#: c-family/c-warn.c:1948 c/c-typeck.c:11499 c/c-typeck.c:11667
+#: c-family/c-warn.c:1957 c/c-typeck.c:11504 c/c-typeck.c:11672
 #: cp/typeck.c:5048
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr "jämförelse mellan typer %qT och %qT"
 
-#: c-family/c-warn.c:1998
+#: c-family/c-warn.c:2007
 #, gcc-internal-format
 msgid "comparison of integer expressions of different signedness: %qT and %qT"
 msgstr "jämförelse av heltalsuttryck av olika teckenläge: %qT och %qT"
 
-#: c-family/c-warn.c:2051
+#: c-family/c-warn.c:2060
 #, gcc-internal-format
 msgid "promoted ~unsigned is always non-zero"
 msgstr "befordrad ~unsigned är alltid skild från noll"
 
-#: c-family/c-warn.c:2054
+#: c-family/c-warn.c:2063
 #, gcc-internal-format
 msgid "comparison of promoted ~unsigned with constant"
 msgstr "jämförelse av befordrad ~unsigned med konstant"
 
-#: c-family/c-warn.c:2064
+#: c-family/c-warn.c:2073
 #, gcc-internal-format
 msgid "comparison of promoted ~unsigned with unsigned"
 msgstr "jämförelse av befordrad ~unsigned med unsigned"
 
-#: c-family/c-warn.c:2118
+#: c-family/c-warn.c:2127
 #, gcc-internal-format
 msgid "unused parameter %qD"
 msgstr "oanvänd parameter %qD"
 
-#: c-family/c-warn.c:2180
+#: c-family/c-warn.c:2189
 #, gcc-internal-format
 msgid "typedef %qD locally defined but not used"
 msgstr "typedef %qD är lokalt definierad men inte använd"
 
-#: c-family/c-warn.c:2215
+#: c-family/c-warn.c:2224
 #, gcc-internal-format
 msgid "duplicated %<if%> condition"
 msgstr "dubblerat %<if%>-villkor"
 
-#: c-family/c-warn.c:2244
+#: c-family/c-warn.c:2253
 #, gcc-internal-format
 msgid "optimization attribute on %qD follows definition but the attribute doesn%'t match"
 msgstr "optimeringsattributet på %qD följer på en definition men attributet stämmer inte"
 
-#: c-family/c-warn.c:2254
+#: c-family/c-warn.c:2261
 #, gcc-internal-format
 msgid "inline declaration of %qD follows declaration with attribute %qs"
 msgstr "inline-deklaration av %qD följer på deklaration med attributet %qs"
 
-#: c-family/c-warn.c:2259
+#: c-family/c-warn.c:2266
 #, gcc-internal-format
 msgid "declaration of %q+D with attribute %qs follows inline declaration"
 msgstr "deklaration av %q+D med attributet %qs följer på inline-deklaration"
 
-#: c-family/c-warn.c:2306
+#: c-family/c-warn.c:2313
 #, gcc-internal-format
 msgid "result of %qE requires %u bits to represent, but %qT only has %u bits"
 msgstr "resultatet av %qE behöver %u bitar för att representeras, men %qT har bara %u bitar"
 
-#: c-family/c-warn.c:2344 c-family/c-warn.c:2368
+#: c-family/c-warn.c:2351 c-family/c-warn.c:2375
 #, gcc-internal-format
 msgid "comparison of constant %qE with boolean expression is always false"
 msgstr "jämförelse av konstant %qE med booleskt uttryck är alltid falskt"
 
-#: c-family/c-warn.c:2347 c-family/c-warn.c:2365
+#: c-family/c-warn.c:2354 c-family/c-warn.c:2372
 #, gcc-internal-format
 msgid "comparison of constant %qE with boolean expression is always true"
 msgstr "jämförelse av konstant %qE med booleskt uttryck är alltid sant"
 
-#: c-family/c-warn.c:2415
+#: c-family/c-warn.c:2422
 msgid "passing argument %i to restrict-qualified parameter aliases with argument %Z"
 msgid_plural "passing argument %i to restrict-qualified parameter aliases with arguments %Z"
 msgstr[0] "att skicka argument %i till en restrict-kvalificerad parameter blir alias med argument %Z"
 msgstr[1] "att skicka argument %i till en restrict-kvalificerad parameter blir alias med argumenten %Z"
 
-#: c-family/c-warn.c:2480 c/c-typeck.c:5288 cp/call.c:5365
+#: c-family/c-warn.c:2487 c/c-typeck.c:5293 cp/call.c:5365
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr "detta villkor har identiska grenar"
 
-#: c-family/c-warn.c:2586
+#: c-family/c-warn.c:2593
 #, gcc-internal-format
 msgid "macro expands to multiple statements"
 msgstr "makrot expanderar till flera satser"
 
-#: c-family/c-warn.c:2587
+#: c-family/c-warn.c:2594
 #, gcc-internal-format
 msgid "some parts of macro expansion are not guarded by this %qs clause"
 msgstr "några delar av makroexpansionen är inte skyddade av denna %qs-klausul"
@@ -26665,7 +26706,7 @@
 msgid "too many input files"
 msgstr "för många indatafiler"
 
-#: common/config/aarch64/aarch64-common.c:319 config/aarch64/aarch64.c:10686
+#: common/config/aarch64/aarch64-common.c:319 config/aarch64/aarch64.c:10702
 #, gcc-internal-format
 msgid "unknown value %qs for -mcpu"
 msgstr "okänt värde %qs till -mcpu"
@@ -26696,13 +26737,13 @@
 msgstr "okänd flagga skickad till %%:target_mode_check"
 
 #: common/config/arm/arm-common.c:322 common/config/arm/arm-common.c:376
-#: common/config/arm/arm-common.c:423 config/aarch64/aarch64.c:10639
+#: common/config/arm/arm-common.c:423 config/aarch64/aarch64.c:10655
 #, gcc-internal-format
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr "giltiga argument är: %s; menade du %qs?"
 
 #: common/config/arm/arm-common.c:325 common/config/arm/arm-common.c:379
-#: common/config/arm/arm-common.c:426 config/aarch64/aarch64.c:10642
+#: common/config/arm/arm-common.c:426 config/aarch64/aarch64.c:10658
 #, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s"
 msgstr "giltiga argument är: %s"
@@ -27175,12 +27216,12 @@
 msgid "profiler support for VxWorks"
 msgstr "profileringsstöd för VxWorks"
 
-#: config/aarch64/aarch64-builtins.c:1109 config/arm/arm-builtins.c:2262
+#: config/aarch64/aarch64-builtins.c:1109 config/arm/arm-builtins.c:2272
 #, gcc-internal-format
 msgid "%Kargument %d must be a constant immediate"
 msgstr "%Kargument %d måste vara en konstant omedelbar"
 
-#: config/aarch64/aarch64-builtins.c:1180 config/arm/arm-builtins.c:2492
+#: config/aarch64/aarch64-builtins.c:1180 config/arm/arm-builtins.c:2502
 #, gcc-internal-format
 msgid "%Klane index must be a constant immediate"
 msgstr "%Kbanindex måste vara en konstant omedelbar"
@@ -27190,175 +27231,175 @@
 msgid "%Ktotal size and element size must be a non-zero constant immediate"
 msgstr "%Ktotal storlek och elementstorlek måste vara en konstant omedelbar skild från noll"
 
-#: config/aarch64/aarch64.c:1053
+#: config/aarch64/aarch64.c:1069
 #, gcc-internal-format
 msgid "%qs is incompatible with %s %s"
 msgstr "%qs är inkompatibel med %s %s"
 
-#: config/aarch64/aarch64.c:1055
+#: config/aarch64/aarch64.c:1071
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with %s %s"
 msgstr "funktionsmodifieraren %qs är inkompatibel med %s %s"
 
-#: config/aarch64/aarch64.c:3772
+#: config/aarch64/aarch64.c:3788
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr "stackprov för SVE-ramar"
 
-#: config/aarch64/aarch64.c:10287
+#: config/aarch64/aarch64.c:10303
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown flag passed in -moverride=%s (%s)"
 msgstr "okänd flagga skickad i -moverride=%s (%s)"
 
-#: config/aarch64/aarch64.c:10331
+#: config/aarch64/aarch64.c:10347
 #, gcc-internal-format, gfc-internal-format
 msgid "%s string ill-formed\n"
 msgstr "%s-sträng är felformad\n"
 
-#: config/aarch64/aarch64.c:10388
+#: config/aarch64/aarch64.c:10404
 #, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr "trimningssträngen saknas i flaggan (%s)"
 
-#: config/aarch64/aarch64.c:10406
+#: config/aarch64/aarch64.c:10422
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown tuning option (%s)"
 msgstr "okänd trimningsflagga (%s)"
 
-#: config/aarch64/aarch64.c:10683
+#: config/aarch64/aarch64.c:10699
 #, gcc-internal-format
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr "cpu-namn saknas i %<-mcpu=%s%>"
 
-#: config/aarch64/aarch64.c:10690
+#: config/aarch64/aarch64.c:10706
 #, gcc-internal-format
 msgid "invalid feature modifier in %<-mcpu=%s%>"
 msgstr "ogiltig funktionsmodifierare i %<-mcpu=%s%>"
 
-#: config/aarch64/aarch64.c:10717
+#: config/aarch64/aarch64.c:10733
 #, gcc-internal-format
 msgid "missing arch name in %<-march=%s%>"
 msgstr "arkitekturnamn saknas i %<-march=%s%>"
 
-#: config/aarch64/aarch64.c:10720
+#: config/aarch64/aarch64.c:10736
 #, gcc-internal-format
 msgid "unknown value %qs for -march"
 msgstr "okänt värde %qs till -march"
 
-#: config/aarch64/aarch64.c:10724
+#: config/aarch64/aarch64.c:10740
 #, gcc-internal-format
 msgid "invalid feature modifier in %<-march=%s%>"
 msgstr "ogiltig funktionsmodifierare i %<-march=%s%>"
 
-#: config/aarch64/aarch64.c:10750
+#: config/aarch64/aarch64.c:10766
 #, gcc-internal-format
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr "cpu-namn saknas i %<-mtune=%s%>"
 
-#: config/aarch64/aarch64.c:10753
+#: config/aarch64/aarch64.c:10769
 #, gcc-internal-format
 msgid "unknown value %qs for -mtune"
 msgstr "okänt värde %qs till -mtune"
 
-#: config/aarch64/aarch64.c:10871 config/arm/arm.c:3173
+#: config/aarch64/aarch64.c:10887 config/arm/arm.c:3173
 #, gcc-internal-format, gfc-internal-format
 msgid "switch -mcpu=%s conflicts with -march=%s switch"
 msgstr "flaggan -mcpu=%s står i konflikt med flaggan -march=%s"
 
-#: config/aarch64/aarch64.c:10906
+#: config/aarch64/aarch64.c:10922
 #, gcc-internal-format
 msgid "assembler does not support -mabi=ilp32"
 msgstr "assemblern stödjer inte -mabi=ilp32"
 
-#: config/aarch64/aarch64.c:10913
+#: config/aarch64/aarch64.c:10929
 #, gcc-internal-format
 msgid "return address signing is only supported for -mabi=lp64"
 msgstr "signering av returadress stödjs endast för -mabi=lp64"
 
-#: config/aarch64/aarch64.c:10975
+#: config/aarch64/aarch64.c:10991
 #, gcc-internal-format
 msgid "code model %qs with -f%s"
 msgstr "kodmodell %qs med -f%s"
 
-#: config/aarch64/aarch64.c:11138
+#: config/aarch64/aarch64.c:11154
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr "namn saknas i pragmat eller attributet %<target(\"arch=\")%>"
 
-#: config/aarch64/aarch64.c:11141
+#: config/aarch64/aarch64.c:11157
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"arch=\")%> pragma or attribute"
 msgstr "felaktigt namn (”%s”) i pragmat eller attributet %<target(\"arch=\")%>"
 
-#: config/aarch64/aarch64.c:11145 config/aarch64/aarch64.c:11184
-#: config/aarch64/aarch64.c:11257
+#: config/aarch64/aarch64.c:11161 config/aarch64/aarch64.c:11200
+#: config/aarch64/aarch64.c:11273
 #, gcc-internal-format
 msgid "invalid value (\"%s\") in %<target()%> pragma or attribute"
 msgstr "felaktigt värde (”%s”) i pragmat eller attributet %<target(\"arch=\")%>"
 
-#: config/aarch64/aarch64.c:11177
+#: config/aarch64/aarch64.c:11193
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr "namn saknas i pragmat eller attributet %<target(\"cpu=\")%>"
 
-#: config/aarch64/aarch64.c:11180
+#: config/aarch64/aarch64.c:11196
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"cpu=\")%> pragma or attribute"
 msgstr "felaktigt namn (”%s”) i pragmat eller attributet %<target(\"cpu=\")%>"
 
-#: config/aarch64/aarch64.c:11213
+#: config/aarch64/aarch64.c:11229
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"tune=\")%> pragma or attribute"
 msgstr "felaktigt namn (”%s”) i pragmat eller attributet %<target(\"tune=\")%>"
 
-#: config/aarch64/aarch64.c:11253
+#: config/aarch64/aarch64.c:11269
 #, gcc-internal-format
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr "värde saknas i pragmat eller attributet %<target()%>"
 
-#: config/aarch64/aarch64.c:11306 config/aarch64/aarch64.c:11483
+#: config/aarch64/aarch64.c:11322 config/aarch64/aarch64.c:11499
 #, gcc-internal-format
 msgid "malformed %<target()%> pragma or attribute"
 msgstr "felformaterat pragma eller attribut %<target()%>"
 
-#: config/aarch64/aarch64.c:11354
+#: config/aarch64/aarch64.c:11370
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr "pragmat eller attributet %<target(\"%s\")%> tar inte något argument"
 
-#: config/aarch64/aarch64.c:11362
+#: config/aarch64/aarch64.c:11378
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr "pragmat eller attributet %<target(\"%s\")%> tillåter inte en negerad form"
 
-#: config/aarch64/aarch64.c:11416
+#: config/aarch64/aarch64.c:11432
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr "pragmat eller attributet %<target(\"%s=%s\")%> är inte giltigt"
 
-#: config/aarch64/aarch64.c:11473 config/arm/arm.c:30742
-#: config/i386/i386.c:5440 config/powerpcspe/powerpcspe.c:39760
-#: config/rs6000/rs6000.c:36904 config/s390/s390.c:15746
+#: config/aarch64/aarch64.c:11489 config/arm/arm.c:30742
+#: config/i386/i386.c:5443 config/powerpcspe/powerpcspe.c:39760
+#: config/rs6000/rs6000.c:36960 config/s390/s390.c:15746
 #, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "argument till attribut %<target%> är inte en sträng"
 
-#: config/aarch64/aarch64.c:11500
+#: config/aarch64/aarch64.c:11516
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr "pragmat eller attributet %<target(\"%s\")%> är inte giltigt"
 
-#: config/aarch64/aarch64.c:11509
+#: config/aarch64/aarch64.c:11525
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr "felformaterat pragma eller attribut %<target(\"%s\")%>"
 
-#: config/aarch64/aarch64.c:13571
+#: config/aarch64/aarch64.c:13587
 #, gcc-internal-format
 msgid "%Klane %wd out of range %wd - %wd"
 msgstr "%Kbana %wd utanför intervallet %wd - %wd"
 
-#: config/aarch64/aarch64.c:13573
+#: config/aarch64/aarch64.c:13589
 #, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr "bana %wd utanför intervallet %wd - %wd"
@@ -27418,8 +27459,8 @@
 msgid "bad value %qs for -mmemory-latency"
 msgstr "felaktigt värde %qs till flaggan -mmemory-latency"
 
-#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6526
-#: config/arc/arc.c:6800 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
+#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6517
+#: config/arc/arc.c:6791 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
 #: config/tilepro/tilepro.c:3108
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -27528,11 +27569,11 @@
 #: config/arm/arm.c:7029 config/avr/avr.c:9718 config/avr/avr.c:9734
 #: config/bfin/bfin.c:4705 config/bfin/bfin.c:4766 config/bfin/bfin.c:4795
 #: config/epiphany/epiphany.c:491 config/h8300/h8300.c:5459
-#: config/i386/i386.c:6452 config/i386/i386.c:12479 config/i386/i386.c:41424
-#: config/i386/i386.c:41474 config/i386/i386.c:41544 config/m68k/m68k.c:780
+#: config/i386/i386.c:6455 config/i386/i386.c:12482 config/i386/i386.c:41418
+#: config/i386/i386.c:41468 config/i386/i386.c:41538 config/m68k/m68k.c:780
 #: config/mcore/mcore.c:3070 config/nvptx/nvptx.c:4611
 #: config/powerpcspe/powerpcspe.c:35785 config/riscv/riscv.c:2698
-#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:32982
+#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:33038
 #: config/rx/rx.c:2719 config/rx/rx.c:2745 config/s390/s390.c:1056
 #: config/s390/s390.c:1143 config/sh/sh.c:8428 config/sh/sh.c:8446
 #: config/sh/sh.c:8470 config/sh/sh.c:8541 config/sh/sh.c:8564
@@ -27542,133 +27583,133 @@
 msgid "%qE attribute only applies to functions"
 msgstr "attributet %qE är bara tillämpligt på funktioner"
 
-#: config/arc/arc.c:6425
+#: config/arc/arc.c:6416
 #, gcc-internal-format
 msgid "__builtin_arc_aligned with non-constant alignment"
 msgstr "__builtin_arc_aligned med icke konstant justering"
 
-#: config/arc/arc.c:6433
+#: config/arc/arc.c:6424
 #, gcc-internal-format
 msgid "invalid alignment value for __builtin_arc_aligned"
 msgstr "ogiltigt argument till __builtin_arc_aligned"
 
-#: config/arc/arc.c:6596
+#: config/arc/arc.c:6587
 #, gcc-internal-format
 msgid "operand 1 should be an unsigned 3-bit immediate"
 msgstr "operand 1 skall vara en teckenlöst 3-bitars omedelbar"
 
-#: config/arc/arc.c:6637 config/arc/arc.c:6734
+#: config/arc/arc.c:6628 config/arc/arc.c:6725
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (I0-I7)"
 msgstr "operand 2 skall vara ett teckenlöst 3-bitars värde (I0-I7)"
 
-#: config/arc/arc.c:6670 config/arc/arc.c:6702
+#: config/arc/arc.c:6661 config/arc/arc.c:6693
 #, gcc-internal-format
 msgid "operand 1 should be an unsigned 3-bit value (I0-I7)"
 msgstr "operand 1 skall vara ett teckenlöst 3-bitars värde (I0-I7)"
 
-#: config/arc/arc.c:6674 config/arc/arc.c:6706
+#: config/arc/arc.c:6665 config/arc/arc.c:6697
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 8-bit value"
 msgstr "operand 2 skall vara ett teckenlöst 8-bitars värde"
 
-#: config/arc/arc.c:6738
+#: config/arc/arc.c:6729
 #, gcc-internal-format
 msgid "operand 3 should be an unsigned 8-bit value"
 msgstr "operand 3 skall vara ett teckenlöst 8-bitars värde"
 
-#: config/arc/arc.c:6771
+#: config/arc/arc.c:6762
 #, gcc-internal-format
 msgid "operand 4 should be an unsigned 8-bit value (0-255)"
 msgstr "operand 4 skall vara ett teckenlöst 8-bitars värde (0-255)"
 
-#: config/arc/arc.c:6775
+#: config/arc/arc.c:6766
 #, gcc-internal-format
 msgid "operand 3 should be an unsigned 3-bit value (I0-I7)"
 msgstr "operand 3 skall vara ett teckenlöst 3-bitars värde (I0-I7)"
 
-#: config/arc/arc.c:6782
+#: config/arc/arc.c:6773
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (subreg 0-7)"
 msgstr "operand 2 skall vara ett teckenlöst 3-bitars värde (subreg 0-7)"
 
-#: config/arc/arc.c:6785
+#: config/arc/arc.c:6776
 #, gcc-internal-format
 msgid "operand 2 should be an even 3-bit value (subreg 0,2,4,6)"
 msgstr "operand 2 skall vara ett jämnt 3-bitars värde (subreg 0,2,4,6)"
 
-#: config/arc/arc.c:6832
+#: config/arc/arc.c:6823
 #, gcc-internal-format, gfc-internal-format
 msgid "builtin requires an immediate for operand %d"
 msgstr "inbyggd behöver en omedelbar som operand %d"
 
-#: config/arc/arc.c:6837
+#: config/arc/arc.c:6828
 #, gcc-internal-format, gfc-internal-format
 msgid "operand %d should be a 6 bit unsigned immediate"
 msgstr "operand %d skall vara en teckenlös 6-bitars omedelbar"
 
-#: config/arc/arc.c:6841
+#: config/arc/arc.c:6832
 #, gcc-internal-format, gfc-internal-format
 msgid "operand %d should be a 8 bit unsigned immediate"
 msgstr "operand %d skall vara en teckenlös 8-bitars omedelbar"
 
-#: config/arc/arc.c:6845
+#: config/arc/arc.c:6836
 #, gcc-internal-format, gfc-internal-format
 msgid "operand %d should be a 3 bit unsigned immediate"
 msgstr "operand %d skall vara en teckenlös 3-bitars omedelbar"
 
-#: config/arc/arc.c:6848
+#: config/arc/arc.c:6839
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown builtin immediate operand type for operand %d"
 msgstr "okänd inbyggd omedelbar operandtyp för operand %d"
 
-#: config/arc/arc.c:6899
+#: config/arc/arc.c:6890
 #, gcc-internal-format
 msgid "register number must be a compile-time constant. Try giving higher optimization levels"
 msgstr "registernummer måste vara en konstant vid kompileringstillfället.  Försök att ange högre optimeringsnivåer"
 
-#: config/arc/arc.c:7685
+#: config/arc/arc.c:7747
 #, gcc-internal-format
 msgid "Insn addresses not set after shorten_branches"
 msgstr "Instruktionsadresser sätts inte efter shorten_branches"
 
-#: config/arc/arc.c:7894
+#: config/arc/arc.c:7956
 #, gcc-internal-format
 msgid "insn addresses not freed"
 msgstr "instruktionsadressen inte frigjord"
 
-#: config/arc/arc.c:10682
+#: config/arc/arc.c:10670
 #, gcc-internal-format
 msgid "%qE attribute only valid for ARCv2 architecture"
 msgstr "attributet %qE är bara giltigt för arkitekturen ARCv2"
 
-#: config/arc/arc.c:10690 config/arc/arc.c:10729
+#: config/arc/arc.c:10678 config/arc/arc.c:10717
 #, gcc-internal-format
 msgid "argument of %qE attribute is missing"
 msgstr "argumentet till attributet %qE saknas"
 
-#: config/arc/arc.c:10701 config/arc/arc.c:10740 config/arc/arc.c:10842
+#: config/arc/arc.c:10689 config/arc/arc.c:10728 config/arc/arc.c:10830
 #: config/avr/avr.c:9790
 #, gcc-internal-format
 msgid "%qE attribute allows only an integer constant argument"
 msgstr "attributet %qE tillåter endast en heltalskonstant som argument"
 
-#: config/arc/arc.c:10721
+#: config/arc/arc.c:10709
 #, gcc-internal-format
 msgid "%qE attribute only valid for ARC EM architecture"
 msgstr "attributet %qE är bara giltigt för arkitekturen ARC EM"
 
-#: config/arc/arc.c:10776
+#: config/arc/arc.c:10764
 #, gcc-internal-format
 msgid "%qE attribute only applies to types"
 msgstr "attributet %qE är bara tillämpligt på typer"
 
-#: config/arc/arc.c:10782
+#: config/arc/arc.c:10770
 #, gcc-internal-format
 msgid "argument of %qE attribute ignored"
 msgstr "argumentet till attributet %qE ignoreras"
 
-#: config/arc/arc.c:10832 config/avr/avr.c:9777 config/bfin/bfin.c:4827
+#: config/arc/arc.c:10820 config/avr/avr.c:9777 config/bfin/bfin.c:4827
 #: config/i386/winnt.c:63 config/msp430/msp430.c:2018
 #: config/nvptx/nvptx.c:4634
 #, gcc-internal-format
@@ -27675,174 +27716,174 @@
 msgid "%qE attribute only applies to variables"
 msgstr "attributet %qE är bara tillämpligt på variabler"
 
-#: config/arm/arm-builtins.c:2370
+#: config/arm/arm-builtins.c:2380
 #, gcc-internal-format
 msgid "this builtin is not supported for this target"
 msgstr "denna inbyggda stödjs inte på denna målarkitektur"
 
-#: config/arm/arm-builtins.c:2475
+#: config/arm/arm-builtins.c:2485
 #, gcc-internal-format
 msgid "You must enable NEON instructions (e.g. -mfloat-abi=softfp -mfpu=neon) to use these intrinsics."
 msgstr "Du måste aktivera NEON-instruktioner (t.ex. -mfloat-abi=softfp -mfpu=neon) för att använda dessa inbyggda."
 
-#: config/arm/arm-builtins.c:2513
+#: config/arm/arm-builtins.c:2523
 #, gcc-internal-format
 msgid "You must enable VFP instructions to use these intrinsics."
 msgstr "Du måste aktivera VFP-instruktioner för att använda dessa inbyggda."
 
-#: config/arm/arm-builtins.c:2573
+#: config/arm/arm-builtins.c:2583
 #, gcc-internal-format
 msgid "You must enable crypto instructions (e.g. include -mfloat-abi=softfp -mfpu=crypto-neon...) to use these intrinsics."
 msgstr "Du måste aktivera kryptoinstruktioner (t.ex. inkludera -mfloat-abi=softfp -mfpu=crypto-neon …) för att använda dessa inbyggda."
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:2633 config/arm/arm-builtins.c:2737
+#: config/arm/arm-builtins.c:2643 config/arm/arm-builtins.c:2747
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr "en väljare måste vara en omedelbar"
 
-#: config/arm/arm-builtins.c:2641 config/arm/arm-builtins.c:2686
-#: config/arm/arm-builtins.c:2744 config/arm/arm-builtins.c:2753
+#: config/arm/arm-builtins.c:2651 config/arm/arm-builtins.c:2696
+#: config/arm/arm-builtins.c:2754 config/arm/arm-builtins.c:2763
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr "intervallet för väljaren skall vara inom 0 till 7"
 
-#: config/arm/arm-builtins.c:2646 config/arm/arm-builtins.c:2755
+#: config/arm/arm-builtins.c:2656 config/arm/arm-builtins.c:2765
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr "intervallet för väljaren skall vara inom 0 till 3"
 
-#: config/arm/arm-builtins.c:2651 config/arm/arm-builtins.c:2757
+#: config/arm/arm-builtins.c:2661 config/arm/arm-builtins.c:2767
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr "intervallet för väljaren skall vara inom 0 till 1"
 
-#: config/arm/arm-builtins.c:2823
+#: config/arm/arm-builtins.c:2833
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr "mask måste vara en omedelbar"
 
-#: config/arm/arm-builtins.c:2828
+#: config/arm/arm-builtins.c:2838
 #, gcc-internal-format
 msgid "the range of mask should be in 0 to 255"
 msgstr "intervallet för masken skall vara i 0 till 255"
 
-#: config/arm/arm-builtins.c:3016
+#: config/arm/arm-builtins.c:3026
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr "intervallet för antal skall vara inom 0 till 32.  kontrollera den inbyggda _mm_rori_pi16 i koden."
 
-#: config/arm/arm-builtins.c:3018
+#: config/arm/arm-builtins.c:3028
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr "intervallet för antal skall vara inom 0 till 32.  kontrollera den inbyggda _mm_rori_pi32 i koden."
 
-#: config/arm/arm-builtins.c:3020
+#: config/arm/arm-builtins.c:3030
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr "intervallet för antal skall vara inom 0 till 32.  kontrollera den inbyggda _mm_ror_pi16 i koden."
 
-#: config/arm/arm-builtins.c:3022
+#: config/arm/arm-builtins.c:3032
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr "intervallet för antal skall vara inom 0 till 32.  kontrollera den inbyggda _mm_ror_pi32 i koden."
 
-#: config/arm/arm-builtins.c:3028
+#: config/arm/arm-builtins.c:3038
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr "intervallet för antal skall vara inom 0 till 64.  kontrollera den inbyggda _mm_rori_si64 i koden."
 
-#: config/arm/arm-builtins.c:3030
+#: config/arm/arm-builtins.c:3040
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr "intervallet för antal skall vara inom 0 till 64.  kontrollera den inbyggda _mm_ror_si64 i koden."
 
-#: config/arm/arm-builtins.c:3035
+#: config/arm/arm-builtins.c:3045
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_srli_pi16 i koden."
 
-#: config/arm/arm-builtins.c:3037
+#: config/arm/arm-builtins.c:3047
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_srli_pi32 i koden."
 
-#: config/arm/arm-builtins.c:3039
+#: config/arm/arm-builtins.c:3049
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_srli_si64 i koden."
 
-#: config/arm/arm-builtins.c:3041
+#: config/arm/arm-builtins.c:3051
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_slli_pi16 i koden."
 
-#: config/arm/arm-builtins.c:3043
+#: config/arm/arm-builtins.c:3053
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_slli_pi32 i koden."
 
-#: config/arm/arm-builtins.c:3045
+#: config/arm/arm-builtins.c:3055
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_slli_si64 i koden."
 
-#: config/arm/arm-builtins.c:3047
+#: config/arm/arm-builtins.c:3057
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_srai_pi16 i koden."
 
-#: config/arm/arm-builtins.c:3049
+#: config/arm/arm-builtins.c:3059
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_srai_pi32 i koden."
 
-#: config/arm/arm-builtins.c:3051
+#: config/arm/arm-builtins.c:3061
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_srai_si64 i koden."
 
-#: config/arm/arm-builtins.c:3053
+#: config/arm/arm-builtins.c:3063
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_srl_pi16 i koden."
 
-#: config/arm/arm-builtins.c:3055
+#: config/arm/arm-builtins.c:3065
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_srl_pi32 i koden."
 
-#: config/arm/arm-builtins.c:3057
+#: config/arm/arm-builtins.c:3067
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_srl_si64 i koden."
 
-#: config/arm/arm-builtins.c:3059
+#: config/arm/arm-builtins.c:3069
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_sll_pi16 i koden."
 
-#: config/arm/arm-builtins.c:3061
+#: config/arm/arm-builtins.c:3071
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_sll_pi32 i koden."
 
-#: config/arm/arm-builtins.c:3063
+#: config/arm/arm-builtins.c:3073
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_sll_si64 i koden."
 
-#: config/arm/arm-builtins.c:3065
+#: config/arm/arm-builtins.c:3075
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_sra_pi16 i koden."
 
-#: config/arm/arm-builtins.c:3067
+#: config/arm/arm-builtins.c:3077
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_sra_pi32 i koden."
 
-#: config/arm/arm-builtins.c:3069
+#: config/arm/arm-builtins.c:3079
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_sra_si64 i koden."
@@ -28749,555 +28790,555 @@
 msgid "can%'t set position in PCH file: %m"
 msgstr "det går inte att sätta position i PCH-fil: %m"
 
-#: config/i386/i386.c:3177
+#: config/i386/i386.c:3180
 #, gcc-internal-format
 msgid "wrong argument %qs to option %qs"
 msgstr "felaktigt argument %qs till flaggan %qs"
 
-#: config/i386/i386.c:3183
+#: config/i386/i386.c:3186
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr "storleksintervall till flaggan %qs skall vara ökande"
 
-#: config/i386/i386.c:3193
+#: config/i386/i386.c:3196
 #, gcc-internal-format
 msgid "wrong strategy name %qs specified for option %qs"
 msgstr "felaktigt strateginamn %qs angivet till flaggan %qs"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3219
+#: config/i386/i386.c:3222
 #, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr "strateginamn %qs angivet till flaggan %qs stödjs inte i 32-bitars kod"
 
-#: config/i386/i386.c:3232
+#: config/i386/i386.c:3235
 #, gcc-internal-format
 msgid "unknown alignment %qs specified for option %qs"
 msgstr "okänd justering %qs angiven till flaggan %qs"
 
-#: config/i386/i386.c:3242
+#: config/i386/i386.c:3245
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr "maxvärdet för det sista storleksintervallet skall vara -1 för flaggan %qs"
 
-#: config/i386/i386.c:3249
+#: config/i386/i386.c:3252
 #, gcc-internal-format
 msgid "too many size ranges specified in option %qs"
 msgstr "för många storleksintervall angivna i flaggan %qs"
 
-#: config/i386/i386.c:3302
+#: config/i386/i386.c:3305
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown parameter to option -mtune-ctrl: %s"
 msgstr "okänd parameter till flaggan -mtune-ctrl: %s"
 
-#: config/i386/i386.c:3726
+#: config/i386/i386.c:3729
 #, gcc-internal-format
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "Intel MCU psABI stödjs inte i %s-läge"
 
-#: config/i386/i386.c:3775
+#: config/i386/i386.c:3778
 #, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "%<-mtune=x86-64%> bör undvikas.  Använd istället det som passar av %<-mtune=k8%> och %<-mtune=generic%>"
 
-#: config/i386/i386.c:3777
+#: config/i386/i386.c:3780
 #, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr "%<target(\"tune=x86-64\")%> bör undvikas.  Använd istället det som passar av %<target(\"tune=k8\")%> och %<target(\"tune=generic\")%>"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3804
+#: config/i386/i386.c:3807
 #, gcc-internal-format
 msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgstr "-mstringop-strategy=rep_8byte stödjs inte för 32-bitarskod"
 
-#: config/i386/i386.c:3821
+#: config/i386/i386.c:3824
 #, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "adressläget %qs stödjs inte i %s-bitsläge"
 
-#: config/i386/i386.c:3833
+#: config/i386/i386.c:3836
 #, gcc-internal-format
 msgid "-mabi=ms not supported with X32 ABI"
 msgstr "-mabi=ms stödjs inte med X32 ABI"
 
-#: config/i386/i386.c:3851 config/i386/i386.c:3860 config/i386/i386.c:3872
-#: config/i386/i386.c:3883 config/i386/i386.c:3894
+#: config/i386/i386.c:3854 config/i386/i386.c:3863 config/i386/i386.c:3875
+#: config/i386/i386.c:3886 config/i386/i386.c:3897
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "kodmodellen %qs stödjs inte i %s-bitsläge"
 
-#: config/i386/i386.c:3863 config/i386/i386.c:3875
+#: config/i386/i386.c:3866 config/i386/i386.c:3878
 #, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "kodmodellen %qs stödjs inte i x32-läge"
 
-#: config/i386/i386.c:3881 config/i386/i386.c:3890 config/i386/i386.c:5213
+#: config/i386/i386.c:3884 config/i386/i386.c:3893 config/i386/i386.c:5216
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "kodmodellen %s stödjer inte PIC-läge"
 
-#: config/i386/i386.c:3918
+#: config/i386/i386.c:3921
 #, gcc-internal-format
 msgid "-masm=intel not supported in this configuration"
 msgstr "-masm=intel stödjs inte i denna konfiguration"
 
-#: config/i386/i386.c:3923
+#: config/i386/i386.c:3926
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "%i-bitsläge inte inkompilerat"
 
 # "generic" är bokstavligt argument till flaggan
-#: config/i386/i386.c:3932
+#: config/i386/i386.c:3935
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr "CPU %<generic%> kan användas endast till flaggan %<-mtune=%>"
 
 # "generic" är bokstavligt argument till flaggan
-#: config/i386/i386.c:3934
+#: config/i386/i386.c:3937
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "CPU %<generic%> kan användas endast till attributet %<target(\"tune=\")%>"
 
 # "intel" är bokstavligt argument till flaggan
-#: config/i386/i386.c:3941
+#: config/i386/i386.c:3944
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr "CPU %<intel%> kan användas endast till flaggan %<-mtune=%>"
 
 # "intel" är bokstavligt argument till flaggan
-#: config/i386/i386.c:3943
+#: config/i386/i386.c:3946
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "CPU %<intel%> kan användas endast till attributet %<target(\"tune=\")%>"
 
-#: config/i386/i386.c:3951 config/i386/i386.c:4265
+#: config/i386/i386.c:3954 config/i386/i386.c:4268
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "CPU:n du valde stödjer inte instruktionsuppsättningen x86-64"
 
-#: config/i386/i386.c:4197 config/i386/i386.c:4200
+#: config/i386/i386.c:4200 config/i386/i386.c:4203
 #, gcc-internal-format
 msgid "Intel MPX does not support x32"
 msgstr "Intel MPX stödjer inte x32"
 
-#: config/i386/i386.c:4205
+#: config/i386/i386.c:4208
 #, gcc-internal-format
 msgid "bad value (%qs) for %<-march=%> switch"
 msgstr "felaktigt värde (%qs) till flaggan %<-march=%>"
 
-#: config/i386/i386.c:4206
+#: config/i386/i386.c:4209
 #, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"arch=\")%> attribute"
 msgstr "felaktigt värde (%qs) till attributet %<target(\"arch=\")%>"
 
-#: config/i386/i386.c:4228
+#: config/i386/i386.c:4231
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "giltiga argument till flaggan %<-march=%> är: %s; menade du %qs?"
 
-#: config/i386/i386.c:4230
+#: config/i386/i386.c:4233
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr "giltiga argument till attributet %<target(\"arch=\")%> är: %s; menade du %qs?"
 
-#: config/i386/i386.c:4235
+#: config/i386/i386.c:4238
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "giltiga argument till flaggan %<-march=%> är: %s"
 
-#: config/i386/i386.c:4236
+#: config/i386/i386.c:4239
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "giltiga argument till attributet %<target(\"arch=\")%> är: %s"
 
-#: config/i386/i386.c:4284
+#: config/i386/i386.c:4287
 #, gcc-internal-format
 msgid "bad value (%qs) for %<-mtune=%> switch"
 msgstr "felaktigt värde (%qs) till flaggan %<-mtune=%>"
 
-#: config/i386/i386.c:4285
+#: config/i386/i386.c:4288
 #, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"tune=\")%> attribute"
 msgstr "felaktigt värde (%qs) till attributet %<target(\"tune=\")%>"
 
-#: config/i386/i386.c:4305
+#: config/i386/i386.c:4308
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "giltiga argument till flaggan %<-mtune=%> är: %s; menade du %qs?"
 
-#: config/i386/i386.c:4307
+#: config/i386/i386.c:4310
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr "giltiga argument till attributet %<target(\"tune=\")%> är: %s; menade du %qs?"
 
-#: config/i386/i386.c:4312
+#: config/i386/i386.c:4315
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "giltiga argument till flaggan %<-mtune=%> är: %s"
 
-#: config/i386/i386.c:4313
+#: config/i386/i386.c:4316
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "giltiga argument till attributet %<target(\"tune=\")%> är: %s"
 
-#: config/i386/i386.c:4379
+#: config/i386/i386.c:4382
 #, gcc-internal-format
 msgid "-mregparm is ignored in 64-bit mode"
 msgstr "-mregparm ignoreras i 64-bitsläge"
 
-#: config/i386/i386.c:4381
+#: config/i386/i386.c:4384
 #, gcc-internal-format
 msgid "-mregparm is ignored for Intel MCU psABI"
 msgstr "-mregparm ignoreras för Intel MCU psABI"
 
-#: config/i386/i386.c:4384
+#: config/i386/i386.c:4387
 #, gcc-internal-format, gfc-internal-format
 msgid "-mregparm=%d is not between 0 and %d"
 msgstr "-mregparm=%d är inte mellan 0 och %d"
 
-#: config/i386/i386.c:4417
+#: config/i386/i386.c:4420
 #, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "%<-mrtd%> ignoreras i 64-bitsläge"
 
-#: config/i386/i386.c:4418
+#: config/i386/i386.c:4421
 #, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "%<target(\"rtd\")%> ignoreras i 64-bitsläge"
 
-#: config/i386/i386.c:4497
+#: config/i386/i386.c:4500
 #, gcc-internal-format
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "-mpreferred-stack-boundary stödjs inte för denna målarkitektur"
 
-#: config/i386/i386.c:4500
+#: config/i386/i386.c:4503
 #, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d är inte mellan %d och %d"
 
-#: config/i386/i386.c:4523
+#: config/i386/i386.c:4526
 #, gcc-internal-format, gfc-internal-format
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr "-mincoming-stack-boundary=%d är inte mellan %d och 12"
 
-#: config/i386/i386.c:4536
+#: config/i386/i386.c:4539
 #, gcc-internal-format
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "-mnop-mcount är inte kompatibelt med denna målarkitektur"
 
-#: config/i386/i386.c:4539
+#: config/i386/i386.c:4542
 #, gcc-internal-format
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr "-mnop-mcount är inte implementerat för -fPIC"
 
-#: config/i386/i386.c:4545
+#: config/i386/i386.c:4548
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "%<-msseregparm%> använd utan SSE aktiverat"
 
-#: config/i386/i386.c:4546
+#: config/i386/i386.c:4549
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "%<target(\"sseregparm\")%> använt utan SSE aktiverat"
 
-#: config/i386/i386.c:4556
+#: config/i386/i386.c:4559
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "instruktionsuppsättningen SSE avaktiverad, använder 387-aritmetik"
 
-#: config/i386/i386.c:4563
+#: config/i386/i386.c:4566
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "instruktionsuppsättningen 387 avaktiverad, använder SSE-aritmetik"
 
-#: config/i386/i386.c:4613
+#: config/i386/i386.c:4616
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr "stackavkänning kräver %<-maccumulate-outgoing-args%> för att bli korrekt"
 
-#: config/i386/i386.c:4615
+#: config/i386/i386.c:4618
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr "stackavkänning kräver %<target(\"accumulate-outgoing-args\")%> för att bli korrekt"
 
-#: config/i386/i386.c:4629
+#: config/i386/i386.c:4632
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr "fasta ebp-register kräver %<-maccumulate-outgoing-args%>"
 
-#: config/i386/i386.c:4631
+#: config/i386/i386.c:4634
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr "fasta ebp-register kräver %<target(\"accumulate-outgoing-args\")%>"
 
-#: config/i386/i386.c:4741
+#: config/i386/i386.c:4744
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr "-mfentry stödjs inte för 32 bitar i kombination med -fpic"
 
-#: config/i386/i386.c:4744
+#: config/i386/i386.c:4747
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr "-mno-fentry är inte kompatibelt med SEH"
 
-#: config/i386/i386.c:4748
+#: config/i386/i386.c:4751
 #, gcc-internal-format
 msgid "-mcall-ms2sysv-xlogues isn%'t currently supported with SEH"
 msgstr "-mcall-ms2sysv-xlogues stödjs inte för närvarande med SEH"
 
-#: config/i386/i386.c:4813 config/powerpcspe/powerpcspe.c:5663
+#: config/i386/i386.c:4816 config/powerpcspe/powerpcspe.c:5663
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown option for -mrecip=%s"
 msgstr "okänt alternativ till -mrecip=%s"
 
-#: config/i386/i386.c:4870 config/powerpcspe/powerpcspe.c:5339
+#: config/i386/i386.c:4873 config/powerpcspe/powerpcspe.c:5339
 #, gcc-internal-format
 msgid "%qs is not a valid number in -mstack-protector-guard-offset="
 msgstr "%qs är inte ett giltigt tal i -mstack-protector-guard-offset="
 
-#: config/i386/i386.c:4875 config/powerpcspe/powerpcspe.c:5344
+#: config/i386/i386.c:4878 config/powerpcspe/powerpcspe.c:5344
 #, gcc-internal-format
 msgid "%qs is not a valid offset in -mstack-protector-guard-offset="
 msgstr "%qs är inte ett giltigt avstånd i -mstack-protector-guard-offset="
 
-#: config/i386/i386.c:4907 config/powerpcspe/powerpcspe.c:5356
+#: config/i386/i386.c:4910 config/powerpcspe/powerpcspe.c:5356
 #, gcc-internal-format
 msgid "%qs is not a valid base register in -mstack-protector-guard-reg="
 msgstr "%qs är inte ett giltigt basregister i -mstack-protector-guard-reg="
 
-#: config/i386/i386.c:5506 config/i386/i386.c:5553 config/s390/s390.c:15812
+#: config/i386/i386.c:5509 config/i386/i386.c:5556 config/s390/s390.c:15812
 #: config/s390/s390.c:15862 config/s390/s390.c:15879
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr "attribute(target(\"%s\")) är okänt"
 
-#: config/i386/i386.c:5534
+#: config/i386/i386.c:5537
 #, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr "option(”%s”) var redan angivet"
 
-#: config/i386/i386.c:5837
+#: config/i386/i386.c:5840
 #, gcc-internal-format
 msgid "interrupt and naked attributes are not compatible"
 msgstr "attributen interrupt och naked är inte kompatibla"
 
-#: config/i386/i386.c:5852
+#: config/i386/i386.c:5855
 #, gcc-internal-format
 msgid "Only DWARF debug format is supported for interrupt service routine."
 msgstr "Endast felsökningsformatet DWARF stödjs för avbrottshanteringsrutiner."
 
-#: config/i386/i386.c:5901
+#: config/i386/i386.c:5904
 #, gcc-internal-format
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "%<-mindirect-branch=%s%> och %<-mcmodel=large%> är inte kompatibla"
 
-#: config/i386/i386.c:5913
+#: config/i386/i386.c:5916
 #, gcc-internal-format
 msgid "%<-mindirect-branch=thunk-extern%>, %<-fcf-protection=branch%> and %<-fcheck-pointer-bounds%> are not compatible"
 msgstr "%<-mindirect-branch=thunk-extern%>, %<-fcf-protection=branch%> och %<--fcheck-pointer-bounds%> är inte kompatibla"
 
-#: config/i386/i386.c:5949
+#: config/i386/i386.c:5952
 #, gcc-internal-format
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "%<-mfunction-return=%s%> och %<-mcmodel=large%> är inte kompatibla"
 
-#: config/i386/i386.c:6047
+#: config/i386/i386.c:6050
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in %s service routine"
 msgstr "%s-instruktioner är inte tillåtna i en %s-hanteringsrutin"
 
-#: config/i386/i386.c:6051
+#: config/i386/i386.c:6054
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in function with no_caller_saved_registers attribute"
 msgstr "%s-instruktioner är inte tillåtna i en funktion utan något attribut no_caller_saved_registers"
 
-#: config/i386/i386.c:6465 config/i386/i386.c:6516
+#: config/i386/i386.c:6468 config/i386/i386.c:6519
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "attributen fastcall och regparm är inte kompatibla"
 
-#: config/i386/i386.c:6470
+#: config/i386/i386.c:6473
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "attributen regparam och thiscall är inte kompatibla"
 
-#: config/i386/i386.c:6477 config/i386/i386.c:41444
+#: config/i386/i386.c:6480 config/i386/i386.c:41438
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "attributet %qE kräver en heltalskonstant som argument"
 
-#: config/i386/i386.c:6483
+#: config/i386/i386.c:6486
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "argument till attributet %qE är större än %d"
 
-#: config/i386/i386.c:6508 config/i386/i386.c:6551
+#: config/i386/i386.c:6511 config/i386/i386.c:6554
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "attributen fastcall och cdecl är inte kompatibla"
 
-#: config/i386/i386.c:6512
+#: config/i386/i386.c:6515
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "attributen fastcall och stdcall är inte kompatibla"
 
-#: config/i386/i386.c:6520 config/i386/i386.c:6569
+#: config/i386/i386.c:6523 config/i386/i386.c:6572
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "attributen fastcall och thiscall är inte kompatibla"
 
-#: config/i386/i386.c:6530 config/i386/i386.c:6547
+#: config/i386/i386.c:6533 config/i386/i386.c:6550
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "attributen stdcall och cdecl är inte kompatibla"
 
-#: config/i386/i386.c:6534
+#: config/i386/i386.c:6537
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "attributen stdcall och fastcall är inte kompatibla"
 
-#: config/i386/i386.c:6538 config/i386/i386.c:6565
+#: config/i386/i386.c:6541 config/i386/i386.c:6568
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "attributen stdcall och thiscall är inte kompatibla"
 
-#: config/i386/i386.c:6555 config/i386/i386.c:6573
+#: config/i386/i386.c:6558 config/i386/i386.c:6576
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "attributen cdecl och thiscall är inte kompatibla"
 
-#: config/i386/i386.c:6561
+#: config/i386/i386.c:6564
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "attributet %qE används för annat än klassmetod"
 
-#: config/i386/i386.c:6805
+#: config/i386/i386.c:6808
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "anrop av %qD med attributet sseregparm utan SSE/SSE2 aktiverat"
 
-#: config/i386/i386.c:6808
+#: config/i386/i386.c:6811
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "anrop av %qT med attributet sseregparm utan SSE/SSE2 aktiverat"
 
-#: config/i386/i386.c:7126
+#: config/i386/i386.c:7129
 #, gcc-internal-format
 msgid "X32 does not support ms_abi attribute"
 msgstr "X32 stödjer inte attributet ms_abi"
 
-#: config/i386/i386.c:7160
+#: config/i386/i386.c:7163
 #, gcc-internal-format
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr "ms_hook_prologue är inte kompatibelt med nästade funktioner"
 
-#: config/i386/i386.c:7502
+#: config/i386/i386.c:7505
 #, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr "AVX512F-vektorargument utan AVX512F aktiverat ändrar ABI:et"
 
-#: config/i386/i386.c:7508
+#: config/i386/i386.c:7511
 #, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr "AVX512F-vektorretur utan AVX512F aktiverat ändrar ABI:et"
 
-#: config/i386/i386.c:7522
+#: config/i386/i386.c:7525
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr "AVX-vektorargument utan AVX aktiverat ändrar ABI:et"
 
-#: config/i386/i386.c:7528
+#: config/i386/i386.c:7531
 #, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr "AVX-vektorretur utan AVX aktiverat ändrar ABI:et"
 
-#: config/i386/i386.c:7544
+#: config/i386/i386.c:7547
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr "SSE-vektorargument utan SSE aktiverat ändrar ABI:et"
 
-#: config/i386/i386.c:7550
+#: config/i386/i386.c:7553
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr "SSE-vektorretur utan SSE aktiverat ändrar ABI:et"
 
-#: config/i386/i386.c:7566
+#: config/i386/i386.c:7569
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr "MMX-vektorargument utan MMX aktiverat ändrar ABI:et"
 
-#: config/i386/i386.c:7572
+#: config/i386/i386.c:7575
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr "MMX-vektorretur utan MMX aktiverat ändrar ABI:et"
 
-#: config/i386/i386.c:7754
+#: config/i386/i386.c:7757
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr "ABI:et för att skicka en post med en flexibel vektormedlem har ändrats i GCC 4.4"
 
-#: config/i386/i386.c:7871
+#: config/i386/i386.c:7874
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr "ABI:et för att skicka unioner med long double har ändrats i GCC 4.4"
 
-#: config/i386/i386.c:7989
+#: config/i386/i386.c:7992
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr "ABI:et för att skicka en post med complex float medlem har ändrats i GCC 4.4"
 
-#: config/i386/i386.c:8152
+#: config/i386/i386.c:8155
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr "SSE-registerretur med SSE avaktiverat"
 
-#: config/i386/i386.c:8158
+#: config/i386/i386.c:8161
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr "SSE-registerargument med SSE avaktiverat"
 
-#: config/i386/i386.c:8174
+#: config/i386/i386.c:8177
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr "x87-registerretur med x87 avaktiverat"
 
-#: config/i386/i386.c:8471 config/i386/i386.c:8750 config/i386/i386.c:9276
+#: config/i386/i386.c:8474 config/i386/i386.c:8753 config/i386/i386.c:9279
 #, gcc-internal-format
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr "anrop av %qD med SSE-anropskonvention utan SSE/SSE2 aktiverat"
 
-#: config/i386/i386.c:8473 config/i386/i386.c:8752 config/i386/i386.c:9278
+#: config/i386/i386.c:8476 config/i386/i386.c:8755 config/i386/i386.c:9281
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr "detta är ett fel i GCC som kan gås runt genom att lägga till attributet used till den anropade funktionen"
 
-#: config/i386/i386.c:9178
+#: config/i386/i386.c:9181
 #, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr "ABI:et för att skicka parametrar med %d-bytejustering har ändrats i GCC 4.6"
 
-#: config/i386/i386.c:11601
+#: config/i386/i386.c:11604
 #, gcc-internal-format, gfc-internal-format
 msgid "-mcall-ms2sysv-xlogues is not compatible with %s"
 msgstr "-mcall-ms2sysv-xlogues är inte kompatibel med %s"
 
-#: config/i386/i386.c:13593
+#: config/i386/i386.c:13596
 #, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr "attributet ms_hook_prologue är inte kompatibelt med -mfentry i 32-bitsläge"
 
-#: config/i386/i386.c:13683
+#: config/i386/i386.c:13686
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr "Dynamic Realign Argument Pointer (DRAP) stödjs inte i avbrottshanteringsrutiner.  Detta kan gås runt genom att undvika funktioner med sammansatta returvärden."
 
-#: config/i386/i386.c:14970
+#: config/i386/i386.c:14973
 #, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr "-fsplit-stack stödjer inte fastcall med nästade funktioner"
 
-#: config/i386/i386.c:14990
+#: config/i386/i386.c:14993
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
 msgstr "-fsplit-stack stödjer inte 2 registerparametrar för en nästad funktion"
@@ -29304,312 +29345,312 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:15001
+#: config/i386/i386.c:15004
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr "-fsplit-stack stödjer inte 3 registerparametrar"
 
-#: config/i386/i386.c:17939
+#: config/i386/i386.c:17942
 #, gcc-internal-format
 msgid "'V' modifier on non-integer register"
 msgstr "modifieraren ”V” på ett register som inte är heltal"
 
-#: config/i386/i386.c:17950 config/i386/i386.c:17964
+#: config/i386/i386.c:17953 config/i386/i386.c:17967
 #, gcc-internal-format
 msgid "unsupported size for integer register"
 msgstr "ej stödd storlek för heltalsregister"
 
-#: config/i386/i386.c:17996
+#: config/i386/i386.c:17999
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr "utökade register har inga höga halvor"
 
-#: config/i386/i386.c:18011
+#: config/i386/i386.c:18014
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr "ej stödd operandstorlek för utökat register"
 
-#: config/i386/i386.c:18202
+#: config/i386/i386.c:18205
 #, gcc-internal-format
 msgid "non-integer operand used with operand code 'z'"
 msgstr "operand som inte är heltal använt med operandkod ”z”"
 
-#: config/i386/i386.c:28467
+#: config/i386/i386.c:28470
 #, gcc-internal-format
 msgid "interrupt service routine can't be called directly"
 msgstr "avbrottshanteringsrutiner kan inte anropas direkt"
 
-#: config/i386/i386.c:29995
+#: config/i386/i386.c:29998
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in -fabi-version=12 (GCC 8)"
 msgstr "den tomma klassen %qT parameterskickande ABI ändras i -fabi-version=12 (GCC 8)"
 
-#: config/i386/i386.c:32435
+#: config/i386/i386.c:32438
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr "Ingen avsändare funnen för versionsattributen"
 
-#: config/i386/i386.c:32485
+#: config/i386/i386.c:32488
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for %s"
 msgstr "Ingen avsändare funnen för %s"
 
-#: config/i386/i386.c:32495
+#: config/i386/i386.c:32498
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr "Ingen avsändare funnen för versionsattributen: %s"
 
-#: config/i386/i386.c:32657
+#: config/i386/i386.c:32660
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr "Funktionsversioner kan inte markeras som gnu_inline, kropparna måste vara genererade"
 
-#: config/i386/i386.c:32662 config/i386/i386.c:32938
-#: config/rs6000/rs6000.c:37850
+#: config/i386/i386.c:32665 config/i386/i386.c:32941
+#: config/rs6000/rs6000.c:37906
 #, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "Multiversionering av virtuell funktion stödjs inte"
 
-#: config/i386/i386.c:32795 config/rs6000/rs6000.c:37607
+#: config/i386/i386.c:32798 config/rs6000/rs6000.c:37663
 #, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "multiversionering behöver ifunc som inte stödjs på detta mål"
 
-#: config/i386/i386.c:33207
+#: config/i386/i386.c:33210
 #, gcc-internal-format
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr "Parameter till inbyggd måste vara en strängkonstant eller -litteral"
 
-#: config/i386/i386.c:33232 config/i386/i386.c:33282
+#: config/i386/i386.c:33235 config/i386/i386.c:33285
 #, gcc-internal-format, gfc-internal-format
 msgid "Parameter to builtin not valid: %s"
 msgstr "Parameter till inbyggd är inte giltig: %s"
 
-#: config/i386/i386.c:33975 config/i386/i386.c:35415
+#: config/i386/i386.c:33978 config/i386/i386.c:35418
 #, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "det sista argumentet måste vara en 2-bitars omedelbar"
 
-#: config/i386/i386.c:34370
+#: config/i386/i386.c:34373
 #, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "det femte argumentet måste vara en 8-bitars omedelbar"
 
-#: config/i386/i386.c:34465
+#: config/i386/i386.c:34468
 #, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "det tredje argumentet måste vara en 8-bitars omedelbar"
 
-#: config/i386/i386.c:35346
+#: config/i386/i386.c:35349
 #, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "det sista argumentet måste vara en 1-bits omedelbar"
 
-#: config/i386/i386.c:35361
+#: config/i386/i386.c:35364
 #, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "det sista argumentet måste vara en 3-bitars omedelbar"
 
-#: config/i386/i386.c:35394
+#: config/i386/i386.c:35397
 #, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "det sista argumentet måste vara en 4-bitars omedelbar"
 
-#: config/i386/i386.c:35434
+#: config/i386/i386.c:35437
 #, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "det sista argumentet måste vara en 1-bits omedelbar"
 
-#: config/i386/i386.c:35447
+#: config/i386/i386.c:35450
 #, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "det sista argumentet måste vara en 5-bitars omedelbar"
 
-#: config/i386/i386.c:35457
+#: config/i386/i386.c:35460
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "det näst sista argumentet måste vara en 8-bitars omedelbar"
 
-#: config/i386/i386.c:35462 config/i386/i386.c:36249
+#: config/i386/i386.c:35465 config/i386/i386.c:36252
 #, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "det sista argumentet måste vara en 8-bitars omedelbar"
 
-#: config/i386/i386.c:35596
+#: config/i386/i386.c:35599
 #, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr "det tredje argumentet måste vara en jämförelsekonstant"
 
-#: config/i386/i386.c:35601
+#: config/i386/i386.c:35604
 #, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr "felaktigt jämförelsesätt"
 
-#: config/i386/i386.c:35607 config/i386/i386.c:35814
+#: config/i386/i386.c:35610 config/i386/i386.c:35817
 #, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr "felaktig avrundningsoperand"
 
-#: config/i386/i386.c:35796
+#: config/i386/i386.c:35799
 #, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "det omedelbara argumentet måste vara en 4-bitars omedelbar"
 
-#: config/i386/i386.c:35802
+#: config/i386/i386.c:35805
 #, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "det omedelbara argumentet måste vara en 5-bitars omedelbar"
 
-#: config/i386/i386.c:35805
+#: config/i386/i386.c:35808
 #, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "det omedelbara argumentet måste vara en 8-bitars omedelbar"
 
-#: config/i386/i386.c:36247
+#: config/i386/i386.c:36250
 #, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "det sista argumentet måste vara en 32-bitars omedelbar"
 
-#: config/i386/i386.c:36329 config/powerpcspe/powerpcspe.c:16219
-#: config/rs6000/rs6000.c:15304
+#: config/i386/i386.c:36332 config/powerpcspe/powerpcspe.c:16219
+#: config/rs6000/rs6000.c:15348
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr "väljaren måste vara en heltalskonstant i intervallet 0..%wi"
 
-#: config/i386/i386.c:36539
+#: config/i386/i386.c:36542
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr "%qE behöver en okänd isa-flagga"
 
-#: config/i386/i386.c:36543
+#: config/i386/i386.c:36546
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "%qE behöver isa-flaggan %s"
 
-#: config/i386/i386.c:37381
+#: config/i386/i386.c:37375
 #, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "sista argumentet måste vara en omedelbar"
 
-#: config/i386/i386.c:38108 config/i386/i386.c:38290
+#: config/i386/i386.c:38102 config/i386/i386.c:38284
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "det sista argumentet ha skala 1, 2, 4, 8"
 
-#: config/i386/i386.c:38343
+#: config/i386/i386.c:38337
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "det fjärde argumentet ha skala 1, 2, 4, 8"
 
-#: config/i386/i386.c:38349
+#: config/i386/i386.c:38343
 #, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr "felaktig tipsoperand"
 
-#: config/i386/i386.c:38368
+#: config/i386/i386.c:38362
 #, gcc-internal-format
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr "argumentet till xabort måste vara en 8-bitars omedelbar"
 
-#: config/i386/i386.c:41431
+#: config/i386/i386.c:41425
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "attributet %qE är bara tillgängligt för 32 bitar"
 
-#: config/i386/i386.c:41452
+#: config/i386/i386.c:41446
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "argumentet till attributet %qE är varken noll eller ett"
 
-#: config/i386/i386.c:41485 config/i386/i386.c:41494
+#: config/i386/i386.c:41479 config/i386/i386.c:41488
 #, gcc-internal-format
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr "attributen ms_abi och sysv_abi är inte kompatibla"
 
-#: config/i386/i386.c:41530 config/powerpcspe/powerpcspe.c:35868
-#: config/rs6000/rs6000.c:33065
+#: config/i386/i386.c:41524 config/powerpcspe/powerpcspe.c:35868
+#: config/rs6000/rs6000.c:33121
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "%qE-inkompatibelt attribut ignorerat"
 
-#: config/i386/i386.c:41555 config/i386/i386.c:41577 config/ia64/ia64.c:815
+#: config/i386/i386.c:41549 config/i386/i386.c:41571 config/ia64/ia64.c:815
 #: config/s390/s390.c:1153
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "attributet %qE kräver en strängkonstant som argument"
 
-#: config/i386/i386.c:41565 config/i386/i386.c:41587 config/s390/s390.c:1182
+#: config/i386/i386.c:41559 config/i386/i386.c:41581 config/s390/s390.c:1182
 #, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "argumentet till attributet %qE är inte (keep|thunk|thunk-inline|thunk-extern)"
 
-#: config/i386/i386.c:41619
+#: config/i386/i386.c:41613
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr "avbrottshanteringsrutiner skall ha en pekare som första argument"
 
 # "unsigned %sint" är tänkt att expanderas till C-syntax
-#: config/i386/i386.c:41626
+#: config/i386/i386.c:41620
 #, gcc-internal-format, gfc-internal-format
 msgid "interrupt service routine should have unsigned %sint as the second argument"
 msgstr "avbrottshanteringsrutiner skall ha unsigned %sint som andra argument"
 
-#: config/i386/i386.c:41636
+#: config/i386/i386.c:41630
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr "avbrottshanteringrutiner kan endast ha ett pekarargument och ett valfritt heltalsargument"
 
-#: config/i386/i386.c:41639
+#: config/i386/i386.c:41633
 #, gcc-internal-format
 msgid "interrupt service routine can't have non-void return value"
 msgstr "avbrottshanteringsrutiner kan inte ha ett annat returvärde än void"
 
-#: config/i386/i386.c:44676
+#: config/i386/i386.c:44670
 #, gcc-internal-format
 msgid "alternatives not allowed in asm flag output"
 msgstr "alternativ är inte tillåtna i asm-flaggutdata"
 
-#: config/i386/i386.c:44740
+#: config/i386/i386.c:44734
 #, gcc-internal-format
 msgid "unknown asm flag output %qs"
 msgstr "okänd asm-flaggutdata %qs"
 
-#: config/i386/i386.c:44769
+#: config/i386/i386.c:44763
 #, gcc-internal-format
 msgid "invalid type for asm flag output"
 msgstr "ogiltig typ för asm-flaggutdata"
 
-#: config/i386/i386.c:50634
+#: config/i386/i386.c:50628
 #, gcc-internal-format
 msgid "unknown architecture specific memory model"
 msgstr "okänd arkitekturspecifik minnesmodell"
 
-#: config/i386/i386.c:50641
+#: config/i386/i386.c:50635
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr "HLE_ACQUIRE används inte med ACQUIRE eller starkare minnesmodell"
 
-#: config/i386/i386.c:50647
+#: config/i386/i386.c:50641
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr "HLE_RELEASE används inte med RELEASE eller starkare minnesmodell"
 
-#: config/i386/i386.c:50671 config/i386/i386.c:50787
+#: config/i386/i386.c:50665 config/i386/i386.c:50781
 #, gcc-internal-format, gfc-internal-format
 msgid "unsupported simdlen %d"
 msgstr "ej stödd simdlen: %d"
 
-#: config/i386/i386.c:50690
+#: config/i386/i386.c:50684
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd"
 msgstr "returtyp %qT stödjs ej för simd"
 
-#: config/i386/i386.c:50712
+#: config/i386/i386.c:50706
 #, gcc-internal-format
 msgid "unsupported argument type %qT for simd"
 msgstr "argumenttyp %qT som inte stödjs till simd"
 
-#: config/i386/i386.c:51033
+#: config/i386/i386.c:51027
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr "Pekarkontrolleraren kräver stöd för MPX på detta mål.  Använd flaggan -mmpx för att aktivera MPX."
@@ -29830,7 +29871,7 @@
 msgstr "interrupt_thread är tillgängligt endast för fido"
 
 #: config/m68k/m68k.c:1128 config/powerpcspe/powerpcspe.c:28512
-#: config/rs6000/rs6000.c:25791
+#: config/rs6000/rs6000.c:25868
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "stackgränsuttryck stödjs inte"
@@ -30409,58 +30450,58 @@
 
 #. Trampoline is not supported on reduced-set registers yet.
 #: config/nds32/nds32.c:2327 config/nds32/nds32.c:2381
-#: config/nds32/nds32.c:3127 config/nds32/nds32.c:3201
-#: config/nds32/nds32.c:3216 config/nds32/nds32.c:3222
-#: config/nds32/nds32.c:3284 config/nds32/nds32.c:3290
-#: config/nds32/nds32.c:3322
+#: config/nds32/nds32.c:3128 config/nds32/nds32.c:3202
+#: config/nds32/nds32.c:3217 config/nds32/nds32.c:3223
+#: config/nds32/nds32.c:3285 config/nds32/nds32.c:3291
+#: config/nds32/nds32.c:3323
 #, gcc-internal-format
 msgid "a nested function is not supported for reduced registers"
 msgstr "en nästad funktion stödjs inte för reducerade register"
 
 #. The enum index value for array size is out of range.
-#: config/nds32/nds32.c:3025
+#: config/nds32/nds32.c:3026
 #, gcc-internal-format
 msgid "intrinsic register index is out of range"
 msgstr "inbyggt registerindex är utanför sitt intervall"
 
-#: config/nds32/nds32.c:3041 config/nds32/nds32.c:3048
-#: config/nds32/nds32.c:3055 config/nds32/nds32.c:3062
-#: config/nds32/nds32.c:3069
+#: config/nds32/nds32.c:3042 config/nds32/nds32.c:3049
+#: config/nds32/nds32.c:3056 config/nds32/nds32.c:3063
+#: config/nds32/nds32.c:3070
 #, gcc-internal-format
 msgid "CCTL intrinsic function subtype out of range!"
 msgstr "Inbyggda CCTL-funktionens undertyp är utanför sitt intervall!"
 
-#: config/nds32/nds32.c:3508
+#: config/nds32/nds32.c:3509
 #, gcc-internal-format
 msgid "invalid id value for interrupt/exception attribute"
 msgstr "ogiltigt id-värde för avbrotts-/undantagsattribut"
 
-#: config/nds32/nds32.c:3536
+#: config/nds32/nds32.c:3537
 #, gcc-internal-format
 msgid "invalid id value for reset attribute"
 msgstr "ogiltigt id-värde för återställningsattribut"
 
-#: config/nds32/nds32.c:3552
+#: config/nds32/nds32.c:3553
 #, gcc-internal-format
 msgid "invalid nmi function for reset attribute"
 msgstr "ogiltig nmi-funktion för återställningsattribut"
 
-#: config/nds32/nds32.c:3565
+#: config/nds32/nds32.c:3566
 #, gcc-internal-format
 msgid "invalid warm function for reset attribute"
 msgstr "ogiltig warm-funktion för återställningsattribut"
 
-#: config/nds32/nds32.c:3638
+#: config/nds32/nds32.c:3639
 #, gcc-internal-format
 msgid "Disable FPU ISA, the ABI option must be enable '-mfloat-abi=soft'"
 msgstr "Avaktivera FPU-ISA, ABI-flaggan måste vara att aktivera ”-mfloat-abi=soft”"
 
-#: config/nds32/nds32.c:3641
+#: config/nds32/nds32.c:3642
 #, gcc-internal-format
 msgid "'-mabi=2fp+' option only support when FPU available, must be enable '-mext-fpu-sp' or '-mext-fpu-dp'"
 msgstr "Flaggan ”-mabi=2fp+” stödjs endast när en FPU är tillgänglig, måste vara aktiverad ”-mext-fpu-sp” eller ”-mext-fpu-dp”"
 
-#: config/nds32/nds32.c:3647
+#: config/nds32/nds32.c:3648
 #, gcc-internal-format
 msgid "position-independent code not supported"
 msgstr "positionsoberoende kod stödjs inte"
@@ -30794,12 +30835,12 @@
 msgid "junk at end of #pragma longcall"
 msgstr "skräp vid slutet av #pragma longcall"
 
-#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6154
+#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6152
 #, gcc-internal-format
 msgid "vec_lvsl is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr "vec_lvsl bör undvikas för omvänd byteordning; använd tilldelning för ojusterade laddningar och lagringar"
 
-#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6158
+#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6156
 #, gcc-internal-format
 msgid "vec_lvsr is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr "vec_lvsr bör undvikas för omvänd byteordning; använd tilldelning för ojusterade laddningar och lagringar"
@@ -30849,7 +30890,7 @@
 msgid "vec_insert only accepts 3 arguments"
 msgstr "vec_insert tar endast 3 argument"
 
-#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6868
+#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6866
 #, gcc-internal-format
 msgid "passing arg %d of %qE discards qualifiers from pointer target type"
 msgstr "att skicka argument %d till %qE kastar kvalificerare från pekarmåltyp"
@@ -30934,7 +30975,7 @@
 msgid "target attribute or pragma changes SPE ABI"
 msgstr "målattribut eller pragma ändrar SPE ABI"
 
-#: config/powerpcspe/powerpcspe.c:4351 config/rs6000/rs6000.c:4223
+#: config/powerpcspe/powerpcspe.c:4351 config/rs6000/rs6000.c:4243
 #, gcc-internal-format
 msgid "AltiVec not supported in this target"
 msgstr "AltiVec stödjs inte på denna målarkitektur"
@@ -31080,7 +31121,7 @@
 msgid "-mvsx-small-integer requires -mpower8-vector, -mupper-regs-di, and -mdirect-move"
 msgstr "-mvsx-small-integer kräver -mpower8-vector, -mupper-regs-di och -mdirect-move"
 
-#: config/powerpcspe/powerpcspe.c:4959 config/rs6000/rs6000.c:4601
+#: config/powerpcspe/powerpcspe.c:4959 config/rs6000/rs6000.c:4628
 #, gcc-internal-format
 msgid "target attribute or pragma changes long double size"
 msgstr "målattribut eller pragma ändrar storlek på long double"
@@ -31121,22 +31162,22 @@
 msgstr "okänd ABI-typ (%s) till vektoriseringsbibliotek för flaggan -mveclibabi="
 
 #: config/powerpcspe/powerpcspe.c:5140 config/powerpcspe/powerpcspe.c:5155
-#: config/rs6000/rs6000.c:4766 config/rs6000/rs6000.c:4781
+#: config/rs6000/rs6000.c:4791 config/rs6000/rs6000.c:4806
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr "målattribut eller pragma ändrar AltiVec ABI"
 
-#: config/powerpcspe/powerpcspe.c:5168 config/rs6000/rs6000.c:4794
+#: config/powerpcspe/powerpcspe.c:5168 config/rs6000/rs6000.c:4819
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr "målattribut eller pragma ändrar darwin64 ABI"
 
-#: config/powerpcspe/powerpcspe.c:5234 config/rs6000/rs6000.c:4828
+#: config/powerpcspe/powerpcspe.c:5234 config/rs6000/rs6000.c:4853
 #, gcc-internal-format
 msgid "target attribute or pragma changes single precision floating point"
 msgstr "målattribut eller pragma ändrar enkel precisions flyttal"
 
-#: config/powerpcspe/powerpcspe.c:5237 config/rs6000/rs6000.c:4831
+#: config/powerpcspe/powerpcspe.c:5237 config/rs6000/rs6000.c:4856
 #, gcc-internal-format
 msgid "target attribute or pragma changes double precision floating point"
 msgstr "målattribut eller pragma ändrar dubbel precisions flyttal"
@@ -31146,12 +31187,12 @@
 msgid "-mstack-protector-guard=tls needs a valid base register"
 msgstr "-mstack-protector-guard=tls behöver ett giltigt basregister"
 
-#: config/powerpcspe/powerpcspe.c:8415 config/rs6000/rs6000.c:7925
+#: config/powerpcspe/powerpcspe.c:8415 config/rs6000/rs6000.c:7950
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr "layouten av aggregat som innehåller vektorer med %d-bytejustering har ändrats i GCC 5"
 
-#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11237
+#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11269
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC-vektor returnerad som referens: icke-standard ABI-utökning utan kompatibilitetsgaranti"
@@ -31161,7 +31202,7 @@
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "det går inte att returnera värde i vektorregister för att altivec-instruktioner är avaktiverade, använd -maltivec för att aktivera dem"
 
-#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11595
+#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11633
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr "ABI:et för att skicka aggregat med %d-bytejustering har ändrats i GCC 5"
@@ -31171,12 +31212,12 @@
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "det går inte att skicka argument i vektorregister för att altivec-instruktioner är avaktiverade, använd -maltivec för att aktivera dem"
 
-#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12604
+#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12648
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr "ABI:et för att skicka homogena flyttalsaggregat har ändrats i GCC 5"
 
-#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12779
+#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12823
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC-vektor skickad som referens: icke-standard ABI-utökning utan kompatibilitetsgaranti"
@@ -31186,28 +31227,28 @@
 msgid "internal error: builtin function %s already processed"
 msgstr "internt fel: den inbyggda funktionen %s redan bearbetad"
 
-#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:13971
+#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:14015
 #, gcc-internal-format
 msgid "argument 1 must be an 8-bit field value"
 msgstr "argument 1 måste vara ett 8-bitars fältvärde"
 
-#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14015
+#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14059
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "argument 1 måste vara en 5-bitars litteral med tecken"
 
 #: config/powerpcspe/powerpcspe.c:14934 config/powerpcspe/powerpcspe.c:16803
-#: config/rs6000/rs6000.c:14101
+#: config/rs6000/rs6000.c:14145
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "argument 2 måste vara en 5-bitars litteral utan tecken"
 
-#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14119
+#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14163
 #, gcc-internal-format
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "argument 1 måste vara en 6-bitars litteral utan tecken"
 
-#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14135
+#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14179
 #, gcc-internal-format
 msgid "argument 2 must be a 7-bit unsigned literal"
 msgstr "argument 2 måste vara en 7-bitars litteral utan tecken"
@@ -31227,12 +31268,12 @@
 msgid "builtin %s is only valid in 64-bit mode"
 msgstr "inbyggd %s är endast giltigt i 64-bitsläge"
 
-#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14791
+#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14835
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %d must be an unsigned literal"
 msgstr "argument %d måste vara en litteral utan tecken"
 
-#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14793
+#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14837
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "argument %d är en litteral utan tecken som är utanför sitt intervall"
@@ -31254,53 +31295,53 @@
 msgid "hwcap %s is an invalid argument to builtin %s"
 msgstr "hwcap %s är ett ogiltigt argument till den inbyggda %s"
 
-#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15065
+#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15109
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "argument 3 måste vara en 4-bitars litteral utan tecken"
 
-#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15090
+#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15134
 #, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "argument 3 måste vara en 2-bitars litteral utan tecken"
 
-#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15110
+#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15154
 #, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "argument 3 måste vara en 1-bitars litteral utan tecken"
 
-#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15122
+#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15166
 #, gcc-internal-format
 msgid "argument 1 must be 0 or 2"
 msgstr "argument 1 måste vara 0 eller 2"
 
-#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15134
+#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15178
 #, gcc-internal-format
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "argument 1 måste vara en 1-bitars litteral utan tecken"
 
-#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15148
+#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15192
 #, gcc-internal-format
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "argument 2 måste vara en 6-bitars litteral utan tecken"
 
-#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15160
+#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15204
 #, gcc-internal-format
 msgid "argument 2 must be 0 or 1"
 msgstr "argument 2 måste vara 0 eller 1"
 
-#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15168
+#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15212
 #, gcc-internal-format
 msgid "argument 3 must be in the range 0..15"
 msgstr "argument 3 måste vara i intervallet 0..15"
 
-#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15237
-#: config/rs6000/rs6000.c:15569
+#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15281
+#: config/rs6000/rs6000.c:15613
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "argument till %qs måste vara en 2-bitars litteral utan tecken"
 
-#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15394
+#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15438
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr "ej upplöst överlagring för inbyggd Altivec %qF"
@@ -31425,7 +31466,7 @@
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr "internt fel: inbyggd funktion %s, argument %d har en oväntad argumenttyp %s"
 
-#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25758
+#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25835
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr "för stor stackram"
@@ -31435,12 +31476,12 @@
 msgid "-fsplit-stack uses register r29"
 msgstr "-fsplit-stack använder register r29"
 
-#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29459
+#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29536
 #, gcc-internal-format
 msgid "Stack frame larger than 2G is not supported for -fsplit-stack"
 msgstr "Stackramar större än 2 G stödjs inte med -fsplit-stack"
 
-#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30447
+#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30524
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "ingen profilering av 64-bitskod för detta ABI"
@@ -31450,22 +31491,22 @@
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr "Du kan inte ta adressen till en nästad funktion om du använder flaggan -mno-pointers-to-nested-functions"
 
-#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32830
+#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32907
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "användning av %<long double%> i AltiVec-typer är ogiltigt"
 
-#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32832
+#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32909
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "användning av booleaner i AltiVec-typer är ogiltigt"
 
-#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32834
+#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32911
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "användning av %<complex%> i AltiVec-typer är ogiltigt"
 
-#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32836
+#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32913
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr "användning av decimala flyttalstyper i AltiVec-typer är ogiltigt"
@@ -31475,7 +31516,7 @@
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr "användning av %<long%> i AltiVec-typer är ogiltigt för 64-bitskod utan -mvsx"
 
-#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32845
+#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32922
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "användning av %<long%> i AltiVec-typer bör undvikas, använd %<int%>"
@@ -32019,71 +32060,71 @@
 "Ej stött cpu-namn returnerat från kärnan till -mcpu=native: %s\n"
 "Ange ett explicit cpu-namn.  Giltiga cpu-namn är: %s"
 
-#: config/rs6000/rs6000-c.c:6168 config/rs6000/rs6000-c.c:6219
-#: config/rs6000/rs6000-c.c:6489 config/rs6000/rs6000-c.c:6555
-#: config/rs6000/rs6000-c.c:6916 config/rs6000/rs6000-c.c:6963
+#: config/rs6000/rs6000-c.c:6166 config/rs6000/rs6000-c.c:6217
+#: config/rs6000/rs6000-c.c:6487 config/rs6000/rs6000-c.c:6553
+#: config/rs6000/rs6000-c.c:6914 config/rs6000/rs6000-c.c:6961
 #, gcc-internal-format
 msgid "builtin %qs only accepts 2 arguments"
 msgstr "den inbyggda %qs tar endast 2 argument"
 
-#: config/rs6000/rs6000-c.c:6292 config/rs6000/rs6000-c.c:6375
-#: config/rs6000/rs6000-c.c:6736
+#: config/rs6000/rs6000-c.c:6290 config/rs6000/rs6000-c.c:6373
+#: config/rs6000/rs6000-c.c:6734
 #, gcc-internal-format
 msgid "builtin %qs only accepts 3 arguments"
 msgstr "den inbyggda %qs tar endast 3 argument"
 
-#: config/rs6000/rs6000-c.c:6484
+#: config/rs6000/rs6000-c.c:6482
 #, gcc-internal-format
 msgid "builtin %qs only accepts 1 argument"
 msgstr "den inbyggda %qs tar endast 1 argument"
 
-#: config/rs6000/rs6000-c.c:7054
+#: config/rs6000/rs6000-c.c:7052
 #, gcc-internal-format
 msgid "builtin %qs requires builtin %qs"
 msgstr "den inbyggda %qs behöver den inbyggda %qs"
 
-#: config/rs6000/rs6000-c.c:7058
+#: config/rs6000/rs6000-c.c:7056
 #, gcc-internal-format
 msgid "builtin function %qs not supported in this compiler configuration"
 msgstr "den inbyggda funktionen %qs stödjs inte i denna kompilatorkonfiguration"
 
-#: config/rs6000/rs6000-c.c:7068
+#: config/rs6000/rs6000-c.c:7066
 #, gcc-internal-format
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr "ogiltig parameterkombination för inbyggd %qs i AltiVec"
 
-#: config/rs6000/rs6000.c:3754 config/rs6000/rs6000.c:3757
-#: config/rs6000/rs6000.c:3760
+#: config/rs6000/rs6000.c:3772 config/rs6000/rs6000.c:3775
+#: config/rs6000/rs6000.c:3778
 #, gcc-internal-format
 msgid "%qs requires %qs or %qs"
 msgstr "%qs kräver %qs eller %qs"
 
-#: config/rs6000/rs6000.c:3861
+#: config/rs6000/rs6000.c:3879
 #, gcc-internal-format
 msgid "%qs requires PowerPC64 architecture, enabling"
 msgstr "%qs kräver PowerPC64-arkitektur, aktiverar"
 
-#: config/rs6000/rs6000.c:4037
+#: config/rs6000/rs6000.c:4057
 #, gcc-internal-format
 msgid "%qs command-line option is deprecated"
 msgstr "kommandoradsflaggan %qs bör undvikas"
 
-#: config/rs6000/rs6000.c:4048
+#: config/rs6000/rs6000.c:4068
 #, gcc-internal-format
 msgid "%qs is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr "%qs stödjs inte för 64-bitars Darwin, det är inkompatibelt med de installerade C- och C++-biblioteken"
 
-#: config/rs6000/rs6000.c:4147
+#: config/rs6000/rs6000.c:4167
 #, gcc-internal-format
 msgid "will not generate %qs instructions because assembler lacks %qs support"
 msgstr "kommer inte generera %qs-instruktioner för att assemblern saknar stöd för %qs"
 
-#: config/rs6000/rs6000.c:4240
+#: config/rs6000/rs6000.c:4260
 #, gcc-internal-format
 msgid "%qs is not supported on little endian systems"
 msgstr "%qs stödjs inte på system med omvänd byteordning"
 
-#: config/rs6000/rs6000.c:4333
+#: config/rs6000/rs6000.c:4353
 #, gcc-internal-format
 msgid "power9 target option is incompatible with %<%s=<xxx>%> for <xxx> less than power9"
 msgstr "målflaggan för power9 är inkompatibel med %<%s=<xxx>%> för <xxx> som är mindre än power9"
@@ -32090,7 +32131,7 @@
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:4341
+#: config/rs6000/rs6000.c:4361
 #, gcc-internal-format
 msgid "%qs incompatible with explicitly disabled options"
 msgstr "%qs är inkompatibel med uttryckligen avaktiverade flaggor"
@@ -32099,240 +32140,241 @@
 #. error messages.  However, if users have managed to select
 #. power9-fusion without selecting power8-fusion, they
 #. already know about undocumented flags.
-#: config/rs6000/rs6000.c:4366 config/rs6000/rs6000.c:4373
-#: config/rs6000/rs6000.c:4380 config/rs6000/rs6000.c:4388
-#: config/rs6000/rs6000.c:4407 config/rs6000/rs6000.c:4464
-#: config/rs6000/rs6000.c:4468 config/rs6000/rs6000.c:4485
-#: config/rs6000/rs6000.c:4538 config/rs6000/rs6000.c:4565
-#: config/rs6000/rs6000.c:4580 config/rs6000/rs6000.c:4588
-#: config/rs6000/rs6000.c:4684
+#: config/rs6000/rs6000.c:4386 config/rs6000/rs6000.c:4393
+#: config/rs6000/rs6000.c:4400 config/rs6000/rs6000.c:4408
+#: config/rs6000/rs6000.c:4427 config/rs6000/rs6000.c:4484
+#: config/rs6000/rs6000.c:4488 config/rs6000/rs6000.c:4505
+#: config/rs6000/rs6000.c:4558 config/rs6000/rs6000.c:4585
+#: config/rs6000/rs6000.c:4600 config/rs6000/rs6000.c:4608
+#: config/rs6000/rs6000.c:4709
 #, gcc-internal-format
 msgid "%qs requires %qs"
 msgstr "%qs behöver %qs"
 
-#: config/rs6000/rs6000.c:4625
+#: config/rs6000/rs6000.c:4650
 #, gcc-internal-format
 msgid "Using IEEE extended precision long double"
 msgstr "Använder long double med IEEE:s utökade precision"
 
-#: config/rs6000/rs6000.c:4627
+#: config/rs6000/rs6000.c:4652
 #, gcc-internal-format
 msgid "Using IBM extended precision long double"
 msgstr "Använder long double med IBM:s utökade precision"
 
-#: config/rs6000/rs6000.c:4644
+#: config/rs6000/rs6000.c:4669
 #, gcc-internal-format
 msgid "%qs requires VSX support"
 msgstr "%qs behöver VSX-stöd"
 
-#: config/rs6000/rs6000.c:4653
+#: config/rs6000/rs6000.c:4678
 #, gcc-internal-format
 msgid "The -mfloat128 option may not be fully supported"
 msgstr "Flaggan -mfloat128 kan inte stödjas helt"
 
-#: config/rs6000/rs6000.c:4676
+#: config/rs6000/rs6000.c:4701
 #, gcc-internal-format
 msgid "%qs requires full ISA 3.0 support"
 msgstr "%qs behöver fullt ISA 3.0-stöd"
 
-#: config/rs6000/rs6000.c:4743
+#: config/rs6000/rs6000.c:4768
 #, gcc-internal-format
 msgid "unknown vectorization library ABI type (%qs) for %qs switch"
 msgstr "okänd ABI-typ (%qs) till vektoriseringsbibliotek för flaggan %qs"
 
-#: config/rs6000/rs6000.c:4930
+#: config/rs6000/rs6000.c:4955
 #, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr "%qs är inte ett giltigt tal i %qs"
 
-#: config/rs6000/rs6000.c:4935
+#: config/rs6000/rs6000.c:4960
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr "%qs är inte ett giltigt avstånd i %qs"
 
-#: config/rs6000/rs6000.c:4947
+#: config/rs6000/rs6000.c:4972
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %qs"
 msgstr "%qs är inte ett giltigt basregister i %qs"
 
-#: config/rs6000/rs6000.c:4955
+#: config/rs6000/rs6000.c:4980
 #, gcc-internal-format
 msgid "%qs needs a valid base register"
 msgstr "%qs behöver ett giltigt basregister"
 
-#: config/rs6000/rs6000.c:5253
+#: config/rs6000/rs6000.c:5278
 #, gcc-internal-format
 msgid "unknown option for %<%s=%s%>"
 msgstr "okänt alternativ till %<%s=%s%>"
 
-#: config/rs6000/rs6000.c:5290
+#: config/rs6000/rs6000.c:5315
 #, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr "%qs bör undvikas och rekommenderas inte under några omständigheter"
 
-#: config/rs6000/rs6000.c:11401
+#: config/rs6000/rs6000.c:11439
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr "det går inte att returnera värde i vektorregister för att altivec-instruktioner är avaktiverade, använd %qs för att aktivera dem"
 
-#: config/rs6000/rs6000.c:11862
+#: config/rs6000/rs6000.c:11906
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr "det går inte att skicka argument i vektorregister för att altivec-instruktioner är avaktiverade, använd %qs för att aktivera dem"
 
-#: config/rs6000/rs6000.c:13572
+#: config/rs6000/rs6000.c:13616
 #, gcc-internal-format
 msgid "internal error: builtin function %qs already processed"
 msgstr "internt fel: den inbyggda funktionen %qs redan bearbetad"
 
-#: config/rs6000/rs6000.c:14150
+#: config/rs6000/rs6000.c:14194
 #, gcc-internal-format
 msgid "argument 2 must be a 1-bit unsigned literal"
 msgstr "argument 2 måste vara en 1-bits litteral utan tecken"
 
-#: config/rs6000/rs6000.c:14189
+#: config/rs6000/rs6000.c:14233
 #, gcc-internal-format
 msgid "argument 1 of %qs must be a constant"
 msgstr "argument 1 till %qs måste vara en konstant"
 
-#: config/rs6000/rs6000.c:14247 config/rs6000/rs6000.c:15898
+#: config/rs6000/rs6000.c:14291 config/rs6000/rs6000.c:15942
 #, gcc-internal-format
 msgid "argument 1 of %qs is out of range"
 msgstr "argument 1 till %qs är utanför sitt intervall"
 
-#: config/rs6000/rs6000.c:14742
+#: config/rs6000/rs6000.c:14786
 #, gcc-internal-format
 msgid "builtin %qs is only valid in 64-bit mode"
 msgstr "inbyggd %qs är endast giltigt i 64-bitsläge"
 
-#: config/rs6000/rs6000.c:14939
+#: config/rs6000/rs6000.c:14983
 #, gcc-internal-format
 msgid "builtin %qs only accepts a string argument"
 msgstr "den inbyggda %qs tar endast ett strängargument"
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000.c:14958
+#: config/rs6000/rs6000.c:15002
 #, gcc-internal-format
 msgid "cpu %qs is an invalid argument to builtin %qs"
 msgstr "cpu %qs är ett ogiltigt argument till den inbyggda %qs"
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000.c:14986
+#: config/rs6000/rs6000.c:15030
 #, gcc-internal-format
 msgid "%s %qs is an invalid argument to builtin %qs"
 msgstr "%s %qs är ett ogiltigt argument till den inbyggda %qs"
 
-#: config/rs6000/rs6000.c:15012
+#: config/rs6000/rs6000.c:15056
 #, gcc-internal-format
 msgid "builtin %qs needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr "den inbyggda %qs behöver GLIBC (2.23 och nyare) som exporterar bitar om hårdvaruegenskaper"
 
-#: config/rs6000/rs6000.c:15616
+#: config/rs6000/rs6000.c:15660
 #, gcc-internal-format
 msgid "second argument to %qs must be 0..12"
 msgstr "andra argumentet till %qs måste vara 0..12"
 
-#: config/rs6000/rs6000.c:15631
+#: config/rs6000/rs6000.c:15675
 #, gcc-internal-format
 msgid "third argument to %qs must be 0..12"
 msgstr "tredje argumentet till %qs måste vara 0..12"
 
-#: config/rs6000/rs6000.c:15850
+#: config/rs6000/rs6000.c:15894
 #, gcc-internal-format, gfc-internal-format
 msgid "argument 1 of %s must be a constant"
 msgstr "argument 1 till %s måste vara en konstant"
 
-#: config/rs6000/rs6000.c:15932
+#: config/rs6000/rs6000.c:15976
 #, gcc-internal-format
 msgid "builtin function %qs is only valid for the cell processor"
 msgstr "den inbyggda funktionen %qs är endast giltig för cell-processorn"
 
-#: config/rs6000/rs6000.c:15934 config/rs6000/rs6000.c:15936
-#: config/rs6000/rs6000.c:15938 config/rs6000/rs6000.c:15940
-#: config/rs6000/rs6000.c:15946 config/rs6000/rs6000.c:15948
-#: config/rs6000/rs6000.c:15955 config/rs6000/rs6000.c:15962
-#: config/rs6000/rs6000.c:15969 config/rs6000/rs6000.c:15975
+#: config/rs6000/rs6000.c:15978 config/rs6000/rs6000.c:15980
+#: config/rs6000/rs6000.c:15982 config/rs6000/rs6000.c:15984
+#: config/rs6000/rs6000.c:15990 config/rs6000/rs6000.c:15992
+#: config/rs6000/rs6000.c:15999 config/rs6000/rs6000.c:16006
+#: config/rs6000/rs6000.c:16011 config/rs6000/rs6000.c:16014
+#: config/rs6000/rs6000.c:16018 config/rs6000/rs6000.c:16024
 #, gcc-internal-format
 msgid "builtin function %qs requires the %qs option"
 msgstr "den inbyggda funktionen %qs behöver flaggan %qs"
 
-#: config/rs6000/rs6000.c:15943 config/rs6000/rs6000.c:15952
-#: config/rs6000/rs6000.c:15959 config/rs6000/rs6000.c:15966
+#: config/rs6000/rs6000.c:15987 config/rs6000/rs6000.c:15996
+#: config/rs6000/rs6000.c:16003
 #, gcc-internal-format
 msgid "builtin function %qs requires the %qs and %qs options"
 msgstr "den inbyggda funktionen %qs behöver flaggorna %qs och %qs"
 
-#: config/rs6000/rs6000.c:15972
+#: config/rs6000/rs6000.c:16021
 #, gcc-internal-format
 msgid "builtin function %qs requires ISA 3.0 IEEE 128-bit floating point"
 msgstr "den inbyggda funktionen %qs behöver 128-bitars flyttal enligt ISA 3.0 IEEE"
 
-#: config/rs6000/rs6000.c:15978
+#: config/rs6000/rs6000.c:16027
 #, gcc-internal-format
 msgid "builtin function %qs requires the %qs (or newer), and %qs or %qs options"
 msgstr "den inbyggda funktionen %qs behöver flaggorna %qs (eller senare), och %qs eller %qs"
 
-#: config/rs6000/rs6000.c:15982
+#: config/rs6000/rs6000.c:16031
 #, gcc-internal-format
 msgid "builtin function %qs is not supported with the current options"
 msgstr "den inbyggda funktionen %qs stödjs inte med de aktuella flaggorna"
 
-#: config/rs6000/rs6000.c:18218
+#: config/rs6000/rs6000.c:18290
 #, gcc-internal-format
 msgid "internal error: builtin function %qs had an unexpected return type %qs"
 msgstr "internt fel: inbyggd funktion %qs hade en oväntad returtyp %qs"
 
-#: config/rs6000/rs6000.c:18235
+#: config/rs6000/rs6000.c:18307
 #, gcc-internal-format
 msgid "internal error: builtin function %qs, argument %d had unexpected argument type %qs"
 msgstr "internt fel: inbyggd funktion %qs, argument %d har en oväntad argumenttyp %qs"
 
-#: config/rs6000/rs6000.c:29451
+#: config/rs6000/rs6000.c:29528
 #, gcc-internal-format
 msgid "%qs uses register r29"
 msgstr "%qs använder register r29"
 
-#: config/rs6000/rs6000.c:32748
+#: config/rs6000/rs6000.c:32825
 #, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "du kan inte ta adressen till en nästad funktion om du använder flaggan %qs"
 
-#: config/rs6000/rs6000.c:32842
+#: config/rs6000/rs6000.c:32919
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "användning av %<long%> i AltiVec-typer är ogiltigt för 64-bitskod utan %qs"
 
-#: config/rs6000/rs6000.c:32850
+#: config/rs6000/rs6000.c:32927
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "användning av %<long long%> i AltiVec-typer är ogiltigt utan %qs"
 
-#: config/rs6000/rs6000.c:32853
+#: config/rs6000/rs6000.c:32930
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "användning av %<double%> i AltiVec-typer är ogiltigt utan %qs"
 
-#: config/rs6000/rs6000.c:36876
+#: config/rs6000/rs6000.c:36932
 #, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "felaktig cpu %qs för %s%qs%s"
 
-#: config/rs6000/rs6000.c:36879
+#: config/rs6000/rs6000.c:36935
 #, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr "%s%qs%s är inte tillåtet"
 
-#: config/rs6000/rs6000.c:36881
+#: config/rs6000/rs6000.c:36937
 #, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr "%s%qs%s är ogiltigt"
 
-#: config/rs6000/rs6000.c:37416
+#: config/rs6000/rs6000.c:37472
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr "%<-mno-%s%> slår av %<-m%s%>"
 
-#: config/rs6000/rs6000.c:37575
+#: config/rs6000/rs6000.c:37631
 #, gcc-internal-format
 msgid "target_clones attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr "attributet target_clones behöver GLIBC (2.23 och nyare) som exporterar bitar om hårdvaruegenskaper"
@@ -33073,48 +33115,48 @@
 msgid "subprogram %q+F not marked Inline"
 msgstr "underprogrammet %q+F är inte markerat Inline"
 
-#: ada/gcc-interface/trans.c:6404
+#: ada/gcc-interface/trans.c:6401
 #, gcc-internal-format
 msgid "out-of-bounds access may be optimized away"
 msgstr "åtkomst utanför gränserna kan optimeras bort"
 
-#: ada/gcc-interface/trans.c:6406
+#: ada/gcc-interface/trans.c:6403
 #, gcc-internal-format
 msgid "containing loop"
 msgstr "kringliggande slinga"
 
-#: ada/gcc-interface/utils.c:3887
+#: ada/gcc-interface/utils.c:3890
 #, gcc-internal-format
 msgid "invalid element type for attribute %qs"
 msgstr "ogiltig elementtyp för attributet %qs"
 
-#: ada/gcc-interface/utils.c:3911
+#: ada/gcc-interface/utils.c:3914
 #, gcc-internal-format
 msgid "number of components of vector not a power of two"
 msgstr "antal komponenter i vektorn inte en tvåpotens"
 
-#: ada/gcc-interface/utils.c:6037 ada/gcc-interface/utils.c:6215
-#: ada/gcc-interface/utils.c:6322
+#: ada/gcc-interface/utils.c:6043 ada/gcc-interface/utils.c:6220
+#: ada/gcc-interface/utils.c:6327
 #, gcc-internal-format
 msgid "%qs attribute ignored"
 msgstr "attributet %qs ignorerat"
 
-#: ada/gcc-interface/utils.c:6158
+#: ada/gcc-interface/utils.c:6164
 #, gcc-internal-format
 msgid "%qs attribute requires prototypes with named arguments"
 msgstr "attributet %qs kräver prototyper med namngivna argument"
 
-#: ada/gcc-interface/utils.c:6167
+#: ada/gcc-interface/utils.c:6173
 #, gcc-internal-format
 msgid "%qs attribute only applies to variadic functions"
 msgstr "attributet %qs fungerar bara på funktioner med variabelt antal argument"
 
-#: ada/gcc-interface/utils.c:6282
+#: ada/gcc-interface/utils.c:6287
 #, gcc-internal-format
 msgid "%qE attribute has no effect"
 msgstr "attributet %qE har ingen effekt"
 
-#: ada/gcc-interface/utils.c:6406
+#: ada/gcc-interface/utils.c:6411
 #, gcc-internal-format
 msgid "attribute %qs applies to array types only"
 msgstr "attributet %qs är bara tillämpbart på vektortyper"
@@ -33129,7 +33171,7 @@
 #. an unprototyped function, it is compile-time undefined;
 #. making it a constraint in that case was rejected in
 #. DR#252.
-#: c/c-convert.c:101 c/c-typeck.c:2175 c/c-typeck.c:6507 c/c-typeck.c:12138
+#: c/c-convert.c:101 c/c-typeck.c:2175 c/c-typeck.c:6512 c/c-typeck.c:12143
 #: cp/typeck.c:2027 cp/typeck.c:7977 cp/typeck.c:8742
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
@@ -33190,7 +33232,7 @@
 msgid "type of array %q+D completed incompatibly with implicit initialization"
 msgstr "den kompletterade typen på vektor %q+D är inkompatibel med implicit initiering"
 
-#: c/c-decl.c:1567 c/c-decl.c:6701 c/c-decl.c:7574 c/c-decl.c:8381
+#: c/c-decl.c:1567 c/c-decl.c:6721 c/c-decl.c:7594 c/c-decl.c:8401
 #, gcc-internal-format
 msgid "originally defined here"
 msgstr "ursprungligen definierad här"
@@ -33596,16 +33638,11 @@
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.c:4548 c/c-decl.c:7147
+#: c/c-decl.c:4548 c/c-decl.c:7167
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr "%<[*]%> är inte tillåtet annat än inom en funktionsprototyp"
 
-#: c/c-decl.c:4635 cp/decl2.c:1520
-#, gcc-internal-format
-msgid "%q+D in declare target directive does not have mappable type"
-msgstr "%q+D i deklarationsmålsdirektiv har inte en avbildbar typ"
-
 #: c/c-decl.c:4693
 #, gcc-internal-format
 msgid "%q+D is usually a function"
@@ -33631,7 +33668,7 @@
 #. of VLAs themselves count as VLAs, it does not make
 #. sense to permit them to be initialized given that
 #. ordinary VLAs may not be initialized.
-#: c/c-decl.c:4732 c/c-decl.c:4747 c/c-typeck.c:7630
+#: c/c-decl.c:4732 c/c-decl.c:4747 c/c-typeck.c:7635
 #, gcc-internal-format
 msgid "variable-sized object may not be initialized"
 msgstr "objekt med variabel storlek kan inte initieras"
@@ -33691,202 +33728,207 @@
 msgid "uninitialized const %qD is invalid in C++"
 msgstr "oinitierad const %qD är ogiltig i C++"
 
-#: c/c-decl.c:5268
+#: c/c-decl.c:5224 cp/decl.c:7318
 #, gcc-internal-format
+msgid "%q+D in declare target directive does not have mappable type"
+msgstr "%q+D i deklarationsmålsdirektiv har inte en avbildbar typ"
+
+#: c/c-decl.c:5288
+#, gcc-internal-format
 msgid "ISO C forbids forward parameter declarations"
 msgstr "ISO C förbjuder framåtdeklaration av parametrar"
 
-#: c/c-decl.c:5371
+#: c/c-decl.c:5391
 #, gcc-internal-format
 msgid "defining a type in a compound literal is invalid in C++"
 msgstr "att definiera en typ i en sammansatt litteral är ogiltigt i C++"
 
-#: c/c-decl.c:5425 c/c-decl.c:5440
+#: c/c-decl.c:5445 c/c-decl.c:5460
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant"
 msgstr "bredden på bitfältet %qs är inte en heltalskonstant"
 
-#: c/c-decl.c:5435
+#: c/c-decl.c:5455
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant expression"
 msgstr "bredden på bitfältet %qs är inte ett konstant heltalsuttryck"
 
-#: c/c-decl.c:5446
+#: c/c-decl.c:5466
 #, gcc-internal-format
 msgid "negative width in bit-field %qs"
 msgstr "negativ storlek i bitfält %qs"
 
-#: c/c-decl.c:5451
+#: c/c-decl.c:5471
 #, gcc-internal-format
 msgid "zero width for bit-field %qs"
 msgstr "storlek noll på bitfält %qs"
 
-#: c/c-decl.c:5461
+#: c/c-decl.c:5481
 #, gcc-internal-format
 msgid "bit-field %qs has invalid type"
 msgstr "bitfältet %qs har ogiltig typ"
 
-#: c/c-decl.c:5467
+#: c/c-decl.c:5487
 #, gcc-internal-format
 msgid "cannot declare bit-field %qs with %<warn_if_not_aligned%> type"
 msgstr "det går inte att deklarera bitfältet %qs med typen %<warn_if_not_aligned%>"
 
-#: c/c-decl.c:5478
+#: c/c-decl.c:5498
 #, gcc-internal-format
 msgid "type of bit-field %qs is a GCC extension"
 msgstr "typen på bitfältet %qs är en GCC-utvidgning"
 
-#: c/c-decl.c:5484
+#: c/c-decl.c:5504
 #, gcc-internal-format
 msgid "width of %qs exceeds its type"
 msgstr "bredden på %qs är större än sin typ"
 
-#: c/c-decl.c:5497
+#: c/c-decl.c:5517
 #, gcc-internal-format
 msgid "%qs is narrower than values of its type"
 msgstr "%qs är smalare än värdena av sin typ"
 
-#: c/c-decl.c:5512
+#: c/c-decl.c:5532
 #, gcc-internal-format
 msgid "ISO C90 forbids array %qE whose size can%'t be evaluated"
 msgstr "ISO C90 förbjuder vektor %qE vars storlek inte kan beräknas"
 
-#: c/c-decl.c:5515
+#: c/c-decl.c:5535
 #, gcc-internal-format
 msgid "ISO C90 forbids array whose size can%'t be evaluated"
 msgstr "ISO C90 förbjuder vektorer vars storlek inte kan beräknas"
 
-#: c/c-decl.c:5522
+#: c/c-decl.c:5542
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array %qE"
 msgstr "ISO C90 förbjuder vektor %qE med variabel längd"
 
-#: c/c-decl.c:5524
+#: c/c-decl.c:5544
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array"
 msgstr "ISO C90 förbjuder vektorer med variabel längd"
 
-#: c/c-decl.c:5733 c/c-decl.c:6107 c/c-decl.c:6117
+#: c/c-decl.c:5753 c/c-decl.c:6127 c/c-decl.c:6137
 #, gcc-internal-format
 msgid "variably modified %qE at file scope"
 msgstr "variabelt ändrad %qE i filräckvidd"
 
-#: c/c-decl.c:5735
+#: c/c-decl.c:5755
 #, gcc-internal-format
 msgid "variably modified field at file scope"
 msgstr "variabelt ändrat fält i filräckvidd"
 
-#: c/c-decl.c:5755
+#: c/c-decl.c:5775
 #, gcc-internal-format
 msgid "type defaults to %<int%> in declaration of %qE"
 msgstr "typen sätts skönsmässigt till %<int%> i deklarationen av %qE"
 
-#: c/c-decl.c:5759
+#: c/c-decl.c:5779
 #, gcc-internal-format
 msgid "type defaults to %<int%> in type name"
 msgstr "typen sätts skönsmässigt till %<int%> i typnamnet"
 
-#: c/c-decl.c:5791
+#: c/c-decl.c:5811
 #, gcc-internal-format
 msgid "duplicate %<const%>"
 msgstr "dubblerat %<const%>"
 
-#: c/c-decl.c:5793
+#: c/c-decl.c:5813
 #, gcc-internal-format
 msgid "duplicate %<restrict%>"
 msgstr "dubblerad %<restrict%>"
 
-#: c/c-decl.c:5795
+#: c/c-decl.c:5815
 #, gcc-internal-format
 msgid "duplicate %<volatile%>"
 msgstr "dubblerad %<volatile%>"
 
-#: c/c-decl.c:5797
+#: c/c-decl.c:5817
 #, gcc-internal-format
 msgid "duplicate %<_Atomic%>"
 msgstr "dubblerad %<_Atomic%>"
 
-#: c/c-decl.c:5800
+#: c/c-decl.c:5820
 #, gcc-internal-format, gfc-internal-format
 msgid "conflicting named address spaces (%s vs %s)"
 msgstr "motstridande namngivna adressrymder (%s respektive %s)"
 
-#: c/c-decl.c:5823 c/c-parser.c:2821
+#: c/c-decl.c:5843 c/c-parser.c:2821
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified array type"
 msgstr "%<_Atomic%>-kvalificerad vektortyp"
 
-#: c/c-decl.c:5837
+#: c/c-decl.c:5857
 #, gcc-internal-format
 msgid "function definition declared %<auto%>"
 msgstr "funktionsdefinition deklarerad som %<auto%>"
 
-#: c/c-decl.c:5839
+#: c/c-decl.c:5859
 #, gcc-internal-format
 msgid "function definition declared %<register%>"
 msgstr "funktionsdefinition deklarerad som %<register%>"
 
-#: c/c-decl.c:5841
+#: c/c-decl.c:5861
 #, gcc-internal-format
 msgid "function definition declared %<typedef%>"
 msgstr "funktionsdefinition deklarerad som %<typedef%>"
 
-#: c/c-decl.c:5843
+#: c/c-decl.c:5863
 #, gcc-internal-format
 msgid "function definition declared %qs"
 msgstr "funktionsdefinition deklarerad som %qs"
 
-#: c/c-decl.c:5861
+#: c/c-decl.c:5881
 #, gcc-internal-format
 msgid "storage class specified for structure field %qE"
 msgstr "lagringsklass angiven för postfält %qE"
 
-#: c/c-decl.c:5864
+#: c/c-decl.c:5884
 #, gcc-internal-format
 msgid "storage class specified for structure field"
 msgstr "lagringsklass angiven för postfält"
 
-#: c/c-decl.c:5868
+#: c/c-decl.c:5888
 #, gcc-internal-format
 msgid "storage class specified for parameter %qE"
 msgstr "lagringsklass angiven för parameter %qE"
 
-#: c/c-decl.c:5871
+#: c/c-decl.c:5891
 #, gcc-internal-format
 msgid "storage class specified for unnamed parameter"
 msgstr "lagringsklass angiven för namnlös parameter"
 
-#: c/c-decl.c:5874 cp/decl.c:10935
+#: c/c-decl.c:5894 cp/decl.c:10959
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "lagringsklass angiven för typnamn"
 
-#: c/c-decl.c:5891
+#: c/c-decl.c:5911
 #, gcc-internal-format
 msgid "%qE initialized and declared %<extern%>"
 msgstr "%qE initierad och deklarerad %<extern%>"
 
-#: c/c-decl.c:5895
+#: c/c-decl.c:5915
 #, gcc-internal-format
 msgid "%qE has both %<extern%> and initializer"
 msgstr "%qE har både %<extern%> och initierare"
 
-#: c/c-decl.c:5900
+#: c/c-decl.c:5920
 #, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<auto%>"
 msgstr "filnivådeklaration av %qE anger %<auto%>"
 
-#: c/c-decl.c:5904
+#: c/c-decl.c:5924
 #, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<register%>"
 msgstr "filnivådeklaration av %qE anger %<register%>"
 
-#: c/c-decl.c:5909
+#: c/c-decl.c:5929
 #, gcc-internal-format
 msgid "nested function %qE declared %<extern%>"
 msgstr "nästad funktion %qE är deklarerad %<extern%>"
 
-#: c/c-decl.c:5912
+#: c/c-decl.c:5932
 #, gcc-internal-format
 msgid "function-scope %qE implicitly auto and declared %qs"
 msgstr "%qE i funktions definitionsområde är implicit auto och deklarerad %qs"
@@ -33894,701 +33936,701 @@
 #. Only the innermost declarator (making a parameter be of
 #. array type which is converted to pointer type)
 #. may have static or type qualifiers.
-#: c/c-decl.c:5959 c/c-decl.c:6328
+#: c/c-decl.c:5979 c/c-decl.c:6348
 #, gcc-internal-format
 msgid "static or type qualifiers in non-parameter array declarator"
 msgstr "static- eller typkvalificerare i vektordeklarerare som inte är parameter"
 
-#: c/c-decl.c:6007
+#: c/c-decl.c:6027
 #, gcc-internal-format
 msgid "declaration of %qE as array of voids"
 msgstr "deklaration av %qE som en vektor av void"
 
-#: c/c-decl.c:6009
+#: c/c-decl.c:6029
 #, gcc-internal-format
 msgid "declaration of type name as array of voids"
 msgstr "deklaration av typnamn som en vektor av void"
 
-#: c/c-decl.c:6016
+#: c/c-decl.c:6036
 #, gcc-internal-format
 msgid "declaration of %qE as array of functions"
 msgstr "deklaration av %qE som en vektor av funktioner"
 
-#: c/c-decl.c:6019
+#: c/c-decl.c:6039
 #, gcc-internal-format
 msgid "declaration of type name as array of functions"
 msgstr "deklaration av typnamn som en vektor av funktioner"
 
-#: c/c-decl.c:6027 c/c-decl.c:8085
+#: c/c-decl.c:6047 c/c-decl.c:8105
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr "ogiltig användning av post med flexibel vektormedlem"
 
-#: c/c-decl.c:6053
+#: c/c-decl.c:6073
 #, gcc-internal-format
 msgid "size of array %qE has non-integer type"
 msgstr "storlek på vektorn %qE är inte av heltalstyp"
 
-#: c/c-decl.c:6057
+#: c/c-decl.c:6077
 #, gcc-internal-format
 msgid "size of unnamed array has non-integer type"
 msgstr "storlek på en namnlös vektor är inte av heltalstyp"
 
-#: c/c-decl.c:6064
+#: c/c-decl.c:6084
 #, gcc-internal-format
 msgid "size of array %qE has incomplete type"
 msgstr "storlek på vektorn %qE har ofullständig typ"
 
-#: c/c-decl.c:6067
+#: c/c-decl.c:6087
 #, gcc-internal-format
 msgid "size of unnamed array has incomplete type"
 msgstr "storlek på en namnlös vektor har ofullständig typ"
 
-#: c/c-decl.c:6078
+#: c/c-decl.c:6098
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array %qE"
 msgstr "ISO C förbjuder vektor %qE med storlek noll"
 
-#: c/c-decl.c:6081
+#: c/c-decl.c:6101
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array"
 msgstr "ISO C förbjuder vektorer med storlek noll"
 
-#: c/c-decl.c:6090
+#: c/c-decl.c:6110
 #, gcc-internal-format
 msgid "size of array %qE is negative"
 msgstr "storleken på vektorn %qE är negativ"
 
-#: c/c-decl.c:6092
+#: c/c-decl.c:6112
 #, gcc-internal-format
 msgid "size of unnamed array is negative"
 msgstr "storleken på en namnlös vektor är negativ"
 
-#: c/c-decl.c:6216 c/c-decl.c:6871
+#: c/c-decl.c:6236 c/c-decl.c:6891
 #, gcc-internal-format
 msgid "ISO C90 does not support flexible array members"
 msgstr "ISO C90 stödjer inte flexibla vektormedlemmar"
 
 #. C99 6.7.5.2p4
-#: c/c-decl.c:6238
+#: c/c-decl.c:6258
 #, gcc-internal-format
 msgid "%<[*]%> not in a declaration"
 msgstr "%<[*]%> är inte i en deklaration"
 
-#: c/c-decl.c:6251
+#: c/c-decl.c:6271
 #, gcc-internal-format
 msgid "array type has incomplete element type %qT"
 msgstr "vektortyp har ofullständig elementtyp %qT"
 
-#: c/c-decl.c:6257
+#: c/c-decl.c:6277
 #, gcc-internal-format
 msgid "declaration of %qE as multidimensional array must have bounds for all dimensions except the first"
 msgstr "deklaration av %qE som flerdimensionell vektor måste ha gränser för alla dimensioner utom den första"
 
-#: c/c-decl.c:6261
+#: c/c-decl.c:6281
 #, gcc-internal-format
 msgid "declaration of multidimensional array must have bounds for all dimensions except the first"
 msgstr "deklaration av flerdimensionell vektor måste ha gränser för alla dimensioner utom den första"
 
-#: c/c-decl.c:6364
+#: c/c-decl.c:6384
 #, gcc-internal-format
 msgid "%qE declared as function returning a function"
 msgstr "%qE är deklarerad som en funktion som returnerar en funktion"
 
-#: c/c-decl.c:6367
+#: c/c-decl.c:6387
 #, gcc-internal-format
 msgid "type name declared as function returning a function"
 msgstr "typnamn är deklarerat som en funktion som returnerar en funktion"
 
-#: c/c-decl.c:6374
+#: c/c-decl.c:6394
 #, gcc-internal-format
 msgid "%qE declared as function returning an array"
 msgstr "%qE är deklarerad som en funktion som returnerar en vektor"
 
-#: c/c-decl.c:6377
+#: c/c-decl.c:6397
 #, gcc-internal-format
 msgid "type name declared as function returning an array"
 msgstr "typnamn är deklarerat som en funktion som returnerar en vektor"
 
-#: c/c-decl.c:6418
+#: c/c-decl.c:6438
 #, gcc-internal-format
 msgid "function definition has qualified void return type"
 msgstr "funktionsdefinition som har kvalificerad void-returtyp"
 
-#: c/c-decl.c:6421 cp/decl.c:11201
+#: c/c-decl.c:6441 cp/decl.c:11225
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "typkvalificerare ignoreras för funktions returtyp"
 
-#: c/c-decl.c:6459 c/c-decl.c:6668 c/c-decl.c:6721 c/c-decl.c:6805
-#: c/c-decl.c:6926 c/c-parser.c:2823
+#: c/c-decl.c:6479 c/c-decl.c:6688 c/c-decl.c:6741 c/c-decl.c:6825
+#: c/c-decl.c:6946 c/c-parser.c:2823
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified function type"
 msgstr "%<_Atomic%>-kvalificerad funktionstyp"
 
-#: c/c-decl.c:6465 c/c-decl.c:6674 c/c-decl.c:6810 c/c-decl.c:6931
+#: c/c-decl.c:6485 c/c-decl.c:6694 c/c-decl.c:6830 c/c-decl.c:6951
 #, gcc-internal-format
 msgid "ISO C forbids qualified function types"
 msgstr "ISO C förbjuder kvalificerade funktionstyper"
 
-#: c/c-decl.c:6559
+#: c/c-decl.c:6579
 #, gcc-internal-format
 msgid "%qs combined with %<auto%> qualifier for %qE"
 msgstr "%qs kombinerad med %<auto%>-kvalificerare för %qE"
 
-#: c/c-decl.c:6563
+#: c/c-decl.c:6583
 #, gcc-internal-format
 msgid "%qs combined with %<register%> qualifier for %qE"
 msgstr "%qs kombinerat med %<register%>-kvalificerare för %qE"
 
-#: c/c-decl.c:6569
+#: c/c-decl.c:6589
 #, gcc-internal-format
 msgid "%qs specified for auto variable %qE"
 msgstr "%qs angiven för auto-variabel %qE"
 
-#: c/c-decl.c:6585
+#: c/c-decl.c:6605
 #, gcc-internal-format
 msgid "%qs specified for parameter %qE"
 msgstr "%qs angiven för parameter %qE"
 
-#: c/c-decl.c:6588
+#: c/c-decl.c:6608
 #, gcc-internal-format
 msgid "%qs specified for unnamed parameter"
 msgstr "%qs angiven för namnlös parameter"
 
-#: c/c-decl.c:6594
+#: c/c-decl.c:6614
 #, gcc-internal-format
 msgid "%qs specified for structure field %qE"
 msgstr "%qs angiven för postfält %qE"
 
-#: c/c-decl.c:6597
+#: c/c-decl.c:6617
 #, gcc-internal-format
 msgid "%qs specified for structure field"
 msgstr "%qs angiven för postfält"
 
-#: c/c-decl.c:6612
+#: c/c-decl.c:6632
 #, gcc-internal-format
 msgid "bit-field %qE has atomic type"
 msgstr "bitfältet %qE har atomär typ"
 
-#: c/c-decl.c:6614
+#: c/c-decl.c:6634
 #, gcc-internal-format
 msgid "bit-field has atomic type"
 msgstr "bitfältet har atomär typ"
 
-#: c/c-decl.c:6623
+#: c/c-decl.c:6643
 #, gcc-internal-format
 msgid "alignment specified for typedef %qE"
 msgstr "minnesjustering angiven för typedef %qE"
 
-#: c/c-decl.c:6625
+#: c/c-decl.c:6645
 #, gcc-internal-format
 msgid "alignment specified for %<register%> object %qE"
 msgstr "minnesjustering angiven för %<register%>-objekt %qE"
 
-#: c/c-decl.c:6630
+#: c/c-decl.c:6650
 #, gcc-internal-format
 msgid "alignment specified for parameter %qE"
 msgstr "minnesjustering angiven för parameter %qE"
 
-#: c/c-decl.c:6632
+#: c/c-decl.c:6652
 #, gcc-internal-format
 msgid "alignment specified for unnamed parameter"
 msgstr "minnesjustering angiven för namnlös parameter"
 
-#: c/c-decl.c:6637
+#: c/c-decl.c:6657
 #, gcc-internal-format
 msgid "alignment specified for bit-field %qE"
 msgstr "minnesjustering angiven för bitfältet %qE"
 
-#: c/c-decl.c:6639
+#: c/c-decl.c:6659
 #, gcc-internal-format
 msgid "alignment specified for unnamed bit-field"
 msgstr "minnesjustering angiven för namnlöst bitfält"
 
-#: c/c-decl.c:6642
+#: c/c-decl.c:6662
 #, gcc-internal-format
 msgid "alignment specified for function %qE"
 msgstr "minnesjustering angiven för funktionen %qE"
 
-#: c/c-decl.c:6649
+#: c/c-decl.c:6669
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of %qE"
 msgstr "%<_Alignas%>-specificerare kan inte reducera justeringen hos %qE"
 
-#: c/c-decl.c:6652
+#: c/c-decl.c:6672
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of unnamed field"
 msgstr "%<_Alignas%>-specificerare kan inte reducera justeringen för namnlösa fält"
 
-#: c/c-decl.c:6683
+#: c/c-decl.c:6703
 #, gcc-internal-format
 msgid "typedef %q+D declared %<inline%>"
 msgstr "typdef %q+D deklarerad %<inline%>"
 
-#: c/c-decl.c:6685
+#: c/c-decl.c:6705
 #, gcc-internal-format
 msgid "typedef %q+D declared %<_Noreturn%>"
 msgstr "typedef %q+D deklarerad %<_Noreturn%>"
 
-#: c/c-decl.c:6727
+#: c/c-decl.c:6747
 #, gcc-internal-format
 msgid "ISO C forbids const or volatile function types"
 msgstr "ISO C förbjuder const- eller volatile-funktionstyper"
 
 #. C99 6.7.2.1p8
-#: c/c-decl.c:6738
+#: c/c-decl.c:6758
 #, gcc-internal-format
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "en medlem av an post eller union får inte ha variabel typ"
 
-#: c/c-decl.c:6755 cp/decl.c:9989
+#: c/c-decl.c:6775 cp/decl.c:10010
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "variabel eller fält %qE deklarerad void"
 
-#: c/c-decl.c:6795
+#: c/c-decl.c:6815
 #, gcc-internal-format
 msgid "attributes in parameter array declarator ignored"
 msgstr "attribut i parametervektordeklarerare ignoreras"
 
-#: c/c-decl.c:6837
+#: c/c-decl.c:6857
 #, gcc-internal-format
 msgid "parameter %q+D declared %<inline%>"
 msgstr "parametern %q+D deklarerad %<inline%>"
 
-#: c/c-decl.c:6839
+#: c/c-decl.c:6859
 #, gcc-internal-format
 msgid "parameter %q+D declared %<_Noreturn%>"
 msgstr "parametern %q+D deklarerad %<_Noreturn%>"
 
-#: c/c-decl.c:6852
+#: c/c-decl.c:6872
 #, gcc-internal-format
 msgid "field %qE declared as a function"
 msgstr "fältet %qE deklarerat som en funktion"
 
-#: c/c-decl.c:6859
+#: c/c-decl.c:6879
 #, gcc-internal-format
 msgid "field %qE has incomplete type"
 msgstr "fält %qE har ofullständig typ"
 
-#: c/c-decl.c:6861
+#: c/c-decl.c:6881
 #, gcc-internal-format
 msgid "unnamed field has incomplete type"
 msgstr "namnlöst fält har ofullständig typ"
 
-#: c/c-decl.c:6897 c/c-decl.c:6908 c/c-decl.c:6911
+#: c/c-decl.c:6917 c/c-decl.c:6928 c/c-decl.c:6931
 #, gcc-internal-format
 msgid "invalid storage class for function %qE"
 msgstr "ogiltig lagringsklass för funktionen %qE"
 
-#: c/c-decl.c:6968
+#: c/c-decl.c:6988
 #, gcc-internal-format
 msgid "cannot inline function %<main%>"
 msgstr "kan inte inline:a funktionen %<main%>"
 
-#: c/c-decl.c:6970
+#: c/c-decl.c:6990
 #, gcc-internal-format
 msgid "%<main%> declared %<_Noreturn%>"
 msgstr "%<main%> deklarerad %<_Noreturn%>"
 
-#: c/c-decl.c:6981
+#: c/c-decl.c:7001
 #, gcc-internal-format
 msgid "ISO C99 does not support %<_Noreturn%>"
 msgstr "ISO C99 stödjer inte %<_Noreturn%>"
 
-#: c/c-decl.c:6984
+#: c/c-decl.c:7004
 #, gcc-internal-format
 msgid "ISO C90 does not support %<_Noreturn%>"
 msgstr "ISO C90 stödjer inte %<_Noreturn%>"
 
-#: c/c-decl.c:7013
+#: c/c-decl.c:7033
 #, gcc-internal-format
 msgid "variable previously declared %<static%> redeclared %<extern%>"
 msgstr "variabel tidigare deklarerad %<static%> omdeklarerad som %<extern%>"
 
-#: c/c-decl.c:7023
+#: c/c-decl.c:7043
 #, gcc-internal-format
 msgid "variable %q+D declared %<inline%>"
 msgstr "variabeln %q+D deklarerad %<inline%>"
 
-#: c/c-decl.c:7025
+#: c/c-decl.c:7045
 #, gcc-internal-format
 msgid "variable %q+D declared %<_Noreturn%>"
 msgstr "variabeln %q+D deklarerad %<_Noreturn%>"
 
-#: c/c-decl.c:7060
+#: c/c-decl.c:7080
 #, gcc-internal-format
 msgid "non-nested function with variably modified type"
 msgstr "onästad funktion med variabelt modifierad typ"
 
-#: c/c-decl.c:7062
+#: c/c-decl.c:7082
 #, gcc-internal-format
 msgid "object with variably modified type must have no linkage"
 msgstr "objekt med variabel typ får inte ha länkklass"
 
-#: c/c-decl.c:7153 c/c-decl.c:8821
+#: c/c-decl.c:7173 c/c-decl.c:8841
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr "funktionsdeklarationen är inte en prototyp"
 
-#: c/c-decl.c:7163
+#: c/c-decl.c:7183
 #, gcc-internal-format
 msgid "parameter names (without types) in function declaration"
 msgstr "parameternamn (utan typer) i funktionsdeklaration"
 
-#: c/c-decl.c:7201
+#: c/c-decl.c:7221
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has incomplete type"
 msgstr "parameter %u (%q+D) har ofullständig typ"
 
-#: c/c-decl.c:7205
+#: c/c-decl.c:7225
 #, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has incomplete type"
 msgstr "parameter %u har ofullständig typ"
 
-#: c/c-decl.c:7216
+#: c/c-decl.c:7236
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has void type"
 msgstr "parameter %u (%q+D) har void-typ"
 
-#: c/c-decl.c:7220
+#: c/c-decl.c:7240
 #, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has void type"
 msgstr "parameter %u har void-typ"
 
-#: c/c-decl.c:7294
+#: c/c-decl.c:7314
 #, gcc-internal-format
 msgid "%<void%> as only parameter may not be qualified"
 msgstr "%<void%> som enda parameter kan inte kvalificeras"
 
-#: c/c-decl.c:7298 c/c-decl.c:7334
+#: c/c-decl.c:7318 c/c-decl.c:7354
 #, gcc-internal-format
 msgid "%<void%> must be the only parameter"
 msgstr "%<void%> måste vara den enda parametern"
 
-#: c/c-decl.c:7328
+#: c/c-decl.c:7348
 #, gcc-internal-format
 msgid "parameter %q+D has just a forward declaration"
 msgstr "parameter %q+D har endast en framåtdeklaration"
 
-#: c/c-decl.c:7374
+#: c/c-decl.c:7394
 #, gcc-internal-format
 msgid "%<%s %E%> declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr "%<%s %E%> deklarerad inuti parameterlista kommer inte vara synlig utanför denna definition eller deklaration"
 
-#: c/c-decl.c:7380
+#: c/c-decl.c:7400
 #, gcc-internal-format, gfc-internal-format
 msgid "anonymous %s declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr "anonym %s deklarerad inuti parameterlista kommer inte vara synlig utanför denna definition eller deklaration"
 
-#: c/c-decl.c:7482
+#: c/c-decl.c:7502
 #, gcc-internal-format
 msgid "enum type defined here"
 msgstr "enum-typ definierad här"
 
-#: c/c-decl.c:7488
+#: c/c-decl.c:7508
 #, gcc-internal-format
 msgid "struct defined here"
 msgstr "post definierad här"
 
-#: c/c-decl.c:7494
+#: c/c-decl.c:7514
 #, gcc-internal-format
 msgid "union defined here"
 msgstr "union definierad här"
 
-#: c/c-decl.c:7570
+#: c/c-decl.c:7590
 #, gcc-internal-format
 msgid "redefinition of %<union %E%>"
 msgstr "omdefinition av %<union %E%>"
 
-#: c/c-decl.c:7572
+#: c/c-decl.c:7592
 #, gcc-internal-format
 msgid "redefinition of %<struct %E%>"
 msgstr "omdefinition av %<struct %E%>"
 
-#: c/c-decl.c:7581
+#: c/c-decl.c:7601
 #, gcc-internal-format
 msgid "nested redefinition of %<union %E%>"
 msgstr "nästad omdefinition av %<union %E%>"
 
-#: c/c-decl.c:7583
+#: c/c-decl.c:7603
 #, gcc-internal-format
 msgid "nested redefinition of %<struct %E%>"
 msgstr "nästad omdefinition av %<struct %E%>"
 
-#: c/c-decl.c:7613 c/c-decl.c:8400
+#: c/c-decl.c:7633 c/c-decl.c:8420
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr "att definiera en typ i %qs-uttryck är ogiltigt i C++"
 
-#: c/c-decl.c:7680 cp/decl.c:4802
+#: c/c-decl.c:7700 cp/decl.c:4802
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "deklaration som inte deklarerar något"
 
-#: c/c-decl.c:7685
+#: c/c-decl.c:7705
 #, gcc-internal-format
 msgid "ISO C99 doesn%'t support unnamed structs/unions"
 msgstr "ISO C99 stödjer inte namnlösa strukturer/unioner"
 
-#: c/c-decl.c:7688
+#: c/c-decl.c:7708
 #, gcc-internal-format
 msgid "ISO C90 doesn%'t support unnamed structs/unions"
 msgstr "ISO C90 stödjer inte namnlösa strukturer/unioner"
 
-#: c/c-decl.c:7781 c/c-decl.c:7799 c/c-decl.c:7860
+#: c/c-decl.c:7801 c/c-decl.c:7819 c/c-decl.c:7880
 #, gcc-internal-format
 msgid "duplicate member %q+D"
 msgstr "dubblerad medlem %q+D"
 
-#: c/c-decl.c:7886
+#: c/c-decl.c:7906
 #, gcc-internal-format
 msgid "empty struct has size 0 in C, size 1 in C++"
 msgstr "tom post har storlek 0 i C, storlek 1 i C++"
 
-#: c/c-decl.c:7889
+#: c/c-decl.c:7909
 #, gcc-internal-format
 msgid "empty union has size 0 in C, size 1 in C++"
 msgstr "tom union har storlek 0 i C, storlek 1 i C++"
 
-#: c/c-decl.c:7994
+#: c/c-decl.c:8014
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr "unionen har inga namngivna medlemmar"
 
-#: c/c-decl.c:7996
+#: c/c-decl.c:8016
 #, gcc-internal-format
 msgid "union has no members"
 msgstr "unionen har inga medlemmar"
 
-#: c/c-decl.c:8001
+#: c/c-decl.c:8021
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr "posten har inga namngivna medlemmar"
 
-#: c/c-decl.c:8003
+#: c/c-decl.c:8023
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr "posten har inga medlemmar"
 
-#: c/c-decl.c:8064 cp/decl.c:12069
+#: c/c-decl.c:8084 cp/decl.c:12093
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "flexibel vektormedlem i union"
 
-#: c/c-decl.c:8070
+#: c/c-decl.c:8090
 #, gcc-internal-format
 msgid "flexible array member not at end of struct"
 msgstr "flexibel vektormedlem inte vid slutet av post"
 
-#: c/c-decl.c:8076
+#: c/c-decl.c:8096
 #, gcc-internal-format
 msgid "flexible array member in a struct with no named members"
 msgstr "flexibel vektormedlem i struct utan namngivna medlemmar"
 
-#: c/c-decl.c:8107
+#: c/c-decl.c:8127
 #, gcc-internal-format
 msgid "type %qT is too large"
 msgstr "typen %qT är för stor"
 
-#: c/c-decl.c:8230
+#: c/c-decl.c:8250
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr "unionen kan inte göras transparent"
 
-#: c/c-decl.c:8372
+#: c/c-decl.c:8392
 #, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr "nästad omdefinition av %<enum %E%>"
 
 #. This enum is a named one that has been declared already.
-#: c/c-decl.c:8379
+#: c/c-decl.c:8399
 #, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr "omdeklaration av %<enum %E%>"
 
-#: c/c-decl.c:8458 cp/decl.c:14423
+#: c/c-decl.c:8478 cp/decl.c:14447
 #, gcc-internal-format
 msgid "specified mode too small for enumeral values"
 msgstr "angiven sort för liten för uppräkningvärden"
 
-#: c/c-decl.c:8473
+#: c/c-decl.c:8493
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr "uppräkningsvärden överskrider gränsen för största heltal"
 
-#: c/c-decl.c:8587 c/c-decl.c:8603
+#: c/c-decl.c:8607 c/c-decl.c:8623
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr "uppräkningsvärde för %qE är inte en heltalskonstant"
 
-#: c/c-decl.c:8598
+#: c/c-decl.c:8618
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr "uppräkningsvärde för %qE är inte ett konstant heltalsuttryck"
 
-#: c/c-decl.c:8622
+#: c/c-decl.c:8642
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr "överspill i uppräkningsvärden"
 
-#: c/c-decl.c:8630
+#: c/c-decl.c:8650
 #, gcc-internal-format
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "ISO C begränsar uppräkningsvärden till intervallet hos %<int%>"
 
-#: c/c-decl.c:8715 cp/decl.c:5104 cp/decl.c:14955
+#: c/c-decl.c:8735 cp/decl.c:5104 cp/decl.c:14979
 #, gcc-internal-format
 msgid "inline function %qD given attribute noinline"
 msgstr "inline-funktionen %qD har fått attributet noinline"
 
-#: c/c-decl.c:8733
+#: c/c-decl.c:8753
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr "returtypen är en ofullständig typ"
 
-#: c/c-decl.c:8744
+#: c/c-decl.c:8764
 #, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr "returtyp sätts skönsmässigt till %<int%>"
 
-#: c/c-decl.c:8771
+#: c/c-decl.c:8791
 #, gcc-internal-format
 msgid "%q+D defined as variadic function without prototype"
 msgstr "%q+D deklarerat som en variadisk funktion utan prototyp"
 
-#: c/c-decl.c:8830
+#: c/c-decl.c:8850
 #, gcc-internal-format
 msgid "no previous prototype for %qD"
 msgstr "ingen tidigare prototyp för %qD"
 
-#: c/c-decl.c:8839
+#: c/c-decl.c:8859
 #, gcc-internal-format
 msgid "%qD was used with no prototype before its definition"
 msgstr "%qD användes utan någon prototyp före sin definition"
 
-#: c/c-decl.c:8847 cp/decl.c:15090
+#: c/c-decl.c:8867 cp/decl.c:15114
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "ingen tidigare deklaration av %qD"
 
-#: c/c-decl.c:8857
+#: c/c-decl.c:8877
 #, gcc-internal-format
 msgid "%qD was used with no declaration before its definition"
 msgstr "%qD användes utan någon deklaration före sin definition"
 
-#: c/c-decl.c:8876
+#: c/c-decl.c:8896
 #, gcc-internal-format
 msgid "return type of %qD is not %<int%>"
 msgstr "returtypen för %qD är inte %<int%>"
 
-#: c/c-decl.c:8878
+#: c/c-decl.c:8898
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr "%<_Atomic%>-kvalificerad returtyp till för %qD"
 
-#: c/c-decl.c:8885
+#: c/c-decl.c:8905
 #, gcc-internal-format
 msgid "%qD is normally a non-static function"
 msgstr "%qD är normalt en icke-statisk funktion"
 
-#: c/c-decl.c:8922
+#: c/c-decl.c:8942
 #, gcc-internal-format
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr "gammaldags parameterdeklarationer i funktionsdefinition med prototyp"
 
-#: c/c-decl.c:8937
+#: c/c-decl.c:8957
 #, gcc-internal-format
 msgid "traditional C rejects ISO C style function definitions"
 msgstr "traditionell C tillåter inte ISO C:s stil av funktionsdefinitioner"
 
-#: c/c-decl.c:8953
+#: c/c-decl.c:8973
 #, gcc-internal-format
 msgid "parameter name omitted"
 msgstr "parameternamn utelämnat"
 
-#: c/c-decl.c:8990
+#: c/c-decl.c:9010
 #, gcc-internal-format
 msgid "old-style function definition"
 msgstr "gammaldags funktionsdefinition"
 
-#: c/c-decl.c:8999
+#: c/c-decl.c:9019
 #, gcc-internal-format
 msgid "parameter name missing from parameter list"
 msgstr "parameternamn saknas i parameterlista"
 
-#: c/c-decl.c:9015
+#: c/c-decl.c:9035
 #, gcc-internal-format
 msgid "%qD declared as a non-parameter"
 msgstr "%qD deklarerad som en icke-parameter"
 
-#: c/c-decl.c:9023
+#: c/c-decl.c:9043
 #, gcc-internal-format
 msgid "multiple parameters named %qD"
 msgstr "flera parametrar med namnet %qD"
 
-#: c/c-decl.c:9032
+#: c/c-decl.c:9052
 #, gcc-internal-format
 msgid "parameter %qD declared with void type"
 msgstr "parameter %qD deklarerad med typen void"
 
-#: c/c-decl.c:9061 c/c-decl.c:9066
+#: c/c-decl.c:9081 c/c-decl.c:9086
 #, gcc-internal-format
 msgid "type of %qD defaults to %<int%>"
 msgstr "typen på %qD sätts skönsmässigt till %<int%>"
 
-#: c/c-decl.c:9086
+#: c/c-decl.c:9106
 #, gcc-internal-format
 msgid "parameter %qD has incomplete type"
 msgstr "parametern %qD har ofullständig typ"
 
-#: c/c-decl.c:9093
+#: c/c-decl.c:9113
 #, gcc-internal-format
 msgid "declaration for parameter %qD but no such parameter"
 msgstr "deklaration av parameter %qD med det finns ingen sådan parameter"
 
-#: c/c-decl.c:9146
+#: c/c-decl.c:9166
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr "antalet argument stämmer inte med inbyggd prototyp"
 
-#: c/c-decl.c:9157
+#: c/c-decl.c:9177
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr "antalet argument stämmer inte med prototypen"
 
-#: c/c-decl.c:9160 c/c-decl.c:9207 c/c-decl.c:9221
+#: c/c-decl.c:9180 c/c-decl.c:9227 c/c-decl.c:9241
 #, gcc-internal-format
 msgid "prototype declaration"
 msgstr "prototypdeklaration"
 
-#: c/c-decl.c:9199
+#: c/c-decl.c:9219
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr "befordrat argument %qD stämmer inte med inbyggd prototyp"
 
-#: c/c-decl.c:9204
+#: c/c-decl.c:9224
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr "befordrat argument %qD stämmer inte med prototypen"
 
-#: c/c-decl.c:9214
+#: c/c-decl.c:9234
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr "argument %qD stämmer inte med inbyggd prototyp"
 
-#: c/c-decl.c:9219
+#: c/c-decl.c:9239
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr "argument %qD stämmer inte med prototypen"
 
-#: c/c-decl.c:9470 cp/decl.c:15873
+#: c/c-decl.c:9490 cp/decl.c:15897
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "ingen retursats i funktion som returnerar icke-void"
 
-#: c/c-decl.c:9490 cp/decl.c:15905
+#: c/c-decl.c:9510 cp/decl.c:15929
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "parametern %qD sätts men används inte"
@@ -34596,247 +34638,247 @@
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:9586
+#: c/c-decl.c:9606
 #, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "%<for%>-slinga med startdeklaration är endast tillåtet i C99- och C11-läge"
 
-#: c/c-decl.c:9591
+#: c/c-decl.c:9611
 #, gcc-internal-format
 msgid "use option -std=c99, -std=gnu99, -std=c11 or -std=gnu11 to compile your code"
 msgstr "använd flaggan -std=c99, -std=gnu99, -std=c11 eller -std=gnu11 för att kompilera din kod"
 
-#: c/c-decl.c:9626
+#: c/c-decl.c:9646
 #, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "deklaration av statisk variabel %qD i %<for%>-slingas initiala deklaration"
 
-#: c/c-decl.c:9630
+#: c/c-decl.c:9650
 #, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "deklaration av %<extern%>-variabel %qD i %<for%>-slingas initiala deklaration"
 
-#: c/c-decl.c:9637
+#: c/c-decl.c:9657
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "%<struct %E%> är deklarerad i %<for%>-slingas initiala deklaration"
 
-#: c/c-decl.c:9642
+#: c/c-decl.c:9662
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "%<union %E%> är deklarerad i %<for%>-slingas initiala deklaration"
 
-#: c/c-decl.c:9646
+#: c/c-decl.c:9666
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "%<enum %E%> är deklarerad i %<for%>-slingas initiala deklaration"
 
-#: c/c-decl.c:9650
+#: c/c-decl.c:9670
 #, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "deklaration av icke-variabel %qD i %<for%>-slingas initiala deklaration"
 
-#: c/c-decl.c:9900
+#: c/c-decl.c:9920
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr "inkompatibla adressrymdskvalificerare %qs och %qs"
 
-#: c/c-decl.c:9958 c/c-decl.c:9965
+#: c/c-decl.c:9978 c/c-decl.c:9985
 #, gcc-internal-format
 msgid "duplicate %qE declaration specifier"
 msgstr "dubblerade %qE-deklarationsspecificerare"
 
-#: c/c-decl.c:9992 c/c-decl.c:10376 c/c-decl.c:10766
+#: c/c-decl.c:10012 c/c-decl.c:10396 c/c-decl.c:10786
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr "två eller fler datatyper i deklaration av specificerare"
 
-#: c/c-decl.c:10004 cp/parser.c:28261
+#: c/c-decl.c:10024 cp/parser.c:28258
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> är för långt för GCC"
 
-#: c/c-decl.c:10017
+#: c/c-decl.c:10037
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C90 stödjer inte %<long long%>"
 
-#: c/c-decl.c:10246 c/c-parser.c:8848
+#: c/c-decl.c:10266 c/c-parser.c:8848
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C90 stödjer inte komplexa typer"
 
-#: c/c-decl.c:10292
+#: c/c-decl.c:10312
 #, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr "ISO C stödjer inte mättning av typer"
 
-#: c/c-decl.c:10363 c/c-decl.c:10923
+#: c/c-decl.c:10383 c/c-decl.c:10943
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "dubblerad %qE"
 
-#: c/c-decl.c:10419
+#: c/c-decl.c:10439
 #, gcc-internal-format
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C stödjer inte typen %<__int%d%>"
 
-#: c/c-decl.c:10441
+#: c/c-decl.c:10461
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr "%<__int%d%> stödjs inte för denna målarkitektur"
 
-#: c/c-decl.c:10484
+#: c/c-decl.c:10504
 #, gcc-internal-format
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C90 stödjer inte booleska typer"
 
-#: c/c-decl.c:10603
+#: c/c-decl.c:10623
 #, gcc-internal-format
 msgid "ISO C does not support the %<_Float%d%s%> type"
 msgstr "ISO C stödjer inte typen %<_Float%d%s%>"
 
-#: c/c-decl.c:10653
+#: c/c-decl.c:10673
 #, gcc-internal-format
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "%<_Float%d%s%> stödjs inte för denna målarkitektur"
 
-#: c/c-decl.c:10724
+#: c/c-decl.c:10744
 #, gcc-internal-format
 msgid "ISO C does not support decimal floating point"
 msgstr "ISO C stödjer inte decimala flyttal"
 
-#: c/c-decl.c:10747 c/c-decl.c:11013 c/c-parser.c:7842
+#: c/c-decl.c:10767 c/c-decl.c:11033 c/c-parser.c:7842
 #, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "fixdecimaltyper stödjs inte för denna målarkitektur"
 
-#: c/c-decl.c:10749
+#: c/c-decl.c:10769
 #, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C stödjer inte fixdecimaltyper"
 
-#: c/c-decl.c:10784
+#: c/c-decl.c:10804
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr "C++-uppslagning av %qD skulle returnera ett fält, inte en typ"
 
-#: c/c-decl.c:10797
+#: c/c-decl.c:10817
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr "%qE är varken en typedef eller en inbyggd typ"
 
-#: c/c-decl.c:10845
+#: c/c-decl.c:10865
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qE är inte i början av deklarationen"
 
-#: c/c-decl.c:10866
+#: c/c-decl.c:10886
 #, gcc-internal-format
 msgid "%qE used with %<auto%>"
 msgstr "%qE använd med %<auto%>"
 
-#: c/c-decl.c:10868
+#: c/c-decl.c:10888
 #, gcc-internal-format
 msgid "%qE used with %<register%>"
 msgstr "%qE använd med %<register%>"
 
-#: c/c-decl.c:10870
+#: c/c-decl.c:10890
 #, gcc-internal-format
 msgid "%qE used with %<typedef%>"
 msgstr "%qE använd med %<typedef%>"
 
-#: c/c-decl.c:10884 c/c-parser.c:7360
+#: c/c-decl.c:10904 c/c-parser.c:7360
 #, gcc-internal-format
 msgid "ISO C99 does not support %qE"
 msgstr "ISO C99 stödjer inte %qE"
 
-#: c/c-decl.c:10887 c/c-parser.c:7363
+#: c/c-decl.c:10907 c/c-parser.c:7363
 #, gcc-internal-format
 msgid "ISO C90 does not support %qE"
 msgstr "ISO C90 stödjer inte %qE"
 
-#: c/c-decl.c:10899
+#: c/c-decl.c:10919
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<__thread%> före %<extern%>"
 
-#: c/c-decl.c:10908
+#: c/c-decl.c:10928
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<__thread%> före %<static%>"
 
-#: c/c-decl.c:10921
+#: c/c-decl.c:10941
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr "dubblerat %<_Thread_local%> eller %<__thread%>"
 
-#: c/c-decl.c:10929
+#: c/c-decl.c:10949
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr "flera lagringsklasser i deklarationsspecificerare"
 
-#: c/c-decl.c:10937
+#: c/c-decl.c:10957
 #, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr "%qs använd med %qE"
 
-#: c/c-decl.c:11010
+#: c/c-decl.c:11030
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "%<_Sat%> används utan %<_Fract%> eller %<_Accum%>"
 
-#: c/c-decl.c:11025
+#: c/c-decl.c:11045
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C stödjer inte bara %<complex%> i meningen %<double complex%>"
 
-#: c/c-decl.c:11076 c/c-decl.c:11092 c/c-decl.c:11118
+#: c/c-decl.c:11096 c/c-decl.c:11112 c/c-decl.c:11138
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C stödjer inte komplexa heltalstyper"
 
-#: c/c-decl.c:11514 cp/semantics.c:5348
+#: c/c-decl.c:11534 cp/semantics.c:5351
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr "%<#pragma omp declare reduction%>-kombinerare refererar variabeln %qD som inte är varken %<omp_out%> eller %<omp_in%>"
 
-#: c/c-decl.c:11518 cp/semantics.c:5352
+#: c/c-decl.c:11538 cp/semantics.c:5355
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr "%<#pragma omp declare reduction%>-initierare refererar till variabeln %qD som inte är varken %<omp_priv%> eller %<omp_orig%>"
 
-#: c/c-fold.c:385 c/c-typeck.c:11426 cp/typeck.c:4680
+#: c/c-fold.c:385 c/c-typeck.c:11431 cp/typeck.c:4680
 #, gcc-internal-format
 msgid "left shift of negative value"
 msgstr "vänsterskift med negativt värde"
 
-#: c/c-fold.c:395 c/c-typeck.c:11435 cp/typeck.c:4688
+#: c/c-fold.c:395 c/c-typeck.c:11440 cp/typeck.c:4688
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "vänstershiftoperanden är negativ"
 
-#: c/c-fold.c:396 c/c-typeck.c:11365 cp/typeck.c:4633
+#: c/c-fold.c:396 c/c-typeck.c:11370 cp/typeck.c:4633
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "högershiftoperanden är negativ"
 
-#: c/c-fold.c:404 c/c-typeck.c:11454 cp/typeck.c:4696
+#: c/c-fold.c:404 c/c-typeck.c:11459 cp/typeck.c:4696
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "vänstershiftoperanden ≥ storleken på typen"
 
-#: c/c-fold.c:405 c/c-typeck.c:11389 cp/typeck.c:4641
+#: c/c-fold.c:405 c/c-typeck.c:11394 cp/typeck.c:4641
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "högershiftoperanden ≥ storleken på typen"
 
-#: c/c-fold.c:412 c/c-typeck.c:11446
+#: c/c-fold.c:412 c/c-typeck.c:11451
 #, gcc-internal-format
 msgid "left shift count >= width of vector element"
 msgstr "vänstershiftoperanden ≥ storleken på vektorelementet"
 
-#: c/c-fold.c:413 c/c-typeck.c:11376
+#: c/c-fold.c:413 c/c-typeck.c:11381
 #, gcc-internal-format
 msgid "right shift count >= width of vector element"
 msgstr "högershiftoperanden ≥ storleken på vektorelementet"
@@ -34856,7 +34898,7 @@
 msgid "to match this %qs"
 msgstr "för att matcha denna %qs"
 
-#: c/c-parser.c:1216 cp/parser.c:28484
+#: c/c-parser.c:1216 cp/parser.c:28481
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr "oväntat radslut"
@@ -34897,7 +34939,7 @@
 msgstr "okänt typnamn %qE"
 
 #: c/c-parser.c:1848 c/c-parser.c:11129 c/c-parser.c:16147 c/c-parser.c:16585
-#: c/c-parser.c:17061 cp/parser.c:36007 cp/parser.c:38993
+#: c/c-parser.c:17061 cp/parser.c:36004 cp/parser.c:38990
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "deklarationsspecificerare förväntades"
@@ -34912,7 +34954,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "%<;%>, identifierare eller %<(%> förväntades"
 
-#: c/c-parser.c:1906 cp/parser.c:30161 cp/parser.c:30235
+#: c/c-parser.c:1906 cp/parser.c:30158 cp/parser.c:30232
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "prefixattribut ignoreras för metoder"
@@ -34966,7 +35008,7 @@
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr "%<__auto_type%> kan endast användas med en ensam deklarerare"
 
-#: c/c-parser.c:2220 cp/parser.c:13002 cp/parser.c:13159
+#: c/c-parser.c:2220 cp/parser.c:12999 cp/parser.c:13156
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "%<,%> eller %<;%> förväntades"
@@ -34994,7 +35036,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C90 stödjer inte %<_Static_assert%>"
 
-#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38634
+#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38631
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr "strängkonstant förväntades"
@@ -35058,13 +35100,13 @@
 #: c/c-parser.c:10745 c/c-parser.c:10798 c/c-parser.c:10814 c/c-parser.c:10860
 #: c/c-parser.c:11496 c/c-parser.c:11537 c/c-parser.c:13445 c/c-parser.c:13681
 #: c/c-parser.c:15544 c/c-parser.c:18218 c/gimple-parser.c:1058
-#: c/gimple-parser.c:1096 cp/parser.c:28487 cp/parser.c:31013
-#: cp/parser.c:31043 cp/parser.c:31113 cp/parser.c:33230 cp/parser.c:38350
+#: c/gimple-parser.c:1096 cp/parser.c:28484 cp/parser.c:31010
+#: cp/parser.c:31040 cp/parser.c:31110 cp/parser.c:33227 cp/parser.c:38347
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "identifierare förväntades"
 
-#: c/c-parser.c:2995 cp/parser.c:18384
+#: c/c-parser.c:2995 cp/parser.c:18381
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "komma i slutet av uppräkningslista"
@@ -35233,12 +35275,12 @@
 msgid "expected statement"
 msgstr "sats förväntades"
 
-#: c/c-parser.c:5639 cp/parser.c:12516
+#: c/c-parser.c:5639 cp/parser.c:12513
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "föreslår klamrar runt tom kropp i en %<if%>-sats"
 
-#: c/c-parser.c:5681 cp/parser.c:12519
+#: c/c-parser.c:5681 cp/parser.c:12516
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "föreslår klamrar runt tom kropp i en %<else%>-sats"
@@ -35576,7 +35618,7 @@
 msgid "%<__builtin_complex%> operands of different types"
 msgstr "operander till %<__builtin_complex%> av olika typer"
 
-#: c/c-parser.c:8891 cp/parser.c:6918
+#: c/c-parser.c:8891 cp/parser.c:6921
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_shuffle%>"
 msgstr "fel antal argument till %<__builtin_shuffle%>"
@@ -35636,76 +35678,76 @@
 msgid "no type or storage class may be specified here,"
 msgstr "ingen typ eller lagringsklass kan anges här,"
 
-#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31073
+#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31070
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "okänt egenskapsattribut"
 
-#: c/c-parser.c:10682 cp/parser.c:31033
+#: c/c-parser.c:10682 cp/parser.c:31030
 #, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "%<=%> saknas (efter attributet %<getter%>)"
 
-#: c/c-parser.c:10685 cp/parser.c:31036
+#: c/c-parser.c:10685 cp/parser.c:31033
 #, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "%<=%> saknas (efter attributet %<setter%>)"
 
-#: c/c-parser.c:10699 cp/parser.c:31051
+#: c/c-parser.c:10699 cp/parser.c:31048
 #, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "attributet %<setter%> kan bara anges en gång"
 
-#: c/c-parser.c:10704 cp/parser.c:31057
+#: c/c-parser.c:10704 cp/parser.c:31054
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr "setter-namn måste avslutas med %<:%>"
 
-#: c/c-parser.c:10711 cp/parser.c:31065
+#: c/c-parser.c:10711 cp/parser.c:31062
 #, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "attributet %<getter%> kan bara anges en gång"
 
-#: c/c-parser.c:10905 cp/parser.c:38674
+#: c/c-parser.c:10905 cp/parser.c:38671
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr "%<#pragma GCC unroll%> kräver ett tilldelningsuttryck som beräknas till en icke-negativ heltalskonstant mindre än %u"
 
 #: c/c-parser.c:10949 c/c-parser.c:16582 c/c-parser.c:16840 c/c-parser.c:16899
-#: c/c-parser.c:16983 cp/parser.c:36004 cp/parser.c:36298 cp/parser.c:36386
-#: cp/parser.c:36457 cp/parser.c:38721 cp/parser.c:38736 cp/parser.c:38752
-#: cp/parser.c:38768 cp/parser.c:38784 cp/parser.c:38811 cp/parser.c:38824
-#: cp/parser.c:38847 cp/parser.c:38860
+#: c/c-parser.c:16983 cp/parser.c:36001 cp/parser.c:36295 cp/parser.c:36383
+#: cp/parser.c:36454 cp/parser.c:38718 cp/parser.c:38733 cp/parser.c:38749
+#: cp/parser.c:38765 cp/parser.c:38781 cp/parser.c:38808 cp/parser.c:38821
+#: cp/parser.c:38844 cp/parser.c:38857
 #, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<#pragma %s%> får bara användas i sammansatta satser"
 
-#: c/c-parser.c:10972 cp/parser.c:38837
+#: c/c-parser.c:10972 cp/parser.c:38834
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<#pragma acc routine%> måste ha filräckvidd"
 
-#: c/c-parser.c:11050 cp/parser.c:38918
+#: c/c-parser.c:11050 cp/parser.c:38915
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<#pragma omp section%> får bara användas i %<#pragma omp sections%>-konstruktion"
 
-#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38947 cp/parser.c:38980
+#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38944 cp/parser.c:38977
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "for-, while- eller do-sats förväntades"
 
-#: c/c-parser.c:11111 cp/parser.c:38711
+#: c/c-parser.c:11111 cp/parser.c:38708
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%> måste komma först"
 
-#: c/c-parser.c:11421 cp/parser.c:31457
+#: c/c-parser.c:11421 cp/parser.c:31454
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "för många %qs-klausuler"
 
-#: c/c-parser.c:11443 cp/parser.c:31994
+#: c/c-parser.c:11443 cp/parser.c:31991
 #, gcc-internal-format
 msgid "expected integer expression before ')'"
 msgstr "heltalsuttryck förväntades före ”)”"
@@ -35720,53 +35762,53 @@
 msgid "%qD is not a variable"
 msgstr "%qD är inte en variabel"
 
-#: c/c-parser.c:11746 cp/semantics.c:6808
+#: c/c-parser.c:11746 cp/semantics.c:6811
 #, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "%qD är inte en pekarvariabel"
 
-#: c/c-parser.c:11788 cp/parser.c:32073
+#: c/c-parser.c:11788 cp/parser.c:32070
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr "collapse-argument behöver ett positivt konstant heltalsuttryck"
 
-#: c/c-parser.c:11865 cp/parser.c:32137
+#: c/c-parser.c:11865 cp/parser.c:32134
 #, gcc-internal-format
 msgid "expected %<none%> or %<present%>"
 msgstr "%<none%> eller %<present%> förväntades"
 
-#: c/c-parser.c:11867 cp/parser.c:32139
+#: c/c-parser.c:11867 cp/parser.c:32136
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "%<none%> eller %<shared%> förväntades"
 
-#: c/c-parser.c:11968 cp/parser.c:32242
+#: c/c-parser.c:11968 cp/parser.c:32239
 #, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "%<data%>, %<update%>, %<enter%> eller %<exit%> förväntades"
 
-#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32260
-#: cp/parser.c:36290 cp/parser.c:36378
+#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32257
+#: cp/parser.c:36287 cp/parser.c:36375
 #, gcc-internal-format
 msgid "expected %<data%>"
 msgstr "%<data%> förväntades"
 
-#: c/c-parser.c:12035 cp/parser.c:32313
+#: c/c-parser.c:12035 cp/parser.c:32310
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr "för många %<if%>-klausuler med %qs-modifierare"
 
-#: c/c-parser.c:12042 cp/parser.c:32320
+#: c/c-parser.c:12042 cp/parser.c:32317
 #, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr "för många %<if%>-klausuler"
 
-#: c/c-parser.c:12044 cp/parser.c:32322
+#: c/c-parser.c:12044 cp/parser.c:32319
 #, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr "för många %<if%>-klausuler utan modifierare"
 
-#: c/c-parser.c:12050 cp/parser.c:32328
+#: c/c-parser.c:12050 cp/parser.c:32325
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr "om någon %<if%>-klausul har en modifierare måste alla %<if%>-klausuler använda modifierare"
@@ -35788,82 +35830,82 @@
 msgid "%<num_tasks%> value must be positive"
 msgstr "%<num_tasks%>-värdet måste vara positivt"
 
-#: c/c-parser.c:12229 cp/semantics.c:6992
+#: c/c-parser.c:12229 cp/semantics.c:6995
 #, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr "%<grainsize%>-värdet måste vara positivt"
 
-#: c/c-parser.c:12276 cp/semantics.c:7021
+#: c/c-parser.c:12276 cp/semantics.c:7024
 #, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr "%<priority%>-värdet måste vara positivt"
 
-#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32545 cp/parser.c:32552
+#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32542 cp/parser.c:32549
 #, gcc-internal-format
 msgid "expected %<tofrom%>"
 msgstr "%<tofrom%> förväntades"
 
-#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32561 cp/parser.c:32568
+#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32558 cp/parser.c:32565
 #, gcc-internal-format
 msgid "expected %<scalar%>"
 msgstr "%<scalar%> förväntades"
 
-#: c/c-parser.c:12425 cp/semantics.c:6299
+#: c/c-parser.c:12425 cp/semantics.c:6302
 #, gcc-internal-format
 msgid "%qs expression must be integral"
 msgstr "%qs-uttrycket måste vara ett heltal"
 
-#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6331
+#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6334
 #, gcc-internal-format
 msgid "%qs value must be positive"
 msgstr "%qs-värdet måste vara positivt"
 
-#: c/c-parser.c:12499 cp/parser.c:31853
+#: c/c-parser.c:12499 cp/parser.c:31850
 #, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "för många %<static%>-argument"
 
-#: c/c-parser.c:12533 cp/parser.c:31886
+#: c/c-parser.c:12533 cp/parser.c:31883
 #, gcc-internal-format
 msgid "unexpected argument"
 msgstr "oväntat argument"
 
-#: c/c-parser.c:12699 cp/semantics.c:7120
+#: c/c-parser.c:12699 cp/semantics.c:7123
 #, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "argumentet till %<tile%> behöver en positiv heltalskonstant"
 
-#: c/c-parser.c:12765 cp/parser.c:32626
+#: c/c-parser.c:12765 cp/parser.c:32623
 #, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr "ordered-argument behöver ett positivt konstant heltalsuttryck"
 
-#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37643
+#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37640
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "%<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> eller identifierare förväntades"
 
-#: c/c-parser.c:12967 cp/parser.c:32840
+#: c/c-parser.c:12967 cp/parser.c:32837
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "både %<monotonic%>- och %<nonmonotonic%>-modifierare angivna"
 
-#: c/c-parser.c:13021 cp/parser.c:32856
+#: c/c-parser.c:13021 cp/parser.c:32853
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "%<runtime%>-schemaläggning tar ingen %<chunk_size%>-parameter"
 
-#: c/c-parser.c:13025 cp/parser.c:32859
+#: c/c-parser.c:13025 cp/parser.c:32856
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "%<auto%>-schemaläggning tar ingen %<chunk_size%>-parameter"
 
-#: c/c-parser.c:13037 cp/semantics.c:6389
+#: c/c-parser.c:13037 cp/semantics.c:6392
 #, gcc-internal-format
 msgid "chunk size value must be positive"
 msgstr "värdet på styckesstorleken måste vara positivt"
 
-#: c/c-parser.c:13060 cp/parser.c:32879
+#: c/c-parser.c:13060 cp/parser.c:32876
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "ogiltig schedule-sort"
@@ -35873,12 +35915,12 @@
 msgid "%<num_teams%> value must be positive"
 msgstr "%<num_teams%>-värdet måste vara positivt"
 
-#: c/c-parser.c:13226 cp/semantics.c:6479
+#: c/c-parser.c:13226 cp/semantics.c:6482
 #, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr "%<thread_limit%>-värdet måste vara positivt"
 
-#: c/c-parser.c:13271 cp/semantics.c:6589
+#: c/c-parser.c:13271 cp/semantics.c:6592
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr "%<aligned%>-klausulens justeringsuttryck måste vara ett positivt konstant heltalsuttryck"
@@ -35898,17 +35940,17 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr "%<simdlen%>-klausulens uttryck måste vara ett positivt konstant heltalsuttryck"
 
-#: c/c-parser.c:13584 cp/parser.c:33374 cp/parser.c:33599
+#: c/c-parser.c:13584 cp/parser.c:33371 cp/parser.c:33596
 #, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "ogiltig depend-sort"
 
-#: c/c-parser.c:13669 cp/parser.c:33447
+#: c/c-parser.c:13669 cp/parser.c:33444
 #, gcc-internal-format
 msgid "invalid map kind"
 msgstr "ogiltig map-sort"
 
-#: c/c-parser.c:13767 cp/parser.c:33546
+#: c/c-parser.c:13767 cp/parser.c:33543
 #, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "ogiltig dist_schedule-sort"
@@ -35918,67 +35960,67 @@
 msgid "invalid proc_bind kind"
 msgstr "ogiltig proc_bind-sort"
 
-#: c/c-parser.c:14059 cp/parser.c:33825
+#: c/c-parser.c:14059 cp/parser.c:33822
 #, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr "%<#pragma acc%>-klausul förväntades"
 
-#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33836 cp/parser.c:34143
+#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33833 cp/parser.c:34140
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs är inte giltigt för %qs"
 
-#: c/c-parser.c:14214 cp/parser.c:34010
+#: c/c-parser.c:14214 cp/parser.c:34007
 #, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "%qs måste vara den första klausulen i %qs"
 
-#: c/c-parser.c:14334 cp/parser.c:34132
+#: c/c-parser.c:14334 cp/parser.c:34129
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "%<#pragma omp%>-klausul förväntades"
 
-#: c/c-parser.c:14472 cp/parser.c:36803
+#: c/c-parser.c:14472 cp/parser.c:36800
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr "inga giltiga klausuler angivna i %<#pragma acc declare%>"
 
-#: c/c-parser.c:14482 cp/parser.c:36813
+#: c/c-parser.c:14482 cp/parser.c:36810
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr "vektorsektionen i %<#pragma acc declare%>"
 
-#: c/c-parser.c:14502 cp/parser.c:36833
+#: c/c-parser.c:14502 cp/parser.c:36830
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr "%qD måste vara en global variabel i %<#pragma acc declare link%>"
 
-#: c/c-parser.c:14513 cp/parser.c:36844
+#: c/c-parser.c:14513 cp/parser.c:36841
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr "ogiltig OpenACC-klausul vid filräckvidd"
 
-#: c/c-parser.c:14520 cp/parser.c:36851
+#: c/c-parser.c:14520 cp/parser.c:36848
 #, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "ogiltig användning av %<extern%>-variabel %qD i %<#pragma acc declare%>"
 
-#: c/c-parser.c:14528 cp/parser.c:36859
+#: c/c-parser.c:14528 cp/parser.c:36856
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "ogiltig användning av %<global%>-variabeln %qD i %<#pragma acc declare%>"
 
-#: c/c-parser.c:14540 cp/parser.c:36871
+#: c/c-parser.c:14540 cp/parser.c:36868
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr "variabeln %qD använd mer än en gång med %<#pragma acc declare%>"
 
-#: c/c-parser.c:14632 cp/parser.c:36957
+#: c/c-parser.c:14632 cp/parser.c:36954
 #, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "%<data%> förväntades efter %<#pragma acc %s%>"
 
-#: c/c-parser.c:14648 cp/parser.c:36974
+#: c/c-parser.c:14648 cp/parser.c:36971
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr "%<#pragma acc %s data%> har ingen dataflyttningsklausul"
@@ -35993,7 +36035,7 @@
 msgid "expected function name"
 msgstr "ett funktionsnamn förväntades"
 
-#: c/c-parser.c:14893 cp/parser.c:38064
+#: c/c-parser.c:14893 cp/parser.c:38061
 #, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr "%qD refererar inte till en funktion"
@@ -36003,42 +36045,42 @@
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr "%<#pragma acc routine%> följs inte omedelbart av en funktionsdeklaration eller -definition"
 
-#: c/c-parser.c:14953 cp/parser.c:38118 cp/parser.c:38160
+#: c/c-parser.c:14953 cp/parser.c:38115 cp/parser.c:38157
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr "%<#pragma acc routine%> följs inte omedelbart av en ensam funktionsdeklaration eller -definition"
 
-#: c/c-parser.c:14970 cp/parser.c:38174
+#: c/c-parser.c:14970 cp/parser.c:38171
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> already applied to %qD"
 msgstr "%<#pragma acc routine%> redan använd på %qD"
 
-#: c/c-parser.c:14979 cp/parser.c:38183
+#: c/c-parser.c:14979 cp/parser.c:38180
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr "%<#pragma acc routine%> måste vara tillämpad före användning"
 
-#: c/c-parser.c:14980 cp/parser.c:38184
+#: c/c-parser.c:14980 cp/parser.c:38181
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<#pragma acc routine%> måste vara tillämpad före definitionen"
 
-#: c/c-parser.c:15023 cp/parser.c:37152
+#: c/c-parser.c:15023 cp/parser.c:37149
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr "%<#pragma acc update%> måste innehålla åtminstone en %<device%>- eller %<host%>- eller %<self%>-klausul"
 
-#: c/c-parser.c:15435 cp/parser.c:34511 cp/parser.c:34537
+#: c/c-parser.c:15435 cp/parser.c:34508 cp/parser.c:34534
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "ogiltig form på %<#pragma omp atomic%>"
 
-#: c/c-parser.c:15439 cp/parser.c:34568 cp/parser.c:34584
+#: c/c-parser.c:15439 cp/parser.c:34565 cp/parser.c:34581
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "ogiltig operator för %<#pragma omp atomic%>"
 
-#: c/c-parser.c:15488 cp/semantics.c:8401 cp/semantics.c:8411
+#: c/c-parser.c:15488 cp/semantics.c:8404 cp/semantics.c:8414
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr "%<#pragma omp atomic capture%> använder två olika uttryck till minne"
@@ -36048,22 +36090,22 @@
 msgid "expected %<(%> or end of line"
 msgstr "%<(%> eller filslut förväntades"
 
-#: c/c-parser.c:15619 cp/parser.c:35103
+#: c/c-parser.c:15619 cp/parser.c:35100
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr "%<ordered%>-klausulparameter är mindre än %<collapse%>"
 
-#: c/c-parser.c:15630 cp/parser.c:35114
+#: c/c-parser.c:15630 cp/parser.c:35111
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr "en %<linear%>-klausul får inte anges tillsammans med en %<ordered%>-klausul med en parameter"
 
-#: c/c-parser.c:15648 cp/parser.c:35141
+#: c/c-parser.c:15648 cp/parser.c:35138
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "for-sats förväntades"
 
-#: c/c-parser.c:15718 cp/semantics.c:8066 cp/semantics.c:8153
+#: c/c-parser.c:15718 cp/semantics.c:8069 cp/semantics.c:8156
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "iterationsdeklaration eller initiering förväntades"
@@ -36073,72 +36115,72 @@
 msgid "not enough perfectly nested loops"
 msgstr "inte tillräckligt med perfekt nästade slingor"
 
-#: c/c-parser.c:15862 cp/parser.c:35364
+#: c/c-parser.c:15862 cp/parser.c:35361
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr "kollapsade slingor inte perfekt nästade"
 
-#: c/c-parser.c:15909 cp/parser.c:35184 cp/parser.c:35226 cp/pt.c:16385
+#: c/c-parser.c:15909 cp/parser.c:35181 cp/parser.c:35223 cp/pt.c:16407
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "iterationsvariabel %qD får inte vara firstprivate"
 
-#: c/c-parser.c:16000 cp/parser.c:35437
+#: c/c-parser.c:16000 cp/parser.c:35434
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "en %<ordered%>-klausul med parameter får inte anges på en %qs-konstruktion"
 
-#: c/c-parser.c:16166 cp/parser.c:35600
+#: c/c-parser.c:16166 cp/parser.c:35597
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr "%<#pragma omp ordered%> med %<depend%>-klausul får bara användas i sammansatta satser"
 
-#: c/c-parser.c:16374 cp/parser.c:35799
+#: c/c-parser.c:16374 cp/parser.c:35796
 #, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "%<for%> förväntades efter %qs"
 
-#: c/c-parser.c:16573 cp/parser.c:35995
+#: c/c-parser.c:16573 cp/parser.c:35992
 #, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "%<point%> förväntades"
 
-#: c/c-parser.c:16793 cp/parser.c:36232
+#: c/c-parser.c:16793 cp/parser.c:36229
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target data%> med en annan map-typ än %<to%>, %<from%>, %<tofrom%> eller %<alloc%> på %<map%>-klausul"
 
-#: c/c-parser.c:16806 cp/parser.c:36245
+#: c/c-parser.c:16806 cp/parser.c:36242
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp target data%> måste innehålla åtminstone en %<map%>-klausul"
 
-#: c/c-parser.c:16853 cp/parser.c:36470
+#: c/c-parser.c:16853 cp/parser.c:36467
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr "%<#pragma omp target update%> måste innehålla åtminstone en %<from%>- eller %<to%>-klausul"
 
-#: c/c-parser.c:16925 cp/parser.c:36325
+#: c/c-parser.c:16925 cp/parser.c:36322
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target enter data%> med en annan map-typ än %<to%> eller %<alloc%> på %<map%>-klausul"
 
-#: c/c-parser.c:16937 cp/parser.c:36337
+#: c/c-parser.c:16937 cp/parser.c:36334
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp target enter data%> måste innehålla åtminstone en %<map%>-klausul"
 
-#: c/c-parser.c:17011 cp/parser.c:36414
+#: c/c-parser.c:17011 cp/parser.c:36411
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr "%<#pragma omp target exit data%> med en annan map-typ än %<from%>-, %<release%>- eller %<delete%> på %<map%>-klausul"
 
-#: c/c-parser.c:17024 cp/parser.c:36427
+#: c/c-parser.c:17024 cp/parser.c:36424
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp target exit data%> måste innehålla åtminstone en %<map%>-klausul"
 
-#: c/c-parser.c:17238 cp/parser.c:36680
+#: c/c-parser.c:17238 cp/parser.c:36677
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target%> med en annan map-typ än %<to%>, %<from%>, %<tofrom%> eller %<alloc%> på %<map%>-klausul"
@@ -36158,32 +36200,32 @@
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr "%<#pragma omp declare simd%> som inte omedelbart följs av en funktionsdefinition eller -deklaration"
 
-#: c/c-parser.c:17395 cp/parser.c:37273
+#: c/c-parser.c:17395 cp/parser.c:37270
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr "%<#pragma omp declare simd%> som inte omedelbart följs av en ensam funktionsdeklaration eller -definition"
 
-#: c/c-parser.c:17474 cp/parser.c:37343
+#: c/c-parser.c:17474 cp/parser.c:37340
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> with clauses in between %<#pragma omp declare target%> without clauses and %<#pragma omp end declare target%>"
 msgstr "%<#pragma omp declare target%> med klausuler mellan %<#pragma omp declare target%> utan klausuler och %<#pragma omp end declare target%>"
 
-#: c/c-parser.c:17493 cp/parser.c:37362
+#: c/c-parser.c:17493 cp/parser.c:37359
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr "%qD angivet både i deklarationsmålets %<link%>- och %<to%>-klausuler"
 
-#: c/c-parser.c:17534 cp/parser.c:37409
+#: c/c-parser.c:17534 cp/parser.c:37406
 #, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "%<target%> förväntades"
 
-#: c/c-parser.c:17541 cp/parser.c:37416
+#: c/c-parser.c:17541 cp/parser.c:37413
 #, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "%<declare%> förväntades"
 
-#: c/c-parser.c:17547 cp/parser.c:37423
+#: c/c-parser.c:17547 cp/parser.c:37420
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr "%<#pragma omp end declare target%> utan en motsvarande %<#pragma omp declare target%>"
@@ -36238,47 +36280,47 @@
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr "en av initierarens anropsargument skall vara %<&omp_priv%>"
 
-#: c/c-parser.c:17947 cp/parser.c:37868
+#: c/c-parser.c:17947 cp/parser.c:37865
 #, gcc-internal-format
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr "%<simd%> eller %<reduction%> eller %<target%> förväntades"
 
-#: c/c-parser.c:18162 cp/semantics.c:7531
+#: c/c-parser.c:18162 cp/semantics.c:7534
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE är deklarerad %<threadprivate%> efter första användningen"
 
-#: c/c-parser.c:18164 cp/semantics.c:7533
+#: c/c-parser.c:18164 cp/semantics.c:7536
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "automatisk variabel %qE kan inte vara %<threadprivate%>"
 
-#: c/c-parser.c:18168 cp/semantics.c:7535
+#: c/c-parser.c:18168 cp/semantics.c:7538
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%<threadprivate%> %qE har ofullständig typ"
 
-#: c/c-parser.c:18368 cp/parser.c:38565
+#: c/c-parser.c:18368 cp/parser.c:38562
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr "%<__transaction_cancel%> utan att stöd för transaktionsminne är aktiverat"
 
-#: c/c-parser.c:18374 cp/parser.c:38571
+#: c/c-parser.c:18374 cp/parser.c:38568
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr "%<__transaction_cancel%> inom en %<__transaction_relaxed%>"
 
-#: c/c-parser.c:18383 cp/parser.c:38580
+#: c/c-parser.c:18383 cp/parser.c:38577
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr "yttre %<__transaction_cancel%> som inte är inom en yttre %<__transaction_atomic%>"
 
-#: c/c-parser.c:18385 cp/parser.c:38583
+#: c/c-parser.c:18385 cp/parser.c:38580
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr "  eller en %<transaction_may_cancel_outer%>-funktion"
 
-#: c/c-parser.c:18391 cp/parser.c:38589
+#: c/c-parser.c:18391 cp/parser.c:38586
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr "%<__transaction_cancel%> inte inom %<__transaction_atomic%>"
@@ -36293,7 +36335,7 @@
 msgid "%qD has an incomplete type %qT"
 msgstr "%qD har en ofullständig typ %qT"
 
-#: c/c-typeck.c:237 c/c-typeck.c:9994 c/c-typeck.c:10036 cp/call.c:4147
+#: c/c-typeck.c:237 c/c-typeck.c:9999 c/c-typeck.c:10041 cp/call.c:4147
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "ogiltig användning av void-uttryck"
@@ -36369,12 +36411,12 @@
 msgid "converting an array compound literal to a pointer is ill-formed in C++"
 msgstr "konvertering av en sammansatt vektorlitteral till en pekare är felaktigt i C++"
 
-#: c/c-typeck.c:2417 c/c-typeck.c:8641
+#: c/c-typeck.c:2417 c/c-typeck.c:8646
 #, gcc-internal-format
 msgid "%qT has no member named %qE; did you mean %qE?"
 msgstr "%qT har ingen medlem med namnet %qE; menade du %qE?"
 
-#: c/c-typeck.c:2421 c/c-typeck.c:8645
+#: c/c-typeck.c:2421 c/c-typeck.c:8650
 #, gcc-internal-format
 msgid "%qT has no member named %qE"
 msgstr "%qT har ingen medlem med namnet %qE"
@@ -36572,457 +36614,457 @@
 msgid "pointer to a function used in subtraction"
 msgstr "pekare till funktion använd i subtraktion"
 
-#: c/c-typeck.c:3847
+#: c/c-typeck.c:3852
 #, gcc-internal-format
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "aritmetik på pekare till ofullständig typ"
 
-#: c/c-typeck.c:3852 cp/typeck.c:5562
+#: c/c-typeck.c:3857 cp/typeck.c:5562
 #, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr "aritmetik på pekare till ett tomt aggregat"
 
-#: c/c-typeck.c:4283
+#: c/c-typeck.c:4288
 #, gcc-internal-format
 msgid "%<~%> on a boolean expression"
 msgstr "%<~%> på ett booleskt uttryck"
 
-#: c/c-typeck.c:4287
+#: c/c-typeck.c:4292
 #, gcc-internal-format
 msgid "did you mean to use logical not?"
 msgstr "tänkte du använda logiskt icke?"
 
-#: c/c-typeck.c:4296
+#: c/c-typeck.c:4301
 #, gcc-internal-format
 msgid "ISO C does not support %<~%> for complex conjugation"
 msgstr "ISO C stödjer inte %<~%> för komplex konjugering"
 
-#: c/c-typeck.c:4335
+#: c/c-typeck.c:4340
 #, gcc-internal-format
 msgid "wrong type argument to unary exclamation mark"
 msgstr "fel typ på argument till unärt utropstecken"
 
-#: c/c-typeck.c:4393
+#: c/c-typeck.c:4398
 #, gcc-internal-format
 msgid "increment of enumeration value is invalid in C++"
 msgstr "ökning av uppräkningsvärde är ogiltigt i C++"
 
-#: c/c-typeck.c:4396
+#: c/c-typeck.c:4401
 #, gcc-internal-format
 msgid "decrement of enumeration value is invalid in C++"
 msgstr "minskning av uppräkningsvärde är ogiltigt i C++"
 
-#: c/c-typeck.c:4403
+#: c/c-typeck.c:4408
 #, gcc-internal-format
 msgid "increment of a boolean expression"
 msgstr "ökning av ett booleskt uttryck"
 
-#: c/c-typeck.c:4406
+#: c/c-typeck.c:4411
 #, gcc-internal-format
 msgid "decrement of a boolean expression"
 msgstr "minskning av ett booleskt uttryck"
 
-#: c/c-typeck.c:4422
+#: c/c-typeck.c:4427
 #, gcc-internal-format
 msgid "ISO C does not support %<++%> and %<--%> on complex types"
 msgstr "ISO C stödjer inte %<++%> och %<--%> på komplexa typer"
 
-#: c/c-typeck.c:4447 c/c-typeck.c:4481
+#: c/c-typeck.c:4452 c/c-typeck.c:4486
 #, gcc-internal-format
 msgid "wrong type argument to increment"
 msgstr "fel typ på argument till ökning"
 
-#: c/c-typeck.c:4449 c/c-typeck.c:4484
+#: c/c-typeck.c:4454 c/c-typeck.c:4489
 #, gcc-internal-format
 msgid "wrong type argument to decrement"
 msgstr "fel typ på argument till minskning"
 
-#: c/c-typeck.c:4469
+#: c/c-typeck.c:4474
 #, gcc-internal-format
 msgid "increment of pointer to an incomplete type %qT"
 msgstr "ökning en pekare till en ofullständig typ %qT"
 
-#: c/c-typeck.c:4473
+#: c/c-typeck.c:4478
 #, gcc-internal-format
 msgid "decrement of pointer to an incomplete type %qT"
 msgstr "minskning av en pekare till en ofullständig typ %qT"
 
-#: c/c-typeck.c:4577
+#: c/c-typeck.c:4582
 #, gcc-internal-format
 msgid "taking address of expression of type %<void%>"
 msgstr "tar adressen till uttryck av typ %<void%>"
 
-#: c/c-typeck.c:4636
+#: c/c-typeck.c:4641
 #, gcc-internal-format
 msgid "cannot take address of bit-field %qD"
 msgstr "kan inte ta adressen till bitfält %qD"
 
-#: c/c-typeck.c:4649
+#: c/c-typeck.c:4654
 #, gcc-internal-format
 msgid "cannot take address of scalar with reverse storage order"
 msgstr "kan inte ta adressen till skalär med omvänd lagringsordning"
 
-#: c/c-typeck.c:4657
+#: c/c-typeck.c:4662
 #, gcc-internal-format
 msgid "address of array with reverse scalar storage order requested"
 msgstr "adress till vektor med omvänd skalär lagringsordning begärd"
 
-#: c/c-typeck.c:4838
+#: c/c-typeck.c:4843
 #, gcc-internal-format
 msgid "global register variable %qD used in nested function"
 msgstr "global registervariabel %qD använd i nästad funktion"
 
-#: c/c-typeck.c:4841
+#: c/c-typeck.c:4846
 #, gcc-internal-format
 msgid "register variable %qD used in nested function"
 msgstr "registervariabel %qD använd i nästad funktion"
 
-#: c/c-typeck.c:4846
+#: c/c-typeck.c:4851
 #, gcc-internal-format
 msgid "address of global register variable %qD requested"
 msgstr "adress till global registervariabel %qD efterfrågad"
 
-#: c/c-typeck.c:4848
+#: c/c-typeck.c:4853
 #, gcc-internal-format
 msgid "address of register variable %qD requested"
 msgstr "adress på registervariabeln %qD efterfrågad"
 
-#: c/c-typeck.c:4951
+#: c/c-typeck.c:4956
 #, gcc-internal-format
 msgid "non-lvalue array in conditional expression"
 msgstr "icke-l-värde-vektor i villkorsuttryck"
 
-#: c/c-typeck.c:5033
+#: c/c-typeck.c:5038
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other result of conditional"
 msgstr "implicit konvertering från %qT till %qT för att stämma med andra resultat i villkor"
 
-#: c/c-typeck.c:5092 c/c-typeck.c:5098
+#: c/c-typeck.c:5097 c/c-typeck.c:5103
 #, gcc-internal-format
 msgid "operand of ?: changes signedness from %qT to %qT due to unsignedness of other operand"
 msgstr "operand till ?: ändrar teckenläge från %qT till %qT på grund av teckenlöshet hos en annan operand"
 
-#: c/c-typeck.c:5115
+#: c/c-typeck.c:5120
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr with only one void side"
 msgstr "ISO C förbjuder villkorliga uttryck med bara en sida void"
 
-#: c/c-typeck.c:5132
+#: c/c-typeck.c:5137
 #, gcc-internal-format
 msgid "pointers to disjoint address spaces used in conditional expression"
 msgstr "pekare till skilda adressrymder använda i villkorsuttryck"
 
-#: c/c-typeck.c:5143 c/c-typeck.c:5160
+#: c/c-typeck.c:5148 c/c-typeck.c:5165
 #, gcc-internal-format
 msgid "pointer to array loses qualifier in conditional expression"
 msgstr "pekare till vektor tappar kvalificerare i villkorsuttryck"
 
-#: c/c-typeck.c:5148 c/c-typeck.c:5165
+#: c/c-typeck.c:5153 c/c-typeck.c:5170
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr between %<void *%> and function pointer"
 msgstr "ISO C förbjuder villkorliga uttryck mellan %<void *%> och funktionspekare"
 
-#: c/c-typeck.c:5178
+#: c/c-typeck.c:5183
 #, gcc-internal-format
 msgid "pointer type mismatch in conditional expression"
 msgstr "pekartyper stämmer inte i villkorsuttryck"
 
-#: c/c-typeck.c:5187 c/c-typeck.c:5198
+#: c/c-typeck.c:5192 c/c-typeck.c:5203
 #, gcc-internal-format
 msgid "pointer/integer type mismatch in conditional expression"
 msgstr "pekar-/heltalstyper stämmer inte  i villkorsuttryck"
 
-#: c/c-typeck.c:5336
+#: c/c-typeck.c:5341
 #, gcc-internal-format
 msgid "left-hand operand of comma expression has no effect"
 msgstr "vänster operand av kommauttryck har ingen effekt"
 
-#: c/c-typeck.c:5354 c/c-typeck.c:10636
+#: c/c-typeck.c:5359 c/c-typeck.c:10641
 #, gcc-internal-format
 msgid "right-hand operand of comma expression has no effect"
 msgstr "höger operand av kommauttryck har ingen effekt"
 
-#: c/c-typeck.c:5423
+#: c/c-typeck.c:5428
 msgid "cast adds %q#v qualifier to function type"
 msgstr "typkonvertering lägger %q#v-kvalificerare till funktionstyp"
 
-#: c/c-typeck.c:5429
+#: c/c-typeck.c:5434
 msgid "cast discards %qv qualifier from pointer target type"
 msgstr "typkonvertering kastar bort %qv-kvalificerare från pekarmåltyp"
 
-#: c/c-typeck.c:5464
+#: c/c-typeck.c:5469
 #, gcc-internal-format
 msgid "to be safe all intermediate pointers in cast from %qT to %qT must be %<const%> qualified"
 msgstr "för att vara säker måste alla mellanliggande pekare i typkonvertering från %qT till %qT vara %<const%>-kvalificerade"
 
-#: c/c-typeck.c:5554
+#: c/c-typeck.c:5559
 #, gcc-internal-format
 msgid "cast specifies array type"
 msgstr "typkonvertering anger vektortyp"
 
-#: c/c-typeck.c:5560
+#: c/c-typeck.c:5565
 #, gcc-internal-format
 msgid "cast specifies function type"
 msgstr "typkonvertering anger funktionstyp"
 
-#: c/c-typeck.c:5575
+#: c/c-typeck.c:5580
 #, gcc-internal-format
 msgid "ISO C forbids casting nonscalar to the same type"
 msgstr "ISO C förbjuder typkonvertering av ickeskalärer till samma typ"
 
-#: c/c-typeck.c:5595
+#: c/c-typeck.c:5600
 #, gcc-internal-format
 msgid "ISO C forbids casts to union type"
 msgstr "ISO C förbjuder typkonvertering till unionstyper"
 
-#: c/c-typeck.c:5605
+#: c/c-typeck.c:5610
 #, gcc-internal-format
 msgid "cast to union type from type not present in union"
 msgstr "typkonvertering till unionstyp från typ som ej finns i unionen"
 
-#: c/c-typeck.c:5640
+#: c/c-typeck.c:5645
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint generic address space pointer"
 msgstr "typkonvertering till adressrymdspekare %s från skild generisk adressrymdspekare"
 
-#: c/c-typeck.c:5645
+#: c/c-typeck.c:5650
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to generic address space pointer from disjoint %s address space pointer"
 msgstr "typkonvertering till generisk adressrymdspekare från skild adressrymdspekare till %s"
 
-#: c/c-typeck.c:5650
+#: c/c-typeck.c:5655
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint %s address space pointer"
 msgstr "typkonvertering från adressrymdspekare till %s från skild adressrymdspekare till %s"
 
-#: c/c-typeck.c:5670
+#: c/c-typeck.c:5675
 #, gcc-internal-format
 msgid "cast increases required alignment of target type"
 msgstr "typkonvertering ökar kravet på justering av måltypen"
 
-#: c/c-typeck.c:5681
+#: c/c-typeck.c:5686
 #, gcc-internal-format
 msgid "cast from pointer to integer of different size"
 msgstr "typkonvertering från pekare till heltal av annan storlek"
 
-#: c/c-typeck.c:5686
+#: c/c-typeck.c:5691
 #, gcc-internal-format
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "typkonvertering från funktionsanrop av typ %qT till typ %qT matchar inte"
 
-#: c/c-typeck.c:5695 cp/typeck.c:7811
+#: c/c-typeck.c:5700 cp/typeck.c:7811
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "typkonvertering till pekare från heltal med annan storlek"
 
-#: c/c-typeck.c:5709
+#: c/c-typeck.c:5714
 #, gcc-internal-format
 msgid "ISO C forbids conversion of function pointer to object pointer type"
 msgstr "ISO C förbjuder konvertering av funktionspekare till objektpekartyp"
 
-#: c/c-typeck.c:5718
+#: c/c-typeck.c:5723
 #, gcc-internal-format
 msgid "ISO C forbids conversion of object pointer to function pointer type"
 msgstr "ISO C förbjuder konvertering av objektpekare till funktionspekartyp"
 
-#: c/c-typeck.c:5728
+#: c/c-typeck.c:5733
 #, gcc-internal-format
 msgid "cast between incompatible function types from %qT to %qT"
 msgstr "typkonvertering mellan inkompatibla funktionstyper från %qT till %qT"
 
-#: c/c-typeck.c:5815
+#: c/c-typeck.c:5820
 #, gcc-internal-format
 msgid "defining a type in a cast is invalid in C++"
 msgstr "definition av en typ i en typkonvertering är ogiltigt i C++"
 
-#: c/c-typeck.c:5856
+#: c/c-typeck.c:5861
 #, gcc-internal-format
 msgid "assignment to expression with array type"
 msgstr "tilldelning till uttryck med vektortyp"
 
-#: c/c-typeck.c:5982
+#: c/c-typeck.c:5987
 #, gcc-internal-format
 msgid "enum conversion in assignment is invalid in C++"
 msgstr "uppräkningskonvertering i tilldelning är ogiltigt i C++"
 
-#: c/c-typeck.c:6180 c/c-typeck.c:6202 c/c-typeck.c:6226
+#: c/c-typeck.c:6185 c/c-typeck.c:6207 c/c-typeck.c:6231
 #, gcc-internal-format
 msgid "(near initialization for %qs)"
 msgstr "(i närheten av initiering av %qs)"
 
-#: c/c-typeck.c:6241
+#: c/c-typeck.c:6246
 #, gcc-internal-format
 msgid "array initialized from parenthesized string constant"
 msgstr "vektor initierad från strängkonstant inom parentes"
 
-#: c/c-typeck.c:6284 c/c-typeck.c:6476 c/c-typeck.c:6908
+#: c/c-typeck.c:6289 c/c-typeck.c:6481 c/c-typeck.c:6913
 #, gcc-internal-format
 msgid "expected %qT but argument is of type %qT"
 msgstr "%qT förväntades men argumentet har typ %qT"
 
-#: c/c-typeck.c:6471
+#: c/c-typeck.c:6476
 #, gcc-internal-format
 msgid "enum conversion when passing argument %d of %qE is invalid in C++"
 msgstr "enum-konvertering när argument %d till %qE skickades är ogiltigt i C++"
 
-#: c/c-typeck.c:6480
+#: c/c-typeck.c:6485
 #, gcc-internal-format
 msgid "enum conversion from %qT to %qT in assignment is invalid in C++"
 msgstr "enum-konvertering från %qT till %qT i tilldelning är ogiltigt i C++"
 
-#: c/c-typeck.c:6484
+#: c/c-typeck.c:6489
 #, gcc-internal-format
 msgid "enum conversion from %qT to %qT in initialization is invalid in C++"
 msgstr "enum-konvertering från %qT till %qT i initiering är ogiltigt i C++"
 
-#: c/c-typeck.c:6489
+#: c/c-typeck.c:6494
 #, gcc-internal-format
 msgid "enum conversion from %qT to %qT in return is invalid in C++"
 msgstr "enum-konvertering från %qT till %qT i retursats är ogiltigt i C++"
 
-#: c/c-typeck.c:6523
+#: c/c-typeck.c:6528
 #, gcc-internal-format
 msgid "cannot pass rvalue to reference parameter"
 msgstr "kan inte skicka rvalue till referensparameter"
 
-#: c/c-typeck.c:6656 c/c-typeck.c:6942
+#: c/c-typeck.c:6661 c/c-typeck.c:6947
 msgid "passing argument %d of %qE makes %q#v qualified function pointer from unqualified"
 msgstr "att skicka argument %d till %qE skapar en %q#v-kvalificerad funktionspekare från en okvalificerad"
 
-#: c/c-typeck.c:6659 c/c-typeck.c:6945
+#: c/c-typeck.c:6664 c/c-typeck.c:6950
 msgid "assignment makes %q#v qualified function pointer from unqualified"
 msgstr "tilldelning skapar en %q#v-kvalificerad funktionspekare från en okvalificerad"
 
-#: c/c-typeck.c:6662 c/c-typeck.c:6947
+#: c/c-typeck.c:6667 c/c-typeck.c:6952
 msgid "initialization makes %q#v qualified function pointer from unqualified"
 msgstr "initiering skapar en %q#v-kvalificerad funktionspekare från en okvalificerad"
 
-#: c/c-typeck.c:6665 c/c-typeck.c:6949
+#: c/c-typeck.c:6670 c/c-typeck.c:6954
 msgid "return makes %q#v qualified function pointer from unqualified"
 msgstr "retur skapar en %q#v-kvalificerad funktionspekare från en okvalificerad"
 
-#: c/c-typeck.c:6673 c/c-typeck.c:6840 c/c-typeck.c:6883
+#: c/c-typeck.c:6678 c/c-typeck.c:6845 c/c-typeck.c:6888
 msgid "passing argument %d of %qE discards %qv qualifier from pointer target type"
 msgstr "att skicka argument %d till %qE kastar %qv-kvalificerare från pekarmåltyp"
 
-#: c/c-typeck.c:6675 c/c-typeck.c:6842 c/c-typeck.c:6885
+#: c/c-typeck.c:6680 c/c-typeck.c:6847 c/c-typeck.c:6890
 msgid "assignment discards %qv qualifier from pointer target type"
 msgstr "tilldelning kastar %qv-kvalificerare från pekarmåltyp"
 
-#: c/c-typeck.c:6677 c/c-typeck.c:6844 c/c-typeck.c:6887
+#: c/c-typeck.c:6682 c/c-typeck.c:6849 c/c-typeck.c:6892
 msgid "initialization discards %qv qualifier from pointer target type"
 msgstr "initiering kastar %qv-kvalificerare från pekarmåltyp"
 
-#: c/c-typeck.c:6679 c/c-typeck.c:6846 c/c-typeck.c:6889
+#: c/c-typeck.c:6684 c/c-typeck.c:6851 c/c-typeck.c:6894
 msgid "return discards %qv qualifier from pointer target type"
 msgstr "retur kastar %qv-kvalificerare från pekarmåltyp"
 
-#: c/c-typeck.c:6688
+#: c/c-typeck.c:6693
 #, gcc-internal-format
 msgid "ISO C prohibits argument conversion to union type"
 msgstr "ISO C förbjuder argumentkonvertering till unionstyp"
 
-#: c/c-typeck.c:6750
+#: c/c-typeck.c:6755
 #, gcc-internal-format
 msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgstr "begäran om implicit konvertering från %qT till %qT tillåts inte i C++"
 
-#: c/c-typeck.c:6762
+#: c/c-typeck.c:6767
 #, gcc-internal-format
 msgid "passing argument %d of %qE from pointer to non-enclosed address space"
 msgstr "skickar argument %d till %qE från pekare till adressutrymme som inte är inneslutet"
 
-#: c/c-typeck.c:6766
+#: c/c-typeck.c:6771
 #, gcc-internal-format
 msgid "assignment from pointer to non-enclosed address space"
 msgstr "tilldelning från pekare till adressutrymme som inte är inneslutet"
 
-#: c/c-typeck.c:6770
+#: c/c-typeck.c:6775
 #, gcc-internal-format
 msgid "initialization from pointer to non-enclosed address space"
 msgstr "initiering från pekare till adressutrymme som inte är inneslutet"
 
-#: c/c-typeck.c:6774
+#: c/c-typeck.c:6779
 #, gcc-internal-format
 msgid "return from pointer to non-enclosed address space"
 msgstr "retur från pekare till ej omgivande adressrymd"
 
-#: c/c-typeck.c:6792
+#: c/c-typeck.c:6797
 #, gcc-internal-format
 msgid "argument %d of %qE might be a candidate for a format attribute"
 msgstr "argumentet %d till %qE kan vara kandidat för ett formatattribut"
 
-#: c/c-typeck.c:6798
+#: c/c-typeck.c:6803
 #, gcc-internal-format
 msgid "assignment left-hand side might be a candidate for a format attribute"
 msgstr "vänsterhandssida av tilldelning kan vara en kandidat för ett formatattribut"
 
-#: c/c-typeck.c:6803
+#: c/c-typeck.c:6808
 #, gcc-internal-format
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "vänsterhandssida av initiering kan vara en kandidat för ett formatattribut"
 
-#: c/c-typeck.c:6808 cp/typeck.c:8891
+#: c/c-typeck.c:6813 cp/typeck.c:8891
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "returtypen kan vara en kandidat för ett formatattribut"
 
-#: c/c-typeck.c:6857
+#: c/c-typeck.c:6862
 #, gcc-internal-format
 msgid "ISO C forbids passing argument %d of %qE between function pointer and %<void *%>"
 msgstr "ISO C förbjuder att skicka argument %d till %qE mellan funktionspekare och %<void *%>"
 
-#: c/c-typeck.c:6860
+#: c/c-typeck.c:6865
 #, gcc-internal-format
 msgid "ISO C forbids assignment between function pointer and %<void *%>"
 msgstr "ISO C förbjuder tilldelning mellan funktionspekare och %<void *%>"
 
-#: c/c-typeck.c:6862
+#: c/c-typeck.c:6867
 #, gcc-internal-format
 msgid "ISO C forbids initialization between function pointer and %<void *%>"
 msgstr "ISO C förbjuder initiering mellan funktionspekare och %<void *%>"
 
-#: c/c-typeck.c:6864
+#: c/c-typeck.c:6869
 #, gcc-internal-format
 msgid "ISO C forbids return between function pointer and %<void *%>"
 msgstr "ISO C förbjuder retur mellan funktionspekare och %<void *%>"
 
-#: c/c-typeck.c:6904
+#: c/c-typeck.c:6909
 #, gcc-internal-format
 msgid "pointer targets in passing argument %d of %qE differ in signedness"
 msgstr "pekarmål när argument %d till %qE skickades skiljer i teckenhet"
 
-#: c/c-typeck.c:6913
+#: c/c-typeck.c:6918
 #, gcc-internal-format
 msgid "pointer targets in assignment from %qT to %qT differ in signedness"
 msgstr "pekarmål i tilldelning från %qT till %qT skiljer i teckenhet"
 
-#: c/c-typeck.c:6918
+#: c/c-typeck.c:6923
 #, gcc-internal-format
 msgid "pointer targets in initialization of %qT from %qT differ in signedness"
 msgstr "pekarmål i initiering från %qT till %qT skiljer i teckenhet"
 
-#: c/c-typeck.c:6923
+#: c/c-typeck.c:6928
 #, gcc-internal-format
 msgid "pointer targets in returning %qT from a function with return type %qT differ in signedness"
 msgstr "pekarmål vid retur av %qT från en funktion med returtyp %qT skiljer i teckenhet"
 
-#: c/c-typeck.c:6961
+#: c/c-typeck.c:6966
 #, gcc-internal-format
 msgid "passing argument %d of %qE from incompatible pointer type"
 msgstr "skickar argument %d till %qE från inkompatibel pekartyp"
 
-#: c/c-typeck.c:6967
+#: c/c-typeck.c:6972
 #, gcc-internal-format
 msgid "assignment to %qT from incompatible pointer type %qT"
 msgstr "tilldelning till %qT från inkompatibel pekartyp %qT"
 
-#: c/c-typeck.c:6972
+#: c/c-typeck.c:6977
 #, gcc-internal-format
 msgid "initialization of %qT from incompatible pointer type %qT"
 msgstr "initiering av %qT från inkompatibel pekartyp %qT"
 
-#: c/c-typeck.c:6977
+#: c/c-typeck.c:6982
 #, gcc-internal-format
 msgid "returning %qT from a function with incompatible return type %qT"
 msgstr "returnerar %qT från en funktion med inkompatibel returtyp %qT"
@@ -37029,782 +37071,782 @@
 
 #. ??? This should not be an error when inlining calls to
 #. unprototyped functions.
-#: c/c-typeck.c:6991 c/c-typeck.c:7514 cp/typeck.c:2063
+#: c/c-typeck.c:6996 c/c-typeck.c:7519 cp/typeck.c:2063
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "ogiltig användning av icke-l-värde-vektor"
 
-#: c/c-typeck.c:7004
+#: c/c-typeck.c:7009
 #, gcc-internal-format
 msgid "passing argument %d of %qE makes pointer from integer without a cast"
 msgstr "att skicka argument %d till %qE skapar pekare av ett heltal utan typkonvertering"
 
-#: c/c-typeck.c:7010
+#: c/c-typeck.c:7015
 #, gcc-internal-format
 msgid "assignment to %qT from %qT makes pointer from integer without a cast"
 msgstr "tilldelning till %qT från %qT skapar pekare av heltal utan typkonvertering"
 
-#: c/c-typeck.c:7015
+#: c/c-typeck.c:7020
 #, gcc-internal-format
 msgid "initialization of %qT from %qT makes pointer from integer without a cast"
 msgstr "initiering av %qT från %qT skapar pekare från heltal utan typkonvertering"
 
-#: c/c-typeck.c:7019
+#: c/c-typeck.c:7024
 #, gcc-internal-format
 msgid "returning %qT from a function with return type %qT makes pointer from integer without a cast"
 msgstr "att returnera %qT från en funktion med returtyp %qT skapar pekare av ett heltal utan typkonvertering"
 
-#: c/c-typeck.c:7035
+#: c/c-typeck.c:7040
 #, gcc-internal-format
 msgid "passing argument %d of %qE makes integer from pointer without a cast"
 msgstr "att skicka argument %d till %qE skapar pekare från heltal utan typkonvertering"
 
-#: c/c-typeck.c:7041
+#: c/c-typeck.c:7046
 #, gcc-internal-format
 msgid "assignment to %qT from %qT makes integer from pointer without a cast"
 msgstr "tilldelning till %qT från %qT skapar heltal från pekare utan typkonvertering"
 
-#: c/c-typeck.c:7046
+#: c/c-typeck.c:7051
 #, gcc-internal-format
 msgid "initialization of %qT from %qT makes integer from pointer without a cast"
 msgstr "initiering av %qT från %qT skapar heltal från pekare utan typkonvertering"
 
-#: c/c-typeck.c:7050
+#: c/c-typeck.c:7055
 #, gcc-internal-format
 msgid "returning %qT from a function with return type %qT makes integer from pointer without a cast"
 msgstr "att returnera %qT från en funktion med returtyp %qT skapar pekare från heltal utan typkonvertering"
 
-#: c/c-typeck.c:7073
+#: c/c-typeck.c:7078
 #, gcc-internal-format
 msgid "incompatible type for argument %d of %qE"
 msgstr "inkompatibel typ för argument %d av %qE"
 
-#: c/c-typeck.c:7078
+#: c/c-typeck.c:7083
 #, gcc-internal-format
 msgid "incompatible types when assigning to type %qT from type %qT"
 msgstr "inkompatibla typer i tilldelning till typ %qT från typ %qT"
 
-#: c/c-typeck.c:7083
+#: c/c-typeck.c:7088
 #, gcc-internal-format
 msgid "incompatible types when initializing type %qT using type %qT"
 msgstr "inkompatibla typer i när typ %qT initierades med typ %qT"
 
-#: c/c-typeck.c:7088
+#: c/c-typeck.c:7093
 #, gcc-internal-format
 msgid "incompatible types when returning type %qT but %qT was expected"
 msgstr "inkompatibla typer när typ %qT returnerades men %qT förväntades"
 
-#: c/c-typeck.c:7152
+#: c/c-typeck.c:7157
 #, gcc-internal-format
 msgid "traditional C rejects automatic aggregate initialization"
 msgstr "traditionell C tillåter inte aggregatinitiering"
 
-#: c/c-typeck.c:7388 c/c-typeck.c:8284 cp/typeck2.c:1045
+#: c/c-typeck.c:7393 c/c-typeck.c:8289 cp/typeck2.c:1045
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "initiering av medlem som är en flexibel vektor"
 
-#: c/c-typeck.c:7398 cp/typeck2.c:1059
+#: c/c-typeck.c:7403 cp/typeck2.c:1059
 #, gcc-internal-format
 msgid "char-array initialized from wide string"
 msgstr "char-vektor initierad från bred sträng"
 
-#: c/c-typeck.c:7407
+#: c/c-typeck.c:7412
 #, gcc-internal-format
 msgid "wide character array initialized from non-wide string"
 msgstr "bred teckenvektor initierad från icke-bred sträng"
 
-#: c/c-typeck.c:7413
+#: c/c-typeck.c:7418
 #, gcc-internal-format
 msgid "wide character array initialized from incompatible wide string"
 msgstr "bred teckenvektor initierad från en inkompatibel bred sträng"
 
-#: c/c-typeck.c:7446
+#: c/c-typeck.c:7451
 #, gcc-internal-format
 msgid "array of inappropriate type initialized from string constant"
 msgstr "vektor av typ som inte passar initierad från strängkonstant"
 
-#: c/c-typeck.c:7533 c/c-typeck.c:7557 c/c-typeck.c:7560 c/c-typeck.c:7568
-#: c/c-typeck.c:7608 c/c-typeck.c:9131 c/c-typeck.c:9181
+#: c/c-typeck.c:7538 c/c-typeck.c:7562 c/c-typeck.c:7565 c/c-typeck.c:7573
+#: c/c-typeck.c:7613 c/c-typeck.c:9136 c/c-typeck.c:9186
 #, gcc-internal-format
 msgid "initializer element is not constant"
 msgstr "initierarelement är inte konstant"
 
-#: c/c-typeck.c:7542
+#: c/c-typeck.c:7547
 #, gcc-internal-format
 msgid "array initialized from non-constant array expression"
 msgstr "vektor initierad från icke-konstant vektoruttryck"
 
-#: c/c-typeck.c:7573 c/c-typeck.c:7621 c/c-typeck.c:9191
+#: c/c-typeck.c:7578 c/c-typeck.c:7626 c/c-typeck.c:9196
 #, gcc-internal-format
 msgid "initializer element is not a constant expression"
 msgstr "initierarelement är inte ett konstant uttryck"
 
-#: c/c-typeck.c:7615 c/c-typeck.c:9186
+#: c/c-typeck.c:7620 c/c-typeck.c:9191
 #, gcc-internal-format
 msgid "initializer element is not computable at load time"
 msgstr "initierarelement är inte beräkningsbart vid laddtidpunkt"
 
-#: c/c-typeck.c:7634
+#: c/c-typeck.c:7639
 #, gcc-internal-format
 msgid "invalid initializer"
 msgstr "ogiltig initierare"
 
-#: c/c-typeck.c:7912 cp/decl.c:6396
+#: c/c-typeck.c:7917 cp/decl.c:6396
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "ogenomskinliga vektortyper kan inte initieras"
 
-#: c/c-typeck.c:8132
+#: c/c-typeck.c:8137
 #, gcc-internal-format
 msgid "extra brace group at end of initializer"
 msgstr "extra klammergrupp vid slutet av initierare"
 
-#: c/c-typeck.c:8215
+#: c/c-typeck.c:8220
 #, gcc-internal-format
 msgid "braces around scalar initializer"
 msgstr "klamrar runt skalär initierare"
 
-#: c/c-typeck.c:8281 c/c-typeck.c:9615 cp/typeck2.c:1084 cp/typeck2.c:1297
+#: c/c-typeck.c:8286 c/c-typeck.c:9620 cp/typeck2.c:1084 cp/typeck2.c:1297
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "initiering av medlem som är en flexibel vektor i nästat sammanhang"
 
-#: c/c-typeck.c:8318
+#: c/c-typeck.c:8323
 #, gcc-internal-format
 msgid "missing braces around initializer"
 msgstr "klamrar saknas runt initierare"
 
-#: c/c-typeck.c:8341
+#: c/c-typeck.c:8346
 #, gcc-internal-format
 msgid "missing initializer for field %qD of %qT"
 msgstr "initierare saknas för fält %qD i %qT"
 
-#: c/c-typeck.c:8365
+#: c/c-typeck.c:8370
 #, gcc-internal-format
 msgid "empty scalar initializer"
 msgstr "tom skalär initierare"
 
-#: c/c-typeck.c:8370
+#: c/c-typeck.c:8375
 #, gcc-internal-format
 msgid "extra elements in scalar initializer"
 msgstr "extra element i skalär initierare"
 
-#: c/c-typeck.c:8483 c/c-typeck.c:8565
+#: c/c-typeck.c:8488 c/c-typeck.c:8570
 #, gcc-internal-format
 msgid "array index in non-array initializer"
 msgstr "vektorindex i initierare för annat än vektor"
 
-#: c/c-typeck.c:8488 c/c-typeck.c:8627
+#: c/c-typeck.c:8493 c/c-typeck.c:8632
 #, gcc-internal-format
 msgid "field name not in record or union initializer"
 msgstr "fältnamn i initierare för annat än post eller union"
 
-#: c/c-typeck.c:8538
+#: c/c-typeck.c:8543
 #, gcc-internal-format
 msgid "array index in initializer not of integer type"
 msgstr "vektorindex i initierare inte av heltalstyp"
 
-#: c/c-typeck.c:8547 c/c-typeck.c:8556
+#: c/c-typeck.c:8552 c/c-typeck.c:8561
 #, gcc-internal-format
 msgid "array index in initializer is not an integer constant expression"
 msgstr "vektorindex i initierare inte av ett konstant heltalsuttryck"
 
-#: c/c-typeck.c:8561 c/c-typeck.c:8563
+#: c/c-typeck.c:8566 c/c-typeck.c:8568
 #, gcc-internal-format
 msgid "nonconstant array index in initializer"
 msgstr "ickekonstant vektorindex i initierare"
 
-#: c/c-typeck.c:8567 c/c-typeck.c:8570
+#: c/c-typeck.c:8572 c/c-typeck.c:8575
 #, gcc-internal-format
 msgid "array index in initializer exceeds array bounds"
 msgstr "vektorindex i initierare överskrider vektorns storlek"
 
-#: c/c-typeck.c:8589
+#: c/c-typeck.c:8594
 #, gcc-internal-format
 msgid "empty index range in initializer"
 msgstr "tomt indexintervall i initierare"
 
-#: c/c-typeck.c:8598
+#: c/c-typeck.c:8603
 #, gcc-internal-format
 msgid "array index range in initializer exceeds array bounds"
 msgstr "vektorindexintervall i initierare överskrider vektorns gränser"
 
-#: c/c-typeck.c:8700 c/c-typeck.c:8730 c/c-typeck.c:9274
+#: c/c-typeck.c:8705 c/c-typeck.c:8735 c/c-typeck.c:9279
 #, gcc-internal-format
 msgid "initialized field with side-effects overwritten"
 msgstr "initierat fält med sidoeffekter överskrivet"
 
-#: c/c-typeck.c:8704 c/c-typeck.c:8734 c/c-typeck.c:9277
+#: c/c-typeck.c:8709 c/c-typeck.c:8739 c/c-typeck.c:9282
 #, gcc-internal-format
 msgid "initialized field overwritten"
 msgstr "initierat fält överskrivet"
 
-#: c/c-typeck.c:9208
+#: c/c-typeck.c:9213
 #, gcc-internal-format
 msgid "enum conversion in initialization is invalid in C++"
 msgstr "enum-konvertering i initiering är ogiltigt i C++"
 
-#: c/c-typeck.c:9496
+#: c/c-typeck.c:9501
 #, gcc-internal-format
 msgid "excess elements in char array initializer"
 msgstr "överflödiga element i teckenvektorinitierare"
 
-#: c/c-typeck.c:9503 c/c-typeck.c:9574
+#: c/c-typeck.c:9508 c/c-typeck.c:9579
 #, gcc-internal-format
 msgid "excess elements in struct initializer"
 msgstr "överflödiga element i postinitierare"
 
-#: c/c-typeck.c:9518
+#: c/c-typeck.c:9523
 #, gcc-internal-format
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr "positionsinitiering av fält i %<struct%> deklarerad med attributet %<designated_init%>"
 
-#: c/c-typeck.c:9589
+#: c/c-typeck.c:9594
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr "icke-statisk initiering av an flexibel vektormedlem"
 
-#: c/c-typeck.c:9687
+#: c/c-typeck.c:9692
 #, gcc-internal-format
 msgid "excess elements in union initializer"
 msgstr "överflödiga element i unioninitierare"
 
-#: c/c-typeck.c:9709
+#: c/c-typeck.c:9714
 #, gcc-internal-format
 msgid "traditional C rejects initialization of unions"
 msgstr "traditionell C tillåter inte initiering av unioner"
 
-#: c/c-typeck.c:9777
+#: c/c-typeck.c:9782
 #, gcc-internal-format
 msgid "excess elements in array initializer"
 msgstr "överflödiga element i vektorinitierare"
 
-#: c/c-typeck.c:9811
+#: c/c-typeck.c:9816
 #, gcc-internal-format
 msgid "excess elements in vector initializer"
 msgstr "överflödiga element i vector-initierare"
 
-#: c/c-typeck.c:9843
+#: c/c-typeck.c:9848
 #, gcc-internal-format
 msgid "excess elements in scalar initializer"
 msgstr "överflödiga element i skalärinitierare"
 
-#: c/c-typeck.c:10086
+#: c/c-typeck.c:10091
 #, gcc-internal-format
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C förbjuder %<goto *expr;%>"
 
-#: c/c-typeck.c:10113 c/gimple-parser.c:1604 cp/typeck.c:9113
+#: c/c-typeck.c:10118 c/gimple-parser.c:1604 cp/typeck.c:9113
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "funktion deklarerad %<noreturn%> har en %<return%>-sats"
 
-#: c/c-typeck.c:10139 c/c-typeck.c:10143
+#: c/c-typeck.c:10144 c/c-typeck.c:10148
 #, gcc-internal-format
 msgid "%<return%> with no value, in function returning non-void"
 msgstr "%<return%> utan värde i funktion som returnerar icke-void"
 
-#: c/c-typeck.c:10157 c/gimple-parser.c:1614
+#: c/c-typeck.c:10162 c/gimple-parser.c:1614
 #, gcc-internal-format
 msgid "%<return%> with a value, in function returning void"
 msgstr "%<return%> med värde i funktion som returnerar void"
 
-#: c/c-typeck.c:10160
+#: c/c-typeck.c:10165
 #, gcc-internal-format
 msgid "ISO C forbids %<return%> with expression, in function returning void"
 msgstr "ISO C förbjuder %<return%> med värde i funktion som returnerar void"
 
-#: c/c-typeck.c:10236
+#: c/c-typeck.c:10241
 #, gcc-internal-format
 msgid "function returns address of label"
 msgstr "funktionen returnerar adress till en etikett"
 
-#: c/c-typeck.c:10327 cp/semantics.c:1171
+#: c/c-typeck.c:10332 cp/semantics.c:1171
 #, gcc-internal-format
 msgid "switch quantity not an integer"
 msgstr "switch-argument är inte ett heltal"
 
-#: c/c-typeck.c:10352
+#: c/c-typeck.c:10357
 #, gcc-internal-format
 msgid "%<long%> switch expression not converted to %<int%> in ISO C"
 msgstr "%<long%>-switch-uttryck konverteras inte till %<int%> i ISO C"
 
-#: c/c-typeck.c:10390 c/c-typeck.c:10398
+#: c/c-typeck.c:10395 c/c-typeck.c:10403
 #, gcc-internal-format
 msgid "case label is not an integer constant expression"
 msgstr "case-etikett är inte ett konstant heltalsuttryck"
 
-#: c/c-typeck.c:10404 cp/parser.c:11067
+#: c/c-typeck.c:10409 cp/parser.c:11067
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "case-etikett är inte i en switch-sats"
 
-#: c/c-typeck.c:10406
+#: c/c-typeck.c:10411
 #, gcc-internal-format
 msgid "%<default%> label not within a switch statement"
 msgstr "%<default%>-etikett som inte ligger i en switch-sats"
 
-#: c/c-typeck.c:10578 cp/parser.c:12356
+#: c/c-typeck.c:10583 cp/parser.c:12353
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "break-sats som inte är i en loop eller switch"
 
-#: c/c-typeck.c:10580 cp/parser.c:12379
+#: c/c-typeck.c:10585 cp/parser.c:12376
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "continue-sats som inte är i en loop"
 
-#: c/c-typeck.c:10585 cp/parser.c:12369
+#: c/c-typeck.c:10590 cp/parser.c:12366
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr "break-sats använd med OpenMP-for-slinga"
 
-#: c/c-typeck.c:10590
+#: c/c-typeck.c:10595
 #, gcc-internal-format
 msgid "break statement within %<#pragma simd%> loop body"
 msgstr "break-sats i en %<#pragma simd%>-slingas kropp"
 
-#: c/c-typeck.c:10592
+#: c/c-typeck.c:10597
 #, gcc-internal-format
 msgid "continue statement within %<#pragma simd%> loop body"
 msgstr "continue-sats i en %<#pragma simd%>-slingas kropp"
 
-#: c/c-typeck.c:10618 cp/cp-gimplify.c:432
+#: c/c-typeck.c:10623 cp/cp-gimplify.c:432
 #, gcc-internal-format
 msgid "statement with no effect"
 msgstr "sats utan effekt"
 
-#: c/c-typeck.c:10662
+#: c/c-typeck.c:10667
 #, gcc-internal-format
 msgid "expression statement has incomplete type"
 msgstr "uttryckssats har ofullständig typ"
 
-#: c/c-typeck.c:11476 c/c-typeck.c:11644 cp/typeck.c:5017
+#: c/c-typeck.c:11481 c/c-typeck.c:11649 cp/typeck.c:5017
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr "jämför vektorer med skilda elementtyper"
 
-#: c/c-typeck.c:11484 c/c-typeck.c:11652 cp/typeck.c:5030
+#: c/c-typeck.c:11489 c/c-typeck.c:11657 cp/typeck.c:5030
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr "jämför vektorer med olika antal element"
 
-#: c/c-typeck.c:11509 c/c-typeck.c:11677 cp/typeck.c:5058
+#: c/c-typeck.c:11514 c/c-typeck.c:11682 cp/typeck.c:5058
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr "det går inte att hitta en heltalstyp med samma storlek som %qT"
 
-#: c/c-typeck.c:11523 cp/typeck.c:4743
+#: c/c-typeck.c:11528 cp/typeck.c:4743
 #, gcc-internal-format
 msgid "comparing floating point with == or != is unsafe"
 msgstr "jämföra flyttal med == eller != är osäkert"
 
-#: c/c-typeck.c:11541 c/c-typeck.c:11562
+#: c/c-typeck.c:11546 c/c-typeck.c:11567
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<false%> for the address of %qD will never be NULL"
 msgstr "jämförelsen kommer alltid beräknas till %<false%> för adressen till %qD kommer aldrig att vara NULL"
 
-#: c/c-typeck.c:11547 c/c-typeck.c:11568
+#: c/c-typeck.c:11552 c/c-typeck.c:11573
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<true%> for the address of %qD will never be NULL"
 msgstr "jämförelsen kommer alltid beräknas till %<true%> för adressen till %qD kommer aldrig att vara NULL"
 
-#: c/c-typeck.c:11589 c/c-typeck.c:11718
+#: c/c-typeck.c:11594 c/c-typeck.c:11723
 #, gcc-internal-format
 msgid "comparison of pointers to disjoint address spaces"
 msgstr "jämförelse av pekare till skilda adressutrymmen"
 
-#: c/c-typeck.c:11596 c/c-typeck.c:11602
+#: c/c-typeck.c:11601 c/c-typeck.c:11607
 #, gcc-internal-format
 msgid "ISO C forbids comparison of %<void *%> with function pointer"
 msgstr "ISO C förbjuder jämförelse mellan %<void *%> och funktionspekare"
 
-#: c/c-typeck.c:11609 c/c-typeck.c:11728
+#: c/c-typeck.c:11614 c/c-typeck.c:11733
 #, gcc-internal-format
 msgid "comparison of distinct pointer types lacks a cast"
 msgstr "jämförelse av skilda pekartyper saknar en typkonvertering"
 
-#: c/c-typeck.c:11621 c/c-typeck.c:11626 c/c-typeck.c:11754 c/c-typeck.c:11759
+#: c/c-typeck.c:11626 c/c-typeck.c:11631 c/c-typeck.c:11759 c/c-typeck.c:11764
 #, gcc-internal-format
 msgid "comparison between pointer and integer"
 msgstr "jämförelse mellan pekare och heltal"
 
-#: c/c-typeck.c:11706
+#: c/c-typeck.c:11711
 #, gcc-internal-format
 msgid "comparison of complete and incomplete pointers"
 msgstr "jämförelse av kompletta och ofullständiga pekare"
 
-#: c/c-typeck.c:11708
+#: c/c-typeck.c:11713
 #, gcc-internal-format
 msgid "ISO C forbids ordered comparisons of pointers to functions"
 msgstr "ISO C förbjuder ordningsjämförelse på pekare till funktioner"
 
-#: c/c-typeck.c:11713
+#: c/c-typeck.c:11718
 #, gcc-internal-format
 msgid "ordered comparison of pointer with null pointer"
 msgstr "ordningsjämförelse av pekare med nollpekare"
 
-#: c/c-typeck.c:11736 c/c-typeck.c:11739 c/c-typeck.c:11746 c/c-typeck.c:11749
+#: c/c-typeck.c:11741 c/c-typeck.c:11744 c/c-typeck.c:11751 c/c-typeck.c:11754
 #: cp/typeck.c:5081 cp/typeck.c:5088
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "ordningsjämförelse av pekare med heltalet noll"
 
-#: c/c-typeck.c:11811
+#: c/c-typeck.c:11816
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
 msgstr "implicit konvertering från %qT till %qT för att matcha den andra operanden i binärt uttryck"
 
-#: c/c-typeck.c:12126
+#: c/c-typeck.c:12131
 #, gcc-internal-format
 msgid "used array that cannot be converted to pointer where scalar is required"
 msgstr "vektor använd som inte kan konverteras till en pekare där en skalär krävs"
 
-#: c/c-typeck.c:12130
+#: c/c-typeck.c:12135
 #, gcc-internal-format
 msgid "used struct type value where scalar is required"
 msgstr "struct-typvärde använt där skalär krävs"
 
-#: c/c-typeck.c:12134
+#: c/c-typeck.c:12139
 #, gcc-internal-format
 msgid "used union type value where scalar is required"
 msgstr "värde av uniontyp använt där skalär krävs"
 
-#: c/c-typeck.c:12150
+#: c/c-typeck.c:12155
 #, gcc-internal-format
 msgid "used vector type where scalar is required"
 msgstr "vektortyp använd där skalär krävs"
 
-#: c/c-typeck.c:12340 cp/semantics.c:8508
+#: c/c-typeck.c:12345 cp/semantics.c:8511
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp cancel%> måste ange en av klausulerna %<parallel%>, %<for%>, %<sections%> eller %<taskgroup%>"
 
-#: c/c-typeck.c:12379 cp/semantics.c:8545
+#: c/c-typeck.c:12384 cp/semantics.c:8548
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp cancellation point%> måste ange en av klausulerna %<parallel%>, %<for%>, %<sections%> eller %<taskgroup%>"
 
-#: c/c-typeck.c:12423 c/c-typeck.c:13581 c/c-typeck.c:13642 c/c-typeck.c:13704
+#: c/c-typeck.c:12428 c/c-typeck.c:13586 c/c-typeck.c:13647 c/c-typeck.c:13709
 #, gcc-internal-format
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "%<_Atomic%> %qE i %qs-klausul"
 
-#: c/c-typeck.c:12436 c/c-typeck.c:13628 cp/semantics.c:4546
-#: cp/semantics.c:6717
+#: c/c-typeck.c:12441 c/c-typeck.c:13633 cp/semantics.c:4549
+#: cp/semantics.c:6720
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr "bitfältet %qE i %qs-klausul"
 
-#: c/c-typeck.c:12445 c/c-typeck.c:13652 cp/semantics.c:4556
-#: cp/semantics.c:6735
+#: c/c-typeck.c:12450 c/c-typeck.c:13657 cp/semantics.c:4559
+#: cp/semantics.c:6738
 #, gcc-internal-format
 msgid "%qE is a member of a union"
 msgstr "%qE är en medlem i en union"
 
-#: c/c-typeck.c:12455 cp/semantics.c:4570 cp/semantics.c:6760
+#: c/c-typeck.c:12460 cp/semantics.c:4573 cp/semantics.c:6763
 #, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD är inte en variabel i en %qs-klausul"
 
-#: c/c-typeck.c:12459 c/c-typeck.c:13669 cp/semantics.c:4574
-#: cp/semantics.c:6763
+#: c/c-typeck.c:12464 c/c-typeck.c:13674 cp/semantics.c:4577
+#: cp/semantics.c:6766
 #, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qE är inte en variabel i en %qs-klausul"
 
-#: c/c-typeck.c:12466
+#: c/c-typeck.c:12471
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %qs clause"
 msgstr "%<_Atomic%> %qD i %qs-klausul"
 
-#: c/c-typeck.c:12475 c/c-typeck.c:13676 c/c-typeck.c:13778
-#: cp/semantics.c:4591 cp/semantics.c:6769 cp/semantics.c:6931
+#: c/c-typeck.c:12480 c/c-typeck.c:13681 c/c-typeck.c:13783
+#: cp/semantics.c:4594 cp/semantics.c:6772 cp/semantics.c:6934
 #, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD är en trådprivat variabel i en %qs-klausul"
 
-#: c/c-typeck.c:12511 cp/semantics.c:4623
+#: c/c-typeck.c:12516 cp/semantics.c:4626
 #, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr "undre gränsen %qE i vektorsektion har inte heltalstyp"
 
-#: c/c-typeck.c:12518 cp/semantics.c:4630
+#: c/c-typeck.c:12523 cp/semantics.c:4633
 #, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr "längden %qE i vektorsektion har inte heltalstyp"
 
-#: c/c-typeck.c:12545 c/c-typeck.c:12609 c/c-typeck.c:12867
-#: cp/semantics.c:4666 cp/semantics.c:4730
+#: c/c-typeck.c:12550 c/c-typeck.c:12614 c/c-typeck.c:12872
+#: cp/semantics.c:4669 cp/semantics.c:4733
 #, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr "nollängds vektorsektion i en %qs-klausul"
 
-#: c/c-typeck.c:12564 cp/semantics.c:4685
+#: c/c-typeck.c:12569 cp/semantics.c:4688
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr "för en vektor med okänd gräns måste ett längduttryck anges"
 
-#: c/c-typeck.c:12572 cp/semantics.c:4693
+#: c/c-typeck.c:12577 cp/semantics.c:4696
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr "negativ nedre gräns i vektorsektion i %qs-klausul"
 
-#: c/c-typeck.c:12581 c/c-typeck.c:12691 cp/semantics.c:4702
-#: cp/semantics.c:4812
+#: c/c-typeck.c:12586 c/c-typeck.c:12696 cp/semantics.c:4705
+#: cp/semantics.c:4815
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr "negativ längd i vektorsektion i en %qs-klausul"
 
-#: c/c-typeck.c:12598 cp/semantics.c:4719
+#: c/c-typeck.c:12603 cp/semantics.c:4722
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr "nedre gränsen %qE över storleken på vektorsektionen i en %qs-klausul"
 
-#: c/c-typeck.c:12635 cp/semantics.c:4756
+#: c/c-typeck.c:12640 cp/semantics.c:4759
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr "längden %qE över storleken på vektorsektionen i en %qs-klausul"
 
-#: c/c-typeck.c:12650 cp/semantics.c:4771
+#: c/c-typeck.c:12655 cp/semantics.c:4774
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr "övre gräns %qE ovanför storleken på vektorsektionen i en %qs-klausul"
 
-#: c/c-typeck.c:12683 cp/semantics.c:4804
+#: c/c-typeck.c:12688 cp/semantics.c:4807
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr "för pekartyper måste ett längduttryck anges"
 
-#: c/c-typeck.c:12701 c/c-typeck.c:12810 cp/semantics.c:4822
-#: cp/semantics.c:4934
+#: c/c-typeck.c:12706 c/c-typeck.c:12815 cp/semantics.c:4825
+#: cp/semantics.c:4937
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr "vektorsektionen är inte sammanhängande i %qs-klausulen"
 
-#: c/c-typeck.c:12709 cp/semantics.c:4830
+#: c/c-typeck.c:12714 cp/semantics.c:4833
 #, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr "%qE har inte pekar- eller vektortyp"
 
-#: c/c-typeck.c:13103 c/c-typeck.c:13113
+#: c/c-typeck.c:13108 c/c-typeck.c:13118
 #, gcc-internal-format
 msgid "%qD in %<reduction%> clause is a zero size array"
 msgstr "%qD i %<reduction%>-klausul är en vektor med storlek noll"
 
-#: c/c-typeck.c:13130
+#: c/c-typeck.c:13135
 #, gcc-internal-format
 msgid "%<_Atomic%> %qE in %<reduction%> clause"
 msgstr "%<_Atomic%> %qE i %<reduction%>-klausul"
 
-#: c/c-typeck.c:13178
+#: c/c-typeck.c:13183
 #, gcc-internal-format
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "%qE har ogiltig typ för %<reduction(%s)%>"
 
-#: c/c-typeck.c:13187 cp/semantics.c:5755
+#: c/c-typeck.c:13192 cp/semantics.c:5758
 #, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr "ingen användardefinierad reduktion funnen för %qE"
 
-#: c/c-typeck.c:13275
+#: c/c-typeck.c:13280
 #, gcc-internal-format
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "elementtyp med variabel längd i vektor-%<reduction%>-klausul"
 
-#: c/c-typeck.c:13293 c/c-typeck.c:13836 cp/semantics.c:7249
+#: c/c-typeck.c:13298 c/c-typeck.c:13841 cp/semantics.c:7252
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr "en %<nowait%>-klausul får inte användas tillsammans med %<copyprivate%>"
 
-#: c/c-typeck.c:13305 cp/semantics.c:7289
+#: c/c-typeck.c:13310 cp/semantics.c:7292
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE måste vara %<threadprivate%> för %<copyin%>"
 
-#: c/c-typeck.c:13319 cp/semantics.c:5929
+#: c/c-typeck.c:13324 cp/semantics.c:5932
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr "modifierare skall inte anges i %<linear%>-klausul på %<simd%>- eller %<for%>-konstruktioner"
 
-#: c/c-typeck.c:13327
+#: c/c-typeck.c:13332
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with type %qT"
 msgstr "en linjär klausul använd på variabel som inte är heltal och inte pekare med typen %qT"
 
-#: c/c-typeck.c:13335
+#: c/c-typeck.c:13340
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr "%<_Atomic%> %qD i %<linear%>-klausul"
 
-#: c/c-typeck.c:13354 cp/semantics.c:5999
+#: c/c-typeck.c:13359 cp/semantics.c:6002
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr "%<linear%>-klausulens steg %qE är varken en konstant eller en parameter"
 
-#: c/c-typeck.c:13384 c/c-typeck.c:13771 cp/semantics.c:6083
-#: cp/semantics.c:6924
+#: c/c-typeck.c:13389 c/c-typeck.c:13776 cp/semantics.c:6086
+#: cp/semantics.c:6927
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE är inte en variabel i klausul %qs"
 
-#: c/c-typeck.c:13393 cp/semantics.c:6092
+#: c/c-typeck.c:13398 cp/semantics.c:6095
 #, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr "%qD förekommer mer än en gång i reduktionsklausuler"
 
-#: c/c-typeck.c:13404 c/c-typeck.c:13434 c/c-typeck.c:13463
+#: c/c-typeck.c:13409 c/c-typeck.c:13439 c/c-typeck.c:13468
 #, gcc-internal-format
 msgid "%qE appears more than once in data clauses"
 msgstr "%qE förekommer mer än en gång i dataklausuler"
 
-#: c/c-typeck.c:13411 c/c-typeck.c:13440 c/c-typeck.c:13600 c/c-typeck.c:13714
-#: c/c-typeck.c:13720 c/c-typeck.c:13733 c/c-typeck.c:13742
-#: cp/semantics.c:6102 cp/semantics.c:6109 cp/semantics.c:6160
-#: cp/semantics.c:6166 cp/semantics.c:6203 cp/semantics.c:6680
-#: cp/semantics.c:6817 cp/semantics.c:6823 cp/semantics.c:6836
-#: cp/semantics.c:6845
+#: c/c-typeck.c:13416 c/c-typeck.c:13445 c/c-typeck.c:13605 c/c-typeck.c:13719
+#: c/c-typeck.c:13725 c/c-typeck.c:13738 c/c-typeck.c:13747
+#: cp/semantics.c:6105 cp/semantics.c:6112 cp/semantics.c:6163
+#: cp/semantics.c:6169 cp/semantics.c:6206 cp/semantics.c:6683
+#: cp/semantics.c:6820 cp/semantics.c:6826 cp/semantics.c:6839
+#: cp/semantics.c:6848
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr "%qD förekommer mer än en gång i dataklausuler"
 
-#: c/c-typeck.c:13413 c/c-typeck.c:13442 c/c-typeck.c:13722 c/c-typeck.c:13744
-#: cp/semantics.c:6111 cp/semantics.c:6168 cp/semantics.c:6825
-#: cp/semantics.c:6847
+#: c/c-typeck.c:13418 c/c-typeck.c:13447 c/c-typeck.c:13727 c/c-typeck.c:13749
+#: cp/semantics.c:6114 cp/semantics.c:6171 cp/semantics.c:6828
+#: cp/semantics.c:6850
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr "%qD förekommer både i data- och map-klausuler"
 
-#: c/c-typeck.c:13427 cp/semantics.c:6154
+#: c/c-typeck.c:13432 cp/semantics.c:6157
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "%qE är inte en variabel i klausul %<firstprivate%>"
 
-#: c/c-typeck.c:13456 cp/semantics.c:6197
+#: c/c-typeck.c:13461 cp/semantics.c:6200
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "%qE är inte en variabel i klausul %<lastprivate%>"
 
-#: c/c-typeck.c:13475 cp/semantics.c:6545
+#: c/c-typeck.c:13480 cp/semantics.c:6548
 #, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "%qE är inte en variabel i %<aligned%>-klausul"
 
-#: c/c-typeck.c:13482
+#: c/c-typeck.c:13487
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array"
 msgstr "%qE i %<aligned%>-klausul är varken en pekare eller en vektor"
 
-#: c/c-typeck.c:13489
+#: c/c-typeck.c:13494
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<aligned%> clause"
 msgstr "%<_Atomic%> %qD i %<aligned%>-klausul"
 
-#: c/c-typeck.c:13496
+#: c/c-typeck.c:13501
 #, gcc-internal-format
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr "%qE förekommer mer än en gång i %<aligned%>-klausuler"
 
-#: c/c-typeck.c:13551 cp/semantics.c:6627
+#: c/c-typeck.c:13556 cp/semantics.c:6630
 #, gcc-internal-format
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr "%qE är inte en variabel i en %<depend%>-klausul"
 
-#: c/c-typeck.c:13573 cp/semantics.c:6658
+#: c/c-typeck.c:13578 cp/semantics.c:6661
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr "vektorsektionen har inte en avbildbar typ i %qs-klausulen"
 
-#: c/c-typeck.c:13597 c/c-typeck.c:13731 cp/semantics.c:6677
-#: cp/semantics.c:6834
+#: c/c-typeck.c:13602 c/c-typeck.c:13736 cp/semantics.c:6680
+#: cp/semantics.c:6837
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD förekommer mer än en gång i rörelseklausuler"
 
-#: c/c-typeck.c:13603 c/c-typeck.c:13735 cp/semantics.c:6683
-#: cp/semantics.c:6838
+#: c/c-typeck.c:13608 c/c-typeck.c:13740 cp/semantics.c:6686
+#: cp/semantics.c:6841
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD förekommer mer än en gång i avbildningsklausuler"
 
-#: c/c-typeck.c:13635 cp/semantics.c:6724
+#: c/c-typeck.c:13640 cp/semantics.c:6727
 #, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qE har inte en avbildbar typ i %qs-klausul"
 
-#: c/c-typeck.c:13695 c/c-typeck.c:13785 cp/semantics.c:6799
-#: cp/semantics.c:6938
+#: c/c-typeck.c:13700 c/c-typeck.c:13790 cp/semantics.c:6802
+#: cp/semantics.c:6941
 #, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD har inte en avbildbar typ i %qs-klausul"
 
-#: c/c-typeck.c:13766 cp/semantics.c:6918
+#: c/c-typeck.c:13771 cp/semantics.c:6921
 #, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE är varken en variabel eller ett funktionsnamn i klausulen %qs"
 
-#: c/c-typeck.c:13794 cp/semantics.c:6947
+#: c/c-typeck.c:13799 cp/semantics.c:6950
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qE förekommer mer än en gång i samma %<declare target%>-direktiv"
 
-#: c/c-typeck.c:13808 cp/semantics.c:6962
+#: c/c-typeck.c:13813 cp/semantics.c:6965
 #, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD är inte en ett argument i en %<uniform%>-klausul"
 
-#: c/c-typeck.c:13811 cp/semantics.c:6964
+#: c/c-typeck.c:13816 cp/semantics.c:6967
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qE är inte ett argument i en %<uniform%>-klausul"
 
-#: c/c-typeck.c:13826
+#: c/c-typeck.c:13831
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "%qs-variabeln är varken en pekare eller en vektor"
 
-#: c/c-typeck.c:13900 cp/semantics.c:6359
+#: c/c-typeck.c:13905 cp/semantics.c:6362
 #, gcc-internal-format
 msgid "%<nonmonotonic%> modifier specified for %qs schedule kind"
 msgstr "%<nonmonotonic%>-modifierare angiven för schemaläggningssort %qs"
 
-#: c/c-typeck.c:13931 cp/semantics.c:7141
+#: c/c-typeck.c:13936 cp/semantics.c:7144
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr "en %<inbranch%>-klausul är inkompatibel med %<notinbranch%>"
 
-#: c/c-typeck.c:13981 cp/semantics.c:7332
+#: c/c-typeck.c:13986 cp/semantics.c:7335
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE är förutbestämd som %qs för %qs"
 
-#: c/c-typeck.c:14001 cp/semantics.c:7223
+#: c/c-typeck.c:14006 cp/semantics.c:7226
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr "%<simdlen%>-klausulvärde är större än %<safelen%>-klausulvärde"
 
-#: c/c-typeck.c:14013 cp/semantics.c:7236
+#: c/c-typeck.c:14018 cp/semantics.c:7239
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr "%<nonmonotonic%>-schemaläggningsmodifierare angiven tillsammans med %<ordered%>-klausul"
 
-#: c/c-typeck.c:14031 cp/semantics.c:7203
+#: c/c-typeck.c:14036 cp/semantics.c:7206
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr "%<linear%>-klausulsteg är en parameter %qD inte angiven i %<uniform%>-klausul"
 
-#: c/c-typeck.c:14204
+#: c/c-typeck.c:14209
 #, gcc-internal-format
 msgid "cannot use %<va_arg%> with reverse storage order"
 msgstr "kan inte använda %<va_arg%> med omvänd lagringsordning"
 
-#: c/c-typeck.c:14209
+#: c/c-typeck.c:14214
 #, gcc-internal-format
 msgid "second argument to %<va_arg%> is of incomplete type %qT"
 msgstr "andra argumentet till %<va_arg%> är av ofullständig typ %qT"
 
-#: c/c-typeck.c:14215
+#: c/c-typeck.c:14220
 #, gcc-internal-format
 msgid "C++ requires promoted type, not enum type, in %<va_arg%>"
 msgstr "C++ kräver en befordrad typ, inte en uppräkningstyp, i %<va_arg%>"
@@ -37918,7 +37960,7 @@
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "  ingen känd konvertering för argument %d från %qH till %qI"
 
-#: cp/call.c:3441 cp/pt.c:6495
+#: cp/call.c:3441 cp/pt.c:6509
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -38208,7 +38250,7 @@
 msgid "%q#D is private within this context"
 msgstr "%q#D är privat inom denna kontext"
 
-#: cp/call.c:6478 cp/decl.c:7343
+#: cp/call.c:6478 cp/decl.c:7364
 #, gcc-internal-format
 msgid "declared private here"
 msgstr "deklarerad privat här"
@@ -38218,7 +38260,7 @@
 msgid "%q#D is protected within this context"
 msgstr "%q#D är skyddad inom denna kontext"
 
-#: cp/call.c:6486 cp/decl.c:7344
+#: cp/call.c:6486 cp/decl.c:7365
 #, gcc-internal-format
 msgid "declared protected here"
 msgstr "deklarerad skyddad här"
@@ -38519,7 +38561,7 @@
 msgid "call to non-function %qD"
 msgstr "anrop av icke-funktion %qD"
 
-#: cp/call.c:9119 cp/pt.c:15053 cp/typeck.c:2901
+#: cp/call.c:9119 cp/pt.c:15075 cp/typeck.c:2901
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "kan inte anropa konstrueraren %<%T::%D%> direkt"
@@ -38727,262 +38769,262 @@
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr "kan inte härleda från %<final%> bas %qT i härledd typ %qT"
 
-#: cp/class.c:2098
+#: cp/class.c:2103
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr "alla medlemsfunktioner i klass %qT är privata"
 
-#: cp/class.c:2110
+#: cp/class.c:2115
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr "%q#T definierar bara en privat destruerare och har inga vänner"
 
-#: cp/class.c:2152
+#: cp/class.c:2156
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr "%q#T definierar bara privata konstruerare och har inga vänner"
 
-#: cp/class.c:2156
+#: cp/class.c:2160
 #, gcc-internal-format
 msgid "%q#D is public, but requires an existing %q#T object"
 msgstr "%q#D är public, men behöver ett befintligt %q#T-objekt"
 
-#: cp/class.c:2430
+#: cp/class.c:2434
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr "ingen unik slutlig ersättare för %qD i %qT"
 
-#: cp/class.c:2785
+#: cp/class.c:2789
 #, gcc-internal-format
 msgid "%qD can be marked override"
 msgstr "%qD kan markeras override"
 
-#: cp/class.c:2797
+#: cp/class.c:2801
 #, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr "%q+#D är markerad %<final%>, men är inte virtuell"
 
-#: cp/class.c:2799
+#: cp/class.c:2803
 #, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr "%q+#D är markerad %<override%>, men den åsidosätter inte"
 
-#: cp/class.c:2861
+#: cp/class.c:2865
 #, gcc-internal-format
 msgid "%qD was hidden"
 msgstr "%qD var dold"
 
-#: cp/class.c:2863
+#: cp/class.c:2867
 #, gcc-internal-format
 msgid "  by %qD"
 msgstr "  av %qD"
 
-#: cp/class.c:2896
+#: cp/class.c:2900
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "%q#D ogiltig, en anonym union kan bara ha publika ickestatiska datamedlemmar"
 
-#: cp/class.c:2906 cp/name-lookup.c:3293 cp/parser.c:19720
+#: cp/class.c:2910 cp/name-lookup.c:3293 cp/parser.c:19717
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr "denna flexibilitet bör undvikas och kommer tas bort"
 
-#: cp/class.c:3097
+#: cp/class.c:3101
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr "ellipsen i %qD ärvs inte"
 
-#: cp/class.c:3213
+#: cp/class.c:3217
 #, gcc-internal-format
 msgid "bit-field %q+#D with non-integral type"
 msgstr "bitfält %q+#D har en icke-heltalstyp"
 
-#: cp/class.c:3229
+#: cp/class.c:3233
 #, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr "bredd för bitfältet %q+D inte en heltalskonstant"
 
-#: cp/class.c:3234
+#: cp/class.c:3238
 #, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr "negativ bredd i bitfält %q+D"
 
-#: cp/class.c:3239
+#: cp/class.c:3243
 #, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr "noll i bredd i bitfält %q+D"
 
-#: cp/class.c:3249
+#: cp/class.c:3253
 #, gcc-internal-format
 msgid "width of %qD exceeds its type"
 msgstr "bredden på %qD är större än dess typ"
 
-#: cp/class.c:3255
+#: cp/class.c:3259
 #, gcc-internal-format
 msgid "%qD is too small to hold all values of %q#T"
 msgstr "%qD är för liten för att få plats med alla värden hos %q#T"
 
-#: cp/class.c:3316
+#: cp/class.c:3320
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr "medlem %q+#D med konstruerare inte tillåten i union"
 
-#: cp/class.c:3319
+#: cp/class.c:3323
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr "medlem %q+#D med destruerare inte tillåten i union"
 
-#: cp/class.c:3321
+#: cp/class.c:3325
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr "medlem %q+#D med kopieringstilldelningsoperator inte tillåten i union"
 
-#: cp/class.c:3325
+#: cp/class.c:3329
 #, gcc-internal-format
 msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgstr "obegränsade unioner är endast tillgängliga med -std=c++11 eller -std=gnu++11"
 
-#: cp/class.c:3453
+#: cp/class.c:3457
 #, gcc-internal-format
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr "i C++98 får %q+D inte vara statisk eftersom den är medlem av en union"
 
-#: cp/class.c:3460
+#: cp/class.c:3464
 #, gcc-internal-format
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr "icke-statisk datamedlem %q+D i en union får inte ha referenstyp %qT"
 
-#: cp/class.c:3470
+#: cp/class.c:3474
 #, gcc-internal-format
 msgid "field %q+D invalidly declared function type"
 msgstr "fält %q+D ogiltigt deklarerad funktionstyp"
 
-#: cp/class.c:3476
+#: cp/class.c:3480
 #, gcc-internal-format
 msgid "field %q+D invalidly declared method type"
 msgstr "fält %q+D ogiltigt deklarerad metodtyp"
 
-#: cp/class.c:3536
+#: cp/class.c:3540
 #, gcc-internal-format
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr "ignorerar attributet packed på grund av opackat icke-POD-fält %q#D"
 
-#: cp/class.c:3585
+#: cp/class.c:3589
 #, gcc-internal-format
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr "medlemmen %q+D kan inte både deklareras %<const%> och %<mutable%>"
 
-#: cp/class.c:3591
+#: cp/class.c:3595
 #, gcc-internal-format
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr "medlem %q+D kan inte deklareras som en %<mutable%> referens"
 
-#: cp/class.c:3617
+#: cp/class.c:3621
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr "flera fält i unionen %qT initierade"
 
-#: cp/class.c:3658
+#: cp/class.c:3662
 #, gcc-internal-format
 msgid "field %q#D with same name as class"
 msgstr "fält %q#D med samma namn som en klass"
 
-#: cp/class.c:3681
+#: cp/class.c:3685
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr "%q#T har pekardatamedlemmar"
 
-#: cp/class.c:3686
+#: cp/class.c:3690
 #, gcc-internal-format
 msgid "  but does not override %<%T(const %T&)%>"
 msgstr "  men ersätter inte %<%T(const %T&)%>"
 
-#: cp/class.c:3688
+#: cp/class.c:3692
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr "  eller %<operator=(const %T&)%>"
 
-#: cp/class.c:3692
+#: cp/class.c:3696
 #, gcc-internal-format
 msgid "  but does not override %<operator=(const %T&)%>"
 msgstr "  men ersätter inte %<operator=(const %T&)%>"
 
-#: cp/class.c:4097
+#: cp/class.c:4101
 #, gcc-internal-format
 msgid "alignment of %qD increased in -fabi-version=9 (GCC 5.2)"
 msgstr "justeringen av %qD ökade i -fabi-version=9 (GCC 5.2)"
 
-#: cp/class.c:4100
+#: cp/class.c:4104
 #, gcc-internal-format
 msgid "alignment of %qD will increase in -fabi-version=9"
 msgstr "justering av %qD kommer öka med -fabi-version=9"
 
-#: cp/class.c:4378
+#: cp/class.c:4382
 #, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "initierare angiven för icke-virtuell metod %q+D"
 
-#: cp/class.c:4813
+#: cp/class.c:4817
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr "metoden åsidosätter både metoderna %<transaction_pure%> och %qE"
 
-#: cp/class.c:4834
+#: cp/class.c:4838
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr "metod deklarerad %qE åsidosätter %qE-metod"
 
-#: cp/class.c:5350 cp/constexpr.c:237
+#: cp/class.c:5367 cp/constexpr.c:237
 #, gcc-internal-format
 msgid "enclosing class of %<constexpr%> non-static member function %q+#D is not a literal type"
 msgstr "omslutande klass till %<constexpr%> icke-statisk medlemsfunktion %q+#D är inte en litteral typ"
 
-#: cp/class.c:5374
+#: cp/class.c:5391
 #, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr "%q+T är inte litteral för att:"
 
-#: cp/class.c:5377
+#: cp/class.c:5394
 #, gcc-internal-format
 msgid "  %qT is a closure type, which is only literal in C++17 and later"
 msgstr "  %qT är en höljestyp (closure), som är litteraler endast i C++17 och senare"
 
-#: cp/class.c:5380
+#: cp/class.c:5397
 #, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr "  %q+T har en icke-trivial destruerare"
 
-#: cp/class.c:5387
+#: cp/class.c:5404
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no %<constexpr%> constructor that is not a copy or move constructor"
 msgstr "  %q+T är inte ett aggregat, har inte en trivial standardkonstruerare och har ingen %<constexpr%>-konstruerare som inte är en kopierings- eller flyttningskonstruerare"
 
-#: cp/class.c:5420
+#: cp/class.c:5437
 #, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "  basklassen %qT till %q+T är inte litteral"
 
-#: cp/class.c:5435
+#: cp/class.c:5452
 #, gcc-internal-format
 msgid "  non-static data member %qD has non-literal type"
 msgstr "  den icke-statiska datamedlemmen %qD har icke-litteral typ"
 
-#: cp/class.c:5442
+#: cp/class.c:5459
 #, gcc-internal-format
 msgid "  non-static data member %qD has volatile type"
 msgstr "  den icke-statiska datamedlemmen %qD har volatile typ"
 
-#: cp/class.c:5561
+#: cp/class.c:5578
 #, gcc-internal-format
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "basklassen %q#T har en åtkomlig icke-virtuell destruerare"
 
-#: cp/class.c:5590
+#: cp/class.c:5607
 #, gcc-internal-format
 msgid "non-static reference %q#D in class without a constructor"
 msgstr "icke-statisk referens %q#D i klass utan en konstruerare"
 
-#: cp/class.c:5596
+#: cp/class.c:5613
 #, gcc-internal-format
 msgid "non-static const member %q#D in class without a constructor"
 msgstr "icke-statisk const-medlem %q#D i klass utan en konstruerare"
@@ -38989,152 +39031,152 @@
 
 #. If the function is defaulted outside the class, we just
 #. give the synthesis error.
-#: cp/class.c:5624
+#: cp/class.c:5641
 #, gcc-internal-format
 msgid "%q+D declared to take const reference, but implicit declaration would take non-const"
 msgstr "%q+D deklarerad att ta const-referens, men implicit deklaration skulle ta icke-const"
 
-#: cp/class.c:5898
+#: cp/class.c:5915
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr "direkt bas %qT är oåtkomlig i %qT på grund av tvetydighet"
 
-#: cp/class.c:5910
+#: cp/class.c:5927
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr "virtuell bas %qT är oåtkomlig i %qT på grund av tvetydighet"
 
-#: cp/class.c:6133
+#: cp/class.c:6150
 #, gcc-internal-format
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr "förskjutningen av %qD följer inte ABI:et och kan ändras i en framtida version av GCC"
 
-#: cp/class.c:6291
+#: cp/class.c:6308
 #, gcc-internal-format
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr "storleken på typen %qT är för stor (%qE byte)"
 
-#: cp/class.c:6576
+#: cp/class.c:6593
 #, gcc-internal-format
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr "ogiltig användning av %qT med en vektor av storlek noll i %q#D"
 
-#: cp/class.c:6578
+#: cp/class.c:6595
 #, gcc-internal-format
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr "ogiltig användning av %q#T med flexibel vektormedlem i %q#T"
 
-#: cp/class.c:6583
+#: cp/class.c:6600
 #, gcc-internal-format
 msgid "array member %q#D declared here"
 msgstr "vektormedlem %q#D är deklarerad här"
 
-#: cp/class.c:6610
+#: cp/class.c:6627
 #, gcc-internal-format
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr "vektormedlem %qD med storlek noll är inte vid slutet av %q#T"
 
-#: cp/class.c:6612
+#: cp/class.c:6629
 #, gcc-internal-format
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr "vektormedlem %qD med storlek noll i en i övrigt tom %q#T"
 
-#: cp/class.c:6620 cp/class.c:6650
+#: cp/class.c:6637 cp/class.c:6667
 #, gcc-internal-format
 msgid "in the definition of %q#T"
 msgstr "i definitionen av %q#T"
 
-#: cp/class.c:6628
+#: cp/class.c:6645
 #, gcc-internal-format
 msgid "flexible array member %qD not at end of %q#T"
 msgstr "flexibel vektormedlem %qD inte vid slutet av %q#T"
 
-#: cp/class.c:6630
+#: cp/class.c:6647
 #, gcc-internal-format
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr "flexibel vektor medlem %qD i en i övrigt tom %q#T"
 
-#: cp/class.c:6648
+#: cp/class.c:6665
 #, gcc-internal-format
 msgid "next member %q#D declared here"
 msgstr "nästa medlem %q#D är deklarerad här"
 
-#: cp/class.c:6760 cp/parser.c:23239
+#: cp/class.c:6777 cp/parser.c:23236
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "omdefinition av %q#T"
 
-#: cp/class.c:6897
+#: cp/class.c:6914
 #, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "%q#T har virtuella funktioner och åtkomlig ickevirtuell destruerare"
 
-#: cp/class.c:6925
+#: cp/class.c:6942
 #, gcc-internal-format
 msgid "type transparent %q#T does not have any fields"
 msgstr "typgenomskinliga %q#T har inga fält"
 
-#: cp/class.c:6931
+#: cp/class.c:6948
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr "den typgenomskinliga klassen %qT har basklasser"
 
-#: cp/class.c:6935
+#: cp/class.c:6952
 #, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr "den typgenomskinliga klassen %qT har virtuella funktioner"
 
-#: cp/class.c:6941
+#: cp/class.c:6958
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr "typtransparenta %q#T kan inte göras transparent eftersom typen på första fältet har ett annat ABI än klassen som helhet"
 
-#: cp/class.c:7071
+#: cp/class.c:7088
 #, gcc-internal-format
 msgid "definition of %qD does not match %<#include <initializer_list>%>"
 msgstr "definitionen av %qD matchar inte %<#include <initializer_list>%>"
 
-#: cp/class.c:7082
+#: cp/class.c:7099
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr "försökte avsluta post, men hoppade ut på grund av tidigare parsningsfel"
 
-#: cp/class.c:7582
+#: cp/class.c:7599
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "språksträng %<”%E”%> känns inte igen"
 
-#: cp/class.c:7672
+#: cp/class.c:7689
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr "det går inte att lösa upp överlagrad funktion %qD baserat på konvertering till typ %qT"
 
-#: cp/class.c:7817
+#: cp/class.c:7834
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr "ingen match som konverterar funktionen %qD till typen %q#T"
 
-#: cp/class.c:7844
+#: cp/class.c:7861
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "konvertering av överlagrad funktion %qD till typ %q#T är tvetydig"
 
-#: cp/class.c:7870
+#: cp/class.c:7887
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "antar pekare till medlem %qD"
 
-#: cp/class.c:7873
+#: cp/class.c:7890
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(en pekare på medlem kan bara skapas med %<&%E%>)"
 
-#: cp/class.c:7948 cp/class.c:7990
+#: cp/class.c:7965 cp/class.c:8007
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "inte tillräcklig typinformation"
 
-#: cp/class.c:7968
+#: cp/class.c:7985
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "kan inte konvertera %qE från typ %qT till typ %qT"
@@ -39144,12 +39186,12 @@
 #. A name N used in a class S shall refer to the same declaration
 #. in its context and when re-evaluated in the completed scope of
 #. S.
-#: cp/class.c:8235
+#: cp/class.c:8252
 #, gcc-internal-format
 msgid "declaration of %q#D"
 msgstr "deklaration av %q#D"
 
-#: cp/class.c:8237
+#: cp/class.c:8254
 #, gcc-internal-format
 msgid "changes meaning of %qD from %q#D"
 msgstr "byter betydelse av %qD från %q#D"
@@ -39541,17 +39583,17 @@
 msgid "unexpected AST of kind %s"
 msgstr "oväntat AST av sorten %s"
 
-#: cp/cp-gimplify.c:1415
+#: cp/cp-gimplify.c:1416
 #, gcc-internal-format
 msgid "throw will always call terminate()"
 msgstr "throw kommer alltid anropa terminate()"
 
-#: cp/cp-gimplify.c:1418
+#: cp/cp-gimplify.c:1419
 #, gcc-internal-format
 msgid "in C++11 destructors default to noexcept"
 msgstr "i C++11 är standard för destruerare noexcept"
 
-#: cp/cp-gimplify.c:1429
+#: cp/cp-gimplify.c:1430
 #, gcc-internal-format
 msgid "in C++11 this throw will terminate because destructors default to noexcept"
 msgstr "i C++11 kommer denna throw att avsluta eftersom standard för destruerare är noexcept"
@@ -39955,7 +39997,7 @@
 msgid "redeclaration %qD differs in %<constexpr%> from previous declaration"
 msgstr "omdeklaration av %qD skiljer i %<constexpr%> från tidigare deklaration"
 
-#: cp/decl.c:1304 cp/decl.c:13843
+#: cp/decl.c:1304 cp/decl.c:13867
 #, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr "tidigare deklaration %qD"
@@ -40279,7 +40321,7 @@
 msgid "  enters OpenMP structured block"
 msgstr "  går in i OpenMP-strukturerat block"
 
-#: cp/decl.c:3434 cp/parser.c:12366 cp/parser.c:12387
+#: cp/decl.c:3434 cp/parser.c:12363 cp/parser.c:12384
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr "ogiltig utgång från OpenMP-strukturerat block"
@@ -40289,7 +40331,7 @@
 msgid "%qD is not a type"
 msgstr "%qD är inte en typ"
 
-#: cp/decl.c:3838 cp/parser.c:6366
+#: cp/decl.c:3838 cp/parser.c:6369
 #, gcc-internal-format
 msgid "%qD used without template parameters"
 msgstr "%qD använd utan mallparametrar"
@@ -40665,8 +40707,8 @@
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr "C99-beteckningen %qE utanför aggregatinitierare"
 
-#: cp/decl.c:6011 cp/decl.c:6234 cp/typeck2.c:1310 cp/typeck2.c:1590
-#: cp/typeck2.c:1638 cp/typeck2.c:1685
+#: cp/decl.c:6011 cp/decl.c:6234 cp/typeck2.c:1310 cp/typeck2.c:1593
+#: cp/typeck2.c:1641 cp/typeck2.c:1688
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "för många initierare för %qT"
@@ -40741,12 +40783,12 @@
 msgid "assignment (not initialization) in declaration"
 msgstr "tilldelning (inte initiering) i deklaration"
 
-#: cp/decl.c:6873 cp/decl.c:12605
+#: cp/decl.c:6873 cp/decl.c:12629
 #, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C++17 tillåter inte specificeraren %<register%> av lagringsklass"
 
-#: cp/decl.c:6877 cp/decl.c:12609
+#: cp/decl.c:6877 cp/decl.c:12633
 #, gcc-internal-format
 msgid "%<register%> storage class specifier used"
 msgstr "specificeraren %<register%> av lagringsklass angiven"
@@ -40771,42 +40813,42 @@
 msgid "function %q#D is initialized like a variable"
 msgstr "funktionen %q#D är initierad som en variabel"
 
-#: cp/decl.c:7329
+#: cp/decl.c:7350
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "det går inte dekomponera klasstypen %qT för att den har en anonym struct-medlem"
 
-#: cp/decl.c:7332
+#: cp/decl.c:7353
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr "kan inte dekomponera klasstypen %qT för att den har en anonym unionsmedlem"
 
-#: cp/decl.c:7339
+#: cp/decl.c:7360
 #, gcc-internal-format
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "det går inte att dekomponera en oåtkomlig medlem %qD av %qT"
 
-#: cp/decl.c:7365
+#: cp/decl.c:7386
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr "kan inte dekomponera klasstypen %qT: både den och dess basklass %qT har ickestatiska datamedlemmar"
 
-#: cp/decl.c:7374
+#: cp/decl.c:7395
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr "kan inte dekomponera klasstypen %qT: dess basklasser %qT och %qT har ickestatiska datamedlemmar"
 
-#: cp/decl.c:7592
+#: cp/decl.c:7613
 #, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr "strukturerad bindning refererar till ofullständig typ %qT"
 
-#: cp/decl.c:7608
+#: cp/decl.c:7629
 #, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr "det går inte att dekomponera en vektor %qT med variabel längd"
 
-#: cp/decl.c:7617 cp/decl.c:7702
+#: cp/decl.c:7638 cp/decl.c:7723
 #, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
@@ -40813,7 +40855,7 @@
 msgstr[0] "%u namn angivet för strukturerad bindning"
 msgstr[1] "%u namn angivna för strukturerad bindning"
 
-#: cp/decl.c:7621
+#: cp/decl.c:7642
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
@@ -40820,7 +40862,7 @@
 msgstr[0] "endast %u namn angivet för strukturerad bindning"
 msgstr[1] "endast %u namn angivna för strukturerad bindning"
 
-#: cp/decl.c:7624
+#: cp/decl.c:7645
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
@@ -40827,878 +40869,878 @@
 msgstr[0] "medan %qT dekomponeras till %wu element"
 msgstr[1] "medan %qT dekomponeras till %wu element"
 
-#: cp/decl.c:7669
+#: cp/decl.c:7690
 #, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr "det går inte att dekomponera en vektor %qT med variabel längd"
 
-#: cp/decl.c:7695
+#: cp/decl.c:7716
 #, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "%<std::tuple_size<%T>::value%> är inte ett konstantuttryck av heltalstyp"
 
-#: cp/decl.c:7704
+#: cp/decl.c:7725
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr "medan %qT dekomponeras till %E element"
 
-#: cp/decl.c:7725
+#: cp/decl.c:7746
 #, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr "i initieringen av variabel %qD i strukturerad bindning"
 
-#: cp/decl.c:7751
+#: cp/decl.c:7772
 #, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr "det går inte att dekomponera unionstypen %qT"
 
-#: cp/decl.c:7756
+#: cp/decl.c:7777
 #, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "det går inte att dekomponera typen %qT som inte är en klass eller vektor"
 
-#: cp/decl.c:7761
+#: cp/decl.c:7782
 #, gcc-internal-format
 msgid "cannot decompose lambda closure type %qT"
 msgstr "det går inte att dekomponera lambdahöljestypen %qT"
 
-#: cp/decl.c:7765
+#: cp/decl.c:7786
 #, gcc-internal-format
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "strukturerad bindning refererar till ofullständig klasstyp %qT"
 
-#: cp/decl.c:7774
+#: cp/decl.c:7795
 #, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "det går inte att dekomponera klasstypen %qT utan icke-statiska datamedlemmar"
 
-#: cp/decl.c:8213
+#: cp/decl.c:8234
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr "ickelokal variabel %qD deklarerad %<__thread%> behöver dynamisk initiering"
 
-#: cp/decl.c:8216
+#: cp/decl.c:8237
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr "den icke-lokala variabeln %qD deklarerad %<__thread%> har en icke-trivial destruerare"
 
-#: cp/decl.c:8222
+#: cp/decl.c:8243
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr "C++11 %<thread_local%> tillåter dynamisk initialisering och destruktion"
 
-#: cp/decl.c:8450
+#: cp/decl.c:8471
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "initierare misslyckas med att bestämma storleken på %qT"
 
-#: cp/decl.c:8454
+#: cp/decl.c:8475
 #, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "vektorstorlek saknas i %qT"
 
-#: cp/decl.c:8457
+#: cp/decl.c:8478
 #, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "vektor med storlek noll %qT"
 
-#: cp/decl.c:8473
+#: cp/decl.c:8494
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "destruerare för främmande class %qT kan inte vara en medlem"
 
-#: cp/decl.c:8475
+#: cp/decl.c:8496
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "konstruerare för främmande klass %qT kan inte vara en medlem"
 
-#: cp/decl.c:8499
+#: cp/decl.c:8520
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD deklarerad som en %<virtual%>-variabel"
 
-#: cp/decl.c:8501
+#: cp/decl.c:8522
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "%<const%>- och %<volatile%>-funktionsspecificerare på %qD är ogiltiga i variabeldeklaration"
 
-#: cp/decl.c:8506
+#: cp/decl.c:8527
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD deklarerad som en %<virtual%>-parameter"
 
-#: cp/decl.c:8508
+#: cp/decl.c:8529
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD deklarerad som en %<inline%>-parameter"
 
-#: cp/decl.c:8510
+#: cp/decl.c:8531
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "%<const%>- och %<volatile%>-funktionsspecificerare på %qD är ogiltiga i parameterdeklaration"
 
-#: cp/decl.c:8515
+#: cp/decl.c:8536
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD deklarerad som en %<virtual%>-typ"
 
-#: cp/decl.c:8517
+#: cp/decl.c:8538
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD deklarerad som en %<inline%>-typ"
 
-#: cp/decl.c:8519
+#: cp/decl.c:8540
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "%<const%>- och %<volatile%>-funktionsspecificerare på %qD är ogiltiga i typdeklaration"
 
-#: cp/decl.c:8524
+#: cp/decl.c:8545
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD deklarerat som ett %<virtual%>-fält"
 
-#: cp/decl.c:8526
+#: cp/decl.c:8547
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD deklarerat som ett %<inline%>-fält"
 
-#: cp/decl.c:8528
+#: cp/decl.c:8549
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "%<const%>- och %<volatile%>-funktionsspecificerare på %qD är ogiltiga i fältdeklaration"
 
-#: cp/decl.c:8535
+#: cp/decl.c:8556
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D deklarerad som en vän"
 
-#: cp/decl.c:8542
+#: cp/decl.c:8563
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D deklarerad med en undantagsspecifikationer"
 
-#: cp/decl.c:8574
+#: cp/decl.c:8595
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "definitionen av %qD är inte i en namnrymd som innesluter %qT"
 
-#: cp/decl.c:8614
+#: cp/decl.c:8635
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "statisk medlemsfunktion %q#D deklarerad med typkvalificerare"
 
-#: cp/decl.c:8624
+#: cp/decl.c:8645
 #, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr "konceptet %q#D deklarerad med funktionsparametrar"
 
-#: cp/decl.c:8630
+#: cp/decl.c:8651
 #, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr "konceptet %q#D deklarerat med en härledd returtyp"
 
-#: cp/decl.c:8632
+#: cp/decl.c:8653
 #, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "koncept %q#D med icke-%<bool%>-returtyp %qT"
 
-#: cp/decl.c:8703
+#: cp/decl.c:8724
 #, gcc-internal-format
 msgid "concept %qD has no definition"
 msgstr "konceptet %qD har ingen definition"
 
-#: cp/decl.c:8772
+#: cp/decl.c:8793
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "definierar explicit specialisering %qD i vändeklaration"
 
 #. Something like `template <class T> friend void f<T>()'.
-#: cp/decl.c:8782
+#: cp/decl.c:8803
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "ogiltig användning av mall-id %qD i deklaration av primär mall"
 
-#: cp/decl.c:8800
+#: cp/decl.c:8821
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "standardargument är inte tillåtna i deklaration av vänmallspecialisering %qD"
 
-#: cp/decl.c:8808
+#: cp/decl.c:8829
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "%<inline%> är inte tillåtet i deklaration av vänmallspecialisering %qD"
 
-#: cp/decl.c:8857
+#: cp/decl.c:8878
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "det går inte att deklarera %<::main%> som en mall"
 
-#: cp/decl.c:8859
+#: cp/decl.c:8880
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "det går inte att deklarera %<::main%> som inline"
 
-#: cp/decl.c:8861
+#: cp/decl.c:8882
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be %<constexpr%>"
 msgstr "det går inte att deklarera %<::main%> som %<constexpr%>"
 
-#: cp/decl.c:8863
+#: cp/decl.c:8884
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "det går inte att deklarera %<::main%> som static"
 
-#: cp/decl.c:8920
+#: cp/decl.c:8941
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "statisk medlemsfunktion %qD kan inte ha cv-kvalificerare"
 
-#: cp/decl.c:8921
+#: cp/decl.c:8942
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "icke-medlemsfunktion %qD kan inte ha cv-kvalificerare"
 
-#: cp/decl.c:8929
+#: cp/decl.c:8950
 #, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "statisk medlemsfunktion %qD kan inte ha ref-kvalificerare"
 
-#: cp/decl.c:8930
+#: cp/decl.c:8951
 #, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "icke-medlemsfunktion %qD kan inte ha ref-kvalificerare"
 
-#: cp/decl.c:8940
+#: cp/decl.c:8961
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared at namespace scope"
 msgstr "härledningsguiden %qD måste deklareras med namnrymdsräckvidd"
 
-#: cp/decl.c:8946
+#: cp/decl.c:8967
 #, gcc-internal-format
 msgid "deduction guide %qD must not have a function body"
 msgstr "härledningsguiden %qD får inte ha en funktionskropp"
 
-#: cp/decl.c:8959
+#: cp/decl.c:8980
 #, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr "litteral operator med C-länkning"
 
-#: cp/decl.c:8969
+#: cp/decl.c:8990
 #, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "%qD har en ogiltig argumentlista"
 
-#: cp/decl.c:8977
+#: cp/decl.c:8998
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr "heltalssuffixet %qs skuggas av implementationen"
 
-#: cp/decl.c:8983
+#: cp/decl.c:9004
 #, gcc-internal-format
 msgid "floating point suffix %qs shadowed by implementation"
 msgstr "flyttalssuffixet %qs skuggas av implementationen"
 
-#: cp/decl.c:8991
+#: cp/decl.c:9012
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr "litterala operatorsuffix som inte föregås av %<_%> är reserverade för framtida standardisering"
 
-#: cp/decl.c:8996
+#: cp/decl.c:9017
 #, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "%qD måste vara en icke-medlems-funktion"
 
-#: cp/decl.c:9076
+#: cp/decl.c:9097
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> måste returnera %<int%>"
 
-#: cp/decl.c:9116
+#: cp/decl.c:9137
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "omdefinition av implicit deklarerad %qD"
 
-#: cp/decl.c:9121
+#: cp/decl.c:9142
 #, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "definition av explicit standarddefinierad %q+D"
 
-#: cp/decl.c:9123
+#: cp/decl.c:9144
 #, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr "%q#D explicit standarddefinierad här"
 
-#: cp/decl.c:9140
+#: cp/decl.c:9161
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "ingen medlemsfunktion %q#D deklarerad i klassen %qT"
 
-#: cp/decl.c:9329
+#: cp/decl.c:9350
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "det går inte att deklarera %<::main%> som en global variabel"
 
-#: cp/decl.c:9337
+#: cp/decl.c:9358
 #, gcc-internal-format
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "en icke-mallvariabel variabel kan inte vara %<concept%>"
 
-#: cp/decl.c:9344
+#: cp/decl.c:9365
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr "koncept måste ha typen %<bool%>"
 
-#: cp/decl.c:9464
+#: cp/decl.c:9485
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "initiering i klassen av statisk datamedlem %q#D med ofullständig typ"
 
-#: cp/decl.c:9468
+#: cp/decl.c:9489
 #, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "%<constexpr%> behövs för initiering i klassen av statisk datamedlem med icke heltalstyp %q#D"
 
-#: cp/decl.c:9472
+#: cp/decl.c:9493
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "initiering i klassen av statisk datamedlem %q#D med icke-litteral typ"
 
-#: cp/decl.c:9486
+#: cp/decl.c:9507
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "ogiltig initiering i klassen av statisk datamedlem med icke heltalstyp %qT"
 
-#: cp/decl.c:9493
+#: cp/decl.c:9514
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ISO C++ förbjuder initiering inom klassen av icke-konstant statisk medlem %qD"
 
-#: cp/decl.c:9498
+#: cp/decl.c:9519
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO C++ förbjuder initiering av medlemskonstant %qD av icke heltalstyp %qT"
 
-#: cp/decl.c:9598
+#: cp/decl.c:9619
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "storlek på vektorn %qD av typen %qT är inte en heltalstyp"
 
-#: cp/decl.c:9600
+#: cp/decl.c:9621
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "storlek på vektorn av typen %qT är inte en heltalstyp"
 
-#: cp/decl.c:9630 cp/decl.c:9680
+#: cp/decl.c:9651 cp/decl.c:9701
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "storlek på vektorn är inte ett konstantuttryck av heltalstyp"
 
-#: cp/decl.c:9646
+#: cp/decl.c:9667
 #, gcc-internal-format
 msgid "size of array %qD is negative"
 msgstr "storleken på vektorn %qD är negativ"
 
-#: cp/decl.c:9648 cp/init.c:3651
+#: cp/decl.c:9669 cp/init.c:3667
 #, gcc-internal-format
 msgid "size of array is negative"
 msgstr "storleken på vektorn är negativ"
 
-#: cp/decl.c:9662
+#: cp/decl.c:9683
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C++ förbjuder vektor %qD med storlek noll"
 
-#: cp/decl.c:9664
+#: cp/decl.c:9685
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++ förbjuder vektor med storlek noll"
 
-#: cp/decl.c:9677
+#: cp/decl.c:9698
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "storlek på vektorn %qD är inte ett konstantuttryck av heltalstyp"
 
-#: cp/decl.c:9686
+#: cp/decl.c:9707
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++ förbjuder vektor %qD med variabel längd"
 
-#: cp/decl.c:9688
+#: cp/decl.c:9709
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++ förbjuder vektor med variabel längd"
 
-#: cp/decl.c:9694
+#: cp/decl.c:9715
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr "vektor %qD med variabel längd används"
 
-#: cp/decl.c:9697
+#: cp/decl.c:9718
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr "vektor med variabel längd används"
 
-#: cp/decl.c:9746
+#: cp/decl.c:9767
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "spill i vektordimension"
 
-#: cp/decl.c:9799
+#: cp/decl.c:9820
 #, gcc-internal-format
 msgid "%qD declared as array of %qT"
 msgstr "%qD är deklarerad som en vektor av %qT"
 
-#: cp/decl.c:9809
+#: cp/decl.c:9830
 #, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "deklaration av %qD som en vektor av void"
 
-#: cp/decl.c:9811
+#: cp/decl.c:9832
 #, gcc-internal-format
 msgid "creating array of void"
 msgstr "skapar vektor av void"
 
-#: cp/decl.c:9816
+#: cp/decl.c:9837
 #, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "deklaration av %qD som en vektor av funktioner"
 
-#: cp/decl.c:9818
+#: cp/decl.c:9839
 #, gcc-internal-format
 msgid "creating array of functions"
 msgstr "skapar vektor av funktioner"
 
-#: cp/decl.c:9823
+#: cp/decl.c:9844
 #, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "deklaration av %qD som en vektor av referenser"
 
-#: cp/decl.c:9825
+#: cp/decl.c:9846
 #, gcc-internal-format
 msgid "creating array of references"
 msgstr "skapar vektor av referenser"
 
-#: cp/decl.c:9830
+#: cp/decl.c:9851
 #, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "deklaration av %qD som en vektor av funktionsmedlemmar"
 
-#: cp/decl.c:9832
+#: cp/decl.c:9853
 #, gcc-internal-format
 msgid "creating array of function members"
 msgstr "skapar vektor av funktionsmedlemmar"
 
-#: cp/decl.c:9846
+#: cp/decl.c:9867
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "deklaration av %qD som flerdimensionell vektor måste ha gränser för alla dimensioner utom den första"
 
-#: cp/decl.c:9850
+#: cp/decl.c:9871
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "flerdimensionell vektor måste ha gränser för alla dimensioner utom den första"
 
-#: cp/decl.c:9909
+#: cp/decl.c:9930
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "en returtypsspecifikation för konstruerare är ogiltig"
 
-#: cp/decl.c:9912
+#: cp/decl.c:9933
 #, gcc-internal-format
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "kvalificerare är inte tillåtna vid kontruerardeklaration"
 
-#: cp/decl.c:9922
+#: cp/decl.c:9943
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "specifikation av returtyp för destruerare är ogiltigt"
 
-#: cp/decl.c:9925
+#: cp/decl.c:9946
 #, gcc-internal-format
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "kvalificerare är inte tillåtna vid destruerardeklaration"
 
-#: cp/decl.c:9937
+#: cp/decl.c:9958
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "returtyp angiven för %<operator %T%>"
 
-#: cp/decl.c:9940
+#: cp/decl.c:9961
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "kvalificerare är inte tillåtna på deklaration av %<operator %T%>"
 
-#: cp/decl.c:9948
+#: cp/decl.c:9969
 #, gcc-internal-format
 msgid "return type specified for deduction guide"
 msgstr "returtypen angiven för härledningsguiden"
 
-#: cp/decl.c:9951
+#: cp/decl.c:9972
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "kvalificerare är inte tillåtna på deklaration av härledningsguide"
 
-#: cp/decl.c:9955
+#: cp/decl.c:9976
 #, gcc-internal-format
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "mallmallparameter %qT i deklaration av härledningsguide"
 
-#: cp/decl.c:9964
+#: cp/decl.c:9985
 #, gcc-internal-format
 msgid "decl-specifier in declaration of deduction guide"
 msgstr "decl-specificerare i deklaration av härledningsguide"
 
-#: cp/decl.c:9985
+#: cp/decl.c:10006
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "namnlös variabel eller fält deklarerad void"
 
-#: cp/decl.c:9992
+#: cp/decl.c:10013
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "variabel eller fält deklarerad void"
 
-#: cp/decl.c:10007
+#: cp/decl.c:10028
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "specificeraren %<inline%> är ogiltig för variabeln %qD deklarerad med blockräckvidd"
 
-#: cp/decl.c:10013
+#: cp/decl.c:10034
 #, gcc-internal-format
 msgid "inline variables are only available with -std=c++17 or -std=gnu++17"
 msgstr "inline-variabler är endast tillgängliga med -std=c++17 eller -std=gnu++17"
 
-#: cp/decl.c:10268
+#: cp/decl.c:10292
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "ogiltigt användning av kvalificerat namn %<::%D%>"
 
-#: cp/decl.c:10271 cp/decl.c:10291
+#: cp/decl.c:10295 cp/decl.c:10315
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "ogiltig användning av kvalificerat namn %<%T::%D%>"
 
-#: cp/decl.c:10274
+#: cp/decl.c:10298
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "ogiltig användning av kvalificerat namn %<%D::%D%>"
 
-#: cp/decl.c:10283
+#: cp/decl.c:10307
 #, gcc-internal-format
 msgid "%q#T is not a class or a namespace"
 msgstr "%q#T är inte en klass eller namnrymd"
 
-#: cp/decl.c:10305 cp/decl.c:10398 cp/decl.c:10407 cp/decl.c:11970
+#: cp/decl.c:10329 cp/decl.c:10422 cp/decl.c:10431 cp/decl.c:11994
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "deklaration av %qD som en icke-funktion"
 
-#: cp/decl.c:10311
+#: cp/decl.c:10335
 #, gcc-internal-format
 msgid "declaration of %qD as non-member"
 msgstr "deklaration av %qD som icke-medlem"
 
-#: cp/decl.c:10339
+#: cp/decl.c:10363
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "deklarerar-id saknas, använder reserverat ord %qD"
 
-#: cp/decl.c:10390
+#: cp/decl.c:10414
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "funktionsdefinition deklarerar inte parametrar"
 
-#: cp/decl.c:10415
+#: cp/decl.c:10439
 #, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "deklaration av %qD som %<typedef%>"
 
-#: cp/decl.c:10420
+#: cp/decl.c:10444
 #, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "deklaration av %qD som en parameter"
 
-#: cp/decl.c:10454
+#: cp/decl.c:10478
 #, gcc-internal-format
 msgid "%<concept%> cannot appear in a typedef declaration"
 msgstr "%<concept%> kan inte förekomma i en typedef-deklaration"
 
-#: cp/decl.c:10460
+#: cp/decl.c:10484
 #, gcc-internal-format
 msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgstr "%<constexpr%> kan inte förekomma i en typedef-deklaration"
 
-#: cp/decl.c:10468
+#: cp/decl.c:10492
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "två eller fler datatyper i deklaration av %qs"
 
-#: cp/decl.c:10474
+#: cp/decl.c:10498
 #, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr "motstridande specificerare i deklarationen av %qs"
 
-#: cp/decl.c:10515
+#: cp/decl.c:10539
 #, gcc-internal-format
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C++ stödjer inte bara %<complex%> i meningen %<double complex%>"
 
-#: cp/decl.c:10564 cp/decl.c:10567 cp/decl.c:10570
+#: cp/decl.c:10588 cp/decl.c:10591 cp/decl.c:10594
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ förbjuder deklaration av %qs utan typ"
 
-#: cp/decl.c:10586
+#: cp/decl.c:10610
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr "%<__int%d%> stödjs inte på denna målarkitektur"
 
-#: cp/decl.c:10592
+#: cp/decl.c:10616
 #, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ stödjer inte %<__int%d%> för %qs"
 
-#: cp/decl.c:10614 cp/decl.c:10634
+#: cp/decl.c:10638 cp/decl.c:10658
 #, gcc-internal-format
 msgid "%<signed%> or %<unsigned%> invalid for %qs"
 msgstr "%<signed%> eller %<unsigned%> är ogiltigt för %qs"
 
-#: cp/decl.c:10616
+#: cp/decl.c:10640
 #, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgstr "%<signed%> och %<unsigned%> givna tillsammans för %qs"
 
-#: cp/decl.c:10618
+#: cp/decl.c:10642
 #, gcc-internal-format
 msgid "%<long long%> invalid for %qs"
 msgstr "%<long long%> ogiltig för %qs"
 
-#: cp/decl.c:10620
+#: cp/decl.c:10644
 #, gcc-internal-format
 msgid "%<long%> invalid for %qs"
 msgstr "%<long%> ogiltig för %qs"
 
-#: cp/decl.c:10622
+#: cp/decl.c:10646
 #, gcc-internal-format
 msgid "%<short%> invalid for %qs"
 msgstr "%<short%> ogiltig för %qs"
 
-#: cp/decl.c:10624
+#: cp/decl.c:10648
 #, gcc-internal-format
 msgid "%<long%> or %<short%> invalid for %qs"
 msgstr "%<long%> eller %<short%> ogiltig för %qs"
 
-#: cp/decl.c:10626
+#: cp/decl.c:10650
 #, gcc-internal-format
 msgid "%<long%>, %<int%>, %<short%>, or %<char%> invalid for %qs"
 msgstr "%<long%>, %<int%>, %<short%> eller %<char%> ogiltig för %qs"
 
-#: cp/decl.c:10628
+#: cp/decl.c:10652
 #, gcc-internal-format
 msgid "%<long%> or %<short%> specified with char for %qs"
 msgstr "%<long%> eller %<short%> angiven med char för %qs"
 
-#: cp/decl.c:10630
+#: cp/decl.c:10654
 #, gcc-internal-format
 msgid "%<long%> and %<short%> specified together for %qs"
 msgstr "%<long%> och %<short%> angivna tillsammans för %qs"
 
-#: cp/decl.c:10636
+#: cp/decl.c:10660
 #, gcc-internal-format
 msgid "%<short%> or %<long%> invalid for %qs"
 msgstr "%<short%> eller %<long%> ogiltig för %qs"
 
-#: cp/decl.c:10644
+#: cp/decl.c:10668
 #, gcc-internal-format
 msgid "long, short, signed or unsigned used invalidly for %qs"
 msgstr "long, short, signed eller unsigned använd felaktigt för %qs"
 
-#: cp/decl.c:10712
+#: cp/decl.c:10736
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "complex ogiltig för %qs"
 
-#: cp/decl.c:10751
+#: cp/decl.c:10775
 #, gcc-internal-format
 msgid "template placeholder type %qT must be followed by a simple declarator-id"
 msgstr "mallens platshållartyp %qT måste följas av ett enkelt deklarerar-id"
 
-#: cp/decl.c:10769
+#: cp/decl.c:10793
 #, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "medlem %qD kan inte deklareras både %<virtual%> och %<static%>"
 
-#: cp/decl.c:10775
+#: cp/decl.c:10799
 #, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<constexpr%>"
 msgstr "medlem %qD kan inte deklareras både %<virtual%> och %<constexpr%>"
 
-#: cp/decl.c:10785
+#: cp/decl.c:10809
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "typedef-deklaration ogiltig i parameterdeklaration"
 
-#: cp/decl.c:10790
+#: cp/decl.c:10814
 #, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "lagringsklass angiven för mallparameter %qs"
 
-#: cp/decl.c:10796
+#: cp/decl.c:10820
 #, gcc-internal-format
 msgid "storage class specifiers invalid in parameter declarations"
 msgstr "specificerare av lagringsklass ogiltig i parameterdeklarationer"
 
-#: cp/decl.c:10800
+#: cp/decl.c:10824
 #, gcc-internal-format
 msgid "a parameter cannot be declared %<concept%>"
 msgstr "en parameter kan inte deklareras %<concept%>"
 
-#: cp/decl.c:10805
+#: cp/decl.c:10829
 #, gcc-internal-format
 msgid "a parameter cannot be declared %<constexpr%>"
 msgstr "en parameter kan inte deklareras %<constexpr%>"
 
-#: cp/decl.c:10815
+#: cp/decl.c:10839
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "%<virtual%> utanför klassdeklaration"
 
-#: cp/decl.c:10825
+#: cp/decl.c:10849
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<inline%>"
 msgstr "deklaration av strukturerad bindning får inte vara %<inline%>"
 
-#: cp/decl.c:10828
+#: cp/decl.c:10852
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<typedef%>"
 msgstr "deklaration av strukturerad bindning får inte vara %<typedef%>"
 
-#: cp/decl.c:10830
+#: cp/decl.c:10854
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<constexpr%>"
 msgstr "deklarationen av strukturerad bindning får inte vara %<constexpr%>"
 
-#: cp/decl.c:10834
+#: cp/decl.c:10858
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr "deklaration av strukturerad bindning får inte vara %qs"
 
-#: cp/decl.c:10839
+#: cp/decl.c:10863
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<concept%>"
 msgstr "deklaration av strukturerad bindning får inte vara %<concept%>"
 
-#: cp/decl.c:10845
+#: cp/decl.c:10869
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<register%>"
 msgstr "deklaration av strukturerad bindning får inte vara %<register%>"
 
-#: cp/decl.c:10849
+#: cp/decl.c:10873
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<static%>"
 msgstr "deklaration av strukturerad bindning får inte vara %<static%>"
 
-#: cp/decl.c:10853
+#: cp/decl.c:10877
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<extern%>"
 msgstr "deklaration av strukturerad bindning får inte vara %<extern%>"
 
-#: cp/decl.c:10857
+#: cp/decl.c:10881
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<mutable%>"
 msgstr "deklaration av strukturerad bindning får inte vara %<mutable%>"
 
-#: cp/decl.c:10861
+#: cp/decl.c:10885
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr "deklaration av strukturerad bindning får inte vara C++98 %<auto%>"
 
-#: cp/decl.c:10872
+#: cp/decl.c:10896
 #, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr "deklaration av strukturerad bindning får inte ha typen %qT"
 
-#: cp/decl.c:10875
+#: cp/decl.c:10899
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr "typen måste vara en cv-kvalificerad %<auto%> eller en referens till en cv-kvalificerad %<auto%>"
 
-#: cp/decl.c:10906
+#: cp/decl.c:10930
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "flera lagringsklasser i deklaration av %qs"
 
-#: cp/decl.c:10929
+#: cp/decl.c:10953
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "lagringsklass angiven för %qs"
 
-#: cp/decl.c:10933
+#: cp/decl.c:10957
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "lagringsklass angiven för parameter %qs"
 
-#: cp/decl.c:10946
+#: cp/decl.c:10970
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "nästad funktion %qs är deklarerad %<extern%>"
 
-#: cp/decl.c:10950
+#: cp/decl.c:10974
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "toppnivådeklaration av %qs anger %<auto%>"
 
-#: cp/decl.c:10957
+#: cp/decl.c:10981
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "funktionsdefinitionsområde %qs implicit auto och deklarerat %<__thread%>"
 
-#: cp/decl.c:10969
+#: cp/decl.c:10993
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "ogiltig specificerare av lagringsklass i vänfunktionsdeklarationer"
 
-#: cp/decl.c:11050
+#: cp/decl.c:11074
 #, gcc-internal-format
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "onödiga parenteser i deklaration av %qs"
 
-#: cp/decl.c:11098
+#: cp/decl.c:11122
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr "requires-klausul på returtypen"
 
-#: cp/decl.c:11118
+#: cp/decl.c:11142
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr "funktionen %qs använder typspecificeraren %<auto%> utan avslutande returtyp"
 
-#: cp/decl.c:11121
+#: cp/decl.c:11145
 #, gcc-internal-format
 msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgstr "härledd returtyp är endast tillgänglig med -std=c++14 eller -std=gnu++14"
 
-#: cp/decl.c:11127
+#: cp/decl.c:11151
 #, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr "en virtuell funktion kan inte ha härledd returtyp"
 
-#: cp/decl.c:11134
+#: cp/decl.c:11158
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr "funktionen %qs med avslutande returtyp har %qT som sin typ istället för bara %<auto%>"
 
-#: cp/decl.c:11147
+#: cp/decl.c:11171
 #, gcc-internal-format
 msgid "deduced class type %qD in function return type"
 msgstr "härledd klasstyp %qD i funktionens returtyp"
 
-#: cp/decl.c:11156
+#: cp/decl.c:11180
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr "härledningsguiden för %qT måste ha en avslutande returtyp"
 
-#: cp/decl.c:11169
+#: cp/decl.c:11193
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr "den avslutande returtypen %qT hos deduktionsguiden är inte en specialisering av %qT"
@@ -41705,459 +41747,459 @@
 
 #. Not using maybe_warn_cpp0x because this should
 #. always be an error.
-#: cp/decl.c:11180
+#: cp/decl.c:11204
 #, gcc-internal-format
 msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgstr "avslutande returtyp är endast tillgänglig med -std=c++11 eller -std=gnu++11"
 
-#: cp/decl.c:11183
+#: cp/decl.c:11207
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr "funktionen %qs med avslutande returtyp är inte deklarerad med typspecificeraren %<auto%>"
 
-#: cp/decl.c:11212
+#: cp/decl.c:11236
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs är deklarerad som en funktion som returnerar en funktion"
 
-#: cp/decl.c:11218
+#: cp/decl.c:11242
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs är deklarerad som en funktion som returnerar en vektor"
 
-#: cp/decl.c:11247
+#: cp/decl.c:11271
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "destruerare kan inte vara en statisk medlemsfunktion"
 
-#: cp/decl.c:11248
+#: cp/decl.c:11272
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "konstruerare kan inte vara en statisk medlemsfunktion"
 
-#: cp/decl.c:11252
+#: cp/decl.c:11276
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "destruerare får inte vara cv-kvalificerade"
 
-#: cp/decl.c:11253
+#: cp/decl.c:11277
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "konstruerare får inte vara cv-kvalificerade"
 
-#: cp/decl.c:11261
+#: cp/decl.c:11285
 #, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr "destruerare får inte vara ref-kvalificerade"
 
-#: cp/decl.c:11262
+#: cp/decl.c:11286
 #, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr "konstruerare får inte vara ref-kvalificerade"
 
-#: cp/decl.c:11280
+#: cp/decl.c:11304
 #, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "konstruerare kan inte deklareras %<virtual%>"
 
 #. Cannot be both friend and virtual.
-#: cp/decl.c:11295
+#: cp/decl.c:11319
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "virtuella funktioner kan inte vara vänner"
 
-#: cp/decl.c:11299
+#: cp/decl.c:11323
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "vändeklaration är inte i klassdefinition"
 
-#: cp/decl.c:11301
+#: cp/decl.c:11325
 #, gcc-internal-format
 msgid "can%'t define friend function %qs in a local class definition"
 msgstr "det går inte att definiera vänfunktion %qs i en lokal klassdefinition"
 
-#: cp/decl.c:11313
+#: cp/decl.c:11337
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr "en konverteringsfunktion kan inte ha en avslutande returtyp"
 
-#: cp/decl.c:11339
+#: cp/decl.c:11363
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "destruerare får inte ha parametrar"
 
-#: cp/decl.c:11379
+#: cp/decl.c:11403
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "det går inte att deklarera pekare till %q#T"
 
-#: cp/decl.c:11392 cp/decl.c:11399
+#: cp/decl.c:11416 cp/decl.c:11423
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "det går inte att deklarera referens till %q#T"
 
-#: cp/decl.c:11401
+#: cp/decl.c:11425
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "det går inte att deklarera pekare medlem av %q#T"
 
-#: cp/decl.c:11430
+#: cp/decl.c:11454
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "det går inte att deklarera en referens till en kvalificerad funktionstyp %qT"
 
-#: cp/decl.c:11431
+#: cp/decl.c:11455
 #, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "det går inte att deklarera en pekare till en kvalificerad funktionstyp %qT"
 
-#: cp/decl.c:11504
+#: cp/decl.c:11528
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr "det går inte att deklarera en referens till %q#T, som inte är ett typedef- eller ett malltypargument"
 
-#: cp/decl.c:11574
+#: cp/decl.c:11598
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "mall-id %qD använd som en deklarerare"
 
-#: cp/decl.c:11599
+#: cp/decl.c:11623
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "medlemsfunktioner är implicit vänner till sin klass"
 
-#: cp/decl.c:11605
+#: cp/decl.c:11629
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "extra kvalifikation %<%T::%> på medlem %qs"
 
-#: cp/decl.c:11635
+#: cp/decl.c:11659
 #, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "det går inte att definiera medlemsfunktion %<%T::%s%> inuti %qT"
 
-#: cp/decl.c:11637
+#: cp/decl.c:11661
 #, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "det går inte att deklarera medlemsfunktionen %<%T::%s%> inuti %qT"
 
-#: cp/decl.c:11645
+#: cp/decl.c:11669
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "det går inte att deklarera medlem %<%T::%s%> inuti %qT"
 
-#: cp/decl.c:11685
+#: cp/decl.c:11709
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "icke-parameter %qs kan inte vara ett parameterpaket"
 
-#: cp/decl.c:11693
+#: cp/decl.c:11717
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "datamedlem får inte ha variabel typ %qT"
 
-#: cp/decl.c:11695
+#: cp/decl.c:11719
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "parameter får inte ha variabel typ %qT"
 
-#: cp/decl.c:11706
+#: cp/decl.c:11730
 #, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "%<explicit%> utanför klassdeklaration"
 
-#: cp/decl.c:11709
+#: cp/decl.c:11733
 #, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr "%<explicit%> i vändeklaration"
 
-#: cp/decl.c:11712
+#: cp/decl.c:11736
 #, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "endast deklarationer av konstruerare och konverteringsoperatorer kan vara %<explicit%>"
 
-#: cp/decl.c:11721
+#: cp/decl.c:11745
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "icke-medlem %qs kan inte deklareras %<mutable%>"
 
-#: cp/decl.c:11726
+#: cp/decl.c:11750
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "icke-objektmedlem %qs kan inte deklareras %<mutable%>"
 
-#: cp/decl.c:11732
+#: cp/decl.c:11756
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "funktionen %qs kan inte deklareras %<mutable%>"
 
-#: cp/decl.c:11737
+#: cp/decl.c:11761
 #, gcc-internal-format
 msgid "static %qs cannot be declared %<mutable%>"
 msgstr "statiska %qs kan inte deklareras %<mutable%>"
 
-#: cp/decl.c:11742
+#: cp/decl.c:11766
 #, gcc-internal-format
 msgid "const %qs cannot be declared %<mutable%>"
 msgstr "const %qs kan inte deklareras %<mutable%>"
 
-#: cp/decl.c:11747
+#: cp/decl.c:11771
 #, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "referensen %qs kan inte deklareras %<mutable%>"
 
-#: cp/decl.c:11778
+#: cp/decl.c:11802
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "typedef deklarerad %<auto%>"
 
-#: cp/decl.c:11783
+#: cp/decl.c:11807
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr "requires-klausul på typedef"
 
-#: cp/decl.c:11787
+#: cp/decl.c:11811
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "typedef-namn får inte vara en nästad-namnspecificerare"
 
-#: cp/decl.c:11813
+#: cp/decl.c:11837
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ISO C++ förbjuder nästad typ %qD med samma namn som en omgivande klass"
 
-#: cp/decl.c:11900
+#: cp/decl.c:11924
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "%<inline%> angivet för vänklassdeklaration"
 
-#: cp/decl.c:11908
+#: cp/decl.c:11932
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "mallparametrar kan inte vara vänner"
 
-#: cp/decl.c:11910
+#: cp/decl.c:11934
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "vändeklaration kräver klassnyckel, d.v.s. %<friend class %T::%D%>"
 
-#: cp/decl.c:11914
+#: cp/decl.c:11938
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "vändeklaration kräver klassnyckel, d.v.s. %<friend %#T%>"
 
-#: cp/decl.c:11927
+#: cp/decl.c:11951
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "försöker göra klassen %qT en vän med global räckvidd"
 
-#: cp/decl.c:11947
+#: cp/decl.c:11971
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "ogiltiga kvalificerare på typ som inte är medlemsfunktion"
 
-#: cp/decl.c:11951
+#: cp/decl.c:11975
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr "requires-klausul på type-id"
 
-#: cp/decl.c:11961
+#: cp/decl.c:11985
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "abstrakt deklarerare %qT använd som deklaration"
 
-#: cp/decl.c:11976
+#: cp/decl.c:12000
 #, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "requires-klausul vid deklaration av icke-funktionstypen %qT"
 
-#: cp/decl.c:11995
+#: cp/decl.c:12019
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "det går inte att använda %<::%> i parameterdeklaration"
 
-#: cp/decl.c:12001
+#: cp/decl.c:12025
 #, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "en %<auto%>-parameter är tillåten i detta sammanhang"
 
-#: cp/decl.c:12003
+#: cp/decl.c:12027
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "parametern deklarerad %<auto%>"
 
-#: cp/decl.c:12052 cp/parser.c:3270
+#: cp/decl.c:12076 cp/parser.c:3270
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "ogiltig användning av mallnamnet %qE utan en argumentlista"
 
-#: cp/decl.c:12056
+#: cp/decl.c:12080
 #, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr "ej statisk datamedlem deklarerad med platshållaren %qT"
 
-#: cp/decl.c:12080
+#: cp/decl.c:12104
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C++ förbjuder den flexibla vektormedlemmen %qs"
 
-#: cp/decl.c:12083
+#: cp/decl.c:12107
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array members"
 msgstr "ISO C++ förbjuder flexibla vektormedlemmar"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:12099
+#: cp/decl.c:12123
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "ogiltigt användning av %<::%>"
 
-#: cp/decl.c:12121
+#: cp/decl.c:12145
 #, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "deklaration av funktionen %qD i ogiltig kontext"
 
-#: cp/decl.c:12130
+#: cp/decl.c:12154
 #, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "funktionen %qD deklarerad %<virtual%> inuti en union"
 
-#: cp/decl.c:12139
+#: cp/decl.c:12163
 #, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%qD kan inte deklareras %<virtual%>, eftersom den alltid är statisk"
 
-#: cp/decl.c:12153
+#: cp/decl.c:12177
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "kvalificerat namn förväntades i vändeklaration för destruerare %qD"
 
-#: cp/decl.c:12160
+#: cp/decl.c:12184
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "deklaration av %qD som medlem av %qT"
 
-#: cp/decl.c:12166
+#: cp/decl.c:12190
 #, gcc-internal-format
 msgid "a destructor cannot be %<concept%>"
 msgstr "en destruerare kan inte vara %<concept%>"
 
-#: cp/decl.c:12171
+#: cp/decl.c:12195
 #, gcc-internal-format
 msgid "a destructor cannot be %<constexpr%>"
 msgstr "en destruerare kan inte vara %<constexpr%>"
 
-#: cp/decl.c:12177
+#: cp/decl.c:12201
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "kvalificerat namn förväntades i vändeklaration för konstruerare %qD"
 
-#: cp/decl.c:12185
+#: cp/decl.c:12209
 #, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr "en konstruerare kan inte vara %<concept%>"
 
-#: cp/decl.c:12190
+#: cp/decl.c:12214
 #, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr "ett koncept kan inte vara en medlemsfunktion"
 
-#: cp/decl.c:12199
+#: cp/decl.c:12223
 #, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr "specialisering av variabelmall %qD deklarerad som en funktion"
 
-#: cp/decl.c:12202
+#: cp/decl.c:12226
 #, gcc-internal-format
 msgid "variable template declared here"
 msgstr "variabelmallen är deklarerad här"
 
-#: cp/decl.c:12257
+#: cp/decl.c:12281
 #, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr "fältet %qD har den ofullständiga typen %qT"
 
-#: cp/decl.c:12262
+#: cp/decl.c:12286
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "namnet %qT har ofullständig typ"
 
-#: cp/decl.c:12272
+#: cp/decl.c:12296
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE är varken en funktion eller medlemsfunktion, kan inte deklareras som vän"
 
-#: cp/decl.c:12318
+#: cp/decl.c:12342
 #, gcc-internal-format
 msgid "static data member %qE declared %<concept%>"
 msgstr "statisk datamedlem %qE deklarerad %<concept%>"
 
-#: cp/decl.c:12322
+#: cp/decl.c:12346
 #, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "statiska %<constexpr%>-datamedlemmen %qD måste ha en initierare"
 
-#: cp/decl.c:12350
+#: cp/decl.c:12374
 #, gcc-internal-format
 msgid "non-static data member %qE declared %<concept%>"
 msgstr "ickestatisk datamedlem %qE deklarerad %<concept%>"
 
-#: cp/decl.c:12354
+#: cp/decl.c:12378
 #, gcc-internal-format
 msgid "non-static data member %qE declared %<constexpr%>"
 msgstr "ickestatisk datamedlem %qE deklarerad %<constexpr%>"
 
-#: cp/decl.c:12409
+#: cp/decl.c:12433
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "lagringsklassen %<auto%> är ogiltig för funktionen %qs"
 
-#: cp/decl.c:12411
+#: cp/decl.c:12435
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "lagringsklassen %<register%> är ogiltig för funktionen %qs"
 
-#: cp/decl.c:12415
+#: cp/decl.c:12439
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "lagringsklassen %<__thread%> är ogiltig för funktionen %qs"
 
-#: cp/decl.c:12418
+#: cp/decl.c:12442
 #, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "lagringsklassen %<thread_local%> är ogiltig för funktionen %qs"
 
-#: cp/decl.c:12423
+#: cp/decl.c:12447
 #, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "virt-specificerare i %qs är inte tillåtet utanför en klassdefinition"
 
-#: cp/decl.c:12434
+#: cp/decl.c:12458
 #, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "specificerare %<static%> är ogiltigt för funktion %qs deklarerad utanför global räckvidd"
 
-#: cp/decl.c:12438
+#: cp/decl.c:12462
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "specificerare %<inline%> är ogiltig för funktionen %qs deklarerad utanför global räckvidd"
 
-#: cp/decl.c:12446
+#: cp/decl.c:12470
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "virtuell icke klassfunktion %qs"
 
-#: cp/decl.c:12453
+#: cp/decl.c:12477
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "%qs definierad utan att vara i klassräckvidd"
 
-#: cp/decl.c:12454
+#: cp/decl.c:12478
 #, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "%qs deklarerad utan att vara i klassräckvidd"
 
-#: cp/decl.c:12489
+#: cp/decl.c:12513
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "det går inte deklarera medlemsfunktionen %qD att ha statisk länkklass"
@@ -42164,77 +42206,77 @@
 
 #. 7.1.1: There can be no static function declarations within a
 #. block.
-#: cp/decl.c:12497
+#: cp/decl.c:12521
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "kan inte deklarera en statisk funktion i en annan funktion"
 
-#: cp/decl.c:12533
+#: cp/decl.c:12557
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "%<static%> får inte användas vid definition (till skillnad mot deklaration) av statisk datamedlem"
 
-#: cp/decl.c:12540
+#: cp/decl.c:12564
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "statisk medlem %qD deklarerad %<register%>"
 
-#: cp/decl.c:12546
+#: cp/decl.c:12570
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "det går inte att deklarera medlem %q#D att ha extern länkklass"
 
-#: cp/decl.c:12553
+#: cp/decl.c:12577
 #, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "deklarationen av %<constexpr%>-variabeln %qD är inte en definition"
 
-#: cp/decl.c:12574
+#: cp/decl.c:12598
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "deklarationen av %q#D har ingen initierare"
 
-#: cp/decl.c:12585
+#: cp/decl.c:12609
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs initierad och deklarerad %<extern%>"
 
-#: cp/decl.c:12589
+#: cp/decl.c:12613
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs har både %<extern%> och initierare"
 
-#: cp/decl.c:12754
+#: cp/decl.c:12778
 #, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "standardargument %qE använder %qD"
 
-#: cp/decl.c:12757
+#: cp/decl.c:12781
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "standardargument %qE använder lokal variabel %qD"
 
-#: cp/decl.c:12841
+#: cp/decl.c:12865
 #, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "felaktig användning av cv-kvalificerad typ %qT i en parameterdeklaration"
 
-#: cp/decl.c:12845
+#: cp/decl.c:12869
 #, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "felaktig användning av typen %<void%> i en parameterdeklaration"
 
-#: cp/decl.c:12868
+#: cp/decl.c:12892
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "parameter %qD ogiltigt deklarerad metodtyp"
 
-#: cp/decl.c:12895
+#: cp/decl.c:12919
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "parameter %qD inkluderar pekare till vektor %qT med okänd gräns"
 
-#: cp/decl.c:12897
+#: cp/decl.c:12921
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "parameter %qD inkluderar referens till vektor %qT med okänd gräns"
@@ -42254,169 +42296,169 @@
 #. or implicitly defined), there's no need to worry about their
 #. existence.  Theoretically, they should never even be
 #. instantiated, but that's hard to forestall.
-#: cp/decl.c:13150
+#: cp/decl.c:13174
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "ogiltig konstruerare, du menade förmodligen %<%T (const %T&)%>"
 
-#: cp/decl.c:13228
+#: cp/decl.c:13252
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD är kanske inte deklarerad i en namnrymd"
 
-#: cp/decl.c:13234
+#: cp/decl.c:13258
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD får inte deklareras som statisk"
 
-#: cp/decl.c:13261
+#: cp/decl.c:13285
 #, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr "%qD måste vara en icke-statisk medlemsfunktion"
 
-#: cp/decl.c:13267
+#: cp/decl.c:13291
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD måste vara antingen en medlemsfunktion som inte är statisk eller funktion som inte är medlem"
 
-#: cp/decl.c:13277
+#: cp/decl.c:13301
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD måste ha ett argument med klass- eller uppräkningstyp"
 
 #. 13.4.0.3
-#: cp/decl.c:13303
+#: cp/decl.c:13327
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading operator ?:"
 msgstr "ISO C++ förhindrar överlagring av operatorn ?:"
 
 #. Variadic.
-#: cp/decl.c:13314
+#: cp/decl.c:13338
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD får inte ha variabelt antal argument"
 
-#: cp/decl.c:13338
+#: cp/decl.c:13362
 #, gcc-internal-format
 msgid "%qD must have either zero or one argument"
 msgstr "%qD måste ha antingen noll eller ett argument"
 
-#: cp/decl.c:13339
+#: cp/decl.c:13363
 #, gcc-internal-format
 msgid "%qD must have either one or two arguments"
 msgstr "%qD måste ha antingen ett eller två argument"
 
-#: cp/decl.c:13350
+#: cp/decl.c:13374
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "postfix %qD måste ha %<int%> som sitt argument"
 
-#: cp/decl.c:13351
+#: cp/decl.c:13375
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "postfix %qD måste ha %<int%> som sitt andra argument"
 
-#: cp/decl.c:13361
+#: cp/decl.c:13385
 #, gcc-internal-format
 msgid "%qD must have no arguments"
 msgstr "%qD får inte ha några argument"
 
-#: cp/decl.c:13362 cp/decl.c:13371
+#: cp/decl.c:13386 cp/decl.c:13395
 #, gcc-internal-format
 msgid "%qD must have exactly one argument"
 msgstr "%qD måste ha exakt ett argument"
 
-#: cp/decl.c:13372
+#: cp/decl.c:13396
 #, gcc-internal-format
 msgid "%qD must have exactly two arguments"
 msgstr "%qD måste ha exakt två argument"
 
-#: cp/decl.c:13389 cp/decl.c:13392
+#: cp/decl.c:13413 cp/decl.c:13416
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD kan inte ha standardargument"
 
-#: cp/decl.c:13419
+#: cp/decl.c:13443
 #, gcc-internal-format
 msgid "conversion to a reference to void will never use a type conversion operator"
 msgstr "konvertering till en referens till void kommer aldrig använda en typkonverteringsoperator"
 
-#: cp/decl.c:13421
+#: cp/decl.c:13445
 #, gcc-internal-format
 msgid "conversion to void will never use a type conversion operator"
 msgstr "konvertering till void kommer aldrig använda en typkonverteringsoperator"
 
-#: cp/decl.c:13428
+#: cp/decl.c:13452
 #, gcc-internal-format
 msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgstr "konvertering till en referens till samma typ kommer aldrig använda en typkonverteringsoperator"
 
-#: cp/decl.c:13430
+#: cp/decl.c:13454
 #, gcc-internal-format
 msgid "conversion to the same type will never use a type conversion operator"
 msgstr "konvertering till samma typ kommer aldrig använda en typkonverteringsoperator"
 
-#: cp/decl.c:13438
+#: cp/decl.c:13462
 #, gcc-internal-format
 msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgstr "konvertering till en referens till en basklass kommer aldrig använda en typkonverteringsoperator"
 
-#: cp/decl.c:13440
+#: cp/decl.c:13464
 #, gcc-internal-format
 msgid "conversion to a base class will never use a type conversion operator"
 msgstr "konvertering till en basklass kommer aldrig använda en typkonverteringsoperator"
 
-#: cp/decl.c:13455
+#: cp/decl.c:13479
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "användardefinierad %qD beräknar alltid båda argumenten"
 
-#: cp/decl.c:13474
+#: cp/decl.c:13498
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "prefix %qD skall returnera %qT"
 
-#: cp/decl.c:13480
+#: cp/decl.c:13504
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "postfix %qD skall returnera %qT"
 
-#: cp/decl.c:13492
+#: cp/decl.c:13516
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD skall returnera som värde"
 
-#: cp/decl.c:13547
+#: cp/decl.c:13571
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "malltypparametern %qT används efter %qs"
 
-#: cp/decl.c:13570
+#: cp/decl.c:13594
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "användning av aliasmallspecialisering %qT efter %qs"
 
-#: cp/decl.c:13573
+#: cp/decl.c:13597
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "typedef-namnet %qD används efter %qs"
 
-#: cp/decl.c:13575
+#: cp/decl.c:13599
 #, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "%qD har en tidigare deklaration här"
 
-#: cp/decl.c:13583
+#: cp/decl.c:13607
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "%qT refererad till som %qs"
 
-#: cp/decl.c:13584 cp/decl.c:13591
+#: cp/decl.c:13608 cp/decl.c:13615
 #, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr "%qT har en tidigare deklaration här"
 
-#: cp/decl.c:13590
+#: cp/decl.c:13614
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "%qT refererad till som enum"
@@ -42428,94 +42470,94 @@
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:13605
+#: cp/decl.c:13629
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "mallargument krävs för %<%s %T%>"
 
-#: cp/decl.c:13659 cp/name-lookup.c:4652
+#: cp/decl.c:13683 cp/name-lookup.c:4652
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD har samma namn som klassen den är deklarerad i"
 
-#: cp/decl.c:13689 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6425
-#: cp/pt.c:9209
+#: cp/decl.c:13713 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6428
+#: cp/pt.c:9223
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT är inte en mall"
 
-#: cp/decl.c:13694
+#: cp/decl.c:13718
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr "kanske du vill explicit lägga till %<%T::%>"
 
-#: cp/decl.c:13703 cp/name-lookup.c:4079 cp/name-lookup.c:4086
-#: cp/name-lookup.c:4939 cp/parser.c:6376 cp/parser.c:26300
+#: cp/decl.c:13727 cp/name-lookup.c:4079 cp/name-lookup.c:4086
+#: cp/name-lookup.c:4939 cp/parser.c:6379 cp/parser.c:26297
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "referens till %qD är tvetydig"
 
-#: cp/decl.c:13806
+#: cp/decl.c:13830
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "enum %q#D används utan tidigare deklaration"
 
-#: cp/decl.c:13842
+#: cp/decl.c:13866
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "omdeklaration av %qT som en icke-mall"
 
-#: cp/decl.c:13982
+#: cp/decl.c:14006
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "härledd unionen %qT ogiltig"
 
-#: cp/decl.c:13989
+#: cp/decl.c:14013
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr "%qT definierad med flera direkta baser"
 
-#: cp/decl.c:14000
+#: cp/decl.c:14024
 #, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr "%qT definerad med en direkt virtuell bas"
 
-#: cp/decl.c:14025
+#: cp/decl.c:14049
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "bastyp %qT är ingen post- eller klasstyp"
 
-#: cp/decl.c:14055
+#: cp/decl.c:14079
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "rekursiv typ %qT odefinierad"
 
-#: cp/decl.c:14057
+#: cp/decl.c:14081
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "upprepat bastyp %qT ogiltig"
 
-#: cp/decl.c:14202
+#: cp/decl.c:14226
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr "uppräkningstyp med/utan räckviddsbegränsning stämmer inte överens för enum %q#T"
 
-#: cp/decl.c:14205 cp/decl.c:14213 cp/decl.c:14225 cp/parser.c:18284
+#: cp/decl.c:14229 cp/decl.c:14237 cp/decl.c:14249 cp/parser.c:18281
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "tidigare definition här"
 
-#: cp/decl.c:14210
+#: cp/decl.c:14234
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr "underliggande typ stämmer inte överens i enum %q#T"
 
-#: cp/decl.c:14222
+#: cp/decl.c:14246
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr "olika underliggande typ i enum %q#T"
 
-#: cp/decl.c:14300
+#: cp/decl.c:14324
 #, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr "underliggande typ %qT till %qT måste vara en heltalstyp"
@@ -42524,77 +42566,77 @@
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:14447
+#: cp/decl.c:14471
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "ingen heltalstyp kan representera alla uppräkningsvärdena i %qT"
 
-#: cp/decl.c:14619
+#: cp/decl.c:14643
 #, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "uppräkningsvärde för %qD är inte en heltalstyp eller uppräkningstyp utan räckviddsbegränsning"
 
-#: cp/decl.c:14629
+#: cp/decl.c:14653
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "uppräkningsvärde för %qD är inte en heltalskonstant"
 
-#: cp/decl.c:14678
+#: cp/decl.c:14702
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "ökat uppräkningsvärde är för stort för %<unsigned long%>"
 
-#: cp/decl.c:14679
+#: cp/decl.c:14703
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "ökat uppräkningsvärde är för stort för %<long%>"
 
-#: cp/decl.c:14690
+#: cp/decl.c:14714
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "överspill i uppräkningsvärden vid %qD"
 
-#: cp/decl.c:14710
+#: cp/decl.c:14734
 #, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "uppräkningsvärdet %qE är utanför intervallet för den underliggande typen %qT"
 
-#: cp/decl.c:14821
+#: cp/decl.c:14845
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "returtypen %q#T är ofullständig"
 
-#: cp/decl.c:14999 cp/typeck.c:9286
+#: cp/decl.c:15023 cp/typeck.c:9286
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> skall returnera en referens till %<*this%>"
 
-#: cp/decl.c:15344
+#: cp/decl.c:15368
 #, gcc-internal-format
 msgid "invalid function declaration"
 msgstr "ogiltig funktionsdeklaration"
 
-#: cp/decl.c:15786
+#: cp/decl.c:15810
 #, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr "inga retursatser i funktion som returnerar %qT"
 
-#: cp/decl.c:15788 cp/typeck.c:9166
+#: cp/decl.c:15812 cp/typeck.c:9166
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "endast enkel returtyp %<auto%> kan härledas till %<void%>"
 
-#: cp/decl.c:15996
+#: cp/decl.c:16020
 #, gcc-internal-format
 msgid "invalid member function declaration"
 msgstr "ogiltig medlemsfunktionsdeklaration"
 
-#: cp/decl.c:16010
+#: cp/decl.c:16034
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD är redan definierad i klassen %qT"
 
-#: cp/decl.c:16386
+#: cp/decl.c:16410
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr "användning av %qD före härledning av %<auto%>"
@@ -42634,7 +42676,7 @@
 msgid "deleting %qT is undefined"
 msgstr "radera %qT är odefinierat"
 
-#: cp/decl2.c:585 cp/pt.c:5552
+#: cp/decl2.c:585 cp/pt.c:5566
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "malldeklaration av %q#D"
@@ -42647,7 +42689,7 @@
 #. [temp.mem]
 #.
 #. A destructor shall not be a member template.
-#: cp/decl2.c:640 cp/pt.c:5511
+#: cp/decl2.c:640 cp/pt.c:5525
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "destrueraren %qD deklarerad som medlemsmall"
@@ -42821,47 +42863,47 @@
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "%<operator delete%> tar typen %qT som första parameter"
 
-#: cp/decl2.c:2660
+#: cp/decl2.c:2650
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type has no linkage"
 msgstr "%qT har ett fält %qD vars typ inte har någon länkklass"
 
-#: cp/decl2.c:2664
+#: cp/decl2.c:2654
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr "%qT har ett fält %qD vars typ beror på typen %qT som inte har någon länkklass"
 
-#: cp/decl2.c:2669
+#: cp/decl2.c:2659
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr "%qT har ett fält %qD vars typ använder den anonyma namnrymden"
 
-#: cp/decl2.c:2677
+#: cp/decl2.c:2667
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr "%qT är deklarerad med större synlighet än typen för dess fält %qD"
 
-#: cp/decl2.c:2695
+#: cp/decl2.c:2685
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type has no linkage"
 msgstr "%qT har en bas %qT vars typ inte har någon länkklass"
 
-#: cp/decl2.c:2699
+#: cp/decl2.c:2689
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type depends on the type %qT which has no linkage"
 msgstr "%qT har en bas %qT vars typ beror på typen %qT som inte har någon länkklass"
 
-#: cp/decl2.c:2704
+#: cp/decl2.c:2694
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr "%qT har en bas %qT vars typ använder den anonyma namnrymden"
 
-#: cp/decl2.c:2711
+#: cp/decl2.c:2701
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr "%qT är deklarerad med större synlighet än sin bas %qT"
 
-#: cp/decl2.c:4309
+#: cp/decl2.c:4299
 #, gcc-internal-format
 msgid "%q#D, declared using unnamed type, is used but never defined"
 msgstr "%q#D, deklarerad med en namnlös typ, används men är aldrig definierad"
@@ -42870,62 +42912,62 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4318
+#: cp/decl2.c:4308
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr "namnlös typ utan länkklass används för att deklarera variabeln %q#D med länkklass"
 
-#: cp/decl2.c:4322
+#: cp/decl2.c:4312
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr "namnlös typ utan länkklass används för att deklarera funktionen %q#D med länkklass"
 
-#: cp/decl2.c:4326
+#: cp/decl2.c:4316
 #, gcc-internal-format
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr "%q#D refererar inte till den okvalificerade typen, så den används int för länkklass"
 
-#: cp/decl2.c:4334
+#: cp/decl2.c:4324
 #, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "%q#D, deklarerad med en lokal typ %qT, används men är aldrig definierad"
 
-#: cp/decl2.c:4338
+#: cp/decl2.c:4328
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr "typen %qT utan länkklass använd för att deklarera variabeln %q#D med länkklass"
 
-#: cp/decl2.c:4341
+#: cp/decl2.c:4331
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "typen %qT utan någon länkklass använd för att deklarera funktionen %q#D med länkklass"
 
-#: cp/decl2.c:4529
+#: cp/decl2.c:4519
 #, gcc-internal-format
 msgid "mangling of %q#D as %qE conflicts with a previous mangle"
 msgstr "mangling av %q#D som %qE står i konflikt med en tidigare mangling"
 
-#: cp/decl2.c:4532
+#: cp/decl2.c:4522
 #, gcc-internal-format
 msgid "previous mangling %q#D"
 msgstr "tidigare mangling %q#D"
 
-#: cp/decl2.c:4534
+#: cp/decl2.c:4524
 #, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr "en senare -fabi-version= (eller =0) undviker detta fel med en ändring av manglingen"
 
-#: cp/decl2.c:4606 cp/decl2.c:4609
+#: cp/decl2.c:4596 cp/decl2.c:4599
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr "programmet borde även definiera %qD"
 
-#: cp/decl2.c:4956
+#: cp/decl2.c:4946
 #, gcc-internal-format
 msgid "inline function %qD used but never defined"
 msgstr "inline-funktion %qD använd men aldrig definierad"
 
-#: cp/decl2.c:5143
+#: cp/decl2.c:5133
 #, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr "standardargumentet saknas för parameter %P till %q+#D"
@@ -42932,17 +42974,17 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5251
+#: cp/decl2.c:5241
 #, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr "konverterar lambda som använder %<...%> till funktionspekare"
 
-#: cp/decl2.c:5254
+#: cp/decl2.c:5244
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "användning av borttagen funktion %qD"
 
-#: cp/decl2.c:5307
+#: cp/decl2.c:5297
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr "användning av det inbyggda parameterpaketet %qD utanför en mall"
@@ -43228,333 +43270,333 @@
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr "rekursiv instansiering av standardmedleminitierare för %qD"
 
-#: cp/init.c:613
+#: cp/init.c:629
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr "standardmedlemsinitieraren för %qD behövs före slutet på dess omgivande klass"
 
-#: cp/init.c:615
+#: cp/init.c:631
 #, gcc-internal-format
 msgid "defined here"
 msgstr "definierad här"
 
-#: cp/init.c:673
+#: cp/init.c:689
 #, gcc-internal-format
 msgid "initializer for flexible array member %q#D"
 msgstr "initierare för flexibel vektormedlem %q#D"
 
-#: cp/init.c:699
+#: cp/init.c:715
 #, gcc-internal-format
 msgid "%qD should be initialized in the member initialization list"
 msgstr "%qD skall initieras i medlemsinitieringslistan"
 
-#: cp/init.c:720
+#: cp/init.c:736
 #, gcc-internal-format
 msgid "%qD is initialized with itself"
 msgstr "%qD initieras med sig själv"
 
-#: cp/init.c:831
+#: cp/init.c:847
 #, gcc-internal-format
 msgid "invalid initializer for array member %q#D"
 msgstr "ogiltig initierare för vektormedlem %q#D"
 
-#: cp/init.c:845 cp/init.c:869 cp/init.c:2410 cp/method.c:1368
+#: cp/init.c:861 cp/init.c:885 cp/init.c:2427 cp/method.c:1368
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr "oinitierad const-medlem i %q#T"
 
-#: cp/init.c:847 cp/init.c:864 cp/init.c:871 cp/init.c:2395 cp/init.c:2423
+#: cp/init.c:863 cp/init.c:880 cp/init.c:887 cp/init.c:2412 cp/init.c:2440
 #: cp/method.c:1371 cp/method.c:1382
 #, gcc-internal-format
 msgid "%q#D should be initialized"
 msgstr "%q#D borde initieras"
 
-#: cp/init.c:862 cp/init.c:2382 cp/method.c:1379
+#: cp/init.c:878 cp/init.c:2399 cp/method.c:1379
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr "oinitierad referensmedlem i %q#T"
 
-#: cp/init.c:1041
+#: cp/init.c:1057
 #, gcc-internal-format
 msgid "%qD will be initialized after"
 msgstr "%qD kommer initieras efter"
 
-#: cp/init.c:1044
+#: cp/init.c:1060
 #, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr "basen %qT kommer initieras efter"
 
-#: cp/init.c:1048
+#: cp/init.c:1064
 #, gcc-internal-format
 msgid "  %q#D"
 msgstr "  %q#D"
 
-#: cp/init.c:1050
+#: cp/init.c:1066
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr "  basen %qT"
 
-#: cp/init.c:1052
+#: cp/init.c:1068
 #, gcc-internal-format
 msgid "  when initialized here"
 msgstr "  vid initiering här"
 
-#: cp/init.c:1069
+#: cp/init.c:1085
 #, gcc-internal-format
 msgid "multiple initializations given for %qD"
 msgstr "flera initieringar givna för %qD"
 
-#: cp/init.c:1073
+#: cp/init.c:1089
 #, gcc-internal-format
 msgid "multiple initializations given for base %qT"
 msgstr "flera initieringar givna för basen %qT"
 
-#: cp/init.c:1158
+#: cp/init.c:1174
 #, gcc-internal-format
 msgid "initializations for multiple members of %qT"
 msgstr "initiering av flera medlemmar av %qT"
 
-#: cp/init.c:1255
+#: cp/init.c:1271
 #, gcc-internal-format
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr "basklass %q#T skulle varit explicit initierad i kopieringskonstrueraren"
 
-#: cp/init.c:1482 cp/init.c:1501
+#: cp/init.c:1498 cp/init.c:1517
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr "klass %qT har inget fält med namnet %qD"
 
-#: cp/init.c:1488
+#: cp/init.c:1504
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr "%q#D är en statisk datamedlem; den kan endast initieras vid sin definition"
 
-#: cp/init.c:1495
+#: cp/init.c:1511
 #, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr "%q#D är inte en icke-statisk datamedlem i %qT"
 
-#: cp/init.c:1534
+#: cp/init.c:1550
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr "namnlös initierare för %qT, som inte har några basklasser"
 
-#: cp/init.c:1542
+#: cp/init.c:1558
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr "namnlös initierare för %qT som använder multipelt arv"
 
-#: cp/init.c:1589
+#: cp/init.c:1605
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr "%qD är både en direkt bas och en indirekt virtuell bas"
 
-#: cp/init.c:1597
+#: cp/init.c:1613
 #, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr "typ %qT är inte en direkt eller virtuell bas till %qT"
 
-#: cp/init.c:1600
+#: cp/init.c:1616
 #, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr "typ %qT är inte en direkt bas till %qT"
 
-#: cp/init.c:1710 cp/init.c:4386 cp/typeck2.c:1175
+#: cp/init.c:1727 cp/init.c:4402 cp/typeck2.c:1175
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "vektorer måste initieras med en initierare inom klamrar"
 
-#: cp/init.c:2019 cp/semantics.c:3268
+#: cp/init.c:2036 cp/semantics.c:3271
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qT är inte en klasstyp"
 
-#: cp/init.c:2075
+#: cp/init.c:2092
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr "ofullständig typ %qT har inte medlem %qD"
 
-#: cp/init.c:2089
+#: cp/init.c:2106
 #, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr "ogiltigt pekare till bitfält %qD"
 
-#: cp/init.c:2175 cp/typeck.c:1893
+#: cp/init.c:2192 cp/typeck.c:1893
 #, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "ogiltig användning av icke-statisk medlemsfunktion %qD"
 
-#: cp/init.c:2182 cp/semantics.c:1835
+#: cp/init.c:2199 cp/semantics.c:1835
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "ogiltig användning av icke-statisk datamedlem %qD"
 
-#: cp/init.c:2379
+#: cp/init.c:2396
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr "oinitierad referensmedlem i %q#T använder %<new%> utan new-initierare"
 
-#: cp/init.c:2387
+#: cp/init.c:2404
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "oinitierad referensmedlem i basen %q#T till %q#T använder %<new%> utan new-initierare"
 
-#: cp/init.c:2391
+#: cp/init.c:2408
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr "oinitierad referensmedlem i basen %q#T till %q#T"
 
-#: cp/init.c:2407
+#: cp/init.c:2424
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr "oinitierad const-medlem i %q#T använder %<new%> utan new-initierare"
 
-#: cp/init.c:2415
+#: cp/init.c:2432
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "oinitierad const-medlem i basen %q#T till %q#T använder %<new%> utan new-initierare"
 
-#: cp/init.c:2419
+#: cp/init.c:2436
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr "oinitierad const-medlem i basen %q#T till %q#T"
 
-#: cp/init.c:2710
+#: cp/init.c:2727
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr "placerande new konstruerar ett objekt av typen %<%T [%wu]%> och storleken %qwu i en region av typen %qT och storleken %qwi"
 
-#: cp/init.c:2721
+#: cp/init.c:2738
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr "placerande new konstruerar en vektor av objekt av typen %qT och storleken %qwu i en region av typen %qT och storleken %qwi"
 
-#: cp/init.c:2732
+#: cp/init.c:2749
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr "placerande new konstruerar ett objekt av typen %qT och storleken %qwu i en region av typen %qT och storleken %qwi"
 
-#: cp/init.c:2880
+#: cp/init.c:2896
 #, gcc-internal-format
 msgid "integer overflow in array size"
 msgstr "heltalsspill i vektorstorlek"
 
-#: cp/init.c:2890
+#: cp/init.c:2906
 #, gcc-internal-format
 msgid "array size in new-expression must be constant"
 msgstr "vektorstorlek i new-uttryck måste vara en konstant"
 
-#: cp/init.c:2904
+#: cp/init.c:2920
 #, gcc-internal-format
 msgid "variably modified type not allowed in new-expression"
 msgstr "variabelt ändrad typ inte tillåten i new-uttryck"
 
-#: cp/init.c:2920
+#: cp/init.c:2936
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by typedef"
 msgstr "en ny längd för en icke-konstant vektor måste anges direkt, inte av en typedef"
 
-#: cp/init.c:2922
+#: cp/init.c:2938
 #, gcc-internal-format
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr "new-längden för en icke-konstant vektor måste anges utan parenteserna runt typ-id:t"
 
-#: cp/init.c:2932
+#: cp/init.c:2948
 #, gcc-internal-format
 msgid "invalid type %<void%> for new"
 msgstr "ogiltig typ %<void%> för new"
 
-#: cp/init.c:2975
+#: cp/init.c:2991
 #, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr "oinitierad const i %<new%> av %q#T"
 
-#: cp/init.c:3101
+#: cp/init.c:3117
 #, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr "ingen lämplig %qD i klassen %qT"
 
-#: cp/init.c:3108 cp/search.c:1023
+#: cp/init.c:3124 cp/search.c:1026
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "begäran av medlem %qD är tvetydig"
 
-#: cp/init.c:3181
+#: cp/init.c:3197
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr "%<new%> av typ %qT med utökad justering %d"
 
-#: cp/init.c:3184
+#: cp/init.c:3200
 #, gcc-internal-format
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr "använder %qD, som inte har någon justeringsparameter"
 
-#: cp/init.c:3187
+#: cp/init.c:3203
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr "använd %<-faligned-new%> för att aktivera stöd för C++17 överjusterade new"
 
-#: cp/init.c:3370
+#: cp/init.c:3386
 #, gcc-internal-format
 msgid "parenthesized initializer in array new"
 msgstr "initierare inom parentes i vektor-new"
 
-#: cp/init.c:3633
+#: cp/init.c:3649
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr "storlek i vektor-new måste ha heltalstyp"
 
-#: cp/init.c:3665
+#: cp/init.c:3681
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr "new kan inte användas på en referenstyp"
 
-#: cp/init.c:3674
+#: cp/init.c:3690
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr "new kan inte användas på en funktionstyp"
 
-#: cp/init.c:3743
+#: cp/init.c:3759
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete [] operator:"
 msgstr "möjligt problem upptäckt vid anrop av operatorn delete []:"
 
-#: cp/init.c:3747
+#: cp/init.c:3763
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete [] will be called, even if they are declared when the class is defined"
 msgstr "varken destrueraren eller den klasspecifika operatorn delete [] kommer anropas, även om de är deklarerade när klassen definieras"
 
-#: cp/init.c:4295
+#: cp/init.c:4311
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "initierare tar slut i förtid"
 
-#: cp/init.c:4599
+#: cp/init.c:4615
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr "okänd vektorstorlek i delete"
 
-#: cp/init.c:4623
+#: cp/init.c:4639
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete operator:"
 msgstr "möjligt problem upptäckt vid anrop av operatorn delete:"
 
-#: cp/init.c:4628
+#: cp/init.c:4644
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
 msgstr "varken destrueraren eller den klasspecifika operatorn delete kommer anropas, även om de är deklarerade när klassen definieras"
 
-#: cp/init.c:4642
+#: cp/init.c:4658
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr "radering av objekt av den abstrakta klasstypen %qT som har en ej virtuell destruerare kommer medföra odefinierat beteende"
 
-#: cp/init.c:4647
+#: cp/init.c:4663
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr "radering av objekt av den polymorfa klasstypen %qT som har en ej virtuell destruerare kommer medföra odefinierat beteende"
 
-#: cp/init.c:4954
+#: cp/init.c:4970
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "typ till vektor-delete är varken pekar- eller vektortyp"
@@ -44026,7 +44068,7 @@
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "ignorerar attributet %qD på en namnrymd som inte är inline"
 
-#: cp/name-lookup.c:5111 cp/name-lookup.c:7065
+#: cp/name-lookup.c:5111 cp/name-lookup.c:7073
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "attributdirektivet %qD ignorerat"
@@ -44073,53 +44115,53 @@
 msgid "it was later defined here"
 msgstr "det definierades senare här"
 
-#: cp/name-lookup.c:6687
+#: cp/name-lookup.c:6695
 #, gcc-internal-format
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn't a template"
 msgstr "definitionen av %<std::initializer_list%> matchar inte %<#include <initializer_list>%>, är inte en mall"
 
-#: cp/name-lookup.c:7059
+#: cp/name-lookup.c:7067
 #, gcc-internal-format
 msgid "strong using directive no longer supported"
 msgstr "direktivet strong using stödjs inte längre"
 
-#: cp/name-lookup.c:7062
+#: cp/name-lookup.c:7070
 #, gcc-internal-format
 msgid "you may use an inline namespace instead"
 msgstr "du kan använda inline-namnrymder istället"
 
-#: cp/name-lookup.c:7079
+#: cp/name-lookup.c:7087
 #, gcc-internal-format
 msgid "attributes ignored on local using directive"
 msgstr "attributet ignorerat på lokalt using-direktiv"
 
-#: cp/name-lookup.c:7163
+#: cp/name-lookup.c:7171
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "namnrymdsalias %qD inte tillåtet här, antar %qD"
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:7183
+#: cp/name-lookup.c:7191
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot nest more than %d namespaces"
 msgstr "det går inte att nästa mer än %d namnrymder"
 
-#: cp/name-lookup.c:7218
+#: cp/name-lookup.c:7226
 #, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr "inline-namnrymder måste anges vid den ursprungliga definitionen"
 
-#: cp/name-lookup.c:7219
+#: cp/name-lookup.c:7227
 #, gcc-internal-format
 msgid "%qD defined here"
 msgstr "%qD definierades här"
 
-#: cp/name-lookup.c:7292
+#: cp/name-lookup.c:7300
 #, gcc-internal-format
 msgid "XXX entering pop_everything ()\n"
 msgstr "XXX går in i pop_everything ()\n"
 
-#: cp/name-lookup.c:7301
+#: cp/name-lookup.c:7309
 #, gcc-internal-format
 msgid "XXX leaving pop_everything ()\n"
 msgstr "XXX lämnar pop_everything ()\n"
@@ -44139,7 +44181,7 @@
 msgid "LEXER_DEBUGGING_ENABLED_P is not set to true"
 msgstr "LEXER_DEBUGGING_ENABLED_P är inte satt till true"
 
-#: cp/parser.c:1352 cp/parser.c:37254
+#: cp/parser.c:1352 cp/parser.c:37251
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr "%<#pragma omp declare simd%> som inte omedelbart följs av en funktionsdeklaration eller -definition"
@@ -44164,7 +44206,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr "begäran av medlem %qE i typ %qT som inte är en klasstyp"
 
-#: cp/parser.c:2949 cp/parser.c:18221
+#: cp/parser.c:2949 cp/parser.c:18218
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "%<%T::%E%> har inte deklarerats"
@@ -44244,7 +44286,7 @@
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "ISO C++ förbjuder användning av en flyttalslitteral i ett konstantuttryck"
 
-#: cp/parser.c:3143 cp/pt.c:17853
+#: cp/parser.c:3143 cp/pt.c:17890
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr "en typomvandling till en annan typ än en heltals- eller uppräkningstyp kan inte förekomma i ett konstantuttryck"
@@ -44466,7 +44508,7 @@
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr "kan inte hitta en stränglitteraloperator %qD med argumenten %qT, %qT"
 
-#: cp/parser.c:4587 cp/parser.c:12940
+#: cp/parser.c:4587 cp/parser.c:12937
 #, gcc-internal-format
 msgid "expected declaration"
 msgstr "en deklaration förväntades"
@@ -44516,7 +44558,7 @@
 msgid "fold-expressions only available with -std=c++17 or -std=gnu++17"
 msgstr "vikningsuttryck är endast tillgängliga med -std=c++17 eller -std=gnu++17"
 
-#: cp/parser.c:5275 cp/parser.c:5452 cp/parser.c:5630 cp/semantics.c:3612
+#: cp/parser.c:5275 cp/parser.c:5452 cp/parser.c:5633 cp/semantics.c:3615
 #, gcc-internal-format
 msgid "expected primary-expression"
 msgstr "primäruttryck förväntades"
@@ -44536,92 +44578,92 @@
 msgid "local variable %qD may not appear in this context"
 msgstr "lokal variabel %qD får inte förekomma i detta sammanhang"
 
-#: cp/parser.c:5787
+#: cp/parser.c:5790
 #, gcc-internal-format
 msgid "expected id-expression"
 msgstr "id-uttryck förväntades"
 
-#: cp/parser.c:5919
+#: cp/parser.c:5922
 #, gcc-internal-format
 msgid "scope %qT before %<~%> is not a class-name"
 msgstr "räckvidd %qT före %<~%> är inte ett klassnamn"
 
-#: cp/parser.c:5948 cp/parser.c:7860
+#: cp/parser.c:5951 cp/parser.c:7860
 #, gcc-internal-format
 msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgstr "%<~auto%> är endast tillgängligt med -std=c++14 eller -std=gnu++14"
 
-#: cp/parser.c:6059
+#: cp/parser.c:6062
 #, gcc-internal-format
 msgid "declaration of %<~%T%> as member of %qT"
 msgstr "deklaration av %<~%T%> som medlem av %qT"
 
-#: cp/parser.c:6074
+#: cp/parser.c:6077
 #, gcc-internal-format
 msgid "typedef-name %qD used as destructor declarator"
 msgstr "typedef-namnet %qD använt som destruerardeklarerare"
 
-#: cp/parser.c:6111 cp/parser.c:20249
+#: cp/parser.c:6114 cp/parser.c:20246
 #, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr "okvalificerat id förväntades"
 
-#: cp/parser.c:6220
+#: cp/parser.c:6223
 #, gcc-internal-format
 msgid "found %<:%> in nested-name-specifier, expected %<::%>"
 msgstr "%<:%> hittades i kapslad namnspecifikation, %<::%> förväntades"
 
-#: cp/parser.c:6288
+#: cp/parser.c:6291
 #, gcc-internal-format
 msgid "decltype evaluates to %qT, which is not a class or enumeration type"
 msgstr "decltype beräknas till %qT, som inte är en klass eller uppräkningstyp"
 
-#: cp/parser.c:6314
+#: cp/parser.c:6317
 #, gcc-internal-format
 msgid "function template-id %qD in nested-name-specifier"
 msgstr "funktionsmalls-id %qD i nästad namnspecificerare"
 
-#: cp/parser.c:6322
+#: cp/parser.c:6325
 #, gcc-internal-format
 msgid "variable template-id %qD in nested-name-specifier"
 msgstr "variabelmall-id %qD  i nästad namnspecificerare"
 
-#: cp/parser.c:6426 cp/typeck.c:2684 cp/typeck.c:2687 cp/typeck.c:2704
+#: cp/parser.c:6429 cp/typeck.c:2684 cp/typeck.c:2687 cp/typeck.c:2704
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD är inte en mall"
 
-#: cp/parser.c:6504
+#: cp/parser.c:6507
 #, gcc-internal-format
 msgid "expected nested-name-specifier"
 msgstr "nästat namn-specificerare förväntades"
 
-#: cp/parser.c:6711 cp/parser.c:8950
+#: cp/parser.c:6714 cp/parser.c:8950
 #, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr "typer får inte definieras i typkonverteringar"
 
-#: cp/parser.c:6797
+#: cp/parser.c:6800
 #, gcc-internal-format
 msgid "types may not be defined in a %<typeid%> expression"
 msgstr "typer får inte definieras i ett %<typeid%>-uttryck"
 
-#: cp/parser.c:6889
+#: cp/parser.c:6892
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "fel antal argument till %<__builtin_addressof%>"
 
-#: cp/parser.c:6901 cp/pt.c:18416
+#: cp/parser.c:6904 cp/pt.c:18453
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "fel antal argument till %<__builtin_launder%>"
 
-#: cp/parser.c:6995
+#: cp/parser.c:6998
 #, gcc-internal-format
 msgid "ISO C++ forbids compound-literals"
 msgstr "ISO C++ förbjuder sammansatta litteraler"
 
-#: cp/parser.c:7054
+#: cp/parser.c:7057
 #, gcc-internal-format
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr "två på varandra följande %<[%> får bara introducera ett attribut"
@@ -44751,7 +44793,7 @@
 msgid "capture of non-variable %qE"
 msgstr "fångst av en icke-variabel %qE"
 
-#: cp/parser.c:10391 cp/parser.c:10401 cp/semantics.c:3453 cp/semantics.c:3465
+#: cp/parser.c:10391 cp/parser.c:10401 cp/semantics.c:3456 cp/semantics.c:3468
 #, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "%q#D är deklarerad här"
@@ -44836,7 +44878,7 @@
 msgid "init-statement in selection statements only available with -std=c++17 or -std=gnu++17"
 msgstr "init-satsen i valsatser är endast tillgängliga med -std=c++17 eller -std=gnu++17"
 
-#: cp/parser.c:11546 cp/parser.c:28490
+#: cp/parser.c:11546 cp/parser.c:28487
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "selektionssats förväntades"
@@ -44856,557 +44898,557 @@
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr "inkonsistenta start-/sluttyper i intervallbaserat %<for%>-sats: %qT och %qT"
 
-#: cp/parser.c:12250 cp/parser.c:28493
+#: cp/parser.c:12250 cp/parser.c:28490
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "iterationssats förväntades"
 
-#: cp/parser.c:12298
+#: cp/parser.c:12297
 #, gcc-internal-format
 msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
 msgstr "intervallbaserad %<for%>-slinga är endast tillgänglig med -std=c++11 eller -std=gnu++11"
 
-#: cp/parser.c:12426
+#: cp/parser.c:12423
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr "%<goto%> i %<constexpr%>-funktion"
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:12434
+#: cp/parser.c:12431
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ förbjuder beräknade goto"
 
-#: cp/parser.c:12447 cp/parser.c:28496
+#: cp/parser.c:12444 cp/parser.c:28493
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "hoppsats förväntades"
 
-#: cp/parser.c:12620 cp/parser.c:23584
+#: cp/parser.c:12617 cp/parser.c:23581
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "extra %<;%>"
 
-#: cp/parser.c:12863
+#: cp/parser.c:12860
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr "%<__label__%> som inte inleder ett block"
 
-#: cp/parser.c:13083
+#: cp/parser.c:13080
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr "icke-variabel %qD i deklaration med mer än en deklarerare med platshållartyp"
 
-#: cp/parser.c:13103
+#: cp/parser.c:13100
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr "inkonsistent härledning för %qT: %qT och sedan %qT"
 
-#: cp/parser.c:13124
+#: cp/parser.c:13121
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr "att blanda deklarationer och funktionsdefinitioner är förbjudet"
 
-#: cp/parser.c:13148
+#: cp/parser.c:13145
 #, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr "typer får inte definieras i en for-range-deklaration"
 
-#: cp/parser.c:13203
+#: cp/parser.c:13200
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr "initierare i intervallbaserad %<for%>-slinga"
 
-#: cp/parser.c:13206
+#: cp/parser.c:13203
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr "flera deklarationer i intervallbaserad %<for%>-slinga"
 
-#: cp/parser.c:13257
+#: cp/parser.c:13254
 #, gcc-internal-format
 msgid "structured bindings only available with -std=c++17 or -std=gnu++17"
 msgstr "strukturerade bindningar är endast tillgängliga med -std=c++17 eller -std=gnu++17"
 
-#: cp/parser.c:13306
+#: cp/parser.c:13303
 #, gcc-internal-format
 msgid "empty structured binding declaration"
 msgstr "tom deklaration av strukturerad bindning"
 
-#: cp/parser.c:13324
+#: cp/parser.c:13321
 #, gcc-internal-format
 msgid "invalid initializer for structured binding declaration"
 msgstr "ogiltig initierare för deklaration av strukturerad bindning"
 
-#: cp/parser.c:13491
+#: cp/parser.c:13488
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr "%<friend%> använd utanför en klass"
 
-#: cp/parser.c:13558
+#: cp/parser.c:13555
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr "%<auto%> ändrar betydelse i C++11; var god ta bort det"
 
-#: cp/parser.c:13594
+#: cp/parser.c:13591
 #, gcc-internal-format
 msgid "decl-specifier invalid in condition"
 msgstr "decl-specificerare är ogiltig i villkor"
 
-#: cp/parser.c:13600
+#: cp/parser.c:13597
 #, gcc-internal-format
 msgid "%qD invalid in lambda"
 msgstr "%qD är ogiltigt i lambda"
 
-#: cp/parser.c:13693
+#: cp/parser.c:13690
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "klassdefinition kan inte deklareras som en vän"
 
-#: cp/parser.c:13763 cp/parser.c:24064
+#: cp/parser.c:13760 cp/parser.c:24061
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr "mallar får inte vara %<virtual%>"
 
-#: cp/parser.c:13805
+#: cp/parser.c:13802
 #, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr "ogiltig länkklasspecifikation"
 
-#: cp/parser.c:13909
+#: cp/parser.c:13906
 #, gcc-internal-format
 msgid "static_assert without a message only available with -std=c++17 or -std=gnu++17"
 msgstr "static_assert utan ett meddelande är endast tillgänglig med -std=c++17 eller -std=gnu++17"
 
-#: cp/parser.c:14111
+#: cp/parser.c:14108
 #, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr "typer får inte definieras i %<decltype%>-uttryck"
 
-#: cp/parser.c:14264
+#: cp/parser.c:14261
 #, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr "typer får inte definieras i en conversion-type-id"
 
-#: cp/parser.c:14291
+#: cp/parser.c:14288
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "ogiltig användning av %<auto%> i konverteringsoperator"
 
-#: cp/parser.c:14295
+#: cp/parser.c:14292
 #, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr "användning av %<auto%> i medlemsmallskonverteringsoperator kan aldrig vara härledd"
 
-#: cp/parser.c:14379
+#: cp/parser.c:14376
 #, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr "endast konstruerare tar medlemsinitierare"
 
-#: cp/parser.c:14406
+#: cp/parser.c:14403
 #, gcc-internal-format
 msgid "cannot expand initializer for member %qD"
 msgstr "det går inte att expandera initierare för medlem %qD"
 
-#: cp/parser.c:14418 cp/pt.c:24255
+#: cp/parser.c:14415 cp/pt.c:24333
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "minnesinitierare för %qD följer en konstruerardelegering"
 
-#: cp/parser.c:14430 cp/pt.c:24267
+#: cp/parser.c:14427 cp/pt.c:24345
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr "konstruerardelegering följer mem-initierare för %qD"
 
-#: cp/parser.c:14482
+#: cp/parser.c:14479
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr "anakronistisk gammaldags basklassinitierare"
 
-#: cp/parser.c:14552
+#: cp/parser.c:14549
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr "nyckelordet %<typename%> är inte tillåtet i detta sammanhang (en kvalificerad medlemsinitierare är implicit en typ)"
 
-#: cp/parser.c:14927
+#: cp/parser.c:14924
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr "oväntat nyckelord; ta bort mellanrum mellan citationstecken och suffixidentifierare"
 
-#: cp/parser.c:14933
+#: cp/parser.c:14930
 #, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr "suffixidentifierare förväntades"
 
-#: cp/parser.c:14942
+#: cp/parser.c:14939
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr "en tom sträng förväntades efter nyckelordet %<operator%>"
 
-#: cp/parser.c:14948
+#: cp/parser.c:14945
 #, gcc-internal-format
 msgid "invalid encoding prefix in literal operator"
 msgstr "ogiltigt kodningsprefix i litteral operator"
 
-#: cp/parser.c:14975
+#: cp/parser.c:14972
 #, gcc-internal-format
 msgid "expected operator"
 msgstr "operator förväntades"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:15020
+#: cp/parser.c:15017
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "nyckelordet %<export%> är inte implementerat och kommer ignoreras"
 
-#: cp/parser.c:15190
+#: cp/parser.c:15187
 #, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr "ogiltig begränsad typparameter"
 
-#: cp/parser.c:15198
+#: cp/parser.c:15195
 #, gcc-internal-format
 msgid "cv-qualified type parameter"
 msgstr "cv-kvalificerad typparameter"
 
-#: cp/parser.c:15283
+#: cp/parser.c:15280
 #, gcc-internal-format
 msgid "variadic constraint introduced without %<...%>"
 msgstr "variadisk begränsning introducerad utan %<...%>"
 
-#: cp/parser.c:15347
+#: cp/parser.c:15344
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "felaktig användning av %<auto%> i standardmallargument"
 
-#: cp/parser.c:15582 cp/parser.c:15668 cp/parser.c:21694
+#: cp/parser.c:15579 cp/parser.c:15665 cp/parser.c:21691
 #, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "mallparameterpaket %qD kan inte ha ett standardargument"
 
-#: cp/parser.c:15586 cp/parser.c:15672
+#: cp/parser.c:15583 cp/parser.c:15669
 #, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr "mallparameterpaket kan inte ha standardargument"
 
-#: cp/parser.c:15738
+#: cp/parser.c:15735
 #, gcc-internal-format
 msgid "expected template-id"
 msgstr "mall-id förväntades"
 
-#: cp/parser.c:15798
+#: cp/parser.c:15795
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "%<<::%> kan inte inleda en argumentlista till en mall"
 
-#: cp/parser.c:15802
+#: cp/parser.c:15799
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr "%<<:%> är en alternativ stavning av %<[%>.  Lägg in mellanrum mellan %<<%> och %<::%>"
 
-#: cp/parser.c:15806
+#: cp/parser.c:15803
 #, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr "(om du använder %<-fpermissive%> eller %<-std=c++11%> eller %<-std=gnu++11%> kommer G++ acceptera din kod)"
 
-#: cp/parser.c:15924
+#: cp/parser.c:15921
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "parsningsfel i mallargumentlista"
 
 #. The name does not name a template.
-#: cp/parser.c:15992 cp/parser.c:16122 cp/parser.c:16337
+#: cp/parser.c:15989 cp/parser.c:16119 cp/parser.c:16334
 #, gcc-internal-format
 msgid "expected template-name"
 msgstr "mallnamn förväntades"
 
 #. Explain what went wrong.
-#: cp/parser.c:16038
+#: cp/parser.c:16035
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr "icke-mall %qD använd som mall"
 
-#: cp/parser.c:16040
+#: cp/parser.c:16037
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr "använd %<%T::template %D%> för att indikera att det är en mall"
 
-#: cp/parser.c:16189
+#: cp/parser.c:16186
 #, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr "parameterpaket förväntades före %<...%>"
 
-#: cp/parser.c:16298 cp/parser.c:16316 cp/parser.c:16483
+#: cp/parser.c:16295 cp/parser.c:16313 cp/parser.c:16480
 #, gcc-internal-format
 msgid "expected template-argument"
 msgstr "mallargument förväntades"
 
-#: cp/parser.c:16458
+#: cp/parser.c:16455
 #, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr "ogiltigt mallargument som inte är en typ"
 
-#: cp/parser.c:16585
+#: cp/parser.c:16582
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "en explicit instansiering skall inte använda %<inline%>-specificerare"
 
-#: cp/parser.c:16589
+#: cp/parser.c:16586
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "en explicit instansiering skall inte använda %<constexpr%>-specificerare"
 
-#: cp/parser.c:16648
+#: cp/parser.c:16645
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr "mallspecialisering med C-länkning"
 
-#: cp/parser.c:16869
+#: cp/parser.c:16866
 #, gcc-internal-format
 msgid "expected type specifier"
 msgstr "typspecificerare förväntades"
 
-#: cp/parser.c:17053
+#: cp/parser.c:17050
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "användning av %<auto%> i lambdaparameterdeklarationer är endast tillgängligt med -std=c++14 eller -std=gnu++14"
 
-#: cp/parser.c:17059
+#: cp/parser.c:17056
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "användning av %<auto%> i parameterdeklarationer är endast tillgängligt med -std=c++14 eller -std=gnu++14"
 
-#: cp/parser.c:17064
+#: cp/parser.c:17061
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -fconcepts"
 msgstr "användning av %<auto%> i parameterdeklarationer är endast tillgängligt med -fconcepts"
 
-#: cp/parser.c:17209
+#: cp/parser.c:17206
 #, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "mall-id för typ förväntades"
 
-#: cp/parser.c:17278
+#: cp/parser.c:17275
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr "typnamn förväntades"
 
-#: cp/parser.c:17631
+#: cp/parser.c:17628
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr "beräknad typspecifikation för en enum med räckvidd får inte använda nyckelordet %qD"
 
-#: cp/parser.c:17854
+#: cp/parser.c:17851
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "deklaration %qD deklarerar inte något"
 
-#: cp/parser.c:17942
+#: cp/parser.c:17939
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "attributet ignorerat på oinstansierad typ"
 
-#: cp/parser.c:17946
+#: cp/parser.c:17943
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "attribut ignoreras vid mallinstansiering"
 
-#: cp/parser.c:17951
+#: cp/parser.c:17948
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr "attribut ignoreras för bearbetade typspecificerare som inte är en framåtdeklaration"
 
-#: cp/parser.c:18085
+#: cp/parser.c:18082
 #, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "%qD är en uppräkningsmall"
 
-#: cp/parser.c:18096
+#: cp/parser.c:18093
 #, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr "%qD är inte namnet på en uppräkningstyp i %qT"
 
-#: cp/parser.c:18111
+#: cp/parser.c:18108
 #, gcc-internal-format
 msgid "unnamed scoped enum is not allowed"
 msgstr "namnlös enum med räckvidd är inte tillåtet"
 
-#: cp/parser.c:18166
+#: cp/parser.c:18163
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "%<;%> eller %<{%> förväntades"
 
-#: cp/parser.c:18215
+#: cp/parser.c:18212
 #, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "det går inte att lägga till en uppräkningslista till en mallinstansiering"
 
-#: cp/parser.c:18229
+#: cp/parser.c:18226
 #, gcc-internal-format
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "nästad namnspecificerare %qT för enum-deklaration som inte namnger en klass eller namnrymd"
 
-#: cp/parser.c:18241 cp/parser.c:23070
+#: cp/parser.c:18238 cp/parser.c:23067
 #, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "deklaration av %qD i namnrymd %qD som inte innesluter %qD"
 
-#: cp/parser.c:18246 cp/parser.c:23075
+#: cp/parser.c:18243 cp/parser.c:23072
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "deklaration av %qD i %qD som inte innesluter %qD"
 
-#: cp/parser.c:18258 cp/parser.c:23089
+#: cp/parser.c:18255 cp/parser.c:23086
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr "extra kvalifikation inte tillåten"
 
-#: cp/parser.c:18282
+#: cp/parser.c:18279
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "fler definitioner av %q#T"
 
-#: cp/parser.c:18295
+#: cp/parser.c:18292
 #, gcc-internal-format
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO C++ förbjuder tomma namnlösa enum"
 
-#: cp/parser.c:18315
+#: cp/parser.c:18312
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr "ogenomskinlig enum-specifikation utan namn"
 
-#: cp/parser.c:18318
+#: cp/parser.c:18315
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr "en ogenomskinlig enum-specifikation måste använda en enkel identifierare"
 
-#: cp/parser.c:18497
+#: cp/parser.c:18494
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD är inte ett namnrymdsnamn"
 
-#: cp/parser.c:18503
+#: cp/parser.c:18500
 #, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "namnrymdsnamn förväntades"
 
-#: cp/parser.c:18570
+#: cp/parser.c:18567
 #, gcc-internal-format
 msgid "nested namespace definitions only available with -std=c++17 or -std=gnu++17"
 msgstr "nästade namnrymdsdefinitioner är endast tillgängliga med -std=c++17 eller -std=gnu++17"
 
-#: cp/parser.c:18578
+#: cp/parser.c:18575
 #, gcc-internal-format
 msgid "nested namespace name required"
 msgstr "nästat namnrymdsnamn krävs"
 
-#: cp/parser.c:18583
+#: cp/parser.c:18580
 #, gcc-internal-format
 msgid "namespace name required"
 msgstr "namnrymdsnamn krävs"
 
-#: cp/parser.c:18587
+#: cp/parser.c:18584
 #, gcc-internal-format
 msgid "a nested namespace definition cannot have attributes"
 msgstr "en nästad namnrymdsdefinition kan inte ha attribut"
 
-#: cp/parser.c:18590
+#: cp/parser.c:18587
 #, gcc-internal-format
 msgid "a nested namespace definition cannot be inline"
 msgstr "en nästad namnrymdsdefinition kan inte inline:as"
 
-#: cp/parser.c:18597
+#: cp/parser.c:18594
 #, gcc-internal-format
 msgid "namespace %qD entered"
 msgstr "gick in i namnrymden %qD"
 
-#: cp/parser.c:18652
+#: cp/parser.c:18649
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "%<namespace%>-definition är inte tillåten här"
 
-#: cp/parser.c:18803
+#: cp/parser.c:18800
 #, gcc-internal-format
 msgid "pack expansion in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr "paketexpansion i using-deklaration är endast tillgängligt med -std=c++17 eller -std=gnu++17"
 
-#: cp/parser.c:18818
+#: cp/parser.c:18815
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "ett mall-id får inte förekomma i en using-deklaration"
 
-#: cp/parser.c:18865
+#: cp/parser.c:18862
 #, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr "en kommaseparerad lista i using-deklaration är endast tillgängligt med -std=c++17 eller -std=gnu++17"
 
-#: cp/parser.c:18875
+#: cp/parser.c:18872
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr "åtkomstdeklarationer bör undvikas till förmån för using-deklarationer; förslag: lägg till nyckelordet %<using%>"
 
-#: cp/parser.c:18940
+#: cp/parser.c:18937
 #, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "typer får inte definieras i aliasmalldeklarationer"
 
-#: cp/parser.c:19106
+#: cp/parser.c:19103
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr "%<asm%> i %<constexpr%>-funktion"
 
-#: cp/parser.c:19493
+#: cp/parser.c:19490
 #, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "en funktionsdefinition är inte tillåten här"
 
-#: cp/parser.c:19504
+#: cp/parser.c:19501
 #, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr "en asm-specifikation är inte tillåten på en funktionsdefinition"
 
-#: cp/parser.c:19508
+#: cp/parser.c:19505
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "attribut är inte tillåtna vid en funktionsdefinition"
 
-#: cp/parser.c:19559
+#: cp/parser.c:19556
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr "konstruerare, destruerare eller typkonvertering förväntades"
 
 #. Anything else is an error.
-#: cp/parser.c:19598 cp/parser.c:21906
+#: cp/parser.c:19595 cp/parser.c:21903
 #, gcc-internal-format
 msgid "expected initializer"
 msgstr "initierare förväntades"
 
-#: cp/parser.c:19679
+#: cp/parser.c:19676
 #, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "initierare angiven för funktion"
 
-#: cp/parser.c:19713
+#: cp/parser.c:19710
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "attribut efter initierare inom parentes ignoreras"
 
-#: cp/parser.c:19727
+#: cp/parser.c:19724
 #, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr "icke-funktionen %qD deklarerad som implicit mall"
 
-#: cp/parser.c:20169
+#: cp/parser.c:20166
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "vektorgräns är inte en heltalskonstant"
 
-#: cp/parser.c:20295
+#: cp/parser.c:20292
 #, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr "det går inte att definiera medlem av beroende typedef %qT"
 
-#: cp/parser.c:20299
+#: cp/parser.c:20296
 #, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "%<%T::%E%> är inte en typ"
@@ -45415,17 +45457,17 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:20328
+#: cp/parser.c:20325
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr "ogiltig deklarator"
 
-#: cp/parser.c:20336
+#: cp/parser.c:20333
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "ogiltig användning av konstruerare som en mall"
 
-#: cp/parser.c:20338
+#: cp/parser.c:20335
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr "använd %<%T::%D%> istället för %<%T::%D%> för att namnge konstrueraren i ett kvalificerat namn"
@@ -45432,382 +45474,382 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:20410
+#: cp/parser.c:20407
 #, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr "kvalificerad id i deklaration"
 
-#: cp/parser.c:20435
+#: cp/parser.c:20432
 #, gcc-internal-format
 msgid "expected declarator"
 msgstr "deklarator förväntades"
 
-#: cp/parser.c:20554
+#: cp/parser.c:20551
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD är en namnrymd"
 
-#: cp/parser.c:20556
+#: cp/parser.c:20553
 #, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "kan inte skapa en pekare till medlem av %q#T som inte är en klass"
 
-#: cp/parser.c:20577
+#: cp/parser.c:20574
 #, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "oväntad pekaroperator"
 
-#: cp/parser.c:20638
+#: cp/parser.c:20635
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "upprepade cv-kvalificerare"
 
-#: cp/parser.c:20692
+#: cp/parser.c:20689
 #, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr "upprepade ref-kvalificerare"
 
-#: cp/parser.c:20729
+#: cp/parser.c:20726
 #, gcc-internal-format
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr "%qE kräver %<-fgnu-tm%>"
 
-#: cp/parser.c:20787
+#: cp/parser.c:20784
 #, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "upprepade virt-specificerare"
 
-#: cp/parser.c:21025
+#: cp/parser.c:21022
 #, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr "mallargument saknas efter %qT"
 
-#: cp/parser.c:21031 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2090
+#: cp/parser.c:21028 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2093
 #, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr "ogiltigt användning av %qT"
 
-#: cp/parser.c:21052
+#: cp/parser.c:21049
 #, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "typer får inte definieras i mallargument"
 
-#: cp/parser.c:21057
+#: cp/parser.c:21054
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "felaktig användning av %<auto%> i mallargument"
 
-#: cp/parser.c:21145
+#: cp/parser.c:21142
 #, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "typspecificerare förväntades"
 
-#: cp/parser.c:21429
+#: cp/parser.c:21426
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "%<,%> eller %<...%> förväntades"
 
-#: cp/parser.c:21504
+#: cp/parser.c:21501
 #, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr "typer får inte definieras i parametertyper"
 
-#: cp/parser.c:21678
+#: cp/parser.c:21675
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "standardargument är endast tillåtna för funktionsparametrar"
 
-#: cp/parser.c:21696
+#: cp/parser.c:21693
 #, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "parameterpaket %qD kan inte ha ett standardargument"
 
-#: cp/parser.c:21702
+#: cp/parser.c:21699
 #, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr "mallparameterpaket kan inte ha ett standardargument"
 
-#: cp/parser.c:21704
+#: cp/parser.c:21701
 #, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr "parameterpaket kan inte ha ett standardargument"
 
-#: cp/parser.c:22131
+#: cp/parser.c:22128
 #, gcc-internal-format
 msgid "C++ designated initializers only available with -std=c++2a or -std=gnu++2a"
 msgstr "C++ designerade initierare är endast tillgängliga med -std=c++2a eller -std=gnu++2a"
 
-#: cp/parser.c:22151
+#: cp/parser.c:22148
 #, gcc-internal-format
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr "ISO C++ tillåter inte GNUs designerade initierare"
 
-#: cp/parser.c:22189
+#: cp/parser.c:22186
 #, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C++ tillåter inte C99:s designerade initierare"
 
-#: cp/parser.c:22203
+#: cp/parser.c:22200
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr "antingen skall alla initierarklausuler vara designerade eller så skall ingen av dem vara det"
 
-#: cp/parser.c:22228
+#: cp/parser.c:22225
 #, gcc-internal-format
 msgid "%<...%> not allowed in designated initializer list"
 msgstr "%<...%> är inte tillåtet i en designerad initierarlista"
 
-#: cp/parser.c:22266
+#: cp/parser.c:22263
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr "designeraren %<.%s%> använd flera gånger i samma intierarlista"
 
-#: cp/parser.c:22322 cp/parser.c:22448
+#: cp/parser.c:22319 cp/parser.c:22445
 #, gcc-internal-format
 msgid "expected class-name"
 msgstr "klassnamn förväntades"
 
-#: cp/parser.c:22650
+#: cp/parser.c:22647
 #, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "%<;%> förväntades efter klassdefinition"
 
-#: cp/parser.c:22653
+#: cp/parser.c:22650
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "%<;%> förväntades efter postdefinition"
 
-#: cp/parser.c:22656
+#: cp/parser.c:22653
 #, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "%<;%> förväntades efter uniondefinition"
 
-#: cp/parser.c:23012
+#: cp/parser.c:23009
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "%<{%> eller %<:%> förväntades"
 
-#: cp/parser.c:23023
+#: cp/parser.c:23020
 #, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "det går inte att ange %<override%> för en klass"
 
-#: cp/parser.c:23031
+#: cp/parser.c:23028
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr "globala kvalificering av klassnamn är ogiltigt"
 
-#: cp/parser.c:23038
+#: cp/parser.c:23035
 #, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "kvalificerat namn namnger inte en klass"
 
-#: cp/parser.c:23050
+#: cp/parser.c:23047
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr "nyckelordet %<template%> är inte tillåtet i klasshuvudnamn"
 
-#: cp/parser.c:23056
+#: cp/parser.c:23053
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "ogiltigt klassnamn i deklaration av %qD"
 
-#: cp/parser.c:23114
+#: cp/parser.c:23111
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "en explicit specialisering måste föregås av %<template <>%>"
 
-#: cp/parser.c:23146
+#: cp/parser.c:23143
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "funktionsmall %qD omdeklarerad som en klassmall"
 
-#: cp/parser.c:23182
+#: cp/parser.c:23179
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr "det gick inte att lösa upp typnamnstyp"
 
-#: cp/parser.c:23241
+#: cp/parser.c:23238
 #, gcc-internal-format
 msgid "previous definition of %q#T"
 msgstr "föregående definition av %q#T"
 
-#: cp/parser.c:23331 cp/parser.c:28499
+#: cp/parser.c:23328 cp/parser.c:28496
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr "klassnyckel förväntades"
 
-#: cp/parser.c:23355
+#: cp/parser.c:23352
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++17 or -std=gnu++17"
 msgstr "ISO C++ förbjuder nyckelordet typename i mall-mall-parameter; använd -std=c++17 eller -std=gnu++17"
 
-#: cp/parser.c:23359
+#: cp/parser.c:23356
 #, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "%<class%> eller %<typename%> förväntades"
 
-#: cp/parser.c:23605
+#: cp/parser.c:23602
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr "i C++03 måste en klassnyckel användas när en vän deklareras"
 
-#: cp/parser.c:23623
+#: cp/parser.c:23620
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "vändeklaration som inte namnger en klass eller funktion"
 
-#: cp/parser.c:23641
+#: cp/parser.c:23638
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr "en lagringklass på ett anonymt aggregat i klassräckvidd tillåts inte"
 
-#: cp/parser.c:23738
+#: cp/parser.c:23735
 #, gcc-internal-format
 msgid "default member initializers for bit-fields only available with -std=c++2a or -std=gnu++2a"
 msgstr "standardmedlemsinitierare för bitfält är endast tillgängliga med -std=c++2a eller -std=gnu++2a"
 
-#: cp/parser.c:23745
+#: cp/parser.c:23742
 #, gcc-internal-format
 msgid "default member initializer for unnamed bit-field"
 msgstr "standardmedlemsinitierare för namnlöst bitfält"
 
-#: cp/parser.c:23758
+#: cp/parser.c:23755
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr "ISO C++ tillåter endast bitfältsattribut före symbolen %<:%>"
 
-#: cp/parser.c:23903
+#: cp/parser.c:23900
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr "pure-specificerare på funktionsdefinition"
 
-#: cp/parser.c:23923
+#: cp/parser.c:23920
 #, gcc-internal-format
 msgid "extra %<;%> after in-class function definition"
 msgstr "extra %<;%> efter funktionsdefinition i klassen"
 
-#: cp/parser.c:23970
+#: cp/parser.c:23967
 #, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr "överblivet %<,%> vid slutet av medlemsdeklaration"
 
-#: cp/parser.c:23984
+#: cp/parser.c:23981
 #, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "%<;%> förväntades vid slutet av medlemsdeklaration"
 
-#: cp/parser.c:24058
+#: cp/parser.c:24055
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr "ogiltig pure-specificerare (endast %<= 0%> är tillåtet)"
 
-#: cp/parser.c:24093
+#: cp/parser.c:24090
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "en klammeromsluten initierare är inte tillåten här"
 
-#: cp/parser.c:24223
+#: cp/parser.c:24220
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr "%<virtual%> anges mer än en gång i basspecificerare"
 
-#: cp/parser.c:24243
+#: cp/parser.c:24240
 #, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr "mer än en åtkomstspecifikation i basspecificerare"
 
-#: cp/parser.c:24267
+#: cp/parser.c:24264
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "nyckelordet %<typename%> är inte tillåtet utanför mallar"
 
-#: cp/parser.c:24270
+#: cp/parser.c:24267
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "nyckelordet %<typename%> är inte tillåtet i detta sammanhang (basklassen är implicit en typ)"
 
-#: cp/parser.c:24364 cp/parser.c:24442
+#: cp/parser.c:24361 cp/parser.c:24439
 #, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "typer får inte definieras i en undantagsspecifikation"
 
-#: cp/parser.c:24450
+#: cp/parser.c:24447
 #, gcc-internal-format
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "ISO C++17 tillåter inte dynamiska undantagsspecifikationer"
 
-#: cp/parser.c:24456
+#: cp/parser.c:24453
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr "dynamiska undantagsspecifikationer undanbedes i C++11"
 
-#: cp/parser.c:24500
+#: cp/parser.c:24497
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "ogiltig användning av %<auto%> i undantagsspecifikation"
 
-#: cp/parser.c:24539
+#: cp/parser.c:24536
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr "%<try%> i %<constexpr%>-funktion"
 
-#: cp/parser.c:24650
+#: cp/parser.c:24647
 #, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr "typer får inte definieras i undantagsdeklarationer"
 
-#: cp/parser.c:25203
+#: cp/parser.c:25200
 #, gcc-internal-format
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr "attribut som använder prefix använt tillsammans med attributsymboler med räckvidd"
 
-#: cp/parser.c:25217
+#: cp/parser.c:25214
 #, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr "en identifierare förväntades som attributnamn"
 
-#: cp/parser.c:25301
+#: cp/parser.c:25298
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr "attributet %<noreturn%> får förekomma högst en gång i en attributlista"
 
-#: cp/parser.c:25305
+#: cp/parser.c:25302
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr "attributet %<deprecated%> kan förekomma högst en gång i en attributlista"
 
-#: cp/parser.c:25342
+#: cp/parser.c:25339
 #, gcc-internal-format
 msgid "expected attribute before %<...%>"
 msgstr "attribut förväntades före %<...%>"
 
-#: cp/parser.c:25403
+#: cp/parser.c:25400
 #, gcc-internal-format
 msgid "attribute using prefix only available with -std=c++17 or -std=gnu++17"
 msgstr "attribut som använder prefix är endast tillgängligt med -std=c++17 eller -std=gnu++17"
 
-#: cp/parser.c:25721
+#: cp/parser.c:25718
 #, gcc-internal-format
 msgid "%<requires%> only available with -fconcepts"
 msgstr "%<requires%> är endast tillgängligt med -fconcepts"
 
-#: cp/parser.c:25753
+#: cp/parser.c:25750
 #, gcc-internal-format
 msgid "a requires expression cannot appear outside a template"
 msgstr "ett transaktionsuttryck får inte finnas utanför en mall"
 
-#: cp/parser.c:26467
+#: cp/parser.c:26464
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr "specialisering av medlem %<%T::%E%> kräver %<template<>%>-syntax"
 
-#: cp/parser.c:26472
+#: cp/parser.c:26469
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "ogiltig omdeklaration av %<%T::%E%>"
 
-#: cp/parser.c:26476
+#: cp/parser.c:26473
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "för få mallparameterlistor"
@@ -45816,454 +45858,454 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:26483
+#: cp/parser.c:26480
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "för många mallparameterlistor"
 
-#: cp/parser.c:26832
+#: cp/parser.c:26829
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "namngivna returvärden stödjs inte längre"
 
-#: cp/parser.c:26991
+#: cp/parser.c:26988
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr "den litterala operatormallen %qD har ogiltig parameterlista.  Ett mallargument som inte är en typ pack <char...> eller <typename CharT, CharT...> förväntades"
 
-#: cp/parser.c:26996
+#: cp/parser.c:26993
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr "den litterala operatormallen %qD har ogiltig parameterlista.  Ett mallargument som inte är en typ pack <char...> förväntades"
 
-#: cp/parser.c:27066
+#: cp/parser.c:27063
 #, gcc-internal-format
 msgid "empty introduction-list"
 msgstr "tom introduktionslista"
 
-#: cp/parser.c:27090
+#: cp/parser.c:27087
 #, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr "det finns inget matchande koncept för mallintroduktionen"
 
-#: cp/parser.c:27112
+#: cp/parser.c:27109
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "ogiltig deklaration av medlemsmall i lokal klass"
 
-#: cp/parser.c:27121
+#: cp/parser.c:27118
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "mall med C-länkning"
 
-#: cp/parser.c:27141
+#: cp/parser.c:27138
 #, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "ogiltig explicit specifikation"
 
-#: cp/parser.c:27245
+#: cp/parser.c:27242
 #, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "malldeklaration av %<typedef%>"
 
-#: cp/parser.c:27296
+#: cp/parser.c:27293
 #, gcc-internal-format
 msgid "a class template declaration must not declare anything else"
 msgstr "en klassmallsdeklaration får inte deklarera något annat"
 
-#: cp/parser.c:27342
+#: cp/parser.c:27339
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "explicit mallspecialisering kan inte ha en lagringsklass"
 
-#: cp/parser.c:27650
+#: cp/parser.c:27647
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%<>>%> skulle vara %<> >%> inuti en nästad mallargumentlista"
 
-#: cp/parser.c:27663
+#: cp/parser.c:27660
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "vilsekommet %<>>%>, använd %<>%> för att avsluta en mallargumentlista"
 
-#: cp/parser.c:27958
+#: cp/parser.c:27955
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr "argument till %<sizeof...%> måste omges av parenteser"
 
-#: cp/parser.c:28118
+#: cp/parser.c:28115
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "ogiltig användning av %qD i länkklasspecifikation"
 
-#: cp/parser.c:28133
+#: cp/parser.c:28130
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> före %qD"
 
-#: cp/parser.c:28267
+#: cp/parser.c:28264
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ 1998 stödjer inte %<long long%>"
 
-#: cp/parser.c:28275
+#: cp/parser.c:28272
 #, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "både %<__thread%> och %<thread_local%> angivna"
 
-#: cp/parser.c:28280
+#: cp/parser.c:28277
 #, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "dubblerad %qD"
 
-#: cp/parser.c:28304
+#: cp/parser.c:28301
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "dubblerad %qs"
 
-#: cp/parser.c:28356
+#: cp/parser.c:28353
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "%<new%> förväntades"
 
-#: cp/parser.c:28359
+#: cp/parser.c:28356
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "%<delete%> förväntades"
 
-#: cp/parser.c:28362
+#: cp/parser.c:28359
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "%<return%> förväntades"
 
-#: cp/parser.c:28368
+#: cp/parser.c:28365
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "%<extern%> förväntades"
 
-#: cp/parser.c:28371
+#: cp/parser.c:28368
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "%<static_assert%> förväntades"
 
-#: cp/parser.c:28374
+#: cp/parser.c:28371
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "%<decltype%> förväntades"
 
-#: cp/parser.c:28377
+#: cp/parser.c:28374
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "%<operator%> förväntades"
 
-#: cp/parser.c:28380
+#: cp/parser.c:28377
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "%<class%> förväntades"
 
-#: cp/parser.c:28383
+#: cp/parser.c:28380
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "%<template%> förväntades"
 
-#: cp/parser.c:28386
+#: cp/parser.c:28383
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "%<namespace%> förväntades"
 
-#: cp/parser.c:28389
+#: cp/parser.c:28386
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "%<using%> förväntades"
 
-#: cp/parser.c:28392
+#: cp/parser.c:28389
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "%<asm%> förväntades"
 
-#: cp/parser.c:28395
+#: cp/parser.c:28392
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "%<try%> förväntades"
 
-#: cp/parser.c:28398
+#: cp/parser.c:28395
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "%<catch%> förväntades"
 
-#: cp/parser.c:28401
+#: cp/parser.c:28398
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "%<throw%> förväntades"
 
-#: cp/parser.c:28404
+#: cp/parser.c:28401
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "%<__label__%> förväntades"
 
-#: cp/parser.c:28407
+#: cp/parser.c:28404
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "%<@try%> förväntades"
 
-#: cp/parser.c:28410
+#: cp/parser.c:28407
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "%<@synchronized%> förväntades"
 
-#: cp/parser.c:28413
+#: cp/parser.c:28410
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "%<@throw%> förväntades"
 
-#: cp/parser.c:28416
+#: cp/parser.c:28413
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "%<__transaction_atomic%> förväntades"
 
-#: cp/parser.c:28419
+#: cp/parser.c:28416
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "%<__transaction_relaxed%> förväntades"
 
-#: cp/parser.c:28451
+#: cp/parser.c:28448
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "%<::%> förväntades"
 
-#: cp/parser.c:28463
+#: cp/parser.c:28460
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "%<...%> förväntades"
 
-#: cp/parser.c:28466
+#: cp/parser.c:28463
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "%<*%> förväntades"
 
-#: cp/parser.c:28469
+#: cp/parser.c:28466
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "%<~%> förväntades"
 
-#: cp/parser.c:28475
+#: cp/parser.c:28472
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "%<:%> eller %<::%> förväntades"
 
-#: cp/parser.c:28502
+#: cp/parser.c:28499
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "%<class%>, %<typename%> eller %<template%> förväntades"
 
-#: cp/parser.c:28772
+#: cp/parser.c:28769
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "%qs-tagg använd vid namngivning av %q#T"
 
-#: cp/parser.c:28777
+#: cp/parser.c:28774
 #, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "%q#T deklarerades tidigare här"
 
-#: cp/parser.c:28798
+#: cp/parser.c:28795
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD omdeklarerad med annan åtkomst"
 
-#: cp/parser.c:28819
+#: cp/parser.c:28816
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "i C++98 är %<template%> (för att lösa upp tvetydighet) är endast tillåtet inuti mallar"
 
-#: cp/parser.c:29062
+#: cp/parser.c:29059
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "filen slutar i standardargument"
 
-#: cp/parser.c:29303 cp/parser.c:30620 cp/parser.c:30808
+#: cp/parser.c:29300 cp/parser.c:30617 cp/parser.c:30805
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "felplacerad Objective-C++-konstruktion %<@%D%>"
 
-#: cp/parser.c:29372
+#: cp/parser.c:29369
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr "objective-c++-meddelandemottagare förväntades"
 
-#: cp/parser.c:29442
+#: cp/parser.c:29439
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr "objective-c++-meddelandeargument förväntades"
 
-#: cp/parser.c:29473
+#: cp/parser.c:29470
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "%<@encode%> måste ange en typ som ett argument"
 
-#: cp/parser.c:29883
+#: cp/parser.c:29880
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "ogiltigt Objective-C++-väljarnamn"
 
-#: cp/parser.c:29958 cp/parser.c:29976
+#: cp/parser.c:29955 cp/parser.c:29973
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr "metoddeklaration i objective-c++ förväntades"
 
-#: cp/parser.c:29970 cp/parser.c:30035
+#: cp/parser.c:29967 cp/parser.c:30032
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "metodattribut måste anges på slutet"
 
 # %qs blir "{" eller "}"
-#: cp/parser.c:30078
+#: cp/parser.c:30075
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr "vilsekommet %qs mellan Objective-C++ metoder"
 
-#: cp/parser.c:30284 cp/parser.c:30291 cp/parser.c:30298
+#: cp/parser.c:30281 cp/parser.c:30288 cp/parser.c:30295
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "ogiltig typ för iterationsvariabel"
 
-#: cp/parser.c:30413
+#: cp/parser.c:30410
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "identifierare förväntades efter %<@protocol%>"
 
-#: cp/parser.c:30585
+#: cp/parser.c:30582
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr "attribut får inte anges före Objective-C++-nyckelordet %<@%D%>"
 
-#: cp/parser.c:30592
+#: cp/parser.c:30589
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "prefixattribut ignoreras före %<@%D%>"
 
-#: cp/parser.c:30867 cp/parser.c:30874 cp/parser.c:30881
+#: cp/parser.c:30864 cp/parser.c:30871 cp/parser.c:30878
 #, gcc-internal-format
 msgid "invalid type for property"
 msgstr "ogiltig typ på egenskap"
 
-#: cp/parser.c:32011
+#: cp/parser.c:32008
 #, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr "%<wait%>-uttryck måste vara heltal"
 
-#: cp/parser.c:32724
+#: cp/parser.c:32721
 #, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr "ogiltig reduktionsidentifierare"
 
-#: cp/parser.c:34911
+#: cp/parser.c:34908
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr "initiering i parenteser är inte tillåtet i en OpenMP-%<for%>-slinga"
 
-#: cp/parser.c:35231 cp/pt.c:16392
+#: cp/parser.c:35228 cp/pt.c:16414
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "iterationsvariabel %qD skall inte vara reduction"
 
-#: cp/parser.c:35316
+#: cp/parser.c:35313
 #, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr "inte tillräckligt med for-slingor att kollapsa"
 
-#: cp/parser.c:37521
+#: cp/parser.c:37518
 #, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr "ogiltig initierarklausul"
 
-#: cp/parser.c:37549
+#: cp/parser.c:37546
 #, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "id-uttryck förväntades (argument)"
 
-#: cp/parser.c:37561
+#: cp/parser.c:37558
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr "en av initieraranropets argument skall vara %<omp_priv%> eller %<&omp_priv%>"
 
-#: cp/parser.c:37662
+#: cp/parser.c:37659
 #, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr "typer får inte definieras i en declare reduction-typlista"
 
-#: cp/parser.c:37682 cp/semantics.c:5405
+#: cp/parser.c:37679 cp/semantics.c:5408
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr "en fördeklarerad aritmetisk typ %qT i %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:37687 cp/semantics.c:5414
+#: cp/parser.c:37684 cp/semantics.c:5417
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr "funktions- eller vektortyp %qT i %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:37690 cp/pt.c:12944 cp/semantics.c:5420
+#: cp/parser.c:37687 cp/pt.c:12966 cp/semantics.c:5423
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr "referenstyp %qT i %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:37693 cp/semantics.c:5426
+#: cp/parser.c:37690 cp/semantics.c:5429
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr "const-, volatile- eller __restrict-kvalificerad typ %qT i %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:38047
+#: cp/parser.c:38044
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr "%<#pragma acc routine%> namnger en mängd överlagrade"
 
-#: cp/parser.c:38057
+#: cp/parser.c:38054
 #, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr "%qD refererar inte till en funktion med namnrymdsräckvidd"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:38392
+#: cp/parser.c:38389
 #, gcc-internal-format
 msgid "atomic_cancel"
 msgstr "atomic_cancel"
 
-#: cp/parser.c:38435 cp/semantics.c:8575
+#: cp/parser.c:38432 cp/semantics.c:8578
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr "%<__transaction_relaxed%> utan stöd för transaktionsminne aktiverat"
 
-#: cp/parser.c:38437 cp/semantics.c:8577
+#: cp/parser.c:38434 cp/semantics.c:8580
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr "%<__transaction_atomic%> utan stöd för transaktionsminne aktiverat"
 
-#: cp/parser.c:38631
+#: cp/parser.c:38628
 #, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "skräp vid slutet av %<#pragma GCC pch_preprocess%>"
 
-#: cp/parser.c:38927
+#: cp/parser.c:38924
 #, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "%<#pragma GCC ivdep%> måste vara inuti en funktion"
 
-#: cp/parser.c:38959
+#: cp/parser.c:38956
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr "%<#pragma GCC unroll%> måste vara inuti en funktion"
 
-#: cp/parser.c:39039
+#: cp/parser.c:39036
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "intermoduloptimeringar inte implementerade för C++"
 
-#: cp/parser.c:39295
+#: cp/parser.c:39292
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr "implicita mallar får inte vara %<virtual%>"
 
-#: cp/parser.c:39351
+#: cp/parser.c:39348
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr "%<extern \"C\"%>-länkning startade här"
@@ -46350,7 +46392,7 @@
 msgid "specialization of %qD after instantiation"
 msgstr "specialisering av %qD efter instansiering"
 
-#: cp/pt.c:1954 cp/semantics.c:5274
+#: cp/pt.c:1954 cp/semantics.c:5277
 #, gcc-internal-format
 msgid "%s %#qD"
 msgstr "%s %#qD"
@@ -46516,107 +46558,107 @@
 msgid "argument to __integer_pack must be between 0 and %d"
 msgstr "argument till __integer_pack måste vara mellan 0 och %d"
 
-#: cp/pt.c:3942
+#: cp/pt.c:3955
 #, gcc-internal-format
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr "basinitierarexpansionen %qT innehåller inga parameterpaket"
 
-#: cp/pt.c:4010
+#: cp/pt.c:4023
 #, gcc-internal-format
 msgid "expansion pattern %qT contains no argument packs"
 msgstr "expansionsmönster %qT innehåller inga argumentpaket"
 
-#: cp/pt.c:4012
+#: cp/pt.c:4025
 #, gcc-internal-format
 msgid "expansion pattern %qE contains no argument packs"
 msgstr "expansionsmönster %qE innehåller inga argumentpaket"
 
-#: cp/pt.c:4063
+#: cp/pt.c:4077
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr "parameterpaket expanderas inte med %<...%>:"
 
-#: cp/pt.c:4080 cp/pt.c:4835
+#: cp/pt.c:4094 cp/pt.c:4849
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
 
-#: cp/pt.c:4082
+#: cp/pt.c:4096
 #, gcc-internal-format
 msgid "        <anonymous>"
 msgstr "        <anonym>"
 
-#: cp/pt.c:4208
+#: cp/pt.c:4222
 #, gcc-internal-format
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr "deklaration av mallparametern %q+D skuggar en mallparameter"
 
-#: cp/pt.c:4211
+#: cp/pt.c:4225
 #, gcc-internal-format
 msgid "declaration of %q+#D shadows template parameter"
 msgstr "deklaration av %q+#D skuggar en mallparameter"
 
-#: cp/pt.c:4213
+#: cp/pt.c:4227
 #, gcc-internal-format
 msgid "template parameter %qD declared here"
 msgstr "mallparametern %qD deklarerad här"
 
-#: cp/pt.c:4771
+#: cp/pt.c:4785
 #, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr "specialisering av variabelkonceptet %q#D"
 
-#: cp/pt.c:4830
+#: cp/pt.c:4844
 #, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr "mallparameter är inte härledbara i partiell specialisering:"
 
-#: cp/pt.c:4854
+#: cp/pt.c:4868
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr "partiell specialisering %q+D specialiserar inte något mallargument; för att definiera den primära mallen, ta bort mallargumentlistan"
 
-#: cp/pt.c:4858
+#: cp/pt.c:4872
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr "partiell specialisering %q+D specialiserar inte något mallargument och är inte mer begränsad än den primära mallen; för att definiera den primära mallen, ta bort mallargumentlistan"
 
-#: cp/pt.c:4862 cp/pt.c:4873
+#: cp/pt.c:4876 cp/pt.c:4887
 #, gcc-internal-format
 msgid "primary template here"
 msgstr "huvudmall här"
 
-#: cp/pt.c:4870
+#: cp/pt.c:4884
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr "partiell specialisering är inte mer specialiserad än huvudmallen eftersom den ersätter flera parametrar med en paketexpansion"
 
-#: cp/pt.c:4885
+#: cp/pt.c:4899
 #, gcc-internal-format
 msgid "partial specialization %qD is not more specialized than"
 msgstr "partiell specialisering %qD är inte mer specialiserad än"
 
-#: cp/pt.c:4887
+#: cp/pt.c:4901
 #, gcc-internal-format
 msgid "primary template %qD"
 msgstr "huvudmallen %qD"
 
-#: cp/pt.c:4934
+#: cp/pt.c:4948
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr "parameterpaketargument %qE måste vara vid slutet av mallens argumentlista"
 
-#: cp/pt.c:4937
+#: cp/pt.c:4951
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr "parameterpaketargument %qT måste vara vid slutet av mallens argumentlista"
 
-#: cp/pt.c:4958
+#: cp/pt.c:4972
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr "mallargument %qE berör mallparametrar"
 
-#: cp/pt.c:5004
+#: cp/pt.c:5018
 #, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
@@ -46623,17 +46665,17 @@
 msgstr[0] "typ %qT för mallargument %qE beror på en mallparameter"
 msgstr[1] "typ %qT för mallargument %qE beror på mallparametrar"
 
-#: cp/pt.c:5066
+#: cp/pt.c:5080
 #, gcc-internal-format
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "deklaration av %qD gör tidigare mallinstansiering av %qD tvetydig"
 
-#: cp/pt.c:5070
+#: cp/pt.c:5084
 #, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "partiell specialisering %qD efter instansiering av %qD"
 
-#: cp/pt.c:5247
+#: cp/pt.c:5261
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "inget standardargument för %qD"
@@ -46641,47 +46683,47 @@
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5269
+#: cp/pt.c:5283
 #, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "parameterpaket %q+D måste vara vid slutet av mallens parameterlista"
 
-#: cp/pt.c:5305
+#: cp/pt.c:5319
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "standardmallargument får inte användas i vänomdeklaration av funktionsmall"
 
-#: cp/pt.c:5308
+#: cp/pt.c:5322
 #, gcc-internal-format
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "standardmallargument får inte användas i vändeklarerade mallar"
 
-#: cp/pt.c:5311
+#: cp/pt.c:5325
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without -std=c++11 or -std=gnu++11"
 msgstr "standarmallargument får inte användas i funktionsmallar utan -std=c++11 eller -std=gnu++11"
 
-#: cp/pt.c:5314
+#: cp/pt.c:5328
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr "standardmallargument får inte användas i partiella specialiseringar"
 
-#: cp/pt.c:5317 cp/pt.c:5375
+#: cp/pt.c:5331 cp/pt.c:5389
 #, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "standardargumentet för mallparameter för klass om omsluter %qD"
 
-#: cp/pt.c:5489
+#: cp/pt.c:5503
 #, gcc-internal-format
 msgid "template %qD declared"
 msgstr "mallen %qD deklarerad"
 
-#: cp/pt.c:5496
+#: cp/pt.c:5510
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "mallklass utan ett namn"
 
-#: cp/pt.c:5504
+#: cp/pt.c:5518
 #, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr "medlemsmallen %qD kan inte ha virt-specificerare"
@@ -46691,57 +46733,57 @@
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5526
+#: cp/pt.c:5540
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "ogiltig malldeklaration av %qD"
 
-#: cp/pt.c:5669
+#: cp/pt.c:5683
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "malldefinition av icke-mall %q#D"
 
-#: cp/pt.c:5712
+#: cp/pt.c:5726
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "%d nivåer av mallparametrar förväntades till %q#D, %d fanns"
 
-#: cp/pt.c:5726
+#: cp/pt.c:5740
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "fick %d mallparametrar till %q#D"
 
-#: cp/pt.c:5729
+#: cp/pt.c:5743
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "fick %d mallparametrar till %q#T"
 
-#: cp/pt.c:5731
+#: cp/pt.c:5745
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  men %d behövs"
 
-#: cp/pt.c:5752
+#: cp/pt.c:5766
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "mallargument till %qD stämmer inte med originalmallen %qD"
 
-#: cp/pt.c:5755
+#: cp/pt.c:5769
 #, gcc-internal-format
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "använd %<template<>%> för en explicit specialisering"
 
-#: cp/pt.c:5882
+#: cp/pt.c:5896
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT är inte en malltyp"
 
-#: cp/pt.c:5895
+#: cp/pt.c:5909
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "mallspecificerare inte angivna i deklarationen av %qD"
 
-#: cp/pt.c:5906
+#: cp/pt.c:5920
 #, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
@@ -46748,7 +46790,7 @@
 msgstr[0] "omdeklarerad med %d mallparameter"
 msgstr[1] "omdeklarerad med %d mallparametrar"
 
-#: cp/pt.c:5910
+#: cp/pt.c:5924
 #, gcc-internal-format
 msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
@@ -46755,12 +46797,12 @@
 msgstr[0] "tidigare deklaration av %qD använde %d mallparameter"
 msgstr[1] "tidigare deklaration av %qD använde %d mallparametrar"
 
-#: cp/pt.c:5947
+#: cp/pt.c:5961
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "mallparameter %q+#D"
 
-#: cp/pt.c:5948
+#: cp/pt.c:5962
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "omdeklarerad här som %q#D"
@@ -46769,117 +46811,117 @@
 #.
 #. A template-parameter may not be given default arguments
 #. by two different declarations in the same scope.
-#: cp/pt.c:5958
+#: cp/pt.c:5972
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "omdefinition av standardargument till %q#D"
 
-#: cp/pt.c:5960
+#: cp/pt.c:5974
 #, gcc-internal-format
 msgid "original definition appeared here"
 msgstr "ursprunglig definition fanns här"
 
-#: cp/pt.c:5988
+#: cp/pt.c:6002
 #, gcc-internal-format
 msgid "redeclaration %q#D with different constraints"
 msgstr "omdeklaration av %q#D med andra begränsningar"
 
-#: cp/pt.c:5991
+#: cp/pt.c:6005
 #, gcc-internal-format
 msgid "original declaration appeared here"
 msgstr "ursprunglig deklaration fanns här"
 
-#: cp/pt.c:6250 cp/pt.c:6318
+#: cp/pt.c:6264 cp/pt.c:6332
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%qE är inte ett giltigt mallargument för typen %qT"
 
-#: cp/pt.c:6253
+#: cp/pt.c:6267
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr "det måste vara adressen till en funktion med extern lagringsklass"
 
-#: cp/pt.c:6256
+#: cp/pt.c:6270
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr "det måste vara namnet på en funktion med extern lagringsklass"
 
-#: cp/pt.c:6268
+#: cp/pt.c:6282
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%qE är inte ett giltigt mallargument för typ %qT eftersom %qD inte har någon länkklass"
 
-#: cp/pt.c:6272
+#: cp/pt.c:6286
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%qE är inte ett giltigt mallargument för typen %qT eftersom %qD inte har extern länkklass"
 
-#: cp/pt.c:6321
+#: cp/pt.c:6335
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "det måste vara en pekare-till-medlem på formen %<&X::Y%>"
 
-#: cp/pt.c:6323
+#: cp/pt.c:6337
 #, gcc-internal-format
 msgid "because it is a member of %qT"
 msgstr "för att den är en medlem av %qT"
 
-#: cp/pt.c:6383
+#: cp/pt.c:6397
 #, gcc-internal-format
 msgid "  couldn't deduce template parameter %qD"
 msgstr "  kunde inte härleda mallparametrar %qD"
 
-#: cp/pt.c:6392
+#: cp/pt.c:6406
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr "  typerna %qT och %qT har inkompatibla cv-kvalificerare"
 
-#: cp/pt.c:6401
+#: cp/pt.c:6415
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr "  typerna %qT och %qT stämmer inte överens"
 
-#: cp/pt.c:6410
+#: cp/pt.c:6424
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr "  mallparameter %qD är inte ett parameterpaket, men argument %qD är det"
 
-#: cp/pt.c:6421
+#: cp/pt.c:6435
 #, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "  mallargument %qE stämmer inte med pekare till medlem-konstanten %qE"
 
-#: cp/pt.c:6431
+#: cp/pt.c:6445
 #, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr "  %qE är inte ekvivalent med %qE"
 
-#: cp/pt.c:6440
+#: cp/pt.c:6454
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr "  inkonsistent härledning av parameterpaket med %qT och %qT"
 
-#: cp/pt.c:6452
+#: cp/pt.c:6466
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr "  härledda typer i konflikt för parametern %qT (T%qT och %qT)"
 
-#: cp/pt.c:6456
+#: cp/pt.c:6470
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr "  härledda värden i konflikt för icke-typ-parametern %qE (%qE och %qE)"
 
-#: cp/pt.c:6467
+#: cp/pt.c:6481
 #, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "  vektortypen %qT med variabel storlek är inte ett giltigt mallargument"
 
-#: cp/pt.c:6478
+#: cp/pt.c:6492
 #, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr "  medlemsfunktionstypen %qT är inte ett giltigt mallargument"
 
-#: cp/pt.c:6490
+#: cp/pt.c:6504
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
@@ -46886,292 +46928,292 @@
 msgstr[0] "  kandidaten förväntade sig åtminstone %d argument, %d fanns"
 msgstr[1] "  kandidaten förväntade sig åtminstone %d argument, %d fanns"
 
-#: cp/pt.c:6521
+#: cp/pt.c:6535
 #, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "  kan inte konvertera %qE (typen %qT) till typ %qT"
 
-#: cp/pt.c:6534
+#: cp/pt.c:6548
 #, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "  %qT är en tvetydig basklass till %qT"
 
-#: cp/pt.c:6538
+#: cp/pt.c:6552
 #, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "  %qT är inte härledd från %qT"
 
-#: cp/pt.c:6549
+#: cp/pt.c:6563
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr "  mallparametrarna till ett mallmallargument är inkonsistenta med andra härledda mallargument"
 
-#: cp/pt.c:6559
+#: cp/pt.c:6573
 #, gcc-internal-format
 msgid "  can't deduce a template for %qT from non-template type %qT"
 msgstr "  det går inte att härleda en mall för %qT från typen %qT som inte är en mall"
 
-#: cp/pt.c:6569
+#: cp/pt.c:6583
 #, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
 msgstr "  mallargument %qE stämmer inte med %qE"
 
-#: cp/pt.c:6609
+#: cp/pt.c:6623
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "%qE är inte ett giltigt mallargument för typ %qT eftersom strängkonstanter aldrig kan användas i detta sammanhang"
 
-#: cp/pt.c:6758
+#: cp/pt.c:6772
 #, gcc-internal-format
 msgid "in template argument for type %qT"
 msgstr "i mallargument för typen %qT"
 
-#: cp/pt.c:6772
+#: cp/pt.c:6786
 #, gcc-internal-format
 msgid "template argument %qE for type %qT not a constant integer"
 msgstr "mallargumentet %qE för typen %qT är inte ett konstant heltal"
 
-#: cp/pt.c:6833
+#: cp/pt.c:6847
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qD är inte ett giltigt mallargument för att %qD är en variabel, inte adressen till en variabel"
 
-#: cp/pt.c:6841
+#: cp/pt.c:6855
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qE är inte ett giltigt mallargument till %qT för det är inte adressen till en variabel"
 
-#: cp/pt.c:6857
+#: cp/pt.c:6871
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "%qE är inte ett giltigt mallargument för typen %qT eftersom %qE inte är en variabel"
 
-#: cp/pt.c:6864
+#: cp/pt.c:6878
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr "%qE är inte ett giltigt mallargument av typ %qT eftersom %qD inte har extern länkklass"
 
-#: cp/pt.c:6873
+#: cp/pt.c:6887
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE är inte ett giltigt mallargument för typen %qT eftersom %qD inte har någon länkklass"
 
-#: cp/pt.c:6888
+#: cp/pt.c:6902
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument"
 msgstr "adressen till %qD är inte ett giltigt mallargument"
 
-#: cp/pt.c:6897
+#: cp/pt.c:6911
 #, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr "adressen till underobjektet %qT till %qD är inte ett giltigt mallargument"
 
-#: cp/pt.c:6904
+#: cp/pt.c:6918
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "adressen till %qD är inte ett giltigt mallargument eftersom den inte har statisk lagringsvaraktighet"
 
-#: cp/pt.c:6933
+#: cp/pt.c:6947
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "%qE är inte ett giltigt mallargument för typ %qT eftersom det står i konflikt med cv-kvalificeringar"
 
-#: cp/pt.c:6941
+#: cp/pt.c:6955
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE är inte ett giltigt mallargument för typ %qT eftersom inte är ett l-värde"
 
-#: cp/pt.c:6959
+#: cp/pt.c:6973
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%q#D är inte ett giltigt mallargument till typen %qT eftersom en referensvariabel inte har en konstant adress"
 
-#: cp/pt.c:6975
+#: cp/pt.c:6989
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an object with linkage"
 msgstr "%qE är inte ett giltigt mallargument för typen %qT eftersom det inte är ett objekt med länkklass"
 
-#: cp/pt.c:6986
+#: cp/pt.c:7000
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because object %qD does not have linkage"
 msgstr "%qE är inte ett giltigt mallargument för typ %qT eftersom objekt %qD inte har någon länkklass"
 
-#: cp/pt.c:7036
+#: cp/pt.c:7050
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE är inte ett giltigt mallargument för typen %qT eftersom det är en pekare"
 
-#: cp/pt.c:7038
+#: cp/pt.c:7052
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "försök att använda %qE istället"
 
-#: cp/pt.c:7092
+#: cp/pt.c:7106
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE är inte ett giltigt mallargument för typen %qT eftersom det är av typen %qT"
 
-#: cp/pt.c:7654
+#: cp/pt.c:7668
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "ignorerar attribut på mallargumentet %qT"
 
-#: cp/pt.c:7670
+#: cp/pt.c:7684
 #, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr "ignorerar attribut i mallargumentet %qE"
 
-#: cp/pt.c:7805
+#: cp/pt.c:7819
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "inskjutet klassnamn %qD använt som mallmallargument"
 
-#: cp/pt.c:7834
+#: cp/pt.c:7848
 #, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "ogiltig användning av destrueraren %qE som en typ"
 
-#: cp/pt.c:7839
+#: cp/pt.c:7853
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "för att referera till en typmedlem av en mallparameter, använd %<typename %E%>"
 
-#: cp/pt.c:7855 cp/pt.c:7877 cp/pt.c:7931
+#: cp/pt.c:7869 cp/pt.c:7891 cp/pt.c:7945
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "typ/värde stämmer inte vid argument %d i mallparameterlistan till %qD"
 
-#: cp/pt.c:7860
+#: cp/pt.c:7874
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  förväntade en konstant av typen %qT, fick %qT"
 
-#: cp/pt.c:7865
+#: cp/pt.c:7879
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  förväntade en klassmall, fick %qE"
 
-#: cp/pt.c:7868
+#: cp/pt.c:7882
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  förväntade en typ, fick %qE"
 
-#: cp/pt.c:7882
+#: cp/pt.c:7896
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  förväntade en typ, fick %qT"
 
-#: cp/pt.c:7885
+#: cp/pt.c:7899
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  förväntade en klassmall, fick %qT"
 
-#: cp/pt.c:7935
+#: cp/pt.c:7949
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  förväntade en mall av typen %qD, fick %qT"
 
-#: cp/pt.c:7949
+#: cp/pt.c:7963
 #, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "begränsningar stämmer inte vid argument %d i mallparameterlistan till %qD"
 
-#: cp/pt.c:7952
+#: cp/pt.c:7966
 #, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr "  %qD förväntades men fick %qD"
 
-#: cp/pt.c:8012
+#: cp/pt.c:8026
 #, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "kunde inte konvertera mallargument %qE från %qT till %qT"
 
-#: cp/pt.c:8149 cp/pt.c:8465
+#: cp/pt.c:8163 cp/pt.c:8479
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "mallargument %d är ogiltigt"
 
-#: cp/pt.c:8164 cp/pt.c:8298
+#: cp/pt.c:8178 cp/pt.c:8312
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "fel antal mallargument (%d, skulle vara %d)"
 
-#: cp/pt.c:8294
+#: cp/pt.c:8308
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "fel antal mallargument (%d, skulle vara åtminstone %d)"
 
-#: cp/pt.c:8303
+#: cp/pt.c:8317
 #, gcc-internal-format
 msgid "provided for %qD"
 msgstr "angivna till %qD"
 
-#: cp/pt.c:8328
+#: cp/pt.c:8342
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr "pack-expansionsargument för icke-pack-parametern %qD till aliasmall %qD"
 
-#: cp/pt.c:8332
+#: cp/pt.c:8346
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "pack-expansionsargument för icke-pack-parametern %qD till konceptet %qD"
 
-#: cp/pt.c:8431
+#: cp/pt.c:8445
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr "så varje instansiering med ett icke-tomt parameterpaket vore felformulerad"
 
-#: cp/pt.c:9054
+#: cp/pt.c:9068
 #, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%q#D är inte en funktionsmall"
 
-#: cp/pt.c:9221
+#: cp/pt.c:9235
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "icke-malltyp %qT använd som en mall"
 
-#: cp/pt.c:9223
+#: cp/pt.c:9237
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "för malldeklaration %q+D"
 
-#: cp/pt.c:9346
+#: cp/pt.c:9360
 #, gcc-internal-format
 msgid "template constraint failure"
 msgstr "mallbegränsningsfel"
 
-#: cp/pt.c:9697
+#: cp/pt.c:9718
 #, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr "användning av felaktig variabelmall %qE"
 
-#: cp/pt.c:10125
+#: cp/pt.c:10148
 #, gcc-internal-format, gfc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr "mallinstansieringsdjupet överskrider maxvärdet på %d (använd -ftemplate-depth= för att öka maxvärdet)"
 
-#: cp/pt.c:11202
+#: cp/pt.c:11225
 #, gcc-internal-format
 msgid "flexible array member %qD in union"
 msgstr "flexibel vektormedlem %qD i union"
 
-#: cp/pt.c:11691
+#: cp/pt.c:11713
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr "fold över tom expansion över %O"
 
-#: cp/pt.c:12160
+#: cp/pt.c:12182
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr "argumentpaketlängder stämmer inte överens vid expansion av %qT"
 
-#: cp/pt.c:12163
+#: cp/pt.c:12185
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr "argumentpaketlängder stämmer inte överens vid expansion av %qE"
 
-#: cp/pt.c:12747
+#: cp/pt.c:12769
 #, gcc-internal-format
 msgid "  when instantiating default argument for call to %qD"
 msgstr "  vid instansiering av standardargument för anrop av %qD"
@@ -47189,276 +47231,276 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:13708
+#: cp/pt.c:13730
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "variabeln %qD har funktionstyp"
 
-#: cp/pt.c:13881
+#: cp/pt.c:13903
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "ogiltig parametertyp %qT"
 
-#: cp/pt.c:13883
+#: cp/pt.c:13905
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "i deklaration %q+D"
 
-#: cp/pt.c:14001
+#: cp/pt.c:14023
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "funktion som returnerar en vektor"
 
-#: cp/pt.c:14003
+#: cp/pt.c:14025
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "funktion som returnerar en funktion"
 
-#: cp/pt.c:14043
+#: cp/pt.c:14065
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "skapar pekare till medlemsfunktion i typ %qT som inte är en klass"
 
-#: cp/pt.c:14637
+#: cp/pt.c:14659
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "formar referens till void"
 
-#: cp/pt.c:14639
+#: cp/pt.c:14661
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "formar pekare till en referenstyp %qT"
 
-#: cp/pt.c:14641
+#: cp/pt.c:14663
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "formar referens till en referenstyp %qT"
 
-#: cp/pt.c:14654
+#: cp/pt.c:14676
 #, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "formerar en pekare till en kvalificerad funktionstyp %qT"
 
-#: cp/pt.c:14657
+#: cp/pt.c:14679
 #, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "formerar en referens till en kvalificerad funktionstyp %qT"
 
-#: cp/pt.c:14705
+#: cp/pt.c:14727
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "skapar pekare till medlem av typ %qT som inte är en klass"
 
-#: cp/pt.c:14711
+#: cp/pt.c:14733
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "skapar pekare till medlemsreferenstyp %qT"
 
-#: cp/pt.c:14717
+#: cp/pt.c:14739
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "skapar pekare till medlem av typ void"
 
-#: cp/pt.c:14783
+#: cp/pt.c:14805
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "skapar vektor av %qT"
 
-#: cp/pt.c:14816
+#: cp/pt.c:14838
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT är inte en klass-, post- eller unionstyp"
 
-#: cp/pt.c:14853
+#: cp/pt.c:14875
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT slås upp till %qT som inte är en uppräkningstyp"
 
-#: cp/pt.c:14861
+#: cp/pt.c:14883
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr "%qT löses upp till %qT, som inte är en klasstyp"
 
-#: cp/pt.c:14925
+#: cp/pt.c:14947
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr "tom initierare i lambdas init-fångst"
 
-#: cp/pt.c:15000
+#: cp/pt.c:15022
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "användning av %qs i mall"
 
-#: cp/pt.c:15178
+#: cp/pt.c:15200
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "kvalificerande typ %qT matchar inte destruerarnamnet ~%qT"
 
-#: cp/pt.c:15193
+#: cp/pt.c:15215
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "namnet %qE i den beroende tolkas som något annat än en typ, men instansiering ger en typ"
 
-#: cp/pt.c:15195
+#: cp/pt.c:15217
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "säg %<typename %E%> om en typ avses"
 
-#: cp/pt.c:15394
+#: cp/pt.c:15416
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "användning av ogiltigt fält %qD"
 
-#: cp/pt.c:15883 cp/pt.c:17386
+#: cp/pt.c:15905 cp/pt.c:17408
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "ogiltig användning av paketexpansionsuttryck"
 
-#: cp/pt.c:15887 cp/pt.c:17390
+#: cp/pt.c:15909 cp/pt.c:17412
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "använd %<...%>  för att expandera argumentpaket"
 
-#: cp/pt.c:18334
+#: cp/pt.c:18371
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr "%qD deklarerades inte i detta definitionsområde, och inga deklarationer hittades av en argumentberoende uppslagning vid instansieringspunkten"
 
-#: cp/pt.c:18362
+#: cp/pt.c:18399
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr "deklarationer i beroende bas %qT hittas inte av en okvalificerad uppslagning"
 
-#: cp/pt.c:18367
+#: cp/pt.c:18404
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "använd %<this->%D%> istället"
 
-#: cp/pt.c:18370
+#: cp/pt.c:18407
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "använd %<%T::%D%> istället"
 
-#: cp/pt.c:18375
+#: cp/pt.c:18412
 #, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "%qD är deklarerad här, senare i översättningsenheten"
 
-#: cp/pt.c:18712
+#: cp/pt.c:18752
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT är inte en klass eller namnrymd"
 
-#: cp/pt.c:18715
+#: cp/pt.c:18755
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD är inte en klass eller namnrymd"
 
-#: cp/pt.c:19026
+#: cp/pt.c:19066
 #, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr "%qT är/använder en namnlös typ"
 
-#: cp/pt.c:19028
+#: cp/pt.c:19068
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "mallargumentet för %qD använder lokal typ %qT"
 
-#: cp/pt.c:19038
+#: cp/pt.c:19078
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT är en variabel typ"
 
-#: cp/pt.c:19053
+#: cp/pt.c:19093
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "heltalsuttryck %qE är inte konstant"
 
-#: cp/pt.c:19071
+#: cp/pt.c:19111
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  försöker instansiera %qD"
 
-#: cp/pt.c:22972
+#: cp/pt.c:23050
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "tvetydig mallinstansiering av %q#T"
 
-#: cp/pt.c:22974
+#: cp/pt.c:23052
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "tvetydig mallinstansiering av %q#D"
 
-#: cp/pt.c:22980
+#: cp/pt.c:23058
 msgid "%s %#qS"
 msgstr "%s %#qS"
 
-#: cp/pt.c:23004 cp/pt.c:23091
+#: cp/pt.c:23082 cp/pt.c:23169
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "explicit instansieringar av icke-mall %q#D"
 
-#: cp/pt.c:23023
+#: cp/pt.c:23101
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD är inte en statisk datamedlem i en klassmall"
 
-#: cp/pt.c:23029 cp/pt.c:23086
+#: cp/pt.c:23107 cp/pt.c:23164
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "det finns ingen matchande mall för %qD"
 
-#: cp/pt.c:23034
+#: cp/pt.c:23112
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "typ %qT för explicit instansiering %qD stämmer inte med deklarerad typ %qT"
 
-#: cp/pt.c:23042
+#: cp/pt.c:23120
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "explicit instansiering av %q#D"
 
-#: cp/pt.c:23078
+#: cp/pt.c:23156
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "dubblerad explicit instansiering av %q#D"
 
-#: cp/pt.c:23101 cp/pt.c:23187
+#: cp/pt.c:23179 cp/pt.c:23265
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ 1998 förbjuder användning av %<extern%> vid explicita instansieringar"
 
-#: cp/pt.c:23106 cp/pt.c:23204
+#: cp/pt.c:23184 cp/pt.c:23282
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "lagringsklass %qD tillämpad på mallinstansiering"
 
-#: cp/pt.c:23163
+#: cp/pt.c:23241
 #, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "explicit instansieringar av mallen %q#D som inte är en klass"
 
-#: cp/pt.c:23165
+#: cp/pt.c:23243
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "explicit instansieringar av icke-malltyp %qT"
 
-#: cp/pt.c:23174
+#: cp/pt.c:23252
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "explicit instansiering av %q#T före definitionen av mallen"
 
-#: cp/pt.c:23192
+#: cp/pt.c:23270
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ förbjuder användning av %qE vid explicita instansieringar"
 
-#: cp/pt.c:23238
+#: cp/pt.c:23316
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "dubblerad explicit instansiering av %q#T"
 
-#: cp/pt.c:23536
+#: cp/pt.c:23614
 #, gcc-internal-format
 msgid "exception specification of %qD depends on itself"
 msgstr "explicit specifikation av %qD beror på sig själv"
@@ -47470,107 +47512,107 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:23842
+#: cp/pt.c:23920
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "explicit instansiering av %qD men ingen definition tillgänglig"
 
-#: cp/pt.c:24043
+#: cp/pt.c:24121
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr "mallinstansieringsdjupet överskrider maxvärdet på %d vid instansiering av %q+D, möjligen från generering av virtuell tabell (använd -ftemplate-depth= för att öka maxvärdet)"
 
-#: cp/pt.c:24418
+#: cp/pt.c:24496
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "ogiltig mallparameter som inte är en typ"
 
-#: cp/pt.c:24420
+#: cp/pt.c:24498
 #, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T är inte en giltig typ för en mallparameter som inte är en typ"
 
-#: cp/pt.c:25723
+#: cp/pt.c:25802
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "nyckelordet %<template%> är inte tillåtet i deklarerar-id"
 
-#: cp/pt.c:25961
+#: cp/pt.c:26040
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr "härledning från klammeromgiven initierarlista kräver %<#include <initializer_list>%>"
 
-#: cp/pt.c:26440
+#: cp/pt.c:26519
 #, gcc-internal-format
 msgid "non-class template %qT used without template arguments"
 msgstr "icke-klass-mall %qT använd utan mallargument"
 
-#: cp/pt.c:26586
+#: cp/pt.c:26665
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr "kan inte härleda mallargument för kopieinitiering av %qT, eftersom den inte har några icke-explicita härledningsguider eller användardeklarerade konstruerare"
 
-#: cp/pt.c:26593
+#: cp/pt.c:26672
 #, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "kan inte härleda mallargument till %qT, eftersom den inte några användbara härledningsguider"
 
-#: cp/pt.c:26607
+#: cp/pt.c:26686
 #, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "härledning av klassmallargument misslyckades:"
 
-#: cp/pt.c:26614
+#: cp/pt.c:26693
 #, gcc-internal-format
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "explicita härledningsguider övervägs inte vid kopieinitiering"
 
-#: cp/pt.c:26676
+#: cp/pt.c:26755
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr "direkt listinitiering av %<auto%> tar precis ett element"
 
-#: cp/pt.c:26679
+#: cp/pt.c:26758
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr "för härledning till %<std::initializer_list%>, använd kopielistinitiering (d.v.s. lägg till %<=%> före %<{%>)"
 
-#: cp/pt.c:26711
+#: cp/pt.c:26790
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr "%qT som en typ snarare en enkel %<decltype(auto)%>"
 
-#: cp/pt.c:26746
+#: cp/pt.c:26825
 #, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "kan inte härleda lambdareturtyp från %qE"
 
-#: cp/pt.c:26748
+#: cp/pt.c:26827
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "kan inte härleda %qT från %qE"
 
-#: cp/pt.c:26781
+#: cp/pt.c:26860
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr "platshållarbegränsningar är inte uppfyllt"
 
-#: cp/pt.c:26785
+#: cp/pt.c:26864
 #, gcc-internal-format
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "härledd initierare uppfyller inte sina platshållarbegränsningar"
 
-#: cp/pt.c:26789
+#: cp/pt.c:26868
 #, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "härledd returtyp uppfyller inte sina platshållarbegränsningar"
 
-#: cp/pt.c:26793
+#: cp/pt.c:26872
 #, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "härledd uttryckstyp uppfyller inte sina platshållarbegränsningar"
 
-#: cp/pt.c:26912
+#: cp/pt.c:26991
 #, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr "felaktig användning av %qT i mallargument"
@@ -47625,77 +47667,77 @@
 msgid "cannot dynamic_cast %qE (of type %q#T) to type %q#T (%s)"
 msgstr "kan inte dynamic_cast %qE (av typ %q#T) till typ %q#T (%s)"
 
-#: cp/search.c:240
+#: cp/search.c:243
 #, gcc-internal-format
 msgid "%qT is an ambiguous base of %qT"
 msgstr "%qT är en tvetydig bas till %qT"
 
-#: cp/search.c:256
+#: cp/search.c:259
 #, gcc-internal-format
 msgid "%qT is an inaccessible base of %qT"
 msgstr "%qT är en oåtkomlig bas till %qT"
 
-#: cp/search.c:1905
+#: cp/search.c:1908
 #, gcc-internal-format
 msgid "invalid covariant return type for %q#D"
 msgstr "ogiltig kovariant returtyp för %q#D"
 
-#: cp/search.c:1907 cp/search.c:1922 cp/search.c:1928 cp/search.c:1957
+#: cp/search.c:1910 cp/search.c:1925 cp/search.c:1931 cp/search.c:1960
 #, gcc-internal-format
 msgid "overridden function is %q#D"
 msgstr "åsidosatt funktion är %q#D"
 
-#: cp/search.c:1920
+#: cp/search.c:1923
 #, gcc-internal-format
 msgid "invalid covariant return type for %q+#D"
 msgstr "ogiltig kovariant returtyp för %q+#D"
 
-#: cp/search.c:1926
+#: cp/search.c:1929
 #, gcc-internal-format
 msgid "conflicting return type specified for %q+#D"
 msgstr "motstridiga returtyp angiven för %q+#D"
 
-#: cp/search.c:1942
+#: cp/search.c:1945
 #, gcc-internal-format
 msgid "looser throw specifier for %q+#F"
 msgstr "friare throw-specificerare för %q+#F"
 
-#: cp/search.c:1944
+#: cp/search.c:1947
 #, gcc-internal-format
 msgid "overridden function is %q#F"
 msgstr "åsidosatt funktion är %q#F"
 
-#: cp/search.c:1955
+#: cp/search.c:1958
 #, gcc-internal-format
 msgid "conflicting type attributes specified for %q+#D"
 msgstr "motstridiga typattribut angivna för %q+#D"
 
-#: cp/search.c:1972
+#: cp/search.c:1975
 #, gcc-internal-format
 msgid "%qD declared %<transaction_safe_dynamic%>"
 msgstr "%qD deklarerad %<transaction_safe_dynamic%>"
 
-#: cp/search.c:1974
+#: cp/search.c:1977
 #, gcc-internal-format
 msgid "overriding %qD declared %<transaction_safe%>"
 msgstr "åsidosätter %qD deklarerad %<transaction_safe%>"
 
-#: cp/search.c:1981
+#: cp/search.c:1984
 #, gcc-internal-format
 msgid "deleted function %q+D overriding non-deleted function"
 msgstr "borttagen funktion %q+D åsidosätter icke borttagen funktion"
 
-#: cp/search.c:1984 cp/search.c:1992 cp/search.c:2000
+#: cp/search.c:1987 cp/search.c:1995 cp/search.c:2003
 #, gcc-internal-format
 msgid "overridden function is %qD"
 msgstr "åsidosatt funktion är %qD"
 
-#: cp/search.c:1989
+#: cp/search.c:1992
 #, gcc-internal-format
 msgid "non-deleted function %q+D overriding deleted function"
 msgstr "ej borttagen funktion %q+D åsidosätter borttagen funktion"
 
-#: cp/search.c:1998
+#: cp/search.c:2001
 #, gcc-internal-format
 msgid "virtual function %q+D overriding final function"
 msgstr "virtuell funktion %q+D åsidosätter slutlig funktion"
@@ -47702,12 +47744,12 @@
 
 #. A static member function cannot match an inherited
 #. virtual member function.
-#: cp/search.c:2082
+#: cp/search.c:2085
 #, gcc-internal-format
 msgid "%q+#D cannot be declared"
 msgstr "%q+#D kan inte deklareras"
 
-#: cp/search.c:2083
+#: cp/search.c:2086
 #, gcc-internal-format
 msgid "  since %q+#D declared in base class"
 msgstr "  eftersom %q+#D är deklarerad i basklassen"
@@ -47747,576 +47789,591 @@
 msgid "invalid use of member %qD in static member function"
 msgstr "ogiltig användning av %qD i en statisk medlemsfunktion"
 
-#: cp/semantics.c:2153
+#: cp/semantics.c:2156
 #, gcc-internal-format
 msgid "a statement expression is an insufficient context for overload resolution"
 msgstr "ett satsuttryck är otillräckligt sammanhang för upplösning av överlagring"
 
-#: cp/semantics.c:2540
+#: cp/semantics.c:2543
 #, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr "argument till destruerare är inte tillåtet"
 
-#: cp/semantics.c:2622
+#: cp/semantics.c:2625
 #, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr "%<this%> är inte tillgängligt i en statisk medlemsfunktion"
 
-#: cp/semantics.c:2624
+#: cp/semantics.c:2627
 #, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr "ogiltig användning av %<this%> i icke-medlemsfunktion"
 
-#: cp/semantics.c:2626
+#: cp/semantics.c:2629
 #, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr "ogiltigt användning av %<this%> på toppnivå"
 
-#: cp/semantics.c:2648
+#: cp/semantics.c:2651
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "ogiltigt kvalificerande räckvidd i pseudodestruerarnamn"
 
-#: cp/semantics.c:2656 cp/typeck.c:2604
+#: cp/semantics.c:2659 cp/typeck.c:2604
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "kvalificerad typ %qT matchar inte destruerarnamnet ~%qT"
 
-#: cp/semantics.c:2678
+#: cp/semantics.c:2681
 #, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr "%qE har inte typen %qT"
 
-#: cp/semantics.c:2751
+#: cp/semantics.c:2754
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr "sammansatt litteral för ej objekttyp %qT"
 
-#: cp/semantics.c:2892
+#: cp/semantics.c:2895
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr "malltypparametrar måste använda nyckelordet %<class%> eller %<typename%>"
 
-#: cp/semantics.c:2942
+#: cp/semantics.c:2945
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr "ogiltigt användning av typ %qT som standardvärde för en mallmallparameter"
 
-#: cp/semantics.c:2945
+#: cp/semantics.c:2948
 #, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr "ogiltigt standardargument för en mallmallparameter"
 
-#: cp/semantics.c:2962
+#: cp/semantics.c:2965
 #, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr "definition av %q#T inuti mallparameterlista"
 
-#: cp/semantics.c:2993
+#: cp/semantics.c:2996
 #, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr "ogiltig definition av kvalificerad typ %qT"
 
-#: cp/semantics.c:3263
+#: cp/semantics.c:3266
 #, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "ogiltig basklasspecifikation"
 
-#: cp/semantics.c:3423
+#: cp/semantics.c:3426
 #, gcc-internal-format
 msgid "cannot capture member %qD of anonymous union"
 msgstr "kan inte fånga medlemmen %qD i anonym union"
 
-#: cp/semantics.c:3443 cp/semantics.c:9269
+#: cp/semantics.c:3446 cp/semantics.c:9272
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qD är inte fångad"
 
-#: cp/semantics.c:3448
+#: cp/semantics.c:3451
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr "lambdat har ingen standardfångst"
 
-#: cp/semantics.c:3450
+#: cp/semantics.c:3453
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr "lambda i lokal klass %q+T kan inte fånga variabler från det omgivande sammanhanget"
 
-#: cp/semantics.c:3462
+#: cp/semantics.c:3465
 #, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr "användning av lokal variabel med automatisk lagringsklass från en kringliggande funktion"
 
-#: cp/semantics.c:3464
+#: cp/semantics.c:3467
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr "användning av parameter från den kringliggande funktionen"
 
-#: cp/semantics.c:3596
+#: cp/semantics.c:3599
 #, gcc-internal-format
 msgid "use of parameter outside function body"
 msgstr "användning av parameter utanför funktionskroppen"
 
-#: cp/semantics.c:3606
+#: cp/semantics.c:3609
 #, gcc-internal-format
 msgid "missing template arguments"
 msgstr "mallargument saknas"
 
-#: cp/semantics.c:3633
+#: cp/semantics.c:3636
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr "mallparameter %qD av typ %qT är inte tillåten i ett konstant heltalsuttryck eftersom den inte är av heltals- eller uppräkningstyp"
 
-#: cp/semantics.c:3664
+#: cp/semantics.c:3667
 #, gcc-internal-format
 msgid "use of namespace %qD as expression"
 msgstr "användning av namnrymden %q+D som uttryck"
 
-#: cp/semantics.c:3669
+#: cp/semantics.c:3672
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr "användning av klassmall %qT som uttryck"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:3675
+#: cp/semantics.c:3678
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "begäran av medlem %qD är tvetydig i gitter av multipelt arv"
 
-#: cp/semantics.c:3702
+#: cp/semantics.c:3705
 #, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "%qD får inte finnas i ett konstantuttryck"
 
-#: cp/semantics.c:3841
+#: cp/semantics.c:3844
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "typen på %qE är okänd"
 
-#: cp/semantics.c:3870
+#: cp/semantics.c:3873
 #, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr "%qT är inte ett uppräkningstyp"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4009
+#: cp/semantics.c:4012
 #, gcc-internal-format
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr "Parameterpakets-__bases är endast giltiga i malldeklarationer"
 
-#: cp/semantics.c:4038
+#: cp/semantics.c:4041
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr "det går inte att applicera %<offsetof%> på destrueraren %<~%T%>"
 
-#: cp/semantics.c:4052
+#: cp/semantics.c:4055
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "det går inte att använda %<offsetof%> på medlemsfunktion %qD"
 
-#: cp/semantics.c:4056
+#: cp/semantics.c:4059
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function"
 msgstr "det går inte att använda %<offsetof%> på en medlemsfunktion"
 
-#: cp/semantics.c:4061
+#: cp/semantics.c:4064
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr "det går inte att använda %<offsetof%> på en uppräknare %qD"
 
-#: cp/semantics.c:4072
+#: cp/semantics.c:4075
 #, gcc-internal-format
 msgid "offsetof within non-standard-layout type %qT is conditionally-supported"
 msgstr "offsetof inom icke-standardlayouttypen %qT är villkorligt stött"
 
-#: cp/semantics.c:4583 cp/semantics.c:6069 cp/semantics.c:6140
-#: cp/semantics.c:6183 cp/semantics.c:6533 cp/semantics.c:6632
-#: cp/semantics.c:6775
+#: cp/semantics.c:4586 cp/semantics.c:6072 cp/semantics.c:6143
+#: cp/semantics.c:6186 cp/semantics.c:6536 cp/semantics.c:6635
+#: cp/semantics.c:6778
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr "%<this%> tillåtet i OpenMP endast i %<declare simd%>-klausuler"
 
-#: cp/semantics.c:5271
+#: cp/semantics.c:5274
 #, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr "användardefinierad reduktionsuppslagning är tvetydig"
 
-#: cp/semantics.c:5544
+#: cp/semantics.c:5547
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr "%qE i %<reduction%>-klausul är en vektor med storlek noll"
 
-#: cp/semantics.c:5592
+#: cp/semantics.c:5595
 #, gcc-internal-format
 msgid "%qE has const type for %<reduction%>"
 msgstr "%qE har const-typ för %<reduction%>"
 
-#: cp/semantics.c:5707
+#: cp/semantics.c:5710
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr "användardefinierad reduktion med konstruerarinitierare för basklassen %qT"
 
-#: cp/semantics.c:5941
+#: cp/semantics.c:5944
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr "linjär klausul med modifieraren %qs tillämpad på en variabel som inte är en referens med typen %qT"
 
-#: cp/semantics.c:5955
+#: cp/semantics.c:5958
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr "linjär klausul tillämpad på en variabel som inte är heltal och inte pekare med typen %qT"
 
-#: cp/semantics.c:5977
+#: cp/semantics.c:5980
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr "ett linjärt steguttryck måste vara ett heltal"
 
-#: cp/semantics.c:6080
+#: cp/semantics.c:6083
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD är inte en variabel i klausul %qs"
 
-#: cp/semantics.c:6152
+#: cp/semantics.c:6155
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "%qD är inte en variabel i klausul %<firstprivate%>"
 
-#: cp/semantics.c:6195
+#: cp/semantics.c:6198
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "%qD är inte en variabel i klausul %<lastprivate%>"
 
-#: cp/semantics.c:6240
+#: cp/semantics.c:6243
 #, gcc-internal-format
 msgid "%<gang%> static expression must be integral"
 msgstr "%<gang%>-statiskt uttryck måste vara heltal"
 
-#: cp/semantics.c:6254
+#: cp/semantics.c:6257
 #, gcc-internal-format
 msgid "%<gang%> static value must be positive"
 msgstr "%<gang%>-statiskt värde måste vara positivt"
 
-#: cp/semantics.c:6288
+#: cp/semantics.c:6291
 #, gcc-internal-format
 msgid "%<gang%> num expression must be integral"
 msgstr "%<gang%>-numeriskt uttryck måste vara ett heltal"
 
-#: cp/semantics.c:6291
+#: cp/semantics.c:6294
 #, gcc-internal-format
 msgid "%<vector%> length expression must be integral"
 msgstr "%<vector%>-längduttryck måste vara ett heltal"
 
-#: cp/semantics.c:6295
+#: cp/semantics.c:6298
 #, gcc-internal-format
 msgid "%<worker%> num expression must be integral"
 msgstr "%<worker%>-numeriskt uttryck måste vara ett heltal"
 
-#: cp/semantics.c:6317
+#: cp/semantics.c:6320
 #, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr "%<gang%>-numeriskt värde måste vara positivt"
 
-#: cp/semantics.c:6321
+#: cp/semantics.c:6324
 #, gcc-internal-format
 msgid "%<vector%> length value must be positive"
 msgstr "%<vector%>-längdvärdet måste vara positivt"
 
-#: cp/semantics.c:6326
+#: cp/semantics.c:6329
 #, gcc-internal-format
 msgid "%<worker%> num value must be positive"
 msgstr "%<worker%>-numeriskt värde måste vara positivt"
 
-#: cp/semantics.c:6376
+#: cp/semantics.c:6379
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr "uttryck för styckesstorlek för schemaläggning måste vara heltal"
 
-#: cp/semantics.c:6406
+#: cp/semantics.c:6409
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr "%qs-längduttryck måste vara ett heltal"
 
-#: cp/semantics.c:6419
+#: cp/semantics.c:6422
 #, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "%qs längduttryck måste vara ett positivt konstant heltalsuttryck"
 
-#: cp/semantics.c:6438
+#: cp/semantics.c:6441
 #, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr "%<async%>-uttryck måste vara heltal"
 
-#: cp/semantics.c:6466
+#: cp/semantics.c:6469
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr "%<thread_limit%>-uttryck måste vara heltal"
 
-#: cp/semantics.c:6495
+#: cp/semantics.c:6498
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr "%<device%>-id måste vara ett heltal"
 
-#: cp/semantics.c:6516
+#: cp/semantics.c:6519
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr "%<dist_schedule%> styckesstorleksuttryck måste vara heltal"
 
-#: cp/semantics.c:6543
+#: cp/semantics.c:6546
 #, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qD är inte en variabel i %<aligned%>-klausul"
 
-#: cp/semantics.c:6557
+#: cp/semantics.c:6560
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr "%qE i %<aligned%>-klausul är varken en pekare eller en vektor eller en referens till pekare eller vektor"
 
-#: cp/semantics.c:6563
+#: cp/semantics.c:6566
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr "%qD förekommer mer än en gång i %<aligned%>-klausuler"
 
-#: cp/semantics.c:6576
+#: cp/semantics.c:6579
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr "%<aligned%>-klausuls justeringsuttryck måste vara heltal"
 
-#: cp/semantics.c:6625
+#: cp/semantics.c:6628
 #, gcc-internal-format
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr "%qD är inte en variabel i %<depend%>-klausul"
 
-#: cp/semantics.c:6910
+#: cp/semantics.c:6913
 #, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr "mallen %qE i-klausulen %qs"
 
-#: cp/semantics.c:6914
+#: cp/semantics.c:6917
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr "överlagrad funktion med namnet %qE i klausulen %qs"
 
-#: cp/semantics.c:6979
+#: cp/semantics.c:6982
 #, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr "%<grainsize%>-uttryck måste vara ett heltal"
 
-#: cp/semantics.c:7008
+#: cp/semantics.c:7011
 #, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr "%<priority%>-uttryck måste vara ett heltal"
 
-#: cp/semantics.c:7037
+#: cp/semantics.c:7040
 #, gcc-internal-format
 msgid "%<num_tasks%> expression must be integral"
 msgstr "%<num_tasks%>-uttryck måste vara ett heltal"
 
-#: cp/semantics.c:7066
+#: cp/semantics.c:7069
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr "%qs-variabeln är varken en pekare, eller en vektor eller en referens till pekare eller vektor"
 
-#: cp/semantics.c:7105
+#: cp/semantics.c:7108
 #, gcc-internal-format
 msgid "%<tile%> argument needs integral type"
 msgstr "%<tile%>-argumentet behöver en heltalstyp"
 
-#: cp/semantics.c:7524
+#: cp/semantics.c:7527
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr "%<threadprivate%> %qD är inte fil-, namnrymds- eller blockräckviddsvariabel"
 
-#: cp/semantics.c:7538
+#: cp/semantics.c:7541
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "%<threadprivate%> %qE-direktiv inte i %qT-definition"
 
-#: cp/semantics.c:7743
+#: cp/semantics.c:7746
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr "skillnaden mellan %qE och %qD har inte heltalstyp"
 
-#: cp/semantics.c:8171
+#: cp/semantics.c:8174
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr "%<#pragma omp simd%> använd med klassiterationsvariabeln %qE"
 
-#: cp/semantics.c:8398 cp/semantics.c:8408
+#: cp/semantics.c:8401 cp/semantics.c:8411
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr "%<#pragma omp atomic update%> använder två olika uttryck för minne"
 
-#: cp/semantics.c:8702
+#: cp/semantics.c:8705
 #, gcc-internal-format
 msgid "static assertion failed"
 msgstr "statisk försäkran misslyckades"
 
-#: cp/semantics.c:8704
+#: cp/semantics.c:8707
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr "statisk försäkran misslyckades: %s"
 
-#: cp/semantics.c:8709
+#: cp/semantics.c:8712
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "icke-konstant villkor i statisk deklaration"
 
-#: cp/semantics.c:8739
+#: cp/semantics.c:8742
 #, gcc-internal-format
 msgid "argument to decltype must be an expression"
 msgstr "argument till decltype måste vara ett uttryck"
 
-#: cp/semantics.c:8767
+#: cp/semantics.c:8770
 #, gcc-internal-format
 msgid "decltype cannot resolve address of overloaded function"
 msgstr "decltype kan inte lösa upp adressen till en överlagrad funktion"
 
-#: cp/semantics.c:9308
+#: cp/semantics.c:9311
 #, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "operanden till vikningsuttrycket har inget oexpanderat parameterpaket"
 
-#: cp/semantics.c:9361
+#: cp/semantics.c:9364
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "båda argumenten i en binär vikning har oexpanderade parameterpaket"
 
-#: cp/semantics.c:9363
+#: cp/semantics.c:9366
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr "inga oexpanderade parameterpack i binär fold"
 
-#: cp/semantics.c:9381
+#: cp/semantics.c:9384
 #, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "icke-pekar-argument till %<__builtin_launder%>"
 
-#: cp/tree.c:1276
+#: cp/tree.c:1295
 #, gcc-internal-format
 msgid "%qV qualifiers cannot be applied to %qT"
 msgstr "%qV-kvalificerare kan inte tillämpas på %qT"
 
-#: cp/tree.c:1788
+#: cp/tree.c:1807
 #, gcc-internal-format
 msgid "lambda-expression in a constant expression"
 msgstr "lambdauttryck i ett konstant uttryck"
 
-#: cp/tree.c:1792
+#: cp/tree.c:1811
 #, gcc-internal-format
 msgid "statement-expression in a constant expression"
 msgstr "satsuttryck i ett konstant uttryck"
 
-#: cp/tree.c:4050
+#: cp/tree.c:4083
 #, gcc-internal-format
-msgid "the calling convention for %qT changes in -fabi-version=12 (GCC 8)"
-msgstr "anropskonventionen för %qT ändras i -fabi-version=12 (GCC 8)"
+msgid "-fabi-version=13 (GCC 8.2) fixes the calling convention for %qT, which was accidentally changed in 8.1"
+msgstr "-fabi-version=13 (GCC 8.2) fixar anropskonventionen för %qT, som ändrades av misstag i 8.1"
 
-#: cp/tree.c:4055
+#: cp/tree.c:4087
 #, gcc-internal-format
+msgid "-fabi-version=12 (GCC 8.1) accidentally changes the calling convention for %qT"
+msgstr "-fabi-version=12 (GCC 8.1) ändrar av misstag anropskonventionen för %qT"
+
+#: cp/tree.c:4090
+#, gcc-internal-format
+msgid " declared here"
+msgstr " deklarerad här"
+
+#: cp/tree.c:4094
+#, gcc-internal-format
+msgid "the calling convention for %qT changes in -fabi-version=13 (GCC 8.2)"
+msgstr "anropskonventionen för %qT ändras i -fabi-version=13 (GCC 8.2)"
+
+#: cp/tree.c:4096
+#, gcc-internal-format
 msgid " because all of its copy and move constructors are deleted"
 msgstr " för att alla dess kopierings- och flyttkonstruerare är borttagna"
 
-#: cp/tree.c:4416
+#: cp/tree.c:4464
 #, gcc-internal-format
 msgid "%qE attribute applied to %qD with void return type"
 msgstr "attributet %qE tillämpat på %qD med returtypen void"
 
-#: cp/tree.c:4423
+#: cp/tree.c:4471
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr "attributet %qE kan bara användas på funktioner eller på klass- eller uppräkningstyper"
 
-#: cp/tree.c:4475
+#: cp/tree.c:4523
 #, gcc-internal-format
 msgid "requested init_priority is not an integer constant"
 msgstr "begärd init_priority är inte en heltalskonstant"
 
-#: cp/tree.c:4497
+#: cp/tree.c:4545
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr "det går bara att använda attributet %qE på definitioner av objekt- eller klasstyp med filräckvidd"
 
-#: cp/tree.c:4505
+#: cp/tree.c:4553
 #, gcc-internal-format
 msgid "requested init_priority is out of range"
 msgstr "begärd init_priority är utanför sitt intervall"
 
-#: cp/tree.c:4515
+#: cp/tree.c:4563
 #, gcc-internal-format
 msgid "requested init_priority is reserved for internal use"
 msgstr "begärt init_priority är reserverad för internt bruk"
 
-#: cp/tree.c:4526
+#: cp/tree.c:4574
 #, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr "attributet %qE stödjs inte på denna plattform"
 
-#: cp/tree.c:4553
+#: cp/tree.c:4601
 #, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %qE"
 msgstr "omdeklaration av %qD lägger till abi-taggen %qE"
 
-#: cp/tree.c:4573
+#: cp/tree.c:4621
 #, gcc-internal-format
 msgid "the %qE attribute requires arguments"
 msgstr "attributet %qE behöver argument"
 
-#: cp/tree.c:4584
+#: cp/tree.c:4632
 #, gcc-internal-format
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "argumenten till attributet %qE måste vara smala strängkonstanter"
 
-#: cp/tree.c:4597 cp/tree.c:4610
+#: cp/tree.c:4645 cp/tree.c:4658
 #, gcc-internal-format
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "argumenten till attributet %qE måste innehålla giltiga identifierare"
 
-#: cp/tree.c:4599
+#: cp/tree.c:4647
 #, gcc-internal-format
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "%<%c%> är inte ett giltigt första tecken för en identifierare"
 
-#: cp/tree.c:4612
+#: cp/tree.c:4660
 #, gcc-internal-format
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "%<%c%> är inte ett giltig bokstav i en identifierare"
 
-#: cp/tree.c:4636
+#: cp/tree.c:4684
 #, gcc-internal-format
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "attributet %qE använt på typen %qT som inte är en klass eller uppräkningstyp"
 
-#: cp/tree.c:4642
+#: cp/tree.c:4690
 #, gcc-internal-format
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "attributet %qE använt på %qT efter dess definition"
 
-#: cp/tree.c:4649
+#: cp/tree.c:4697
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "ignorerar attributet %qE använt på mallinstansieringen %qT"
 
-#: cp/tree.c:4656
+#: cp/tree.c:4704
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "ignorerar attributet %qE använt på mallspecialiseringen %qT"
 
-#: cp/tree.c:4678
+#: cp/tree.c:4726
 #, gcc-internal-format
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "attributet %qE tillämpat på %qD som inte är en funktion eller variabel"
 
-#: cp/tree.c:4684
+#: cp/tree.c:4732
 #, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "attributet %qE tillämpat på extern \"C\"-deklaration %qD"
 
-#: cp/tree.c:5440
+#: cp/tree.c:5488
 #, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "noll som en nollpekarkonstant"
 
-#: cp/tree.c:5453
+#: cp/tree.c:5501
 #, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr "lang_*-kontroll: misslyckades i %s, vid %s:%d"
@@ -49400,107 +49457,107 @@
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "det går inte att initiera aggregat med typ %qT med en sammansatt litteral"
 
-#: cp/typeck2.c:1496 cp/typeck2.c:1523
+#: cp/typeck2.c:1499 cp/typeck2.c:1526
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "initierare saknas för medlem %qD"
 
-#: cp/typeck2.c:1504
+#: cp/typeck2.c:1507
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "medlem %qD är oinitierad referens"
 
-#: cp/typeck2.c:1511
+#: cp/typeck2.c:1514
 #, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr "medlem %qD med oinitierade referensfält"
 
-#: cp/typeck2.c:1587
+#: cp/typeck2.c:1590
 #, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "ordningen på designeraren för fält %qD stämmer inte med deklarationsordningen i %qT"
 
-#: cp/typeck2.c:1660
+#: cp/typeck2.c:1663
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "inget fält %qD finns i unionen som initieras"
 
-#: cp/typeck2.c:1671
+#: cp/typeck2.c:1674
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "indexvärde istället för fältnamn i unioninitierare"
 
-#: cp/typeck2.c:1858
+#: cp/typeck2.c:1861
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "cirkulär pekardelegering detekterad"
 
-#: cp/typeck2.c:1872
+#: cp/typeck2.c:1875
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "basoperanden till %<->%> har icke-pekartyp %qT"
 
-#: cp/typeck2.c:1898
+#: cp/typeck2.c:1901
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "resultatet av %<operator->()%> ger annat än pekare"
 
-#: cp/typeck2.c:1900
+#: cp/typeck2.c:1903
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "basoperanden till %<->%> är inte en pekare"
 
-#: cp/typeck2.c:1927
+#: cp/typeck2.c:1930
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE kan inte användas som en medlemspekare eftersom den är av typen %qT"
 
-#: cp/typeck2.c:1936
+#: cp/typeck2.c:1939
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "det går inte att applicera medlemspekare %qE på %qE, som är av typ %qT som inte är en klass"
 
-#: cp/typeck2.c:1958
+#: cp/typeck2.c:1961
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "pekare-på-medlemstyp %qT är inkompatibel med objekttyp %qT"
 
-#: cp/typeck2.c:2018
+#: cp/typeck2.c:2021
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "pekare-till-medlemsfunktionstyp %qT kräver ett r-värde"
 
-#: cp/typeck2.c:2029
+#: cp/typeck2.c:2032
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "pekare-till-medlemsfunktiontyp %qT kräver ett l-värde"
 
-#: cp/typeck2.c:2037
+#: cp/typeck2.c:2040
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++2a"
 msgstr "pekare-till-medlemsfunktiontyp %qT kräver ett l-värde före C++2a"
 
-#: cp/typeck2.c:2080
+#: cp/typeck2.c:2083
 #, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "funktionell konvertering till vektortypen %qT"
 
-#: cp/typeck2.c:2096
+#: cp/typeck2.c:2099
 #, gcc-internal-format
 msgid "cannot deduce template arguments for %qT from ()"
 msgstr "kan inte härleda mallargument för %qT från ()"
 
-#: cp/typeck2.c:2114
+#: cp/typeck2.c:2117
 #, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "ogiltig värdeinitiering av referenstyper"
 
-#: cp/typeck2.c:2341
+#: cp/typeck2.c:2344
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "anrop till funktion %qD som kastar ofullständig typ %q#T"
 
-#: cp/typeck2.c:2344
+#: cp/typeck2.c:2347
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "anrop till funktion som kastar ofullständig typ %q#T"
@@ -49715,11 +49772,11 @@
 msgstr "Vektorreferens vid %C kan inte ha mer än %d dimensioner"
 
 #: fortran/array.c:221 fortran/array.c:661 fortran/check.c:2849
-#: fortran/check.c:5222 fortran/check.c:5260 fortran/check.c:5302
-#: fortran/check.c:5329 fortran/check.c:5529 fortran/match.c:1821
+#: fortran/check.c:5225 fortran/check.c:5263 fortran/check.c:5305
+#: fortran/check.c:5332 fortran/check.c:5532 fortran/match.c:1821
 #: fortran/match.c:3174 fortran/match.c:3516 fortran/match.c:3712
-#: fortran/simplify.c:2909 fortran/simplify.c:2939 fortran/simplify.c:5764
-#: fortran/simplify.c:7658
+#: fortran/simplify.c:2909 fortran/simplify.c:2939 fortran/simplify.c:5769
+#: fortran/simplify.c:7663
 #, gcc-internal-format
 msgid "Coarrays disabled at %C, use %<-fcoarray=%> to enable"
 msgstr "Co-vektorer avaktiverade vid %C, använd %<-fcoarray=%> för att aktivera"
@@ -49854,118 +49911,123 @@
 msgid "DO-iterator %qs at %L is inside iterator of the same name"
 msgstr "DO-iterator %qs vid %L är inuti en iterator med samma namn"
 
-#: fortran/array.c:1073 fortran/array.c:1255
+#: fortran/array.c:1073 fortran/array.c:1264
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in array constructor at %C"
 msgstr "Syntaxfel i vektorkonstruerare vid %C"
 
-#: fortran/array.c:1129
+#: fortran/array.c:1105
 #, gcc-internal-format, gfc-internal-format
+msgid "NULL() at %C cannot appear in an array constructor"
+msgstr "NULL() vid %C kan inte förekomma i en vektorkonstruerare"
+
+#: fortran/array.c:1138
+#, gcc-internal-format, gfc-internal-format
 msgid "[...] style array constructors at %C"
 msgstr "[...]-stils vektorkonstruerare vid %C"
 
-#: fortran/array.c:1149
+#: fortran/array.c:1158
 #, gcc-internal-format, gfc-internal-format
 msgid "Array constructor including type specification at %C"
 msgstr "Vektorkonstruerare med typspecifikation vid %C"
 
-#: fortran/array.c:1155 fortran/match.c:4148
+#: fortran/array.c:1164 fortran/match.c:4148
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-spec at %L cannot contain a deferred type parameter"
 msgstr "Typspecifikation vid %L kan inte innehålla ha en fördröjd typparameter"
 
-#: fortran/array.c:1163
+#: fortran/array.c:1172
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-spec at %L cannot contain an asterisk for a type parameter"
 msgstr "Typspecifikation vid %L kan inte innehålla en asterisk som en typparameter"
 
-#: fortran/array.c:1181
+#: fortran/array.c:1190
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty array constructor at %C is not allowed"
 msgstr "Tom vektorkonstruerare vid %C är inte tillåtet"
 
-#: fortran/array.c:1218 fortran/array.c:1228
+#: fortran/array.c:1227 fortran/array.c:1237
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible typespec for array element at %L"
 msgstr "Inkompatibel typspecifikation för vektorelement vid %L"
 
-#: fortran/array.c:1302
+#: fortran/array.c:1311
 #, gcc-internal-format, gfc-internal-format
 msgid "Element in %s array constructor at %L is %s"
 msgstr "Element i %s-vektorkonstruerare vid %L är %s"
 
-#: fortran/array.c:1633
+#: fortran/array.c:1642
 #, gcc-internal-format, gfc-internal-format
 msgid "Iterator step at %L cannot be zero"
 msgstr "Iteratorsteg vid %L kan inte vara noll"
 
-#: fortran/array.c:1770
+#: fortran/array.c:1779
 #, gcc-internal-format
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit.   See %<-fmax-array-constructor%> option"
 msgstr "Antalet element i vektorkonstrueraren vid %L kräver en ökning av den tillåtna övre gränsen %d.  Se flaggan %<-fmax-array-constructor%>"
 
-#: fortran/array.c:1940
+#: fortran/array.c:1949
 #, gcc-internal-format, gfc-internal-format
 msgid "AC-IMPLIED-DO initial expression references control variable at %L"
 msgstr "Initialt AC-IMPLIED-DO-uttryck refererar styrvariabel vid %L"
 
-#: fortran/array.c:1947
+#: fortran/array.c:1956
 #, gcc-internal-format, gfc-internal-format
 msgid "AC-IMPLIED-DO final expression references control variable at %L"
 msgstr "Slutligt AC-IMPLIED-DO-uttryck refererar styrvariabel vid %L"
 
-#: fortran/array.c:1954
+#: fortran/array.c:1963
 #, gcc-internal-format, gfc-internal-format
 msgid "AC-IMPLIED-DO step expression references control variable at %L"
 msgstr "AC-IMPLIED-DO-steguttryck refererar styrvariabel vid %L"
 
-#: fortran/array.c:1966
+#: fortran/array.c:1975
 #, gcc-internal-format, gfc-internal-format
 msgid "Array constructor value at %L shall not be unlimited polymorphic [F2008: C4106]"
 msgstr "Vektorkonstruerarvärde vid %L får inte vara obegränsat polymorft [F2008: C4106]"
 
-#: fortran/array.c:2055
+#: fortran/array.c:2067
 #, gcc-internal-format, gfc-internal-format
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor at %L"
 msgstr "Olika CHARACTER-längder (%ld/%ld) i vektorkonstruerare vid %L"
 
-#: fortran/array.c:2174
+#: fortran/array.c:2186
 #, gcc-internal-format
 msgid "spec_dimen_size(): Bad dimension"
 msgstr "spec_dimen_size(): Felaktig dimension"
 
-#: fortran/array.c:2233
+#: fortran/array.c:2245
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimension"
 msgstr "gfc_ref_dimen_size(): Felaktig dimension"
 
-#: fortran/array.c:2237
+#: fortran/array.c:2249
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array dimension at %L"
 msgstr "Felaktig vektordimension vid %L"
 
-#: fortran/array.c:2264 fortran/data.c:552 fortran/data.c:571
-#: fortran/data.c:585 fortran/data.c:714
+#: fortran/array.c:2276 fortran/data.c:563 fortran/data.c:582
+#: fortran/data.c:596 fortran/data.c:725
 #, gcc-internal-format
 msgid "Simplification error"
 msgstr "Förenklingsfel"
 
-#: fortran/array.c:2376
+#: fortran/array.c:2388
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimen_type"
 msgstr "gfc_ref_dimen_size(): Felaktig dimen_type"
 
-#: fortran/array.c:2427
+#: fortran/array.c:2439
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad dimension"
 msgstr "gfc_array_dimen_size(): Felaktig dimension"
 
-#: fortran/array.c:2472
+#: fortran/array.c:2484
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad EXPR_ARRAY expr"
 msgstr "gfc_array_dimen_size(): Felaktigt EXPR_ARRAY-uttryck"
 
-#: fortran/array.c:2620
+#: fortran/array.c:2632
 #, gcc-internal-format
 msgid "gfc_find_array_ref(): No ref found"
 msgstr "gfc_find_array_ref(): Det finns ingen referens"
@@ -50016,7 +50078,7 @@
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or PROCEDURE"
 msgstr "%qs-argumentet till inbyggd %qs vid %L måste vara INTEGER eller PROCEDURE"
 
-#: fortran/check.c:205 fortran/check.c:6658
+#: fortran/check.c:205 fortran/check.c:6661
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a constant"
 msgstr "%qs-argumentet till inbyggd %qs vid %L måste vara en konstant"
@@ -50131,7 +50193,7 @@
 msgid "Unequal character lengths (%ld/%ld) in %s at %L"
 msgstr "Olika teckenlängder (%ld/%ld) i %s vid %L"
 
-#: fortran/check.c:946 fortran/check.c:6602
+#: fortran/check.c:946 fortran/check.c:6605
 #, gcc-internal-format
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have the same type"
 msgstr "%qs- och %qs-argumenten till inbyggd %qs vid %L måste ha samma typ"
@@ -50366,9 +50428,9 @@
 msgstr "Argument %qs till inbyggd %qs vid %L skall ha typen heltal, reell eller tecken"
 
 #: fortran/check.c:1939 fortran/check.c:2525 fortran/check.c:2628
-#: fortran/check.c:2835 fortran/check.c:2880 fortran/check.c:4256
-#: fortran/check.c:4390 fortran/check.c:4445 fortran/check.c:5515
-#: fortran/check.c:5644
+#: fortran/check.c:2835 fortran/check.c:2880 fortran/check.c:4259
+#: fortran/check.c:4393 fortran/check.c:4448 fortran/check.c:5518
+#: fortran/check.c:5647
 #, gcc-internal-format
 msgid "%qs intrinsic with KIND argument at %L"
 msgstr "inbyggd %qs med KIND-argument vid %L"
@@ -50563,7 +50625,7 @@
 msgid "NULL intrinsic with allocatable MOLD at %L"
 msgstr "Inbyggd NULL med allokerbar MOLD vid %L"
 
-#: fortran/check.c:3768 fortran/check.c:5591
+#: fortran/check.c:3768 fortran/check.c:5594
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must provide at least as many elements as there are .TRUE. values in %qs (%ld/%d)"
 msgstr "%qs-argumentet till inbyggd %qs vid %L måste ge åtminstone lika många element som det finns .TRUE.-värden i %qs (%ld/%d)"
@@ -50583,372 +50645,372 @@
 msgid "%qs argument of %qs intrinsic at %L must not be a subobject of %qs"
 msgstr "%qs-argumentet till inbyggd %qs vid %L får inte vara ett underobjekt till %qs"
 
-#: fortran/check.c:3901
+#: fortran/check.c:3904
 #, gcc-internal-format, gfc-internal-format
 msgid "The argument of the RANK intrinsic at %L must be a data object"
 msgstr "Argumentet till inbyggd RANK vid %L måste vara ett dataobjekt"
 
-#: fortran/check.c:4005
+#: fortran/check.c:4008
 #, gcc-internal-format
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L must be an array of constant size"
 msgstr "%<shape%>-argumentet till inbyggd %<reshape%> vid %L måste vara en vektor av konstant storlek"
 
-#: fortran/check.c:4015
+#: fortran/check.c:4018
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L is empty"
 msgstr "%qs-argumentet till inbyggd %qs vid %L är tomt"
 
-#: fortran/check.c:4022
+#: fortran/check.c:4025
 #, gcc-internal-format
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L has more than %d elements"
 msgstr "%<shape%>-argumentet till inbyggd %<reshape%> vid %L har mer än %d element"
 
-#: fortran/check.c:4039
+#: fortran/check.c:4042
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has negative element (%d)"
 msgstr "%qs-argumentet till inbyggd %qs vid %L har negativa element (%d)"
 
-#: fortran/check.c:4071
+#: fortran/check.c:4074
 #, gcc-internal-format, gfc-internal-format
 msgid "Element %d of actual argument of RESHAPE at %L cannot be negative"
 msgstr "Elementet %d av aktuellt argument till RESHAPE vid %L får inte vara negativt"
 
-#: fortran/check.c:4109
+#: fortran/check.c:4112
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has wrong number of elements (%d/%d)"
 msgstr "%qs-argumentet till inbyggd %qs vid %L har fel antal element (%d/%d)"
 
-#: fortran/check.c:4127
+#: fortran/check.c:4130
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has out-of-range dimension (%d)"
 msgstr "%qs-argumentet till inbyggd %qs vid %L har dimension utanför giltigt intervall (%d)"
 
-#: fortran/check.c:4136
+#: fortran/check.c:4139
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has invalid permutation of dimensions (dimension %qd duplicated)"
 msgstr "%qs-argumentet till inbyggd %qs vid %L har en ogiltig permutation av dimensioner (dimension %qd dubblerad)"
 
-#: fortran/check.c:4172
+#: fortran/check.c:4175
 #, gcc-internal-format, gfc-internal-format
 msgid "Without padding, there are not enough elements in the intrinsic RESHAPE source at %L to match the shape"
 msgstr "Utan utfyllnad finns det inte tillräckligt med element i inbyggda RESHAPE-källan vid %L för att stämma med formen"
 
-#: fortran/check.c:4189 fortran/check.c:4208
+#: fortran/check.c:4192 fortran/check.c:4211
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L cannot be of type %s"
 msgstr "Argumentet %qs till inbyggd %qs vid %L kan inte ha typen %s"
 
-#: fortran/check.c:4199 fortran/check.c:4218
+#: fortran/check.c:4202 fortran/check.c:4221
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of an extensible type"
 msgstr "%qs-argumentet till inbyggd %qs vid %L måste vara en utvidgningsbar typ"
 
-#: fortran/check.c:4317
+#: fortran/check.c:4320
 #, gcc-internal-format
 msgid "SELECTED_REAL_KIND with neither %<P%> nor %<R%> argument at %L"
 msgstr "SELECTED_REAL_KIND med varken %<P%>- eller %<R%>-argument vid %L"
 
-#: fortran/check.c:4348
+#: fortran/check.c:4351
 #, gcc-internal-format
 msgid "%qs intrinsic with RADIX argument at %L"
 msgstr "inbyggd %qs med RADIX-argument vid %L"
 
-#: fortran/check.c:4383
+#: fortran/check.c:4386
 #, gcc-internal-format
 msgid "%<source%> argument of %<shape%> intrinsic at %L must not be an assumed size array"
 msgstr "%<source%>-argumentet till inbyggd %<shape%> vid %L får inte vara en vektor med antagen storlek"
 
-#: fortran/check.c:4460 fortran/check.c:6641
+#: fortran/check.c:4463 fortran/check.c:6644
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be a procedure"
 msgstr "Argument %qs till inbyggd %qs vid %L får inte vara en procedur"
 
-#: fortran/check.c:4473 fortran/check.c:4612 fortran/check.c:6633
+#: fortran/check.c:4476 fortran/check.c:4615 fortran/check.c:6636
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be TYPE(*)"
 msgstr "Argumentet %qs till inbyggd %qs vid %L skall inte vara TYPE(*)"
 
-#: fortran/check.c:4484 fortran/check.c:4624
+#: fortran/check.c:4487 fortran/check.c:4627
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be an assumed-size array"
 msgstr "Argumentet %qs till inbyggd %qs vid %L får inte vara en vektor med antagen storlek"
 
-#: fortran/check.c:4554
+#: fortran/check.c:4557
 #, gcc-internal-format
 msgid "is_c_interoperable(): gfc_simplify_expr failed"
 msgstr "is_c_interoperable(): gfc_simplify_expr misslyckades"
 
-#: fortran/check.c:4603
+#: fortran/check.c:4606
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be an interoperable data entity: %s"
 msgstr "Argumentet %qs till inbyggd %qs vid %L måste vara en interoperabel dataenhet: %s"
 
-#: fortran/check.c:4642
+#: fortran/check.c:4645
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_1 at %L to C_ASSOCIATED shall have the type TYPE(C_PTR) or TYPE(C_FUNPTR)"
 msgstr "Argumentet C_PTR_1 vid %L till C_ASSOCIATED skall ha typen TYPE(C_PTR) eller TYPE(C_FUNPTR)"
 
-#: fortran/check.c:4656
+#: fortran/check.c:4659
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_2 at %L to C_ASSOCIATED shall have the same type as C_PTR_1: %s instead of %s"
 msgstr "Argumentet C_PTR_2 vid %L till C_ASSOCIATED skall ha samma typ som C_PTR_1: %s istället för %s"
 
-#: fortran/check.c:4680
+#: fortran/check.c:4683
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_POINTER shall have the type TYPE(C_PTR)"
 msgstr "Argumentet CPTR vid %L till C_F_POINTER skall ha typen TYPE(C_PTR)"
 
-#: fortran/check.c:4692
+#: fortran/check.c:4695
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER must be a pointer"
 msgstr "Argumentet FPTR vid %L till C_F_POINTER måste vara en pekare"
 
-#: fortran/check.c:4699
+#: fortran/check.c:4702
 #, gcc-internal-format, gfc-internal-format
 msgid "FPTR argument at %L to C_F_POINTER shall not be polymorphic"
 msgstr "Argumentet FPTR vid %L till C_F_POINTER får inte vara polymorft"
 
-#: fortran/check.c:4706
+#: fortran/check.c:4709
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER shall not be coindexed"
 msgstr "Argumentet FPTR vid %L till C_F_POINTER skall inte vara co-indexerat"
 
-#: fortran/check.c:4713
+#: fortran/check.c:4716
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected SHAPE argument at %L to C_F_POINTER with scalar FPTR"
 msgstr "Oväntat SHAPE-argumentet vid %L till C_F_POINTER med skalär FPTR"
 
-#: fortran/check.c:4719
+#: fortran/check.c:4722
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected SHAPE argument to C_F_POINTER with array FPTR at %L"
 msgstr "SHAPE-argument förväntades till C_F_POINTER med vektor FPTR vid %L"
 
-#: fortran/check.c:4738
+#: fortran/check.c:4741
 #, gcc-internal-format, gfc-internal-format
 msgid "SHAPE argument at %L to C_F_POINTER must have the same size as the RANK of FPTR"
 msgstr "SHAPE-argumentet vid %L till C_F_POINTER måste ha samma storlek som FPTR:s RANK"
 
-#: fortran/check.c:4748
+#: fortran/check.c:4751
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic FPTR at %L to C_F_POINTER"
 msgstr "Polymorf FPTR vid %L till C_F_POINTER"
 
-#: fortran/check.c:4753
+#: fortran/check.c:4756
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array FPTR at %L to C_F_POINTER: %s"
 msgstr "Ej interoperabel vektor-FPTR vid %L till C_F_POINTER: %s"
 
-#: fortran/check.c:4769
+#: fortran/check.c:4772
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_PROCPOINTER shall have the type TYPE(C_FUNPTR)"
 msgstr "Argumentet CPTR vid %L till C_F_PROCPOINTER skall ha typen TYPE(C_FUNPTR)"
 
-#: fortran/check.c:4781
+#: fortran/check.c:4784
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall be a procedure pointer"
 msgstr "Argumentet FPTR vid %L till C_F_PROCPOINTER skall vara en procedurpekare"
 
-#: fortran/check.c:4788
+#: fortran/check.c:4791
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall not be coindexed"
 msgstr "Argumentet FPTR vid %L till C_F_PROCPOINTER får inte vara co-indexerat"
 
-#: fortran/check.c:4794
+#: fortran/check.c:4797
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure pointer at %L to C_F_PROCPOINTER"
 msgstr "Ej interoperabel procedurpekare vid %L till C_F_PROCPOINTER"
 
-#: fortran/check.c:4808
+#: fortran/check.c:4811
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall not be coindexed"
 msgstr "Argumentet X vid %L till C_FUNLOC får inte vara co-indexerat"
 
-#: fortran/check.c:4823
+#: fortran/check.c:4826
 #, gcc-internal-format
 msgid "Function result %qs at %L is invalid as X argument to C_FUNLOC"
 msgstr "Funktionsresultatet %qs vid %L är ogiltigt som X-argument till C_FUNLOC"
 
-#: fortran/check.c:4831
+#: fortran/check.c:4834
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall be a procedure or a procedure pointer"
 msgstr "Argumentet X vid %L till C_FUNLOC skall vara en procedur eller en procedurpekare"
 
-#: fortran/check.c:4837
+#: fortran/check.c:4840
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure at %L to C_FUNLOC"
 msgstr "Ej interoperabel procedur vid %L till C_FUNLOC"
 
-#: fortran/check.c:4851
+#: fortran/check.c:4854
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall not be coindexed"
 msgstr "Argumentet X vid %L till C_LOC får inte vara co-indexerat"
 
-#: fortran/check.c:4857
+#: fortran/check.c:4860
 #, gcc-internal-format, gfc-internal-format
 msgid "X argument at %L to C_LOC shall not be polymorphic"
 msgstr "X-argumentet vid %L till C_LOC får inte vara polymorft"
 
-#: fortran/check.c:4868
+#: fortran/check.c:4871
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall have either the POINTER or the TARGET attribute"
 msgstr "Argumentet X vid %L till C_LOC skall antingen ha attributet POINTER eller TARGET"
 
-#: fortran/check.c:4876
+#: fortran/check.c:4879
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall be not be a zero-sized string"
 msgstr "Argumentet X vid %L till C_LOC får inte vara en sträng med längden noll"
 
-#: fortran/check.c:4885
+#: fortran/check.c:4888
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument at %L to C_LOC shall not be polymorphic"
 msgstr "Argumentet vid %L till C_LOC får inte vara polymorft"
 
-#: fortran/check.c:4892
+#: fortran/check.c:4895
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array at %L as argument to C_LOC: %s"
 msgstr "Ej interoperabel vektor vid %L som argument till C_LOC: %s"
 
-#: fortran/check.c:4903
+#: fortran/check.c:4906
 #, gcc-internal-format, gfc-internal-format
 msgid "Array of interoperable type at %L to C_LOC which is nonallocatable and neither assumed size nor explicit size"
 msgstr "Vektor med interoperabla typer vid %L till C_LOC som inte är allokerbar och varken antagen storlek eller explicit storlek"
 
-#: fortran/check.c:4908
+#: fortran/check.c:4911
 #, gcc-internal-format, gfc-internal-format
 msgid "Array section at %L to C_LOC"
 msgstr "Vektorsektion vid %L till C_LOC"
 
-#: fortran/check.c:4936
+#: fortran/check.c:4939
 #, gcc-internal-format, gfc-internal-format
 msgid "non double precision REAL argument to %s intrinsic at %L"
 msgstr "REAL-argument utan dubbel precision till inbyggd %s vid %L"
 
-#: fortran/check.c:4949
+#: fortran/check.c:4952
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be less than rank %d"
 msgstr "%qs-argumentet till inbyggd %qs vid %L måste vara av lägre ordning än %d"
 
-#: fortran/check.c:4968
+#: fortran/check.c:4971
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L is not a valid dimension index"
 msgstr "%qs-argumentet till inbyggd %qs vid %L är inte ett giltigt dimensionsindex"
 
-#: fortran/check.c:5231
+#: fortran/check.c:5234
 #, gcc-internal-format, gfc-internal-format
 msgid "%s argument to IMAGE_INDEX must be a rank one array at %L"
 msgstr "%s-argument till IMAGE_INDEX skall vara en vektor av ordning ett vid %L"
 
-#: fortran/check.c:5242
+#: fortran/check.c:5245
 #, gcc-internal-format, gfc-internal-format
 msgid "The number of array elements of the SUB argument to IMAGE_INDEX at %L shall be %d (corank) not %d"
 msgstr "Antalet vektorelement i argumentet SUB till IMAGE_INDEX vid %L skall vara %d (co-ordning) inte %d"
 
-#: fortran/check.c:5275
+#: fortran/check.c:5278
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to NUM_IMAGES at %L"
 msgstr "DISTANCE= argument till NUM_IMAGES vid %L"
 
-#: fortran/check.c:5288
+#: fortran/check.c:5291
 #, gcc-internal-format, gfc-internal-format
 msgid "FAILED= argument to NUM_IMAGES at %L"
 msgstr "FAILED=-argument till NUM_IMAGES vid %L"
 
-#: fortran/check.c:5312
+#: fortran/check.c:5315
 #, gcc-internal-format, gfc-internal-format
 msgid "TEAM argument at %L to the intrinsic TEAM_NUMBER shall be of type TEAM_TYPE"
 msgstr "Argumentet TEAM vid %L till den inbyggda TEAM_NUMBER skall ha typen TEAM_TYPE"
 
-#: fortran/check.c:5338
+#: fortran/check.c:5341
 #, gcc-internal-format, gfc-internal-format
 msgid "DIM argument without COARRAY argument not allowed for THIS_IMAGE intrinsic at %L"
 msgstr "DIM-argument utan COARRAY-argument är inte tillåtet för inbyggd THIS_IMAGE vid %L"
 
-#: fortran/check.c:5345
+#: fortran/check.c:5348
 #, gcc-internal-format, gfc-internal-format
 msgid "The DISTANCE argument may not be specified together with the COARRAY or DIM argument in intrinsic at %L"
 msgstr "Argumentet DISTANCE får inte anges tillsammans med argumentet COARRAY eller DIM i den inbyggda vid %L"
 
-#: fortran/check.c:5356
+#: fortran/check.c:5359
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected DIM argument with noncoarray argument at %L"
 msgstr "Oväntat DIM-argument med icke-co-vektor-argument vid %L"
 
-#: fortran/check.c:5374
+#: fortran/check.c:5377
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to THIS_IMAGE at %L"
 msgstr "DISTANCE= argument till THIS_IMAGE vid %L"
 
-#: fortran/check.c:5454
+#: fortran/check.c:5457
 #, gcc-internal-format
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L must not be %s"
 msgstr "%<MOLD%>-argumentet till inbyggd %<TRANSFER%> vid %L måste vara %s"
 
-#: fortran/check.c:5483
+#: fortran/check.c:5486
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic TRANSFER at %L has partly undefined result: source size %ld < result size %ld"
 msgstr "Inbyggd TRANSFER vid %L har delvis odefinierat resultat: källstorlek %ld < resultatstorlek %ld"
 
-#: fortran/check.c:5605
+#: fortran/check.c:5608
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must have the same rank as %qs or be a scalar"
 msgstr "%qs-argumentet till inbyggd %qs vid %L måste ha samma ordning som %qs eller vara en skalär"
 
-#: fortran/check.c:5618
+#: fortran/check.c:5621
 #, gcc-internal-format
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have identical shape."
 msgstr "%qs- och %qs-argumenten till inbyggd %qs vid %L måste ha identiska former."
 
-#: fortran/check.c:5861 fortran/check.c:5893
+#: fortran/check.c:5864 fortran/check.c:5896
 #, gcc-internal-format
 msgid "Size of %qs argument of %qs intrinsic at %L too small (%i/%i)"
 msgstr "Storlek på %qs-argumentet till inbyggd %qs vid %L är för liten (%i/%i)"
 
-#: fortran/check.c:5901
+#: fortran/check.c:5904
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many arguments to %s at %L"
 msgstr "För många argument till %s vid %L"
 
-#: fortran/check.c:5919
+#: fortran/check.c:5922
 #, gcc-internal-format
 msgid "fe_runtime_error string must be null terminated"
 msgstr "fe_runtime_error-sträng måste vara null-terminerad"
 
-#: fortran/check.c:5931
+#: fortran/check.c:5934
 #, gcc-internal-format, gfc-internal-format
 msgid "fe_runtime_error: Wrong number of arguments (%d instead of %d)"
 msgstr "fe_runtime_error: Fel antal argument (%d istället för %d)"
 
-#: fortran/check.c:5971
+#: fortran/check.c:5974
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr "Argumentet COUNT till SYSTEM_CLOCK vid %L har icke-standardsort"
 
-#: fortran/check.c:5990
+#: fortran/check.c:5993
 #, gcc-internal-format, gfc-internal-format
 msgid "Real COUNT_RATE argument to SYSTEM_CLOCK at %L"
 msgstr "Reellt COUNT_RATE-argument till SYSTEM_CLOCK vid %L"
 
-#: fortran/check.c:6000
+#: fortran/check.c:6003
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT_RATE argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr "Argumentet COUNT_RATE till SYSTEM_CLOCK vid %L har en icke-standardsort"
 
-#: fortran/check.c:6017
+#: fortran/check.c:6020
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT_MAX argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr "Argumentet COUNT_MAX till SYSTEM_CLOCK vid %L har en icke-standardsort"
 
-#: fortran/check.c:6234
+#: fortran/check.c:6237
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of a kind not wider than the default kind (%d)"
 msgstr "%qs-argumentet till inbyggd %qs vid %L måste ha en sort som inte är bredare än standardsorten (%d)"
 
-#: fortran/check.c:6586 fortran/check.c:6594
+#: fortran/check.c:6589 fortran/check.c:6597
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or LOGICAL"
 msgstr "%qs-argumentet till inbyggd %qs vid %L måste vara INTEGER eller LOGICAL"
 
-#: fortran/check.c:6625
+#: fortran/check.c:6628
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic function NULL at %L cannot be an actual argument to STORAGE_SIZE, because it returns a disassociated pointer"
 msgstr "Den inbyggda funktionen NULL vid %L kan inte vara ett aktuellt argument till STORATE_SIZE, eftersom den returnerar en disassocierad pekare"
@@ -50960,7 +51022,7 @@
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:727 fortran/decl.c:3636 fortran/decl.c:10066
+#: fortran/class.c:727 fortran/decl.c:3655 fortran/decl.c:10091
 #, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr "Maximal utökningsnivå nådd med typen %qs vid %L"
@@ -50985,43 +51047,48 @@
 msgid "non-constant array in DATA statement %L"
 msgstr "ickekonstant vektor i DATA-sats %L"
 
-#: fortran/data.c:137
+#: fortran/data.c:140
 #, gcc-internal-format, gfc-internal-format
 msgid "failure to simplify substring reference in DATA statement at %L"
 msgstr "misslyckades att förenkla delsträngreferens i DATA-sats vid %L"
 
-#: fortran/data.c:170
+#: fortran/data.c:173
 #, gcc-internal-format, gfc-internal-format
 msgid "Unused initialization string at %L because variable has zero length"
 msgstr "Oanvänd initieringssträng vid %L för att variabeln har nollängd"
 
-#: fortran/data.c:176
+#: fortran/data.c:179
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization string at %L was truncated to fit the variable (%ld/%ld)"
 msgstr "Initieringssträng vid %L höggs av för att stämma med variabeln (%ld/%ld)"
 
-#: fortran/data.c:265
+#: fortran/data.c:268
 #, gcc-internal-format
 msgid "%qs at %L already is initialized at %L"
 msgstr "%qs vid %L är redan initierad vid %L"
 
-#: fortran/data.c:289
+#: fortran/data.c:292
 #, gcc-internal-format, gfc-internal-format
 msgid "Data element below array lower bound at %L"
 msgstr "Dataelement under undre vektorgräns vid %L"
 
-#: fortran/data.c:306 fortran/data.c:395
+#: fortran/data.c:309 fortran/data.c:398
 #, gcc-internal-format, gfc-internal-format
 msgid "Data element above array upper bound at %L"
 msgstr "Dataelement ovanför övre vektorgräns vid %L"
 
-#: fortran/data.c:336 fortran/data.c:505
+#: fortran/data.c:339 fortran/data.c:496
 #, gcc-internal-format
 msgid "re-initialization of %qs at %L"
 msgstr "ominitiering av %qs vid %L"
 
-#: fortran/data.c:727
+#: fortran/data.c:515
 #, gcc-internal-format
+msgid "Nonpointer object %qs with default initialization shall not appear in a DATA statement at %L"
+msgstr "Objectet %qs som inte är en pekare, med standardinitierare skall inte förekomma i en DATA-sats vid %L"
+
+#: fortran/data.c:738
+#, gcc-internal-format
 msgid "TODO: Vector sections in data statements"
 msgstr "ATTGÖRA: Vektorsektionen i datasatser"
 
@@ -51045,784 +51112,784 @@
 msgid "Invalid initializer %s in Data statement at %C"
 msgstr "Ogiltig initierare %s på DATA-sats vid %C"
 
-#: fortran/decl.c:536
+#: fortran/decl.c:537
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C is not allowed in a PURE procedure"
 msgstr "Initieringen vid %C får inte förekomma i en PURE-procedur"
 
-#: fortran/decl.c:573
+#: fortran/decl.c:574
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %C cannot appear within an INTERFACE"
 msgstr "DATA-sats vid %C kan inte förekomma inuti ett INTERFACE"
 
-#: fortran/decl.c:597
+#: fortran/decl.c:598
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid substring in data-implied-do at %L in DATA statement"
 msgstr "Ogiltig delsträng i data-implicerat-do vid %L i DATA-sats"
 
-#: fortran/decl.c:619
+#: fortran/decl.c:620
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %C is not allowed in a PURE procedure"
 msgstr "DATA-sats vid %C får inte förekomma i en PURE-procedur"
 
-#: fortran/decl.c:664
+#: fortran/decl.c:662
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty old style initializer list at %C"
 msgstr "Tom gammaldags initierarlista vid %C"
 
-#: fortran/decl.c:684
+#: fortran/decl.c:671
 #, gcc-internal-format, gfc-internal-format
+msgid "Array in initializer list at %L must have an explicit shape"
+msgstr "Vektor i initierarlista vid %L måste ha en uttrycklig form"
+
+#: fortran/decl.c:694
+#, gcc-internal-format, gfc-internal-format
 msgid "Repeat spec invalid in scalar initializer at %C"
 msgstr "Repetitionsspecifikationen är felaktig i skalär initierare vid %C"
 
-#: fortran/decl.c:689
+#: fortran/decl.c:699
 #, gcc-internal-format, gfc-internal-format
 msgid "Repeat spec must be an integer at %C"
 msgstr "Repetitionsspecifikationen måste vara ett heltal vid %C"
 
-#: fortran/decl.c:698
+#: fortran/decl.c:710
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected data constant after repeat spec at %C"
 msgstr "Datakonstant förväntades efter repetitionsspecifikation vid %C"
 
-#: fortran/decl.c:729
+#: fortran/decl.c:742
 #, gcc-internal-format, gfc-internal-format
 msgid "End of scalar initializer expected at %C"
 msgstr "Slut på skalärt initieringsuttryck förväntades vid %C"
 
-#: fortran/decl.c:758
+#: fortran/decl.c:773
 #, gcc-internal-format, gfc-internal-format
-msgid "Expected constant array-spec in initializer list at %L"
-msgstr "Konstant vektorspecifikation förväntades i initierarlista vid %L"
-
-#: fortran/decl.c:767
-#, gcc-internal-format, gfc-internal-format
 msgid "Not enough elements in array initializer at %C"
 msgstr "Inte tillräckligt med element i vektorinitieraren vid %C"
 
-#: fortran/decl.c:769
+#: fortran/decl.c:775
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many elements in array initializer at %C"
 msgstr "För många element i vektorinitieraren vid %C"
 
-#: fortran/decl.c:790
+#: fortran/decl.c:795
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in old style initializer list at %C"
 msgstr "Syntaxfel i gammaldags initierarlista vid %C"
 
-#: fortran/decl.c:812
+#: fortran/decl.c:821
 #, gcc-internal-format, gfc-internal-format
 msgid "The assumed-rank array at %C shall not have a codimension"
 msgstr "Vektorn med antagen ordning vid %C får inte ha en co-dimension"
 
-#: fortran/decl.c:876
+#: fortran/decl.c:885
 #, gcc-internal-format, gfc-internal-format
 msgid "Sum of array rank %d and corank %d at %C exceeds maximum allowed dimensions of %d"
 msgstr "Summan av vektorn med ordning %d och co-ordning %d vid %C överskrider maximalt tillåtna dimensioner på %d"
 
-#: fortran/decl.c:900
+#: fortran/decl.c:909
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad INTENT specification at %C"
 msgstr "Felaktig INTENT-specifikation vid %C"
 
-#: fortran/decl.c:921
+#: fortran/decl.c:930
 #, gcc-internal-format, gfc-internal-format
 msgid "deferred type parameter at %C"
 msgstr "fördröjd typparameter vid %C"
 
-#: fortran/decl.c:1004 fortran/resolve.c:11705
+#: fortran/decl.c:1013 fortran/resolve.c:11725
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr "Skalärt INTEGER-uttryck förväntades vid %L"
 
-#: fortran/decl.c:1030
+#: fortran/decl.c:1039
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style character length at %C"
 msgstr "Gammaldags teckenlängd vid %C"
 
-#: fortran/decl.c:1061
+#: fortran/decl.c:1070
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in character length specification at %C"
 msgstr "Syntaxfel i specifikation av teckenlängd vid %C"
 
-#: fortran/decl.c:1212 fortran/decl.c:1217 fortran/decl.c:1266
+#: fortran/decl.c:1221 fortran/decl.c:1226 fortran/decl.c:1275
 #, gcc-internal-format
 msgid "Procedure %qs at %C is already defined at %L"
 msgstr "Proceduren %qs vid %C är redan definierad vid %L"
 
-#: fortran/decl.c:1222
+#: fortran/decl.c:1231
 #, gcc-internal-format
 msgid "Contained procedure %qs at %C clashes with procedure defined at %L"
 msgstr "Den inneslutna proceduren %qs vid %C krockar med proceduren definierad vid %L"
 
-#: fortran/decl.c:1231
+#: fortran/decl.c:1240
 #, gcc-internal-format
 msgid "Name %qs at %C is already defined as a generic interface at %L"
 msgstr "Namnet %qs vid %C är redan definierat som ett generiskt gränssnitt vid %L"
 
-#: fortran/decl.c:1244
+#: fortran/decl.c:1253
 #, gcc-internal-format
 msgid "Procedure %qs at %C has an explicit interface from a previous declaration"
 msgstr "Proceduren %qs vid %C har ett explicit gränssnitt från en tidigare deklaration"
 
-#: fortran/decl.c:1257
+#: fortran/decl.c:1266
 #, gcc-internal-format
 msgid "Procedure %qs defined in interface body at %L clashes with internal procedure defined at %C"
 msgstr "Proceduren %qs som är definierad i gränssnittskroppen vid %L kolliderar med den interna proceduren definierad vid %C"
 
-#: fortran/decl.c:1335
+#: fortran/decl.c:1344
 #, gcc-internal-format
 msgid "Procedure %qs at %L must have the BIND(C) attribute to be C interoperable"
 msgstr "Proceduren %qs vid %L måste ha attributet BIND(C) för att vara C-interoperativ"
 
-#: fortran/decl.c:1362
+#: fortran/decl.c:1371
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because derived type %qs is not C interoperable"
 msgstr "Typen %qs vid %L är ett attrappargument till BIND(C)-proceduren %qs men är inte interoperativ med C för att den härledda typen %qs inte är interoperativ med C"
 
-#: fortran/decl.c:1369
+#: fortran/decl.c:1378
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because it is polymorphic"
 msgstr "Variabeln %qs vid %L är ett attrappargument till BIND(C)-proceduren %qs men är inte interoperativ med C eftersom den är polymorf"
 
-#: fortran/decl.c:1376
+#: fortran/decl.c:1385
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument of the BIND(C) procedure %qs but may not be C interoperable"
 msgstr "Variabeln %qs vid %L är en attrapparameter till BIND(C)-proceduren %qs men är kanske inte interoperativ med C"
 
-#: fortran/decl.c:1391
+#: fortran/decl.c:1400
 #, gcc-internal-format
 msgid "Character argument %qs at %L must be length 1 because procedure %qs is BIND(C)"
 msgstr "Teckenargument %qs vid %L måste ha längden 1 eftersom proceduren %qs är BIND(C)"
 
-#: fortran/decl.c:1404
+#: fortran/decl.c:1413
 #, gcc-internal-format
 msgid "Variable %qs at %L with ALLOCATABLE attribute in procedure %qs with BIND(C)"
 msgstr "Variabeln %qs vid %L med attributet ALLOCATABLE i proceduren %qs med BIND(C)"
 
-#: fortran/decl.c:1412
+#: fortran/decl.c:1421
 #, gcc-internal-format
 msgid "Variable %qs at %L with POINTER attribute in procedure %qs with BIND(C)"
 msgstr "Variabeln %qs vid %L med attributet POINTER i proceduren %qs med BIND(C)"
 
-#: fortran/decl.c:1421
+#: fortran/decl.c:1430
 #, gcc-internal-format
 msgid "Scalar variable %qs at %L with POINTER or ALLOCATABLE in procedure %qs with BIND(C) is not yet supported"
 msgstr "Den skalära Variabeln %qs vid %L med POINTER eller ALLOCATABLE i proceduren %qs med BIND(C) stödjs inte ännu"
 
-#: fortran/decl.c:1430
+#: fortran/decl.c:1439
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the OPTIONAL and the VALUE attribute because procedure %qs is BIND(C)"
 msgstr "Variabeln %qs vid %L kan inte både ha attributet OPTIONAL och VALUE eftersom proceduren %qs är BIND(C)"
 
-#: fortran/decl.c:1437
+#: fortran/decl.c:1446
 #, gcc-internal-format
 msgid "Variable %qs at %L with OPTIONAL attribute in procedure %qs which is BIND(C)"
 msgstr "Variabeln %qs vid %L med attributet OPTIONAL i proceduren %qs som är BIND(C)"
 
-#: fortran/decl.c:1448
+#: fortran/decl.c:1457
 #, gcc-internal-format
 msgid "Assumed-shape array %qs at %L as dummy argument to the BIND(C) procedure %qs at %L"
 msgstr "Vektorn %qs med antagen form vid %L som attrappargument till BIND(C)-proceduren %qs vid %L"
 
-#: fortran/decl.c:1516
+#: fortran/decl.c:1525
 #, gcc-internal-format
 msgid "Symbol %qs at %C also declared as a type at %L"
 msgstr "Symbolen %qs vid %C är också deklarerad som en typ vid %L"
 
-#: fortran/decl.c:1575
+#: fortran/decl.c:1584
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %C must be declared with a C interoperable kind since common block %qs is BIND(C)"
 msgstr "Variabeln %qs i common-blocket %qs vid %C måste deklareras med en sort som är C-interoperativ eftersom common-blocket %qs är BIND(C)"
 
-#: fortran/decl.c:1615
+#: fortran/decl.c:1624
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER length must be a constant at %L"
 msgstr "CHARACTER-längden måste vara en konstant vid %L"
 
-#: fortran/decl.c:1630
+#: fortran/decl.c:1639
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression at %L is being truncated (%ld/%ld)"
 msgstr "CHARACTER-uttryck vid %L huggs av (%ld/%ld)"
 
-#: fortran/decl.c:1638
+#: fortran/decl.c:1647
 #, gcc-internal-format, gfc-internal-format
 msgid "The CHARACTER elements of the array constructor at %L must have the same length (%ld/%ld)"
 msgstr "CHARACTER-elementen i vektorkonstrueraren vid %L måste ha samma längd (%ld/%ld)"
 
-#: fortran/decl.c:1729
+#: fortran/decl.c:1738
 #, gcc-internal-format
 msgid "Initializer not allowed for PARAMETER %qs at %C"
 msgstr "Initierare är inte tillåten för PARAMETER %qs vid %C"
 
-#: fortran/decl.c:1739
+#: fortran/decl.c:1748
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER at %L is missing an initializer"
 msgstr "PARAMETER vid %L saknar en initierare"
 
-#: fortran/decl.c:1749
+#: fortran/decl.c:1758
 #, gcc-internal-format
 msgid "Variable %qs at %C with an initializer already appears in a DATA statement"
 msgstr "Variabeln %qs vid %C med en initierare finns redan i en DATA-sats"
 
-#: fortran/decl.c:1792
+#: fortran/decl.c:1801
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot initialize parameter array at %L with variable length elements"
 msgstr "Det går inte att initiera en parametervektor vid %L med element med variabel längd"
 
-#: fortran/decl.c:1861
+#: fortran/decl.c:1870
 #, gcc-internal-format, gfc-internal-format
 msgid "Can't initialize implied-shape array at %L with scalar"
 msgstr "Det går inte att initiera en vektor med antagen form vid %L med en skalär"
 
-#: fortran/decl.c:1896
+#: fortran/decl.c:1905
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-constant lower bound in implied-shape declaration at %L"
 msgstr "Lägre gräns som inte är konstant i förmodat formad deklaration vid %L"
 
-#: fortran/decl.c:1982 fortran/decl.c:1989
+#: fortran/decl.c:1991 fortran/decl.c:1998
 #, gcc-internal-format, gfc-internal-format
 msgid "Component at %C must have the POINTER attribute"
 msgstr "Komponent vid %C måste ha attributet POINTER"
 
-#: fortran/decl.c:1998
+#: fortran/decl.c:2007
 #, gcc-internal-format
 msgid "Component %qs with CLASS at %C must be allocatable or pointer"
 msgstr "Komponenten %qs med CLASS vid %C måste vara allokerbar eller en pekare"
 
-#: fortran/decl.c:2007
+#: fortran/decl.c:2016
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr "Vektorkomponent i post vid %C måste ha fördröjd form"
 
-#: fortran/decl.c:2031 fortran/symbol.c:2230
+#: fortran/decl.c:2040 fortran/symbol.c:2244
 #, gcc-internal-format
 msgid "Component %qs at %C already declared at %L"
 msgstr "Komponenten %qs vid %C är redan deklarerad vid %L"
 
-#: fortran/decl.c:2079
+#: fortran/decl.c:2088
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer array component of structure at %C must have a deferred shape"
 msgstr "Pekarvektorkomponent i post vid %C måste ha fördröjd form"
 
-#: fortran/decl.c:2088
+#: fortran/decl.c:2097
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component of structure at %C must have a deferred shape"
 msgstr "Allokerbar komponent i post vid %C måste ha fördröjd form"
 
-#: fortran/decl.c:2097
+#: fortran/decl.c:2106
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have an explicit shape"
 msgstr "Vektorkomponent i post vid %C måste ha uttrycklig form"
 
-#: fortran/decl.c:2114
+#: fortran/decl.c:2123
 #, gcc-internal-format
 msgid "Type parameter %qs at %C has no corresponding entry in the type parameter name list at %L"
 msgstr "Typparametern %qs vid %C har ingen motsvarande post i typparameternamnlistan vid %L"
 
-#: fortran/decl.c:2171
+#: fortran/decl.c:2180
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C is ambiguous"
 msgstr "NULL()-initiering vid %C är tvetydig"
 
-#: fortran/decl.c:2188
+#: fortran/decl.c:2197
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C may not have MOLD"
 msgstr "NULL()-initiering vid %C kan inte ha MOLD"
 
-#: fortran/decl.c:2205
+#: fortran/decl.c:2214
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of pointer at %C is not allowed in a PURE procedure"
 msgstr "Initiering av pekare vid %C är inte tillåtet i en PURE-procedur"
 
-#: fortran/decl.c:2226
+#: fortran/decl.c:2235
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in pointer initialization at %C"
 msgstr "Fel i pekarinitiering vid %C"
 
-#: fortran/decl.c:2233
+#: fortran/decl.c:2242
 #, gcc-internal-format, gfc-internal-format
 msgid "non-NULL pointer initialization at %C"
 msgstr "annan pekarinitiering än NULL vid %C"
 
-#: fortran/decl.c:2256
+#: fortran/decl.c:2265
 #, gcc-internal-format
 msgid "RESULT variable %qs at %L prohibits FUNCTION name %qs at %C from appearing in a specification statement"
 msgstr "RESULT-variabeln %qs vid %L förhindrar FUNCTION-namnet %qs vid %C från att förekomma i en specifikationssats"
 
-#: fortran/decl.c:2318
+#: fortran/decl.c:2327
 #, gcc-internal-format
 msgid "%qs not allowed outside STRUCTURE at %C"
 msgstr "%qs är inte tillåtet utanför STRUCTURE vid %C"
 
-#: fortran/decl.c:2320
+#: fortran/decl.c:2329
 #, gcc-internal-format
 msgid "%qs at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr "%qs vid %C är en DEC-utökning, aktivera den med %<-fdec-structure%>"
 
-#: fortran/decl.c:2327
+#: fortran/decl.c:2336
 #, gcc-internal-format
 msgid "%qs entity cannot have attributes at %C"
 msgstr "Enheten %qs kan inte ha attribut vid %C"
 
-#: fortran/decl.c:2367
+#: fortran/decl.c:2376
 #, gcc-internal-format
 msgid "Non-PARAMETER symbol %qs at %L can't be implied-shape"
 msgstr "Icke-PARAMETER-symbolen %qs vid %L kan inte ha antagen form"
 
-#: fortran/decl.c:2377
+#: fortran/decl.c:2386
 #, gcc-internal-format, gfc-internal-format
 msgid "Implied-shape array at %L"
 msgstr "Vektor med antagen form vid %L"
 
-#: fortran/decl.c:2422
+#: fortran/decl.c:2431
 #, gcc-internal-format, gfc-internal-format
 msgid "Explicit shaped array with nonconstant bounds at %C"
 msgstr "Explicit formad vektor med ickekonstanta gränser vid %C"
 
-#: fortran/decl.c:2501
+#: fortran/decl.c:2510
 #, gcc-internal-format
 msgid "%qs at %C is a redefinition of the declaration in the corresponding interface for MODULE PROCEDURE %qs"
 msgstr "%qs vid %C är en omdefinition av deklarationen i motsvarande gränssnitt för MODULE PROCEDURE %qs"
 
-#: fortran/decl.c:2512
+#: fortran/decl.c:2521
 #, gcc-internal-format
 msgid "%qs entity cannot have an initializer at %C"
 msgstr "Enheten %qs kan inte ha en initierare vid %C"
 
-#: fortran/decl.c:2538 fortran/decl.c:8369
+#: fortran/decl.c:2547 fortran/decl.c:8388
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr "Dubblerad vektorspecifikation för Cray-utpekad vid %C"
 
-#: fortran/decl.c:2546
+#: fortran/decl.c:2555
 #, gcc-internal-format
 msgid "Couldn't set pointee array spec."
 msgstr "Kunde inte sätta utpekads vektorspecifikation."
 
-#: fortran/decl.c:2609
+#: fortran/decl.c:2618
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style initialization at %C"
 msgstr "Gammaldags initiering vid %C"
 
-#: fortran/decl.c:2617
+#: fortran/decl.c:2626
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr "Felaktig gammaldags initiering av härledd typkomponent vid %C"
 
-#: fortran/decl.c:2630
+#: fortran/decl.c:2639
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in old style initialization of %s at %C"
 msgstr "Syntaxfel i gammaldags initiering av %s vid %C"
 
-#: fortran/decl.c:2650 fortran/decl.c:6661
+#: fortran/decl.c:2659 fortran/decl.c:6680
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr "Initieringen vid %C är inte för en pekarvariabel"
 
-#: fortran/decl.c:2663
+#: fortran/decl.c:2672
 #, gcc-internal-format
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr "Pekarinitiering vid %C kräver %<=>%>, inte %<=%>"
 
-#: fortran/decl.c:2672 fortran/decl.c:10240
+#: fortran/decl.c:2681 fortran/decl.c:10265
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr "Ett initieringsuttryck förväntades vid %C"
 
-#: fortran/decl.c:2679
+#: fortran/decl.c:2688
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr "Initiering av variabel vid %C är inte tillåtet i en PURE-procedur"
 
-#: fortran/decl.c:2696
+#: fortran/decl.c:2705
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr "Initiering av allokerbar komponent vid %C är inte tillåtet"
 
-#: fortran/decl.c:2710
+#: fortran/decl.c:2719
 #, gcc-internal-format, gfc-internal-format
 msgid "The component with KIND or LEN attribute at %C does not not appear in the type parameter list at %L"
 msgstr "Komponenten med attributet KIND eller LEN vid %C förekommer inte i typparameterlistan vid %L"
 
-#: fortran/decl.c:2718
+#: fortran/decl.c:2727
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C that appears in the type parameter list at %L has neither the KIND nor LEN attribute"
 msgstr "Komponenten vid %C som förekommer i typparameterlistan vid %L har varken attributet KIND eller LEN"
 
-#: fortran/decl.c:2726
+#: fortran/decl.c:2735
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C which is a type parameter must be a scalar"
 msgstr "Pekarkomponenten vid %C som är en typparameter måste vara en skalär"
 
-#: fortran/decl.c:2789 fortran/decl.c:2825
+#: fortran/decl.c:2798 fortran/decl.c:2834
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr "Gammaldags typdeklaration %s*%d stödjs inte vid %C"
 
-#: fortran/decl.c:2831
+#: fortran/decl.c:2840
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr "Typdeklaration ej enligt standard %s*%d vid %C"
 
-#: fortran/decl.c:2890 fortran/decl.c:2967
+#: fortran/decl.c:2899 fortran/decl.c:2976
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis at %C"
 msgstr "Saknad högerparentes vid %C"
 
-#: fortran/decl.c:2903 fortran/decl.c:3038
+#: fortran/decl.c:2912 fortran/decl.c:3047
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr "Initieringsuttryck förväntades vid %C"
 
-#: fortran/decl.c:2911 fortran/decl.c:3044
+#: fortran/decl.c:2920 fortran/decl.c:3053
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr "Ett skalärt initieringsuttryck förväntades vid %C"
 
-#: fortran/decl.c:2941 fortran/decl.c:3657
+#: fortran/decl.c:2950 fortran/decl.c:3676
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr "Sorten %d stödjs inte för typen %s vid %C"
 
-#: fortran/decl.c:2954
+#: fortran/decl.c:2963
 #, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr "Parameter med sort C är för typ %s men typen vid %L är %s"
 
-#: fortran/decl.c:2965
+#: fortran/decl.c:2974
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr "Högerparentes eller komma saknas vid %C"
 
-#: fortran/decl.c:3070
+#: fortran/decl.c:3079
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr "Sorten %d stödjs inte för typen CHARACTER vid %C"
 
-#: fortran/decl.c:3202
+#: fortran/decl.c:3211
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr "Syntaxfel i CHARACTER-deklaration vid %C"
 
-#: fortran/decl.c:3291
+#: fortran/decl.c:3310
 #, gcc-internal-format, gfc-internal-format
 msgid "RECORD at %C is an extension, enable it with -fdec-structure"
 msgstr "RECORD vid %C är en utökning, aktivera den med -fdec-structure"
 
-#: fortran/decl.c:3304
+#: fortran/decl.c:3323
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected after RECORD at %C"
 msgstr "Postnamn förväntades efter RECORD vid %C"
 
-#: fortran/decl.c:3417
+#: fortran/decl.c:3436
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C cannot contain both ASSUMED and DEFERRED parameters"
 msgstr "Typparameterspecifikationslistan vid %C får inte innehålla både ASSUMED- och DEFERRED-parametrar"
 
-#: fortran/decl.c:3441
+#: fortran/decl.c:3460
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C does not contain enough parameter expressions"
 msgstr "Typparameterspecifikationslistan vid %C innehåller inte tillräckligt med parameteruttryck"
 
-#: fortran/decl.c:3465
+#: fortran/decl.c:3484
 #, gcc-internal-format
 msgid "The derived parameter %qs at %C does not have a default value"
 msgstr "Den härledda parametern %qs vid %C har inte ett standardvärde"
 
-#: fortran/decl.c:3497
+#: fortran/decl.c:3516
 #, gcc-internal-format, gfc-internal-format
 msgid "The parameter expression at %C must be of INTEGER type and not %s type"
 msgstr "Parameteruttrycket vid %C måste vara av typen INTEGER och inte av typen %s"
 
-#: fortran/decl.c:3525
+#: fortran/decl.c:3544
 #, gcc-internal-format
 msgid "The KIND parameter %qs at %C cannot either be ASSUMED or DEFERRED"
 msgstr "KIND-parametern %qs vid %C kan varken vara ASSUMED eller DEFERRED"
 
-#: fortran/decl.c:3532
+#: fortran/decl.c:3551
 #, gcc-internal-format
 msgid "The value for the KIND parameter %qs at %C does not reduce to a constant expression"
 msgstr "Värdet på KIND-parametern %qs vid %C reduceras inte till ett konstant uttryck"
 
-#: fortran/decl.c:3547
+#: fortran/decl.c:3566
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C contains too many parameter expressions"
 msgstr "Typparameterspecifikationslistan vid %C innehåller för många parameteruttryck"
 
-#: fortran/decl.c:3556
+#: fortran/decl.c:3575
 #, gcc-internal-format, gfc-internal-format
 msgid "Parameterized derived type at %C is ambiguous"
 msgstr "Parametriserad härledd typ vid %C är tvetydig"
 
-#: fortran/decl.c:3819
+#: fortran/decl.c:3838
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type at %C"
 msgstr "BYTE-typ vid %C"
 
-#: fortran/decl.c:3824
+#: fortran/decl.c:3843
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr "BYTE-typ använd vid %C är inte tillgänglig på målmaskinen"
 
-#: fortran/decl.c:3846
+#: fortran/decl.c:3865
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C is not allowed for components"
 msgstr "Förmodad typ vid %C är inte tillåtet för komponenter"
 
-#: fortran/decl.c:3849
+#: fortran/decl.c:3868
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr "Antagen typ vid %C"
 
-#: fortran/decl.c:3872 fortran/decl.c:3903 fortran/decl.c:3932
-#: fortran/decl.c:4216
+#: fortran/decl.c:3891 fortran/decl.c:3922 fortran/decl.c:3951
+#: fortran/decl.c:4235
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr "TYPE med inbyggd typspecifikation vid %C"
 
-#: fortran/decl.c:3928
+#: fortran/decl.c:3947
 #, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr "DOUBLE COMPLEX vid %C"
 
-#: fortran/decl.c:3971 fortran/decl.c:4107 fortran/decl.c:4119
-#: fortran/decl.c:4133 fortran/decl.c:4611 fortran/decl.c:4619
+#: fortran/decl.c:3990 fortran/decl.c:4126 fortran/decl.c:4138
+#: fortran/decl.c:4152 fortran/decl.c:4630 fortran/decl.c:4638
 #, gcc-internal-format
 msgid "Type name %qs at %C is ambiguous"
 msgstr "Typnamnet %qs vid %C är tvetydigt"
 
-#: fortran/decl.c:4066
+#: fortran/decl.c:4085
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS statement at %C"
 msgstr "CLASS-sats vid %C"
 
-#: fortran/decl.c:4148
+#: fortran/decl.c:4167
 #, gcc-internal-format
 msgid "Type name %qs at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr "Typnamnet %qs vid %C står i konflikt med tidigare deklarerad enhet vid %L, som har samma namn"
 
-#: fortran/decl.c:4287
+#: fortran/decl.c:4306
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr "Dubblerad IMPLICIT NONE-sats vid %C"
 
-#: fortran/decl.c:4296
+#: fortran/decl.c:4315
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr "IMPORT NONE med specifikationslista vid %C"
 
-#: fortran/decl.c:4355
+#: fortran/decl.c:4374
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr "Teckenintervall saknas i IMPLICIT vid %C"
 
-#: fortran/decl.c:4401
+#: fortran/decl.c:4420
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr "Bokstäver måste vara i alfabetisk ordning i IMPLICIT-sats vid %C"
 
-#: fortran/decl.c:4454
+#: fortran/decl.c:4473
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr "IMPLICIT-sats vid %C följer en IMPLICIT NONE (type)-sats"
 
-#: fortran/decl.c:4464
+#: fortran/decl.c:4483
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr "Tom IMPLICIT-sats vid %C"
 
-#: fortran/decl.c:4570
+#: fortran/decl.c:4589
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr "IMPORT-sats vid %C endast tillåten inuti en INTERFACE-kropp"
 
-#: fortran/decl.c:4577
+#: fortran/decl.c:4596
 #, gcc-internal-format, gfc-internal-format
 msgid "F2008: C1210 IMPORT statement at %C is not permitted in a module procedure interface body"
 msgstr "F2008: C1210 IMPORT-sats vid %C är inte tillåten i en moduls procedurgränssnittskropp"
 
-#: fortran/decl.c:4582
+#: fortran/decl.c:4601
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C"
 msgstr "IMPORT-sats vid %C"
 
-#: fortran/decl.c:4596
+#: fortran/decl.c:4615
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr "Lista med namngivna entiteter förväntades vid %C"
 
-#: fortran/decl.c:4625
+#: fortran/decl.c:4644
 #, gcc-internal-format
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr "Det går inte att IMPORT:era %qs från värdräckviddsenhet vid %C — finns inte."
 
-#: fortran/decl.c:4632
+#: fortran/decl.c:4651
 #, gcc-internal-format
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr "%qs är redan IMPORT:erad från värdräckviddsenhet vid %C."
 
-#: fortran/decl.c:4673
+#: fortran/decl.c:4692
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IMPORT statement at %C"
 msgstr "Syntaxfel i IMPORT-sats vid %C"
 
-#: fortran/decl.c:5010
+#: fortran/decl.c:5029
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing codimension specification at %C"
 msgstr "Co-dimensionsspecifikation saknas vid %C"
 
-#: fortran/decl.c:5012
+#: fortran/decl.c:5031
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr "Dimensionsspecifikation saknas vid %C"
 
-#: fortran/decl.c:5107
+#: fortran/decl.c:5126
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr "Dubblerat %s-attribut vid %L"
 
-#: fortran/decl.c:5124
+#: fortran/decl.c:5143
 #, gcc-internal-format
 msgid "%s at %L is a DEC extension, enable with %<-fdec-static%>"
 msgstr "%s vid %L är en DEC-utökning, aktivera den med %<-fdec-static%>"
 
-#: fortran/decl.c:5141
+#: fortran/decl.c:5160
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr "Attributet ALLOCATABLE vid %C i en TYPE-definition"
 
-#: fortran/decl.c:5150
+#: fortran/decl.c:5169
 #, gcc-internal-format, gfc-internal-format
 msgid "KIND attribute at %C in a TYPE definition"
 msgstr "Attributet KIND vid %C i en TYPE-definition"
 
-#: fortran/decl.c:5158
+#: fortran/decl.c:5177
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be INTEGER"
 msgstr "Komponent med attributet KIND vid %C måste vara INTEGER"
 
-#: fortran/decl.c:5165
+#: fortran/decl.c:5184
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be default integer kind (%d)"
 msgstr "Komponenten med attributet KIND vid %C måste vara av standardheltalssort (%d)"
 
-#: fortran/decl.c:5174
+#: fortran/decl.c:5193
 #, gcc-internal-format, gfc-internal-format
 msgid "LEN attribute at %C in a TYPE definition"
 msgstr "Attributet LEN vid %C i en TYPE-definition"
 
-#: fortran/decl.c:5182
+#: fortran/decl.c:5201
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be INTEGER"
 msgstr "Komponenten med attributet LEN vid %C måste vara INTEGER"
 
-#: fortran/decl.c:5189
+#: fortran/decl.c:5208
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be default integer kind (%d)"
 msgstr "Komponenten med attributet LEN vid %C måste vara av standardheltalssort (%d)"
 
-#: fortran/decl.c:5198
+#: fortran/decl.c:5217
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr "Attribut vid %L är inte tillåtet i en TYPE-definition"
 
-#: fortran/decl.c:5216
+#: fortran/decl.c:5235
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr "Attributet %s vid %L i en TYPE-definition"
 
-#: fortran/decl.c:5226
+#: fortran/decl.c:5245
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr "%s-attribut vid %L är inte tillåtet utanför specifikationsdelen av en modul"
 
-#: fortran/decl.c:5236
+#: fortran/decl.c:5255
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed outside a TYPE definition"
 msgstr "Attribut vid %L är inte tillåtet utanför en TYPE-definition"
 
-#: fortran/decl.c:5249
+#: fortran/decl.c:5268
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr "Attributet ASYNCHRONOUS vid %C"
 
-#: fortran/decl.c:5260
+#: fortran/decl.c:5279
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr "Attributet CONTIGUOUS vid %C"
 
-#: fortran/decl.c:5315 fortran/decl.c:8673
+#: fortran/decl.c:5334 fortran/decl.c:8692
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr "PROTECTED vid %C är endast tillåtet i specifikation av en del av en modul"
 
-#: fortran/decl.c:5321
+#: fortran/decl.c:5340
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute at %C"
 msgstr "Attributet PROTECTED vid %C"
 
-#: fortran/decl.c:5355
+#: fortran/decl.c:5374
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE attribute at %C"
 msgstr "Attributet VALUE vid %C"
 
-#: fortran/decl.c:5362
+#: fortran/decl.c:5381
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
 msgstr "Attributet VOLATILE vid %C"
 
-#: fortran/decl.c:5369
+#: fortran/decl.c:5388
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr "match_attr_spec(): Felaktigt attribut"
 
-#: fortran/decl.c:5410
+#: fortran/decl.c:5429
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr "Flera identifierare angivna med en ensam NAME=-specificerare vid %C"
 
-#: fortran/decl.c:5508
+#: fortran/decl.c:5527
 #, gcc-internal-format
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr "Implicit deklarerad BIND(C)-funktion %qs vid %L kan inte vara C-interoperativ"
 
-#: fortran/decl.c:5530
+#: fortran/decl.c:5549
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr "Variabeln %qs i common-blocket %qs vid %L får inte vara en sort interoperativ med C men common-blocket %qs är BIND(C)"
 
-#: fortran/decl.c:5539
+#: fortran/decl.c:5558
 #, gcc-internal-format
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr "Typdeklaration %qs vid %L är inte C-interoperativ men den är BIND(C)"
 
-#: fortran/decl.c:5543
+#: fortran/decl.c:5562
 #, gcc-internal-format
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr "Variabeln %qs vid %L får inte ha en C-interoperativ sort men den är BIND(C)"
 
-#: fortran/decl.c:5555
+#: fortran/decl.c:5574
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr "Variabeln %qs i common-blocket %qs vid %L får inte deklareras med BIND(C) eftersom den inte är en global"
 
-#: fortran/decl.c:5569
+#: fortran/decl.c:5588
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr "Variabeln %qs vid %L får inte ha både attributet POINTER och BIND(C)"
 
-#: fortran/decl.c:5577
+#: fortran/decl.c:5596
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr "Variabeln %qs vid %L får inte ha både attributet ALLOCATABLE och BIND(C)"
 
-#: fortran/decl.c:5589
+#: fortran/decl.c:5608
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr "Returtyp till BIND(C)-funktion %qs vid %L kan inte vara en vektor"
 
-#: fortran/decl.c:5597
+#: fortran/decl.c:5616
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be a character string"
 msgstr "Returtyp till BIND(C)-funktion %qs vid %L kan inte vara en teckensträng"
@@ -51829,951 +51896,956 @@
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:5608
+#: fortran/decl.c:5627
 #, gcc-internal-format
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr "Symbolen %qs vid %L är markerad PRIVATE men har getts bindningsetiketten %qs"
 
-#: fortran/decl.c:5682
+#: fortran/decl.c:5701
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr "Det behövs antingen entitet- eller common-blocknamn för attributspecifikationssatsen vid %C"
 
-#: fortran/decl.c:5727
+#: fortran/decl.c:5746
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr "Entitets- eller common-blocknamn saknas till attributspecifikationssats vid %C"
 
-#: fortran/decl.c:5734
+#: fortran/decl.c:5753
 #, gcc-internal-format
 msgid "Missing symbol"
 msgstr "Symbol saknas"
 
-#: fortran/decl.c:5763
+#: fortran/decl.c:5782
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) statement at %C"
 msgstr "BIND(C)-sats vid %C"
 
-#: fortran/decl.c:5850
+#: fortran/decl.c:5869
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr "Härledd typ vid %C har inte definierats tidigare och kan därför inte förekomma i en härledd typdefinition"
 
-#: fortran/decl.c:5892
+#: fortran/decl.c:5911
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in anonymous structure declaration at %C"
 msgstr "Syntaxfel i anonym postdeklaration vid %C"
 
-#: fortran/decl.c:5901
+#: fortran/decl.c:5920
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr "Syntaxfel i datadeklaration vid %C"
 
-#: fortran/decl.c:5951
+#: fortran/decl.c:5970
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C"
 msgstr "MODULE-prefix vid %C"
 
-#: fortran/decl.c:5996
+#: fortran/decl.c:6015
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPURE procedure at %C"
 msgstr "IMPURE-procedur vid %C"
 
-#: fortran/decl.c:6008
+#: fortran/decl.c:6027
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr "PURE och IMPURE får inte båda finnas vid %C"
 
-#: fortran/decl.c:6054
+#: fortran/decl.c:6073
 #, gcc-internal-format, gfc-internal-format
 msgid "ELEMENTAL prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr "ELEMENTAL-prefixet i MODULE PROCEDURE-gränssnittet saknas vid %L"
 
-#: fortran/decl.c:6061
+#: fortran/decl.c:6080
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr "PURE-prefixet i MODULE PROCEDURE-gränssnittet saknas vid %L"
 
-#: fortran/decl.c:6068
+#: fortran/decl.c:6087
 #, gcc-internal-format, gfc-internal-format
 msgid "RECURSIVE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr "RECURSIVE-prefixet i MODULE PROCEDURE-gränssnittet saknas vid %L"
 
-#: fortran/decl.c:6134 fortran/primary.c:1820
+#: fortran/decl.c:6153 fortran/primary.c:1820
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate-return argument at %C"
 msgstr "Alternativt returargument vid %C"
 
-#: fortran/decl.c:6140 fortran/decl.c:6148
+#: fortran/decl.c:6159 fortran/decl.c:6167
 #, gcc-internal-format, gfc-internal-format
 msgid "A parameter name is required at %C"
 msgstr "Ett parameternamn krävs vid %C"
 
-#: fortran/decl.c:6188
+#: fortran/decl.c:6207
 #, gcc-internal-format
 msgid "Name %qs at %C is the name of the procedure"
 msgstr "Namnet %qs vid %C är namnet på proceduren"
 
-#: fortran/decl.c:6201
+#: fortran/decl.c:6220
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected parameter list in type declaration at %C"
 msgstr "En parameterlista förväntades i typdeklarationen vid %C"
 
-#: fortran/decl.c:6204
+#: fortran/decl.c:6223
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr "Oväntat skräp i formell argumentlista vid %C"
 
-#: fortran/decl.c:6222
+#: fortran/decl.c:6241
 #, gcc-internal-format
 msgid "Duplicate name %qs in parameter list at %C"
 msgstr "Dubblerat namn %qs i parameterlistan vid %C"
 
-#: fortran/decl.c:6225
+#: fortran/decl.c:6244
 #, gcc-internal-format
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr "Dubblerad symbol %qs i formell argumentlista vid %C"
 
-#: fortran/decl.c:6264
+#: fortran/decl.c:6283
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in MODULE PROCEDURE formal argument names (%s/%s) at %C"
 msgstr "Formella argumentnamnen till MODULE PROCEDURE stämmer inte (%s/%s) vid %C"
 
-#: fortran/decl.c:6270
+#: fortran/decl.c:6289
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in number of MODULE PROCEDURE formal arguments at %C"
 msgstr "Antalet formella MODULE PROCEDURE-argument vid %C stämmer inte"
 
-#: fortran/decl.c:6309
+#: fortran/decl.c:6328
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr "RESULT-variabel vid %C måste vara skilt från funktionsnamnet"
 
-#: fortran/decl.c:6386
+#: fortran/decl.c:6405
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr "Oväntat skräp efter funktionsdeklaration vid %C"
 
-#: fortran/decl.c:6396 fortran/decl.c:7494
+#: fortran/decl.c:6415 fortran/decl.c:7513
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr "Attributet BIND(C) vid %L kan inte anges för en intern procedur"
 
-#: fortran/decl.c:6600
+#: fortran/decl.c:6619
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr "Attribut BIND(C) vid %C kräver ett gränssnitt med BIND(C)"
 
-#: fortran/decl.c:6607
+#: fortran/decl.c:6626
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr "BIND(C)-procedur med NAME får inte ha attributet POINTER vid %C"
 
-#: fortran/decl.c:6613
+#: fortran/decl.c:6632
 #, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr "Attrapprocedur vid %C kan inte ha attributet BIND(C) tillsammans med NAME"
 
-#: fortran/decl.c:6636
+#: fortran/decl.c:6655
 #, gcc-internal-format
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr "Proceduren %qs vid %L har redan en grundtyp %s"
 
-#: fortran/decl.c:6682 fortran/decl.c:6870 fortran/decl.c:10723
+#: fortran/decl.c:6701 fortran/decl.c:6889 fortran/decl.c:10748
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr "Syntaxfel i PROCEDURE-sats vid %C"
 
-#: fortran/decl.c:6731 fortran/decl.c:10623
+#: fortran/decl.c:6750 fortran/decl.c:10648
 #, gcc-internal-format
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr "%<::%> förväntades efter bindningsattribut vid %C"
 
-#: fortran/decl.c:6738
+#: fortran/decl.c:6757
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr "NOPASS eller explicit gränssnitt krävs vid %C"
 
-#: fortran/decl.c:6742
+#: fortran/decl.c:6761
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component at %C"
 msgstr "Procedurpekarkomponent vid %C"
 
-#: fortran/decl.c:6814
+#: fortran/decl.c:6833
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in procedure pointer component at %C"
 msgstr "Syntaxfel i procedurpekarkomponent vid %C"
 
-#: fortran/decl.c:6832
+#: fortran/decl.c:6851
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr "PROCEDURE vid %C måste vara i ett generiskt gränssnitt"
 
-#: fortran/decl.c:6841 fortran/decl.c:9392
+#: fortran/decl.c:6860 fortran/decl.c:9411
 #, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr "dubbelkolon i MODULE PROCEDURE-sats vid %L"
 
-#: fortran/decl.c:6911
+#: fortran/decl.c:6930
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE statement at %C"
 msgstr "PROCEDURE-sats vid %C"
 
-#: fortran/decl.c:6983
+#: fortran/decl.c:7002
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr "Formell argumentlista förväntades i funktionsdefinitionen vid %C"
 
-#: fortran/decl.c:7007 fortran/decl.c:7011 fortran/decl.c:7266
-#: fortran/decl.c:7270 fortran/decl.c:7462 fortran/decl.c:7466
-#: fortran/symbol.c:1875
+#: fortran/decl.c:7026 fortran/decl.c:7030 fortran/decl.c:7285
+#: fortran/decl.c:7289 fortran/decl.c:7481 fortran/decl.c:7485
+#: fortran/symbol.c:1889
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr "Attribut BIND(C) vid %L kan endast användas för variabler och common-block"
 
-#: fortran/decl.c:7164
+#: fortran/decl.c:7183
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C"
 msgstr "ENTRY-sats vid %C"
 
-#: fortran/decl.c:7173
+#: fortran/decl.c:7192
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr "ENTRY-sats vid %C kan inte förekomma inuti ett PROGRAM"
 
-#: fortran/decl.c:7176
+#: fortran/decl.c:7195
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr "ENTRY-sats vid %C kan inte förekomma inuti en MODULE"
 
-#: fortran/decl.c:7179
+#: fortran/decl.c:7198
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SUBMODULE"
 msgstr "ENTRY-sats vid %C kan inte förekomma inuti en SUBMODULE"
 
-#: fortran/decl.c:7182
+#: fortran/decl.c:7201
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr "ENTRY-sats vid %C kan inte förekomma inuti ett BLOCK DATA"
 
-#: fortran/decl.c:7186 fortran/decl.c:7231
+#: fortran/decl.c:7205 fortran/decl.c:7250
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr "ENTRY-sats vid %C kan inte förekomma inuti ett INTERFACE"
 
-#: fortran/decl.c:7190
+#: fortran/decl.c:7209
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a STRUCTURE block"
 msgstr "ENTRY-sats vid %C kan inte förekomma inuti ett STRUCTURE-block"
 
-#: fortran/decl.c:7194
+#: fortran/decl.c:7213
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr "ENTRY-sats vid %C kan inte förekomma inuti en ett DERIVED TYPE-block"
 
-#: fortran/decl.c:7198
+#: fortran/decl.c:7217
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr "ENTRY-sats vid %C kan inte förekomma inuti ett IF-THEN-block"
 
-#: fortran/decl.c:7203
+#: fortran/decl.c:7222
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr "ENTRY-sats vid %C kan inte förekomma inuti ett DO-block"
 
-#: fortran/decl.c:7207
+#: fortran/decl.c:7226
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr "ENTRY-sats vid %C kan inte förekomma inuti ett SELECT-block"
 
-#: fortran/decl.c:7211
+#: fortran/decl.c:7230
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr "ENTRY-sats vid %C kan inte förekomma inuti ett FORALL-block"
 
-#: fortran/decl.c:7215
+#: fortran/decl.c:7234
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr "ENTRY-sats vid %C kan inte förekomma inuti ett WHERE-block"
 
-#: fortran/decl.c:7219
+#: fortran/decl.c:7238
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr "ENTRY-sats vid %C kan inte förekomma inuti ett inneslutet underprogram"
 
-#: fortran/decl.c:7223
+#: fortran/decl.c:7242
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected ENTRY statement at %C"
 msgstr "Oväntad ENTRY-sats vid %C"
 
-#: fortran/decl.c:7244
+#: fortran/decl.c:7263
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr "ENTRY-sats vid %C kan inte förekomma i en innesluten procedur"
 
-#: fortran/decl.c:7295 fortran/decl.c:7501
+#: fortran/decl.c:7314 fortran/decl.c:7520
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr "Nödvändig parentes saknas före BIND(C) vid %C"
 
-#: fortran/decl.c:7563 fortran/decl.c:7570
+#: fortran/decl.c:7582 fortran/decl.c:7589
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr "Ogiltig C-identifierare i NAME=-specificerare vid %C"
 
-#: fortran/decl.c:7610
+#: fortran/decl.c:7629
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr "Syntaxfel i NAME=-specifikation för att binda etikett vid %C"
 
-#: fortran/decl.c:7626
+#: fortran/decl.c:7645
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr "NAME=-specificerare vid %C skall vara ett konstant uttryck"
 
-#: fortran/decl.c:7634
+#: fortran/decl.c:7653
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr "NAME=-specificerare vid %C skall vara en skalär av standardteckensort"
 
-#: fortran/decl.c:7653
+#: fortran/decl.c:7672
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing closing paren for binding label at %C"
 msgstr "Slutparentes saknas för att binda etikett vid %C"
 
-#: fortran/decl.c:7659
+#: fortran/decl.c:7678
 #, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr "Inget bindningsnamn är tillåtet i BIND(C) vid %C"
 
-#: fortran/decl.c:7665
+#: fortran/decl.c:7684
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr "För attrapprocedur %s är inget bindningsnamn tillåtet i BIND(C) vid %C"
 
-#: fortran/decl.c:7694
+#: fortran/decl.c:7713
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr "NAME är inte tillåtet på BIND(C) för ABSTRACT INTERFACE vid %C"
 
-#: fortran/decl.c:7939
+#: fortran/decl.c:7958
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr "Oväntad END-sats vid %C"
 
-#: fortran/decl.c:7948
+#: fortran/decl.c:7967
 #, gcc-internal-format, gfc-internal-format
 msgid "END statement instead of %s statement at %L"
 msgstr "END-sats istället för %s-sats vid %L"
 
 #. We would have required END [something].
-#: fortran/decl.c:7957
+#: fortran/decl.c:7976
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr "%s-sats förväntades vid %L"
 
-#: fortran/decl.c:7968
+#: fortran/decl.c:7987
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s statement at %L"
 msgstr "%s-sats förväntades vid %L"
 
-#: fortran/decl.c:7988
+#: fortran/decl.c:8007
 #, gcc-internal-format
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr "Blocknamn på %qs i %s-sats förväntades vid %L"
 
-#: fortran/decl.c:8005
+#: fortran/decl.c:8024
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr "Avslutande namn förväntades vid %C"
 
-#: fortran/decl.c:8019 fortran/decl.c:8027
+#: fortran/decl.c:8038 fortran/decl.c:8046
 #, gcc-internal-format
 msgid "Expected label %qs for %s statement at %C"
 msgstr "Etikett %qs för %s-sats förväntades vid %C"
 
-#: fortran/decl.c:8126
+#: fortran/decl.c:8145
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr "Vektorspecifikation saknas vid %L i DIMENSION-sats"
 
-#: fortran/decl.c:8134
+#: fortran/decl.c:8153
 #, gcc-internal-format, gfc-internal-format
 msgid "Dimensions specified for %s at %L after its initialization"
 msgstr "Dimensioner angivna för %s vid %L efter dess initiering"
 
-#: fortran/decl.c:8142
+#: fortran/decl.c:8161
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr "Vektorspecifikation saknas vid %L i CODIMENSION-sats"
 
-#: fortran/decl.c:8151
+#: fortran/decl.c:8170
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr "Vektorspecifikation måste vara fördröjd vid %L"
 
-#: fortran/decl.c:8249
+#: fortran/decl.c:8268
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr "Oväntat tecken i variabellista vid %C"
 
-#: fortran/decl.c:8286
+#: fortran/decl.c:8305
 #, gcc-internal-format
 msgid "Expected %<(%> at %C"
 msgstr "%<(%> förväntades vid %C"
 
-#: fortran/decl.c:8300 fortran/decl.c:8340
+#: fortran/decl.c:8319 fortran/decl.c:8359
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr "Variabelnamn förväntades vid %C"
 
-#: fortran/decl.c:8316
+#: fortran/decl.c:8335
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C must be an integer"
 msgstr "Cray-pekare vid %C måste vara ett heltal"
 
-#: fortran/decl.c:8320
+#: fortran/decl.c:8339
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr "Cray-pekare vid %C har %d bytes precision, minnesadresser kräver %d byte"
 
-#: fortran/decl.c:8326
+#: fortran/decl.c:8345
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr "”,” förväntades vid %C"
 
-#: fortran/decl.c:8365
+#: fortran/decl.c:8384
 #, gcc-internal-format
 msgid "Couldn't set Cray pointee array spec."
 msgstr "Kunde inte sätta Cray-utpekad vektorspecifikation."
 
-#: fortran/decl.c:8389
+#: fortran/decl.c:8408
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr "”)” förväntades vid %C"
 
-#: fortran/decl.c:8401
+#: fortran/decl.c:8420
 #, gcc-internal-format
 msgid "Expected %<,%> or end of statement at %C"
 msgstr "%<,%> eller slut på sats förväntades vid %C"
 
-#: fortran/decl.c:8427
+#: fortran/decl.c:8446
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr "INTENT är inte tillåtet inuti BLOCK vid %C"
 
-#: fortran/decl.c:8459
+#: fortran/decl.c:8478
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr "OPTIONAL är inte tillåtet inuti BLOCK vid %C"
 
-#: fortran/decl.c:8478
+#: fortran/decl.c:8497
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer declaration at %C requires -fcray-pointer flag"
 msgstr "Cray-pekardeklaration vid %C kräver flaggan -fcray-pointer"
 
-#: fortran/decl.c:8517
+#: fortran/decl.c:8536
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS statement at %C"
 msgstr "CONTIGUOUS-sats vid %C"
 
-#: fortran/decl.c:8623
+#: fortran/decl.c:8642
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr "Åtkomstspecifikation av operatorn %s vid %C har redan angivits"
 
-#: fortran/decl.c:8640
+#: fortran/decl.c:8659
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr "Åtkomstspecifikation för operatorn .%s. vid %C har redan angivits"
 
-#: fortran/decl.c:8679
+#: fortran/decl.c:8698
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED statement at %C"
 msgstr "PROTECTED-sats vid %C"
 
-#: fortran/decl.c:8717
+#: fortran/decl.c:8736
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr "Syntaxfel i PROTECTED-sats vid %C"
 
-#: fortran/decl.c:8741
+#: fortran/decl.c:8760
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr "PRIVATE-sats vid %C får endast förekomma i specifikationsdelen av en modul"
 
-#: fortran/decl.c:8778
+#: fortran/decl.c:8797
 #, gcc-internal-format, gfc-internal-format
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr "PUBLIC-sats vid %C får endast förekomma i specifikationsdelen av en modul"
 
-#: fortran/decl.c:8806
+#: fortran/decl.c:8825
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr "Variabelnamn förväntades vid %C i PARAMETER-sats"
 
-#: fortran/decl.c:8813
+#: fortran/decl.c:8832
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr "=-tecken i PARAMETER-sats förväntades vid %C"
 
-#: fortran/decl.c:8819
+#: fortran/decl.c:8838
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr "Uttryck förväntades vid %C i PARAMETER-sats"
 
-#: fortran/decl.c:8839
+#: fortran/decl.c:8858
 #, gcc-internal-format, gfc-internal-format
 msgid "Initializing already initialized variable at %C"
 msgstr "Initierar redan initierad variabel vid %C"
 
 #. With legacy PARAMETER statements, don't expect a terminating ')'.
-#: fortran/decl.c:8864
+#: fortran/decl.c:8883
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER without '()' at %C"
 msgstr "PARAMETER utan ”()” vid %C"
 
-#: fortran/decl.c:8880
+#: fortran/decl.c:8899
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr "Oväntade tecken i PARAMETER-sats vid %C"
 
-#: fortran/decl.c:8899 fortran/decl.c:8955
+#: fortran/decl.c:8918 fortran/decl.c:8974
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-static%>"
 msgstr "%s vid %C är en DEC-utökning, aktivera den med %<-fdec-static%>"
 
-#: fortran/decl.c:8934
+#: fortran/decl.c:8953
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in AUTOMATIC statement at %C"
 msgstr "Entitetslista förväntades i AUTOMATIC-sats vid %C"
 
-#: fortran/decl.c:8941
+#: fortran/decl.c:8960
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in AUTOMATIC statement at %C"
 msgstr "Syntaxfel i AUTOMATIC-sats vid %C"
 
-#: fortran/decl.c:8990
+#: fortran/decl.c:9009
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in STATIC statement at %C"
 msgstr "Entitetslista förväntades i STATIC-sats vid %C"
 
-#: fortran/decl.c:8997
+#: fortran/decl.c:9016
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in STATIC statement at %C"
 msgstr "Syntaxfel i STATIC-sats vid %C"
 
-#: fortran/decl.c:9016
+#: fortran/decl.c:9035
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr "Allmän SAVE-sats vid %C följer tidigare SAVE-sats"
 
-#: fortran/decl.c:9027
+#: fortran/decl.c:9046
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr "SAVE-sats vid %C följer allmän SAVE-sats"
 
-#: fortran/decl.c:9073
+#: fortran/decl.c:9092
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr "Syntaxfel i SAVE-sats vid %C"
 
-#: fortran/decl.c:9087
+#: fortran/decl.c:9106
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr "VALUE är inte tillåtet inuti BLOCK vid %C"
 
-#: fortran/decl.c:9091
+#: fortran/decl.c:9110
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE statement at %C"
 msgstr "VALUE-sats vid %C"
 
-#: fortran/decl.c:9129
+#: fortran/decl.c:9148
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VALUE statement at %C"
 msgstr "Syntaxfel i VALUE-sats vid %C"
 
-#: fortran/decl.c:9141
+#: fortran/decl.c:9160
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE statement at %C"
 msgstr "VOLATILE-sats vid %C"
 
-#: fortran/decl.c:9168
+#: fortran/decl.c:9187
 #, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr "VOLATILE anges för co-vektorvariabel %qs vid %C, vilket är use-/host-associerat"
 
-#: fortran/decl.c:9193
+#: fortran/decl.c:9212
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr "Syntaxfel i VOLATILE-sats vid %C"
 
-#: fortran/decl.c:9205
+#: fortran/decl.c:9224
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS statement at %C"
 msgstr "ASYNCHRONOUS-sats vid %C"
 
-#: fortran/decl.c:9249
+#: fortran/decl.c:9268
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr "Syntaxfel i ASYNCHRONOUS-sats vid %C"
 
-#: fortran/decl.c:9274
+#: fortran/decl.c:9293
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE declaration at %C"
 msgstr "MODULE PROCEDURE-deklaration vid %C"
 
-#: fortran/decl.c:9367
+#: fortran/decl.c:9386
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr "MODULE PROCEDURE vid %C måste vara i ett generiskt modulgränssnitt"
 
-#: fortran/decl.c:9425
+#: fortran/decl.c:9444
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr "Den inbyggda proceduren vid %L kan inte vara en MODULE PROCEDURE"
 
-#: fortran/decl.c:9474
+#: fortran/decl.c:9493
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr "Tvetydig symbol i TYPE-definition vid %C"
 
-#: fortran/decl.c:9483
+#: fortran/decl.c:9502
 #, gcc-internal-format
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr "Symbolen %qs vid %C har inte definierats tidigare"
 
-#: fortran/decl.c:9489
+#: fortran/decl.c:9508
 #, gcc-internal-format
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr "%qs i EXTENDS-uttryck vid %C är inte en härledd typ"
 
-#: fortran/decl.c:9496
+#: fortran/decl.c:9515
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr "%qs kan inte utökas vid %C för att den är BIND(C)"
 
-#: fortran/decl.c:9503
+#: fortran/decl.c:9522
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr "%qs kan inte utökas vid %C eftersom det är en SEQUENCE-typ"
 
-#: fortran/decl.c:9526
+#: fortran/decl.c:9545
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr "Härledd typ vid %C kan endast vara PRIVATE i specifikationsdelen av en modul"
 
-#: fortran/decl.c:9538
+#: fortran/decl.c:9557
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr "Härledd typ vid %C kan endast vara PUBLIC i specifikationsdelen av en modul"
 
-#: fortran/decl.c:9559
+#: fortran/decl.c:9578
 #, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
 msgstr "ABSTRACT typ vid %C"
 
-#: fortran/decl.c:9605
+#: fortran/decl.c:9624
 #, gcc-internal-format, gfc-internal-format
 msgid "Failed to create structure type '%s' at %C"
 msgstr "Misslyckades att skapa en post av typen ”%s” vid %C"
 
-#: fortran/decl.c:9611
+#: fortran/decl.c:9630
 #, gcc-internal-format
 msgid "Type definition of %qs at %C was already defined at %L"
 msgstr "Typdefinitionen av %qs vid %C definierades redan vid %L"
 
-#: fortran/decl.c:9658
+#: fortran/decl.c:9677
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after MAP statement at %C"
 msgstr "Skräp efter MAP-sats vid %C"
 
-#: fortran/decl.c:9691
+#: fortran/decl.c:9710
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after UNION statement at %C"
 msgstr "Skräp efter UNION-sats vid %C"
 
-#: fortran/decl.c:9726
+#: fortran/decl.c:9745
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr "%s vid %C är en DEC-utökning, aktivera den med %<-fdec-structure%>"
 
-#: fortran/decl.c:9740
+#: fortran/decl.c:9759
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected in non-nested structure declaration at %C"
 msgstr "Postnamn förväntades i icke nästad postdeklaration vid %C"
 
-#: fortran/decl.c:9758
+#: fortran/decl.c:9777
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after non-nested STRUCTURE statement at %C"
 msgstr "Skräp efter icke nästad STRUCTURE-sats vid %C"
 
-#: fortran/decl.c:9765
+#: fortran/decl.c:9784
 #, gcc-internal-format
 msgid "Structure name %qs at %C cannot be the same as an intrinsic type"
 msgstr "Postnamnet %qs vid %C får inte vara samma som en inbyggd typ"
 
-#: fortran/decl.c:9926
+#: fortran/decl.c:9947
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr ":: förväntades i TYPE-definition vid %C"
 
-#: fortran/decl.c:9954
+#: fortran/decl.c:9975
 #, gcc-internal-format
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr "Typnamnet %qs vid %C kan inte vara samma som en inbyggd typ"
 
-#: fortran/decl.c:9964
+#: fortran/decl.c:9986
 #, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr "Härlett typnamn %qs vid %C har redan en grundtyp %s"
 
-#: fortran/decl.c:9981
+#: fortran/decl.c:9989
 #, gcc-internal-format
+msgid "Derived type name %qs at %C already has a basic type"
+msgstr "Härlett typnamn %qs vid %C har redan en grundtyp"
+
+#: fortran/decl.c:10006
+#, gcc-internal-format
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr "Härledd typdefinition %qs vid %C har redan definierats"
 
-#: fortran/decl.c:10042
+#: fortran/decl.c:10067
 #, gcc-internal-format, gfc-internal-format
 msgid "Garbage after PARAMETERIZED TYPE declaration at %C"
 msgstr "Skräp efter PARAMETERIZED TYPE-deklaration vid %C"
 
-#: fortran/decl.c:10126
+#: fortran/decl.c:10151
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr "Cray-utpekad vid %C kan inte vara förmodat formad vektor"
 
-#: fortran/decl.c:10146
+#: fortran/decl.c:10171
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM and ENUMERATOR at %C"
 msgstr "ENUM och ENUMERATOR vid %C"
 
-#: fortran/decl.c:10178
+#: fortran/decl.c:10203
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr "Uppräkningstypen överskrider C:s heltalstyp vid %C"
 
-#: fortran/decl.c:10257
+#: fortran/decl.c:10282
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr "ENUMERATOR %L är inte initierad med ett heltalsuttryck"
 
-#: fortran/decl.c:10305
+#: fortran/decl.c:10330
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr "ENUM-definitionssats förväntades före %C"
 
-#: fortran/decl.c:10341
+#: fortran/decl.c:10366
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr "Syntaxfel i ENUMERATOR-definition vid %C"
 
-#: fortran/decl.c:10388 fortran/decl.c:10403
+#: fortran/decl.c:10413 fortran/decl.c:10428
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate access-specifier at %C"
 msgstr "Dubblerad åtkomstspecifikation vid %C"
 
-#: fortran/decl.c:10423
+#: fortran/decl.c:10448
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr "Bindningsattribut anger redan passing, otillåten NOPASS vid %C"
 
-#: fortran/decl.c:10443
+#: fortran/decl.c:10468
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr "Bindningsattribut anger redan passing, otillåten PASS vid %C"
 
-#: fortran/decl.c:10470
+#: fortran/decl.c:10495
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate POINTER attribute at %C"
 msgstr "Dubblerat POINTER-attribut vid %C"
 
-#: fortran/decl.c:10488
+#: fortran/decl.c:10513
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr "Dubblerad NON_OVERRIDABLE vid %C"
 
-#: fortran/decl.c:10504
+#: fortran/decl.c:10529
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DEFERRED at %C"
 msgstr "Dubblerad DEFERRED vid %C"
 
-#: fortran/decl.c:10517
+#: fortran/decl.c:10542
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected access-specifier at %C"
 msgstr "Åtkomstspecificerare förväntades vid %C"
 
-#: fortran/decl.c:10519
+#: fortran/decl.c:10544
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr "Bindningsattribut förväntades vid %C"
 
-#: fortran/decl.c:10527
+#: fortran/decl.c:10552
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED can't both appear at %C"
 msgstr "NON_OVERRIDABLE och DEFERRED kan inte båda finnas vid %C"
 
-#: fortran/decl.c:10539
+#: fortran/decl.c:10564
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr "POINTER-attribut krävs för procedurpekarkomponenten vid %C"
 
-#: fortran/decl.c:10581
+#: fortran/decl.c:10606
 #, gcc-internal-format
 msgid "Interface-name expected after %<(%> at %C"
 msgstr "Gränssnittsnamn förväntades efter %<(%> vid %C"
 
-#: fortran/decl.c:10587
+#: fortran/decl.c:10612
 #, gcc-internal-format
 msgid "%<)%> expected at %C"
 msgstr "%<)%> förväntades vid %C"
 
-#: fortran/decl.c:10607
+#: fortran/decl.c:10632
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr "Gränssnitt måste anges för DEFERRED bindning vid %C"
 
-#: fortran/decl.c:10612
+#: fortran/decl.c:10637
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr "PROCEDURE(interface) vid %C skulle vara deklarerat DEFERRED"
 
-#: fortran/decl.c:10635
+#: fortran/decl.c:10660
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr "Bindningsnamn förväntades vid %C"
 
-#: fortran/decl.c:10639
+#: fortran/decl.c:10664
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
 msgstr "PROCEDURE-lista vid %C"
 
-#: fortran/decl.c:10651
+#: fortran/decl.c:10676
 #, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr "%<=> mål%> är ogiltigt för DEFERRED-bindning vid %C"
 
-#: fortran/decl.c:10657
+#: fortran/decl.c:10682
 #, gcc-internal-format
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr "%<::%> behövs i PROCEDURE-bindning med explicit mål vid %C"
 
-#: fortran/decl.c:10667
+#: fortran/decl.c:10692
 #, gcc-internal-format
 msgid "Expected binding target after %<=>%> at %C"
 msgstr "Bindningsmål förväntades efter %<=>%> vid %C"
 
-#: fortran/decl.c:10684
+#: fortran/decl.c:10709
 #, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr "Typen %qs som innehåller en DEFERRED-bindning vid %C är inte ABSTRACT"
 
-#: fortran/decl.c:10695
+#: fortran/decl.c:10720
 #, gcc-internal-format
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr "Det finns redan en procedur med bindningsnamnet %qs för den härledda typen %qs vid %C"
 
-#: fortran/decl.c:10746
+#: fortran/decl.c:10771
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr "GENERIC vid %C måste vara inuti en härledd typs CONTAINS"
 
-#: fortran/decl.c:10766
+#: fortran/decl.c:10791
 #, gcc-internal-format
 msgid "Expected %<::%> at %C"
 msgstr "%<::%> förväntades vid %C"
 
-#: fortran/decl.c:10778
+#: fortran/decl.c:10803
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected generic name or operator descriptor at %C"
 msgstr "Generiskt namn eller operatorbeskrivare förväntades vid %C"
 
-#: fortran/decl.c:10799
+#: fortran/decl.c:10824
 #, gcc-internal-format, gfc-internal-format
 msgid "Malformed GENERIC statement at %C"
 msgstr "Felformad GENERIC-sats vid %C"
 
-#: fortran/decl.c:10810
+#: fortran/decl.c:10835
 #, gcc-internal-format
 msgid "Expected %<=>%> at %C"
 msgstr "%<=>%> förväntades vid %C"
 
-#: fortran/decl.c:10846
+#: fortran/decl.c:10871
 #, gcc-internal-format
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr "Det finns redan en icke-generisk procedur med bindningsnamnet %qs för den härledda typen %qs vid %C"
 
-#: fortran/decl.c:10854
+#: fortran/decl.c:10879
 #, gcc-internal-format
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr "Bindning vid %C måste ha samma åtkomst som den redan definierade bindningen %qs"
 
-#: fortran/decl.c:10902
+#: fortran/decl.c:10927
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr "Specifikt bindningsnamn förväntades vid %C"
 
-#: fortran/decl.c:10912
+#: fortran/decl.c:10937
 #, gcc-internal-format
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr "%qs är redan definierat som en specifik bindning för den generiska %qs vid %C"
 
-#: fortran/decl.c:10930
+#: fortran/decl.c:10955
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr "Skräp efter GENERIC-bindning vid %C"
 
-#: fortran/decl.c:10965
+#: fortran/decl.c:10990
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr "FINAL-deklaration vid %C måste vara inuti en härledd typs CONTAINS-sektion"
 
-#: fortran/decl.c:10976
+#: fortran/decl.c:11001
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr "Härledd typdeklaration med FINAL vid %C måste vara med i specifikationsdelen av en MODULE"
 
-#: fortran/decl.c:10998
+#: fortran/decl.c:11023
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr "Tom FINAL vid %C"
 
-#: fortran/decl.c:11005
+#: fortran/decl.c:11030
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr "Modulprocedurnamn förväntades vid %C"
 
-#: fortran/decl.c:11015
+#: fortran/decl.c:11040
 #, gcc-internal-format
 msgid "Expected %<,%> at %C"
 msgstr "%<,%> förväntades vid %C"
 
-#: fortran/decl.c:11021
+#: fortran/decl.c:11046
 #, gcc-internal-format
 msgid "Unknown procedure name %qs at %C"
 msgstr "Okänt procedurnamn %qs vid %C"
 
-#: fortran/decl.c:11034
+#: fortran/decl.c:11059
 #, gcc-internal-format
 msgid "%qs at %C is already defined as FINAL procedure"
 msgstr "%qs vid %C är redan definierad som FINAL procedur"
 
-#: fortran/decl.c:11104
+#: fortran/decl.c:11129
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr "Okänt attribut i !GCC$ ATTRIBUTES-sats vid %C"
 
-#: fortran/decl.c:11150
+#: fortran/decl.c:11175
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr "Syntaxfel i !GCC$ ATTRIBUTES-sats vid %C"
 
-#: fortran/decl.c:11170
+#: fortran/decl.c:11195
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive requires a non-negative integral constant less than or equal to %u at %C"
 msgstr "Direktivet %<GCC unroll%> kräver en icke-negativ heltalskonstant mindre än eller lika med %u vid %C"
 
-#: fortran/decl.c:11184
+#: fortran/decl.c:11209
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ UNROLL directive at %C"
 msgstr "Syntaxfel i direktivet !GCC$ UNROLL vid %C"
@@ -53108,27 +53180,27 @@
 msgid "BOZ literal at %L used to initialize non-integer variable %qs"
 msgstr "BOZ-litteral vid %L används för att initiera icke-heltalsvariabeln %qs"
 
-#: fortran/expr.c:3369 fortran/resolve.c:10197
+#: fortran/expr.c:3369 fortran/resolve.c:10210
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal at %L outside a DATA statement and outside INT/REAL/DBLE/CMPLX"
 msgstr "BOZ-litteral vid %L utanför en DATA-sats och utanför INT/REAL/DBLE/CMPLX"
 
-#: fortran/expr.c:3380 fortran/resolve.c:10208
+#: fortran/expr.c:3380 fortran/resolve.c:10221
 #, gcc-internal-format
 msgid "BOZ literal at %L is bitwise transferred non-integer symbol %qs"
 msgstr "BOZ-litteral vid %L är bitvis överförd icke-heltalssymbol %qs"
 
-#: fortran/expr.c:3388 fortran/resolve.c:10217
+#: fortran/expr.c:3388 fortran/resolve.c:10230
 #, gcc-internal-format
 msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "Aritmetiskt underspill av bitvis överförd BOZ vid %L.  Denna kontroll kan avaktiveras med flaggan %<-fno-range-check%>"
 
-#: fortran/expr.c:3392 fortran/resolve.c:10221
+#: fortran/expr.c:3392 fortran/resolve.c:10234
 #, gcc-internal-format
 msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "Aritmetiskt överspill vid bitvis överförd BOZ vid %L.  Denna kontroll kan avaktiveras med flaggan %<-fno-range-check%>"
 
-#: fortran/expr.c:3396 fortran/resolve.c:10225
+#: fortran/expr.c:3396 fortran/resolve.c:10238
 #, gcc-internal-format
 msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "Aritmetisk NaN vid bitvis överförd BOZ vid %L.  Denna kontroll kan avaktiveras med flaggan %<-fno-range-check%>"
@@ -53138,147 +53210,147 @@
 msgid "The assignment to a KIND or LEN component of a parameterized type at %L is not allowed"
 msgstr "Tilldelningen till en KIND- eller LEN-komponent i en parametriserad typ vid %L tillåts inte"
 
-#: fortran/expr.c:3426
+#: fortran/expr.c:3429
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible types in DATA statement at %L; attempted conversion of %s to %s"
 msgstr "Inkompatibla typer i DATA-sats vid %L, försökte med konvertering av %s till %s"
 
-#: fortran/expr.c:3465
+#: fortran/expr.c:3468
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is not a POINTER at %L"
 msgstr "Pekartilldelningsmålet är inte en POINTER vid %L"
 
-#: fortran/expr.c:3473
+#: fortran/expr.c:3476
 #, gcc-internal-format
 msgid "%qs in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgstr "%qs i pekartilldelningen vid %L kan inte vara ett l-värde eftersom det är en procedur"
 
-#: fortran/expr.c:3496
+#: fortran/expr.c:3499
 #, gcc-internal-format
 msgid "Expected bounds specification for %qs at %L"
 msgstr "Begränsningsspecifikation för %qs förväntades vid %L"
 
-#: fortran/expr.c:3501
+#: fortran/expr.c:3504
 #, gcc-internal-format
 msgid "Bounds specification for %qs in pointer assignment at %L"
 msgstr "Begränsningsspecifikation för %qs i pekartilldelning vid %L"
 
-#: fortran/expr.c:3514
+#: fortran/expr.c:3517
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower bound has to be present at %L"
 msgstr "Undre gräns måste finnas vid %L"
 
-#: fortran/expr.c:3520
+#: fortran/expr.c:3523
 #, gcc-internal-format, gfc-internal-format
 msgid "Stride must not be present at %L"
 msgstr "Steg får inte finnas vid %L"
 
-#: fortran/expr.c:3532
+#: fortran/expr.c:3535
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the upper bounds must be specified at %L"
 msgstr "Antingen alla eller ingen av de övre gränserna måste anges vid %L"
 
-#: fortran/expr.c:3558
+#: fortran/expr.c:3561
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %L shall not have a coindex"
 msgstr "Pekarobjektet vid %L kan inte ha ett co-index"
 
-#: fortran/expr.c:3579
+#: fortran/expr.c:3582
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure pointer assignment at %L"
 msgstr "Ogiltig procedurpekartilldelning vid %L"
 
-#: fortran/expr.c:3603
+#: fortran/expr.c:3606
 #, gcc-internal-format
 msgid "Function result %qs is invalid as proc-target in procedure pointer assignment at %L"
 msgstr "Funktionsresultatet %qs är ogiltigt i proc-mål i procedurpekartilldelning vid %L"
 
-#: fortran/expr.c:3612
+#: fortran/expr.c:3615
 #, gcc-internal-format
 msgid "Abstract interface %qs is invalid in procedure pointer assignment at %L"
 msgstr "Abstrakt gränssnitt %qs är ogiltigt i procedurpekartilldelning vid %L"
 
-#: fortran/expr.c:3622
+#: fortran/expr.c:3625
 #, gcc-internal-format
 msgid "Statement function %qs is invalid in procedure pointer assignment at %L"
 msgstr "Satsfunktion %qs är ogiltigt i procedurpekartilldelning vid %L"
 
-#: fortran/expr.c:3628
+#: fortran/expr.c:3631
 #, gcc-internal-format
 msgid "Internal procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "Intern procedur %qs är ogiltigt i procedurpekartilldelning vid %L"
 
-#: fortran/expr.c:3635
+#: fortran/expr.c:3638
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L is invalid in procedure pointer assignment"
 msgstr "Inbyggd %qs vid %L är ogiltigt i procedurpekartilldelning"
 
-#: fortran/expr.c:3643
+#: fortran/expr.c:3646
 #, gcc-internal-format
 msgid "Nonintrinsic elemental procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "Den ej inbyggda elementära proceduren %qs är ogiltig i procedurpekartilldelning vid %L"
 
-#: fortran/expr.c:3666
+#: fortran/expr.c:3669
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in the procedure pointer assignment at %L: mismatch in the calling convention"
 msgstr "Det stämmer inte i procedurpekartilldelningen vid %L: anropskonventionen stämmer inte"
 
-#: fortran/expr.c:3719
+#: fortran/expr.c:3722
 #, gcc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %qs is not a subroutine"
 msgstr "Gränssnitten stämmer inte överens i procedurpekartilldelning vid %L: %qs är inte en subrutin"
 
-#: fortran/expr.c:3729 fortran/expr.c:3744
+#: fortran/expr.c:3732 fortran/expr.c:3747
 #, gcc-internal-format
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr "Explicit gränssnitt krävs för komponenten %qs vid %L: %s"
 
-#: fortran/expr.c:3735 fortran/expr.c:3750 fortran/resolve.c:2566
+#: fortran/expr.c:3738 fortran/expr.c:3753 fortran/resolve.c:2566
 #, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr "Explicit gränssnitt krävs för %qs vid %L: %s"
 
-#: fortran/expr.c:3762
+#: fortran/expr.c:3765
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %s"
 msgstr "Gränssnitten stämmer inte överens i procedurpekartilldelning vid %L: %s"
 
-#: fortran/expr.c:3771
+#: fortran/expr.c:3774
 #, gcc-internal-format
 msgid "Procedure pointer target %qs at %L must be either an intrinsic, host or use associated, referenced or have the EXTERNAL attribute"
 msgstr "Procedurpekarmålet %qs vid %L måste vara antingen en inbyggd, värd, värd- eller användningsassocierad, refererad eller ha attributet EXTERNAL"
 
-#: fortran/expr.c:3788
+#: fortran/expr.c:3791
 #, gcc-internal-format, gfc-internal-format
 msgid "Data-pointer-object at %L must be unlimited polymorphic, or of a type with the BIND or SEQUENCE attribute, to be compatible with an unlimited polymorphic target"
 msgstr "Datapekarobjekt vid %L måste vara obegränsat polymorft, eller av en typ med attributet BIND eller SEQUENCE, för att vara kompatibel med ett obegränsat polymorft mål"
 
-#: fortran/expr.c:3793
+#: fortran/expr.c:3796
 #, gcc-internal-format, gfc-internal-format
 msgid "Different types in pointer assignment at %L; attempted assignment of %s to %s"
 msgstr "Olika typer i pekartilldelning vid %L, försökte med tilldelning av %s till %s"
 
-#: fortran/expr.c:3802
+#: fortran/expr.c:3805
 #, gcc-internal-format, gfc-internal-format
 msgid "Different kind type parameters in pointer assignment at %L"
 msgstr "Olika sorters typparametrar i pekartilldelning vid %L"
 
-#: fortran/expr.c:3809
+#: fortran/expr.c:3812
 #, gcc-internal-format, gfc-internal-format
 msgid "Different ranks in pointer assignment at %L"
 msgstr "Olika ordning i pekartilldelning vid %L"
 
-#: fortran/expr.c:3828
+#: fortran/expr.c:3831
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is smaller than size of the pointer (%ld < %ld) at %L"
 msgstr "Målet för översättning av ordningen är mindre än storleken på pekaren (%ld < %ld) vid %L"
 
-#: fortran/expr.c:3841
+#: fortran/expr.c:3844
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target must be rank 1 or simply contiguous at %L"
 msgstr "Målet för översättning av målet måste ha ordning 1 eller vara enkelt sammanhängande vid %L"
 
-#: fortran/expr.c:3845
+#: fortran/expr.c:3848
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is not rank 1 at %L"
 msgstr "Målet för översättning av ordning är inte av ordning 1 vid %L"
@@ -53286,147 +53358,152 @@
 #. The test above might need to be extend when F08, Note 5.4 has to be
 #. interpreted in the way that target and pointer with the same coindex
 #. are allowed.
-#: fortran/expr.c:3877 fortran/expr.c:3925
+#: fortran/expr.c:3880 fortran/expr.c:3928
 #, gcc-internal-format, gfc-internal-format
 msgid "Data target at %L shall not have a coindex"
 msgstr "Datamålet vid %L får inte ha co-index"
 
-#: fortran/expr.c:3880
+#: fortran/expr.c:3883
 #, gcc-internal-format, gfc-internal-format
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr "Måluttryck i pekartilldelning vid %L måste leverera ett pekarresultat"
 
-#: fortran/expr.c:3888
+#: fortran/expr.c:3891
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr "Pekartilldelningsmål är vare sig TARGET eller POINTER vid %L"
 
-#: fortran/expr.c:3895
+#: fortran/expr.c:3898
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr "Felaktigt mål i pekartilldelning i PURE-procedur vid %L"
 
-#: fortran/expr.c:3904
+#: fortran/expr.c:3907
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr "Pekartilldelning med vektorindexering på högersidan vid %L"
 
-#: fortran/expr.c:3912
+#: fortran/expr.c:3915
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr "Pekartilldelningsmålet har attributet PROTECTED vid %L"
 
-#: fortran/expr.c:3936
+#: fortran/expr.c:3939
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to contiguous pointer from non-contiguous target at %L"
 msgstr "Tilldelning till sammanhängande pekare från icke sammanhängande mål vid %L"
 
-#: fortran/expr.c:3975
+#: fortran/expr.c:3978
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr "Pekare vid %L i pekartilldelning kan överleva pekarmålet"
 
-#: fortran/expr.c:4051 fortran/resolve.c:1452
+#: fortran/expr.c:4054 fortran/resolve.c:1452
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr "Pekarinitieringsmål vid %L får inte vara ALLOCATABLE"
 
-#: fortran/expr.c:4057
+#: fortran/expr.c:4060
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr "Målet för pekarinitieringen vid %L måste ha attributet TARGET"
 
-#: fortran/expr.c:4072 fortran/resolve.c:1458
+#: fortran/expr.c:4075 fortran/resolve.c:1458
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr "Pekarinitieringsmål vid %L måste ha attributet SAVE"
 
-#: fortran/expr.c:4084
+#: fortran/expr.c:4087
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr "Procedurpekarinitieringsmål vid %L får inte vara en procedurpekare"
 
-#: fortran/expr.c:5512
+#: fortran/expr.c:4557
+#, gcc-internal-format
+msgid "generate_isocbinding_initializer(): bad iso_c_binding type, expected %<c_ptr%> or %<c_funptr%>"
+msgstr "generate_isocbinding_initializer(): felaktig iso_c_binding-typ, %<c_ptr%> eller %<c_funptr%> förväntades"
+
+#: fortran/expr.c:5568
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr "Fortran 2008: Pekarfunktioner i variabeldefinitionssammanhang (%s) vid %L"
 
-#: fortran/expr.c:5520
+#: fortran/expr.c:5576
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr "Icke variabelt uttryck i variabeldefinitionssammanhang (%s) vid %L"
 
-#: fortran/expr.c:5528
+#: fortran/expr.c:5584
 #, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr "Namngiven konstant %qs i variabeldefinitionssammanhang (%s) vid %L"
 
-#: fortran/expr.c:5537
+#: fortran/expr.c:5593
 #, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr "%qs i variabeldefinitionssammanhang (%s) vid %L är inte en variabel"
 
-#: fortran/expr.c:5548
+#: fortran/expr.c:5604
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr "Icke-POINTER i pekarassociationssammanhang (%s) vid %L"
 
-#: fortran/expr.c:5557
+#: fortran/expr.c:5613
 #, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr "Typen är oåtkomlig i variabeldefinitionssammanhang (%s) vid %L"
 
-#: fortran/expr.c:5570
+#: fortran/expr.c:5626
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr "LOCK_TYPE i variabeldefinitionssammanhang (%s) vid %L"
 
-#: fortran/expr.c:5583
+#: fortran/expr.c:5639
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr "LOCK_EVENT i variabeldefinitionssammanhang (%s) vid %L"
 
-#: fortran/expr.c:5613
+#: fortran/expr.c:5669
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr "Attrappargument %qs med INTENT(IN) i pekarassociationssammanhang (%s) vid %L"
 
-#: fortran/expr.c:5621
+#: fortran/expr.c:5677
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr "Attrappargument %qs med INTENT(IN) i variabeldefinitionssammanhang (%s) vid %L"
 
-#: fortran/expr.c:5634
+#: fortran/expr.c:5690
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a pointer association context (%s) at %L"
 msgstr "Variabeln %qs är PROTECTED och kan inte förekomma i ett pekarassociationssammanhang (%s) vid %L"
 
-#: fortran/expr.c:5642
+#: fortran/expr.c:5698
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a variable definition context (%s) at %L"
 msgstr "Variabeln %qs är PROTECTED och kan inte förekomma i ett variabeldefinitionssammanhang (%s) vid %L"
 
-#: fortran/expr.c:5654
+#: fortran/expr.c:5710
 #, gcc-internal-format
 msgid "Variable %qs can not appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr "Variabeln %qs kan inte förekomma i ett variabeldefinitionssammanhang (%s) vid %L"
 
-#: fortran/expr.c:5713
+#: fortran/expr.c:5769
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
 msgstr "%qs vid %L som är associerad med vektorindexerat mål kan inte användas i ett variabeldefinitionssammanhang (%s)"
 
-#: fortran/expr.c:5717
+#: fortran/expr.c:5773
 #, gcc-internal-format
 msgid "%qs at %L associated to expression can not be used in a variable definition context (%s)"
 msgstr "%qs vid %L som är associerad med uttryck kan inte användas i ett variabeldefinitionssammanhang (%s)"
 
-#: fortran/expr.c:5728
+#: fortran/expr.c:5784
 #, gcc-internal-format
 msgid "Associate-name %qs can not appear in a variable definition context (%s) at %L because its target at %L can not, either"
 msgstr "Associationsnamn %qs kan inte förekomma i ett variabeldefinitionssammanhang (%s) vid %L eftersom dess mål vid %L inte heller kan"
 
-#: fortran/expr.c:5770
+#: fortran/expr.c:5826
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr "Element med samma värde vid %L och %L i vektorindex i ett variabeldefinitionssammanhang (%s)"
@@ -53436,22 +53513,22 @@
 msgid "can't open input file: %s"
 msgstr "Kan inte öppna indatafil: %s"
 
-#: fortran/frontend-passes.c:190
+#: fortran/frontend-passes.c:192
 #, gcc-internal-format
 msgid "No location in statement"
 msgstr "Ingen plats i sats"
 
-#: fortran/frontend-passes.c:205
+#: fortran/frontend-passes.c:207
 #, gcc-internal-format, gfc-internal-format
 msgid "No location in expression near %L"
 msgstr "Ingen plats i uttryck nära %L"
 
-#: fortran/frontend-passes.c:409
+#: fortran/frontend-passes.c:414
 #, gcc-internal-format
 msgid "Illegal id in copy_walk_reduction_arg"
 msgstr "Otillåtet id i copy_walk_reduction_arg"
 
-#: fortran/frontend-passes.c:817 fortran/trans-array.c:1182
+#: fortran/frontend-passes.c:822 fortran/trans-array.c:1182
 #: fortran/trans-array.c:6440 fortran/trans-array.c:7864
 #: fortran/trans-intrinsic.c:7307
 #, gcc-internal-format, gfc-internal-format
@@ -53458,67 +53535,67 @@
 msgid "Creating array temporary at %L"
 msgstr "Skapar vektortemporär vid %L"
 
-#: fortran/frontend-passes.c:842 fortran/frontend-passes.c:846
+#: fortran/frontend-passes.c:847 fortran/frontend-passes.c:851
 #, gcc-internal-format
 msgid "Removing call to function %qs at %L"
 msgstr "Tar bort anrop av funktionen %qs vid %L"
 
-#: fortran/frontend-passes.c:1273 fortran/frontend-passes.c:1312
+#: fortran/frontend-passes.c:1278 fortran/frontend-passes.c:1317
 #, gcc-internal-format
 msgid "bad expression"
 msgstr "felaktigt uttryck"
 
-#: fortran/frontend-passes.c:1308
+#: fortran/frontend-passes.c:1313
 #, gcc-internal-format
 msgid "bad op"
 msgstr "felaktig operator"
 
-#: fortran/frontend-passes.c:2161
+#: fortran/frontend-passes.c:2166
 #, gcc-internal-format
 msgid "illegal OP in optimize_comparison"
 msgstr "otillåten OP i optimize_comparison"
 
-#: fortran/frontend-passes.c:2407
+#: fortran/frontend-passes.c:2412
 #, gcc-internal-format
 msgid "Variable %qs at %L set to undefined value inside loop  beginning at %L as INTENT(OUT) argument to subroutine %qs"
 msgstr "Variabeln %qs vid %L satt till odefinierad inuti en slinga som börjar vid %L är argument INTENT(OUT) till subrutin %qs"
 
-#: fortran/frontend-passes.c:2414
+#: fortran/frontend-passes.c:2419
 #, gcc-internal-format
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to subroutine %qs"
 msgstr "Variabeln %qs vid %L ej definierbar inuti slingan som börjar vid %L är argument INTENT(INOUT) till subrutin %qs"
 
-#: fortran/frontend-passes.c:2637 fortran/frontend-passes.c:2661
+#: fortran/frontend-passes.c:2642 fortran/frontend-passes.c:2666
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L out of bounds (%ld < %ld) in loop beginning at %L"
 msgstr "Vektorreferens vid %L är utanför gränsen (%ld < %ld) i slingan som börjar vid %L"
 
-#: fortran/frontend-passes.c:2646 fortran/frontend-passes.c:2670
+#: fortran/frontend-passes.c:2651 fortran/frontend-passes.c:2675
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L out of bounds (%ld > %ld) in loop beginning at %L"
 msgstr "Vektorreferens vid %L är utanför gränsen (%ld > %ld) i slingan som börjar vid %L"
 
-#: fortran/frontend-passes.c:2730
+#: fortran/frontend-passes.c:2735
 #, gcc-internal-format
 msgid "Variable %qs at %L set to undefined value inside loop beginning at %L as INTENT(OUT) argument to function %qs"
 msgstr "Variabeln %qs vid %L satt till odefinierad inuti slingan som börjar vid %L är argument INTENT(OUT) till funktionen %qs"
 
-#: fortran/frontend-passes.c:2736
+#: fortran/frontend-passes.c:2741
 #, gcc-internal-format
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr "Variabeln %qs vid %L ej definierbar inuti slingan som börjar vid %L är argument INTENT(INOUT) till funktionen %qs"
 
-#: fortran/frontend-passes.c:3128 fortran/trans-expr.c:1581
+#: fortran/frontend-passes.c:3133 fortran/trans-expr.c:1581
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr "Kod för omallokering av den allokerbara vektorn vid %L kommer läggas till"
 
-#: fortran/frontend-passes.c:3637
+#: fortran/frontend-passes.c:3642
 #, gcc-internal-format
 msgid "Scalarization using DIMEN_RANGE unimplemented"
 msgstr "Skalärisering med DIMEN_RANGE är oimplementerat"
 
-#: fortran/frontend-passes.c:4429
+#: fortran/frontend-passes.c:4434
 #, gcc-internal-format, gfc-internal-format
 msgid "Interchanging loops at %L"
 msgstr "Utväxlande slingor vid %L"
@@ -53638,12 +53715,12 @@
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "Andra argumentet av definierad tilldelning vid %L måste vara INTENT(IN)"
 
-#: fortran/interface.c:970 fortran/resolve.c:16351
+#: fortran/interface.c:970 fortran/resolve.c:16378
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "Första argumentet till operatorgränssnitt vid %L måste vara INTENT(IN)"
 
-#: fortran/interface.c:977 fortran/resolve.c:16369
+#: fortran/interface.c:977 fortran/resolve.c:16396
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "Andra argumentet till operatorgränssnitt vid %L måste vara INTENT(IN)"
@@ -54833,7 +54910,7 @@
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr "NAMELIST-objekt %qs i namnlistan %qs vid %L är polymorf och behöver en definierad input/output-procedur"
 
-#: fortran/io.c:3369 fortran/resolve.c:14263
+#: fortran/io.c:3369 fortran/resolve.c:14283
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr "NAMELIST-objektet %qs i namnlistan %qs vid %L med ALLOCATABLE- eller POINTER-komponenter"
@@ -54999,7 +55076,7 @@
 msgid "Integer too large at %C"
 msgstr "För stort heltal vid %C"
 
-#: fortran/match.c:580 fortran/parse.c:1132
+#: fortran/match.c:580 fortran/parse.c:1136
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many digits in statement label at %C"
 msgstr "För många siffror i satsetikett vid %C"
@@ -55760,57 +55837,57 @@
 msgid "Expected block name %qs of SELECT construct at %C"
 msgstr "Blocknamnet %qs förväntades av SELECT-konstruktionen vid %C"
 
-#: fortran/match.c:6186
+#: fortran/match.c:6201
 #, gcc-internal-format, gfc-internal-format
 msgid "parse error in SELECT TYPE statement at %C"
 msgstr "parsningsfel i SELECT TYPE-sats vid %C"
 
-#: fortran/match.c:6211
+#: fortran/match.c:6226
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr "Väljare i SELECT TYPE vid %C är inte en namngiven variabel, använd associationsnamn =>"
 
-#: fortran/match.c:6249
+#: fortran/match.c:6264
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr "Oväntad CASE-sats vid %C"
 
-#: fortran/match.c:6301
+#: fortran/match.c:6316
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CASE specification at %C"
 msgstr "Syntaxfel i CASE-specifikation vid %C"
 
-#: fortran/match.c:6319
+#: fortran/match.c:6334
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected TYPE IS statement at %C"
 msgstr "Oväntad TYPE IS-sats vid %C"
 
-#: fortran/match.c:6351
+#: fortran/match.c:6366
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr "Typspecifikationen skall inte specificera en sekvens härledd typ eller en typ med attributet BIND i SELECT TYPE vid %C [F2003:C815]"
 
-#: fortran/match.c:6362
+#: fortran/match.c:6377
 #, gcc-internal-format, gfc-internal-format
 msgid "All the LEN type parameters in the TYPE IS statement at %C must be ASSUMED"
 msgstr "Alla LEN-typparametrar i satsen TYPE IS vid %C måste vara ASSUMED"
 
-#: fortran/match.c:6373
+#: fortran/match.c:6388
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr "Syntaxfel i TYPE IS-specifikation vid %C"
 
-#: fortran/match.c:6449
+#: fortran/match.c:6464
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr "Syntaxfel i CLASS IS-specifikation vid %C"
 
-#: fortran/match.c:6572
+#: fortran/match.c:6587
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr "ELSEWHERE-sats vid %C inte innesluten i WHERE-block"
 
-#: fortran/match.c:6610
+#: fortran/match.c:6625
 #, gcc-internal-format
 msgid "Label %qs at %C doesn't match WHERE label %qs"
 msgstr "Etiketten %qs vid %C stämmer inte med WHERE-etikett %qs"
@@ -55961,188 +56038,188 @@
 msgid "mio_array_ref(): Unknown array ref"
 msgstr "mio_array_ref(): Okänd vektorreferens"
 
-#: fortran/module.c:3716
+#: fortran/module.c:3718
 #, gcc-internal-format, gfc-internal-format
 msgid "Namelist %s cannot be renamed by USE association to %s"
 msgstr "Namnlistan %s får inte namnändras av USE-association till %s"
 
-#: fortran/module.c:4832
+#: fortran/module.c:4834
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr "Tvetydig !$OMP DECLARE REDUCTION från modulen %s vid %L"
 
-#: fortran/module.c:4835
+#: fortran/module.c:4837
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr "Tidigare !$OMP DECLARE REDUCTION från modulen %s vid %L"
 
-#: fortran/module.c:5029
+#: fortran/module.c:5031
 #, gcc-internal-format
 msgid "%qs of module %qs, imported at %C, is also the name of the current program unit"
 msgstr "%qs i modulen %qs, importerad vid %C, är också namnet på den aktuella programenheten"
 
-#: fortran/module.c:5381
+#: fortran/module.c:5383
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in module %qs"
 msgstr "Symbolen %qs refererad från %L finns inte i modulen %qs"
 
-#: fortran/module.c:5388
+#: fortran/module.c:5390
 #, gcc-internal-format
 msgid "User operator %qs referenced at %L not found in module %qs"
 msgstr "Användaroperatorn %qs refererad från %L finns inte i modulen %qs"
 
-#: fortran/module.c:5393
+#: fortran/module.c:5395
 #, gcc-internal-format
 msgid "Intrinsic operator %qs referenced at %L not found in module %qs"
 msgstr "Inbyggd operator %qs refererad från %L finns inte i modulen %qs"
 
-#: fortran/module.c:5628
+#: fortran/module.c:5630
 #, gcc-internal-format
 msgid "write_symbol(): bad module symbol %qs"
 msgstr "write_symbol(): felaktig modulsymbol %qs"
 
-#: fortran/module.c:5961
+#: fortran/module.c:5963
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr "write_symtree(): Symbolen inte skriven"
 
-#: fortran/module.c:6148
+#: fortran/module.c:6150
 #, gcc-internal-format
 msgid "Can't open module file %qs for writing at %C: %s"
 msgstr "Kan inte öppna modulfilen %qs för skrivning vid %C: %s"
 
-#: fortran/module.c:6169
+#: fortran/module.c:6171
 #, gcc-internal-format
 msgid "Error writing module file %qs for writing: %s"
 msgstr "Fel när modulfilen %qs skrevs: %s"
 
-#: fortran/module.c:6180
+#: fortran/module.c:6182
 #, gcc-internal-format
 msgid "Can't delete module file %qs: %s"
 msgstr "Kan inte radera modulfilen %qs: %s"
 
-#: fortran/module.c:6183
+#: fortran/module.c:6185
 #, gcc-internal-format
 msgid "Can't rename module file %qs to %qs: %s"
 msgstr "Kan inte ändra namn på modulfilen %qs till %qs: %s"
 
-#: fortran/module.c:6189
+#: fortran/module.c:6191
 #, gcc-internal-format
 msgid "Can't delete temporary module file %qs: %s"
 msgstr "Kan inte radera temporär modulfil %qs: %s"
 
-#: fortran/module.c:6246
+#: fortran/module.c:6248
 #, gcc-internal-format
 msgid "Symbol %qs at %C already declared"
 msgstr "Symbolen %qs vid %C är redan deklarerad"
 
-#: fortran/module.c:6317
+#: fortran/module.c:6319
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr "import_iso_c_binding_module(): Kan inte skapa en symbol för %s"
 
-#: fortran/module.c:6425 fortran/module.c:6769
+#: fortran/module.c:6427 fortran/module.c:6771
 #, gcc-internal-format
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr "Symbolen %qs, refererad vid %L, finns inte i den valda standarden"
 
-#: fortran/module.c:6553
+#: fortran/module.c:6555
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr "Symbolen %qs refererad från %L hittas inte i den inbyggda modulen ISO_C_BINDING"
 
-#: fortran/module.c:6574 fortran/module.c:6607 fortran/module.c:6649
+#: fortran/module.c:6576 fortran/module.c:6609 fortran/module.c:6651
 #, gcc-internal-format
 msgid "Symbol %qs already declared"
 msgstr "Symbolen %qs är redan deklarerad"
 
-#: fortran/module.c:6754
+#: fortran/module.c:6756
 #, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr "Användning av inbyggd modul %qs vid %C står i konflikt med namn på ej inbyggd modul använd tidigare"
 
-#: fortran/module.c:6776
+#: fortran/module.c:6778
 #, gcc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr "Användning av namngiven NUMERIC_STORAGE_SIZE-konstant från inbyggd modul ISO_FORTRAN_ENV vid %L är inte kompatibelt med flaggan %qs"
 
-#: fortran/module.c:6844
+#: fortran/module.c:6846
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr "Användning av namngiven NUMERIC_STORAGE_SIZE-konstant från inbyggd modul ISO_FORTRAN_ENV vid %C är inte kompatibelt med flaggan %s"
 
-#: fortran/module.c:6898
+#: fortran/module.c:6900
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr "Symbolen %qs refererad vid %L hittas inte i den inbyggda modulen ISO_FORTRAN_ENV"
 
-#: fortran/module.c:6924
+#: fortran/module.c:6926
 #, gcc-internal-format, gfc-internal-format
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr "USE-sats vid %C har ingen ONLY-kvalificerare"
 
-#: fortran/module.c:6953
+#: fortran/module.c:6955
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr "inbyggd modul ISO_FORTRAN_ENV vid %C"
 
-#: fortran/module.c:6965
+#: fortran/module.c:6967
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
 msgstr "ISO_C_BINDING-modul vid %C"
 
-#: fortran/module.c:6978
+#: fortran/module.c:6980
 #, gcc-internal-format
 msgid "Can't find an intrinsic module named %qs at %C"
 msgstr "Det finns ingen inbyggd modul med namnet %qs vid %C"
 
-#: fortran/module.c:6984
+#: fortran/module.c:6986
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr "IEEE_FEATURES-modul vid %C"
 
-#: fortran/module.c:6990
+#: fortran/module.c:6992
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr "IEEE_EXCEPTIONS-modul vid %C"
 
-#: fortran/module.c:6996
+#: fortran/module.c:6998
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr "IEEE_ARITHMETIC-modul vid %C"
 
-#: fortran/module.c:7006
+#: fortran/module.c:7008
 #, gcc-internal-format
 msgid "Can't open module file %qs for reading at %C: %s"
 msgstr "Kan inte öppna modulfilen %qs för läsning vid %C: %s"
 
-#: fortran/module.c:7009
+#: fortran/module.c:7011
 #, gcc-internal-format
 msgid "Module file %qs has not been generated, either because the module does not contain a MODULE PROCEDURE or there is an error in the module."
 msgstr "Modulfilen %qs har inte genererats, antingen för att modulen inte innehåller en MODULE PROCEDURE eller så finns det ett fel i modulen."
 
-#: fortran/module.c:7020
+#: fortran/module.c:7022
 #, gcc-internal-format
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr "Användning av ej inbyggd modul %qs vid %C står i konflikt med namn på inbyggd modul använd tidigare"
 
-#: fortran/module.c:7043
+#: fortran/module.c:7045
 #, gcc-internal-format
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr "Filen %qs öppnad vid %C är inte en GNU Fortran-modulfil"
 
-#: fortran/module.c:7051
+#: fortran/module.c:7053
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr "Kan inte läsa modulfilen %qs öppnad vid %C, eftersom den skapades av en annan version av GNU Fortran"
 
-#: fortran/module.c:7066
+#: fortran/module.c:7068
 #, gcc-internal-format, gfc-internal-format
 msgid "Can't USE the same %smodule we're building"
 msgstr "Det går inte att USE samma %smodul vi bygger"
 
 #: fortran/openmp.c:296 fortran/openmp.c:397 fortran/openmp.c:692
-#: fortran/openmp.c:3167
+#: fortran/openmp.c:3166
 #, gcc-internal-format, gfc-internal-format
 msgid "COMMON block /%s/ not found at %C"
 msgstr "COMMON-block /%s/ finns inte vid %C"
@@ -56219,860 +56296,860 @@
 
 #: fortran/openmp.c:2180
 #, gcc-internal-format, gfc-internal-format
-msgid "Invalid argument to !$ACC WAIT at %L"
-msgstr "Ogiltiga argument till !$ACC WAIT vid %L"
+msgid "Invalid argument to !$ACC WAIT at %C"
+msgstr "Ogiltiga argument till !$ACC WAIT vid %C"
 
-#: fortran/openmp.c:2188
+#: fortran/openmp.c:2187
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT clause at %L requires a scalar INTEGER expression"
 msgstr "WAIT-klausul vid %L kräver ett skalärt INTEGER-uttryck"
 
-#: fortran/openmp.c:2221
+#: fortran/openmp.c:2220
 #, gcc-internal-format, gfc-internal-format
 msgid "ACC CACHE directive must be inside of loop %C"
 msgstr "Direktivet ACC CACHE måste vara inuti en slinga %C"
 
-#: fortran/openmp.c:2252
+#: fortran/openmp.c:2251
 #, gcc-internal-format
 msgid "Multiple loop axes specified for routine"
 msgstr "Multipla slingaxlar angivna för rutinen"
 
-#: fortran/openmp.c:2278
+#: fortran/openmp.c:2277
 #, gcc-internal-format, gfc-internal-format
 msgid "Only the !$ACC ROUTINE form without list is allowed in interface block at %C"
 msgstr "Endast formen !$ACC ROUTINE utan en lista är tillåten i gränssnittsblock vid %C"
 
-#: fortran/openmp.c:2306
+#: fortran/openmp.c:2305
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$ACC ROUTINE ( NAME ) at %C, invalid function name %s"
 msgstr "Syntaxfel i !$ACC ROUTINE ( NAMN ) vid %C, felaktigt funktionsnamn %s"
 
-#: fortran/openmp.c:2315
+#: fortran/openmp.c:2314
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$ACC ROUTINE ( NAME ) at %C"
 msgstr "Syntaxfel i !ACC$ ROUTINE ( NAME ) vid %C"
 
-#: fortran/openmp.c:2322
+#: fortran/openmp.c:2321
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$ACC ROUTINE ( NAME ) at %C, expecting ')' after NAME"
 msgstr "Syntaxfel i !$ACC ROUTINE ( NAMN ) vid %C, ')' förväntades efter NAMN"
 
-#: fortran/openmp.c:2457 fortran/openmp.c:2481
+#: fortran/openmp.c:2456 fortran/openmp.c:2480
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP CRITICAL statement at %C"
 msgstr "Oväntat skräp efter $OMP CRITICAL-sats vid %C"
 
-#: fortran/openmp.c:2548
+#: fortran/openmp.c:2547
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP FLUSH statement at %C"
 msgstr "Oväntat skräp efter $OMP FLUSH-sats vid %C"
 
-#: fortran/openmp.c:2942 fortran/openmp.c:6225
+#: fortran/openmp.c:2941 fortran/openmp.c:6230
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined %s !$OMP DECLARE REDUCTION at %L"
 msgstr "Omdefinition av fördefinierad %s !$OMP DECLARE REDUCTION vid %L"
 
-#: fortran/openmp.c:2946 fortran/openmp.c:6229
+#: fortran/openmp.c:2945 fortran/openmp.c:6234
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined !$OMP DECLARE REDUCTION at %L"
 msgstr "Omdefinition av fördefinierad !$OMP DECLARE REDUCTION vid %L"
 
-#: fortran/openmp.c:2951
+#: fortran/openmp.c:2950
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of !$OMP DECLARE REDUCTION at %L"
 msgstr "Omdefinition av !$OMP DECLARE REDUCTION vid %L"
 
-#: fortran/openmp.c:2953
+#: fortran/openmp.c:2952
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION at %L"
 msgstr "Föregående !$OMP DECLARE REDUCTION vid %L"
 
-#: fortran/openmp.c:2973
+#: fortran/openmp.c:2972
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after !$OMP DECLARE REDUCTION at %C"
 msgstr "Oväntat skräp efter !$OMP DECLARE REDUCTION vid %C"
 
-#: fortran/openmp.c:3010
+#: fortran/openmp.c:3009
 #, gcc-internal-format, gfc-internal-format
 msgid "Only the !$OMP DECLARE TARGET form without clauses is allowed in interface block at %C"
 msgstr "Endast formen !$OMP DECLARE TARGET utan klausuler är tillåten i gränssnittsblock vid %C"
 
-#: fortran/openmp.c:3025
+#: fortran/openmp.c:3024
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after !$OMP DECLARE TARGET at %C"
 msgstr "Oväntat skräp efter !$OMP DECLARE TARGET vid %C"
 
-#: fortran/openmp.c:3048
+#: fortran/openmp.c:3047
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET variable at %L is an element of a COMMON block"
 msgstr "OMP DECLARE TARGET-variabel vid %L är ett element i ett COMMON-block"
 
-#: fortran/openmp.c:3053
+#: fortran/openmp.c:3052
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET variable at %L previously mentioned in LINK clause and later in TO clause"
 msgstr "OMP DECLARE TARGET-variabeln vid %L nämndes tidigare i en LINK-klausul och senare i en TO-klausul"
 
-#: fortran/openmp.c:3059
+#: fortran/openmp.c:3058
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET variable at %L previously mentioned in TO clause and later in LINK clause"
 msgstr "OMP DECLARE TARGET-variabel vid %L nämndes tidigare i en TO-klausul och senare i en LINK-klausul"
 
-#: fortran/openmp.c:3063
+#: fortran/openmp.c:3062
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable at %L mentioned multiple times in clauses of the same OMP DECLARE TARGET directive"
 msgstr "Variabeln vid %L nämnd flera gånger i klausuler av samma OMP DECLARE TARGET-direktiv"
 
-#: fortran/openmp.c:3078
+#: fortran/openmp.c:3077
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET COMMON at %L previously mentioned in LINK clause and later in TO clause"
 msgstr "OMP DECLARE TARGET COMMON vid %L är tidigare nämnd i en LINK-klausul och senare i en TO-klausul"
 
-#: fortran/openmp.c:3084
+#: fortran/openmp.c:3083
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET COMMON at %L previously mentioned in TO clause and later in LINK clause"
 msgstr "OMP DECLARE TARGET COMMON %L är tidigare nämnd i en TO-klausul och senare i en LINK-klausul"
 
-#: fortran/openmp.c:3088
+#: fortran/openmp.c:3087
 #, gcc-internal-format, gfc-internal-format
 msgid "COMMON at %L mentioned multiple times in clauses of the same OMP DECLARE TARGET directive"
 msgstr "COMMON vid %L nämnt flera gånger i klausuler av samma OMP DECLARE TARGET-direktiv"
 
-#: fortran/openmp.c:3115
+#: fortran/openmp.c:3114
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$OMP DECLARE TARGET list at %C"
 msgstr "Syntaxfel i !$OMP DECLARE TARGET-lista vid %C"
 
-#: fortran/openmp.c:3147
+#: fortran/openmp.c:3146
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate variable at %C is an element of a COMMON block"
 msgstr "Trådprivat variabel vid %C är ett element i ett COMMON-block"
 
-#: fortran/openmp.c:3184
+#: fortran/openmp.c:3183
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after OMP THREADPRIVATE at %C"
 msgstr "Oväntat skräp efter OMP THREADPRIVATE vid %C"
 
-#: fortran/openmp.c:3191
+#: fortran/openmp.c:3190
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$OMP THREADPRIVATE list at %C"
 msgstr "Syntaxfel i !$OMP THREADPRIVATE-lista vid %C"
 
-#: fortran/openmp.c:3405
+#: fortran/openmp.c:3404
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after TASKWAIT clause at %C"
 msgstr "Oväntat skräp efter TASKWAIT-klausul vid %C"
 
-#: fortran/openmp.c:3419
+#: fortran/openmp.c:3418
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after TASKYIELD clause at %C"
 msgstr "Oväntat skräp efter TASKYIELD-klausul vid %C"
 
-#: fortran/openmp.c:3478
+#: fortran/openmp.c:3477
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP WORKSHARE statement at %C"
 msgstr "Oväntat skräp efter $OMP ORDERED-sats vid %C"
 
-#: fortran/openmp.c:3492
+#: fortran/openmp.c:3491
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP MASTER statement at %C"
 msgstr "Oväntat skräp efter $OMP MASTER-sats vid %C"
 
-#: fortran/openmp.c:3551
+#: fortran/openmp.c:3550
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP ATOMIC statement at %C"
 msgstr "Oväntat skräp efter $OMP ATOMIC-sats vid %C"
 
-#: fortran/openmp.c:3578
+#: fortran/openmp.c:3577
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP BARRIER statement at %C"
 msgstr "Oväntat skräp efter $OMP BARRIER-sats vid %C"
 
-#: fortran/openmp.c:3592
+#: fortran/openmp.c:3591
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP TASKGROUP statement at %C"
 msgstr "Oväntat skräp efter $OMP TASKGROUP-sats vid %C"
 
-#: fortran/openmp.c:3642
+#: fortran/openmp.c:3641
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP CANCELLATION POINT statement at %C"
 msgstr "Oväntat skräp efter $OMP CANCELLATION POINT-sats vid %C"
 
-#: fortran/openmp.c:3662
+#: fortran/openmp.c:3661
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after NOWAIT clause at %C"
 msgstr "Oväntat skräp efter NOWAIT-klausul vid %C"
 
-#: fortran/openmp.c:3704
+#: fortran/openmp.c:3703
 #, gcc-internal-format, gfc-internal-format
 msgid "%s clause at %L requires a scalar INTEGER expression"
 msgstr "%s-klausul vid %L kräver ett skalärt INTEGER-uttryck"
 
-#: fortran/openmp.c:3715
+#: fortran/openmp.c:3714
 #, gcc-internal-format, gfc-internal-format
 msgid "INTEGER expression of %s clause at %L must be positive"
 msgstr "INTEGER-uttryck i %s-klausul vid %L måste vara positivt"
 
-#: fortran/openmp.c:3726
+#: fortran/openmp.c:3725
 #, gcc-internal-format, gfc-internal-format
 msgid "INTEGER expression of %s clause at %L must be non-negative"
 msgstr "INTEGER-uttryck i %s-klausul vid %L får inte vara negativt"
 
-#: fortran/openmp.c:3737
+#: fortran/openmp.c:3736
 #, gcc-internal-format
 msgid "POINTER object %qs of derived type in %s clause at %L"
 msgstr "POINTER-objekt %qs av härledd typ i %s-klausul vid %L"
 
-#: fortran/openmp.c:3740
+#: fortran/openmp.c:3739
 #, gcc-internal-format
 msgid "Cray pointer object %qs of derived type in %s clause at %L"
 msgstr "Cray-pekarobjekt %qs av härledd typ i %s-klausul vid %L"
 
-#: fortran/openmp.c:3743
+#: fortran/openmp.c:3742
 #, gcc-internal-format
 msgid "Cray pointee object %qs of derived type in %s clause at %L"
 msgstr "Cray-utpekat objekt %qs av härledd typ i %s-klausul vid %L"
 
-#: fortran/openmp.c:3749 fortran/openmp.c:4687
+#: fortran/openmp.c:3748 fortran/openmp.c:4686
 #, gcc-internal-format
 msgid "POINTER object %qs of polymorphic type in %s clause at %L"
 msgstr "POINTER-objekt %qs av polymorf typ i %s-klausul vid %L"
 
-#: fortran/openmp.c:3754
+#: fortran/openmp.c:3753
 #, gcc-internal-format
 msgid "Cray pointer object %qs of polymorphic type in %s clause at %L"
 msgstr "Cray-pekarobjekt %qs av polymorf typ i %s-klausul vid %L"
 
-#: fortran/openmp.c:3759
+#: fortran/openmp.c:3758
 #, gcc-internal-format
 msgid "Cray pointee object %qs of polymorphic type in %s clause at %L"
 msgstr "Cray-utpekat objekt %qs av polymorf typ i %s-klausul vid %L"
 
-#: fortran/openmp.c:3769 fortran/openmp.c:4385 fortran/openmp.c:4490
+#: fortran/openmp.c:3768 fortran/openmp.c:4384 fortran/openmp.c:4489
 #, gcc-internal-format
 msgid "Assumed size array %qs in %s clause at %L"
 msgstr "Vektor %qs med antagen storlek i %s-klausul vid %L"
 
-#: fortran/openmp.c:3772
+#: fortran/openmp.c:3771
 #, gcc-internal-format
 msgid "Assumed rank array %qs in %s clause at %L"
 msgstr "Vektor %qs med antagen storlek i %s-klausul vid %L"
 
-#: fortran/openmp.c:3776
+#: fortran/openmp.c:3775
 #, gcc-internal-format
 msgid "Noncontiguous deferred shape array %qs in %s clause at %L"
 msgstr "Osammanhängande vektor med fördröjd form %qs i %s-klausul vid %L"
 
-#: fortran/openmp.c:3784
+#: fortran/openmp.c:3783
 #, gcc-internal-format
 msgid "ALLOCATABLE object %qs of derived type in %s clause at %L"
 msgstr "ALLOCATABLE-objekt %qs av härledd typ i %s-klausul vid %L"
 
-#: fortran/openmp.c:3789
+#: fortran/openmp.c:3788
 #, gcc-internal-format
 msgid "ALLOCATABLE object %qs of polymorphic type in %s clause at %L"
 msgstr "ALLOCATABLE-objekt %qs av polymorf typ i %s-klausul vid %L"
 
-#: fortran/openmp.c:3801 fortran/openmp.c:4480
+#: fortran/openmp.c:3800 fortran/openmp.c:4479
 #, gcc-internal-format
 msgid "POINTER object %qs in %s clause at %L"
 msgstr "POINTER-objekt %qs i %s-fall vid %L"
 
-#: fortran/openmp.c:3806 fortran/openmp.c:4691
+#: fortran/openmp.c:3805 fortran/openmp.c:4690
 #, gcc-internal-format
 msgid "Cray pointer object %qs in %s clause at %L"
 msgstr "Cray-pekarobjekt %qs i %s-klausul vid %L"
 
-#: fortran/openmp.c:3811 fortran/openmp.c:4694
+#: fortran/openmp.c:3810 fortran/openmp.c:4693
 #, gcc-internal-format
 msgid "Cray pointee object %qs in %s clause at %L"
 msgstr "Cray-utpekadobjekt %qs i %s-klausul vid %L"
 
-#: fortran/openmp.c:3816 fortran/openmp.c:4682
+#: fortran/openmp.c:3815 fortran/openmp.c:4681
 #, gcc-internal-format
 msgid "ALLOCATABLE object %qs in %s clause at %L"
 msgstr "ALLOCATABLE-objekt %qs i %s-klausul vid %L"
 
-#: fortran/openmp.c:3819
+#: fortran/openmp.c:3818
 #, gcc-internal-format
 msgid "VALUE object %qs in %s clause at %L"
 msgstr "VALUE-objekt %qs i %s-klausul vid %L"
 
-#: fortran/openmp.c:3862
+#: fortran/openmp.c:3861
 #, gcc-internal-format, gfc-internal-format
 msgid "Implicitly declared function %s used in !$OMP DECLARE REDUCTION at %L"
 msgstr "Den implicit deklarerade funktionen %s används i !$OMP DECLARE REDUCTION vid %L"
 
-#: fortran/openmp.c:3911
+#: fortran/openmp.c:3910
 #, gcc-internal-format, gfc-internal-format
 msgid "Implicitly declared subroutine %s used in !$OMP DECLARE REDUCTION at %L"
 msgstr "Den implicit deklarerade subrutinen %s används i !$OMP DECLARE REDUCTION vid %L"
 
-#: fortran/openmp.c:3944
+#: fortran/openmp.c:3943
 #, gcc-internal-format, gfc-internal-format
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr "ORDERED-klausulparameter är mindre än COLLAPSE vid %L"
 
-#: fortran/openmp.c:3952 fortran/openmp.c:3963 fortran/resolve.c:10028
-#: fortran/resolve.c:11295
+#: fortran/openmp.c:3951 fortran/openmp.c:3962 fortran/resolve.c:10041
+#: fortran/resolve.c:11315
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "IF-klausul vid %L kräver ett skalärt LOGICAL-uttryck"
 
-#: fortran/openmp.c:3967
+#: fortran/openmp.c:3966
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause without modifier at %L used together with IF clauses with modifiers"
 msgstr "IF-klausul utan modifierare vid %L använd tillsammans med IF-klausuler med modifierare"
 
-#: fortran/openmp.c:4044
+#: fortran/openmp.c:4043
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause modifier %s at %L not appropriate for the current OpenMP construct"
 msgstr "IF-klausulmodifierare %s vid %L passar inte för den aktuella OpenMP-konstruktionen"
 
-#: fortran/openmp.c:4054
+#: fortran/openmp.c:4053
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL clause at %L requires a scalar LOGICAL expression"
 msgstr "FINAL-klausul vid %L kräver ett skalärt LOGICAL-uttryck"
 
-#: fortran/openmp.c:4064
+#: fortran/openmp.c:4063
 #, gcc-internal-format, gfc-internal-format
 msgid "SCHEDULE clause's chunk_size at %L requires a scalar INTEGER expression"
 msgstr "SCHEDULE-klausuls chunk_size vid %L kräver ett skalärt INTEGER-uttryck"
 
-#: fortran/openmp.c:4069
+#: fortran/openmp.c:4068
 #, gcc-internal-format, gfc-internal-format
 msgid "INTEGER expression of SCHEDULE clause's chunk_size at %L must be positive"
 msgstr "INTEGER-uttryck i SCHEDULE-klausulens chunk_size vid %L måste vara positivt"
 
-#: fortran/openmp.c:4084
+#: fortran/openmp.c:4083
 #, gcc-internal-format
 msgid "Variable %qs is not a dummy argument at %L"
 msgstr "Variabeln %qs är inte ett attrappargument vid %L"
 
-#: fortran/openmp.c:4116
+#: fortran/openmp.c:4115 fortran/openmp.c:5998
 #, gcc-internal-format
 msgid "Object %qs is not a variable at %L"
 msgstr "Objekt %qs är inte en variabel vid %L"
 
-#: fortran/openmp.c:4132 fortran/openmp.c:4143 fortran/openmp.c:4151
-#: fortran/openmp.c:4162 fortran/openmp.c:4174 fortran/openmp.c:4189
-#: fortran/openmp.c:6023
+#: fortran/openmp.c:4131 fortran/openmp.c:4142 fortran/openmp.c:4150
+#: fortran/openmp.c:4161 fortran/openmp.c:4173 fortran/openmp.c:4188
+#: fortran/openmp.c:6028
 #, gcc-internal-format
 msgid "Symbol %qs present on multiple clauses at %L"
 msgstr "Symbolen %qs finns i flera fall vid %L"
 
-#: fortran/openmp.c:4196
+#: fortran/openmp.c:4195
 #, gcc-internal-format
 msgid "Array %qs is not permitted in reduction at %L"
 msgstr "Vektorn %qs får inte förekomma i reduktionen vid %L"
 
-#: fortran/openmp.c:4209
+#: fortran/openmp.c:4208
 #, gcc-internal-format
 msgid "Symbol %qs present on both FROM and TO clauses at %L"
 msgstr "Symbolen %qs finns i både FROM- och TO-klausuler vid %L"
 
-#: fortran/openmp.c:4231
+#: fortran/openmp.c:4230
 #, gcc-internal-format
 msgid "Non-THREADPRIVATE object %qs in COPYIN clause at %L"
 msgstr "Ej THREADPRIVATE objekt %qs i COPYIN-fall vid %L"
 
-#: fortran/openmp.c:4239
+#: fortran/openmp.c:4238
 #, gcc-internal-format
 msgid "Assumed size array %qs in COPYPRIVATE clause at %L"
 msgstr "Vektor %qs med antagen storlek i COPYPRIVATE-klausul vid %L"
 
-#: fortran/openmp.c:4242
+#: fortran/openmp.c:4241
 #, gcc-internal-format
 msgid "INTENT(IN) POINTER %qs in COPYPRIVATE clause at %L"
 msgstr "INTENT(IN) POINTER %qs i COPYPRIVATE-klausul vid %L"
 
-#: fortran/openmp.c:4250
+#: fortran/openmp.c:4249
 #, gcc-internal-format
 msgid "THREADPRIVATE object %qs in SHARED clause at %L"
 msgstr "THREADPRIVATE objekt %qs i SHARED fall vid %L"
 
-#: fortran/openmp.c:4253
+#: fortran/openmp.c:4252
 #, gcc-internal-format
 msgid "Cray pointee %qs in SHARED clause at %L"
 msgstr "Cray-utpekad %qs i SHARED-klausul vid %L"
 
-#: fortran/openmp.c:4256
+#: fortran/openmp.c:4255
 #, gcc-internal-format
 msgid "ASSOCIATE name %qs in SHARED clause at %L"
 msgstr "ASSOCIATE-namn %qs i SHARED-klausul vid %L"
 
-#: fortran/openmp.c:4271
+#: fortran/openmp.c:4270
 #, gcc-internal-format
 msgid "%qs in ALIGNED clause must be POINTER, ALLOCATABLE, Cray pointer or C_PTR at %L"
 msgstr "%qs i ALIGNED-klausul måste vara POINTER, ALLOCATABLE, Cray-pekare eller C_PTR vid %L"
 
-#: fortran/openmp.c:4283
+#: fortran/openmp.c:4282
 #, gcc-internal-format
 msgid "%qs in ALIGNED clause at %L requires a scalar positive constant integer alignment expression"
 msgstr "%qs i ALIGNED-klausul vid %L behöver ett skalärt positivt konstant heltals justeringsuttryck"
 
-#: fortran/openmp.c:4302
+#: fortran/openmp.c:4301
 #, gcc-internal-format, gfc-internal-format
 msgid "SINK dependence type only allowed on ORDERED directive at %L"
 msgstr "En SINK-beroendetyp är endast tillåten med ORDERED-direktiv vid %L"
 
-#: fortran/openmp.c:4306
+#: fortran/openmp.c:4305
 #, gcc-internal-format, gfc-internal-format
 msgid "DEPEND SINK used together with DEPEND SOURCE on the same construct at %L"
 msgstr "DEPEND SINK använt tillsammans med DEPEND SOURCE med samma konstruktion vid %L"
 
-#: fortran/openmp.c:4316
+#: fortran/openmp.c:4315
 #, gcc-internal-format, gfc-internal-format
 msgid "SINK addend not a constant integer at %L"
 msgstr "SINK-termen är inte ett konstant heltal vid %L"
 
-#: fortran/openmp.c:4322
+#: fortran/openmp.c:4321
 #, gcc-internal-format, gfc-internal-format
 msgid "Only SOURCE or SINK dependence types are allowed on ORDERED directive at %L"
 msgstr "Endast SOURCE- eller SINK-beroendetyper är tillåtna med ORDERED-direktiv vid %L"
 
-#: fortran/openmp.c:4333 fortran/openmp.c:4354
+#: fortran/openmp.c:4332 fortran/openmp.c:4353
 #, gcc-internal-format
 msgid "%qs in %s clause at %L is not a proper array section"
 msgstr "%qs i %s-klausul vid %L är inte en riktig vektorsektion"
 
-#: fortran/openmp.c:4337
+#: fortran/openmp.c:4336
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarrays not supported in %s clause at %L"
 msgstr "Co-vektorer stödjs inte i %s-klausul vid %L"
 
-#: fortran/openmp.c:4346
+#: fortran/openmp.c:4345
 #, gcc-internal-format, gfc-internal-format
 msgid "Stride should not be specified for array section in %s clause at %L"
 msgstr "Steget skall inte anges i vektorsektionen i %s-klausulen vid %L"
 
-#: fortran/openmp.c:4367
+#: fortran/openmp.c:4366
 #, gcc-internal-format
 msgid "%qs in DEPEND clause at %L is a zero size array section"
 msgstr "%qs i DEPEND-klausul vid %L är en vektorsektion med storlek noll"
 
 # Första "%s" blir antingen en tom sträng eller "DATA".
-#: fortran/openmp.c:4403
+#: fortran/openmp.c:4402
 #, gcc-internal-format, gfc-internal-format
 msgid "TARGET%s with map-type other than TO, FROM, TOFROM, or ALLOC on MAP clause at %L"
 msgstr "TARGET%s med with en annan map-typ än TO, FROM, TOFROM eller ALLOC i MAP-klausul vid %L"
 
-#: fortran/openmp.c:4419
+#: fortran/openmp.c:4418
 #, gcc-internal-format, gfc-internal-format
 msgid "TARGET ENTER DATA with map-type other than TO, or ALLOC on MAP clause at %L"
 msgstr "TARGET ENTER DATA med en annan map-typ än TO eller ALLOC i MAP-klausul vid %L"
 
-#: fortran/openmp.c:4434
+#: fortran/openmp.c:4433
 #, gcc-internal-format, gfc-internal-format
 msgid "TARGET EXIT DATA with map-type other than FROM, RELEASE, or DELETE on MAP clause at %L"
 msgstr "TARGET EXIT DATA med en annan map-typ än FROM, RELEASE eller DELETE i MAP-klausul vid %L"
 
-#: fortran/openmp.c:4450 fortran/openmp.c:4466
+#: fortran/openmp.c:4449 fortran/openmp.c:4465
 #, gcc-internal-format
 msgid "THREADPRIVATE object %qs in %s clause at %L"
 msgstr "THREADPRIVATE objekt %qs i %s-fall vid %L"
 
-#: fortran/openmp.c:4453 fortran/openmp.c:4469
+#: fortran/openmp.c:4452 fortran/openmp.c:4468
 #, gcc-internal-format
 msgid "Cray pointee %qs in %s clause at %L"
 msgstr "Cray-utpekad %qs i %s-klausul vid %L"
 
-#: fortran/openmp.c:4472
+#: fortran/openmp.c:4471
 #, gcc-internal-format
 msgid "ASSOCIATE name %qs in %s clause at %L"
 msgstr "ASSOCIATE-namn %qs i %s-klausul vid %L"
 
-#: fortran/openmp.c:4477
+#: fortran/openmp.c:4476
 #, gcc-internal-format
 msgid "Procedure pointer %qs in %s clause at %L"
 msgstr "Procedurpekare %qs i %s-klausul vid %L"
 
-#: fortran/openmp.c:4483
+#: fortran/openmp.c:4482
 #, gcc-internal-format
 msgid "Cray pointer %qs in %s clause at %L"
 msgstr "Cray-pekare %qs i %s-klausul vid %L"
 
-#: fortran/openmp.c:4493
+#: fortran/openmp.c:4492
 #, gcc-internal-format
 msgid "Variable %qs in %s clause is used in NAMELIST statement at %L"
 msgstr "Variabeln %qs i %s-klausul används i NAMELIST-sats vid %L"
 
 #. case OMP_LIST_REDUCTION:
-#: fortran/openmp.c:4503
+#: fortran/openmp.c:4502
 #, gcc-internal-format
 msgid "INTENT(IN) POINTER %qs in %s clause at %L"
 msgstr "INTENT(IN) POINTER %qs i %s-klausul vid %L"
 
-#: fortran/openmp.c:4596
+#: fortran/openmp.c:4595
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP DECLARE REDUCTION %s not found for type %s at %L"
 msgstr "!$OMP DECLARE REDUCTION %s finns inte för typen %s vid %L"
 
-#: fortran/openmp.c:4622
+#: fortran/openmp.c:4621
 #, gcc-internal-format, gfc-internal-format
 msgid "LINEAR clause modifier used on DO or SIMD construct at %L"
 msgstr "LINEAR-klausulmodifierare använd på DO- eller SIMD-konstruktion vid %L"
 
-#: fortran/openmp.c:4627
+#: fortran/openmp.c:4626
 #, gcc-internal-format, gfc-internal-format
 msgid "LINEAR clause specified together with ORDERED clause with argument at %L"
 msgstr "LINEAR-klausul angiven tillsammans med ORDERED-klausul med ett argument vid %L"
 
-#: fortran/openmp.c:4632
+#: fortran/openmp.c:4631
 #, gcc-internal-format
 msgid "LINEAR variable %qs must be INTEGER at %L"
 msgstr "LINEAR-variabel %qs måste vara INTEGER vid %L"
 
-#: fortran/openmp.c:4637
+#: fortran/openmp.c:4636
 #, gcc-internal-format
 msgid "LINEAR dummy argument %qs with VALUE attribute with %s modifier at %L"
 msgstr "LINEAR-attrappargument %qs med VALUE-attribut med %s-modifierare vid %L"
 
-#: fortran/openmp.c:4648
+#: fortran/openmp.c:4647
 #, gcc-internal-format
 msgid "%qs in LINEAR clause at %L requires a scalar integer linear-step expression"
 msgstr "%qs i LINEAR-klausul vid %L kräver ett skalärt heltalsuttryck för linjärsteg"
 
-#: fortran/openmp.c:4665
+#: fortran/openmp.c:4664
 #, gcc-internal-format
 msgid "%qs in LINEAR clause at %L requires a constant integer linear-step expression or dummy argument specified in UNIFORM clause"
 msgstr "%qs i LINEAR-klausul vid %L kräver ett konstant heltalsuttryck för linjärsteg eller ett attrappargument angivet i en UNIFORM-klausul"
 
-#: fortran/openmp.c:4699
+#: fortran/openmp.c:4698
 #, gcc-internal-format
 msgid "%s clause variable %qs at %L is neither a POINTER nor an array"
 msgstr "%s-klausulvariabeln %qs vid %L är varken en POINTER eller en vektor"
 
-#: fortran/openmp.c:4731
+#: fortran/openmp.c:4730
 #, gcc-internal-format, gfc-internal-format
 msgid "DIST_SCHEDULE clause's chunk_size at %L requires a scalar INTEGER expression"
 msgstr "DIST_SCHEDULE-klausulens chunk_size vid %L kräver ett skalärt INTEGER-uttryck"
 
-#: fortran/openmp.c:4763
+#: fortran/openmp.c:4762
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible use of TILE and COLLAPSE at %L"
 msgstr "Inkompatibel användning av TILE och COLLAPSE vid %L"
 
-#: fortran/openmp.c:4765
+#: fortran/openmp.c:4764
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE dependence type only allowed on ORDERED directive at %L"
 msgstr "En SOURCE-beroendetyp är endast tillåten med ORDERED-direktiv vid %L"
 
-#: fortran/openmp.c:4778
+#: fortran/openmp.c:4777
 #, gcc-internal-format, gfc-internal-format
 msgid "%s must contain at least one MAP clause at %L"
 msgstr "%s måste innehålla åtminstone en MAP-klausul vid %L"
 
-#: fortran/openmp.c:4875
+#: fortran/openmp.c:4874
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected !$OMP ATOMIC expression at %L"
 msgstr "oväntat !$OMP ATOMIC-uttryck vid %L"
 
-#: fortran/openmp.c:4904
+#: fortran/openmp.c:4903
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC statement must set a scalar variable of intrinsic type at %L"
 msgstr "!$OMP ATOMIC-sats måste sätta en skalär variabel av inbyggd typ vid %L"
 
-#: fortran/openmp.c:4929
+#: fortran/openmp.c:4928
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC READ statement must read from a scalar variable of intrinsic type at %L"
 msgstr "!$OMP ATOMIC READ-sats måste läsa från en skalär variabel av inbyggd typ vid %L"
 
-#: fortran/openmp.c:4934
+#: fortran/openmp.c:4933
 #, gcc-internal-format, gfc-internal-format
 msgid "expr in !$OMP ATOMIC WRITE assignment var = expr must be scalar and cannot reference var at %L"
 msgstr "uttr i !$OMP ATOMIC WRITE-tilldelning var = uttr måste vara skalär och får inte referera var vid %L"
 
-#: fortran/openmp.c:4956 fortran/openmp.c:5247
+#: fortran/openmp.c:4955 fortran/openmp.c:5246
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE capture statement must read from a scalar variable of intrinsic type at %L"
 msgstr "!$OMP ATOMIC CAPTURE-fångstsats måste läsa från en skalär variabel av inbyggd typ vid %L"
 
-#: fortran/openmp.c:4971
+#: fortran/openmp.c:4970
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE update statement must set a scalar variable of intrinsic type at %L"
 msgstr "!$OMP ATOMIC CAPTURE-uppdateringssats måste sätta en skalär variabel av inbyggd typ vid %L"
 
-#: fortran/openmp.c:4978 fortran/openmp.c:5254
+#: fortran/openmp.c:4977 fortran/openmp.c:5253
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE capture statement reads from different variable than update statement writes into at %L"
 msgstr "!$OMP ATOMIC CAPTURE-fångstsats läser från en annan variabel än uppdateringssatsen skriver till vid %L"
 
-#: fortran/openmp.c:4994
+#: fortran/openmp.c:4993
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC with ALLOCATABLE variable at %L"
 msgstr "!$OMP ATOMIC med ALLOCATABLE variabel vid %L"
 
-#: fortran/openmp.c:5036
+#: fortran/openmp.c:5035
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment operator must be binary +, *, -, /, .AND., .OR., .EQV. or .NEQV. at %L"
 msgstr "!$OMP ATOMIC-tilldelningsoperator måste vara binärt +, *, -, /, .AND., .OR., .EQV. eller .NEQV. vid %L"
 
-#: fortran/openmp.c:5084
+#: fortran/openmp.c:5083
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment must be var = var op expr or var = expr op var at %L"
 msgstr "!$OMP ATOMIC-tilldelning måste vara var = var op uttr eller var = uttr op var vid %L"
 
-#: fortran/openmp.c:5098
+#: fortran/openmp.c:5097
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC var = var op expr not mathematically equivalent to var = var op (expr) at %L"
 msgstr "!$OMP ATOMIC var = var op expr är inte matematiskt ekvivalent med var = var op (uttr) vid %L"
 
-#: fortran/openmp.c:5130
+#: fortran/openmp.c:5129
 #, gcc-internal-format, gfc-internal-format
 msgid "expr in !$OMP ATOMIC assignment var = var op expr must be scalar and cannot reference var at %L"
 msgstr "uttr i !$OMP ATOMIC-tilldelning var = var op uttr måste vara skalär och får inte referera var vid %L"
 
-#: fortran/openmp.c:5154
+#: fortran/openmp.c:5153
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment intrinsic IAND, IOR or IEOR must have two arguments at %L"
 msgstr "!$OMP ATOMIC-tilldelning av inbyggd IAND, IOR eller IEOR måste ha två argument vid %L"
 
-#: fortran/openmp.c:5161
+#: fortran/openmp.c:5160
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment intrinsic must be MIN, MAX, IAND, IOR or IEOR at %L"
 msgstr "!$OMP ATOMIC-tilldelning av inbyggd måste vara MIN, MAX, IAND, IOR eller IEOR vid %L"
 
-#: fortran/openmp.c:5178
+#: fortran/openmp.c:5177
 #, gcc-internal-format
 msgid "!$OMP ATOMIC intrinsic arguments except one must not reference %qs at %L"
 msgstr "!$OMP ATOMIC-inbyggds argument utom ett får inte referera %qs vid %L"
 
-#: fortran/openmp.c:5185
+#: fortran/openmp.c:5184
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC intrinsic arguments must be scalar at %L"
 msgstr "!$OMP ATOMIC-inbyggds argument måste vara skalära vid %L"
 
-#: fortran/openmp.c:5193
+#: fortran/openmp.c:5192
 #, gcc-internal-format
 msgid "First or last !$OMP ATOMIC intrinsic argument must be %qs at %L"
 msgstr "Första eller sista !$OMP ATOMIC-inbyggds argument måste vara %qs vid %L"
 
-#: fortran/openmp.c:5211
+#: fortran/openmp.c:5210
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment must have an operator or intrinsic on right hand side at %L"
 msgstr "!$OMP ATOMIC-tilldelning måste ha en operator eller inbyggd på högersidan vid %L"
 
-#: fortran/openmp.c:5225
+#: fortran/openmp.c:5224
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE capture statement must set a scalar variable of intrinsic type at %L"
 msgstr "!$OMP ATOMIC CAPTURE-fångstsats måste sätta en skalär variabel av inbyggd typ vid %L"
 
-#: fortran/openmp.c:5544
+#: fortran/openmp.c:5543
 #, gcc-internal-format, gfc-internal-format
 msgid "%s cannot be a DO WHILE or DO without loop control at %L"
 msgstr "%s får inte vara en DO WHILE eller DO utan slingstyrning vid %L"
 
-#: fortran/openmp.c:5550
+#: fortran/openmp.c:5549
 #, gcc-internal-format, gfc-internal-format
 msgid "%s cannot be a DO CONCURRENT loop at %L"
 msgstr "%s kan inte vara en DO CONCURRENT-slinga vid %L"
 
-#: fortran/openmp.c:5556
+#: fortran/openmp.c:5555
 #, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable must be of type integer at %L"
 msgstr "%s-iterationsvariabel måste ha typen heltal vid %L"
 
-#: fortran/openmp.c:5560
+#: fortran/openmp.c:5559
 #, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable must not be THREADPRIVATE at %L"
 msgstr "%s-iterationsvariabel får inte vara THREADPRIVATE vid %L"
 
-#: fortran/openmp.c:5573
+#: fortran/openmp.c:5572
 #, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable present on clause other than PRIVATE or LASTPRIVATE at %L"
 msgstr "%s-iterationsvariabel finns i en annan klausul än PRIVATE eller LASTPRIVATE vid %L"
 
-#: fortran/openmp.c:5577
+#: fortran/openmp.c:5576
 #, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable present on clause other than LASTPRIVATE at %L"
 msgstr "%s-iterationsvariabel finns i en annan klausul än LASTPRIVATE vid %L"
 
-#: fortran/openmp.c:5581
+#: fortran/openmp.c:5580
 #, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable present on clause other than LINEAR at %L"
 msgstr "%s-iterationsvariabel finns i en annan klausul än LINEAR vid %L"
 
-#: fortran/openmp.c:5599
+#: fortran/openmp.c:5598
 #, gcc-internal-format, gfc-internal-format
 msgid "%s collapsed loops don't form rectangular iteration space at %L"
 msgstr "%s-kollapsad slinga formar inte en rektangulär iterationsrymd vid %L"
 
-#: fortran/openmp.c:5611
+#: fortran/openmp.c:5610
 #, gcc-internal-format, gfc-internal-format
 msgid "collapsed %s loops not perfectly nested at %L"
 msgstr "kollapsade %s-slingor är inte perfekt nästade vid %L"
 
-#: fortran/openmp.c:5620 fortran/openmp.c:5628
+#: fortran/openmp.c:5619 fortran/openmp.c:5627
 #, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for collapsed %s at %L"
 msgstr "inte tillräckligt med DO-slingor för kollapsad %s vid %L"
 
-#: fortran/openmp.c:5712 fortran/openmp.c:5725
+#: fortran/openmp.c:5711 fortran/openmp.c:5724
 #, gcc-internal-format, gfc-internal-format
 msgid "The %s directive cannot be specified within a %s region at %L"
 msgstr "Direktivet %s kan inte anges inuti en %s-region vid %L"
 
-#: fortran/openmp.c:5744
+#: fortran/openmp.c:5743
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP cannot be a DO WHILE or DO without loop control at %L"
 msgstr "!$ACC LOOP får inte vara en DO WHILE eller DO utan slingstyrning vid %L"
 
-#: fortran/openmp.c:5750
+#: fortran/openmp.c:5749
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP iteration variable must be of type integer at %L"
 msgstr "!$ACC LOOP-iterationsvariabel måste ha typen heltal vid %L"
 
-#: fortran/openmp.c:5766
+#: fortran/openmp.c:5765
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s loops don't form rectangular iteration space at %L"
 msgstr "!$ACC LOOP %s-slingor formar inte en rektangulär iterationsrymd vid %L"
 
-#: fortran/openmp.c:5778
+#: fortran/openmp.c:5777
 #, gcc-internal-format, gfc-internal-format
 msgid "%s !$ACC LOOP loops not perfectly nested at %L"
 msgstr "%s !$ACC LOOP-slingor är inte perfekt nästade vid %L"
 
-#: fortran/openmp.c:5788 fortran/openmp.c:5797
+#: fortran/openmp.c:5787 fortran/openmp.c:5796
 #, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for %s !$ACC LOOP at %L"
 msgstr "inte tillräckligt med DO-slingor för %s !$ACC LOOP vid %L"
 
-#: fortran/openmp.c:5812 fortran/openmp.c:5819
+#: fortran/openmp.c:5811 fortran/openmp.c:5818
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s in PARALLEL region doesn't allow %s arguments at %L"
 msgstr "!$ACC LOOP %s i PARALLEL-region tillåter inte %s-argument vid %L"
 
-#: fortran/openmp.c:5841
+#: fortran/openmp.c:5840
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside another loop parallelized across gangs at %L"
 msgstr "Slinga parallelliserad över gang är inte tillåten inuti en annan slinga parallelliserad över gang vid %L"
 
-#: fortran/openmp.c:5845 fortran/openmp.c:5849
+#: fortran/openmp.c:5844 fortran/openmp.c:5848
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside loop parallelized across workers at %L"
 msgstr "Slinga parallelliserad över gang är inte tillåten inuti en slinga parallelliserad över worker vid %L"
 
-#: fortran/openmp.c:5856
+#: fortran/openmp.c:5855
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across workers at %L"
 msgstr "Slinga parallelliserad över worker är inte tillåten inuti en annan slinga parallelliserad över worker vid %L"
 
-#: fortran/openmp.c:5860
+#: fortran/openmp.c:5859
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across vectors at %L"
 msgstr "Slinga parallelliserad över worker är inte tillåten inuti en annan slinga parallelliserad över vektorer vid %L"
 
-#: fortran/openmp.c:5866
+#: fortran/openmp.c:5865
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across vectors is not allowed inside another loop parallelized across vectors at %L"
 msgstr "Slinga parallelliserad över vektorer är inte tillåten inuti en annan slinga parallelliserad över vektorer vid %L"
 
-#: fortran/openmp.c:5878
+#: fortran/openmp.c:5877
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with INDEPENDENT at %L"
 msgstr "Klausulen SEQ står i konflikt med INDEPENDENT vid %L"
 
-#: fortran/openmp.c:5880
+#: fortran/openmp.c:5879
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with GANG at %L"
 msgstr "Klausulen SEQ  står i konflikt med GANG vid %L"
 
-#: fortran/openmp.c:5882
+#: fortran/openmp.c:5881
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with WORKER at %L"
 msgstr "Klausulen SEQ står i konflikt med WORKER vid %L"
 
-#: fortran/openmp.c:5884
+#: fortran/openmp.c:5883
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with VECTOR at %L"
 msgstr "Klausulen SEQ står i konflikt med VECTOR vid %L"
 
-#: fortran/openmp.c:5886
+#: fortran/openmp.c:5885
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with AUTO at %L"
 msgstr "Klausulen SEQ står i konflikt med AUTO vid %L"
 
-#: fortran/openmp.c:5891
+#: fortran/openmp.c:5890
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with GANG at %L"
 msgstr "Klausulen AUTO står i konflikt med GANG vid %L"
 
-#: fortran/openmp.c:5893
+#: fortran/openmp.c:5892
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with WORKER at %L"
 msgstr "Klausulen AUTO står i konflikt med WORKER vid %L"
 
-#: fortran/openmp.c:5895
+#: fortran/openmp.c:5894
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with VECTOR at %L"
 msgstr "Klausulen AUTO står i konflikt med VECTOR vid %L"
 
-#: fortran/openmp.c:5899
+#: fortran/openmp.c:5898
 #, gcc-internal-format, gfc-internal-format
 msgid "Tiled loop cannot be parallelized across gangs, workers and vectors at the same time at %L"
 msgstr "Slinga uppdelad i bitar kan inte parallelliseras över gang, worker och vektorer på samma gång vid %L"
 
-#: fortran/openmp.c:5934
+#: fortran/openmp.c:5933
 #, gcc-internal-format, gfc-internal-format
 msgid "TILE requires constant expression at %L"
 msgstr "TILE behöver ett konstant uttryck vid %L"
 
-#: fortran/openmp.c:5999
+#: fortran/openmp.c:6004
 #, gcc-internal-format
 msgid "PARAMETER object %qs is not allowed at %L"
 msgstr "PARAMETER-objekt %qs är inte tillåtet vid %L"
 
-#: fortran/openmp.c:6006
+#: fortran/openmp.c:6011
 #, gcc-internal-format
 msgid "Array sections: %qs not allowed in !$ACC DECLARE at %L"
 msgstr "Vektorsektioner: %qs är inte tillåtet i !$ACC DECLARE vid %L"
 
-#: fortran/openmp.c:6133
+#: fortran/openmp.c:6138
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP TARGET UPDATE at %L requires at least one TO or FROM clause"
 msgstr "OMP TARGET UPDATE vid %L behöver åtminstone en TO- eller FROM-klausul"
 
-#: fortran/openmp.c:6155
+#: fortran/openmp.c:6160
 #, gcc-internal-format
 msgid "!$OMP DECLARE SIMD should refer to containing procedure %qs at %L"
 msgstr "!$OMP DECLARE SIMD skall referera till den inneslutande proceduren %qs vid %L"
 
-#: fortran/openmp.c:6179
+#: fortran/openmp.c:6184
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_PRIV or OMP_ORIG used in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr "En annan variabel än OMP_PRIV eller OMP_ORIG använd i INITIALIZER-klausul i !$OMP DECLARE REDUCTION vid %L"
 
-#: fortran/openmp.c:6187
+#: fortran/openmp.c:6192
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_OUT or OMP_IN used in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr "En annan variabel än OMP_OUT eller OMP_IN använd i kombineraren i !$OMP DECLARE REDUCTION vid %L"
 
-#: fortran/openmp.c:6216
+#: fortran/openmp.c:6221
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid operator for !$OMP DECLARE REDUCTION %s at %L"
 msgstr "Felaktig operator för !$OMP DECLARE REDUCTION %s vid %L"
 
-#: fortran/openmp.c:6238
+#: fortran/openmp.c:6243
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER length in !$OMP DECLARE REDUCTION %s not constant at %L"
 msgstr "CHARACTER-längden i !$OMP DECLARE REDUCTION %s är inte konstant vid %L"
 
-#: fortran/openmp.c:6254
+#: fortran/openmp.c:6259
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr "Subrutinanrop med alternativa returer i kombinerare i !$OMP DECLARE REDUCTION vid %L"
 
-#: fortran/openmp.c:6269
+#: fortran/openmp.c:6274
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr "Subrutinanrop med alternativa returer i INITIALIZER-klausul i !$OMP DECLARE REDUCTION vid %L"
 
-#: fortran/openmp.c:6279
+#: fortran/openmp.c:6284
 #, gcc-internal-format, gfc-internal-format
 msgid "One of actual subroutine arguments in INITIALIZER clause of !$OMP DECLARE REDUCTION must be OMP_PRIV at %L"
 msgstr "Ett av de aktuella subrutinargumenten i INITIALIZER-klausulen i !$OMP DECLARE REDUCTION måste vara OMP_PRIV vid %L"
 
-#: fortran/openmp.c:6287
+#: fortran/openmp.c:6292
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing INITIALIZER clause for !$OMP DECLARE REDUCTION of derived type without default initializer at %L"
 msgstr "INITIALIZER-klausul saknas i !$OMP DECLARE REDUCTION av härledd typ utan standardinitierare vid %L"
@@ -57182,492 +57259,492 @@
 msgid "Unclassifiable statement at %C"
 msgstr "Oklassificerbar sats vid %C"
 
-#: fortran/parse.c:629
+#: fortran/parse.c:631
 #, gcc-internal-format, gfc-internal-format
 msgid "OpenACC directives at %C may not appear in PURE procedures"
 msgstr "OpenACC-direktiv vid %C får inte förekomma i PURE-procedurer"
 
-#: fortran/parse.c:705
+#: fortran/parse.c:707
 #, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable OpenACC directive at %C"
 msgstr "Oklassificerbart OpenACC-direktiv vid %C"
 
-#: fortran/parse.c:831 fortran/parse.c:1040
+#: fortran/parse.c:835 fortran/parse.c:1044
 #, gcc-internal-format, gfc-internal-format
 msgid "OpenMP directives other than SIMD or DECLARE TARGET at %C may not appear in PURE or ELEMENTAL procedures"
 msgstr "Andra OpenMP-direktiv än SIMD eller DECLARE TARGET vid %C för inte förekomma i PURE- eller ELEMENTAL-procedurer"
 
-#: fortran/parse.c:1024
+#: fortran/parse.c:1028
 #, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable OpenMP directive at %C"
 msgstr "Oklassificerbart OpenMP-direktiv vid %C"
 
-#: fortran/parse.c:1076
+#: fortran/parse.c:1080
 #, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable GCC directive at %C"
 msgstr "Oklassificerbart GCC-direktiv vid %C"
 
-#: fortran/parse.c:1135 fortran/parse.c:1362
+#: fortran/parse.c:1139 fortran/parse.c:1366
 #, gcc-internal-format, gfc-internal-format
 msgid "Zero is not a valid statement label at %C"
 msgstr "Noll är inte en giltig satsetikett vid %C"
 
-#: fortran/parse.c:1142 fortran/parse.c:1354
+#: fortran/parse.c:1146 fortran/parse.c:1358
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-numeric character in statement label at %C"
 msgstr "Icke-numeriska tecken i satsetikett vid %C"
 
-#: fortran/parse.c:1154 fortran/parse.c:1403
+#: fortran/parse.c:1158 fortran/parse.c:1407
 #, gcc-internal-format, gfc-internal-format
 msgid "Semicolon at %C needs to be preceded by statement"
 msgstr "Semikolon vid %C måste föregås av en sats"
 
-#: fortran/parse.c:1161 fortran/parse.c:1418
+#: fortran/parse.c:1165 fortran/parse.c:1422
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label without statement at %L"
 msgstr "Satsetikett utan sats vid %L"
 
-#: fortran/parse.c:1224 fortran/parse.c:1405
+#: fortran/parse.c:1228 fortran/parse.c:1409
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Semicolon at %C without preceding statement"
 msgstr "Fortran 2008: Semikolon vid %C utan föregående sats"
 
-#: fortran/parse.c:1247 fortran/parse.c:1381
+#: fortran/parse.c:1251 fortran/parse.c:1385
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad continuation line at %C"
 msgstr "Felaktig fortsättningsrad vid %C"
 
-#: fortran/parse.c:1679
+#: fortran/parse.c:1683
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT statement at %L does not have a statement label"
 msgstr "FORMAT-sats vid %L har inte en satsetikett"
 
-#: fortran/parse.c:2435
+#: fortran/parse.c:2439
 #, gcc-internal-format
 msgid "gfc_ascii_statement(): Bad statement code"
 msgstr "gfc_ascii_statement(): Felaktig satskod"
 
-#: fortran/parse.c:2577
+#: fortran/parse.c:2581
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement at %C"
 msgstr "Oväntad %s-sats vid %C"
 
-#: fortran/parse.c:2732
+#: fortran/parse.c:2736
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot follow %s statement at %L"
 msgstr "%s-sats vid %C får inte följa efter %s-sats vid %L"
 
-#: fortran/parse.c:2749
+#: fortran/parse.c:2753
 #, gcc-internal-format
 msgid "Unexpected end of file in %qs"
 msgstr "Oväntat filslut i %qs"
 
-#: fortran/parse.c:2784
+#: fortran/parse.c:2788
 #, gcc-internal-format
 msgid "Derived-type %qs with SEQUENCE must not have a CONTAINS section at %C"
 msgstr "Härledd typ %qs med SEQUENCE får inte ha en CONTAINS-sektion vid %C"
 
-#: fortran/parse.c:2787
+#: fortran/parse.c:2791
 #, gcc-internal-format
 msgid "Derived-type %qs with BIND(C) must not have a CONTAINS section at %C"
 msgstr "Härledd typ %qs med BIND(C) får inte ha en CONTAINS-sektion vid %C"
 
-#: fortran/parse.c:2807
+#: fortran/parse.c:2811
 #, gcc-internal-format, gfc-internal-format
 msgid "Components in TYPE at %C must precede CONTAINS"
 msgstr "Komponenter i TYPE vid %C måste föregå CONTAINS"
 
-#: fortran/parse.c:2811
+#: fortran/parse.c:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound procedure at %C"
 msgstr "Typbunden procedur vid %C"
 
-#: fortran/parse.c:2819
+#: fortran/parse.c:2823
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC binding at %C"
 msgstr "GENERIC-bindning vid %C"
 
-#: fortran/parse.c:2827
+#: fortran/parse.c:2831
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure declaration at %C"
 msgstr "FINAL-procedurdeklaration vid %C"
 
-#: fortran/parse.c:2839
+#: fortran/parse.c:2843
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type definition at %C with empty CONTAINS section"
 msgstr "Härledd typdefinition vid %C med tom CONTAINS-sektion"
 
-#: fortran/parse.c:2849 fortran/parse.c:3304
+#: fortran/parse.c:2853 fortran/parse.c:3308
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement in TYPE at %C must be inside a MODULE"
 msgstr "PRIVATE-sats i TYPE vid %C måste vara inuti en MODULE"
 
-#: fortran/parse.c:2856
+#: fortran/parse.c:2860
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede procedure bindings"
 msgstr "PRIVATE-sats vid %C måste föregå procedurbindningar"
 
-#: fortran/parse.c:2863 fortran/parse.c:3317
+#: fortran/parse.c:2867 fortran/parse.c:3321
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PRIVATE statement at %C"
 msgstr "Dubblerad PRIVATE-sats vid %C"
 
-#: fortran/parse.c:2873
+#: fortran/parse.c:2877
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede CONTAINS"
 msgstr "SEQUENCE-sats vid %C måste föregå CONTAINS"
 
-#: fortran/parse.c:2877
+#: fortran/parse.c:2881
 #, gcc-internal-format, gfc-internal-format
 msgid "Already inside a CONTAINS block at %C"
 msgstr "Redan inuti ett CONTAINS-block vid %C"
 
-#: fortran/parse.c:2996
+#: fortran/parse.c:3000
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s at %L of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray, which is not possible as the component has the pointer attribute"
 msgstr "Komponenten %s vid %L av typen LOCK_TYPE måste ha en co-dimension eller vara en delkomponent till en co-vektor, vilket inte är möjligt eftersom komponenten har pekarattributet"
 
-#: fortran/parse.c:3002
+#: fortran/parse.c:3006
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer component %s at %L has a noncoarray subcomponent of type LOCK_TYPE, which must have a codimension or be a subcomponent of a coarray"
 msgstr "Pekarkomponenten %s vid %L har en icke co-vektordelkomponent av typen LOCK_TYPE, som måste ha en co-dimension eller vara en delkomponent av en co-vektor"
 
-#: fortran/parse.c:3007
+#: fortran/parse.c:3011
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L of type LOCK_TYPE must have a codimension"
 msgstr "Allokerbar komponent %s vid %L av typen LOCK_TYPE måste ha en co-dimension"
 
-#: fortran/parse.c:3011
+#: fortran/parse.c:3015
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L must have a codimension as it has a noncoarray subcomponent of type LOCK_TYPE"
 msgstr "Den allokerbara komponenten %s vid %L måste ha en co-dimension eftersom den har en icke co-vektordelkomponent av typen LOCK_TYPE"
 
-#: fortran/parse.c:3016
+#: fortran/parse.c:3020
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as already a coarray subcomponent exists)"
 msgstr "Icke co-vektorkomponenten %s vid %L av typen LOCK_TYPE eller med en underkomponent av typen LOCK_TYPE måste ha en co-dimension eller vara en underkomponent av en co-vektor.  (Variabler av typen %s får inte ha en co-dimension eftersom det redan finns en co-vektorunderkomponent)"
 
-#: fortran/parse.c:3023
+#: fortran/parse.c:3027
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as %s at %L has a codimension or a coarray subcomponent)"
 msgstr "Icke co-vektorkomponenten %s vid %L av typen LOCK_TYPE eller med en underkomponent av typen LOCK_TYPE måste ha en co-dimension eller vara en underkomponent till en co-vektor.  (Variabler av typen %s får inte ha en co-dimension eftersom %s vid %L har en co-dimension eller en co-vektorunderkomponent)"
 
-#: fortran/parse.c:3033
+#: fortran/parse.c:3037
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s at %L of type EVENT_TYPE must have a codimension or be a subcomponent of a coarray, which is not possible as the component has the pointer attribute"
 msgstr "Komponenten %s vid %L av typen EVENT_TYPE måste ha en co-dimension eller vara en delkomponent till en co-vektor, vilket inte är möjligt eftersom komponenten har pekarattributet"
 
-#: fortran/parse.c:3039
+#: fortran/parse.c:3043
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer component %s at %L has a noncoarray subcomponent of type EVENT_TYPE, which must have a codimension or be a subcomponent of a coarray"
 msgstr "Pekarkomponenten %s vid %L har en icke co-vektordelkomponent av typen EVENT_TYPE, som måste ha en co-dimension eller vara en delkomponent av en co-vektor"
 
-#: fortran/parse.c:3044
+#: fortran/parse.c:3048
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L of type EVENT_TYPE must have a codimension"
 msgstr "Allokerbar komponent %s vid %L av typen EVENT_TYPE måste ha en co-dimension"
 
-#: fortran/parse.c:3048
+#: fortran/parse.c:3052
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L must have a codimension as it has a noncoarray subcomponent of type EVENT_TYPE"
 msgstr "Den allokerbara komponenten %s vid %L måste ha en co-dimension eftersom den har en icke co-vektordelkomponent av typen EVENT_TYPE"
 
-#: fortran/parse.c:3053
+#: fortran/parse.c:3057
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as already a coarray subcomponent exists)"
 msgstr "Icke co-vektorkomponenten %s vid %L av typen EVENT_TYPE eller med en underkomponent av typen LOCK_TYPE måste ha en co-dimension eller vara en underkomponent av en co-vektor.  (Variabler av typen %s får inte ha en co-dimension eftersom det redan finns en co-vektorunderkomponent)"
 
-#: fortran/parse.c:3060
+#: fortran/parse.c:3064
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as %s at %L has a codimension or a coarray subcomponent)"
 msgstr "Icke co-vektorkomponenten %s vid %L av typen EVENT_TYPE eller med en underkomponent av typen EVENT_TYPE måste ha en co-dimension eller vara en underkomponent till en co-vektor.  (Variabler av typen %s får inte ha en co-dimension eftersom %s vid %L har en co-dimension eller en co-vektorunderkomponent)"
 
-#: fortran/parse.c:3112
+#: fortran/parse.c:3116
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to create map component '%s'"
 msgstr "misslyckades att skapa en avbildningskomponent ”%s”"
 
-#: fortran/parse.c:3145
+#: fortran/parse.c:3149
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to create union component '%s'"
 msgstr "kunde inte hitta skapa unionkomponenten ”%s”"
 
-#: fortran/parse.c:3200
+#: fortran/parse.c:3204
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in nested structure declaration at %C"
 msgstr "Syntaxfel i nästad postdeklaration vid %C"
 
-#: fortran/parse.c:3287
+#: fortran/parse.c:3291
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside CONTAINS"
 msgstr "FINAL-deklaration vid %C måste vara inuti CONTAINS"
 
-#: fortran/parse.c:3295
+#: fortran/parse.c:3299
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type definition at %C without components"
 msgstr "Härledd typdefinition vid %C utan komponenter"
 
-#: fortran/parse.c:3311
+#: fortran/parse.c:3315
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede structure components"
 msgstr "PRIVATE-sats vid %C måste föregå strukturkomponenter"
 
-#: fortran/parse.c:3328
+#: fortran/parse.c:3332
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede structure components"
 msgstr "SEQUENCE-sats vid %C måste föregå strukturkomponenter"
 
-#: fortran/parse.c:3334
+#: fortran/parse.c:3338
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE attribute at %C already specified in TYPE statement"
 msgstr "SEQUENCE-attribut vid %C är redan angett i TYPE-sats"
 
-#: fortran/parse.c:3339
+#: fortran/parse.c:3343
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SEQUENCE statement at %C"
 msgstr "Dubblerad SEQUENCE-sats vid %C"
 
-#: fortran/parse.c:3349
+#: fortran/parse.c:3353
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS block in derived type definition at %C"
 msgstr "CONTAINS-block i härledd typdefinition vid %C"
 
-#: fortran/parse.c:3407
+#: fortran/parse.c:3411
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM declaration at %C has no ENUMERATORS"
 msgstr "ENUM-deklaration vid %C har inga ENUMERATORS"
 
-#: fortran/parse.c:3494
+#: fortran/parse.c:3498
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in INTERFACE block at %C"
 msgstr "Oväntad %s-sats i INTERFACE-block vid %C"
 
-#: fortran/parse.c:3518
+#: fortran/parse.c:3522
 #, gcc-internal-format
 msgid "Name %qs of ABSTRACT INTERFACE at %C cannot be the same as an intrinsic type"
 msgstr "Namnet %qs i ABSTRACT INTERFACE vid %C kan inte vara samma som en inbyggd typ"
 
-#: fortran/parse.c:3552
+#: fortran/parse.c:3556
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement at %C in INTERFACE body"
 msgstr "Oväntad %s-sats vid %C i INTERFACE-kropp"
 
-#: fortran/parse.c:3570
+#: fortran/parse.c:3574
 #, gcc-internal-format
 msgid "INTERFACE procedure %qs at %L has the same name as the enclosing procedure"
 msgstr "INTERFACE-procedur %qs vid %L har samma namn som den inneslutande proceduren"
 
-#: fortran/parse.c:3700
+#: fortran/parse.c:3704
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement is not allowed inside of BLOCK at %C"
 msgstr "%s-sats är inte tillåten inuti BLOCK vid %C"
 
-#: fortran/parse.c:3732
+#: fortran/parse.c:3736
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement is not allowed inside of BLOCK DATA at %C"
 msgstr "%s-sats är inte tillåten inuti BLOCK DATA vid %C"
 
-#: fortran/parse.c:3822
+#: fortran/parse.c:3826
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement must appear in a MODULE"
 msgstr "%s-sats måste vara i en MODULE"
 
-#: fortran/parse.c:3830
+#: fortran/parse.c:3834
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C follows another accessibility specification"
 msgstr "%s-sats vid %C följer på en annan åtkomstspecifikation"
 
-#: fortran/parse.c:3882
+#: fortran/parse.c:3886
 #, gcc-internal-format
 msgid "Bad kind expression for function %qs at %L"
 msgstr "Fel sorts uttryck för funktionen %qs vid %L"
 
-#: fortran/parse.c:3886
+#: fortran/parse.c:3890
 #, gcc-internal-format
 msgid "The type for function %qs at %L is not accessible"
 msgstr "Typen på funktionen %qs vid %L är inte tillgänglig"
 
-#: fortran/parse.c:3946
+#: fortran/parse.c:3950
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C follows previous unmasked ELSEWHERE"
 msgstr "ELSEWHERE-sats vid %C följer tidigare omaskerat ELSEWHERE"
 
-#: fortran/parse.c:3968
+#: fortran/parse.c:3972
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in WHERE block at %C"
 msgstr "Oväntad %s-sats i WHERE-block vid %C"
 
-#: fortran/parse.c:4027
+#: fortran/parse.c:4031
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in FORALL block at %C"
 msgstr "Oväntad %s-sats i FORALL-block vid %C"
 
-#: fortran/parse.c:4078
+#: fortran/parse.c:4082
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSE IF statement at %C cannot follow ELSE statement at %L"
 msgstr "ELSE IF-sats vid %C kan inte följa ELSE-sats vid %L"
 
-#: fortran/parse.c:4096
+#: fortran/parse.c:4100
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ELSE statements at %L and %C"
 msgstr "Dubblerad ELSE-sats vid %L och %C"
 
-#: fortran/parse.c:4157
+#: fortran/parse.c:4161
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected a CASE or END SELECT statement following SELECT CASE at %C"
 msgstr "En CASE- eller END SELECT-sats förväntades följa efter SELECT CASE vid %C"
 
-#: fortran/parse.c:4241
+#: fortran/parse.c:4245
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected TYPE IS, CLASS IS or END SELECT statement following SELECT TYPE at %C"
 msgstr "En TYPE IS-, CLASS IS- eller END SELECT-sats förväntades följa efter SELECT TYPE vid %C"
 
-#: fortran/parse.c:4303
+#: fortran/parse.c:4307
 #, gcc-internal-format
 msgid "Variable %qs at %C cannot be redefined inside loop beginning at %L"
 msgstr "Variabeln %qs vid %C får inte definieras om inuti slingan som börjar vid %L"
 
-#: fortran/parse.c:4336
+#: fortran/parse.c:4340
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is within another block"
 msgstr "Slut på DO-sats utan block vid %C är inuti ett annat block"
 
-#: fortran/parse.c:4346
+#: fortran/parse.c:4350
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is interwoven with another DO loop"
 msgstr "Slut på DO-sats utan block vid %C är sammanvävt med en annan DO-slinga"
 
-#: fortran/parse.c:4372
+#: fortran/parse.c:4376
 #, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL block inside of OpenACC region at %C"
 msgstr "CRITICAL-block inuti OpenACC-region vid %C"
 
-#: fortran/parse.c:4373
+#: fortran/parse.c:4377
 #, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL block inside of OpenMP region at %C"
 msgstr "CRITICAL-block i unuti OpenMP-region vid %C"
 
-#: fortran/parse.c:4399
+#: fortran/parse.c:4403
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label in END CRITICAL at %C does not match CRITICAL label"
 msgstr "Satsetikett i END CRITICAL vid %C stämmer inte med CRITICAL-etikett"
 
-#: fortran/parse.c:4468
+#: fortran/parse.c:4472
 #, gcc-internal-format, gfc-internal-format
 msgid "BLOCK construct at %C"
 msgstr "BLOCK-konstruktion vid %C"
 
-#: fortran/parse.c:4502
+#: fortran/parse.c:4506
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSOCIATE construct at %C"
 msgstr "ASSOCIATE-konstruktion vid %C"
 
-#: fortran/parse.c:4690
+#: fortran/parse.c:4694
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label in ENDDO at %C doesn't match DO label"
 msgstr "Satsetikett i ENDDO vid %C stämmer inte med DO-etikett"
 
-#: fortran/parse.c:4706
+#: fortran/parse.c:4710
 #, gcc-internal-format, gfc-internal-format
 msgid "Named block DO at %L requires matching ENDDO name"
 msgstr "Namngivet DO-block vid %L kräver matchande ENDDO-namn"
 
-#: fortran/parse.c:4897
+#: fortran/parse.c:4901
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing !$OMP END ATOMIC after !$OMP ATOMIC CAPTURE at %C"
 msgstr "!$OMP END ATOMIC saknas efter !$OMP ATOMIC CAPTURE vid %C"
 
-#: fortran/parse.c:4913 fortran/parse.c:4972
+#: fortran/parse.c:4917 fortran/parse.c:4976
 #, gcc-internal-format, gfc-internal-format
 msgid "OpenACC directive inside of CRITICAL block at %C"
 msgstr "OpenACC-direktiv inuti CRITICAL-block vid %C"
 
-#: fortran/parse.c:4947
+#: fortran/parse.c:4951
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s at %C"
 msgstr "%s förväntades vid %C"
 
-#: fortran/parse.c:4991
+#: fortran/parse.c:4995
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected DO loop at %C"
 msgstr "DO-slinga förväntades vid %C"
 
-#: fortran/parse.c:5011
+#: fortran/parse.c:5015
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant !$ACC END LOOP at %C"
 msgstr "Överflödig !$ACC END LOOP vid %C"
 
-#: fortran/parse.c:5225
+#: fortran/parse.c:5229
 #, gcc-internal-format, gfc-internal-format
 msgid "Name after !$omp critical and !$omp end critical does not match at %C"
 msgstr "Namn efter !$omp critical och !$omp end critical matchar inte vid %C"
 
-#: fortran/parse.c:5283
+#: fortran/parse.c:5287
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot terminate a non-block DO loop"
 msgstr "%s-sats vid %C kan inte avsluta en DO-slinga utan block"
 
-#: fortran/parse.c:5297
+#: fortran/parse.c:5301
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %C after the first executable statement"
 msgstr "DATA-sats vid %C efter den första körbara satsen"
 
-#: fortran/parse.c:5423
+#: fortran/parse.c:5427
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive does not commence a loop at %C"
 msgstr "Direktivet %<GCC unroll%> börjar inte en slinga vid %C"
 
-#: fortran/parse.c:5538
+#: fortran/parse.c:5542
 #, gcc-internal-format
 msgid "Contained procedure %qs at %C is already ambiguous"
 msgstr "Innesluten procedur %qs vid %C är redan tvetydig"
 
-#: fortran/parse.c:5595
+#: fortran/parse.c:5599
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in CONTAINS section at %C"
 msgstr "Oväntad %s-sats i CONTAINS-sektion vid %C"
 
-#: fortran/parse.c:5620
+#: fortran/parse.c:5624
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS statement without FUNCTION or SUBROUTINE statement at %L"
 msgstr "CONTAINS-sats utan FUNCTION- eller SUBROUTINE-sats vid %L"
 
-#: fortran/parse.c:5732
+#: fortran/parse.c:5736
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS statement at %C is already in a contained program unit"
 msgstr "CONTAINS-sats vid %C är redan i en innesluten programenhet"
 
-#: fortran/parse.c:5784
+#: fortran/parse.c:5788
 #, gcc-internal-format
 msgid "Global binding name %qs at %L is already being used as a %s at %L"
 msgstr "Globalt bindningsnamn %qs vid %L används redan som en %s vid %L"
 
-#: fortran/parse.c:5788
+#: fortran/parse.c:5792
 #, gcc-internal-format
 msgid "Global name %qs at %L is already being used as a %s at %L"
 msgstr "Globalt namn %qs vid %L används redan som en %s vid %L"
 
-#: fortran/parse.c:5794
+#: fortran/parse.c:5798
 #, gcc-internal-format
 msgid "Global binding name %qs at %L is already being used at %L"
 msgstr "Globalt bindningsnamn %qs vid %L används redan vid %L"
 
-#: fortran/parse.c:5797
+#: fortran/parse.c:5801
 #, gcc-internal-format
 msgid "Global name %qs at %L is already being used at %L"
 msgstr "Globalt namn %qs vid %L används redan vid %L"
 
-#: fortran/parse.c:5819
+#: fortran/parse.c:5823
 #, gcc-internal-format, gfc-internal-format
 msgid "Blank BLOCK DATA at %C conflicts with prior BLOCK DATA at %L"
 msgstr "Blank BLOCK DATA vid %C står i konflikt med tidigare BLOCK DATA vid %L"
 
-#: fortran/parse.c:5845
+#: fortran/parse.c:5849
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in BLOCK DATA at %C"
 msgstr "Oväntad %s-sats i BLOCK DATA vid %C"
 
-#: fortran/parse.c:5949
+#: fortran/parse.c:5953
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in MODULE at %C"
 msgstr "Oväntad %s-sats i MODULE vid %C"
@@ -57675,7 +57752,7 @@
 #. If we see a duplicate main program, shut down.  If the second
 #. instance is an implied main program, i.e. data decls or executable
 #. statements, we're in for lots of errors.
-#: fortran/parse.c:6333
+#: fortran/parse.c:6337
 #, gcc-internal-format, gfc-internal-format
 msgid "Two main PROGRAMs at %L and %C"
 msgstr "Två huvud-PROGRAM vid %L och %C"
@@ -58422,7 +58499,7 @@
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr "Icke RECURSIVE procedur %qs vid %L anropar kanske sig själv rekursivt.  Deklarera den RECURSIVE eller använd %<-frecursive%>."
 
-#: fortran/resolve.c:1893 fortran/resolve.c:9560 fortran/resolve.c:11225
+#: fortran/resolve.c:1893 fortran/resolve.c:9573 fortran/resolve.c:11245
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "Etikett %d som refereras vid %L är aldrig definierad"
@@ -58532,7 +58609,7 @@
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "Funktionen %qs vid %L har ingen IMPLICIT-typ; menade du %qs?"
 
-#: fortran/resolve.c:2905 fortran/resolve.c:16283
+#: fortran/resolve.c:2905 fortran/resolve.c:16310
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr "Funktionen %qs vid %L har ingen IMPLICIT-typ"
@@ -58653,197 +58730,197 @@
 msgid "logical_to_bitwise(): Bad intrinsic"
 msgstr "logical_to_bitwise(): Felaktig inbyggd"
 
-#: fortran/resolve.c:4059
+#: fortran/resolve.c:4065
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr "resolve_operator(): Felaktig inbyggd"
 
-#: fortran/resolve.c:4229 fortran/resolve.c:4252
+#: fortran/resolve.c:4235 fortran/resolve.c:4258
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr "compare_bound_int(): Felaktigt uttryck"
 
-#: fortran/resolve.c:4347
+#: fortran/resolve.c:4353
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Vektorreferens vid %L är utanför gränsen (%ld < %ld) i dimension %d"
 
-#: fortran/resolve.c:4352
+#: fortran/resolve.c:4358
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr "Vektorreferens vid %L är utanför gränsen (%ld < %ld) i co-dimension %d"
 
-#: fortran/resolve.c:4362
+#: fortran/resolve.c:4368
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Vektorreferens vid %L är utanför gränsen (%ld > %ld) i dimension %d"
 
-#: fortran/resolve.c:4367
+#: fortran/resolve.c:4373
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr "Vektorreferens vid %L är utanför gränsen (%ld > %ld) i co-dimension %d"
 
-#: fortran/resolve.c:4387
+#: fortran/resolve.c:4393
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr "Otillåtet steg på noll vid %L"
 
-#: fortran/resolve.c:4404
+#: fortran/resolve.c:4410
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Undre vektorreferens vid %L är utanför gränsen (%ld < %ld) i dimension %d"
 
-#: fortran/resolve.c:4412
+#: fortran/resolve.c:4418
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Undre vektorreferens vid %L är utanför gränsen (%ld > %ld) i dimension %d"
 
-#: fortran/resolve.c:4428
+#: fortran/resolve.c:4434
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Övre vektorreferens vid %L är utanför gränsen (%ld < %ld) i dimension %d"
 
-#: fortran/resolve.c:4437
+#: fortran/resolve.c:4443
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Övre vektorreferens vid %L är utanför gränsen (%ld > %ld) i dimension %d"
 
-#: fortran/resolve.c:4453
+#: fortran/resolve.c:4459
 #, gcc-internal-format
 msgid "check_dimension(): Bad array reference"
 msgstr "check_dimension(): Felaktig vektorreferens"
 
-#: fortran/resolve.c:4476
+#: fortran/resolve.c:4482
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr "Högraste övre gränsen av en sektion av vektor med antagen storlek inte angiven vid %L"
 
-#: fortran/resolve.c:4486
+#: fortran/resolve.c:4492
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr "Ordning stämmer inte i vektorreferens vid %L (%d/%d)"
 
-#: fortran/resolve.c:4494
+#: fortran/resolve.c:4500
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr "Co-indexordning stämmer inte i vektorreferens vid %L (%d/%d)"
 
-#: fortran/resolve.c:4510
+#: fortran/resolve.c:4516
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr "Co-index i co-dimension %d måste vara en skalär vid %L"
 
-#: fortran/resolve.c:4538
+#: fortran/resolve.c:4544
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr "Vektorindex vid %L måste vara skalärt"
 
-#: fortran/resolve.c:4544
+#: fortran/resolve.c:4550
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr "Vektorindex vid %L måste ha INTEGER-typ, fann %s"
 
-#: fortran/resolve.c:4550
+#: fortran/resolve.c:4556
 #, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr "REAL-vektorindex vid %L"
 
-#: fortran/resolve.c:4589
+#: fortran/resolve.c:4595
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr "Dim-argumentet vid %L måste vara skalärt"
 
-#: fortran/resolve.c:4596
+#: fortran/resolve.c:4602
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr "Dim-argumentet vid %L måste ha INTEGER-typ"
 
-#: fortran/resolve.c:4641
+#: fortran/resolve.c:4647
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr "find_array_spec(): Specifikation saknas"
 
-#: fortran/resolve.c:4652
+#: fortran/resolve.c:4658
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr "find_array_spec(): oanvänd as(1)"
 
-#: fortran/resolve.c:4663
+#: fortran/resolve.c:4669
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr "find_array_spec(): oanvänd as(2)"
 
-#: fortran/resolve.c:4706
+#: fortran/resolve.c:4712
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr "Vektorindex vid %L är en vektor med ordning %d"
 
-#: fortran/resolve.c:4804
+#: fortran/resolve.c:4810
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr "Startindex för delsträng vid %L måste typen INTEGER"
 
-#: fortran/resolve.c:4811
+#: fortran/resolve.c:4817
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr "Startindex för delsträng vid %L måste vara skalärt"
 
-#: fortran/resolve.c:4820
+#: fortran/resolve.c:4826
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr "Delsträngs startindex vid %L är mindre än ett"
 
-#: fortran/resolve.c:4833
+#: fortran/resolve.c:4839
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr "Slutindex för delsträng vid %L måste ha typen INTEGER"
 
-#: fortran/resolve.c:4840
+#: fortran/resolve.c:4846
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr "Slutsträng för delsträng vid %L måste vara skalärt"
 
-#: fortran/resolve.c:4850
+#: fortran/resolve.c:4856
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr "Slutindex för delsträng vid %L överstiger strängens längd"
 
-#: fortran/resolve.c:4860
+#: fortran/resolve.c:4866
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr "Slutindex för delsträng vid %L är för stort"
 
-#: fortran/resolve.c:5013
+#: fortran/resolve.c:5019
 #, gcc-internal-format
 msgid "resolve_ref(): Bad array reference"
 msgstr "resolve_ref(): Felaktig vektorreferens"
 
-#: fortran/resolve.c:5027
+#: fortran/resolve.c:5033
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr "Komponent till den högra av en delreferens med ordning skild från noll får inte ha attributet POINTER vid %L"
 
-#: fortran/resolve.c:5037
+#: fortran/resolve.c:5043
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr "Komponent till den högra av en delreferens med ordning skild från noll får inte ha attributet ALLOCATABLE vid %L"
 
-#: fortran/resolve.c:5056
+#: fortran/resolve.c:5062
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr "Två eller flera delreferenser med ordning skild från noll får inte anges vid %L"
 
-#: fortran/resolve.c:5154
+#: fortran/resolve.c:5160
 #, gcc-internal-format
 msgid "expression_rank(): Two array specs"
 msgstr "expression_rank(): Två vektorspecifikationer"
 
-#: fortran/resolve.c:5236
+#: fortran/resolve.c:5242
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr "Variabeln %s vid %L med attributet NO_ARG_CHECK får bara användas som ett aktuellt argument"
 
-#: fortran/resolve.c:5246
+#: fortran/resolve.c:5252
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr "Variabeln %s med antagen typ vid %L får bara användas som ett aktuellt argument"
@@ -58852,12 +58929,12 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5256
+#: fortran/resolve.c:5262
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr "Variabel med antagen typ %s vid %L som aktuellt argument till en frågefunktion skall vara det första argumentet"
 
-#: fortran/resolve.c:5271
+#: fortran/resolve.c:5277
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr "Variabeln %s med antagen ordning vid %L kan bara användas som ett aktuellt argument"
@@ -58866,268 +58943,268 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5281
+#: fortran/resolve.c:5287
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr "Variabel med antagen ordning %s vid %L som aktuellt argument till en frågefunktion skall vara det första argumentet"
 
-#: fortran/resolve.c:5292
+#: fortran/resolve.c:5298
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr "Variabeln %s vid %L med attributet NO_ARG_CHECK skall inte ha en subobjektreferens"
 
-#: fortran/resolve.c:5301
+#: fortran/resolve.c:5307
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr "Variabeln %s med antagen typ vid %L skall inte ha en subobjektreferens"
 
-#: fortran/resolve.c:5316
+#: fortran/resolve.c:5322
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr "Variabeln %s med antagen ordning vid %L skall inte ha en subobjektreferens"
 
-#: fortran/resolve.c:5478
+#: fortran/resolve.c:5484
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr "Variabel %qs, använd i ett specifikationsuttryck, refereras vid %L före ENTRY-satsen i vilken den är en parameter"
 
-#: fortran/resolve.c:5483
+#: fortran/resolve.c:5489
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr "Variabel %qs används vid %L före ENTRY-satsen i vilken den är en parameter"
 
-#: fortran/resolve.c:5553
+#: fortran/resolve.c:5559
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr "Polymorft subobjekt till co-indexerat objekt vid %L"
 
-#: fortran/resolve.c:5566
+#: fortran/resolve.c:5572
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr "Co-indexerat objekt med polymorf allokerbar delkomponent vid %L"
 
-#: fortran/resolve.c:5919
+#: fortran/resolve.c:5925
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "Skickat objekt vid %L måste vara skalär"
 
-#: fortran/resolve.c:5926
+#: fortran/resolve.c:5932
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr "Basobjekt för procedurpekarkomponentanrop vid %L är av ABSTRACT typ %qs"
 
-#: fortran/resolve.c:5961
+#: fortran/resolve.c:5967
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr "Basobjekt för typbundet proceduranrop vid %L är av ABSTRACT typ %qs"
 
-#: fortran/resolve.c:5970
+#: fortran/resolve.c:5976
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr "Basobjekt för typbundet NOPASS-proceduranrop vid %L måste vara skalärt"
 
 #. Nothing matching found!
-#: fortran/resolve.c:6158
+#: fortran/resolve.c:6164
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr "Hittade ingen matchande specifik bindning för anropet till GENERIC %qs vid %L"
 
-#: fortran/resolve.c:6185
+#: fortran/resolve.c:6191
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "%qs vid %L skulle vara en SUBROUTINE"
 
-#: fortran/resolve.c:6236
+#: fortran/resolve.c:6242
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr "%qs vid %L skulle vara en SUBROUTINE"
 
-#: fortran/resolve.c:6786
+#: fortran/resolve.c:6792
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "gfc_resolve_expr(): Felaktig uttryckstyp"
 
-#: fortran/resolve.c:6812
+#: fortran/resolve.c:6818
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s vid %L måste vara en skalär"
 
-#: fortran/resolve.c:6822
+#: fortran/resolve.c:6828
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "%s vid %L måste vara ett heltal"
 
-#: fortran/resolve.c:6826 fortran/resolve.c:6833
+#: fortran/resolve.c:6832 fortran/resolve.c:6839
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s vid %L måste vara INTEGER"
 
-#: fortran/resolve.c:6875
+#: fortran/resolve.c:6881
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "Steguttryck i DO-slinga vid %L får inte vara noll"
 
-#: fortran/resolve.c:6911
+#: fortran/resolve.c:6917
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr "DO-slinga vid %L kommer köras noll gånger"
 
-#: fortran/resolve.c:6928
+#: fortran/resolve.c:6934
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr "DO-slingan vid %L är odefinierad eftersom den spiller över"
 
-#: fortran/resolve.c:6934
+#: fortran/resolve.c:6940
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr "DO-slingan vid %L är odefinierad eftersom den spiller under"
 
-#: fortran/resolve.c:6995
+#: fortran/resolve.c:7001
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "FORALL-indexnamn vid %L måste vara en skalär INTEGER"
 
-#: fortran/resolve.c:7000
+#: fortran/resolve.c:7006
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "FORALL-slututtryck vid %L måste vara en skalär INTEGER"
 
-#: fortran/resolve.c:7007
+#: fortran/resolve.c:7013
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "FORALL-slututtryck vid %L måste vara en skalär INTEGER"
 
-#: fortran/resolve.c:7015
+#: fortran/resolve.c:7021
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "FORALL-steguttryck vid %L måste vara en skalär %s"
 
-#: fortran/resolve.c:7020
+#: fortran/resolve.c:7026
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "FORALL-steguttryck vid %L får inte vara noll"
 
-#: fortran/resolve.c:7033
+#: fortran/resolve.c:7039
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "FORALL-index %qs får inte förekomma i triplettspecifikation vid %L"
 
-#: fortran/resolve.c:7136 fortran/resolve.c:7428
+#: fortran/resolve.c:7142 fortran/resolve.c:7434
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "Allokeringsobjekt vid %L måste vara ALLOCATABLE eller en POINTER"
 
-#: fortran/resolve.c:7144 fortran/resolve.c:7393
+#: fortran/resolve.c:7150 fortran/resolve.c:7399
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr "Co-indexerat allokerbart objekt vid %L"
 
-#: fortran/resolve.c:7250
+#: fortran/resolve.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr "Källuttryck vid %L måste vara skalärt eller ha samma ordning som allokeringsobjektet vid %L"
 
-#: fortran/resolve.c:7281
+#: fortran/resolve.c:7287
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr "Källuttryck vid %L och allokeringsobjekt vid %L måste ha samma form"
 
-#: fortran/resolve.c:7439
+#: fortran/resolve.c:7445
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr "Typen på enheten vid %L är typinkompatibel med källuttrycket vid %L"
 
-#: fortran/resolve.c:7451
+#: fortran/resolve.c:7457
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr "Allokeringsobjektet vid %L och källuttrycket vid %L skall ha samma sorts typparameter"
 
-#: fortran/resolve.c:7465
+#: fortran/resolve.c:7471
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr "Källuttrycket vid %L skall varken vara av typen LOCK_TYPE eller ha en LOCK_TYPE-komponent om det allokerbara objektet vid %L är en co-vektor"
 
-#: fortran/resolve.c:7480
+#: fortran/resolve.c:7486
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr "Källuttrycket vid %L skall varken vara av typen EVENT_TYPE eller ha en EVENT_TYPE-komponent om det allokerbara objektet vid %L är en co-vektor"
 
-#: fortran/resolve.c:7493
+#: fortran/resolve.c:7499
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr "Allokering %s av ABSTRACT bastyp vid %L behöver en typspecifikation eller source-uttryck"
 
-#: fortran/resolve.c:7511
+#: fortran/resolve.c:7517
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr "Allokerar %s vid %L med typspecifikation kräver samma teckenlängdsparameter som i deklarationen"
 
-#: fortran/resolve.c:7592 fortran/resolve.c:7607
+#: fortran/resolve.c:7598 fortran/resolve.c:7613
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "Vektorspecifikation krävs i ALLOCATE-sats vid %L"
 
-#: fortran/resolve.c:7599
+#: fortran/resolve.c:7605
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "Vektorspecifikation eller vektorvärt SOURCE=-uttryck krävs i ALLOCATE-sats vid %L"
 
-#: fortran/resolve.c:7622
+#: fortran/resolve.c:7628
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "Co-vektorspecifikation krävs i ALLOCATE-sats vid %L"
 
-#: fortran/resolve.c:7649
+#: fortran/resolve.c:7655
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "Felaktig vektorspecifikation i ALLOCATE-sats vid %L"
 
-#: fortran/resolve.c:7668
+#: fortran/resolve.c:7674
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr "%qs får inte förekomma i vektorspecifikationen vid %L i samma ALLOCATE-sats där den själv allokeras"
 
-#: fortran/resolve.c:7683
+#: fortran/resolve.c:7689
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr "”*” förväntades i co-indexspecifikation i ALLOCATE-sats vid %L"
 
-#: fortran/resolve.c:7694
+#: fortran/resolve.c:7700
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "Felaktig co-vektorspecifikation i ALLOCATE-sats vid %L"
 
-#: fortran/resolve.c:7726
+#: fortran/resolve.c:7732
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "Statvariabel vid %L måste vara en INTEGER-variabel"
 
-#: fortran/resolve.c:7749
+#: fortran/resolve.c:7755
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "Statvariabel vid %L skall inte %s:as i samma %s-sats"
 
-#: fortran/resolve.c:7760
+#: fortran/resolve.c:7766
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr "ERRMSG vid %L är oanvändbart utan en STAT-tagg"
 
-#: fortran/resolve.c:7771
+#: fortran/resolve.c:7782
 #, gcc-internal-format, gfc-internal-format
-msgid "Errmsg-variable at %L must be a scalar CHARACTER variable"
-msgstr "Errmsg-variabeln vid %L måste vara en skalär CHARACTER-variabel"
+msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
+msgstr "ERRMSG-variabeln vid %L måste vara en skalär standard-CHARACTER-variabel"
 
-#: fortran/resolve.c:7794
+#: fortran/resolve.c:7805
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr "Errmsg-variabel vid %L skall inte %s:as i samma %s-sats"
 
-#: fortran/resolve.c:7824
+#: fortran/resolve.c:7835
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr "Allokeringsobjekt vid %L förekommer också vid %L"
 
-#: fortran/resolve.c:7830 fortran/resolve.c:7836
+#: fortran/resolve.c:7841 fortran/resolve.c:7847
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr "Allokeringsobjekt vid %L är underobjekt till objekt vid %L"
@@ -59136,232 +59213,232 @@
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8064
+#: fortran/resolve.c:8075
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "CASE-etikett vid %L överlappar med CASE-etikett vid %L"
 
-#: fortran/resolve.c:8115
+#: fortran/resolve.c:8126
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "uttryck i CASE-sats vid %L måste vara av typ %s"
 
-#: fortran/resolve.c:8126
+#: fortran/resolve.c:8137
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "Uttryck i CASE-sats vid %L måste ha sort %d"
 
-#: fortran/resolve.c:8139
+#: fortran/resolve.c:8150
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "Uttryck i CASE-sats vid %L måste vara skalärt"
 
-#: fortran/resolve.c:8185
+#: fortran/resolve.c:8196
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "Valuttryck i beräknad-GOTO-sats vid %L måste vara ett skalärt heltalsuttryck"
 
-#: fortran/resolve.c:8204
+#: fortran/resolve.c:8215
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "Argument till SELECT-sats vid %L kan inte vara %s"
 
-#: fortran/resolve.c:8214
+#: fortran/resolve.c:8225
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "Argumentet till SELECT-satsen vid %L måste vara ett skalärt uttryck"
 
-#: fortran/resolve.c:8232 fortran/resolve.c:8240
+#: fortran/resolve.c:8243 fortran/resolve.c:8251
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "Uttryck i CASE-sats vid %L ligger inte i intervallet %s"
 
-#: fortran/resolve.c:8302 fortran/resolve.c:8873
+#: fortran/resolve.c:8313 fortran/resolve.c:8884
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "DEFAULT CASE vid %L får inte följas av ett andra DEFAULT CASE vid %L"
 
-#: fortran/resolve.c:8328
+#: fortran/resolve.c:8339
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "Logiskt intervall CASE-sats vid %L är inte tillåtet"
 
-#: fortran/resolve.c:8340
+#: fortran/resolve.c:8351
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "Konstant logiskt värde i CASE-sats upprepas vid %L"
 
-#: fortran/resolve.c:8355
+#: fortran/resolve.c:8366
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "Intervallspecifikationen vid %L kan aldrig matchas"
 
-#: fortran/resolve.c:8458
+#: fortran/resolve.c:8469
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "Logiskt SELECT CASE-block vid %L har mer än två fall"
 
-#: fortran/resolve.c:8518
+#: fortran/resolve.c:8529
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr "Selektorn vid %L får inte vara NULL()"
 
-#: fortran/resolve.c:8523
+#: fortran/resolve.c:8534
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr "Selektorn vid %L har ingen typ"
 
-#: fortran/resolve.c:8545
+#: fortran/resolve.c:8556
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr "Associationsnamn %qs vid %L används som en vektor"
 
-#: fortran/resolve.c:8556
+#: fortran/resolve.c:8567
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr "CLASS-väljare vid %L behöver en temporär som inte är implementerad ännu"
 
-#: fortran/resolve.c:8763
+#: fortran/resolve.c:8774
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "Selektorer skall vara polymorfiska i SELECT TYPE-sats vid %L"
 
-#: fortran/resolve.c:8783 fortran/resolve.c:8795
+#: fortran/resolve.c:8794 fortran/resolve.c:8806
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr "Selektorn vid %L får inte vara co-indexerad"
 
-#: fortran/resolve.c:8824
+#: fortran/resolve.c:8835
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "TYPE IS vid %L överlappar med TYPE IS vid %L"
 
-#: fortran/resolve.c:8836
+#: fortran/resolve.c:8847
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr "Härledd typ %qs vid %L måste vara utökningsbar"
 
-#: fortran/resolve.c:8848
+#: fortran/resolve.c:8859
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "Härledd typ %qs vid %L måste vara en utökning av %qs"
 
-#: fortran/resolve.c:8851
+#: fortran/resolve.c:8862
 #, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "Oväntad inbyggd typ %qs vid %L"
 
-#: fortran/resolve.c:8861
+#: fortran/resolve.c:8872
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr "Typspecifikationen vid %L skall ange att varje längdtypparameter är antagen"
 
-#: fortran/resolve.c:9108
+#: fortran/resolve.c:9119
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr "Dubbelt CLASS IS-block i SELECT TYPE-sats vid %L"
 
-#: fortran/resolve.c:9204
+#: fortran/resolve.c:9215
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "Ogiltigt sammanhang för inbyggd NULL () vid %L"
 
-#: fortran/resolve.c:9257
+#: fortran/resolve.c:9268
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "DTIO %s-procedur vid %L måste vara rekursiv"
 
-#: fortran/resolve.c:9267
+#: fortran/resolve.c:9278
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr "Dataöverföringselementet vid %L kan inte vara polymorft om det inte behandlas av en definierad input/output-procedur"
 
-#: fortran/resolve.c:9280
+#: fortran/resolve.c:9291
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "Dataöverföringselementet vid %L kan inte ha POINTER-komponenter om det inte behandlas av en definierad input/output-procedur"
 
-#: fortran/resolve.c:9289
+#: fortran/resolve.c:9300
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "Dataöverföringselement vid %L får inte ha procedurpekarkomponenter"
 
-#: fortran/resolve.c:9296
+#: fortran/resolve.c:9307
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "Dataöverföringselementet vid %L kan inte ha ALLOCATABLE-komponenter om det inte behandlas av en definierad input/output-procedur"
 
-#: fortran/resolve.c:9307
+#: fortran/resolve.c:9318
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "Dataöverföringselement vid %L får inte ha PRIVATE-komponenter"
 
-#: fortran/resolve.c:9313
+#: fortran/resolve.c:9324
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr "Dataöverföringselementet vid %L kan inte ha PRIVATE-komponenter om det inte behandlas av en definierad input/output-procedur"
 
-#: fortran/resolve.c:9328
+#: fortran/resolve.c:9339
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "Dataöverföringselement vid %L får inte vara en full referens till en vektor med antagen storlek"
 
-#: fortran/resolve.c:9388
+#: fortran/resolve.c:9399
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "Låsvariabel vid %L måste vara en skalär av typen LOCK_TYPE"
 
-#: fortran/resolve.c:9398
+#: fortran/resolve.c:9409
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr "Händelsevariabeln vid %L måste vara en skalär av typen EVENT_TYPE"
 
-#: fortran/resolve.c:9402
+#: fortran/resolve.c:9413
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "Händelsevariabelargumentet vid %L måste vara en co-vektor eller co-indexerat"
 
-#: fortran/resolve.c:9405
+#: fortran/resolve.c:9416
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "Händelsevariabelargumentet vid %L måste vara en co-vektor men inte co-indexerat"
 
-#: fortran/resolve.c:9412 fortran/resolve.c:9533
+#: fortran/resolve.c:9423 fortran/resolve.c:9545
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "STAT=-argumentet vid %L måste vara en skalär INTEGER-variabel"
 
-#: fortran/resolve.c:9424 fortran/resolve.c:9540
+#: fortran/resolve.c:9435 fortran/resolve.c:9553
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "ERRMSG=-variabeln vid %L måste vara en skalär CHARACTER-variabel"
 
-#: fortran/resolve.c:9436
+#: fortran/resolve.c:9447
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "ACQUIRED_LOCK=-argumentet vid %L måste vara en skalär LOGICAL-variabel"
 
-#: fortran/resolve.c:9449
+#: fortran/resolve.c:9460
 #, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "UNTIL_COUNT=-argumentet vid %L måste vara ett skalärt INTEGER-uttryck"
 
-#: fortran/resolve.c:9510
+#: fortran/resolve.c:9521
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "Bildmängdsargument vid %L måste vara ett skalärt eller ordning-1-uttryck"
 
-#: fortran/resolve.c:9514 fortran/resolve.c:9524
+#: fortran/resolve.c:9525 fortran/resolve.c:9535
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "Bildmängdsargument vid %L måste vara mellan 1 och num_images()"
 
-#: fortran/resolve.c:9567
+#: fortran/resolve.c:9580
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "Sats vid %L är inte en giltig grenmålssats för grensatsen vid %L"
 
-#: fortran/resolve.c:9577
+#: fortran/resolve.c:9590
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr "Gren vid %L kan orsaka en oändlig slinga"
@@ -59368,12 +59445,12 @@
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:9594 fortran/resolve.c:9617
+#: fortran/resolve.c:9607 fortran/resolve.c:9630
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr "GOTO-sats vid %L lämnar CRITICAL-konstruktion för etikett vid %L"
 
-#: fortran/resolve.c:9598 fortran/resolve.c:9623
+#: fortran/resolve.c:9611 fortran/resolve.c:9636
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr "GOTO-sats vid %L lämnar DO CONCURRENT-konstruktion för etikett vid %L"
@@ -59381,107 +59458,107 @@
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:9638
+#: fortran/resolve.c:9651
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "Etiketten vid %L är inte i samma block som GOTO-satsen vid %L"
 
-#: fortran/resolve.c:9710
+#: fortran/resolve.c:9723
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "WHERE-mask vid %L har inkonsistent form"
 
-#: fortran/resolve.c:9726
+#: fortran/resolve.c:9739
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "WHERE-tilldelningsmål vid %L har inkonsistent form"
 
-#: fortran/resolve.c:9734 fortran/resolve.c:9821
+#: fortran/resolve.c:9747 fortran/resolve.c:9834
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr "Ej ELEMENTAL användardefinierad tilldelning i WHERE vid %L"
 
-#: fortran/resolve.c:9744 fortran/resolve.c:9831
+#: fortran/resolve.c:9757 fortran/resolve.c:9844
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "Ej stödd sats inuti WHERE vid %L"
 
-#: fortran/resolve.c:9775
+#: fortran/resolve.c:9788
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "Tilldelning till en FORALL-indexvariabel vid %L"
 
-#: fortran/resolve.c:9784
+#: fortran/resolve.c:9797
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "FORALL med index %qs används inte på vänster sida av en tilldelning vid %L och kan därför orsaka multipla tilldelningar till detta objekt"
 
-#: fortran/resolve.c:9949
+#: fortran/resolve.c:9962
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "FORALL-indexnamn vid %L måste vara en skalär variabel av heltalstyp"
 
-#: fortran/resolve.c:9959
+#: fortran/resolve.c:9972
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "En yttre FORALL-konstruktion har redan ett index med detta namn %L"
 
-#: fortran/resolve.c:10036
+#: fortran/resolve.c:10049
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "WHERE/ELSEWHERE-klausul vid %L kräver en LOGICAL-vektor"
 
-#: fortran/resolve.c:10138
+#: fortran/resolve.c:10151
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr "gfc_resolve_blocks(): Felaktig blocktyp"
 
-#: fortran/resolve.c:10251
+#: fortran/resolve.c:10264
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr "CHARACTER-uttryck kommer att huggas av i tilldelning (%ld/%ld) vid %L"
 
-#: fortran/resolve.c:10283
+#: fortran/resolve.c:10296
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "Co-indexerat uttryck vid %L är tilldelat till en härledd typvariabel med en POINTER-komponent i en PURE-procedur"
 
-#: fortran/resolve.c:10288
+#: fortran/resolve.c:10301
 #, gcc-internal-format, gfc-internal-format
 msgid "The impure variable at %L is assigned to a derived type variable with a POINTER component in a PURE procedure (12.6)"
 msgstr "Den orena variabeln vid %L är tilldelad till en härledd typvariabel med en POINTER-komponent i en PURE-procedur (12.6)"
 
-#: fortran/resolve.c:10298
+#: fortran/resolve.c:10311
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "Tilldelning till en co-indexerad variabel vid %L i en PURE-procedur"
 
-#: fortran/resolve.c:10330
+#: fortran/resolve.c:10343
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr "Tilldelning till en polymorf co-vektor vid %L är inte tillåtet"
 
-#: fortran/resolve.c:10334
+#: fortran/resolve.c:10347
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "Tilldelning till en allokerbar polymorf variabel vid %L"
 
-#: fortran/resolve.c:10339
+#: fortran/resolve.c:10352
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr "Tilldelning till en allokerbar polymorf variabel vid %L kräver %<-frealloc-lhs%>"
 
-#: fortran/resolve.c:10346
+#: fortran/resolve.c:10359
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr "Ej allokerbar variabel får inte vara polymorf i inbyggd tilldelning vid %L - kontrollera att det finns en matchande specifik subrutin för operatorn ”=”"
 
-#: fortran/resolve.c:10357
+#: fortran/resolve.c:10370
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr "Co-indexerad variabel får inte ha en allokerbar yttersta komponent i tilldelningen vid %L"
 
-#: fortran/resolve.c:10663
+#: fortran/resolve.c:10683
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr "ATT GÖRA: typbegränsad definierad tilldelning vid %L inte gjord för att multipla delvektorreferenser skulle uppträda i intermediära uttryck."
@@ -59488,67 +59565,67 @@
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:10905
+#: fortran/resolve.c:10925
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr "Procedurpekartilldelning vid %L"
 
-#: fortran/resolve.c:10917
+#: fortran/resolve.c:10937
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr "Funktionsresultatet på vänstersidan av tilldelningen vid %L måste ha attributet pointer."
 
-#: fortran/resolve.c:11157
+#: fortran/resolve.c:11177
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgstr "ASSIGNED GOTO-sats vid %L kräver en INTEGER-variabel"
 
-#: fortran/resolve.c:11160
+#: fortran/resolve.c:11180
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "Variabeln %qs har inte tilldelats någon måletikett vid %L"
 
-#: fortran/resolve.c:11171
+#: fortran/resolve.c:11191
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "Alternativ RETURN-sats vid %L kräver en SCALAR-INTEGER-returspecificerare"
 
-#: fortran/resolve.c:11233
+#: fortran/resolve.c:11253
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "ASSIGN-sats vid %L kräver en skalär standard-INTEGER-variabel"
 
-#: fortran/resolve.c:11278
+#: fortran/resolve.c:11298
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid NULL at %L"
 msgstr "Ogiltig NULL vid %L"
 
-#: fortran/resolve.c:11282
+#: fortran/resolve.c:11302
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr "Aritmetisk IF-sats vid %L kräver ett skalärt REAL- eller INTEGER-uttryck"
 
-#: fortran/resolve.c:11339
+#: fortran/resolve.c:11359
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr "gfc_resolve_code(): Inget uttryck i DO WHILE"
 
-#: fortran/resolve.c:11344
+#: fortran/resolve.c:11364
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "Avslutsvillkor i DO WHILE-slinga vid %L måste vara ett skalärt LOGICAL-uttryck"
 
-#: fortran/resolve.c:11428
+#: fortran/resolve.c:11448
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "FORALL-maskklausul vid %L kräver ett skalärt LOGICAL-uttryck"
 
-#: fortran/resolve.c:11507
+#: fortran/resolve.c:11527
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_resolve_code(): Felaktig satskod"
 
-#: fortran/resolve.c:11617
+#: fortran/resolve.c:11637
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "Variabeln %qs med bindningsetiketten %qs vid %L använder samma globala identifierare som en enhet vid %L"
@@ -59555,7 +59632,7 @@
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:11630
+#: fortran/resolve.c:11650
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr "Variabeln %qs från modulen %qs med bindningsetikett %qs vid %L använder samma globala identifierare som entiteten vid %L från modulen %qs"
@@ -59563,57 +59640,57 @@
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:11647
+#: fortran/resolve.c:11667
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "Proceduren %qs med bindningsetiketten %qs vid %L använder samma globala identifierare som entiteten vid %L"
 
-#: fortran/resolve.c:11732
+#: fortran/resolve.c:11752
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "Stränglängden vid %L är för stor"
 
-#: fortran/resolve.c:11961
+#: fortran/resolve.c:11981
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "Den allokerbara vektorn %qs vid %L måste ha en fördröjd form eller antagen ordning"
 
-#: fortran/resolve.c:11965
+#: fortran/resolve.c:11985
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "Skalärt objekt %qs vid %L får inte vara ALLOCATABLE"
 
-#: fortran/resolve.c:11973
+#: fortran/resolve.c:11993
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "Vektorpekaren %qs vid %L måste ha en fördröjd form eller antagen ordning"
 
-#: fortran/resolve.c:11983
+#: fortran/resolve.c:12003
 #, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "Vektor %qs vid %L kan inte ha en fördröjd form"
 
-#: fortran/resolve.c:11998
+#: fortran/resolve.c:12018
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr "Typen %qs på CLASS-variabeln %qs vid %L är inte utvidgningsbar"
 
-#: fortran/resolve.c:12010
+#: fortran/resolve.c:12030
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr "CLASS-variabel %qs vid %L måste vara en attrapp, allokerbar eller pekare"
 
-#: fortran/resolve.c:12041
+#: fortran/resolve.c:12061
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr "Typen %qs kan inte vara värdassocierad vid %L för att den blockeras av ett inkompatibelt objekt med samma namn deklarerat vid %L"
 
-#: fortran/resolve.c:12063
+#: fortran/resolve.c:12083
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr "Implicerad SAVE för modulvariabeln %qs vid %L, behövs på grund av standardinitieringar"
 
-#: fortran/resolve.c:12090
+#: fortran/resolve.c:12110
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr "Enheten %qs vid %L har en fördröjd typparameter och kräver antingen attributet POINTER eller ALLOCATABLE"
@@ -59620,887 +59697,892 @@
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12131
+#: fortran/resolve.c:12151
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "Modul- eller huvudprogramvektorn %qs vid %L måste ha konstant form"
 
-#: fortran/resolve.c:12150
+#: fortran/resolve.c:12170
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "Entitet med antagen teckenlängd vid %L måste vara ett attrappargument eller en PARAMETER"
 
-#: fortran/resolve.c:12171
+#: fortran/resolve.c:12191
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr "%qs vid %L måste ha konstant teckenlängd i detta sammanhang"
 
-#: fortran/resolve.c:12178
+#: fortran/resolve.c:12198
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "COMMON-variabeln %qs vid %L måste ha konstant teckenlängd"
 
-#: fortran/resolve.c:12225
+#: fortran/resolve.c:12245
 #, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "Allokerbar %qs vid %L kan inte ha en initierare"
 
-#: fortran/resolve.c:12228
+#: fortran/resolve.c:12248
 #, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr "Extern %qs vid %L kan inte ha en initierare"
 
-#: fortran/resolve.c:12232
+#: fortran/resolve.c:12252
 #, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "Attrapp-%qs vid %L kan inte ha en initierare"
 
-#: fortran/resolve.c:12235
+#: fortran/resolve.c:12255
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "Inbyggd %qs vid %L kan inte ha en initierare"
 
-#: fortran/resolve.c:12238
+#: fortran/resolve.c:12258
 #, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "Funktionsresultat %qs vid %L kan inte ha en initierare"
 
-#: fortran/resolve.c:12241
+#: fortran/resolve.c:12261
 #, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "Automatisk vektor %qs vid %L kan inte ha en initierare"
 
-#: fortran/resolve.c:12283
+#: fortran/resolve.c:12303
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L"
 msgstr "%s vid %L"
 
-#: fortran/resolve.c:12310
+#: fortran/resolve.c:12330
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "Teckenvärd satsfunktion %qs vid %L måste ha konstant längd"
 
-#: fortran/resolve.c:12332
+#: fortran/resolve.c:12352
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "%qs är av en PRIVATE-typ och kan inte vara ett attrappargument till %qs, som är PUBLIC vid %L"
 
-#: fortran/resolve.c:12354
+#: fortran/resolve.c:12374
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr "Proceduren %qs i PUBLIC-gränssnittet %qs vid %L tar attrappargument för %qs som är PRIVATE"
 
-#: fortran/resolve.c:12372
+#: fortran/resolve.c:12392
 #, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "Funktion %qs vid %L kan inte ha en initierare"
 
-#: fortran/resolve.c:12381
+#: fortran/resolve.c:12401
 #, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr "Externt objekt %qs vid %L kan inte ha en initierare"
 
-#: fortran/resolve.c:12389
+#: fortran/resolve.c:12409
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "ELEMENTAL-funktion %qs vid %L måste ha ett skalärt resultat"
 
-#: fortran/resolve.c:12399
+#: fortran/resolve.c:12419
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "Satsfunktionen %qs vid %L får inte ha attributet pointer eller allocatable"
 
-#: fortran/resolve.c:12418
+#: fortran/resolve.c:12438
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "CHARACTER(*)-funktion %qs vid %L kan inte ha vektorvärde"
 
-#: fortran/resolve.c:12422
+#: fortran/resolve.c:12442
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "CHARACTER(*)-funktion %qs vid %L kan inte ha pekarvärde"
 
-#: fortran/resolve.c:12426
+#: fortran/resolve.c:12446
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "CHARACTER(*)-funktion %qs vid %L kan inte vara pure"
 
-#: fortran/resolve.c:12430
+#: fortran/resolve.c:12450
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "CHARACTER(*)-funktion %qs vid %L kan inte vara rekursiv"
 
-#: fortran/resolve.c:12443
+#: fortran/resolve.c:12463
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "CHARACTER(*)-funktionen %qs vid %L"
 
-#: fortran/resolve.c:12452
+#: fortran/resolve.c:12472
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "Procedurpekaren %qs vid %L skall inte vara elementär"
 
-#: fortran/resolve.c:12458
+#: fortran/resolve.c:12478
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "Attrapprocedur %qs vid %L skall inte vara elementär"
 
-#: fortran/resolve.c:12470
+#: fortran/resolve.c:12490
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr "Funktionens resultatvariabel %qs vid %L för den elementära funktionen %qs skall inte ha ett attribut ALLOCATABLE eller POINTER"
 
-#: fortran/resolve.c:12527
+#: fortran/resolve.c:12547
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "PROCEDURE-attribut i konflikt med SAVE-attribut i %qs vid %L"
 
-#: fortran/resolve.c:12533
+#: fortran/resolve.c:12553
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "PROCEDURE-attribut i konflikt med INTENT-attribut i %qs vid %L"
 
-#: fortran/resolve.c:12539
+#: fortran/resolve.c:12559
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "PROCEDURE-attribut i konflikt med RESULT-attribut i %qs vid %L"
 
-#: fortran/resolve.c:12547
+#: fortran/resolve.c:12567
 #, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "EXTERNAL-attribut i konflikt med FUNCTION-attribut i %qs vid %L"
 
-#: fortran/resolve.c:12553
+#: fortran/resolve.c:12573
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr "Procedurpekarresultat %qs vid %L saknar pekarattributet"
 
-#: fortran/resolve.c:12596
+#: fortran/resolve.c:12616
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "ELEMENTAL-attribut stämmer inte mellan MODULE PROCEDURE vid %L och dess gränssnitt i %s"
 
-#: fortran/resolve.c:12604
+#: fortran/resolve.c:12624
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "PURE-attribut stämmer inte mellan MODULE PROCEDURE vid %L och dess gränssnitt i %s"
 
-#: fortran/resolve.c:12612
+#: fortran/resolve.c:12632
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "RECURSIVE-attribut stämmer inte mellan MODULE PROCEDURE vid %L och dess gränssnitt i %s"
 
-#: fortran/resolve.c:12621
+#: fortran/resolve.c:12641
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr "%s mellan MODULE PROCEDURE-deklarationen i MODULE %qs och deklarationen vid %L i (SUB)MODULE %qs"
 
-#: fortran/resolve.c:12705
+#: fortran/resolve.c:12725
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "FINAL-procedur %qs vid %L är inte en SUBROUTINE"
 
-#: fortran/resolve.c:12714
+#: fortran/resolve.c:12734
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "FINAL-procedur vid %L måste ha precis ett argument"
 
-#: fortran/resolve.c:12723
+#: fortran/resolve.c:12743
 #, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "Argument till FINAL-procedur vid %L måste ha typen %qs"
 
-#: fortran/resolve.c:12731
+#: fortran/resolve.c:12751
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "Argument till FINAL-procedur vid %L får inte vara en POINTER"
 
-#: fortran/resolve.c:12737
+#: fortran/resolve.c:12757
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "Argument till FINAL-procedur vid %L får inte vara ALLOCATABLE"
 
-#: fortran/resolve.c:12743
+#: fortran/resolve.c:12763
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "Argument till FINAL-procedur vid %L får inte vara OPTIONAL"
 
-#: fortran/resolve.c:12751
+#: fortran/resolve.c:12771
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "Argument till FINAL-procedur vid %L får inte vara INTENT(OUT)"
 
-#: fortran/resolve.c:12760
+#: fortran/resolve.c:12780
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "Ickeskalär FINAL-procedur vid %L skulle ha argument med antagen form"
 
-#: fortran/resolve.c:12782
+#: fortran/resolve.c:12802
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "FINAL-procedur %qs deklarerad vid %L har samma ordning (%d) som %qs"
 
-#: fortran/resolve.c:12819
+#: fortran/resolve.c:12839
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr "Endast vektor-FINAL-procedurer deklarerade för den härledda typen %qs definierade vid %L, föreslår även en skalär"
 
-#: fortran/resolve.c:12859
+#: fortran/resolve.c:12879
 #, gcc-internal-format
 msgid "%qs and %qs can't be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr "%qs och %qs kan inte blandad FUNCTION/SUBROUTINE för GENERIC %qs vid %L"
 
-#: fortran/resolve.c:12895
+#: fortran/resolve.c:12915
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr "%qs och %qs för GENERIC %qs vid %L är tvetydiga"
 
-#: fortran/resolve.c:12954
+#: fortran/resolve.c:12974
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr "Odefinierad specifik bindning %qs som mål för GENERIC %qs vid %L"
 
-#: fortran/resolve.c:12966
+#: fortran/resolve.c:12986
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr "GENERIC %qs vid %L måste ha som mål en specifik bindning, %qs är också GENERIC"
 
-#: fortran/resolve.c:12994
+#: fortran/resolve.c:13014
 #, gcc-internal-format
 msgid "GENERIC %qs at %L can't overwrite specific binding with the same name"
 msgstr "GENERIC %qs vid %L kan inte åsidosätta en specifik bindning med samma namn"
 
-#: fortran/resolve.c:13050
+#: fortran/resolve.c:13070
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L can't be NOPASS"
 msgstr "Typgränsoperator vid %L kan inte vara NOPASS"
 
-#: fortran/resolve.c:13242
+#: fortran/resolve.c:13262
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "%qs måste vara en modulprocedur eller en extern procedur med ett explicit gränssnitt vid %L"
 
-#: fortran/resolve.c:13284
+#: fortran/resolve.c:13304
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "Proceduren %qs med PASS(%s) vid %L har inget argument %qs"
 
-#: fortran/resolve.c:13298
+#: fortran/resolve.c:13318
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "Procedur %qs med PASS vid %L måste ha åtminstone ett argument"
 
-#: fortran/resolve.c:13312 fortran/resolve.c:13778
+#: fortran/resolve.c:13332 fortran/resolve.c:13798
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "Ickepolymorfa attrappargument för pass-objekt till %qs vid %L"
 
-#: fortran/resolve.c:13320
+#: fortran/resolve.c:13340
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "Argument %qs till %qs med PASS(%s) vid %L måste ha den härledda typen %qs"
 
-#: fortran/resolve.c:13329
+#: fortran/resolve.c:13349
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "Skickat objekt-attrappargument till %qs vid %L måste vara skalärt"
 
-#: fortran/resolve.c:13335
+#: fortran/resolve.c:13355
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "Skickat objekt-attrappargument till %qs vid %L får inte vara ALLOCATABLE"
 
-#: fortran/resolve.c:13341
+#: fortran/resolve.c:13361
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "Skickat objekt-attrappargument till %qs vid %L får inte vara POINTER"
 
-#: fortran/resolve.c:13370
+#: fortran/resolve.c:13390
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "Procedur %qs vid %L har samma namn som en komponent i %qs"
 
-#: fortran/resolve.c:13380
+#: fortran/resolve.c:13400
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "Proceduren %qs vid %L har samma namn som den ärvd komponent i %qs"
 
-#: fortran/resolve.c:13472
+#: fortran/resolve.c:13492
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr "Härledd typ %qs deklarerad vid %L måste vara ABSTRACT för att %qs är DEFERRED och inte åsidosatt"
 
-#: fortran/resolve.c:13574
+#: fortran/resolve.c:13594
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "Co-vektorkomponent %qs vid %L måste vara allokerbar med fördröjd form"
 
-#: fortran/resolve.c:13583
+#: fortran/resolve.c:13603
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "Komponenten %qs vid %L av TYPE(C_PTR) eller TYPE(C_FUNPTR) får inte vara en co-vektor"
 
-#: fortran/resolve.c:13593
+#: fortran/resolve.c:13613
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr "Komponenten %qs vid %L med co-vektorkomponent skall skalär som inte är en pekare eller allokerbar"
 
-#: fortran/resolve.c:13602
+#: fortran/resolve.c:13622
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr "Component %qs vid %L har attributet CONTIGUOUS men är inte en vektorpekare"
 
-#: fortran/resolve.c:13613
+#: fortran/resolve.c:13633
 #, gcc-internal-format
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "Komponenten %qs med typen BIND(C) vid %L måste ha längden ett"
 
-#: fortran/resolve.c:13711
+#: fortran/resolve.c:13731
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "Procedurpekarkomponent %qs med PASS(%s) vid %L har inget argument %qs"
 
-#: fortran/resolve.c:13725
+#: fortran/resolve.c:13745
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "Procedurpekarkomponent %qs med PASS vid %L måste ha åtminstone ett argument"
 
-#: fortran/resolve.c:13741
+#: fortran/resolve.c:13761
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "Argument %qs till %qs med PASS(%s) vid %L måste ha den härledda typen %qs"
 
-#: fortran/resolve.c:13751
+#: fortran/resolve.c:13771
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "Argument %qs till %qs med PASS(%s) vid %L måste vara skalärt"
 
-#: fortran/resolve.c:13760
+#: fortran/resolve.c:13780
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "Argumentet %qs till %qs med PASS(%s) vid %L får inte ha attributet POINTER"
 
-#: fortran/resolve.c:13769
+#: fortran/resolve.c:13789
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "Argumentet %qs till %qs med PASS(%s) vid %L får inte vara ALLOCATABLE"
 
-#: fortran/resolve.c:13811
+#: fortran/resolve.c:13831
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "Komponent %qs i %qs vid %L har samma namn som en ärvd typbunden procedur"
 
-#: fortran/resolve.c:13824
+#: fortran/resolve.c:13844
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "Teckenlängd på komponent %qs behöver vara ett konstant specifikationsuttryck vid %L"
 
-#: fortran/resolve.c:13835
+#: fortran/resolve.c:13855
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr "Teckenkomponent %qs av %qs vid %L med fördröjd längd måste vara en POINTER eller ALLOCATABLE"
 
-#: fortran/resolve.c:13868
+#: fortran/resolve.c:13888
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "komponenten %qs är en PRIVATE-typ och kan inte vara en komponent i %qs, som är PUBLIC vid %L"
 
-#: fortran/resolve.c:13876
+#: fortran/resolve.c:13896
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr "Polymorf komponent %s vid %L i SEQUENCE- eller BIND(C)-typ %s"
 
-#: fortran/resolve.c:13885
+#: fortran/resolve.c:13905
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "Komponent %s av SEQUENCE-typ deklarerad vid %L har inte attributet SEQUENCE"
 
-#: fortran/resolve.c:13903 fortran/resolve.c:13915
+#: fortran/resolve.c:13923 fortran/resolve.c:13935
 #, gcc-internal-format
 msgid "The pointer component %qs of %qs at %L is a type that has not been declared"
 msgstr "Pekarkomponenten %qs av %qs vid %L är en typen som inte har deklarerats"
 
-#: fortran/resolve.c:13989
+#: fortran/resolve.c:14009
 #, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "Initierare som står i konflikt i unionen vid %L och %L"
 
-#: fortran/resolve.c:14034
+#: fortran/resolve.c:14054
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr "Eftersom utvidgningen av %qs vid %L har en co-vektorkomponent, skall föräldratypen %qs också ha en"
 
-#: fortran/resolve.c:14047
+#: fortran/resolve.c:14067
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "Ej utvidgningsbar härledd typ %qs vid %L får inte vara ABSTRACT"
 
-#: fortran/resolve.c:14111
+#: fortran/resolve.c:14131
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr "Den parametriserade typen %qs har inte någon komponent som motsvarar parametern %qs vid %L"
 
-#: fortran/resolve.c:14144
+#: fortran/resolve.c:14164
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr "Det generiska namnet %qs på funktionen %qs vid %L är samma namn som den härledda typen vid %L"
 
-#: fortran/resolve.c:14216
+#: fortran/resolve.c:14236
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "Vektor %qs med antagen storlek i namnlistan %qs vid %L är inte tillåtet"
 
-#: fortran/resolve.c:14222
+#: fortran/resolve.c:14242
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "NAMELIST-vektorobjektet %qs med antagen form i namnlistan %qs vid %L"
 
-#: fortran/resolve.c:14228
+#: fortran/resolve.c:14248
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "NAMELIST-vektorobjektet %qs med icke-konstant form in namnlistan %qs vid %L"
 
-#: fortran/resolve.c:14236
+#: fortran/resolve.c:14256
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "NAMELIST-vektorobjektet %qs med icke-konstant längd i namnlistan %qs vid %L"
 
-#: fortran/resolve.c:14253
+#: fortran/resolve.c:14273
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "NAMELIST-objekt %qs deklarerades PRIVATE och kan inte vara medlem av PUBLIC-namnlista %qs vid %L"
 
-#: fortran/resolve.c:14275
+#: fortran/resolve.c:14295
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "NAMELIST-objekt %qs har användningsassociativa PRIVATE-komponenter och kan inte vara medlem av namnlistan %qs vid %L"
 
-#: fortran/resolve.c:14286
+#: fortran/resolve.c:14306
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "NAMELIST-objekt %qs har PRIVATE-komponenter och kan inte vara medlem av PUBLIC-namnlista %qs vid %L"
 
-#: fortran/resolve.c:14313
+#: fortran/resolve.c:14333
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "PROCEDURE-attribut i konflikt med NAMELIST-attribut i %qs vid %L"
 
-#: fortran/resolve.c:14337
+#: fortran/resolve.c:14357
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "Parametervektor %qs vid %L kan inte ha automatisk eller fördröjd form"
 
-#: fortran/resolve.c:14353
+#: fortran/resolve.c:14373
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "Implicit typad PARAMETER %qs vid %L matchar inte en senare IMPLICIT-typ"
 
-#: fortran/resolve.c:14364
+#: fortran/resolve.c:14384
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "Inkompatibel härledd typ i PARAMETER vid %L"
 
-#: fortran/resolve.c:14372
+#: fortran/resolve.c:14392
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "CLASS-variabeln %qs vid %L får inte ha attributet PARAMETER"
 
-#: fortran/resolve.c:14423
+#: fortran/resolve.c:14443
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr "Objektet %qs vid %L har en fördröjd LEN-parameter %qs och är varken allokerbar eller en pekare"
 
-#: fortran/resolve.c:14434
+#: fortran/resolve.c:14454
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr "AUTOMATIC-objektet %qs vid %L får inte ha attributet SAVE eller vara en variabel deklarerad i huvudprogrammet, en modul eller en submodul(F08/C513)"
 
-#: fortran/resolve.c:14441
+#: fortran/resolve.c:14461
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr "Objektet %qs vid %L med ASSUMED typparametrar måste vara en attrapp eller en SELECT TYPE-selektor(F08/4.2)"
 
-#: fortran/resolve.c:14480
+#: fortran/resolve.c:14500
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr "Ledsen, allocatable/pointer-komponenter i co-vektor av polymorf (CLASS)-typ vid %L stödjs inte"
 
-#: fortran/resolve.c:14544
+#: fortran/resolve.c:14564
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "Attributet PROTECTED står i konflikt med attributet EXTERNAL vid %L"
 
-#: fortran/resolve.c:14547
+#: fortran/resolve.c:14567
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "Attributet PROCEDURE står i konflikt med attributet PROTECTED vid %L"
 
-#: fortran/resolve.c:14643
+#: fortran/resolve.c:14663
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr "%qs vid %L har attributet CONTIGUOUS, men är inte en vektorpekare eller en vektor med antagen form eller antagen ordning"
 
-#: fortran/resolve.c:14664
+#: fortran/resolve.c:14684
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr "Felaktig specifikation för vektor med antagen storlek vid %L"
 
-#: fortran/resolve.c:14677
+#: fortran/resolve.c:14697
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "Vektor med antagen storlek vid %L måste vara ett attrappargument"
 
-#: fortran/resolve.c:14680
+#: fortran/resolve.c:14700
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "Vektor med antagen form vid %L måste vara ett attrappargument"
 
-#: fortran/resolve.c:14688
+#: fortran/resolve.c:14708
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "Vektor med antagen ordning vid %L måste vara ett attrappargument"
 
-#: fortran/resolve.c:14695
+#: fortran/resolve.c:14715
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr "Vektor med antagen ordning vid %L kan inte ha attributet VALUE eller CODIMENSION"
 
-#: fortran/resolve.c:14708
+#: fortran/resolve.c:14728
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "Symbol vid %L är inte en DUMMY-variabel"
 
-#: fortran/resolve.c:14714
+#: fortran/resolve.c:14734
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "%qs vid %L kan inte ha attributet VALUE eftersom det inte är ett attrappargument"
 
-#: fortran/resolve.c:14724
+#: fortran/resolve.c:14744
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "Teckenvärd attrappvariabel %qs vid %L med attributet VALUE måste ha konstant längd"
 
-#: fortran/resolve.c:14733
+#: fortran/resolve.c:14753
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "C-interoperativ teckenattrappvariabel %qs vid %L med attributet VALUE måste ha längd ett"
 
-#: fortran/resolve.c:14746 fortran/resolve.c:14923
+#: fortran/resolve.c:14766 fortran/resolve.c:14943
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "Den härledda typen %qs vid %L har typen %qs, som inte har definierats"
 
-#: fortran/resolve.c:14760
+#: fortran/resolve.c:14780
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr "Variabeln %s vid %L med attributet NO_ARG_CHECK skall vara ett attrappargument"
 
-#: fortran/resolve.c:14769
+#: fortran/resolve.c:14789
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr "Variabeln %s vid %L med attributet NO_ARG_CHECK skall ha typen TYPE(*) eller en numerisk inbyggd typ"
 
-#: fortran/resolve.c:14778
+#: fortran/resolve.c:14798
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Variabeln %s vid %L med attributet NO_ARG_CHECK får inte ha attributet ALLOCATABLE, CODIMENSION, POINTER eller VALUE"
 
-#: fortran/resolve.c:14786
+#: fortran/resolve.c:14806
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "Variabeln %s vid %L med attributet NO_ARG_CHECK får inte ha attributet INTENT(OUT)"
 
-#: fortran/resolve.c:14793
+#: fortran/resolve.c:14813
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr "Variabeln %s vid %L med attributet NO_ARG_CHECK skall antingen vara en skalär eller en vektor med förmodad storlek"
 
-#: fortran/resolve.c:14813
+#: fortran/resolve.c:14833
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "Den antagna typen på variabeln %s vid %L är bara tillåten för attrappvariabler"
 
-#: fortran/resolve.c:14820
+#: fortran/resolve.c:14840
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Variabeln ”%s” med antagen typ vid %L får inte ha attributet ALLOCATABLE, CODIMENSION, POINTER eller VALUE"
 
-#: fortran/resolve.c:14827
+#: fortran/resolve.c:14847
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "Variabeln ”%s” med antagen typ vid %L får inte ha attributet INTENT(OUT)"
 
-#: fortran/resolve.c:14834
+#: fortran/resolve.c:14854
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr "Variabeln %s med antagen typ vid %L får inte vara en vektor med explicit form"
 
-#: fortran/resolve.c:14860
+#: fortran/resolve.c:14880
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr "Variabel %qs vid %L kan inte vara BIND(C) eftersom den varken är ett COMMON-block eller deklarerad med räckvidd modulnivå"
 
-#: fortran/resolve.c:14870
+#: fortran/resolve.c:14890
 #, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "BIND(C)-variabeln %qs vid %L måste ha längden ett"
 
-#: fortran/resolve.c:14949
+#: fortran/resolve.c:14969
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "PUBLIC %s %qs vid %L har PRIVATE härledd typ %qs"
 
-#: fortran/resolve.c:14964
+#: fortran/resolve.c:14984
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr "Variabeln %s vid %L av typen LOCK_TYPE eller med en delkomponent av typen LOCK_TYPE måste vara en co-vektor"
 
-#: fortran/resolve.c:14977
+#: fortran/resolve.c:14997
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr "Variabeln %s vid %L av typen EVENT_TYPE eller med en delkomponent av typen EVENT_TYPE måste vara en co-vektor"
 
-#: fortran/resolve.c:14995
+#: fortran/resolve.c:15015
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "INTENT(OUT)-attrappargumentet %qs vid %L har ASSUMED SIZE och kan därför inte ha en standardinitierare"
 
-#: fortran/resolve.c:15007
+#: fortran/resolve.c:15027
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "Attrappargumentet %qs vid %L av LOCK_TYPE får inte vara INTENT(OUT)"
 
-#: fortran/resolve.c:15016
+#: fortran/resolve.c:15036
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "Attrappargumentet %qs vid %L av EVENT_TYPE får inte vara INTENT(OUT)"
 
-#: fortran/resolve.c:15028
+#: fortran/resolve.c:15048
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "Funktionsresultat %qs vid %L skall inte vara en co-vektor eller ha en co-vektorkomponent"
 
-#: fortran/resolve.c:15037
+#: fortran/resolve.c:15057
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "Variabeln %qs vid %L av TYPE(C_PTR) eller TYPE(C_FUNPTR) får inte vara en co-vektor"
 
-#: fortran/resolve.c:15049
+#: fortran/resolve.c:15069
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr "Variabeln %qs vid %L med co-vektorkomponent skall vara en skalär som inte är en pekare eller allokerbar och inte en co-vektor"
 
-#: fortran/resolve.c:15065
+#: fortran/resolve.c:15085
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr "Variabeln %qs vid %L är en co-vektor och är inte ALLOCATABLE, SAVE eller ett attrappargument"
 
-#: fortran/resolve.c:15073
+#: fortran/resolve.c:15093
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "Co-vektorvariabeln %qs vid %L skall inte ha co-dimensioner med fördröjd form"
 
-#: fortran/resolve.c:15080
+#: fortran/resolve.c:15100
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "Allokerbar co-vektorvariabel %qs vid %L måste ha en fördröjd form"
 
-#: fortran/resolve.c:15092
+#: fortran/resolve.c:15112
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "Variabeln %qs vid %L är INTENT(OUT) och kan alltså inte vara en allokerbara co-vektor eller har co-vektorkomponenter"
 
-#: fortran/resolve.c:15101
+#: fortran/resolve.c:15121
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "Co-attrappvariabeln %qs vid %L är inte tillåten i BIND(C)-proceduren %qs"
 
-#: fortran/resolve.c:15117
+#: fortran/resolve.c:15137
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "LOGICAL-attrappargumentet %qs vid %L med icke-C_Bool-sort i BIND(C)-proceduren %qs"
 
-#: fortran/resolve.c:15123
+#: fortran/resolve.c:15143
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "LOGICAL-resultatvariabeln %qs vid %L med icke-C_Bool-sort i BIND(C)-proceduren %qs"
 
-#: fortran/resolve.c:15148
+#: fortran/resolve.c:15168
 #, gcc-internal-format
 msgid "Namelist %qs can not be an argument to subroutine or function at %L"
 msgstr "Namnlistan %qs får inte vara ett argument till en subrutin eller funktion vid %L"
 
-#: fortran/resolve.c:15218
+#: fortran/resolve.c:15238
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "Trådprivat vid %L är inte SAVE:ad"
 
-#: fortran/resolve.c:15229
+#: fortran/resolve.c:15249
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr "!$OMP DECLARE TARGET-variabeln %qs vid %L är inte SAVE:ad"
 
-#: fortran/resolve.c:15333
+#: fortran/resolve.c:15353
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr "check_data_variable(): Felaktigt uttryck"
 
-#: fortran/resolve.c:15339
+#: fortran/resolve.c:15359
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "BLOCK DATA-element %qs vid %L måste vara i COMMON"
 
-#: fortran/resolve.c:15345
+#: fortran/resolve.c:15365
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "DATA-vektor %qs vid %L måste anges i en tidigare deklaration"
 
-#: fortran/resolve.c:15354
+#: fortran/resolve.c:15374
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "DATA-elementet %qs vid %L kan inte ha ett co-index"
 
-#: fortran/resolve.c:15368
+#: fortran/resolve.c:15388
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr "DATA-element %qs vid %L är en pekare och måste då vara en fullständig vektor"
 
-#: fortran/resolve.c:15414
+#: fortran/resolve.c:15434
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "Ickekonstant vektorsektion vid %L i DATA-sats."
 
-#: fortran/resolve.c:15427
+#: fortran/resolve.c:15447
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "DATA-sats vid %L har fler variabler än värden"
 
-#: fortran/resolve.c:15526
+#: fortran/resolve.c:15546
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr "början av implicerad do-slinga vid %L kan inte förenklas till ett konstant värde"
 
-#: fortran/resolve.c:15534
+#: fortran/resolve.c:15554
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr "slutet av implicerad do-slinga vid %L kan inte förenklas till ett konstant värde"
 
-#: fortran/resolve.c:15542
+#: fortran/resolve.c:15562
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr "steget i implicerad do-slinga vid %L kan inte förenklas till ett konstant värde"
 
-#: fortran/resolve.c:15667
+#: fortran/resolve.c:15687
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "DATA-sats vid %L har fler värden än variabler"
 
-#: fortran/resolve.c:15832
+#: fortran/resolve.c:15852
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "Etiketten %d vid %L är definierad men inte använd"
 
-#: fortran/resolve.c:15838
+#: fortran/resolve.c:15858
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "Etiketten %d vid %L är definierad men kan inte användas"
 
-#: fortran/resolve.c:15922
+#: fortran/resolve.c:15942
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "Härledd typvariabel %qs vid %L måste ha attributet SEQUENCE för att vara ett EQUIVALENCE-objekt"
 
-#: fortran/resolve.c:15931
+#: fortran/resolve.c:15951
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "Härledd typvariabel %qs vid %L kan inte ha ALLOCATABLE-komponenter för att vara ett EQUIVALENCE-objekt"
 
-#: fortran/resolve.c:15939
+#: fortran/resolve.c:15959
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "Härledd typvariabel %qs vid %L med standardinitiering kan inte vara i EQUIVALENCE med en variabel i COMMON"
 
-#: fortran/resolve.c:15955
+#: fortran/resolve.c:15975
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "Härledd typvariabel %qs vid %L med pekarkomponent(er) kan inte vara ett EQUIVALENCE-objekt"
 
-#: fortran/resolve.c:16058
+#: fortran/resolve.c:16078
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "Syntaxfel i EQUIVALENCE-sats vid %L"
 
-#: fortran/resolve.c:16073
+#: fortran/resolve.c:16093
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr "Antingen alla eller inget av objekten i EQUIVALENCE-mängden vid %L kan ha attributet PROTECTED"
 
-#: fortran/resolve.c:16098
+#: fortran/resolve.c:16118
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "COMMON-blockmedlem %qs vid %L kan inte vara ett EQUIVALENCE-objekt i den rena proceduren %qs"
 
-#: fortran/resolve.c:16107
+#: fortran/resolve.c:16127
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Namngiven konstant %qs vid %L kan inte vara ett EQUIVALENCE-objekt"
 
-#: fortran/resolve.c:16180
+#: fortran/resolve.c:16200
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "Vektor %qs vid %L med icke-konstanta gränser kan inte vara ett EQUIVALENCE-objekt"
 
-#: fortran/resolve.c:16191
+#: fortran/resolve.c:16211
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Postkomponent %qs vid %L kan inte vara ett EQUIVALENCE-objekt"
 
-#: fortran/resolve.c:16202
+#: fortran/resolve.c:16222
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "Delsträng vid %L har längden noll"
 
-#: fortran/resolve.c:16293
+#: fortran/resolve.c:16253
 #, gcc-internal-format
+msgid "Self reference in character length expression for %qs at %L"
+msgstr "Självreferens i uttrycket för teckenlängd för %qs vid %L"
+
+#: fortran/resolve.c:16320
+#, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "PUBLIC-funktionen %qs vid %L har PRIVATE typ %qs"
 
-#: fortran/resolve.c:16306
+#: fortran/resolve.c:16333
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "ENTRY %qs vid %L har ingen IMPLICIT-typ"
 
-#: fortran/resolve.c:16326
+#: fortran/resolve.c:16353
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "Användaroperatorprocedur %qs vid %L måste vara en FUNCTION"
 
-#: fortran/resolve.c:16336
+#: fortran/resolve.c:16363
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "Användaroperatorprocedur %qs vid %L får inte ha antagen teckenlängd"
 
-#: fortran/resolve.c:16344
+#: fortran/resolve.c:16371
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "Användaroperatorprocedur %qs vid %L måste ha åtminstone ett argument"
 
-#: fortran/resolve.c:16358
+#: fortran/resolve.c:16385
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "Första argumentet till operatorgränssnitt vid %L får inte vara frivilligt"
 
-#: fortran/resolve.c:16376
+#: fortran/resolve.c:16403
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "Andra argumentet till operatorgränssnitt vid %L får inte vara valfritt"
 
-#: fortran/resolve.c:16383
+#: fortran/resolve.c:16410
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "Operatorgränssnitt vid %L måste ha, högst, två argument"
 
-#: fortran/resolve.c:16461
+#: fortran/resolve.c:16488
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr "Innesluten procedur %qs vid %L i en PURE-procedur måste också vara PURE"
@@ -60826,19 +60908,12 @@
 msgid "simplify_min_max(): Bad type in arglist"
 msgstr "simplify_min_max(): Felaktig typ i argumentlistan"
 
-#. Result is processor-dependent.
-#: fortran/simplify.c:5472
-#, gcc-internal-format, gfc-internal-format
-msgid "Second argument MOD at %L is zero"
-msgstr "Andra argumentet till MOD vid %L är noll"
+#: fortran/simplify.c:5470 fortran/simplify.c:5478
+#, gcc-internal-format
+msgid "Argument %qs of MOD at %L shall not be zero"
+msgstr "Argument %qs till MOD vid %L får inte vara noll"
 
-#. Result is processor-dependent.
-#: fortran/simplify.c:5483
-#, gcc-internal-format, gfc-internal-format
-msgid "Second argument of MOD at %L is zero"
-msgstr "Andra argumentet till MOD vid %L är noll"
-
-#: fortran/simplify.c:5494
+#: fortran/simplify.c:5484
 #, gcc-internal-format
 msgid "gfc_simplify_mod(): Bad arguments"
 msgstr "gfc_simplify_mod(): Felaktiga argument"
@@ -60846,97 +60921,97 @@
 #. Result is processor-dependent. This processor just opts
 #. to not handle it at all.
 #. Result is processor-dependent.
-#: fortran/simplify.c:5520 fortran/simplify.c:5532
+#: fortran/simplify.c:5525 fortran/simplify.c:5537
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of MODULO at %L is zero"
 msgstr "Andra argumentet till MODULO vid %L är noll"
 
-#: fortran/simplify.c:5552
+#: fortran/simplify.c:5557
 #, gcc-internal-format
 msgid "gfc_simplify_modulo(): Bad arguments"
 msgstr "gfc_simplify_modulo(): felaktiga argument"
 
-#: fortran/simplify.c:5600
+#: fortran/simplify.c:5605
 #, gcc-internal-format, gfc-internal-format
 msgid "Result of NEAREST is NaN at %L"
 msgstr "Resultatet av NEAREST är NaN vid %L"
 
-#: fortran/simplify.c:6081
+#: fortran/simplify.c:6086
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative at %L"
 msgstr "Argument NCOPIES till inbyggd REPEAT är negativt vid %L"
 
-#: fortran/simplify.c:6137
+#: fortran/simplify.c:6142
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument NCOPIES of REPEAT intrinsic is too large at %L"
 msgstr "Argumentet NCOPIES till inbyggd REPEAT är för stort vid %L"
 
-#: fortran/simplify.c:6174
+#: fortran/simplify.c:6179
 #, gcc-internal-format, gfc-internal-format
 msgid "Evaluation of string longer than 2**28 at %L deferred to runtime, expect bugs"
 msgstr "Beräkningen av en sträng längre än 2**28 vid %L fördröjd till körtillfället, förvänta dig fel"
 
-#: fortran/simplify.c:6302
+#: fortran/simplify.c:6307
 #, gcc-internal-format, gfc-internal-format
 msgid "Reshaped array too large at %C"
 msgstr "Omformad vektor är för stor vid %C"
 
-#: fortran/simplify.c:6416
+#: fortran/simplify.c:6421
 #, gcc-internal-format, gfc-internal-format
 msgid "Result of SCALE overflows its kind at %L"
 msgstr "Resultat av SCALE spiller över sin sort vid %L"
 
-#: fortran/simplify.c:6995
+#: fortran/simplify.c:7000
 #, gcc-internal-format
 msgid "Bad type in gfc_simplify_sign"
 msgstr "Felaktig typ i gfc_simplify_sign"
 
-#: fortran/simplify.c:7024
+#: fortran/simplify.c:7029
 #, gcc-internal-format
 msgid "in gfc_simplify_sin(): Bad type"
 msgstr "i gfc_simplify_sin(): Felaktig typ"
 
-#: fortran/simplify.c:7151 fortran/simplify.c:7431
+#: fortran/simplify.c:7156 fortran/simplify.c:7436
 #, gcc-internal-format
 msgid "Failure getting length of a constant array."
 msgstr "Misslyckades att bestämma längden på en konstant vektor."
 
-#: fortran/simplify.c:7161
+#: fortran/simplify.c:7166
 #, gcc-internal-format
 msgid "The number of elements (%d) in the array constructor at %L requires an increase of the allowed %d upper limit.  See %<-fmax-array-constructor%> option."
 msgstr "Antalet element (%d) i vektorkonstrueraren vid %L kräver en ökning av den tillåtna övre gränsen %d.  Se flaggan %<-fmax-array-constructor%>"
 
-#: fortran/simplify.c:7227
+#: fortran/simplify.c:7232
 #, gcc-internal-format, gfc-internal-format
 msgid "Simplification of SPREAD at %C not yet implemented"
 msgstr "Förenkling av SPREAD vid %C är inte implementerat ännu"
 
-#: fortran/simplify.c:7251
+#: fortran/simplify.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SQRT at %L has a negative value"
 msgstr "Argument till SQRT vid %L har ett negativt värde"
 
-#: fortran/simplify.c:7267
+#: fortran/simplify.c:7272
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid argument of SQRT at %L"
 msgstr "ogiltigt argument till SQRT vid %L"
 
-#: fortran/simplify.c:7598
+#: fortran/simplify.c:7603
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY lower bound is %ld)"
 msgstr "Utanför gränserna i IMAGE_INDEX vid %L för dimension %d, SUB har %ld och COARRAY nedre gräns är %ld)"
 
-#: fortran/simplify.c:7621
+#: fortran/simplify.c:7626
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY upper bound is %ld)"
 msgstr "Utanför gränserna i IMAGE_INDEX vid %L för dimension %d, SUB har %ld och COARRAY övre gräns är %ld)"
 
-#: fortran/simplify.c:7993
+#: fortran/simplify.c:7998
 #, gcc-internal-format
 msgid "gfc_convert_constant(): Unexpected type"
 msgstr "gfc_convert_constant(): Oväntad typ"
 
-#: fortran/simplify.c:8078
+#: fortran/simplify.c:8083
 #, gcc-internal-format
 msgid "Character %qs in string at %L cannot be converted into character kind %d"
 msgstr "Tecknet %qs i sträng vid %L kan inte konverteras till tecken av sort %d"
@@ -61039,7 +61114,7 @@
 msgid "BIND(C) applied to %s %s at %L"
 msgstr "BIND(C) applicerat på %s %s vid %L"
 
-#: fortran/symbol.c:901 fortran/symbol.c:912 fortran/symbol.c:1762
+#: fortran/symbol.c:901 fortran/symbol.c:912 fortran/symbol.c:1776
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute conflicts with %s attribute at %L"
 msgstr "%s-attribut i konflikt med %s-attribut vid %L"
@@ -61114,17 +61189,22 @@
 msgid "Duplicate VOLATILE attribute specified at %L"
 msgstr "Dubblerat VOLATILE-attribut angivet vid %L"
 
-#: fortran/symbol.c:1367
+#: fortran/symbol.c:1360
 #, gcc-internal-format, gfc-internal-format
+msgid "VOLATILE attribute at %L cannot be specified in a PURE procedure"
+msgstr "Attributet VOLATILE vid %L kan inte anges i en PURE-procedur"
+
+#: fortran/symbol.c:1381
+#, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ASYNCHRONOUS attribute specified at %L"
 msgstr "Dubblerat ASYNCHRONOUS-attribut angivet vid %L"
 
-#: fortran/symbol.c:1758
+#: fortran/symbol.c:1772
 #, gcc-internal-format
 msgid "%s attribute of %qs conflicts with %s attribute at %L"
 msgstr "%s-attribut på %qs i konflikt med %s-attribut vid %L"
 
-#: fortran/symbol.c:1794
+#: fortran/symbol.c:1808
 #, gcc-internal-format, gfc-internal-format
 msgid ""
 "%s procedure at %L is already declared as %s procedure. \n"
@@ -61133,147 +61213,147 @@
 "%s-proceduren vid %L är redan deklarerad som en %s-procedur. \n"
 "F2008: En tilldelning av funktionspekare är tvetydig om det är dn första exekverbara satsen efter specifikationsblocket.  Lägg någon annan sorts exekverbar sats före den. FIXAMIG"
 
-#: fortran/symbol.c:1802
+#: fortran/symbol.c:1816
 #, gcc-internal-format, gfc-internal-format
 msgid "%s procedure at %L is already declared as %s procedure"
 msgstr "Proceduren ”%s” vid %L är redan deklarerad som %s-procedur"
 
-#: fortran/symbol.c:1837
+#: fortran/symbol.c:1851
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgstr "INTENT (%s) står i konflikt med INTENT(%s) vid %L"
 
-#: fortran/symbol.c:1861
+#: fortran/symbol.c:1875
 #, gcc-internal-format, gfc-internal-format
 msgid "ACCESS specification at %L was already specified"
 msgstr "ACCESS-specifikation vid %L var redan angiven"
 
-#: fortran/symbol.c:1878
+#: fortran/symbol.c:1892
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate BIND attribute specified at %L"
 msgstr "Dubblerat BIND-attribut angivna vid %L"
 
-#: fortran/symbol.c:1885
+#: fortran/symbol.c:1899
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) at %L"
 msgstr "BIND(C) vid %L"
 
-#: fortran/symbol.c:1901
+#: fortran/symbol.c:1915
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate EXTENDS attribute specified at %L"
 msgstr "Dubblerat EXTENDS-attribut angivet vid %L"
 
-#: fortran/symbol.c:1905
+#: fortran/symbol.c:1919
 #, gcc-internal-format, gfc-internal-format
 msgid "EXTENDS at %L"
 msgstr "EXTENDS vid %L"
 
-#: fortran/symbol.c:1931
+#: fortran/symbol.c:1945
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has an explicit interface"
 msgstr "Symbolen %qs vid %L har redan ett explicit gränssnitt"
 
-#: fortran/symbol.c:1938
+#: fortran/symbol.c:1952
 #, gcc-internal-format
 msgid "%qs at %L has attributes specified outside its INTERFACE body"
 msgstr "%qs vid %L har attribut angivna utanför dess INTERFACE-kropp"
 
-#: fortran/symbol.c:1976
+#: fortran/symbol.c:1990
 #, gcc-internal-format
 msgid "Symbol %qs at %L conflicts with symbol from module %qs, use-associated at %L"
 msgstr "Symbolen %qs vid %L står i konflikt med symbolen från modulen %qs, användningsassocierad vid %L"
 
-#: fortran/symbol.c:1980
+#: fortran/symbol.c:1994
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr "Symbolen %qs vid %L har redan grundtypen %s"
 
-#: fortran/symbol.c:1987
+#: fortran/symbol.c:2001
 #, gcc-internal-format
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr "Procedur %qs vid %L får inte ha grundtypen %s"
 
-#: fortran/symbol.c:1999
+#: fortran/symbol.c:2013
 #, gcc-internal-format
 msgid "Symbol %qs at %L cannot have a type"
 msgstr "Symbolen %qs vid %L kan inte ha en typ"
 
-#: fortran/symbol.c:2242
+#: fortran/symbol.c:2256
 #, gcc-internal-format
 msgid "Component %qs at %C already in the parent type at %L"
 msgstr "Komponenten %qs vid %C finns redan i föräldratypen vid %L"
 
-#: fortran/symbol.c:2327
+#: fortran/symbol.c:2341
 #, gcc-internal-format
 msgid "Symbol %qs at %C is ambiguous"
 msgstr "Symbolen %qs vid %C är tvetydig"
 
-#: fortran/symbol.c:2359
+#: fortran/symbol.c:2373
 #, gcc-internal-format
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr "Härledd typ %qs vid %C används före den är definierad"
 
-#: fortran/symbol.c:2508
+#: fortran/symbol.c:2522
 #, gcc-internal-format
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr "Komponent %qs vid %C är en PRIVATE-komponent i %qs"
 
-#: fortran/symbol.c:2529
+#: fortran/symbol.c:2543
 #, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure; did you mean %qs?"
 msgstr "%qs vid %C är inte en medlem av posten %qs; menade du %qs?"
 
-#: fortran/symbol.c:2533
+#: fortran/symbol.c:2547
 #, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr "%qs vid %C är inte en medlem av posten %qs"
 
-#: fortran/symbol.c:2697
+#: fortran/symbol.c:2711
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr "Dubblerad satsetikett %d vid %L och %L"
 
-#: fortran/symbol.c:2708
+#: fortran/symbol.c:2722
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr "Etikett %d vid %C är redan refererad som ett grenmål"
 
-#: fortran/symbol.c:2718
+#: fortran/symbol.c:2732
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr "Etiketten %d vid %C är redan refererad som en formatetikett"
 
-#: fortran/symbol.c:2724
+#: fortran/symbol.c:2738
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr "DO avslutningssats som inte är END DO eller CONTINUE med etikett %d vid %C"
 
-#: fortran/symbol.c:2766
+#: fortran/symbol.c:2780
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr "Etikett %d vid %C användes tidigare som en FORMAT-etikett"
 
-#: fortran/symbol.c:2775
+#: fortran/symbol.c:2789
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr "Etikett %d vid %C användes tidigare som ett grenmål"
 
-#: fortran/symbol.c:2781
+#: fortran/symbol.c:2795
 #, gcc-internal-format, gfc-internal-format
 msgid "Shared DO termination label %d at %C"
 msgstr "Delad DO-avslutningsetikett %d vid %C"
 
-#: fortran/symbol.c:3110
+#: fortran/symbol.c:3124
 #, gcc-internal-format
 msgid "new_symbol(): Symbol name too long"
 msgstr "new_symbol(): Symbolnamnet är för långt"
 
-#: fortran/symbol.c:3135
+#: fortran/symbol.c:3149
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr "Namnet %qs vid %C är en tvetydig referens till %qs från modulen %qs"
 
-#: fortran/symbol.c:3138
+#: fortran/symbol.c:3152
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
 msgstr "Namnet %qs vid %C är en tvetydig referens till %qs från den aktuella programenheten"
@@ -61280,62 +61360,62 @@
 
 # Vad är "host associated"?
 #. Symbol is from another namespace.
-#: fortran/symbol.c:3381
+#: fortran/symbol.c:3395
 #, gcc-internal-format
 msgid "Symbol %qs at %C has already been host associated"
 msgstr "Symbolen %qs vid %C har redan blivit host-associerad"
 
-#: fortran/symbol.c:4397
+#: fortran/symbol.c:4411
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr "verify_bind_c_derived_type(): Den angivna symbolen är oväntat NULL"
 
-#: fortran/symbol.c:4410
+#: fortran/symbol.c:4424
 #, gcc-internal-format
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr "Härledd typ %qs deklarerad vid %L måste ha attributet BIND för att vara ett C-interoperativ"
 
-#: fortran/symbol.c:4428
+#: fortran/symbol.c:4442
 #, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr "Härledd typ %qs med attributet BIND(C) vid %L är tom, och kan vara otillgängliga av C-följeslagarprocessorn"
 
-#: fortran/symbol.c:4449
+#: fortran/symbol.c:4463
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr "Komponent %qs vid %L får inte ha attributet POINTER eftersom det är en medlem av den BIND(C)-härledda typen %qs vid %L"
 
-#: fortran/symbol.c:4459
+#: fortran/symbol.c:4473
 #, gcc-internal-format
 msgid "Procedure pointer component %qs at %L cannot be a member of the BIND(C) derived type %qs at %L"
 msgstr "Procedurpekarkomponenten %qs vid %L kan inte vara en medlem av den BIND(C)-härledda typen %qs vid %L"
 
-#: fortran/symbol.c:4470
+#: fortran/symbol.c:4484
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr "Komponent %qs vid %L får inte ha attributet ALLOCATABLE eftersom det är en medlem av den BIND(C)-härledda typen %qs vid %L"
 
-#: fortran/symbol.c:4509
+#: fortran/symbol.c:4523
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr "Komponent %qs i härledd typ %qs vid %L får inte vara C-interoperativ, trots att den härledda typen %qs är BIND(C)"
 
-#: fortran/symbol.c:4519
+#: fortran/symbol.c:4533
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr "Komponent %qs i härledd typ %qs vid %L får inte vara C-interoperativ"
 
-#: fortran/symbol.c:4533
+#: fortran/symbol.c:4547
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot be declared with both PRIVATE and BIND(C) attributes"
 msgstr "Härledd typ %qs vid %L kan inte deklareras med både attributet PRIVATE och BIND(C)"
 
-#: fortran/symbol.c:4541
+#: fortran/symbol.c:4555
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr "Härledd typ %qs vid %L kan inte ha attributet SEQUENCE för att den är BIND(C)"
 
-#: fortran/symbol.c:5018 fortran/symbol.c:5023
+#: fortran/symbol.c:5032 fortran/symbol.c:5037
 #, gcc-internal-format
 msgid "Symbol %qs is used before it is typed at %L"
 msgstr "Symbolen %qs används före den har fått sin typ vid %L"
@@ -61382,7 +61462,7 @@
 msgid "Creating array temporary at %L for argument %qs"
 msgstr "Skapar vektortemporär vid %L för argument %qs"
 
-#: fortran/trans-array.c:10693
+#: fortran/trans-array.c:10724
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr "felaktig uttryckstyp under genomlöpning (%d)"
@@ -61584,12 +61664,12 @@
 msgid "%<dim%> argument of %s intrinsic at %L is not a valid dimension index"
 msgstr "%<dim%>-argumentet till inbyggd %s vid %L är inte ett giltigt dimensionsindex"
 
-#: fortran/trans-intrinsic.c:10572 fortran/trans-stmt.c:1050
+#: fortran/trans-intrinsic.c:10574 fortran/trans-stmt.c:1050
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, the event component of derived type at %L is not yet supported"
 msgstr "Ledsen, händelsekomponenten hos härledd typ vid %L stödjs inte ännu"
 
-#: fortran/trans-intrinsic.c:10579
+#: fortran/trans-intrinsic.c:10581
 #, gcc-internal-format, gfc-internal-format
 msgid "The event variable at %L shall not be coindexed"
 msgstr "Händelsevariabeln vid %L får inte vara co-indexerad"
@@ -61629,7 +61709,7 @@
 msgid "Sorry, only support for integer kind %d implemented for image-set at %L"
 msgstr "Tyvärr, endast stöd för heltalssort %d implementerad för bildmängden vid %L"
 
-#: fortran/trans-stmt.c:3346
+#: fortran/trans-stmt.c:3343
 #, gcc-internal-format
 msgid "gfc_trans_select(): Bad type for case expr."
 msgstr "gfc_trans_select(): Felaktig typ för Bad type for case-uttryck."
@@ -61755,7 +61835,7 @@
 msgid "two or more sections for %s"
 msgstr "två eller flera sektioner för %s"
 
-#: lto/lto-partition.c:516
+#: lto/lto-partition.c:570
 #, gcc-internal-format
 msgid "min partition size cannot be greater than max partition size"
 msgstr "min partitionsstorlek kan inte vara större än max partitionsstorlek"
@@ -61890,57 +61970,57 @@
 msgid "Cannot read %s"
 msgstr "Kan inte läsa %s"
 
-#: lto/lto.c:2369
+#: lto/lto.c:2337
 #, gcc-internal-format
 msgid "lto_obj_file_open() failed"
 msgstr "lto_obj_file_open() misslyckades"
 
-#: lto/lto.c:2394
+#: lto/lto.c:2362
 #, gcc-internal-format
 msgid "waitpid failed"
 msgstr "waitpid misslyckades"
 
-#: lto/lto.c:2397
+#: lto/lto.c:2365
 #, gcc-internal-format
 msgid "streaming subprocess failed"
 msgstr "strömmande underprocess misslyckades"
 
-#: lto/lto.c:2400
+#: lto/lto.c:2368
 #, gcc-internal-format
 msgid "streaming subprocess was killed by signal"
 msgstr "strömmande underprocess dödades av en signal"
 
-#: lto/lto.c:2476
+#: lto/lto.c:2445
 #, gcc-internal-format
 msgid "no LTRANS output list filename provided"
 msgstr "inget filnamn för LTRANS-utdatalista angivet"
 
-#: lto/lto.c:2564
+#: lto/lto.c:2525
 #, gcc-internal-format
 msgid "opening LTRANS output list %s: %m"
 msgstr "när LTRANS-utdatafil %s öppnades: %m"
 
-#: lto/lto.c:2570
+#: lto/lto.c:2532
 #, gcc-internal-format
 msgid "writing to LTRANS output list %s: %m"
 msgstr "när utdata skrevs till LTRANS-utdatalista %s: %m"
 
-#: lto/lto.c:2581
+#: lto/lto.c:2542
 #, gcc-internal-format
 msgid "closing LTRANS output list %s: %m"
 msgstr "när LTRANS-utdatalista %s stängdes: %m"
 
-#: lto/lto.c:2833
+#: lto/lto.c:2794
 #, gcc-internal-format
 msgid "could not open symbol resolution file: %m"
 msgstr "det gick inte att öppna symbolupplösningsfilen: %m"
 
-#: lto/lto.c:2954
+#: lto/lto.c:2915
 #, gcc-internal-format, gfc-internal-format
 msgid "missing resolution data for %s"
 msgstr "upplösningsdata saknas för %s"
 
-#: lto/lto.c:2986
+#: lto/lto.c:2947
 #, gcc-internal-format
 msgid "errors during merging of translation units"
 msgstr "fel vid sammanslagning av översättningsenheter"
Index: gcc/po/de.po
===================================================================
--- gcc/po/de.po	(.../tags/gcc_8_2_0_release)
+++ gcc/po/de.po	(.../branches/gcc-8-branch)
@@ -8,10 +8,10 @@
 # Roland Illig <roland.illig@gmx.de>, 2015, 2017-2018.
 msgid ""
 msgstr ""
-"Project-Id-Version: gcc 8.1.0\n"
+"Project-Id-Version: gcc 8.2.0\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2018-05-01 20:30+0000\n"
-"PO-Revision-Date: 2018-05-05 21:15+0200\n"
+"POT-Creation-Date: 2018-07-25 14:25+0000\n"
+"PO-Revision-Date: 2018-07-28 01:30+0200\n"
 "Last-Translator: Roland Illig <roland.illig@gmx.de>\n"
 "Language-Team: German <translation-team-de@lists.sourceforge.net>\n"
 "Language: de\n"
@@ -20,7 +20,7 @@
 "Content-Transfer-Encoding: 8bit\n"
 "X-Bugs: Report translation errors to the Language-Team address.\n"
 "Plural-Forms: nplurals=2; plural=(n != 1);\n"
-"X-Generator: Poedit 2.0.7\n"
+"X-Generator: Poedit 2.1.1\n"
 
 #: cfgrtl.c:2679
 msgid "flow control insn inside a basic block"
@@ -43,12 +43,12 @@
 msgid "[cannot find %s]"
 msgstr "[%s kann nicht gefunden werden]"
 
-#: collect2.c:1557
+#: collect2.c:1585
 #, c-format
 msgid "collect2 version %s\n"
 msgstr "collect2-Version %s\n"
 
-#: collect2.c:1664
+#: collect2.c:1692
 #, c-format
 msgid "%d constructor found\n"
 msgid_plural "%d constructors found\n"
@@ -55,7 +55,7 @@
 msgstr[0] "Einen Konstruktor gefunden\n"
 msgstr[1] "%d Konstruktoren gefunden\n"
 
-#: collect2.c:1668
+#: collect2.c:1696
 #, c-format
 msgid "%d destructor found\n"
 msgid_plural "%d destructors found\n"
@@ -62,7 +62,7 @@
 msgstr[0] "Einen Destruktor gefunden\n"
 msgstr[1] "%d Destruktoren gefunden\n"
 
-#: collect2.c:1672
+#: collect2.c:1700
 #, c-format
 msgid "%d frame table found\n"
 msgid_plural "%d frame tables found\n"
@@ -69,12 +69,12 @@
 msgstr[0] "Eine Rahmentabelle gefunden\n"
 msgstr[1] "%d Rahmentabellen gefunden\n"
 
-#: collect2.c:1836
+#: collect2.c:1864
 #, c-format
 msgid "[Leaving %s]\n"
 msgstr "[%s wird verlassen]\n"
 
-#: collect2.c:2068
+#: collect2.c:2094
 #, c-format
 msgid ""
 "\n"
@@ -83,7 +83,7 @@
 "\n"
 "write_c_file: Ausgabename ist %s, Präfix ist %s\n"
 
-#: collect2.c:2584
+#: collect2.c:2610
 #, c-format
 msgid ""
 "\n"
@@ -106,7 +106,7 @@
 msgid "%s: some warnings being treated as errors"
 msgstr "%s: Einige Warnungen werden als Fehler behandelt"
 
-#: diagnostic.c:324 input.c:222 input.c:1834 c-family/c-opts.c:1377
+#: diagnostic.c:324 input.c:222 input.c:1834 c-family/c-opts.c:1392
 #: fortran/cpp.c:576 fortran/error.c:1008 fortran/error.c:1028
 msgid "<built-in>"
 msgstr "<eingebaut>"
@@ -198,13 +198,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:4164 config/arc/arc.c:5784 config/i386/i386.c:17302
+#: final.c:4164 config/arc/arc.c:5775 config/i386/i386.c:17305
 #: config/pdp11/pdp11.c:1715
 #, c-format
 msgid "floating constant misused"
 msgstr "Gleitkommakonstante falsch verwendet"
 
-#: final.c:4222 config/arc/arc.c:5881 config/i386/i386.c:17393
+#: final.c:4222 config/arc/arc.c:5872 config/i386/i386.c:17396
 #: config/pdp11/pdp11.c:1756
 #, c-format
 msgid "invalid expression as operand"
@@ -1127,7 +1127,7 @@
 msgid "GCSE disabled"
 msgstr "GCSE ausgeschaltet"
 
-#: gimple-ssa-isolate-paths.c:542 c/c-typeck.c:10240
+#: gimple-ssa-isolate-paths.c:542 c/c-typeck.c:10245
 #, gcc-internal-format
 msgid "function returns address of local variable"
 msgstr "Funktion liefert Adresse einer lokalen Variablen zurück"
@@ -1427,7 +1427,7 @@
 msgid "options enabled: "
 msgstr "eingeschaltete Optionen: "
 
-#: tree-diagnostic.c:299 c/c-decl.c:5419 c/c-typeck.c:7259 cp/error.c:1042
+#: tree-diagnostic.c:299 c/c-decl.c:5439 c/c-typeck.c:7264 cp/error.c:1042
 #: c-family/c-pretty-print.c:413
 #, gcc-internal-format
 msgid "<anonymous>"
@@ -2881,64 +2881,64 @@
 msgstr "Längenmodifizierer im strfmon-Format"
 
 #. Handle deferred options from command-line.
-#: c-family/c-opts.c:1402 fortran/cpp.c:590
+#: c-family/c-opts.c:1417 fortran/cpp.c:590
 msgid "<command-line>"
 msgstr "<Kommandozeile>"
 
-#: config/aarch64/aarch64.c:6613
+#: config/aarch64/aarch64.c:6629
 #, c-format
 msgid "unsupported operand for code '%c'"
 msgstr "Operand für Code »%c« nicht unterstützt"
 
-#: config/aarch64/aarch64.c:6624 config/aarch64/aarch64.c:6640
-#: config/aarch64/aarch64.c:6652 config/aarch64/aarch64.c:6663
-#: config/aarch64/aarch64.c:6673 config/aarch64/aarch64.c:6694
-#: config/aarch64/aarch64.c:6764 config/aarch64/aarch64.c:6775
-#: config/aarch64/aarch64.c:6789 config/aarch64/aarch64.c:7011
-#: config/aarch64/aarch64.c:7029
+#: config/aarch64/aarch64.c:6640 config/aarch64/aarch64.c:6656
+#: config/aarch64/aarch64.c:6668 config/aarch64/aarch64.c:6679
+#: config/aarch64/aarch64.c:6689 config/aarch64/aarch64.c:6710
+#: config/aarch64/aarch64.c:6780 config/aarch64/aarch64.c:6791
+#: config/aarch64/aarch64.c:6805 config/aarch64/aarch64.c:7027
+#: config/aarch64/aarch64.c:7045
 #, c-format
 msgid "invalid operand for '%%%c'"
 msgstr "ungültiger Operand für »%%%c«"
 
-#: config/aarch64/aarch64.c:6709 config/aarch64/aarch64.c:6720
-#: config/aarch64/aarch64.c:6871 config/aarch64/aarch64.c:6882
+#: config/aarch64/aarch64.c:6725 config/aarch64/aarch64.c:6736
+#: config/aarch64/aarch64.c:6887 config/aarch64/aarch64.c:6898
 #, c-format
 msgid "invalid vector constant"
 msgstr "ungültige Vektorkonstante"
 
-#: config/aarch64/aarch64.c:6732 config/aarch64/aarch64.c:6744
-#: config/aarch64/aarch64.c:6755
+#: config/aarch64/aarch64.c:6748 config/aarch64/aarch64.c:6760
+#: config/aarch64/aarch64.c:6771
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr "unverträglicher Gleitkomma- / Vektorregisteroperand für »%%%c«"
 
-#: config/aarch64/aarch64.c:6823 config/arm/arm.c:22704
+#: config/aarch64/aarch64.c:6839 config/arm/arm.c:22704
 #, c-format
 msgid "missing operand"
 msgstr "fehlender Operand"
 
-#: config/aarch64/aarch64.c:6908
+#: config/aarch64/aarch64.c:6924
 #, c-format
 msgid "invalid constant"
 msgstr "ungültige Konstante"
 
-#: config/aarch64/aarch64.c:6911
+#: config/aarch64/aarch64.c:6927
 #, c-format
 msgid "invalid operand"
 msgstr "ungültiger Operand"
 
-#: config/aarch64/aarch64.c:7040 config/aarch64/aarch64.c:7045
+#: config/aarch64/aarch64.c:7056 config/aarch64/aarch64.c:7061
 #, c-format
 msgid "invalid operand prefix '%%%c'"
 msgstr "ungültiger Operandenpräfix »%%%c«"
 
-#: config/aarch64/aarch64.c:7062
+#: config/aarch64/aarch64.c:7078
 #, c-format
 msgid "invalid address mode"
 msgstr "ungültiger Adressierungsmodus"
 
-#: config/alpha/alpha.c:5125 config/i386/i386.c:18558
-#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21798
+#: config/alpha/alpha.c:5125 config/i386/i386.c:18561
+#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21875
 #: config/sparc/sparc.c:9290
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
@@ -2955,7 +2955,7 @@
 msgstr "ungültiger %%r-Wert"
 
 #: config/alpha/alpha.c:5223 config/ia64/ia64.c:5534
-#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21506
+#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21583
 #: config/xtensa/xtensa.c:2429
 #, c-format
 msgid "invalid %%R value"
@@ -2962,13 +2962,13 @@
 msgstr "ungültiger %%R-Wert"
 
 #: config/alpha/alpha.c:5229 config/powerpcspe/powerpcspe.c:23933
-#: config/rs6000/rs6000.c:21426 config/xtensa/xtensa.c:2396
+#: config/rs6000/rs6000.c:21503 config/xtensa/xtensa.c:2396
 #, c-format
 msgid "invalid %%N value"
 msgstr "ungültiger %%N-Wert"
 
 #: config/alpha/alpha.c:5237 config/powerpcspe/powerpcspe.c:23961
-#: config/rs6000/rs6000.c:21454
+#: config/rs6000/rs6000.c:21531
 #, c-format
 msgid "invalid %%P value"
 msgstr "ungültiger %%P-Wert"
@@ -2999,7 +2999,7 @@
 msgstr "ungültiger %%U-Wert"
 
 #: config/alpha/alpha.c:5323 config/powerpcspe/powerpcspe.c:24021
-#: config/rs6000/rs6000.c:21514
+#: config/rs6000/rs6000.c:21591
 #, c-format
 msgid "invalid %%s value"
 msgstr "ungültiger %%s-Wert"
@@ -3010,7 +3010,7 @@
 msgstr "ungültiger %%C-Wert"
 
 #: config/alpha/alpha.c:5371 config/powerpcspe/powerpcspe.c:23797
-#: config/rs6000/rs6000.c:21290
+#: config/rs6000/rs6000.c:21367
 #, c-format
 msgid "invalid %%E value"
 msgstr "ungültiger %%E-Wert"
@@ -3021,7 +3021,7 @@
 msgstr "Unbekanntes relocation unspec"
 
 #: config/alpha/alpha.c:5405 config/cr16/cr16.c:1569
-#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21803
+#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21880
 #: config/spu/spu.c:1458
 #, c-format
 msgid "invalid %%xn code"
@@ -3032,57 +3032,57 @@
 msgid "invalid operand address"
 msgstr "ungültige Operandenadresse"
 
-#: config/arc/arc.c:3810
+#: config/arc/arc.c:3808
 #, c-format
 msgid "invalid operand to %%Z code"
 msgstr "ungültiger Operand für Code %%Z"
 
-#: config/arc/arc.c:3818
+#: config/arc/arc.c:3816
 #, c-format
 msgid "invalid operand to %%z code"
 msgstr "ungültiger Operand für Code %%z"
 
-#: config/arc/arc.c:3826
+#: config/arc/arc.c:3824
 #, c-format
 msgid "invalid operands to %%c code"
 msgstr "ungültige Operanden für Code %%c"
 
-#: config/arc/arc.c:3834
+#: config/arc/arc.c:3832
 #, c-format
 msgid "invalid operand to %%M code"
 msgstr "ungültiger Operand für Code %%M"
 
-#: config/arc/arc.c:3842 config/m32r/m32r.c:2100
+#: config/arc/arc.c:3840 config/m32r/m32r.c:2100
 #, c-format
 msgid "invalid operand to %%p code"
 msgstr "ungültiger Operand für Code %%p"
 
-#: config/arc/arc.c:3853 config/m32r/m32r.c:2093
+#: config/arc/arc.c:3851 config/m32r/m32r.c:2093
 #, c-format
 msgid "invalid operand to %%s code"
 msgstr "ungültiger Operand für Code %%s"
 
-#: config/arc/arc.c:4001 config/m32r/m32r.c:2126
+#: config/arc/arc.c:3999 config/m32r/m32r.c:2126
 #, c-format
 msgid "invalid operand to %%R code"
 msgstr "ungültiger Operand für %%R-Code"
 
-#: config/arc/arc.c:4077 config/m32r/m32r.c:2149
+#: config/arc/arc.c:4075 config/m32r/m32r.c:2149
 #, c-format
 msgid "invalid operand to %%H/%%L code"
 msgstr "ungültiger Operand für %%H/%%L-Code"
 
-#: config/arc/arc.c:4145 config/m32r/m32r.c:2220
+#: config/arc/arc.c:4143 config/m32r/m32r.c:2220
 #, c-format
 msgid "invalid operand to %%U code"
 msgstr "ungültiger Operand für %%U-Code"
 
-#: config/arc/arc.c:4157
+#: config/arc/arc.c:4155
 #, c-format
 msgid "invalid operand to %%V code"
 msgstr "ungültiger Operand für %%V-Code"
 
-#: config/arc/arc.c:4214
+#: config/arc/arc.c:4212
 #, c-format
 msgid "invalid operand to %%O code"
 msgstr "ungültiger Operand für Code %%O"
@@ -3089,18 +3089,18 @@
 
 #. Unknown flag.
 #. Undocumented flag.
-#: config/arc/arc.c:4240 config/epiphany/epiphany.c:1305
-#: config/m32r/m32r.c:2247 config/nds32/nds32.c:3079 config/sparc/sparc.c:9569
+#: config/arc/arc.c:4238 config/epiphany/epiphany.c:1305
+#: config/m32r/m32r.c:2247 config/nds32/nds32.c:3080 config/sparc/sparc.c:9569
 #, c-format
 msgid "invalid operand output code"
 msgstr "ungültiger Operanden-Ausgabecode"
 
-#: config/arc/arc.c:5869
+#: config/arc/arc.c:5860
 #, c-format
 msgid "invalid UNSPEC as operand: %d"
 msgstr "ungültiges UNSPEC als Operand: %d"
 
-#: config/arc/arc.c:6158 config/cris/cris.c:2568
+#: config/arc/arc.c:6149 config/cris/cris.c:2568
 msgid "unrecognized supposed constant"
 msgstr "unerkannte vermutete Konstante"
 
@@ -3135,7 +3135,7 @@
 #: config/arm/arm.c:22685 config/arm/arm.c:22692 config/bfin/bfin.c:1441
 #: config/bfin/bfin.c:1448 config/bfin/bfin.c:1455 config/bfin/bfin.c:1462
 #: config/bfin/bfin.c:1471 config/bfin/bfin.c:1478 config/bfin/bfin.c:1485
-#: config/bfin/bfin.c:1492 config/nds32/nds32.c:3098
+#: config/bfin/bfin.c:1492 config/nds32/nds32.c:3099
 #, c-format
 msgid "invalid operand for code '%c'"
 msgstr "ungültiger Operand für Code »%c«"
@@ -3476,97 +3476,97 @@
 msgid "bad output_condmove_single operand"
 msgstr "Falscher Operand für output_condmove_single"
 
-#: config/i386/i386.c:17387
+#: config/i386/i386.c:17390
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "ungültiges UNSPEC als Operand"
 
-#: config/i386/i386.c:17925
+#: config/i386/i386.c:17928
 #, c-format
 msgid "invalid use of register '%s'"
 msgstr "Ungültige Verwendung von Register »%s«"
 
-#: config/i386/i386.c:17930
+#: config/i386/i386.c:17933
 #, c-format
 msgid "invalid use of asm flag output"
 msgstr "ungültige Verwendung der asm-Schalter-Ausgabe"
 
-#: config/i386/i386.c:18160
+#: config/i386/i386.c:18163
 #, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr "ungültige Operandengröße für Operandencode »O«"
 
-#: config/i386/i386.c:18195
+#: config/i386/i386.c:18198
 #, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr "ungültige Operandengröße für Operandencode »z«"
 
-#: config/i386/i386.c:18264
+#: config/i386/i386.c:18267
 #, c-format
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "ungültiger Operandentyp mit Operandencode »Z« verwendet"
 
-#: config/i386/i386.c:18269
+#: config/i386/i386.c:18272
 #, c-format
 msgid "invalid operand size for operand code 'Z'"
 msgstr "ungültige Operandengröße für Operandencode »Z«"
 
-#: config/i386/i386.c:18346
+#: config/i386/i386.c:18349
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "Operand ist kein Bedingungscode, ungültiger Operandencode »Y«"
 
-#: config/i386/i386.c:18425
+#: config/i386/i386.c:18428
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "Operand ist kein Bedingungscode, ungültiger Operandencode »D«"
 
-#: config/i386/i386.c:18443
+#: config/i386/i386.c:18446
 #, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "Operand ist kein Bedingungscode, ungültiger Operandencode »%c«"
 
-#: config/i386/i386.c:18456
+#: config/i386/i386.c:18459
 #, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "Operand ist keine ausgleichbare Speicherreferenz, ungültiger Operandencode »H«"
 
-#: config/i386/i386.c:18471
+#: config/i386/i386.c:18474
 #, c-format
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr "Operand ist keine Ganzzahl, ungültiger Operandencode »K«"
 
-#: config/i386/i386.c:18499
+#: config/i386/i386.c:18502
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr "Operand ist keine bestimmte Ganzzahl, ungültiger Operandencode »r«"
 
-#: config/i386/i386.c:18517
+#: config/i386/i386.c:18520
 #, c-format
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr "Operand ist keine Ganzzahl, ungültiger Operandencode »R«"
 
-#: config/i386/i386.c:18540
+#: config/i386/i386.c:18543
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "Operand ist keine bestimmte Ganzzahl, ungültiger Operandencode »R«"
 
-#: config/i386/i386.c:18626
+#: config/i386/i386.c:18629
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "ungültiger Operandencode »%c«"
 
-#: config/i386/i386.c:18688
+#: config/i386/i386.c:18691
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "ungültige Bedingungen für Operand"
 
-#: config/i386/i386.c:18738
+#: config/i386/i386.c:18741
 #, c-format
 msgid "invalid vector immediate"
 msgstr "ungültiger Vektordirektwert"
 
-#: config/i386/i386.c:29572
+#: config/i386/i386.c:29575
 msgid "unknown insn mode"
 msgstr "unbekannter Befehlsmodus"
 
@@ -3604,7 +3604,7 @@
 msgstr "ungültiger %%P-Operand"
 
 #: config/iq2000/iq2000.c:3185 config/powerpcspe/powerpcspe.c:23951
-#: config/rs6000/rs6000.c:21444
+#: config/rs6000/rs6000.c:21521
 #, c-format
 msgid "invalid %%p value"
 msgstr "ungültiger %%p-Wert"
@@ -3658,7 +3658,7 @@
 msgstr "Post-Increment-Adresse ist kein Register"
 
 #: config/m32r/m32r.c:2350 config/m32r/m32r.c:2365
-#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33292
+#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33348
 msgid "bad address"
 msgstr "Falsche Adresse"
 
@@ -3777,185 +3777,185 @@
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr "»%s« in der Shell könnte diese Beschränkung erhöhen.\n"
 
-#: config/powerpcspe/powerpcspe.c:4411 config/rs6000/rs6000.c:4258
+#: config/powerpcspe/powerpcspe.c:4411 config/rs6000/rs6000.c:4278
 msgid "-maltivec=le not allowed for big-endian targets"
 msgstr "-maltivec=le ist nicht für Big-Endian-Zielsysteme erlaubt"
 
-#: config/powerpcspe/powerpcspe.c:4423 config/rs6000/rs6000.c:4273
+#: config/powerpcspe/powerpcspe.c:4423 config/rs6000/rs6000.c:4293
 msgid "-mvsx requires hardware floating point"
 msgstr "-mvsx benötigt Hardware-Gleitkommabefehle"
 
-#: config/powerpcspe/powerpcspe.c:4431 config/rs6000/rs6000.c:4281
+#: config/powerpcspe/powerpcspe.c:4431 config/rs6000/rs6000.c:4301
 msgid "-mvsx and -mpaired are incompatible"
 msgstr "»-mvsx« und »-mpaired« sind unverträglich"
 
-#: config/powerpcspe/powerpcspe.c:4433 config/rs6000/rs6000.c:4283
+#: config/powerpcspe/powerpcspe.c:4433 config/rs6000/rs6000.c:4303
 msgid "-mvsx needs indexed addressing"
 msgstr "-mvsx benötigt indizierte Adressierung"
 
-#: config/powerpcspe/powerpcspe.c:4438 config/rs6000/rs6000.c:4288
+#: config/powerpcspe/powerpcspe.c:4438 config/rs6000/rs6000.c:4308
 msgid "-mvsx and -mno-altivec are incompatible"
 msgstr "»-mvsx« und »-mno-altivec« sind unverträglich"
 
-#: config/powerpcspe/powerpcspe.c:4440 config/rs6000/rs6000.c:4290
+#: config/powerpcspe/powerpcspe.c:4440 config/rs6000/rs6000.c:4310
 msgid "-mno-altivec disables vsx"
 msgstr "-mno-altivec schaltet vsx aus"
 
-#: config/powerpcspe/powerpcspe.c:4648 config/rs6000/rs6000.c:4416
+#: config/powerpcspe/powerpcspe.c:4648 config/rs6000/rs6000.c:4436
 msgid "-mquad-memory requires 64-bit mode"
 msgstr "-mquad-memory benötigt 64-Bit-Modus"
 
-#: config/powerpcspe/powerpcspe.c:4651 config/rs6000/rs6000.c:4419
+#: config/powerpcspe/powerpcspe.c:4651 config/rs6000/rs6000.c:4439
 msgid "-mquad-memory-atomic requires 64-bit mode"
 msgstr "-mquad-memory-atomic benötigt 64-Bit-Modus"
 
-#: config/powerpcspe/powerpcspe.c:4663 config/rs6000/rs6000.c:4431
+#: config/powerpcspe/powerpcspe.c:4663 config/rs6000/rs6000.c:4451
 msgid "-mquad-memory is not available in little endian mode"
 msgstr "-mquad-memory ist im Little-Endian-Modus nicht verfügbar"
 
-#: config/powerpcspe/powerpcspe.c:4735 config/rs6000/rs6000.c:4512
+#: config/powerpcspe/powerpcspe.c:4735 config/rs6000/rs6000.c:4532
 msgid "-mtoc-fusion requires 64-bit"
 msgstr "-mtoc-fusion benötigt 64-bit-Zielarchitektur"
 
-#: config/powerpcspe/powerpcspe.c:4742 config/rs6000/rs6000.c:4519
+#: config/powerpcspe/powerpcspe.c:4742 config/rs6000/rs6000.c:4539
 msgid "-mtoc-fusion requires medium/large code model"
 msgstr "»-mtoc-fusion« benötigt medium/large-Codemodell"
 
-#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10915
+#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10947
 msgid "bad move"
 msgstr "ungültige Bewegung"
 
-#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21087
+#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21164
 msgid "Bad 128-bit move"
 msgstr "Falsche 128-Bit-Verschiebung"
 
-#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21278
+#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21355
 #, c-format
 msgid "invalid %%e value"
 msgstr "ungültiger %%e-Wert"
 
-#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21299
+#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21376
 #, c-format
 msgid "invalid %%f value"
 msgstr "ungültiger %%f-Wert"
 
-#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21308
+#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21385
 #, c-format
 msgid "invalid %%F value"
 msgstr "ungültiger %%F-Wert"
 
-#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21317
+#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21394
 #, c-format
 msgid "invalid %%G value"
 msgstr "ungültiger %%G-Wert"
 
-#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21352
+#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21429
 #, c-format
 msgid "invalid %%j code"
 msgstr "ungültiger %%j-Code"
 
-#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21362
+#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21439
 #, c-format
 msgid "invalid %%J code"
 msgstr "ungültiger %%J-Code"
 
-#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21372
+#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21449
 #, c-format
 msgid "invalid %%k value"
 msgstr "ungültiger %%k-Wert"
 
-#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21387
+#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21464
 #: config/xtensa/xtensa.c:2415
 #, c-format
 msgid "invalid %%K value"
 msgstr "ungültiger %%K-Wert"
 
-#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21434
+#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21511
 #, c-format
 msgid "invalid %%O value"
 msgstr "ungültiger %%O-Wert"
 
-#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21481
+#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21558
 #, c-format
 msgid "invalid %%q value"
 msgstr "ungültiger %%q-Wert"
 
-#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21534
+#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21611
 #, c-format
 msgid "invalid %%T value"
 msgstr "ungültiger %%T-Wert"
 
-#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21546
+#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21623
 #, c-format
 msgid "invalid %%u value"
 msgstr "ungültiger %%u-Wert"
 
-#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21560
+#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21637
 #: config/xtensa/xtensa.c:2384
 #, c-format
 msgid "invalid %%v value"
 msgstr "ungültiger %%v-Wert"
 
-#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21627
+#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21704
 #: config/xtensa/xtensa.c:2436
 #, c-format
 msgid "invalid %%x value"
 msgstr "ungültiger %%x-Wert"
 
-#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21747
+#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21824
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "ungültiger %%y-Wert, bitte »Z«-Bedingung probieren"
 
-#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22282
+#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22359
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr "__float128 und __ibm128 können nicht im selben Ausdruck verwendet werden"
 
-#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22288
+#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22365
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr "__ibm128 und long double können nicht im gleichen Ausdruck verwendet werden"
 
-#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22294
+#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22371
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr "__float128 und long double können nicht im selben Ausdruck verwendet werden"
 
-#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36572
+#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36628
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "AltiVec-Argument an Funktion ohne Prototyp übergeben"
 
-#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38739
+#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38795
 msgid "Could not generate addis value for fusion"
 msgstr "addis-Wert für Fusion kann nicht erzeugt werden"
 
-#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38809
+#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38865
 msgid "Unable to generate load/store offset for fusion"
 msgstr "Lade-/Speicheroffset für Fusion kann nicht generiert werden"
 
-#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38908
+#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38964
 msgid "Bad GPR fusion"
 msgstr "Falsche GPR-Fusion"
 
-#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39126
+#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39182
 msgid "emit_fusion_p9_load, bad reg #1"
 msgstr "emit_fusion_p9_load, falsches Register #1"
 
-#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39172
+#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39228
 msgid "emit_fusion_p9_load, bad reg #2"
 msgstr "emit_fusion_p9_load, falsches Register #2"
 
-#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39175
+#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39231
 msgid "emit_fusion_p9_load not MEM"
 msgstr "emit_fusion_p9_load kein MEM"
 
-#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39213
+#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39269
 msgid "emit_fusion_p9_store, bad reg #1"
 msgstr "emit_fusion_p9_store, falsches Register #1"
 
-#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39259
+#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39315
 msgid "emit_fusion_p9_store, bad reg #2"
 msgstr "emit_fusion_p9_store, falsches Register #2"
 
-#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39262
+#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39318
 msgid "emit_fusion_p9_store not MEM"
 msgstr "emit_fusion_p9_store kein MEM"
 
@@ -4332,14 +4332,14 @@
 #: c/gimple-parser.c:188 c/gimple-parser.c:197 c/gimple-parser.c:226
 #: c/gimple-parser.c:1375 c/gimple-parser.c:1404 c/gimple-parser.c:1484
 #: c/gimple-parser.c:1511 c/c-parser.c:3204 c/c-parser.c:9967
-#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27841
-#: cp/parser.c:28430
+#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27838
+#: cp/parser.c:28427
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "%<;%> erwartet"
 
 #: c/c-parser.c:2431 c/c-parser.c:7573 c/c-parser.c:8015 c/c-parser.c:8058
-#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27839 cp/parser.c:28448
+#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27836 cp/parser.c:28445
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "%<,%> erwartet"
@@ -4354,7 +4354,7 @@
 #: c/gimple-parser.c:821 c/gimple-parser.c:837 c/gimple-parser.c:853
 #: c/gimple-parser.c:880 c/gimple-parser.c:915 c/gimple-parser.c:1038
 #: c/gimple-parser.c:1209 c/gimple-parser.c:1220 c/gimple-parser.c:1342
-#: c/gimple-parser.c:1441 cp/parser.c:28478
+#: c/gimple-parser.c:1441 cp/parser.c:28475
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "%<)%> erwartet"
@@ -4362,7 +4362,7 @@
 #: c/c-parser.c:3824 c/c-parser.c:4733 c/c-parser.c:4769 c/c-parser.c:6441
 #: c/c-parser.c:8125 c/c-parser.c:8983 c/c-parser.c:9127 c/c-parser.c:11588
 #: c/c-parser.c:18220 c/c-parser.c:18222 c/gimple-parser.c:1015
-#: cp/parser.c:28442
+#: cp/parser.c:28439
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "%<]%> erwartet"
@@ -4376,7 +4376,7 @@
 #: c/c-parser.c:17792 c/gimple-parser.c:363 c/gimple-parser.c:811
 #: c/gimple-parser.c:873 c/gimple-parser.c:911 c/gimple-parser.c:1198
 #: c/gimple-parser.c:1339 c/gimple-parser.c:1438 c/c-parser.c:11911
-#: cp/parser.c:28433
+#: cp/parser.c:28430
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "%<(%> erwartet"
@@ -4383,7 +4383,7 @@
 
 #: c/c-parser.c:4903 c/c-parser.c:10310 c/c-parser.c:16212 c/c-parser.c:18449
 #: c/gimple-parser.c:141 c/gimple-parser.c:1444 c/c-parser.c:3018
-#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18155 cp/parser.c:28439
+#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18152 cp/parser.c:28436
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "%<{%> erwartet"
@@ -4393,13 +4393,13 @@
 #: c/c-parser.c:12351 c/c-parser.c:12493 c/c-parser.c:12864 c/c-parser.c:12957
 #: c/c-parser.c:13566 c/c-parser.c:17636 c/c-parser.c:17695
 #: c/gimple-parser.c:431 c/gimple-parser.c:1492 c/gimple-parser.c:1519
-#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28472 cp/parser.c:29597
-#: cp/parser.c:32279
+#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28469 cp/parser.c:29594
+#: cp/parser.c:32276
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "%<:%> erwartet"
 
-#: c/c-parser.c:5974 cp/parser.c:28365
+#: c/c-parser.c:5974 cp/parser.c:28362
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "%<while%> erwartet"
@@ -4408,18 +4408,18 @@
 msgid "expected %<.%>"
 msgstr "%<.%> erwartet"
 
-#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30172
-#: cp/parser.c:30246
+#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30169
+#: cp/parser.c:30243
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "%<@end%> erwartet"
 
-#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28457
+#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28454
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "%<>%> erwartet"
 
-#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28481
+#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28478
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "%<,%> oder %<)%> erwartet"
@@ -4427,32 +4427,32 @@
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15190 c/c-parser.c:15234 c/c-parser.c:15466 c/c-parser.c:15701
 #: c/c-parser.c:17833 c/gimple-parser.c:286 c/c-parser.c:4792
-#: cp/parser.c:28460
+#: cp/parser.c:28457
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "%<=%> erwartet"
 
-#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28436
-#: cp/parser.c:30389
+#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28433
+#: cp/parser.c:30386
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "%<}%> erwartet"
 
-#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35674
+#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35671
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "%<#pragma omp section%> oder %<}%> erwartet"
 
-#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28445 cp/parser.c:31535
+#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28442 cp/parser.c:31532
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "%<[%> erwartet"
 
-#: c/c-typeck.c:7847
+#: c/c-typeck.c:7852
 msgid "(anonymous)"
 msgstr "(anonym)"
 
-#: c/gimple-parser.c:795 cp/parser.c:15791 cp/parser.c:28454
+#: c/gimple-parser.c:795 cp/parser.c:15788 cp/parser.c:28451
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "%<%> erwartet"
@@ -4706,11 +4706,11 @@
 msgid "%r%s:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr "%r%s:%d:%R   in %<constexpr%>-Ersetzung von %qs"
 
-#: cp/pt.c:1949 cp/semantics.c:5268
+#: cp/pt.c:1949 cp/semantics.c:5271
 msgid "candidates are:"
 msgstr "Kandidaten sind:"
 
-#: cp/pt.c:1951 cp/pt.c:22975
+#: cp/pt.c:1951 cp/pt.c:23053
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "Kandidat ist:"
@@ -4756,27 +4756,27 @@
 msgid "source type is not polymorphic"
 msgstr "Quellentyp ist nicht polymorph"
 
-#: cp/typeck.c:6083 c/c-typeck.c:4261
+#: cp/typeck.c:6083 c/c-typeck.c:4266
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "Argument falschen Typs für unäres Minus"
 
-#: cp/typeck.c:6084 c/c-typeck.c:4248
+#: cp/typeck.c:6084 c/c-typeck.c:4253
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "Argument falschen Typs für unäres Plus"
 
-#: cp/typeck.c:6111 c/c-typeck.c:4302
+#: cp/typeck.c:6111 c/c-typeck.c:4307
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "Argument falschen Typs für Bit-Komplement"
 
-#: cp/typeck.c:6128 c/c-typeck.c:4310
+#: cp/typeck.c:6128 c/c-typeck.c:4315
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "Argument falschen Typs für abs"
 
-#: cp/typeck.c:6140 c/c-typeck.c:4322
+#: cp/typeck.c:6140 c/c-typeck.c:4327
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "Argument falschen Typs für Konjugation"
@@ -5016,67 +5016,67 @@
 msgid "Expected attribute bit name"
 msgstr "Attributbitname erwartet"
 
-#: fortran/module.c:3223
+#: fortran/module.c:3225
 msgid "Expected integer string"
 msgstr "Ganzzahlzeichenkette erwartet"
 
-#: fortran/module.c:3227
+#: fortran/module.c:3229
 msgid "Error converting integer"
 msgstr "Fehler beim Umwandeln einer Ganzzahl"
 
-#: fortran/module.c:3249
+#: fortran/module.c:3251
 msgid "Expected real string"
 msgstr "Echte Zeichenkette erwartet"
 
-#: fortran/module.c:3474
+#: fortran/module.c:3476
 msgid "Expected expression type"
 msgstr "Ausdruckstyp erwartet"
 
-#: fortran/module.c:3554
+#: fortran/module.c:3556
 msgid "Bad operator"
 msgstr "Falscher Operator"
 
-#: fortran/module.c:3671
+#: fortran/module.c:3673
 msgid "Bad type in constant expression"
 msgstr "Falscher Typ in Konstanten-Ausdruck"
 
-#: fortran/module.c:7038
+#: fortran/module.c:7040
 msgid "Unexpected end of module"
 msgstr "Unerwartetes Modulende"
 
-#: fortran/parse.c:1757
+#: fortran/parse.c:1761
 msgid "arithmetic IF"
 msgstr "arithmetisches IF"
 
-#: fortran/parse.c:1766
+#: fortran/parse.c:1770
 msgid "attribute declaration"
 msgstr "Attribut-Deklaration"
 
-#: fortran/parse.c:1802
+#: fortran/parse.c:1806
 msgid "data declaration"
 msgstr "Daten-Deklaration"
 
-#: fortran/parse.c:1820
+#: fortran/parse.c:1824
 msgid "derived type declaration"
 msgstr "Deklaration eines abgeleiteten Typs"
 
-#: fortran/parse.c:1947
+#: fortran/parse.c:1951
 msgid "block IF"
 msgstr "Block-IF"
 
-#: fortran/parse.c:1956
+#: fortran/parse.c:1960
 msgid "implied END DO"
 msgstr "impliziertes END DO"
 
-#: fortran/parse.c:2050 fortran/resolve.c:11199
+#: fortran/parse.c:2054 fortran/resolve.c:11219
 msgid "assignment"
 msgstr "Zuweisung"
 
-#: fortran/parse.c:2053 fortran/resolve.c:11250 fortran/resolve.c:11253
+#: fortran/parse.c:2057 fortran/resolve.c:11270 fortran/resolve.c:11273
 msgid "pointer assignment"
 msgstr "Zeigerzuweisung"
 
-#: fortran/parse.c:2071
+#: fortran/parse.c:2075
 msgid "simple IF"
 msgstr "einfaches IF"
 
@@ -5168,106 +5168,111 @@
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr "Operand des unären numerischen Operators %%<%s%%> bei %%L ist %s"
 
-#: fortran/resolve.c:3878
+#: fortran/resolve.c:3879
 #, c-format
+msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
+msgstr "Unerwartete Entitäten mit abgeleitetem Typ im binären intrinsischen numerischen Operator %%<%s%%> bei %%L"
+
+#: fortran/resolve.c:3884
+#, c-format
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr "Operanden des binären numerischen Operators %%<%s%%> bei %%L sind %s/%s"
 
-#: fortran/resolve.c:3893
+#: fortran/resolve.c:3899
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr "Operanden des Zeichenkettenverkettungsoperators bei %%L sind %s/%s"
 
-#: fortran/resolve.c:3926
+#: fortran/resolve.c:3932
 #, c-format
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr "Operanden des logischen Operators %%<%s%%> bei %%L sind %s/%s"
 
-#: fortran/resolve.c:3949
+#: fortran/resolve.c:3955
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr "Operand des Operators .not. bei %%L ist %s"
 
-#: fortran/resolve.c:3963
+#: fortran/resolve.c:3969
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "COMPLEX-Größen können nicht bei %L verglichen werden"
 
-#: fortran/resolve.c:4015
+#: fortran/resolve.c:4021
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr "Logische Werte bei %%L müssen mit %s statt mit %s verglichen werden"
 
-#: fortran/resolve.c:4021
+#: fortran/resolve.c:4027
 #, c-format
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr "Operanden des Vergleichsoperators %%<%s%%> bei %%L sind %s/%s"
 
-#: fortran/resolve.c:4034
+#: fortran/resolve.c:4040
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L; did you mean '%s'?"
 msgstr "Unbekannter Operator %%<%s%%> bei %%L; meinten Sie »%s«?"
 
-#: fortran/resolve.c:4037
+#: fortran/resolve.c:4043
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr "Unbekannter Operator %%<%s%%> bei %%L"
 
-#: fortran/resolve.c:4040
+#: fortran/resolve.c:4046
 #, c-format
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr "Operand des Benutzeroperators %%<%s%%> bei %%L ist %s"
 
-#: fortran/resolve.c:4044
+#: fortran/resolve.c:4050
 #, c-format
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr "Operanden des Benutzeroperators %%<%s%%> bei %%L sind %s/%s"
 
-#: fortran/resolve.c:4132
+#: fortran/resolve.c:4138
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "Ränge für Operator bei %%L und %%L stimmen nicht überein"
 
-#: fortran/resolve.c:6849
+#: fortran/resolve.c:6855
 msgid "Loop variable"
 msgstr "Schleifenvariable"
 
-#: fortran/resolve.c:6853
+#: fortran/resolve.c:6859
 msgid "iterator variable"
 msgstr "Iteratorvariable"
 
-#: fortran/resolve.c:6857
+#: fortran/resolve.c:6863
 msgid "Start expression in DO loop"
 msgstr "Anfangs-Ausdruck in DO-Schleife"
 
-#: fortran/resolve.c:6861
+#: fortran/resolve.c:6867
 msgid "End expression in DO loop"
 msgstr "End-Ausdruck in DO-Schleife"
 
-#: fortran/resolve.c:6865
+#: fortran/resolve.c:6871
 msgid "Step expression in DO loop"
 msgstr "Schrittausdruck in DO-Schleife"
 
-#: fortran/resolve.c:7150 fortran/resolve.c:7153
+#: fortran/resolve.c:7156 fortran/resolve.c:7159
 msgid "DEALLOCATE object"
 msgstr "DEALLOCATE Objekt"
 
-#: fortran/resolve.c:7525 fortran/resolve.c:7528
+#: fortran/resolve.c:7531 fortran/resolve.c:7534
 msgid "ALLOCATE object"
 msgstr "ALLOCATE Objekt"
 
-#: fortran/resolve.c:7720 fortran/resolve.c:9417
+#: fortran/resolve.c:7726 fortran/resolve.c:9428
 msgid "STAT variable"
 msgstr "STAT-Variable"
 
-#: fortran/resolve.c:7764 fortran/resolve.c:9429
+#: fortran/resolve.c:7770 fortran/resolve.c:9440
 msgid "ERRMSG variable"
 msgstr "ERRMSG-Variable"
 
-#: fortran/resolve.c:9219
+#: fortran/resolve.c:9230
 msgid "item in READ"
 msgstr "Element in READ"
 
-#: fortran/resolve.c:9441
+#: fortran/resolve.c:9452
 msgid "ACQUIRED_LOCK variable"
 msgstr "Variable ACQUIRED_LOCK"
 
@@ -5300,7 +5305,7 @@
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr "Ziel für neue Rangabbildung ist zu klein (%ld < %ld)"
 
-#: fortran/trans-expr.c:10154
+#: fortran/trans-expr.c:10157
 msgid "Assignment of scalar to unallocated array"
 msgstr "Zuweisung von Skalar zu unalloziertem Array"
 
@@ -5309,12 +5314,12 @@
 msgid "Unequal character lengths (%ld/%ld) in %s"
 msgstr "Ungleiche Zeichenlängen (%ld/%ld) in %s"
 
-#: fortran/trans-intrinsic.c:8088
+#: fortran/trans-intrinsic.c:8090
 #, c-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative (its value is %ld)"
 msgstr "Argument NCOPIES des intrinsischen REPEAT ist negativ (sein Wert ist %ld)"
 
-#: fortran/trans-intrinsic.c:8120
+#: fortran/trans-intrinsic.c:8122
 msgid "Argument NCOPIES of REPEAT intrinsic is too large"
 msgstr "Argument NCOPIES des intrinsischen REPEAT ist zu groß"
 
@@ -5335,15 +5340,15 @@
 msgid "Invalid image number %d in SYNC IMAGES"
 msgstr "Ungültige Bildanzahl %d in SYNC IMAGES"
 
-#: fortran/trans-stmt.c:2180
+#: fortran/trans-stmt.c:2177
 msgid "Loop iterates infinitely"
 msgstr "Schleife läuft endlos"
 
-#: fortran/trans-stmt.c:2200 fortran/trans-stmt.c:2456
+#: fortran/trans-stmt.c:2197 fortran/trans-stmt.c:2453
 msgid "Loop variable has been modified"
 msgstr "Schleifenvariable wurde geändert"
 
-#: fortran/trans-stmt.c:2309
+#: fortran/trans-stmt.c:2306
 msgid "DO step value is zero"
 msgstr "DO-Schrittwert ist Null"
 
@@ -5916,10 +5921,10 @@
 msgid "Allow dollar signs in entity names."
 msgstr "Dollarzeichen in Entitätsnamen erlauben."
 
-#: fortran/lang.opt:485 config/alpha/alpha.opt:31 common.opt:783
-#: common.opt:985 common.opt:989 common.opt:993 common.opt:997 common.opt:1532
-#: common.opt:1588 common.opt:1712 common.opt:1716 common.opt:1946
-#: common.opt:2116 common.opt:2792
+#: fortran/lang.opt:485 config/alpha/alpha.opt:31 common.opt:649
+#: common.opt:783 common.opt:989 common.opt:993 common.opt:997 common.opt:1001
+#: common.opt:1536 common.opt:1592 common.opt:1716 common.opt:1720
+#: common.opt:1950 common.opt:2120 common.opt:2796
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr "Tut nichts. Für Rückwärtskompatibilität erhalten."
 
@@ -6138,12 +6143,12 @@
 msgstr "Unterstriche an extern sichtbare Namen anhängen."
 
 #: fortran/lang.opt:751 c-family/c.opt:1356 c-family/c.opt:1384
-#: c-family/c.opt:1634 config/pa/pa.opt:42 config/pa/pa.opt:70 common.opt:1154
-#: common.opt:1333 common.opt:1408 common.opt:1676 common.opt:1799
-#: common.opt:2169 common.opt:2205 common.opt:2298 common.opt:2302
-#: common.opt:2407 common.opt:2498 common.opt:2506 common.opt:2514
-#: common.opt:2522 common.opt:2623 common.opt:2675 common.opt:2755
-#: common.opt:2893 common.opt:2897 common.opt:2901 common.opt:2905
+#: c-family/c.opt:1634 config/pa/pa.opt:42 config/pa/pa.opt:70 common.opt:1158
+#: common.opt:1337 common.opt:1412 common.opt:1680 common.opt:1803
+#: common.opt:2173 common.opt:2209 common.opt:2302 common.opt:2306
+#: common.opt:2411 common.opt:2502 common.opt:2510 common.opt:2518
+#: common.opt:2526 common.opt:2627 common.opt:2679 common.opt:2759
+#: common.opt:2897 common.opt:2901 common.opt:2905 common.opt:2909
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr "Tut nichts. Für Rückwärtskompatibilität erhalten."
 
@@ -6193,7 +6198,7 @@
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:220 c-family/c.opt:224
 #: c-family/c.opt:236 c-family/c.opt:1855 c-family/c.opt:1863 brig/lang.opt:39
-#: config/darwin.opt:56 common.opt:338 common.opt:341 common.opt:3046
+#: config/darwin.opt:56 common.opt:338 common.opt:341 common.opt:3050
 #, c-format
 msgid "missing filename after %qs"
 msgstr "fehlender Dateiname hinter %qs"
@@ -6769,7 +6774,7 @@
 #: c-family/c.opt:1525 c-family/c.opt:1528 c-family/c.opt:1569
 #: c-family/c.opt:1704 c-family/c.opt:1731 c-family/c.opt:1771
 #: c-family/c.opt:1802 c-family/c.opt:1806 c-family/c.opt:1822
-#: config/ia64/ia64.opt:167 config/ia64/ia64.opt:170 c-family/c-opts.c:434
+#: config/ia64/ia64.opt:167 config/ia64/ia64.opt:170 c-family/c-opts.c:432
 #, gcc-internal-format
 msgid "switch %qs is no longer supported"
 msgstr "Schalter %qs wird nicht mehr unterstützt"
@@ -13812,10 +13817,6 @@
 msgid "Warn if dereferencing a NULL pointer may lead to erroneous or undefined behavior."
 msgstr "Warnen, wenn das Dereferenzieren eines Nullzeigers zu fehlerhaftem oder undefiniertem Verhalten führen kann."
 
-#: common.opt:649
-msgid "Warn if the loop cannot be optimized due to nontrivial assumptions."
-msgstr "Warnen, wenn Schleife wegen nichttrivialer Annahmen nicht optimiert werden kann."
-
 #: common.opt:656
 msgid "Warn about some C++ One Definition Rule violations during link time optimization."
 msgstr "Während der Optimierungen zur Linkzeit bei einigen Verletzungen der One-Definition-Rule aus C++ warnen."
@@ -13984,1676 +13985,1676 @@
 msgid "-dumpdir <dir>\tSet the directory name to be used for dumps."
 msgstr "-dumpdir <Verzeichnis>\tDen Basis-Verzeichnisnamen für Ausgaben setzen."
 
-#: common.opt:946
+#: common.opt:950
 msgid "The version of the C++ ABI in use."
 msgstr "Die Version der C++-ABI, die verwendet wird."
 
-#: common.opt:950
+#: common.opt:954
 msgid "Aggressively optimize loops using language constraints."
 msgstr "Schleifen aggressiv optimieren, dabei sprachspezifische Einschränkungen einbeziehen."
 
-#: common.opt:954
+#: common.opt:958
 msgid "Align the start of functions."
 msgstr "Funktionsanfänge ausrichten."
 
-#: common.opt:964
+#: common.opt:968
 msgid "Align labels which are only reached by jumping."
 msgstr "Marken ausrichten, die nur mit Sprüngen erreicht werden können."
 
-#: common.opt:971
+#: common.opt:975
 msgid "Align all labels."
 msgstr "Alle Marken ausrichten."
 
-#: common.opt:978
+#: common.opt:982
 msgid "Align the start of loops."
 msgstr "Schleifenanfänge ausrichten."
 
-#: common.opt:1001
+#: common.opt:1005
 msgid "Select what to sanitize."
 msgstr "Auswählen, was bereinigt werden soll."
 
-#: common.opt:1005
+#: common.opt:1009
 msgid "Select type of coverage sanitization."
 msgstr "Art der Abdeckungs-Bereinigung auswählen."
 
-#: common.opt:1009
+#: common.opt:1013
 msgid "-fasan-shadow-offset=<number>\tUse custom shadow memory offset."
 msgstr "-fasan-shadow-offset=<Zahl>\tSpezifischen Offset für Schattenspeicher verwenden."
 
-#: common.opt:1013
+#: common.opt:1017
 msgid "-fsanitize-sections=<sec1,sec2,...>\tSanitize global variables in user-defined sections."
 msgstr "-fsanitize-sections=<sec1,sec2,...>\tGlobale Variablen in benutzerdefinierten Abschnitten bereinigen."
 
-#: common.opt:1018
+#: common.opt:1022
 msgid "After diagnosing undefined behavior attempt to continue execution."
 msgstr "Nach dem Erkennen von undefiniertem Verhalten versuchen, die Ausführung fortzusetzen."
 
-#: common.opt:1022
+#: common.opt:1026
 msgid "This switch is deprecated; use -fsanitize-recover= instead."
 msgstr "Dieser Schalter ist veraltet; stattdessen -fsanitize-recover= verwenden."
 
-#: common.opt:1029
+#: common.opt:1033
 msgid "Use trap instead of a library function for undefined behavior sanitization."
 msgstr "Für das Bereinigen von undefiniertem Verhalten eine Trap statt einer Bibliotheksfunktion verwenden."
 
-#: common.opt:1033
+#: common.opt:1037
 msgid "Generate unwind tables that are exact at each instruction boundary."
 msgstr "Abwicklungstabellen erzeugen, die genau an jeder Befehlsgrenze liegen."
 
-#: common.opt:1037
+#: common.opt:1041
 msgid "Generate auto-inc/dec instructions."
 msgstr "Auto-inc/dec-Befehle erzeugen."
 
-#: common.opt:1041
+#: common.opt:1045
 msgid "Use sample profile information for call graph node weights. The default profile file is fbdata.afdo in 'pwd'."
 msgstr "Profilierungsinformationen für Aufrufgraph-Knotengewichtungen verwenden. Vorgabe ist die Datei fbdata.afdo im aktuellen Arbeitsverzeichnis."
 
-#: common.opt:1046
+#: common.opt:1050
 msgid "Use sample profile information for call graph node weights. The profile file is specified in the argument."
 msgstr "Profilierungsinformationen für Aufrufgraph-Knotengewichtungen verwenden. Die Profilierungsdatei ist im Argument angegeben."
 
-#: common.opt:1055
+#: common.opt:1059
 msgid "Generate code to check bounds before indexing arrays."
 msgstr "Code zur Überprüfung der Grenzen vor Arrayindizierung erzeugen."
 
-#: common.opt:1059
+#: common.opt:1063
 msgid "Replace add, compare, branch with branch on count register."
 msgstr "Addieren, Vergleichen, Verzweigen mit Verzweigung anhand des Zählregisters ersetzen."
 
-#: common.opt:1063
+#: common.opt:1067
 msgid "Use profiling information for branch probabilities."
 msgstr "Profilierungsinformationen für Verzweigungswahrscheinlichkeiten verwenden."
 
-#: common.opt:1067
+#: common.opt:1071
 msgid "Perform branch target load optimization before prologue / epilogue threading."
 msgstr "Ladeoptimierungen für Sprungziele vor Prolog/Epilog-Behandlung ausführen."
 
-#: common.opt:1071
+#: common.opt:1075
 msgid "Perform branch target load optimization after prologue / epilogue threading."
 msgstr "Ladeoptimierung für Sprungziele nach Prolog/Epilog-Behandlung ausführen."
 
-#: common.opt:1075
+#: common.opt:1079
 msgid "Restrict target load migration not to re-use registers in any basic block."
 msgstr "In Basis-Blöcken keine Register bei der Ziel-Lade-Bewegung wiederverwenden."
 
-#: common.opt:1079
+#: common.opt:1083
 msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions."
 msgstr "-fcall-saved-<Register>\t<Register> als über Funktionsgrenzen hinweg reserviert markieren."
 
-#: common.opt:1083
+#: common.opt:1087
 msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls."
 msgstr "-fcall-used-<Register>\t<Register> als durch Funktionsaufrufe beschädigt markieren."
 
-#: common.opt:1090
+#: common.opt:1094
 msgid "Save registers around function calls."
 msgstr "Register bei Funktionsaufrufen sichern."
 
-#: common.opt:1094
+#: common.opt:1098
 msgid "This switch is deprecated; do not use."
 msgstr "Dieser Schalter ist veraltet; nicht verwenden."
 
-#: common.opt:1098
+#: common.opt:1102
 msgid "Check the return value of new in C++."
 msgstr "Rückgabewert des C++-Operators new prüfen."
 
-#: common.opt:1102 common.opt:1106
+#: common.opt:1106 common.opt:1110
 msgid "Perform internal consistency checkings."
 msgstr "Interne Konsistenzprüfungen durchführen."
 
-#: common.opt:1110
+#: common.opt:1114
 msgid "Enable code hoisting."
 msgstr "Codeanhebung einschalten."
 
-#: common.opt:1114
+#: common.opt:1118
 msgid "Looks for opportunities to reduce stack adjustments and stack references."
 msgstr "Sucht Möglichkeiten, Stapel-Anpassungen und Stapel-Referenzen zu reduzieren."
 
-#: common.opt:1118
+#: common.opt:1122
 msgid "Do not put uninitialized globals in the common section."
 msgstr "Keine uninitialisierten globalen Symbole in gemeinsamen Abschnitt legen."
 
-#: common.opt:1126
+#: common.opt:1130
 msgid "-fcompare-debug[=<opts>]\tCompile with and without e.g. -gtoggle, and compare the final-insns dump."
 msgstr "-fcompare-debug[=<Optionen>]\tMit und ohne z.B. -gtoggle kompilieren, und den Dump der »final-insns« vergleichen."
 
-#: common.opt:1130
+#: common.opt:1134
 msgid "Run only the second compilation of -fcompare-debug."
 msgstr "Nur die zweite Kompilierung von -fcompare-debug laufen lassen."
 
-#: common.opt:1134
+#: common.opt:1138
 msgid "Perform comparison elimination after register allocation has finished."
 msgstr "Beseitigung von Vergleichen nach Registerreservierung durchführen."
 
-#: common.opt:1138
+#: common.opt:1142
 msgid "Do not perform optimizations increasing noticeably stack usage."
 msgstr "Keine Optimierungen durchführen, die die Stapelverwendung deutlich erhöhen."
 
-#: common.opt:1142
+#: common.opt:1146
 msgid "Perform a register copy-propagation optimization pass."
 msgstr "Optimierungsdurchlauf zur Kopierübertragung von Registern durchführen."
 
-#: common.opt:1146
+#: common.opt:1150
 msgid "Perform cross-jumping optimization."
 msgstr "Optimierung zum Kreuzsprung durchführen."
 
-#: common.opt:1150
+#: common.opt:1154
 msgid "When running CSE, follow jumps to their targets."
 msgstr "Beim Durchlaufen von CSE: Sprüngen zu ihren Zielen folgen."
 
-#: common.opt:1158
+#: common.opt:1162
 msgid "Omit range reduction step when performing complex division."
 msgstr "Schritt zur Bereichsverkleinerung auslassen, wenn komplexe Division durchgeführt wird."
 
-#: common.opt:1162
+#: common.opt:1166
 msgid "Complex multiplication and division follow Fortran rules."
 msgstr "Komplexe Multiplikation und Division befolgen Fortran-Regeln."
 
-#: common.opt:1166
+#: common.opt:1170
 msgid "Place data items into their own section."
 msgstr "Datenstücke in ihren eigenen Abschnitt legen."
 
-#: common.opt:1170
+#: common.opt:1174
 msgid "List all available debugging counters with their limits and counts."
 msgstr "Alle verfügbaren Fehleranalysezähler mit ihren Grenzen und Werten auflisten."
 
-#: common.opt:1174
+#: common.opt:1178
 msgid "-fdbg-cnt=<counter>:<limit>[,<counter>:<limit>,...]\tSet the debug counter limit."
 msgstr "-fdbg-cnt=<Zähler>:<Grenze>[,<Zähler>:<Grenze>,...]\tGrenze des Fehlersuchzählers setzen."
 
-#: common.opt:1178
+#: common.opt:1182
 msgid "-fdebug-prefix-map=<old>=<new> Map one directory name to another in debug information."
 msgstr "-fdebug-prefix-map=<alt>=<neu> In Fehlersuchinfo einen Verzeichnisnamen auf einen anderen abbilden."
 
-#: common.opt:1182
+#: common.opt:1186
 msgid "-ffile-prefix-map=<old>=<new> Map one directory name to another in compilation result."
 msgstr "-ffile-prefix-map=<alt>=<neu> In Übersetzungsergebnis einen Verzeichnisnamen auf einen anderen abbilden."
 
-#: common.opt:1186
+#: common.opt:1190
 msgid "Output .debug_types section when using DWARF v4 debuginfo."
 msgstr ".debug_types-Abschnitt ausgeben, wenn DWARF v4-Debuginfo verwendet wird."
 
-#: common.opt:1192
+#: common.opt:1196
 msgid "Defer popping functions args from stack until later."
 msgstr "Zurückholen der Funktionsargumente vom Stapel bis auf weiteres hinauszögern."
 
-#: common.opt:1196
+#: common.opt:1200
 msgid "Attempt to fill delay slots of branch instructions."
 msgstr "Versuchen, die Verzögerungsschlitze der Sprungbefehle auszufüllen."
 
-#: common.opt:1200
+#: common.opt:1204
 msgid "Delete dead instructions that may throw exceptions."
 msgstr "Unerreichbare Befehle löschen, die Ausnahmen werfen können."
 
-#: common.opt:1204
+#: common.opt:1208
 msgid "Delete useless null pointer checks."
 msgstr "Unnötige Nullzeigerprüfungen löschen."
 
-#: common.opt:1208
+#: common.opt:1212
 msgid "Stream extra data to support more aggressive devirtualization in LTO local transformation mode."
 msgstr "Zusätzliche Daten verarbeiten, um in LTO-lokalem Umwandlungsmodus aggressiver zu devirtualisieren."
 
-#: common.opt:1212
+#: common.opt:1216
 msgid "Perform speculative devirtualization."
 msgstr "Spekulative Devirtualisierung durchführen."
 
-#: common.opt:1216
+#: common.opt:1220
 msgid "Try to convert virtual calls to direct ones."
 msgstr "Versuchen, virtuelle Sprünge in direkte umzuwandeln."
 
-#: common.opt:1220
+#: common.opt:1224
 msgid "-fdiagnostics-show-location=[once|every-line]\tHow often to emit source location at the beginning of line-wrapped diagnostics."
 msgstr "-fdiagnostics-show-location=[once|every-line]\tWie oft die Quelltext-Position am Zeilenanfang ausgegeben wird, wenn die Diagnose über mehrere Zeilen geht."
 
-#: common.opt:1237
+#: common.opt:1241
 msgid "Show the source line with a caret indicating the column."
 msgstr "Quellzeile mit Einschaltungszeichen anzeigen, um die Spalte zu kennzeichnen."
 
-#: common.opt:1245
+#: common.opt:1249
 msgid "-fdiagnostics-color=[never|always|auto]\tColorize diagnostics."
 msgstr "-fdiagnostics-color=[never|always|auto]\tDiagnosemeldungen einfärben."
 
-#: common.opt:1265
+#: common.opt:1269
 msgid "Print fix-it hints in machine-readable form."
 msgstr "Behebungshinweise in maschinenlesbarer Form ausgeben."
 
-#: common.opt:1269
+#: common.opt:1273
 msgid "Print fix-it hints to stderr in unified diff format."
 msgstr "Behebungshinweise in vereinheitlichtem Diff-Format auf stderr ausgeben."
 
-#: common.opt:1273
+#: common.opt:1277
 msgid "Amend appropriate diagnostic messages with the command line option that controls them."
 msgstr "Die geeignete Diagnosemeldung mit der Kommandozeilenoption anreichern, die sie steuert."
 
-#: common.opt:1277
+#: common.opt:1281
 msgid "-fdisable-[tree|rtl|ipa]-<pass>=range1+range2 disables an optimization pass."
 msgstr "-fdisable-[tree|rtl|ipa]-<Durchgang>=range1+range2 schaltet einen Optimierungsdurchgang aus."
 
-#: common.opt:1281
+#: common.opt:1285
 msgid "-fenable-[tree|rtl|ipa]-<pass>=range1+range2 enables an optimization pass."
 msgstr "-fenable-[tree|rtl|ipa]-<Durchgang>=range1+range2 schaltet einen Optimierungsdurchgang ein."
 
-#: common.opt:1285
+#: common.opt:1289
 msgid "-fdump-<type>\tDump various compiler internals to a file."
 msgstr "-fdump-<type>\tVerschiedene compilerinterne Informationen in eine Datei abziehen."
 
-#: common.opt:1292
+#: common.opt:1296
 msgid "-fdump-final-insns=filename\tDump to filename the insns at the end of translation."
 msgstr "-fdump-final-insns=<Datei>\tDie Befehle am Ende der Übersetzung in Datei abziehen."
 
-#: common.opt:1296
+#: common.opt:1300
 msgid "-fdump-go-spec=filename\tWrite all declarations to file as Go code."
 msgstr "-fdump-go-spec=<Datei>\tAlle Deklarationen als Go-Code in <Datei> schreiben."
 
-#: common.opt:1300
+#: common.opt:1304
 msgid "Suppress output of addresses in debugging dumps."
 msgstr "Ausgabe von Adressen in Fehlersuch-Auszügen unterdrücken."
 
-#: common.opt:1304
+#: common.opt:1308
 msgid "Collect and dump debug information into temporary file if ICE in C/C++ compiler occurred."
 msgstr "Im Falle eines internen Fehlers im C/C++-Compiler die Debuginformationen sammeln und in temporäre Datei ausgeben."
 
-#: common.opt:1309
+#: common.opt:1313
 msgid "Dump detailed information on GCC's internal representation of source code locations."
 msgstr "Detaillierte Informationen über die GCC-interne Repräsentation von Quellcode-Stellen ausgeben."
 
-#: common.opt:1313
+#: common.opt:1317
 msgid "Dump optimization passes."
 msgstr "Optimierungsdurchläufe ausgeben."
 
-#: common.opt:1317
+#: common.opt:1321
 msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps."
 msgstr "Ausgabe von Befehlszahlen, Zeilennummernangaben und Adressen in Fehlersuch-Auszügen unterdrücken."
 
-#: common.opt:1321
+#: common.opt:1325
 msgid "Suppress output of previous and next insn numbers in debugging dumps."
 msgstr "Ausgabe der vorigen und nächsten Befehlsnummern in Fehlersuch-Auszügen unterdrücken."
 
-#: common.opt:1325
+#: common.opt:1329
 msgid "Enable CFI tables via GAS assembler directives."
 msgstr "CFI-Tabellen über GAS-Assembler-Direktiven einschalten."
 
-#: common.opt:1329
+#: common.opt:1333
 msgid "Perform early inlining."
 msgstr "Frühes Inlining durchführen."
 
-#: common.opt:1337
+#: common.opt:1341
 msgid "Perform interprocedural reduction of aggregates."
 msgstr "Zwischenprozedurale Reduktion von Aggregaten durchführen."
 
-#: common.opt:1341
+#: common.opt:1345
 msgid "Perform unused symbol elimination in debug info."
 msgstr "Ungenutzte Symbole aus Info zur Fehlersuche entfernen."
 
-#: common.opt:1345
+#: common.opt:1349
 msgid "Perform unused type elimination in debug info."
 msgstr "Ungenutzte Typen aus Info zur Fehlersuche entfernen."
 
-#: common.opt:1349
+#: common.opt:1353
 msgid "Do not suppress C++ class debug information."
 msgstr "Keine Fehlersuchinformationen für C++-Klassen unterdrücken."
 
-#: common.opt:1353
+#: common.opt:1357
 msgid "Enable exception handling."
 msgstr "Ausnahmebehandlung einschalten."
 
-#: common.opt:1357
+#: common.opt:1361
 msgid "Perform a number of minor, expensive optimizations."
 msgstr "Eine Reihe kleiner, aber teurer, Optimierungen durchführen."
 
-#: common.opt:1361
+#: common.opt:1365
 msgid "-fexcess-precision=[fast|standard]\tSpecify handling of excess floating-point precision."
 msgstr "-fexcess-precision=[fast|standard]\tBehandlung überschüssiger Gleitkommagenauigkeit bestimmen."
 
-#: common.opt:1364
+#: common.opt:1368
 #, c-format
 msgid "unknown excess precision style %qs"
 msgstr "unbekannte Art überschüssiger Genauigkeit %qs"
 
-#: common.opt:1376
+#: common.opt:1380
 msgid "-fpermitted-flt-eval-methods=[c11|ts-18661]\tSpecify which values of FLT_EVAL_METHOD are permitted."
 msgstr "-fpermitted-flt-eval-methods=[c11|ts-18661]\tAngeben, welche Werte von FLT_EVAL_METHOD erlaubt sind."
 
-#: common.opt:1379
+#: common.opt:1383
 #, c-format
 msgid "unknown specification for the set of FLT_EVAL_METHOD values to permit %qs"
 msgstr "unbekannte Spezifikation für die Menge der FLT_EVAL_METHOD-Werte, um %qs zu erlauben"
 
-#: common.opt:1392
+#: common.opt:1396
 msgid "Output lto objects containing both the intermediate language and binary output."
 msgstr "LTO-Objekte ausgeben, die sowohl Zwischensprache als auch Binärausgabe enthalten."
 
-#: common.opt:1396
+#: common.opt:1400
 msgid "Assume no NaNs or infinities are generated."
 msgstr "Annehmen, dass keine NaNs oder Unendlichkeiten erzeugt werden."
 
-#: common.opt:1400
+#: common.opt:1404
 msgid "-ffixed-<register>\tMark <register> as being unavailable to the compiler."
 msgstr "-ffixed-<Register>\t<Register> als für den Compiler nicht verfügbar markieren."
 
-#: common.opt:1404
+#: common.opt:1408
 msgid "Don't allocate floats and doubles in extended-precision registers."
 msgstr "Keine floats und doubles in Registern erweiterter Genauigkeit reservieren."
 
-#: common.opt:1412
+#: common.opt:1416
 msgid "Perform a forward propagation pass on RTL."
 msgstr "Schritt zur Vorwärts-Übertragung auf RTL durchführen."
 
-#: common.opt:1416
+#: common.opt:1420
 msgid "-ffp-contract=[off|on|fast]\tPerform floating-point expression contraction."
 msgstr "-ffp-contract=[off|on|fast]\tSchrumpfung von Gleitkommaausdrücken durchführen."
 
-#: common.opt:1419
+#: common.opt:1423
 #, c-format
 msgid "unknown floating point contraction style %qs"
 msgstr "unbekannte Art der Gleitkomma-Kürzung %qs"
 
-#: common.opt:1433
+#: common.opt:1437
 msgid "Allow built-in functions ceil, floor, round, trunc to raise \"inexact\" exceptions."
 msgstr "Den eingebauten Funktionen ceil, floor, round, trunc erlauben, »inexact«-Exceptions zu werfen."
 
-#: common.opt:1440
+#: common.opt:1444
 msgid "Allow function addresses to be held in registers."
 msgstr "Vorhalten von Funktionsadressen in Registern erlauben."
 
-#: common.opt:1444
+#: common.opt:1448
 msgid "Place each function into its own section."
 msgstr "Jede Funktion in ihren eigenen Abschnitt platzieren."
 
-#: common.opt:1448
+#: common.opt:1452
 msgid "Perform global common subexpression elimination."
 msgstr "Beseitigung globaler gemeinsamer Teilausdrücke durchführen."
 
-#: common.opt:1452
+#: common.opt:1456
 msgid "Perform enhanced load motion during global common subexpression elimination."
 msgstr "Erweiterte Ladebewegung während Beseitigung globaler gemeinsamer Teilausdrücke durchführen."
 
-#: common.opt:1456
+#: common.opt:1460
 msgid "Perform store motion after global common subexpression elimination."
 msgstr "Speicherbewegung nach Beseitigung globaler gemeinsamer Teilausdrücke durchführen."
 
-#: common.opt:1460
+#: common.opt:1464
 msgid "Perform redundant load after store elimination in global common subexpression elimination."
 msgstr "Beseitigung überflüssigen Ladens nach dem Abspeichern in globalem gemeinsamem Teilausdruck durchführen."
 
-#: common.opt:1465
+#: common.opt:1469
 msgid "Perform global common subexpression elimination after register allocation has finished."
 msgstr "Beseitigung globaler gemeinsamer Teilausdrücke nach Registerreservierung durchführen."
 
-#: common.opt:1482
+#: common.opt:1486
 msgid "-fgnat-encodings=[all|gdb|minimal]\tSelect the balance between GNAT encodings and standard DWARF emitted in the debug information"
 msgstr "-fgnat-encodings=[all|gdb|minimal]\tGleichgewicht zwischen GNAT-Encodings und Standard-DWARF auswählen, die in den Debuginformationen landen"
 
-#: common.opt:1487
+#: common.opt:1491
 msgid "Enable in and out of Graphite representation."
 msgstr "Ein- und Ausgabe der Graphite-Repräsentierung einschalten."
 
-#: common.opt:1491
+#: common.opt:1495
 msgid "Enable Graphite Identity transformation."
 msgstr "Transformation der Graphite-Identität einschalten."
 
-#: common.opt:1495
+#: common.opt:1499
 msgid "Enable hoisting adjacent loads to encourage generating conditional move instructions."
 msgstr "Herausziehen aufeinanderfolgender Ladeoperationen einschalten, um Erzeugung bedingter Kopieroperationen zu fördern."
 
-#: common.opt:1504
+#: common.opt:1508
 msgid "Mark all loops as parallel."
 msgstr "Alle Schleifen als parallel markieren."
 
-#: common.opt:1508 common.opt:1516 common.opt:2587
+#: common.opt:1512 common.opt:1520 common.opt:2591
 msgid "Enable loop nest transforms.  Same as -floop-nest-optimize."
 msgstr "Schleifenschachtelungs-Umwandlungen einschalten. Entspricht -floop-next-optimize."
 
-#: common.opt:1512
+#: common.opt:1516
 msgid "Enable loop interchange on trees."
 msgstr "Umordnen der Schleifen auf Bäumen einschalten."
 
-#: common.opt:1520
+#: common.opt:1524
 msgid "Perform unroll-and-jam on loops."
 msgstr "Schleifenabwicklung (unroll-and-jam) für Schleifen durchführen."
 
-#: common.opt:1524
+#: common.opt:1528
 msgid "Enable support for GNU transactional memory."
 msgstr "Unterstützung für GNU-Transaktionsspeicher einschalten."
 
-#: common.opt:1528
+#: common.opt:1532
 msgid "Use STB_GNU_UNIQUE if supported by the assembler."
 msgstr "STB_GNU_UNIQUE verwenden, sofern der Assembler es unterstützt."
 
-#: common.opt:1536
+#: common.opt:1540
 msgid "Enable the loop nest optimizer."
 msgstr "Optimierer für geschachtelte Schleifen einschalten."
 
-#: common.opt:1540
+#: common.opt:1544
 msgid "Force bitfield accesses to match their type width."
 msgstr "Bitfeld-Zugriffe zwingen, zu ihrer Typbreite zu passen."
 
-#: common.opt:1544
+#: common.opt:1548
 msgid "Merge adjacent stores."
 msgstr "Nebeneinanderliegende Speicheroperationen zusammenfassen."
 
-#: common.opt:1548
+#: common.opt:1552
 msgid "Enable guessing of branch probabilities."
 msgstr "Erraten der Sprungwahrscheinlichkeiten einschalten."
 
-#: common.opt:1556
+#: common.opt:1560
 msgid "Process #ident directives."
 msgstr "#ident-Direktiven verarbeiten."
 
-#: common.opt:1560
+#: common.opt:1564
 msgid "Perform conversion of conditional jumps to branchless equivalents."
 msgstr "Umwandlung bedingter Sprünge in zweiglose Äquivalente durchführen."
 
-#: common.opt:1564
+#: common.opt:1568
 msgid "Perform conversion of conditional jumps to conditional execution."
 msgstr "Umwandlung bedingter Sprünge in bedingte Ausführung durchführen."
 
-#: common.opt:1568
+#: common.opt:1572
 msgid "-fstack-reuse=[all|named_vars|none]\tSet stack reuse level for local variables."
 msgstr "-fstack-reuse=[all|named_vars|none]\tStufe der Stapel-Wiederverwendung für lokale Variablen festlegen."
 
-#: common.opt:1571
+#: common.opt:1575
 #, c-format
 msgid "unknown Stack Reuse Level %qs"
 msgstr "Unbekannte Stufe %qs für Stapel-Wiederverwendung"
 
-#: common.opt:1584
+#: common.opt:1588
 msgid "Convert conditional jumps in innermost loops to branchless equivalents."
 msgstr "Umwandlung bedingter Sprünge in innersten Schleifen in zweiglose Äquivalente durchführen."
 
-#: common.opt:1596
+#: common.opt:1600
 msgid "Do not generate .size directives."
 msgstr "Keine .size-Direktiven erzeugen."
 
-#: common.opt:1600
+#: common.opt:1604
 msgid "Perform indirect inlining."
 msgstr "Indirektes Inlining durchführen."
 
-#: common.opt:1606
+#: common.opt:1610
 msgid "Enable inlining of function declared \"inline\", disabling disables all inlining."
 msgstr "Einschalten des Inlining von »inline«-Funktionen, ansonsten wird jegliches Inlining ausgeschaltet."
 
-#: common.opt:1610
+#: common.opt:1614
 msgid "Integrate functions into their callers when code size is known not to grow."
 msgstr "Funktionen in ihre Aufrufer einfügen, wenn Codegröße als nicht wachsend bekannt ist."
 
-#: common.opt:1614
+#: common.opt:1618
 msgid "Integrate functions not declared \"inline\" into their callers when profitable."
 msgstr "Nicht als »inline« deklarierte Funktionen in ihre Aufrufer einfügen, wenn gewinnbringend."
 
-#: common.opt:1618
+#: common.opt:1622
 msgid "Integrate functions only required by their single caller."
 msgstr "Nur an einer Stelle aufgerufene Funktionen in ihre Aufrufer einfügen."
 
-#: common.opt:1625
+#: common.opt:1629
 msgid "-finline-limit=<number>\tLimit the size of inlined functions to <number>."
 msgstr "-finline-limit=<Zahl>\tGröße von »inline«-Funktionen auf <Zahl> beschränken."
 
-#: common.opt:1629
+#: common.opt:1633
 msgid "Inline __atomic operations when a lock free instruction sequence is available."
 msgstr "__atomic-Operationen »inline« erzeugen, wenn Lock-freie Befehlssequenz verfügbar ist."
 
-#: common.opt:1636
+#: common.opt:1640
 msgid "-fcf-protection=[full|branch|return|none]\tInstrument functions with checks to verify jump/call/return control-flow transfer instructions have valid targets."
 msgstr "-fcf-protection=[full|branch|return|none]\tFunktionen mit zusätzlichen Prüfungen versehen, dass die Sprungziele von jump/call/return gültig sind."
 
-#: common.opt:1640
+#: common.opt:1644
 #, c-format
 msgid "unknown Control-Flow Protection Level %qs"
 msgstr "Unbekannte Schutzstufe %qs für Kontrollfluss"
 
-#: common.opt:1656
+#: common.opt:1660
 msgid "Instrument function entry and exit with profiling calls."
 msgstr "Ein- und Austritte von Funktionen beim Profilieren von Aufrufen verwenden."
 
-#: common.opt:1660
+#: common.opt:1664
 msgid "-finstrument-functions-exclude-function-list=name,...  Do not instrument listed functions."
 msgstr "-finstrument-functions-exclude-function-list=name,...  Aufgezählte Funktionen nicht instrumentieren."
 
-#: common.opt:1664
+#: common.opt:1668
 msgid "-finstrument-functions-exclude-file-list=filename,...  Do not instrument functions listed in files."
 msgstr "-finstrument-functions-exclude-file-list=filename,...  In Dateien aufgezählte Funktionen nicht instrumentieren."
 
-#: common.opt:1668
+#: common.opt:1672
 msgid "Perform interprocedural constant propagation."
 msgstr "Zwischenprozedurale Konstantenweitergabe durchführen."
 
-#: common.opt:1672
+#: common.opt:1676
 msgid "Perform cloning to make Interprocedural constant propagation stronger."
 msgstr "Kopien erzeugen, um zwischenprozedurale Konstantenweitergabe zu verstärken."
 
-#: common.opt:1680
+#: common.opt:1684
 msgid "Perform interprocedural bitwise constant propagation."
 msgstr "Zwischenprozedurale bitweise Konstantenweitergabe durchführen."
 
-#: common.opt:1684
+#: common.opt:1688
 msgid "Perform interprocedural profile propagation."
 msgstr "Zwischenprozedurale Profilweitergabe durchführen."
 
-#: common.opt:1688
+#: common.opt:1692
 msgid "Perform interprocedural points-to analysis."
 msgstr "Zwischenprozedurale Zeigt-auf-Analyse durchführen."
 
-#: common.opt:1692
+#: common.opt:1696
 msgid "Discover pure and const functions."
 msgstr "Reine und konstante Funktionen entdecken."
 
-#: common.opt:1696
+#: common.opt:1700
 msgid "Perform Identical Code Folding for functions and read-only variables."
 msgstr "Identischen Code für Funktionen und schreibgeschützte Variablen zusammenfassen."
 
-#: common.opt:1700
+#: common.opt:1704
 msgid "Perform Identical Code Folding for functions."
 msgstr "Identischen Code für Funktionen zusammenfassen."
 
-#: common.opt:1704
+#: common.opt:1708
 msgid "Perform Identical Code Folding for variables."
 msgstr "Identischen Code für Variablen zusammenfassen."
 
-#: common.opt:1708
+#: common.opt:1712
 msgid "Discover readonly and non addressable static variables."
 msgstr "Nur-lese und nicht-adressierbare statische Variablen entdecken."
 
-#: common.opt:1720
+#: common.opt:1724
 msgid "Perform IPA Value Range Propagation."
 msgstr "Informationen über IPA-Wertebereiche weitergeben."
 
-#: common.opt:1724
+#: common.opt:1728
 msgid "-fira-algorithm=[CB|priority]\tSet the used IRA algorithm."
 msgstr "-fira-algorithm=[CB|priority]\tVerwendeten IRA-Algorithmus festlegen."
 
-#: common.opt:1727
+#: common.opt:1731
 #, c-format
 msgid "unknown IRA algorithm %qs"
 msgstr "unbekannter IRA-Algorithmus %qs"
 
-#: common.opt:1737
+#: common.opt:1741
 msgid "-fira-region=[one|all|mixed]\tSet regions for IRA."
 msgstr "-fira-region=[one|all|mixed]\tRegionen für IRA festlegen."
 
-#: common.opt:1740
+#: common.opt:1744
 #, c-format
 msgid "unknown IRA region %qs"
 msgstr "unbekannte IRA-Region %qs"
 
-#: common.opt:1753
+#: common.opt:1757
 msgid "Use IRA based register pressure calculation in RTL hoist optimizations."
 msgstr "IRA-basierte Registerdruckberechnungen in RTL-Optimierungen zum Anheben verwenden."
 
-#: common.opt:1758
+#: common.opt:1762
 msgid "Use IRA based register pressure calculation in RTL loop optimizations."
 msgstr "IRA-basierte Registerdruckberechnungen in RTL-Schleifenoptimierungen verwenden."
 
-#: common.opt:1763
+#: common.opt:1767
 msgid "Share slots for saving different hard registers."
 msgstr "Schlitze gemeinsam verwenden, um verschiedene harte Register zu sichern."
 
-#: common.opt:1767
+#: common.opt:1771
 msgid "Share stack slots for spilled pseudo-registers."
 msgstr "Stapel-Schlitze für übergelaufene Pseudo-Register gemeinsam verwenden."
 
-#: common.opt:1771
+#: common.opt:1775
 msgid "-fira-verbose=<number>\tControl IRA's level of diagnostic messages."
 msgstr "-fira-verbose=<Zahl<\tStufe der IRA Diagnosemeldungen steuern."
 
-#: common.opt:1775
+#: common.opt:1779
 msgid "Optimize induction variables on trees."
 msgstr "Induktionsvariablen auf Bäumen optimieren."
 
-#: common.opt:1779
+#: common.opt:1783
 msgid "Use jump tables for sufficiently large switch statements."
 msgstr "Sprungtabellen für hinreichend große switch-Anweisungen verwenden."
 
-#: common.opt:1783
+#: common.opt:1787
 msgid "Generate code for functions even if they are fully inlined."
 msgstr "Code für Funktionen erzeugen, auch wenn sie vollständig »inline« sind."
 
-#: common.opt:1787
+#: common.opt:1791
 msgid "Generate code for static functions even if they are never called."
 msgstr "Code für static-Funktionen erzeugen, auch wenn sie nie aufgerufen werden."
 
-#: common.opt:1791
+#: common.opt:1795
 msgid "Emit static const variables even if they are not used."
 msgstr "static-const-Variablen erzeugen, auch wenn sie nicht verwendet werden."
 
-#: common.opt:1795
+#: common.opt:1799
 msgid "Give external symbols a leading underscore."
 msgstr "Externen Symbolen einen führenden Unterstrich geben."
 
-#: common.opt:1803
+#: common.opt:1807
 msgid "Do CFG-sensitive rematerialization in LRA."
 msgstr "In LRA die ablaufsensitive Rematerialisierung durchführen."
 
-#: common.opt:1807
+#: common.opt:1811
 msgid "Enable link-time optimization."
 msgstr "Optimierungen zur Bindezeit einschalten."
 
-#: common.opt:1811
+#: common.opt:1815
 msgid "Link-time optimization with number of parallel jobs or jobserver."
 msgstr "Optimierungen zur Bindezeit mit Anzahl paralleler Jobs oder Jobserver."
 
-#: common.opt:1814
+#: common.opt:1818
 #, c-format
 msgid "unknown LTO partitioning model %qs"
 msgstr "Unbekanntes LTO-Partitionierungs-Modell %qs"
 
-#: common.opt:1833
+#: common.opt:1837
 msgid "Specify the algorithm to partition symbols and vars at linktime."
 msgstr "Algorithmus, mit dem Symbole und Variablen zur Linkzeit partitioniert werden."
 
-#: common.opt:1838
+#: common.opt:1842
 msgid "-flto-compression-level=<number>\tUse zlib compression level <number> for IL."
 msgstr "-flto-compression-level=<Stufe>\tZlib-Kompressionsstufe <Stufe> für IL verwenden."
 
-#: common.opt:1842
+#: common.opt:1846
 msgid "Merge C++ types using One Definition Rule."
 msgstr "C++-Typen mithilfe der One-Definition-Rule zusammenfassen."
 
-#: common.opt:1846
+#: common.opt:1850
 msgid "Report various link-time optimization statistics."
 msgstr "Verschiedene Statistiken über Linkzeit-Optimierung ausgeben."
 
-#: common.opt:1850
+#: common.opt:1854
 msgid "Report various link-time optimization statistics for WPA only."
 msgstr "Nur in WPA verschiedene Statistiken über Linkzeit-Optimierung ausgeben."
 
-#: common.opt:1854
+#: common.opt:1858
 msgid "Set errno after built-in math functions."
 msgstr "Nach eingebauten Mathematikfunktionen errno setzen."
 
-#: common.opt:1858
+#: common.opt:1862
 msgid "-fmax-errors=<number>\tMaximum number of errors to report."
 msgstr "-fmax-errors=<Anzahl>\tHöchstzahl der zu meldenden Fehler."
 
-#: common.opt:1862
+#: common.opt:1866
 msgid "Report on permanent memory allocation."
 msgstr "Über dauerhafte Speicherreservierung berichten."
 
-#: common.opt:1866
+#: common.opt:1870
 msgid "Report on permanent memory allocation in WPA only."
 msgstr "Nur in WPA über dauerhafte Speicherreservierung berichten."
 
-#: common.opt:1873
+#: common.opt:1877
 msgid "Attempt to merge identical constants and constant variables."
 msgstr "Versuchen, identische Konstanten und konstante Variablen zu verschmelzen."
 
-#: common.opt:1877
+#: common.opt:1881
 msgid "Attempt to merge identical constants across compilation units."
 msgstr "Versuchen, identische Konstanten über Übersetzungseinheiten hinweg zu verschmelzen."
 
-#: common.opt:1881
+#: common.opt:1885
 msgid "Attempt to merge identical debug strings across compilation units."
 msgstr "Versuchen, identische Zeichenketten zur Fehlersuche über Übersetzungseinheiten hinweg zu verschmelzen."
 
-#: common.opt:1885
+#: common.opt:1889
 msgid "-fmessage-length=<number>\tLimit diagnostics to <number> characters per line.  0 suppresses line-wrapping."
 msgstr "-fmessage-length=<Anzahl>\tDiagnosemeldungen auf <Anzahl> Zeichen pro Zeile beschränken. 0 unterdrückt Zeilenumbruch."
 
-#: common.opt:1889
+#: common.opt:1893
 msgid "Perform SMS based modulo scheduling before the first scheduling pass."
 msgstr "SMS-basierte modulo-Planung vor erstem Planungsdurchlauf durchführen."
 
-#: common.opt:1893
+#: common.opt:1897
 msgid "Perform SMS based modulo scheduling with register moves allowed."
 msgstr "SMS-basierte modulo-Planung mit erlaubten Register-Verschiebungen durchführen."
 
-#: common.opt:1897
+#: common.opt:1901
 msgid "Move loop invariant computations out of loops."
 msgstr "Berechnung der Schleifeninvarianten außerhalb der Schleifen legen."
 
-#: common.opt:1901
+#: common.opt:1905
 msgid "Use the RTL dead code elimination pass."
 msgstr "Den RTL-Durchlauf zur Entfernung toten Codes verwenden."
 
-#: common.opt:1905
+#: common.opt:1909
 msgid "Use the RTL dead store elimination pass."
 msgstr "Den RTL-Durchlauf zur Entfernung toter Speicherungen verwenden."
 
-#: common.opt:1909
+#: common.opt:1913
 msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling."
 msgstr "Traditionelle Planung in Schleifen, die bereits Modulo-Planung unterzogen wurden, einschalten/ausschalten."
 
-#: common.opt:1913
+#: common.opt:1917
 msgid "Support synchronous non-call exceptions."
 msgstr "Synchrone Nicht-Aufruf-Ausnahmen unterstützen."
 
-#: common.opt:1916
+#: common.opt:1920
 #, c-format
 msgid "options or targets missing after %qs"
 msgstr "Optionen oder Zielarchitekturen fehlen hinter %qs"
 
-#: common.opt:1917
+#: common.opt:1921
 msgid "-foffload=<targets>=<options>  Specify offloading targets and options for them."
 msgstr "-foffload=<Ziele>=<Optionen>  Offloading-Ziele und deren Optionen angeben."
 
-#: common.opt:1921
+#: common.opt:1925
 msgid "-foffload-abi=[lp64|ilp32]     Set the ABI to use in an offload compiler."
 msgstr "-foffload-abi=[lp64|ilp32]     Festlegen, welche ABI in einem Offload-Compiler verwendet wird."
 
-#: common.opt:1924
+#: common.opt:1928
 #, c-format
 msgid "unknown offload ABI %qs"
 msgstr "Unbekannte Offload-ABI %qs"
 
-#: common.opt:1934
+#: common.opt:1938
 msgid "When possible do not generate stack frames."
 msgstr "Wenn möglich, keine Stapelrahmen erzeugen."
 
-#: common.opt:1938
+#: common.opt:1942
 msgid "Enable all optimization info dumps on stderr."
 msgstr "Alle Informationen über Optimierungen auf stderr einschalten."
 
-#: common.opt:1942
+#: common.opt:1946
 msgid "-fopt-info[-<type>=filename]\tDump compiler optimization details."
 msgstr "-fopt-info[-<Typ>=Dateiname]\tOptimierungsdetails des Compilers ausgeben."
 
-#: common.opt:1950
+#: common.opt:1954
 msgid "Optimize sibling and tail recursive calls."
 msgstr "Geschwister- und endrekursive Aufrufe optimieren."
 
-#: common.opt:1954
+#: common.opt:1958
 msgid "Perform partial inlining."
 msgstr "Teilweises Inlining durchführen."
 
-#: common.opt:1958 common.opt:1962
+#: common.opt:1962 common.opt:1966
 msgid "Report on memory allocation before interprocedural optimization."
 msgstr "Über Speicherbelegung vor zwischenprozeduraler Optimierung berichten."
 
-#: common.opt:1966
+#: common.opt:1970
 msgid "Pack structure members together without holes."
 msgstr "Strukturelemente ohne Lücken zusammenpacken."
 
-#: common.opt:1970
+#: common.opt:1974
 msgid "-fpack-struct=<number>\tSet initial maximum structure member alignment."
 msgstr "-fpack-struct=<Zahl>\tAnfängliche größte Ausrichtung für Strukturelemente festlegen."
 
-#: common.opt:1974
+#: common.opt:1978
 msgid "Return small aggregates in memory, not registers."
 msgstr "Kleine Aggregate über Speicher, nicht Register, zurückgeben."
 
-#: common.opt:1978
+#: common.opt:1982
 msgid "Perform loop peeling."
 msgstr "Schleifen-Schälung durchführen."
 
-#: common.opt:1982
+#: common.opt:1986
 msgid "Enable machine specific peephole optimizations."
 msgstr "Maschinenspezifische Guckloch-Optimierungen einschalten."
 
-#: common.opt:1986
+#: common.opt:1990
 msgid "Enable an RTL peephole pass before sched2."
 msgstr "Einen RTL-Guckloch-Durchlauf vor sched2 einschalten."
 
-#: common.opt:1990
+#: common.opt:1994
 msgid "Generate position-independent code if possible (large mode)."
 msgstr "Wenn möglich, lageunabhängigen Code erzeugen (large mode)."
 
-#: common.opt:1994
+#: common.opt:1998
 msgid "Generate position-independent code for executables if possible (large mode)."
 msgstr "Wenn möglich, lageunabhängigen Code für ausführbare Dateien erzeugen (large mode)."
 
-#: common.opt:1998
+#: common.opt:2002
 msgid "Generate position-independent code if possible (small mode)."
 msgstr "Wenn möglich, positionsunabhängigen Code erzeugen (small mode)."
 
-#: common.opt:2002
+#: common.opt:2006
 msgid "Generate position-independent code for executables if possible (small mode)."
 msgstr "Wenn möglich, positionsunabhängigen Code für ausführbare Dateien erzeugen (small mode)."
 
-#: common.opt:2006
+#: common.opt:2010
 msgid "Use PLT for PIC calls (-fno-plt: load the address from GOT at call site)."
 msgstr "PLT für PIC-Aufrufe verwenden (-fno-plt: die Adresse beim Aufrufer aus der GOT laden)."
 
-#: common.opt:2010
+#: common.opt:2014
 msgid "Specify a plugin to load."
 msgstr "Zu ladendes Plugin angeben."
 
-#: common.opt:2014
+#: common.opt:2018
 msgid "-fplugin-arg-<name>-<key>[=<value>]\tSpecify argument <key>=<value> for plugin <name>."
 msgstr "-fplugin-arg-<Name>-<Schlüssel>[=<Wert>]\tArgument <Schlüssel>=<Wert> für Plugin <Name> angeben."
 
-#: common.opt:2018
+#: common.opt:2022
 msgid "Run predictive commoning optimization."
 msgstr "Vorhersehende vereinheitlichende Optimierung durchlaufen."
 
-#: common.opt:2022
+#: common.opt:2026
 msgid "Generate prefetch instructions, if available, for arrays in loops."
 msgstr "Wenn verfügbar, Prefetch-Befehle für Arrays in Schleifen erzeugen."
 
-#: common.opt:2026
+#: common.opt:2030
 msgid "Enable basic program profiling code."
 msgstr "Einfachen Programm-Profilierungscode einschalten."
 
-#: common.opt:2030
+#: common.opt:2034
 msgid "Generate absolute source path names for gcov."
 msgstr "Absolute Quellpfade für gcov erzeugen."
 
-#: common.opt:2034
+#: common.opt:2038
 msgid "Insert arc-based program profiling code."
 msgstr "Arc-basierten Programm-Profilierungscode einfügen."
 
-#: common.opt:2038
+#: common.opt:2042
 msgid "Set the top-level directory for storing the profile data. The default is 'pwd'."
 msgstr "Basisverzeichnis zum Speichern der Profildaten setzen. Vorgabe ist das aktuelle Verzeichnis."
 
-#: common.opt:2043
+#: common.opt:2047
 msgid "Enable correction of flow inconsistent profile data input."
 msgstr "Korrektur fluss-unstimmiger Profildateneingabe einschalten."
 
-#: common.opt:2047
+#: common.opt:2051
 msgid "-fprofile-update=[single|atomic|prefer-atomic]\tSet the profile update method."
 msgstr "-fprofile-update=[single|atomic|prefer-atomic]\tMethode für Profilupdates festlegen."
 
-#: common.opt:2050
+#: common.opt:2054
 #, c-format
 msgid "unknown profile update method %qs"
 msgstr "Unbekannte Profil-Aktualisierungs-Methode %qs"
 
-#: common.opt:2063
+#: common.opt:2067
 msgid "Enable common options for generating profile info for profile feedback directed optimizations."
 msgstr "Allgemeine Optionen zum Erzeugen von Profil-Info für Profil-Feedback-gerichtete Optimierungen einschalten."
 
-#: common.opt:2067
+#: common.opt:2071
 msgid "Enable common options for generating profile info for profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr "Allgemeine Optionen zum Erzeugen von Profil-Info für Profil-Feedback-gerichtete Optimierungen einschalten, und -fprofile-dir= setzen."
 
-#: common.opt:2071
+#: common.opt:2075
 msgid "Enable common options for performing profile feedback directed optimizations."
 msgstr "Allgemeine Optionen zum Durchführen von Profil-Feedback-gerichteten Optimierungen einschalten."
 
-#: common.opt:2075
+#: common.opt:2079
 msgid "Enable common options for performing profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr "Allgemeine Optionen zum Durchführen von Profil-Feedback-gerichteten Optimierungen einschalten, und -fprofile-dir= setzen."
 
-#: common.opt:2079
+#: common.opt:2083
 msgid "Insert code to profile values of expressions."
 msgstr "Code einfügen, um Ausdrücke zu profilen."
 
-#: common.opt:2083
+#: common.opt:2087
 msgid "Report on consistency of profile."
 msgstr "Über Konsistenz des Profils berichten."
 
-#: common.opt:2087
+#: common.opt:2091
 msgid "Enable function reordering that improves code placement."
 msgstr "Funktionen umsortieren, um Codeplatzierung zu verbessern."
 
-#: common.opt:2091
+#: common.opt:2095
 msgid "Insert NOP instructions at each function entry."
 msgstr "In jedem Funktionsprolog NOP-Befehle erzeugen."
 
-#: common.opt:2098
+#: common.opt:2102
 msgid "-frandom-seed=<string>\tMake compile reproducible using <string>."
 msgstr "-frandom-seed=<Zeichenkette>\tÜbersetzung mit <Zeichenkette> reproduzierbar machen."
 
-#: common.opt:2108
+#: common.opt:2112
 msgid "Record gcc command line switches in the object file."
 msgstr "GCC-Kommandozeilenschalter in Objektdateien aufzeichnen."
 
-#: common.opt:2112
+#: common.opt:2116
 msgid "Return small aggregates in registers."
 msgstr "Kleine Aggregate über Register zurückgeben."
 
-#: common.opt:2120
+#: common.opt:2124
 msgid "Tell DSE that the storage for a C++ object is dead when the constructor starts and when the destructor finishes."
 msgstr "DSE mitteilen, dass der Speicher für ein C++-Objekt tot ist, wenn der Konstruktor anfängt und wenn der Destruktor aufhört."
 
-#: common.opt:2128
+#: common.opt:2132
 msgid "Relief of register pressure through live range shrinkage."
 msgstr "Entlastung des Registerdrucks durch Live-Bereichs-Schrumpfung."
 
-#: common.opt:2132
+#: common.opt:2136
 msgid "Perform a register renaming optimization pass."
 msgstr "Einen Optimierungsdurchgang zur Registerumbenennung durchführen."
 
-#: common.opt:2136
+#: common.opt:2140
 msgid "Perform a target dependent instruction fusion optimization pass."
 msgstr "Einen zielabhängigen Optimierungsdurchgang zur Befehlsfusion durchführen."
 
-#: common.opt:2140
+#: common.opt:2144
 msgid "Reorder basic blocks to improve code placement."
 msgstr "Basisblöcke umsortieren, um Codeplatzierung zu verbessern."
 
-#: common.opt:2144
+#: common.opt:2148
 msgid "-freorder-blocks-algorithm=[simple|stc]\tSet the used basic block reordering algorithm."
 msgstr "-freorder-blocks-algorithm=[simple|stc]\tAlgorithmus zum Umordnen der Basisblöcke festlegen."
 
-#: common.opt:2147
+#: common.opt:2151
 #, c-format
 msgid "unknown basic block reordering algorithm %qs"
 msgstr "unbekannter Basisblock-Umsortierungs-Algorithmus %qs"
 
-#: common.opt:2157
+#: common.opt:2161
 msgid "Reorder basic blocks and partition into hot and cold sections."
 msgstr "Basisblöcke und in heiße und kalte Abschnitte umordnen und partitionieren."
 
-#: common.opt:2161
+#: common.opt:2165
 msgid "Reorder functions to improve code placement."
 msgstr "Funktionen umsortieren, um Codeplatzierung zu verbessern."
 
-#: common.opt:2165
+#: common.opt:2169
 msgid "Add a common subexpression elimination pass after loop optimizations."
 msgstr "Einen Durchlauf zur Entfernung von Teilausdrücken nach Schleifenoptimierungen hinzufügen."
 
-#: common.opt:2173
+#: common.opt:2177
 msgid "Disable optimizations that assume default FP rounding behavior."
 msgstr "Optimierungen, die Standard-Rundungsverhalten für Gleitkomma annehmen, ausschalten."
 
-#: common.opt:2177
+#: common.opt:2181
 msgid "Enable scheduling across basic blocks."
 msgstr "Planung über Basisblöcke hinaus einschalten."
 
-#: common.opt:2181
+#: common.opt:2185
 msgid "Enable register pressure sensitive insn scheduling."
 msgstr "Registerdruckempfindliche Befehlsplanung einschalten."
 
-#: common.opt:2185
+#: common.opt:2189
 msgid "Allow speculative motion of non-loads."
 msgstr "Spekulative Bewegung von Nicht-Lade-Befehlen erlauben."
 
-#: common.opt:2189
+#: common.opt:2193
 msgid "Allow speculative motion of some loads."
 msgstr "Spekulative Bewegung bei einigen Ladebefehlen erlauben."
 
-#: common.opt:2193
+#: common.opt:2197
 msgid "Allow speculative motion of more loads."
 msgstr "Spekulative Bewegung bei mehr Ladebefehlen erlauben."
 
-#: common.opt:2197
+#: common.opt:2201
 msgid "-fsched-verbose=<number>\tSet the verbosity level of the scheduler."
 msgstr "-fsched-verbose=<Stufe>\tStufe der Wortfülle des Planers angeben."
 
-#: common.opt:2201
+#: common.opt:2205
 msgid "If scheduling post reload, do superblock scheduling."
 msgstr "Wenn Planung nach dem Neuladen, dann Superblock-Planung."
 
-#: common.opt:2209
+#: common.opt:2213
 msgid "Reschedule instructions before register allocation."
 msgstr "Befehle vor Registerbelegung neu planen."
 
-#: common.opt:2213
+#: common.opt:2217
 msgid "Reschedule instructions after register allocation."
 msgstr "Befehle nach Registerbelegung neu planen."
 
-#: common.opt:2220
+#: common.opt:2224
 msgid "Schedule instructions using selective scheduling algorithm."
 msgstr "Befehle mit selektivem Planungs-Algorithmus einplanen."
 
-#: common.opt:2224
+#: common.opt:2228
 msgid "Run selective scheduling after reload."
 msgstr "Ausgewählte Planung nach Neuladen durchführen."
 
-#: common.opt:2228
+#: common.opt:2232
 msgid "Run self-tests, using the given path to locate test files."
 msgstr "Selbsttests durchführen, mit dem angegebenen Pfad, um die Testdateien zu finden."
 
-#: common.opt:2232
+#: common.opt:2236
 msgid "Perform software pipelining of inner loops during selective scheduling."
 msgstr "Während selektiver Planung Software-Pipelining innerer Schleifen durchführen."
 
-#: common.opt:2236
+#: common.opt:2240
 msgid "Perform software pipelining of outer loops during selective scheduling."
 msgstr "Während selektiver Planung Software-Pipelining äußerer Schleifen durchführen."
 
-#: common.opt:2240
+#: common.opt:2244
 msgid "Reschedule pipelined regions without pipelining."
 msgstr "Regionen mit Pipelining ohne Pipelining neu planen."
 
-#: common.opt:2244
+#: common.opt:2248
 msgid "Allow interposing function (or variables) by ones with different semantics (or initializer) respectively by dynamic linker."
 msgstr "Erlauben, dass der dynamische Linker Funktionen und Variablen mit solchen unterschiedlicher Semantik (oder Initialisierungen) gemischt platzieren darf."
 
-#: common.opt:2250
+#: common.opt:2254
 msgid "Allow premature scheduling of queued insns."
 msgstr "Nicht ausgereifte Planung von eingereihten Befehlen erlauben."
 
-#: common.opt:2254
+#: common.opt:2258
 msgid "-fsched-stalled-insns=<number>\tSet number of queued insns that can be prematurely scheduled."
 msgstr "-fsched-stalled-insns=<Anzahl>\tAnzahl der eingereihten Befehle festlegen, die unausgereift geplant werden können."
 
-#: common.opt:2262
+#: common.opt:2266
 msgid "Set dependence distance checking in premature scheduling of queued insns."
 msgstr "Prüfung der Abhängigkeitsentfernung in nicht ausgereifter Planung von eingereihten Befehlen festlegen."
 
-#: common.opt:2266
+#: common.opt:2270
 msgid "-fsched-stalled-insns-dep=<number>\tSet dependence distance checking in premature scheduling of queued insns."
 msgstr "-fsched-stalled-insns-dep=<Zahl>\tAbhängigkeitsentfernung für Prüfung in nicht ausgereifter Planung von eingereihten Befehlen festlegen."
 
-#: common.opt:2270
+#: common.opt:2274
 msgid "Enable the group heuristic in the scheduler."
 msgstr "Gruppenheuristik im Planer einschalten."
 
-#: common.opt:2274
+#: common.opt:2278
 msgid "Enable the critical path heuristic in the scheduler."
 msgstr "Critical-Path-Heuristik im Planer einschalten."
 
-#: common.opt:2278
+#: common.opt:2282
 msgid "Enable the speculative instruction heuristic in the scheduler."
 msgstr "Heuristik für spekulative Befehle im Planer einschalten."
 
-#: common.opt:2282
+#: common.opt:2286
 msgid "Enable the rank heuristic in the scheduler."
 msgstr "Rang-Heuristik im Planer einschalten."
 
-#: common.opt:2286
+#: common.opt:2290
 msgid "Enable the last instruction heuristic in the scheduler."
 msgstr "Heuristik für letzte Befehle im Planer einschalten."
 
-#: common.opt:2290
+#: common.opt:2294
 msgid "Enable the dependent count heuristic in the scheduler."
 msgstr "Heuristik für Abhängigkeits-Zähler bei Planung einschalten."
 
-#: common.opt:2294
+#: common.opt:2298
 msgid "Access data in the same section from shared anchor points."
 msgstr "Auf Daten im gleichen Abschnitt von gemeinsam verwendeten Ankerpunkten zugreifen."
 
-#: common.opt:2306
+#: common.opt:2310
 msgid "Turn on Redundant Extensions Elimination pass."
 msgstr "Durchlauf für Redundante Erweiterungsentfernung (REE) einschalten."
 
-#: common.opt:2310
+#: common.opt:2314
 msgid "Show column numbers in diagnostics, when available.  Default on."
 msgstr "Spaltenzahlen in Diagnose zeigen, wenn verfügbar. Standard: Ein."
 
-#: common.opt:2314
+#: common.opt:2318
 msgid "Emit function prologues only before parts of the function that need it, rather than at the top of the function."
 msgstr "Funktionsprologe nur vor Teilen der Funktion erzeugen, die diese benötigt, statt am Anfang der Funktion."
 
-#: common.opt:2319
+#: common.opt:2323
 msgid "Shrink-wrap parts of the prologue and epilogue separately."
 msgstr "Teile des Prologs und Epilogs separat an den nötigen Stellen erzeugen."
 
-#: common.opt:2323
+#: common.opt:2327
 msgid "Disable optimizations observable by IEEE signaling NaNs."
 msgstr "Von IEEE-Signalisierungs-NaNs wahrnehmbare Optimierungen ausschalten."
 
-#: common.opt:2327
+#: common.opt:2331
 msgid "Disable floating point optimizations that ignore the IEEE signedness of zero."
 msgstr "Gleitkommaoptimierungen ausschalten, die die IEEE-Vorzeichenbehaftung von Null nicht beachten."
 
-#: common.opt:2331
+#: common.opt:2335
 msgid "Convert floating point constants to single precision constants."
 msgstr "Gleitkommakonstanten in Konstanten einfacher Genauigkeit umwandeln."
 
-#: common.opt:2335
+#: common.opt:2339
 msgid "Split lifetimes of induction variables when loops are unrolled."
 msgstr "Lebensdauer von Induktionsvariablen aufteilen, wenn Schleifen abgerollt werden."
 
-#: common.opt:2339
+#: common.opt:2343
 msgid "Generate discontiguous stack frames."
 msgstr "Nicht zusammenhängende Stapelrahmen erzeugen."
 
-#: common.opt:2343
+#: common.opt:2347
 msgid "Split wide types into independent registers."
 msgstr "Breite Typen in unabhängige Register aufteilen."
 
-#: common.opt:2347
+#: common.opt:2351
 msgid "Enable backward propagation of use properties at the SSA level."
 msgstr "Rückwärtsübermittlung von Nutzungseigenschaften auf SSA-Ebene einschalten."
 
-#: common.opt:2351
+#: common.opt:2355
 msgid "Optimize conditional patterns using SSA PHI nodes."
 msgstr "Bedingte Ausdrücke mittels SSA-PHI-Knoten optimieren."
 
-#: common.opt:2355
+#: common.opt:2359
 msgid "Optimize amount of stdarg registers saved to stack at start of function."
 msgstr "Anzahl der stdarg-Register optimieren, die am Anfang einer Funktion auf dem Stapel gespeichert werden."
 
-#: common.opt:2359
+#: common.opt:2363
 msgid "Apply variable expansion when loops are unrolled."
 msgstr "Variablenerweiterung anwenden, wenn Schleifen abgerollt werden."
 
-#: common.opt:2363
+#: common.opt:2367
 msgid "-fstack-check=[no|generic|specific]\tInsert stack checking code into the program."
 msgstr "-fstack-check=[no|generic|specific]\tCode zur Stapelprüfung in das Programm einfügen."
 
-#: common.opt:2367
+#: common.opt:2371
 msgid "Insert stack checking code into the program.  Same as -fstack-check=specific."
 msgstr "Code zur Stapelprüfung in das Programm einfügen. Dasselbe wie -fstack-check=specific."
 
-#: common.opt:2371
+#: common.opt:2375
 msgid "Insert code to probe each page of stack space as it is allocated to protect from stack-clash style attacks."
 msgstr "Code einfügen, der jede Speicherseite des Stapels bei der Allokation antestet, um vor Angriffen basierend auf Überschneidungen zu schützen."
 
-#: common.opt:2379
+#: common.opt:2383
 msgid "-fstack-limit-register=<register>\tTrap if the stack goes past <register>."
 msgstr "-fstack-limit-register=<Register>\tWenn der Stapel über <Register> hinausgeht, abfangen (»trap«)."
 
-#: common.opt:2383
+#: common.opt:2387
 msgid "-fstack-limit-symbol=<name>\tTrap if the stack goes past symbol <name>."
 msgstr "-fstack-limit-symbol=<Name>\tWenn der Stapel über das Symbol <Name> hinausgeht, abfangen (»trap«)."
 
-#: common.opt:2387
+#: common.opt:2391
 msgid "Use propolice as a stack protection method."
 msgstr "Propolice als Stapelschutzmethode verwenden."
 
-#: common.opt:2391
+#: common.opt:2395
 msgid "Use a stack protection method for every function."
 msgstr "Eine Stapelschutzmethode für jede Funktion verwenden."
 
-#: common.opt:2395
+#: common.opt:2399
 msgid "Use a smart stack protection method for certain functions."
 msgstr "Eine schlaue Stapelschutzmethode für gewisse Funktionen verwenden."
 
-#: common.opt:2399
+#: common.opt:2403
 msgid "Use stack protection method only for functions with the stack_protect attribute."
 msgstr "Stapelschutzmethode nur für Funktionen mit dem Attribut »stack_protect« verwenden."
 
-#: common.opt:2403
+#: common.opt:2407
 msgid "Output stack usage information on a per-function basis."
 msgstr "Information über Stapelverwendung auf Funktionsbasis ausgeben."
 
-#: common.opt:2415
+#: common.opt:2419
 msgid "Assume strict aliasing rules apply."
 msgstr "Annehmen, dass strenge Alias-Regeln gelten."
 
-#: common.opt:2419
+#: common.opt:2423
 msgid "Treat signed overflow as undefined.  Negated as -fwrapv -fwrapv-pointer."
 msgstr "Vorzeichenbehafteten Überlauf als undefiniertes Verhalten behandeln. Wird mit -fwrapv -fwrapv-pointer negiert."
 
-#: common.opt:2423
+#: common.opt:2427
 msgid "Implement __atomic operations via libcalls to legacy __sync functions."
 msgstr "__atomic-Operationen über Bibliotheksaufrufe alter __sync-Funktionen durchführen."
 
-#: common.opt:2427
+#: common.opt:2431
 msgid "Check for syntax errors, then stop."
 msgstr "Auf Syntaxfehler prüfen, dann anhalten."
 
-#: common.opt:2431
+#: common.opt:2435
 msgid "Create data files needed by \"gcov\"."
 msgstr "Von »gcov« benötigte Dateien anlegen."
 
-#: common.opt:2435
+#: common.opt:2439
 msgid "Perform jump threading optimizations."
 msgstr "Sprung-Threading-Optimierungen durchführen."
 
-#: common.opt:2439
+#: common.opt:2443
 msgid "Report the time taken by each compiler pass."
 msgstr "Benötigte Zeit für jeden Compilerdurchlauf ausgeben."
 
-#: common.opt:2443
+#: common.opt:2447
 msgid "Record times taken by sub-phases separately."
 msgstr "Dauer der Teilphasen separat aufzeichnen."
 
-#: common.opt:2447
+#: common.opt:2451
 msgid "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tSet the default thread-local storage code generation model."
 msgstr "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tDas standardmäßige Codeerzeugungsmodell für Thread-lokalen Speicher angeben."
 
-#: common.opt:2450
+#: common.opt:2454
 #, c-format
 msgid "unknown TLS model %qs"
 msgstr "unbekanntes TLS-Modell %qs"
 
-#: common.opt:2466
+#: common.opt:2470
 msgid "Reorder top level functions, variables, and asms."
 msgstr "Funktionen, Variablen und asms höchster Ebene umordnen."
 
-#: common.opt:2470
+#: common.opt:2474
 msgid "Perform superblock formation via tail duplication."
 msgstr "Superblockerzeugung über Ende-Vervielfältigung durchführen."
 
-#: common.opt:2474
+#: common.opt:2478
 msgid "For targets that normally need trampolines for nested functions, always generate them instead of using descriptors."
 msgstr "Für Ziele, die normalerweise Trampoline für geschachtelte Funktionen benötigen, diese stets generieren, statt Deskriptoren zu verwenden."
 
-#: common.opt:2482
+#: common.opt:2486
 msgid "Assume floating-point operations can trap."
 msgstr "Annehmen, dass Gleitkommaoperationen abgefangen werden können (»trap«)."
 
-#: common.opt:2486
+#: common.opt:2490
 msgid "Trap for signed overflow in addition, subtraction and multiplication."
 msgstr "Vorzeichenbehafteten Überlauf in Addition, Subtraktion und Multiplikation abfangen (»trap«)."
 
-#: common.opt:2490
+#: common.opt:2494
 msgid "Enable SSA-CCP optimization on trees."
 msgstr "SSA-CCP-Optimierungen auf Bäumen einschalten."
 
-#: common.opt:2494
+#: common.opt:2498
 msgid "Enable SSA-BIT-CCP optimization on trees."
 msgstr "SSA-BIT-CCP-Optimierungen auf Bäumen einschalten."
 
-#: common.opt:2502
+#: common.opt:2506
 msgid "Enable loop header copying on trees."
 msgstr "Kopieren des Schleifenkopfes auf Bäumen einschalten."
 
-#: common.opt:2510
+#: common.opt:2514
 msgid "Enable SSA coalescing of user variables."
 msgstr "Zusammenfassen von nutzersichtbaren Variablen während des SSA-Durchlaufs einschalten."
 
-#: common.opt:2518
+#: common.opt:2522
 msgid "Enable copy propagation on trees."
 msgstr "Kopieweitergabe auf Bäumen einschalten."
 
-#: common.opt:2526
+#: common.opt:2530
 msgid "Transform condition stores into unconditional ones."
 msgstr "Bedingte Speicherbefehle in unbedingte umwandeln."
 
-#: common.opt:2530
+#: common.opt:2534
 msgid "Perform conversions of switch initializations."
 msgstr "Umwandlungen von »switch«-Initialisierungen durchführen."
 
-#: common.opt:2534
+#: common.opt:2538
 msgid "Enable SSA dead code elimination optimization on trees."
 msgstr "Beseitigungsoptimierung für toten SSA-Code auf Bäumen einschalten."
 
-#: common.opt:2538
+#: common.opt:2542
 msgid "Enable dominator optimizations."
 msgstr "Dominator-Optimierungen einschalten."
 
-#: common.opt:2542
+#: common.opt:2546
 msgid "Enable tail merging on trees."
 msgstr "Enden-Zusammenfassung auf Bäumen einschalten."
 
-#: common.opt:2546
+#: common.opt:2550
 msgid "Enable dead store elimination."
 msgstr "Entfernung toter Speicherungen einschalten."
 
-#: common.opt:2550
+#: common.opt:2554
 msgid "Enable forward propagation on trees."
 msgstr "Vorwärts-Übertragung auf Bäumen einschalten."
 
-#: common.opt:2554
+#: common.opt:2558
 msgid "Enable Full Redundancy Elimination (FRE) on trees."
 msgstr "Vollständige Redundanzentfernung (FRE) auf Bäumen einschalten."
 
-#: common.opt:2558
+#: common.opt:2562
 msgid "Enable string length optimizations on trees."
 msgstr "Zeichenkettenlängen-Optimierungen auf Bäumen einschalten."
 
-#: common.opt:2562
+#: common.opt:2566
 msgid "Detect paths that trigger erroneous or undefined behavior due to dereferencing a null pointer.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr "Ausführungspfade erkennen, die durch Dereferenzieren eines Nullzeigers fehlerhaftes oder undefiniertes Verhalten auslösen. Solche Pfade werden aus dem Hauptablauf herausgenommen und durch eine Trap ersetzt."
 
-#: common.opt:2568
+#: common.opt:2572
 msgid "Detect paths that trigger erroneous or undefined behavior due to a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr "Ausführungspfade erkennen, die ausgelöst werden, indem ein Nullwert auf eine Weise verwendet wird, die durch ein »returns_nonnull«- oder »nonnull«-Attribut verboten ist. Solche Pfade werden aus dem Hauptablauf herausgenommen und durch eine Trap ersetzt."
 
-#: common.opt:2575
+#: common.opt:2579
 msgid "Enable loop distribution on trees."
 msgstr "Schleifenverteilung auf Bäumen einschalten."
 
-#: common.opt:2579
+#: common.opt:2583
 msgid "Enable loop distribution for patterns transformed into a library call."
 msgstr "Schleifenverteilung für in Bibliotheksaufruf umgewandelte Muster einschalten."
 
-#: common.opt:2583
+#: common.opt:2587
 msgid "Enable loop invariant motion on trees."
 msgstr "Bewegung der Schleifeninvariante auf Bäumen einschalten."
 
-#: common.opt:2591
+#: common.opt:2595
 msgid "Create canonical induction variables in loops."
 msgstr "Kanonische Induktionsvariablen in Schleifen erzeugen."
 
-#: common.opt:2595
+#: common.opt:2599
 msgid "Enable loop optimizations on tree level."
 msgstr "Schleifenoptimierungen auf Baumebene einschalten."
 
-#: common.opt:2599
+#: common.opt:2603
 msgid "-ftree-parallelize-loops=<number>\tEnable automatic parallelization of loops."
 msgstr "-ftree-parallelize-loops=<Anzahl>\tAutomatische Parallelisierung von Schleifen einschalten."
 
-#: common.opt:2603
+#: common.opt:2607
 msgid "Enable hoisting loads from conditional pointers."
 msgstr "Herausziehen von Ladeoperationen aus bedingten Zeigern einschalten."
 
-#: common.opt:2607
+#: common.opt:2611
 msgid "Enable SSA-PRE optimization on trees."
 msgstr "SSA-PRE-Optimierungen auf Bäumen einschalten."
 
-#: common.opt:2611
+#: common.opt:2615
 msgid "In SSA-PRE optimization on trees, enable partial-partial redundancy elimination."
 msgstr "In SSA-PRE-Optimierungen auf Bäumen Teils-Teils-Redundanz eliminieren."
 
-#: common.opt:2615
+#: common.opt:2619
 msgid "Perform function-local points-to analysis on trees."
 msgstr "Funktionslokale Analyse von Zeigerzielen auf Bäumen durchführen."
 
-#: common.opt:2619
+#: common.opt:2623
 msgid "Enable reassociation on tree level."
 msgstr "Neuverbindung auf Baumebene einschalten."
 
-#: common.opt:2627
+#: common.opt:2631
 msgid "Enable SSA code sinking on trees."
 msgstr "SSA-Codeversenkung auf Bäumen einschalten."
 
-#: common.opt:2631
+#: common.opt:2635
 msgid "Perform straight-line strength reduction."
 msgstr "Geradlinige Stärkereduktion durchführen."
 
-#: common.opt:2635
+#: common.opt:2639
 msgid "Perform scalar replacement of aggregates."
 msgstr "Skalarersetzung von Aggregaten durchführen."
 
-#: common.opt:2639
+#: common.opt:2643
 msgid "Replace temporary expressions in the SSA->normal pass."
 msgstr "Vorübergehende Ausdrücke im SSA->Normal-Durchlauf ersetzen."
 
-#: common.opt:2643
+#: common.opt:2647
 msgid "Perform live range splitting during the SSA->normal pass."
 msgstr "Lebensdaueraufteilung während des »SSA -> Normal«-Durchlaufs durchführen."
 
-#: common.opt:2647
+#: common.opt:2651
 msgid "Perform Value Range Propagation on trees."
 msgstr "Wertebereichsweitergabe auf Bäumen durchführen."
 
-#: common.opt:2651
+#: common.opt:2655
 msgid "Split paths leading to loop backedges."
 msgstr "Pfade aufteilen, die zu Schleifen-Rückkanten führen."
 
-#: common.opt:2655
+#: common.opt:2659
 msgid "Assume common declarations may be overridden with ones with a larger trailing array."
 msgstr "Annehmen, dass gemeinsame Deklarationen durch solche übersteuert werden dürfen, die ein längeres hintangestelltes Array haben."
 
-#: common.opt:2660
+#: common.opt:2664
 msgid "Compile whole compilation unit at a time."
 msgstr "Ganze Übersetzungseinheit auf einmal übersetzen."
 
-#: common.opt:2664
+#: common.opt:2668
 msgid "Perform loop unrolling when iteration count is known."
 msgstr "Schleifenabwicklung durchführen, wenn Anzahl der Wiederholungen bekannt ist."
 
-#: common.opt:2668
+#: common.opt:2672
 msgid "Perform loop unrolling for all loops."
 msgstr "Schleifenabwicklung für alle Schleifen durchführen."
 
-#: common.opt:2679
+#: common.opt:2683
 msgid "Allow optimization for floating-point arithmetic which may change the result of the operation due to rounding."
 msgstr "Optimierung für Gleitkommaarithmetik erlauben, auch wenn durch Runden ein anderes Ergebnis herauskommen kann."
 
-#: common.opt:2684
+#: common.opt:2688
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr "Das gleiche wie -fassociative-math für Ausdrücke, die Division enthalten."
 
-#: common.opt:2692
+#: common.opt:2696
 msgid "Allow math optimizations that may violate IEEE or ISO standards."
 msgstr "Mathematische Optimierungen erlauben, die IEEE- oder ISO-Standards verletzen könnten."
 
-#: common.opt:2696
+#: common.opt:2700
 msgid "Perform loop unswitching."
 msgstr "Schleifenausschaltung durchführen."
 
-#: common.opt:2700
+#: common.opt:2704
 msgid "Perform loop splitting."
 msgstr "Schleifen-Aufteilung durchführen."
 
-#: common.opt:2704
+#: common.opt:2708
 msgid "Just generate unwind tables for exception handling."
 msgstr "Einfach Abwicklungstabellen für Ausnahmebehandlung erzeugen."
 
-#: common.opt:2708
+#: common.opt:2712
 msgid "Use the bfd linker instead of the default linker."
 msgstr "BFD-Linker statt Standardlinker verwenden."
 
-#: common.opt:2712
+#: common.opt:2716
 msgid "Use the gold linker instead of the default linker."
 msgstr "Gold-Linker statt Standardlinker verwenden."
 
-#: common.opt:2724
+#: common.opt:2728
 msgid "Perform variable tracking."
 msgstr "Variablenverfolgung durchführen."
 
-#: common.opt:2732
+#: common.opt:2736
 msgid "Perform variable tracking by annotating assignments."
 msgstr "Variablenverfolgung durch Zuweisungsanmerkungen durchführen."
 
-#: common.opt:2738
+#: common.opt:2742
 msgid "Toggle -fvar-tracking-assignments."
 msgstr "-fvar-tracking-assignments umschalten."
 
-#: common.opt:2746
+#: common.opt:2750
 msgid "Perform variable tracking and also tag variables that are uninitialized."
 msgstr "Variablenverfolgung durchführen und auch Variablen markieren, die uninitialisiert sind."
 
-#: common.opt:2751
+#: common.opt:2755
 msgid "Enable vectorization on trees."
 msgstr "Vektorisierung auf Bäumen einschalten."
 
-#: common.opt:2759
+#: common.opt:2763
 msgid "Enable loop vectorization on trees."
 msgstr "Schleifenvektorisierung auf Bäumen einschalten."
 
-#: common.opt:2763
+#: common.opt:2767
 msgid "Enable basic block vectorization (SLP) on trees."
 msgstr "Vektorisierung von Basisblöcken (SLP) auf Bäumen einschalten."
 
-#: common.opt:2767
+#: common.opt:2771
 msgid "Specifies the cost model for vectorization. -fvect-cost-model=[unlimited|dynamic|cheap]\tSpecifies the cost model for vectorization."
 msgstr "Kostenmodell für Vektorisierung angeben. -fvect-cost-model=[unlimited|dynamic|cheap]\tKostenmodell für Vektorisierung angeben."
 
-#: common.opt:2772
+#: common.opt:2776
 msgid "-fsimd-cost-model=[unlimited|dynamic|cheap]\tSpecifies the vectorization cost model for code marked with a simd directive."
 msgstr "-fsimd-cost-model=[unlimited|dynamic|cheap]\tVektorisierungs-Kostenmodell angeben, das für mit einer SIMD-Direktive markierten Code verwendet wird."
 
-#: common.opt:2775
+#: common.opt:2779
 #, c-format
 msgid "unknown vectorizer cost model %qs"
 msgstr "Unbekanntes Vektorisierer-Kostenmodell %qs"
 
-#: common.opt:2788
+#: common.opt:2792
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr "Schaltet das dynamische Vektorisierer-Kostenmodell ein. Für Rückwärtskompatibilität erhalten."
 
-#: common.opt:2796
+#: common.opt:2800
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr "Kopieweitergabe von Informationen über Skalar-Evolution einschalten."
 
-#: common.opt:2806
+#: common.opt:2810
 msgid "Add extra commentary to assembler output."
 msgstr "Zusätzliche Anmerkungen an Assemblerausgabe anfügen."
 
-#: common.opt:2810
+#: common.opt:2814
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility."
 msgstr "-fvisibility=[default|internal|hidden|protected]\tStandard-Symbolsichtbarkeit festlegen."
 
-#: common.opt:2813
+#: common.opt:2817
 #, c-format
 msgid "unrecognized visibility value %qs"
 msgstr "unbekannter Sichtbarkeitswert %qs"
 
-#: common.opt:2829
+#: common.opt:2833
 msgid "Validate vtable pointers before using them."
 msgstr "VTable-Zeiger validieren, bevor sie verwendet werden."
 
-#: common.opt:2832
+#: common.opt:2836
 #, c-format
 msgid "unknown vtable verify initialization priority %qs"
 msgstr "Unbekannte Initialisierungspriorität %qs für VTable-Verifikation"
 
-#: common.opt:2845
+#: common.opt:2849
 msgid "Output vtable verification counters."
 msgstr "Verifikationszähler für VTables ausgeben."
 
-#: common.opt:2849
+#: common.opt:2853
 msgid "Output vtable verification pointer sets information."
 msgstr "Informationen über Zeigermengen der VTable-Verifikation ausgeben."
 
-#: common.opt:2853
+#: common.opt:2857
 msgid "Use expression value profiles in optimizations."
 msgstr "Profile von Ausdruckswerten in Optimierungen verwenden."
 
-#: common.opt:2857
+#: common.opt:2861
 msgid "Construct webs and split unrelated uses of single variable."
 msgstr "Netze konstruieren und nicht zusammenhängende Verwendungen einzelner Variablen aufteilen."
 
-#: common.opt:2861
+#: common.opt:2865
 msgid "Enable conditional dead code elimination for builtin calls."
 msgstr "Beseitigung von bedingt totem Code für Aufrufe eingebauter Funktionen einschalten."
 
-#: common.opt:2865
+#: common.opt:2869
 msgid "Perform whole program optimizations."
 msgstr "Gesamtprogrammoptimierung durchführen."
 
-#: common.opt:2869
+#: common.opt:2873
 msgid "Assume pointer overflow wraps around."
 msgstr "Annehmen, dass Zeigerüberläufe überschlagen (Wraparound)."
 
-#: common.opt:2873
+#: common.opt:2877
 msgid "Assume signed arithmetic overflow wraps around."
 msgstr "Annehmen, dass vorzeichenbehaftete arithmetische Überläufe regulär überschlagen (Wraparound)."
 
-#: common.opt:2877
+#: common.opt:2881
 msgid "Put zero initialized data in the bss section."
 msgstr "Null-initialisierte Daten in den bss-Abschnitt legen."
 
-#: common.opt:2881
+#: common.opt:2885
 msgid "Generate debug information in default format."
 msgstr "Fehlersuchinformationen im Standardformat erzeugen."
 
-#: common.opt:2885
+#: common.opt:2889
 msgid "Assume assembler support for (DWARF2+) .loc directives"
 msgstr "Assembler-Unterstützung für (DWARF2+-).loc-Direktiven annehmen"
 
-#: common.opt:2889
+#: common.opt:2893
 msgid "Assume assembler support for view in (DWARF2+) .loc directives"
 msgstr "Assembler-Unterstützung für Ansicht in (DWARF2+-).loc-Direktiven annehmen"
 
-#: common.opt:2892 common.opt:2896 common.opt:2900 common.opt:2904
+#: common.opt:2896 common.opt:2900 common.opt:2904 common.opt:2908
 #, c-format
 msgid "switch %qs no longer supported"
 msgstr "Schalter %qs wird nicht mehr unterstützt"
 
-#: common.opt:2909
+#: common.opt:2913
 msgid "Record DW_AT_decl_column and DW_AT_call_column in DWARF."
 msgstr "DW_AT_decl_column und DW_AT_call_column in DWARF aufzeichnen."
 
-#: common.opt:2913
+#: common.opt:2917
 msgid "Generate debug information in default version of DWARF format."
 msgstr "Fehlersuchinformationen im Standardversion des DWARF-Formats erzeugen."
 
-#: common.opt:2917
+#: common.opt:2921
 msgid "Generate debug information in DWARF v2 (or later) format."
 msgstr "Fehlersuchinformationen im DWARF-v2-Format (oder neuer) erzeugen."
 
-#: common.opt:2921
+#: common.opt:2925
 msgid "Generate debug information in default extended format."
 msgstr "Fehlersuchinformationen im erweiterten Standardformat erzeugen."
 
-#: common.opt:2925
+#: common.opt:2929
 msgid "Generate extended entry point information for inlined functions"
 msgstr "Erweiterte Informationen für Einsprungpunkt für inline-Funktionen erzeugen"
 
-#: common.opt:2929
+#: common.opt:2933
 msgid "Compute locview reset points based on insn length estimates"
 msgstr "Locview-Rücksetzpunkte auf Basis der geschätzten Befehlslängen berechnen"
 
-#: common.opt:2937
+#: common.opt:2941
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr "Keine DWARF-Abschnitte für Pubnames und Pubtypes erzeugen."
 
-#: common.opt:2941
+#: common.opt:2945
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr "DWARF-Abschnitte für Pubnames und Pubtypes erzeugen."
 
-#: common.opt:2945
+#: common.opt:2949
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr "DWARF-Abschnitte für Pubnames und Pubtypes mit GNU-Erweiterungen erzeugen."
 
-#: common.opt:2949
+#: common.opt:2953
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr "GCC-Kommandozeilenschalter in DWARF DW_AT_producer aufzeichnen."
 
-#: common.opt:2953
+#: common.opt:2957
 msgid "Generate debug information in separate .dwo files."
 msgstr "Fehlersuchinformationen in separaten .dwo-Dateien erzeugen."
 
-#: common.opt:2957
+#: common.opt:2961
 msgid "Generate debug information in STABS format."
 msgstr "Fehlersuchinformationen im STABS-Format erzeugen."
 
-#: common.opt:2961
+#: common.opt:2965
 msgid "Generate debug information in extended STABS format."
 msgstr "Fehlersuchinformationen im erweiterten STABS-Format erzeugen."
 
-#: common.opt:2965
+#: common.opt:2969
 msgid "Emit progressive recommended breakpoint locations."
 msgstr "Progressive empfohlene Breakpoint-Stellen ausgeben."
 
-#: common.opt:2969
+#: common.opt:2973
 msgid "Don't emit DWARF additions beyond selected version."
 msgstr "Keine DWARF-Ergänzungen über gewählte Version hinaus erzeugen."
 
-#: common.opt:2973
+#: common.opt:2977
 msgid "Toggle debug information generation."
 msgstr "Erzeugung von Fehlersuchinformationen umschalten."
 
-#: common.opt:2977
+#: common.opt:2981
 msgid "Augment variable location lists with progressive views."
 msgstr "Adresslisten der Variablen mit progressiven Sichten anreichern."
 
-#: common.opt:2984
+#: common.opt:2988
 msgid "Generate debug information in VMS format."
 msgstr "Fehlersuchinformationen im VMS-Format erzeugen."
 
-#: common.opt:2988
+#: common.opt:2992
 msgid "Generate debug information in XCOFF format."
 msgstr "Fehlersuchinformationen im XCOFF-Format erzeugen."
 
-#: common.opt:2992
+#: common.opt:2996
 msgid "Generate debug information in extended XCOFF format."
 msgstr "Fehlersuchinformationen im erweiterten XCOFF-Format erzeugen."
 
-#: common.opt:3010
+#: common.opt:3014
 msgid "Generate compressed debug sections."
 msgstr "Komprimierte Fehlersuchinformationen erzeugen."
 
-#: common.opt:3014
+#: common.opt:3018
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>."
 msgstr "-gz=<Format>\tKomprimierte Debugabschnitte im Format <Format> erzeugen."
 
-#: common.opt:3021
+#: common.opt:3025
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory."
 msgstr "-iplugindir=<Verz>\t<Verz> als Standard-Plugin-Verzeichnis festlegen."
 
-#: common.opt:3025
+#: common.opt:3029
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory."
 msgstr "-imultiarch <Verzeichnis>\t<Verzeichnis> als Multiarch-include-Verzeichnis festlegen."
 
-#: common.opt:3047
+#: common.opt:3051
 msgid "-o <file>\tPlace output into <file>."
 msgstr "-o <Datei>\tAusgabe in <Datei> schreiben."
 
-#: common.opt:3051
+#: common.opt:3055
 msgid "Enable function profiling."
 msgstr "Funktionsprofilierung einschalten."
 
-#: common.opt:3061
+#: common.opt:3065
 msgid "Like -pedantic but issue them as errors."
 msgstr "Wie -pedantic, aber als Fehler ausgeben."
 
-#: common.opt:3101
+#: common.opt:3105
 msgid "Do not display functions compiled or elapsed time."
 msgstr "Übersetzte Funktionen oder verstrichene Zeit nicht ausgeben."
 
-#: common.opt:3133
+#: common.opt:3137
 msgid "Enable verbose output."
 msgstr "Wortreiche Ausgabe einschalten."
 
-#: common.opt:3137
+#: common.opt:3141
 msgid "Display the compiler's version."
 msgstr "Compiler-Version anzeigen."
 
-#: common.opt:3141
+#: common.opt:3145
 msgid "Suppress warnings."
 msgstr "Warnungen unterdrücken."
 
-#: common.opt:3151
+#: common.opt:3155
 msgid "Create a shared library."
 msgstr "Shared Library erzeugen."
 
-#: common.opt:3196
+#: common.opt:3200
 msgid "Don't create a dynamically linked position independent executable."
 msgstr "Keine dynamisch gebundene, lageunabhängige ausführbare Datei erzeugen."
 
-#: common.opt:3200
+#: common.opt:3204
 msgid "Create a dynamically linked position independent executable."
 msgstr "Dynamisch gebundene, lageunabhängige ausführbare Datei erzeugen."
 
-#: common.opt:3204
+#: common.opt:3208
 msgid "Create a static position independent executable."
 msgstr "Statische, lageunabhängige ausführbare Datei erzeugen."
 
-#: common.opt:3211
+#: common.opt:3215
 msgid "Use caller save register across calls if possible."
 msgstr "Vom Aufrufer zu sichernde Register über Aufrufe hinweg verwenden, wenn möglich."
 
-#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:598 cp/cvt.c:1308
+#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:599 cp/cvt.c:1308
 #: cp/cvt.c:1561
 #, gcc-internal-format
 msgid "value computed is not used"
@@ -15680,7 +15681,7 @@
 msgstr "boolescher Typ erwartet"
 
 #: go/gofrontend/expressions.cc:4331 c/c-parser.c:13477 c/c-parser.c:13484
-#: cp/parser.c:33264 cp/parser.c:33271
+#: cp/parser.c:33261 cp/parser.c:33268
 #, gcc-internal-format
 msgid "expected integer"
 msgstr "Ganzzahl erwartet"
@@ -16095,14 +16096,14 @@
 msgid "ignoring attribute %qE because it conflicts with attribute %qs"
 msgstr "Attribut %qE steht mit Attribut %qs in Konflikt; wird ignoriert"
 
-#: attribs.c:449 c-family/c-attribs.c:1894 cp/decl.c:13690 cp/friend.c:302
-#: cp/tree.c:4559
+#: attribs.c:449 c-family/c-attribs.c:1905 cp/decl.c:13714 cp/friend.c:302
+#: cp/tree.c:4607
 #, gcc-internal-format
 msgid "previous declaration here"
 msgstr "vorherige Deklaration hier"
 
 #. Warn about and ignore all others for now, but store them.
-#: attribs.c:564 c-family/c-attribs.c:2717 objc/objc-act.c:4963
+#: attribs.c:564 c-family/c-attribs.c:2728 objc/objc-act.c:4963
 #: objc/objc-act.c:6932 objc/objc-act.c:8119 objc/objc-act.c:8170
 #, gcc-internal-format
 msgid "%qE attribute directive ignored"
@@ -16121,17 +16122,17 @@
 #. This is a c++11 attribute that appertains to a
 #. type-specifier, outside of the definition of, a class
 #. type.  Ignore it.
-#: attribs.c:590 cp/decl.c:10999
+#: attribs.c:590 cp/decl.c:11023
 #, gcc-internal-format
 msgid "attribute ignored"
 msgstr "Attribut wird ignoriert"
 
-#: attribs.c:592 cp/decl.c:11000
+#: attribs.c:592 cp/decl.c:11024
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr "ein Attribut, das sich auf eine Typspezifizierung bezieht, wird ignoriert"
 
-#: attribs.c:610 c-family/c-attribs.c:3219
+#: attribs.c:610 c-family/c-attribs.c:3230
 #, gcc-internal-format
 msgid "%qE attribute does not apply to types"
 msgstr "Attribut %qE kann nicht auf Typen angewandt werden"
@@ -16147,40 +16148,40 @@
 msgstr "Typattribute ignoriert, nachdem Typ bereits definiert ist"
 
 #: attribs.c:691 attribs.c:1622 attribs.c:1632 attribs.c:1642
-#: c-family/c-attribs.c:540 c-family/c-attribs.c:559 c-family/c-attribs.c:577
-#: c-family/c-attribs.c:607 c-family/c-attribs.c:628 c-family/c-attribs.c:649
-#: c-family/c-attribs.c:690 c-family/c-attribs.c:717 c-family/c-attribs.c:733
-#: c-family/c-attribs.c:750 c-family/c-attribs.c:766 c-family/c-attribs.c:792
-#: c-family/c-attribs.c:807 c-family/c-attribs.c:835 c-family/c-attribs.c:852
-#: c-family/c-attribs.c:870 c-family/c-attribs.c:893 c-family/c-attribs.c:931
-#: c-family/c-attribs.c:954 c-family/c-attribs.c:971 c-family/c-attribs.c:1000
-#: c-family/c-attribs.c:1021 c-family/c-attribs.c:1042
-#: c-family/c-attribs.c:1069 c-family/c-attribs.c:1099
-#: c-family/c-attribs.c:1136 c-family/c-attribs.c:1189
-#: c-family/c-attribs.c:1255 c-family/c-attribs.c:1313
-#: c-family/c-attribs.c:1402 c-family/c-attribs.c:1432
-#: c-family/c-attribs.c:1483 c-family/c-attribs.c:1998
-#: c-family/c-attribs.c:2035 c-family/c-attribs.c:2096
-#: c-family/c-attribs.c:2152 c-family/c-attribs.c:2230
-#: c-family/c-attribs.c:2312 c-family/c-attribs.c:2371
-#: c-family/c-attribs.c:2390 c-family/c-attribs.c:2498
-#: c-family/c-attribs.c:2514 c-family/c-attribs.c:2530
-#: c-family/c-attribs.c:2551 c-family/c-attribs.c:2608
-#: c-family/c-attribs.c:2635 c-family/c-attribs.c:2690
-#: c-family/c-attribs.c:2870 c-family/c-attribs.c:2891
-#: c-family/c-attribs.c:3004 c-family/c-attribs.c:3031
-#: c-family/c-attribs.c:3221 c-family/c-attribs.c:3239
-#: c-family/c-attribs.c:3262 c-family/c-attribs.c:3301
-#: c-family/c-attribs.c:3383 c-family/c-attribs.c:3439
-#: c-family/c-attribs.c:3455 c-family/c-attribs.c:3549
-#: c-family/c-common.c:5600 config/darwin.c:2072 config/arm/arm.c:6868
+#: c-family/c-attribs.c:547 c-family/c-attribs.c:566 c-family/c-attribs.c:584
+#: c-family/c-attribs.c:614 c-family/c-attribs.c:635 c-family/c-attribs.c:656
+#: c-family/c-attribs.c:697 c-family/c-attribs.c:728 c-family/c-attribs.c:744
+#: c-family/c-attribs.c:761 c-family/c-attribs.c:777 c-family/c-attribs.c:803
+#: c-family/c-attribs.c:818 c-family/c-attribs.c:846 c-family/c-attribs.c:863
+#: c-family/c-attribs.c:881 c-family/c-attribs.c:904 c-family/c-attribs.c:942
+#: c-family/c-attribs.c:965 c-family/c-attribs.c:982 c-family/c-attribs.c:1011
+#: c-family/c-attribs.c:1032 c-family/c-attribs.c:1053
+#: c-family/c-attribs.c:1080 c-family/c-attribs.c:1110
+#: c-family/c-attribs.c:1147 c-family/c-attribs.c:1200
+#: c-family/c-attribs.c:1266 c-family/c-attribs.c:1324
+#: c-family/c-attribs.c:1413 c-family/c-attribs.c:1443
+#: c-family/c-attribs.c:1494 c-family/c-attribs.c:2009
+#: c-family/c-attribs.c:2046 c-family/c-attribs.c:2107
+#: c-family/c-attribs.c:2163 c-family/c-attribs.c:2241
+#: c-family/c-attribs.c:2323 c-family/c-attribs.c:2382
+#: c-family/c-attribs.c:2401 c-family/c-attribs.c:2509
+#: c-family/c-attribs.c:2525 c-family/c-attribs.c:2541
+#: c-family/c-attribs.c:2562 c-family/c-attribs.c:2619
+#: c-family/c-attribs.c:2646 c-family/c-attribs.c:2701
+#: c-family/c-attribs.c:2881 c-family/c-attribs.c:2902
+#: c-family/c-attribs.c:3015 c-family/c-attribs.c:3042
+#: c-family/c-attribs.c:3232 c-family/c-attribs.c:3250
+#: c-family/c-attribs.c:3273 c-family/c-attribs.c:3312
+#: c-family/c-attribs.c:3394 c-family/c-attribs.c:3450
+#: c-family/c-attribs.c:3466 c-family/c-attribs.c:3560
+#: c-family/c-common.c:5598 config/darwin.c:2072 config/arm/arm.c:6868
 #: config/arm/arm.c:6896 config/arm/arm.c:6913 config/avr/avr.c:9698
-#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6497
-#: config/i386/i386.c:41520 config/ia64/ia64.c:788
-#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33056
-#: config/spu/spu.c:3743 ada/gcc-interface/utils.c:6244
-#: ada/gcc-interface/utils.c:6261 ada/gcc-interface/utils.c:6277
-#: ada/gcc-interface/utils.c:6303 brig/brig-lang.c:476 lto/lto-lang.c:283
+#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6500
+#: config/i386/i386.c:41514 config/ia64/ia64.c:788
+#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33112
+#: config/spu/spu.c:3743 ada/gcc-interface/utils.c:6249
+#: ada/gcc-interface/utils.c:6266 ada/gcc-interface/utils.c:6282
+#: ada/gcc-interface/utils.c:6308 brig/brig-lang.c:476 lto/lto-lang.c:283
 #, gcc-internal-format
 msgid "%qE attribute ignored"
 msgstr "Attribut %qE wird ignoriert"
@@ -16548,88 +16549,103 @@
 msgid "%Kattempt to free a non-heap object"
 msgstr "%KVersuch, Nicht-Heap-Objekt freizugeben"
 
-#: calls.c:1434
+#: calls.c:1291 file-prefix-map.c:50
 #, gcc-internal-format
+msgid "invalid argument %qs to %qs"
+msgstr "ungültiges Argument %qs für %qs"
+
+#: calls.c:1452
+#, gcc-internal-format
 msgid "%Kargument %i value %qE is negative"
 msgstr "%KArgument %i Wert %qE ist negativ"
 
-#: calls.c:1452
+#: calls.c:1470
 #, gcc-internal-format
 msgid "%Kargument %i value is zero"
 msgstr "%KArgument %i Wert ist null"
 
-#: calls.c:1469
+#: calls.c:1487
 #, gcc-internal-format
 msgid "%Kargument %i value %qE exceeds maximum object size %E"
 msgstr "%KArgument %i Wert %qE übersteigt maximale Objektgröße %E"
 
-#: calls.c:1483
+#: calls.c:1501
 #, gcc-internal-format
 msgid "%Kargument %i range [%E, %E] is negative"
 msgstr "%KArgument %i Bereich [%E, %E] ist negativ"
 
-#: calls.c:1490
+#: calls.c:1508
 #, gcc-internal-format
 msgid "%Kargument %i range [%E, %E] exceeds maximum object size %E"
 msgstr "%KArgument %i Bereich [%E, %E] übersteigt maximal Objektgröße %E"
 
-#: calls.c:1520
+#: calls.c:1538
 #, gcc-internal-format
 msgid "%Kproduct %<%E * %E%> of arguments %i and %i exceeds %<SIZE_MAX%>"
 msgstr "%KProdukt %<%E * %E%> der Argumente %i und %i überschreitet %<SIZE_MAX%>"
 
-#: calls.c:1526
+#: calls.c:1544
 #, gcc-internal-format
 msgid "%Kproduct %<%E * %E%> of arguments %i and %i exceeds maximum object size %E"
 msgstr "%KProdukt %<%E * %E%> der Argumente %i und %i überschreitet maximale Objektgröße %E"
 
-#: calls.c:1537 calls.c:1540
+#: calls.c:1555 calls.c:1558
 #, gcc-internal-format
 msgid "argument %i in the range [%E, %E]"
 msgstr "Argument %i im Bereich [%E, %E]"
 
-#: calls.c:1551
+#: calls.c:1569
 #, gcc-internal-format
 msgid "in a call to built-in allocation function %qD"
 msgstr "in einem Aufruf der eingebauten Allokationsfunktion %qD"
 
-#: calls.c:1554
+#: calls.c:1572
 #, gcc-internal-format
 msgid "in a call to allocation function %qD declared here"
 msgstr "in einem Aufruf der hier deklarierten Allokationsfunktion %qD"
 
-#: calls.c:1711
+#: calls.c:1835
 #, gcc-internal-format
-msgid "%qD argument %i declared attribute %<nonstring%> is smaller than the specified bound %E"
-msgstr "%qD Argument %i (als Attribut %<nonstring%> deklariert) ist kleiner als die angegebene Grenze %E"
+msgid "%qD argument %i declared attribute %<nonstring%> is smaller than the specified bound %wu"
+msgstr "%qD Argument %i (als Attribut %<nonstring%> deklariert) ist kleiner als die angegebene Grenze %wu"
 
-#: calls.c:1716
+#: calls.c:1841
 #, gcc-internal-format
+msgid "%qD argument %i declared attribute %<nonstring%> is smaller than the specified bound [%E, %E]"
+msgstr "%qD Argument %i (als Attribut %<nonstring%> deklariert) ist kleiner als die angegebene Grenze [%E, %E]"
+
+#: calls.c:1847
+#, gcc-internal-format
+msgid "%qD argument %i declared attribute %<nonstring%> may be smaller than the specified bound [%E, %E]"
+msgstr "%qD Argument %i (als Attribut %<nonstring%> deklariert) ist möglicherweise kleiner als die angegebene Grenze [%E, %E]"
+
+#: calls.c:1857
+#, gcc-internal-format
 msgid "%qD argument %i declared attribute %<nonstring%>"
 msgstr "%qD Argument %i ist als Attribut %<nonstring%> deklariert"
 
-#: calls.c:1721
+#: calls.c:1862
 #, gcc-internal-format
 msgid "argument %qD declared here"
 msgstr "Argument %qD ist hier deklariert"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=80188
-#: calls.c:1735
+#: calls.c:1876
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot tail-call: %s"
 msgstr "Tail-Call nicht möglich: %s"
 
-#: calls.c:3365
+#: calls.c:3506
 #, gcc-internal-format
 msgid "function call has aggregate value"
 msgstr "Funktionsaufruf hat zusammengesetzten Wert"
 
-#: calls.c:4059
+#: calls.c:4200
 #, gcc-internal-format
 msgid "passing too large argument on stack"
 msgstr "Übergabe von zu großem Argument auf dem Stapel"
 
-#: cfgexpand.c:1665 function.c:1002 varasm.c:2231
+#: cfgexpand.c:1665 function.c:1002 varasm.c:2242
 #, gcc-internal-format
 msgid "size of variable %q+D is too large"
 msgstr "Größe der Variablen %q+D ist zu hoch"
@@ -17201,237 +17217,237 @@
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr "Interner Fehler: number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 
-#: cgraph.c:3051
+#: cgraph.c:3056
 #, gcc-internal-format
 msgid "caller edge count invalid"
 msgstr "Interner Fehler: caller edge count invalid"
 
-#: cgraph.c:3135
+#: cgraph.c:3140
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr "Interner Fehler: aux field set for edge %s->%s"
 
-#: cgraph.c:3142
+#: cgraph.c:3147
 #, gcc-internal-format
 msgid "cgraph count invalid"
 msgstr "Interner Fehler: cgraph count invalid"
 
-#: cgraph.c:3147
+#: cgraph.c:3152
 #, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr "Interner Fehler: inline clone in same comdat group list"
 
-#: cgraph.c:3152
+#: cgraph.c:3157
 #, gcc-internal-format
 msgid "local symbols must be defined"
 msgstr "Interner Fehler: local symbols must be defined"
 
-#: cgraph.c:3157
+#: cgraph.c:3162
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr "Interner Fehler: externally visible inline clone"
 
-#: cgraph.c:3162
+#: cgraph.c:3167
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr "Interner Fehler: inline clone with address taken"
 
-#: cgraph.c:3167
+#: cgraph.c:3172
 #, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr "Interner Fehler: inline clone is forced to output"
 
-#: cgraph.c:3174
+#: cgraph.c:3179
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for indirect edge from %s"
 msgstr "Interner Fehler: aux field set for indirect edge from %s"
 
-#: cgraph.c:3181
+#: cgraph.c:3186
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr "Interner Fehler: An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 
-#: cgraph.c:3196
+#: cgraph.c:3201
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr "Interner Fehler: comdat-local function called by %s outside its comdat"
 
-#: cgraph.c:3206
+#: cgraph.c:3211
 #, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr "Interner Fehler: inlined_to pointer is wrong"
 
-#: cgraph.c:3211
+#: cgraph.c:3216
 #, gcc-internal-format
 msgid "multiple inline callers"
 msgstr "Interner Fehler: multiple inline callers"
 
-#: cgraph.c:3218
+#: cgraph.c:3223
 #, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr "Interner Fehler: inlined_to pointer set for noninline callers"
 
-#: cgraph.c:3239
+#: cgraph.c:3244
 #, gcc-internal-format
 msgid "caller edge count does not match BB count"
 msgstr "Interner Fehler: caller edge count does not match BB count"
 
-#: cgraph.c:3261
+#: cgraph.c:3266
 #, gcc-internal-format
 msgid "indirect call count does not match BB count"
 msgstr "Interner Fehler: indirect call count does not match BB count"
 
-#: cgraph.c:3272
+#: cgraph.c:3277
 #, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr "Interner Fehler: inlined_to pointer is set but no predecessors found"
 
-#: cgraph.c:3277
+#: cgraph.c:3282
 #, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr "Interner Fehler: inlined_to pointer refers to itself"
 
-#: cgraph.c:3289
+#: cgraph.c:3294
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr "Interner Fehler: cgraph_node has wrong clone_of"
 
-#: cgraph.c:3301
+#: cgraph.c:3306
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr "Interner Fehler: cgraph_node has wrong clone list"
 
-#: cgraph.c:3307
+#: cgraph.c:3312
 #, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr "Interner Fehler: cgraph_node is in clone list but it is not clone"
 
-#: cgraph.c:3312
+#: cgraph.c:3317
 #, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr "Interner Fehler: cgraph_node has wrong prev_clone pointer"
 
-#: cgraph.c:3317
+#: cgraph.c:3322
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr "Interner Fehler: double linked list of clones corrupted"
 
-#: cgraph.c:3329
+#: cgraph.c:3334
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr "Interner Fehler: Alias has call edges"
 
-#: cgraph.c:3337
+#: cgraph.c:3342
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr "Interner Fehler: Alias has non-alias reference"
 
-#: cgraph.c:3342
+#: cgraph.c:3347
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr "Interner Fehler: Alias has more than one alias reference"
 
-#: cgraph.c:3349
+#: cgraph.c:3354
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr "Interner Fehler: Analyzed alias has no reference"
 
-#: cgraph.c:3358
+#: cgraph.c:3363
 #, gcc-internal-format
 msgid "Instrumentation clone does not reference original node"
 msgstr "Interner Fehler: Instrumentation clone does not reference original node"
 
-#: cgraph.c:3365
+#: cgraph.c:3370
 #, gcc-internal-format
 msgid "Not instrumented node has non-NULL original declaration"
 msgstr "Interner Fehler: Not instrumented node has non-NULL original declaration"
 
-#: cgraph.c:3375
+#: cgraph.c:3380
 #, gcc-internal-format
 msgid "Instrumented node has wrong original declaration"
 msgstr "Interner Fehler: Instrumented node has wrong original declaration"
 
-#: cgraph.c:3393
+#: cgraph.c:3398
 #, gcc-internal-format
 msgid "Node has more than one chkp reference"
 msgstr "Interner Fehler: Node has more than one chkp reference"
 
-#: cgraph.c:3398
+#: cgraph.c:3403
 #, gcc-internal-format
 msgid "Wrong node is referenced with chkp reference"
 msgstr "Interner Fehler: Wrong node is referenced with chkp reference"
 
-#: cgraph.c:3406
+#: cgraph.c:3411
 #, gcc-internal-format
 msgid "Analyzed node has no reference to instrumented version"
 msgstr "Interner Fehler: Analyzed node has no reference to instrumented version"
 
-#: cgraph.c:3420
+#: cgraph.c:3425
 #, gcc-internal-format
 msgid "Alias chain for instrumented node is broken"
 msgstr "Interner Fehler: Alias chain for instrumented node is broken"
 
-#: cgraph.c:3429
+#: cgraph.c:3434
 #, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr "Interner Fehler: No edge out of thunk node"
 
-#: cgraph.c:3434
+#: cgraph.c:3439
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr "Interner Fehler: More than one edge out of thunk node"
 
-#: cgraph.c:3439
+#: cgraph.c:3444
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr "Interner Fehler: Thunk is not supposed to have body"
 
-#: cgraph.c:3445
+#: cgraph.c:3450
 #, gcc-internal-format
 msgid "Instrumentation thunk has wrong edge callee"
 msgstr "Interner Fehler: Instrumentation thunk has wrong edge callee"
 
-#: cgraph.c:3481
+#: cgraph.c:3486
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr "Interner Fehler: shared call_stmt:"
 
-#: cgraph.c:3489
+#: cgraph.c:3494
 #, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr "Interner Fehler: edge points to wrong declaration:"
 
-#: cgraph.c:3498
+#: cgraph.c:3503
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr "Interner Fehler: an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 
-#: cgraph.c:3508
+#: cgraph.c:3513
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr "Interner Fehler: missing callgraph edge for call stmt:"
 
-#: cgraph.c:3518
+#: cgraph.c:3523
 #, gcc-internal-format
 msgid "reference to dead statement"
 msgstr "Interner Fehler: reference to dead statement"
 
-#: cgraph.c:3531
+#: cgraph.c:3536
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr "Interner Fehler: edge %s->%s has no corresponding call_stmt"
 
-#: cgraph.c:3543
+#: cgraph.c:3548
 #, gcc-internal-format, gfc-internal-format
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr "Interner Fehler: an indirect edge from %s has no corresponding call_stmt"
 
-#: cgraph.c:3554
+#: cgraph.c:3559
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr "Interner Fehler: verify_cgraph_node failed"
 
-#: cgraph.c:3661 varpool.c:306
+#: cgraph.c:3666 varpool.c:306
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: section %s is missing"
 msgstr "Interner Fehler: %s: section %s is missing"
@@ -17462,12 +17478,12 @@
 msgstr "Attribut %<weakref%> ignoriert, da Variable bereits initialisiert ist"
 
 #. include_self=
-#: cgraphunit.c:981 c/c-decl.c:11282
+#: cgraphunit.c:981 c/c-decl.c:11302
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F verwendet, aber nirgendwo definiert"
 
-#: cgraphunit.c:983 c/c-decl.c:11291
+#: cgraphunit.c:983 c/c-decl.c:11311
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "%q+F als %<static%> deklariert, aber nirgendwo definiert"
@@ -17582,12 +17598,12 @@
 msgid "cannot find '%s'"
 msgstr "»%s« kann nicht gefunden werden"
 
-#: collect-utils.c:183 collect2.c:2361 collect2.c:2560 gcc.c:3080 gcc.c:6856
+#: collect-utils.c:183 collect2.c:2387 collect2.c:2586 gcc.c:3080 gcc.c:6856
 #, gcc-internal-format
 msgid "pex_init failed: %m"
 msgstr "pex_init gescheitert: %m"
 
-#: collect-utils.c:192 collect2.c:2370 collect2.c:2568 gcc.c:8498
+#: collect-utils.c:192 collect2.c:2396 collect2.c:2594 gcc.c:8498
 #, gcc-internal-format
 msgid "%s: %m"
 msgstr "%s: %m"
@@ -17597,93 +17613,93 @@
 msgid "COLLECT_LTO_WRAPPER must be set"
 msgstr "COLLECT_LTO_WRAPPER muss gesetzt sein"
 
-#: collect2.c:966 gcc.c:7382 lto-wrapper.c:1666
+#: collect2.c:969 gcc.c:7382 lto-wrapper.c:1692
 #: config/i386/intelmic-mkoffload.c:556 config/nvptx/mkoffload.c:405
 #, gcc-internal-format
 msgid "atexit failed"
 msgstr "atexit gescheitert"
 
-#: collect2.c:1064
+#: collect2.c:1067
 #, gcc-internal-format
 msgid "no arguments"
 msgstr "Keine Argumente"
 
-#: collect2.c:1303 opts.c:904
+#: collect2.c:1311 opts.c:904
 #, gcc-internal-format
 msgid "LTO support has not been enabled in this configuration"
 msgstr "LTO-Unterstützung wurde in dieser Konfiguration nicht eingeschaltet"
 
-#: collect2.c:1344
+#: collect2.c:1352
 #, gcc-internal-format
 msgid "can't open %s: %m"
 msgstr "%s kann nicht geöffnet werden: %m"
 
-#: collect2.c:1450
+#: collect2.c:1472
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown demangling style '%s'"
 msgstr "unbekannter Mangelstil »%s«"
 
-#: collect2.c:1546 collect2.c:1729 collect2.c:1769
+#: collect2.c:1574 collect2.c:1757 collect2.c:1797
 #, gcc-internal-format
 msgid "fopen %s: %m"
 msgstr "fopen %s: %m"
 
-#: collect2.c:1549 collect2.c:1734 collect2.c:1772
+#: collect2.c:1577 collect2.c:1762 collect2.c:1800
 #, gcc-internal-format
 msgid "fclose %s: %m"
 msgstr "fclose %s: %m"
 
-#: collect2.c:2335
+#: collect2.c:2361
 #, gcc-internal-format
 msgid "cannot find 'nm'"
 msgstr "»nm« kann nicht gefunden werden"
 
-#: collect2.c:2383
+#: collect2.c:2409
 #, gcc-internal-format
 msgid "can't open nm output: %m"
 msgstr "nm-Ausgabe kann nicht geöffnet werden: %m"
 
-#: collect2.c:2467
+#: collect2.c:2493
 #, gcc-internal-format, gfc-internal-format
 msgid "init function found in object %s"
 msgstr "init-Funktion im Objekt %s gefunden"
 
-#: collect2.c:2478
+#: collect2.c:2504
 #, gcc-internal-format, gfc-internal-format
 msgid "fini function found in object %s"
 msgstr "fini-Funktion im Objekt %s gefunden"
 
-#: collect2.c:2535
+#: collect2.c:2561
 #, gcc-internal-format
 msgid "cannot find 'ldd'"
 msgstr "»ldd« kann nicht gefunden werden"
 
-#: collect2.c:2581
+#: collect2.c:2607
 #, gcc-internal-format
 msgid "can't open ldd output: %m"
 msgstr "ldd-Ausgabe kann nicht geöffnet werden: %m"
 
-#: collect2.c:2599
+#: collect2.c:2625
 #, gcc-internal-format, gfc-internal-format
 msgid "dynamic dependency %s not found"
 msgstr "dynamische Abhängigkeit »%s« nicht gefunden"
 
-#: collect2.c:2611
+#: collect2.c:2637
 #, gcc-internal-format, gfc-internal-format
 msgid "unable to open dynamic dependency '%s'"
 msgstr "dynamische Abhängigkeit »%s« kann nicht geöffnet werden"
 
-#: collect2.c:2765
+#: collect2.c:2791
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: not a COFF file"
 msgstr "%s: keine COFF-Datei"
 
-#: collect2.c:2930
+#: collect2.c:2961
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: cannot open as COFF file"
 msgstr "%s kann nicht als COFF-Datei geöffnet werden"
 
-#: collect2.c:2989
+#: collect2.c:3020
 #, gcc-internal-format, gfc-internal-format
 msgid "library lib%s not found"
 msgstr "Bibliothek lib%s nicht gefunden"
@@ -17893,12 +17909,12 @@
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr "Mehrere EH-Persönlichkeiten werden nur mit Assemblern unterstützt, die die Direktive .cfi_personality unterstützen"
 
-#: dwarf2out.c:10901
+#: dwarf2out.c:10909
 #, gcc-internal-format
 msgid "-gdwarf-6 is output as version 5 with incompatibilities"
 msgstr "-gdwarf-6 wird als Version 5 ausgegeben, mit Inkompatibilitäten"
 
-#: dwarf2out.c:14415
+#: dwarf2out.c:14423
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr "Nicht-Delegitimiertes UNSPEC %s (%d) am Variablenort gefunden"
@@ -18019,11 +18035,6 @@
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr "%KAufruf von %qs mit Attributwarnung deklariert: %s"
 
-#: file-prefix-map.c:50
-#, gcc-internal-format
-msgid "invalid argument %qs to %qs"
-msgstr "ungültiges Argument %qs für %qs"
-
 #: final.c:1868
 #, gcc-internal-format
 msgid "the frame size of %wd bytes is larger than %wd bytes"
@@ -18044,42 +18055,42 @@
 msgid "large fixed-point constant implicitly truncated to fixed-point type"
 msgstr "große Festkommakonstante implizit auf Festkommatypen abgeschnitten"
 
-#: fold-const.c:4151 fold-const.c:4161
+#: fold-const.c:4157 fold-const.c:4167
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d due to width of bit-field"
 msgstr "Vergleich ist immer %d wegen Breite des Bitfeldes"
 
-#: fold-const.c:5478 tree-ssa-reassoc.c:2374 tree-ssa-reassoc.c:3214
+#: fold-const.c:5484 tree-ssa-reassoc.c:2379 tree-ssa-reassoc.c:3219
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr "Annahme, dass vorzeichenbehafteter Überlauf nicht auftritt, wenn Bereichsprüfung vereinfacht wird"
 
-#: fold-const.c:5928 fold-const.c:5942
+#: fold-const.c:5934 fold-const.c:5948
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr "Vergleich ist immer %d"
 
-#: fold-const.c:6085
+#: fold-const.c:6091
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr "»oder« nicht passender Ungleichheits-Tests ist immer 1"
 
-#: fold-const.c:6090
+#: fold-const.c:6096
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr "»und« sich gegenseitig ausschließender Gleichheits-Tests ist immer 0"
 
-#: fold-const.c:8310
+#: fold-const.c:8316
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr "Annahme, dass vorzeichenbehafteter Überlauf nicht auftritt, wenn Konstante in Vergleich verringert wird"
 
-#: fold-const.c:8710
+#: fold-const.c:8716
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr "Annahme, dass vorzeichenbehafteter Überlauf nicht auftritt, wenn Konstanten um einen Vergleich kombiniert werden"
 
-#: fold-const.c:12063
+#: fold-const.c:12069
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr "Faltungstest: ursprünglicher Baum durch Faltung geändert"
@@ -18089,7 +18100,7 @@
 msgid "total size of local objects too large"
 msgstr "Gesamtgröße der lokalen Objekte zu hoch"
 
-#: function.c:1776 gimplify.c:6270
+#: function.c:1776 gimplify.c:6273
 #, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr "unmögliche Bedingung in »asm«"
@@ -18394,7 +18405,7 @@
 msgid "%s: linker input file unused because linking not done"
 msgstr "%s: Eingabedatei des Linkers unbenutzt, da das Linken nicht durchgeführt wird"
 
-#: gcc.c:8420 c-family/c-opts.c:770
+#: gcc.c:8420 c-family/c-opts.c:768
 #, gcc-internal-format
 msgid "cannot use %<-%> as input filename for a precompiled header"
 msgstr "der Eingabedateiname für einen vorkompilierten Header darf nicht %<-%> sein"
@@ -18629,7 +18640,7 @@
 msgid "%G%qD destination unchanged after copying no bytes"
 msgstr "%G%qD Ziel unverändert, nachdem keine Bytes kopiert wurden"
 
-#: gimple-fold.c:2052 tree-ssa-strlen.c:2050
+#: gimple-fold.c:2052 tree-ssa-strlen.c:2074
 msgid "%G%qD specified bound %E equals destination size"
 msgstr "%G%qD angegebene Grenze %E ist genau die Größe des Ziels"
 
@@ -18651,12 +18662,12 @@
 msgid "null pointer dereference"
 msgstr "Dereferenzierung eines Nullzeigers"
 
-#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12451
-#: tree.c:12488 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10147
-#: c/c-typeck.c:10164 c/gimple-parser.c:1616 c/gimple-parser.c:1624
+#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12455
+#: tree.c:12492 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10152
+#: c/c-typeck.c:10169 c/gimple-parser.c:1616 c/gimple-parser.c:1624
 #: cp/call.c:6493 cp/call.c:8098 cp/constexpr.c:820 cp/constexpr.c:2309
-#: cp/cvt.c:1015 cp/cvt.c:1042 cp/decl.c:7334 cp/decl2.c:5256 cp/pt.c:8334
-#: cp/semantics.c:1836 cp/semantics.c:4053 cp/typeck.c:1700 cp/typeck.c:1895
+#: cp/cvt.c:1015 cp/cvt.c:1042 cp/decl.c:7355 cp/decl2.c:5246 cp/pt.c:8348
+#: cp/semantics.c:1836 cp/semantics.c:4056 cp/typeck.c:1700 cp/typeck.c:1895
 #: cp/typeck.c:3837
 #, gcc-internal-format
 msgid "declared here"
@@ -18667,27 +18678,27 @@
 msgid "nonnull argument %qD compared to NULL"
 msgstr "nichtnull-Argument %qD wird mit NULL verglichen"
 
-#: gimple-ssa-sprintf.c:2517 gimple-ssa-sprintf.c:2637
+#: gimple-ssa-sprintf.c:2555 gimple-ssa-sprintf.c:2675
 #, gcc-internal-format
 msgid "%qE output may be truncated before the last format character"
 msgstr "%qE-Ausgabe könnte vor dem letzten Formatzeichen abgeschnitten sein"
 
-#: gimple-ssa-sprintf.c:2519 gimple-ssa-sprintf.c:2639
+#: gimple-ssa-sprintf.c:2557 gimple-ssa-sprintf.c:2677
 #, gcc-internal-format
 msgid "%qE output truncated before the last format character"
 msgstr "%qE-Ausgabe ist vor dem letzten Formatzeichen abgeschnitten"
 
-#: gimple-ssa-sprintf.c:2522 gimple-ssa-sprintf.c:2642
+#: gimple-ssa-sprintf.c:2560 gimple-ssa-sprintf.c:2680
 #, gcc-internal-format
 msgid "%qE may write a terminating nul past the end of the destination"
 msgstr "%qE könnte ein abschließendes NUL hinter das Ende des Ziels schreiben"
 
-#: gimple-ssa-sprintf.c:2524 gimple-ssa-sprintf.c:2644
+#: gimple-ssa-sprintf.c:2562 gimple-ssa-sprintf.c:2682
 #, gcc-internal-format
 msgid "%qE writing a terminating nul past the end of the destination"
 msgstr "%qE schreibt ein abschließendes NUL hinter das Ende des Ziels"
 
-#: gimple-ssa-sprintf.c:2534
+#: gimple-ssa-sprintf.c:2572
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size %wu"
@@ -18694,7 +18705,7 @@
 msgstr[0] "%<%.*s%>-Direktive schreibt %wu Byte in eine Region der Größe %wu"
 msgstr[1] "%<%.*s%>-Direktive schreibt %wu Bytes in eine Region der Größe %wu"
 
-#: gimple-ssa-sprintf.c:2541
+#: gimple-ssa-sprintf.c:2579
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size %wu"
@@ -18701,7 +18712,7 @@
 msgstr[0] "Ausgabe der %<%.*s%>-Direktive könnte abgeschnitten sein, beim Schreiben von %wu Byte in eine Region der Größe %wu"
 msgstr[1] "Ausgabe der %<%.*s%>-Direktive könnte abgeschnitten sein, beim Schreiben von %wu Bytes in eine Region der Größe %wu"
 
-#: gimple-ssa-sprintf.c:2548
+#: gimple-ssa-sprintf.c:2586
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size %wu"
@@ -18708,67 +18719,67 @@
 msgstr[0] "Ausgabe der %<%.*s%>-Direktive abgeschnitten, beim Schreiben von %wu Byte in eine Region der Größe %wu"
 msgstr[1] "Ausgabe der %<%.*s%>-Direktive abgeschnitten, beim Schreiben von %wu Bytes in eine Region der Größe %wu"
 
-#: gimple-ssa-sprintf.c:2559
+#: gimple-ssa-sprintf.c:2597
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size %wu"
 msgstr "Ausgabe der %<%.*s%>-Direktive könnte abgeschnitten sein, beim Schreiben von bis zu %wu Bytes in eine Region der Größe %wu"
 
-#: gimple-ssa-sprintf.c:2562
+#: gimple-ssa-sprintf.c:2600
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size %wu"
 msgstr "Ausgabe der %<%.*s%>-Direktive abgeschnitten, beim Schreiben von bis zu %wu Bytes in eine Region der Größe %wu"
 
-#: gimple-ssa-sprintf.c:2564
+#: gimple-ssa-sprintf.c:2602
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size %wu"
 msgstr "%<%.*s%>-Direktive schreibt bis zu %wu Bytes in eine Region der Größe %wu"
 
-#: gimple-ssa-sprintf.c:2576
+#: gimple-ssa-sprintf.c:2614
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr "Ausgabe der %<%.*s%>-Direktive könnte abgeschnitten sein, beim Schreiben von wahrscheinlich %wu oder mehr Bytes in eine Region der Größe %wu"
 
-#: gimple-ssa-sprintf.c:2579
+#: gimple-ssa-sprintf.c:2617
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr "Ausgabe der %<%.*s%>-Direktive abgeschnitten, beim Schreiben von wahrscheinlich %wu oder mehr Bytes in eine Region der Größe %wu"
 
-#: gimple-ssa-sprintf.c:2582
+#: gimple-ssa-sprintf.c:2620
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size %wu"
 msgstr "%<%.*s%>-Direktive schreibt wahrscheinlich %wu oder mehr Bytes in eine Region der Größe %wu"
 
-#: gimple-ssa-sprintf.c:2591
+#: gimple-ssa-sprintf.c:2629
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr "Ausgabe der %<%.*s%>-Direktive könnte abgeschnitten sein, beim Schreiben von %wu bis %wu Bytes in eine Region der Größe %wu"
 
-#: gimple-ssa-sprintf.c:2594
+#: gimple-ssa-sprintf.c:2632
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr "Ausgabe der %<%.*s%>-Direktive abgeschnitten, beim Schreiben von %wu bis %wu Bytes in eine Region der Größe %wu"
 
-#: gimple-ssa-sprintf.c:2597
+#: gimple-ssa-sprintf.c:2635
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size %wu"
 msgstr "%<%.*s%>-Direktive schreibt zwischen %wu und %wu Bytes in eine Region der Größe %wu"
 
-#: gimple-ssa-sprintf.c:2606
+#: gimple-ssa-sprintf.c:2644
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size %wu"
 msgstr "Ausgabe der %<%.*s%>-Direktive könnte abgeschnitten sein, beim Schreiben von %wu oder mehr Bytes in eine Region der Größe %wu"
 
-#: gimple-ssa-sprintf.c:2609
+#: gimple-ssa-sprintf.c:2647
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size %wu"
 msgstr "Ausgabe der %<%.*s%>-Direktive abgeschnitten, beim Schreiben von %wu oder mehr Bytes in eine Region der Größe %wu"
 
-#: gimple-ssa-sprintf.c:2611
+#: gimple-ssa-sprintf.c:2649
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size %wu"
 msgstr "%<%.*s%>-Direktive schreibt %wu oder mehr Bytes in eine Region der Größe %wu"
 
-#: gimple-ssa-sprintf.c:2653
+#: gimple-ssa-sprintf.c:2691
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size between %wu and %wu"
@@ -18775,7 +18786,7 @@
 msgstr[0] "%<%.*s%>-Direktive schreibt %wu Byte in eine Region der Größe zwischen %wu und %wu"
 msgstr[1] "%<%.*s%>-Direktive schreibt %wu Bytes in eine Region der Größe zwischen %wu und %wu"
 
-#: gimple-ssa-sprintf.c:2660
+#: gimple-ssa-sprintf.c:2698
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size between %wu and %wu"
@@ -18782,7 +18793,7 @@
 msgstr[0] "Ausgabe der %<%.*s%>-Direktive könnte abgeschnitten sein, beim Schreiben von %wu Byte in eine Region der Größe zwischen %wu und %wu"
 msgstr[1] "Ausgabe der %<%.*s%>-Direktive könnte abgeschnitten sein, beim Schreiben von %wu Bytes in eine Region der Größe zwischen %wu und %wu"
 
-#: gimple-ssa-sprintf.c:2668
+#: gimple-ssa-sprintf.c:2706
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size between %wu and %wu"
@@ -18789,102 +18800,102 @@
 msgstr[0] "Ausgabe der %<%.*s%>-Direktive abgeschnitten, beim Schreiben von %wu Byte in eine Region der Größe zwischen %wu und %wu"
 msgstr[1] "Ausgabe der %<%.*s%>-Direktive abgeschnitten, beim Schreiben von %wu Bytes in eine Region der Größe zwischen %wu und %wu"
 
-#: gimple-ssa-sprintf.c:2680
+#: gimple-ssa-sprintf.c:2718
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr "Ausgabe der %<%.*s%>-Direktive könnte abgeschnitten sein, beim Schreiben von bis zu %wu Bytes in eine Region der Größe zwischen %wu und %wu"
 
-#: gimple-ssa-sprintf.c:2683
+#: gimple-ssa-sprintf.c:2721
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr "Ausgabe der %<%.*s%>-Direktive abgeschnitten, beim Schreiben von bis zu %wu Bytes in eine Region der Größe zwischen %wu und %wu"
 
-#: gimple-ssa-sprintf.c:2686
+#: gimple-ssa-sprintf.c:2724
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr "%<%.*s%>-Direktive schreibt bis zu %wu Bytes in eine Region der Größe zwischen %wu und %wu"
 
-#: gimple-ssa-sprintf.c:2699
+#: gimple-ssa-sprintf.c:2737
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr "Ausgabe der %<%.*s%>-Direktive könnte abgeschnitten sein, beim Schreiben von wahrscheinlich %wu oder mehr Bytes in eine Region der Größe zwischen %wu und %wu"
 
-#: gimple-ssa-sprintf.c:2702
+#: gimple-ssa-sprintf.c:2740
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr "Ausgabe der %<%.*s%>-Direktive abgeschnitten, beim Schreiben von wahrscheinlich %wu oder mehr Bytes in eine Region der Größe zwischen %wu und %wu"
 
-#: gimple-ssa-sprintf.c:2705
+#: gimple-ssa-sprintf.c:2743
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr "%<%.*s%>-Direktive schreibt wahrscheinlich %wu oder mehr Bytes in eine Region der Größe zwischen %wu und %wu"
 
-#: gimple-ssa-sprintf.c:2715
+#: gimple-ssa-sprintf.c:2753
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr "Ausgabe der %<%.*s%>-Direktive könnte abgeschnitten sein, beim Schreiben zwischen %wu und %wu Bytes in eine Region der Größe zwischen %wu und %wu"
 
-#: gimple-ssa-sprintf.c:2718
+#: gimple-ssa-sprintf.c:2756
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr "Ausgabe der %<%.*s%>-Direktive abgeschnitten, beim Schreiben von %wu bis %wu Bytes in eine Region der Größe zwischen %wu und %wu"
 
-#: gimple-ssa-sprintf.c:2721
+#: gimple-ssa-sprintf.c:2759
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr "%<%.*s%>-Direktive schreibt zwischen %wu und %wu Bytes in eine Region der Größe zwischen %wu und %wu"
 
-#: gimple-ssa-sprintf.c:2730
+#: gimple-ssa-sprintf.c:2768
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr "Ausgabe der %<%.*s%>-Direktive könnte abgeschnitten sein, beim Schreiben von %wu oder mehr Bytes in eine Region der Größe zwischen %wu und %wu"
 
-#: gimple-ssa-sprintf.c:2733
+#: gimple-ssa-sprintf.c:2771
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr "Ausgabe der %<%.*s%>-Direktive abgeschnitten, beim Schreiben von %wu oder mehr Bytes in eine Region der Größe zwischen %wu und %wu"
 
-#: gimple-ssa-sprintf.c:2736
+#: gimple-ssa-sprintf.c:2774
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr "%<%.*s%>-Direktive schreibt %wu oder mehr Bytes in eine Region der Größe zwischen %wu und %wu"
 
-#: gimple-ssa-sprintf.c:2825
+#: gimple-ssa-sprintf.c:2863
 #, gcc-internal-format
 msgid "%<%.*s%> directive argument is null"
 msgstr "Argument für %<%.*s%>-Direktive ist null"
 
-#: gimple-ssa-sprintf.c:2890
+#: gimple-ssa-sprintf.c:2928
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes exceeds minimum required size of 4095"
 msgstr "Ausgabe der %<%.*s%>-Direktive von %wu Bytes überschreitet die minimal erforderliche Größe von 4095"
 
-#: gimple-ssa-sprintf.c:2897
+#: gimple-ssa-sprintf.c:2935
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may exceed minimum required size of 4095"
 msgstr "Ausgabe der %<%.*s%>-Direktive zwischen %wu und %wu Bytes könnte die minimal erforderliche Größe von 4095 überschreiten"
 
-#: gimple-ssa-sprintf.c:2900
+#: gimple-ssa-sprintf.c:2938
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes exceeds minimum required size of 4095"
 msgstr "Ausgabe der %<%.*s%>-Direktive zwischen %wu und %wu Bytes überschreitet die minimal erforderliche Größe von 4095"
 
-#: gimple-ssa-sprintf.c:2929
+#: gimple-ssa-sprintf.c:2967
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr "Ausgabe der %<%.*s%>-Direktive von %wu Bytes macht das Ergebnis größer als %<INT_MAX%>"
 
-#: gimple-ssa-sprintf.c:2936
+#: gimple-ssa-sprintf.c:2974
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr "Ausgabe der %<%.*s%>-Direktive zwischen %wu und %wu Bytes macht das Ergebnis größer als %<INT_MAX%>"
 
-#: gimple-ssa-sprintf.c:2939
+#: gimple-ssa-sprintf.c:2977
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may cause result to exceed %<INT_MAX%>"
 msgstr "Ausgabe der %<%.*s%>-Direktive zwischen %wu und %wu Bytes könnte das Ergebnis größer als %<INT_MAX%> machen"
 
-#: gimple-ssa-sprintf.c:2949
+#: gimple-ssa-sprintf.c:2987
 #, gcc-internal-format
 msgid "assuming directive output of %wu byte"
 msgid_plural "assuming directive output of %wu bytes"
@@ -18891,77 +18902,77 @@
 msgstr[0] "angenommen, dass die Ausgabe der Direktive %wu Byte groß ist"
 msgstr[1] "angenommen, dass die Ausgabe der Direktive %wu Bytes groß ist"
 
-#: gimple-ssa-sprintf.c:2956
+#: gimple-ssa-sprintf.c:2994
 #, gcc-internal-format
 msgid "directive argument %qE"
 msgstr "Direktiven-Argument %qE"
 
-#: gimple-ssa-sprintf.c:2958
+#: gimple-ssa-sprintf.c:2996
 #, gcc-internal-format
 msgid "directive argument in the range [%E, %E]"
 msgstr "Direktiven-Argument im Bereich [%E, %E]"
 
-#: gimple-ssa-sprintf.c:2962
+#: gimple-ssa-sprintf.c:3000
 #, gcc-internal-format
 msgid "using the range [%E, %E] for directive argument"
 msgstr "das Intervall [%E, %E] wird für das Argument der Direktive verwendet"
 
-#: gimple-ssa-sprintf.c:2982
+#: gimple-ssa-sprintf.c:3020
 #, gcc-internal-format
 msgid "%qE output %wu byte into a destination of size %wu"
 msgstr "%qE gibt %wu Byte in das Ziel der Größe %wu aus"
 
-#: gimple-ssa-sprintf.c:2983
+#: gimple-ssa-sprintf.c:3021
 #, gcc-internal-format
 msgid "%qE output %wu bytes into a destination of size %wu"
 msgstr "%qE gibt %wu Bytes in das Ziel der Größe %wu aus"
 
-#: gimple-ssa-sprintf.c:2987
+#: gimple-ssa-sprintf.c:3025
 #, gcc-internal-format
 msgid "%qE output between %wu and %wu bytes into a destination of size %wu"
 msgstr "%qE gibt zwischen %wu und %wu Bytes in das Ziel der Größe %wu aus"
 
-#: gimple-ssa-sprintf.c:2992
+#: gimple-ssa-sprintf.c:3030
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes (assuming %wu) into a destination of size %wu"
 msgstr "%qE gibt %wu oder mehr Bytes (angenommen %wu) in das Ziel der Größe %wu aus"
 
-#: gimple-ssa-sprintf.c:2997
+#: gimple-ssa-sprintf.c:3035
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes into a destination of size %wu"
 msgstr "%qE gibt %wu oder mehr Bytes in das Ziel der Größe %wu aus"
 
-#: gimple-ssa-sprintf.c:3368
+#: gimple-ssa-sprintf.c:3406
 #, gcc-internal-format
 msgid "%<%.*s%> directive width out of range"
 msgstr "Breite für %<%.*s%>-Direktive außerhalb des zulässigen Bereichs"
 
-#: gimple-ssa-sprintf.c:3402
+#: gimple-ssa-sprintf.c:3440
 #, gcc-internal-format
 msgid "%<%.*s%> directive precision out of range"
 msgstr "Genauigkeit der %<%.*s%>-Direktive außerhalb des zulässigen Bereichs"
 
-#: gimple-ssa-sprintf.c:3893
+#: gimple-ssa-sprintf.c:3931
 #, gcc-internal-format
 msgid "specified bound %wu exceeds maximum object size %wu"
 msgstr "angegebene Grenze %wu überschreitet maximale Objektgröße %wu"
 
-#: gimple-ssa-sprintf.c:3899
+#: gimple-ssa-sprintf.c:3937
 #, gcc-internal-format
 msgid "specified bound %wu exceeds %<INT_MAX%>"
 msgstr "angegebene Grenze %wu überschreitet %<INT_MAX%>"
 
-#: gimple-ssa-sprintf.c:3949
+#: gimple-ssa-sprintf.c:3987
 #, gcc-internal-format
 msgid "null destination pointer"
 msgstr "Zielzeiger ist NULL"
 
-#: gimple-ssa-sprintf.c:3966
+#: gimple-ssa-sprintf.c:4004
 #, gcc-internal-format
 msgid "specified bound %wu exceeds the size %wu of the destination object"
 msgstr "angegebene Grenze %wu überschreitet die Größe %wu des Zielobjekts"
 
-#: gimple-ssa-sprintf.c:3978
+#: gimple-ssa-sprintf.c:4016
 #, gcc-internal-format
 msgid "null format string"
 msgstr "NULL-Formatzeichenkette"
@@ -19174,10 +19185,10 @@
 msgstr "%G%qD Offset %s ist außerhalb der Grenzen von Objekt %qD mit Typ %qT"
 
 #: gimple-ssa-warn-restrict.c:1678 c/c-decl.c:3603 c/c-decl.c:3874
-#: c/c-typeck.c:8345 cp/class.c:1346 cp/class.c:3098 cp/decl.c:3979
-#: cp/decl.c:10753 cp/decl.c:11151 cp/decl.c:11160 cp/friend.c:384
+#: c/c-typeck.c:8350 cp/class.c:1346 cp/class.c:3102 cp/decl.c:3979
+#: cp/decl.c:10777 cp/decl.c:11175 cp/decl.c:11184 cp/friend.c:384
 #: cp/friend.c:393 cp/parser.c:3275 cp/parser.c:3372 cp/parser.c:3422
-#: cp/parser.c:6327 cp/parser.c:21027
+#: cp/parser.c:6330 cp/parser.c:21024
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD ist hier deklariert"
@@ -19245,218 +19256,218 @@
 msgid "using result of function returning %<void%>"
 msgstr "Ergebnis einer %<void%> zurückgebenden Funktion verwendet"
 
-#: gimplify.c:6128
+#: gimplify.c:6131
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid lvalue in asm output %d"
 msgstr "ungültiger L-Wert in asm-Ausgabe %d"
 
-#: gimplify.c:6271
+#: gimplify.c:6274
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr "Eingabe von Nicht-Speicher %d muss im Speicher bleiben"
 
-#: gimplify.c:6311 gimplify.c:6320
+#: gimplify.c:6314 gimplify.c:6323
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr "Speichereingabe %d ist nicht direkt adressierbar"
 
-#: gimplify.c:6928
+#: gimplify.c:6931
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in target region"
 msgstr "threadprivate Variable %qE in Zielregion verwendet"
 
-#: gimplify.c:6930
+#: gimplify.c:6933
 #, gcc-internal-format
 msgid "enclosing target region"
 msgstr "umgebende Zielregion"
 
-#: gimplify.c:6942
+#: gimplify.c:6945
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in untied task"
 msgstr "threadprivate Variable %qE in unverknüpfter Task verwendet"
 
-#: gimplify.c:6944
+#: gimplify.c:6947
 #, gcc-internal-format
 msgid "enclosing task"
 msgstr "umgebende Task"
 
-#: gimplify.c:7016
+#: gimplify.c:7019
 #, gcc-internal-format
 msgid "%qE not specified in enclosing %qs"
 msgstr "%qE in umgebendem %qs nicht angegeben"
 
-#: gimplify.c:7018
+#: gimplify.c:7021
 #, gcc-internal-format
 msgid "enclosing %qs"
 msgstr "umgebendes %qs"
 
-#: gimplify.c:7143
+#: gimplify.c:7146
 #, gcc-internal-format
 msgid "%qE not specified in enclosing OpenACC %qs construct"
 msgstr "%qE in umgebendem OpenACC-%qs-Konstrukt nicht angegeben"
 
-#: gimplify.c:7145
+#: gimplify.c:7148
 #, gcc-internal-format
 msgid "enclosing OpenACC %qs construct"
 msgstr "umgebendes OpenACC-%qs-Konstrukt"
 
-#: gimplify.c:7198
+#: gimplify.c:7201
 #, gcc-internal-format
 msgid "%qE with %<link%> clause used in %<routine%> function"
 msgstr "%qE mit %<link%>-Klausel wird in %<routine%>-Funktion verwendet"
 
-#: gimplify.c:7206
+#: gimplify.c:7209
 #, gcc-internal-format
 msgid "%qE requires a %<declare%> directive for use in a %<routine%> function"
 msgstr "%qE erfordert eine %<declare%>-Direktive, um in einer %<routine%>-Funktion verwendet zu werden"
 
-#: gimplify.c:7272 gimplify.c:7872
+#: gimplify.c:7275 gimplify.c:7875
 #, gcc-internal-format
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr "Variable %qE in umgebender %<host_data%>-Region deklariert"
 
-#: gimplify.c:7293
+#: gimplify.c:7296
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr "Zielregion verweist auf %qD, aber der Ausdruck hat keinen zuordenbaren Typ"
 
-#: gimplify.c:7411 gimplify.c:7443
+#: gimplify.c:7414 gimplify.c:7446
 #, gcc-internal-format
 msgid "iteration variable %qE is predetermined linear"
 msgstr "Iterationsvariable %qE ist vorbestimmt linear"
 
-#: gimplify.c:7414
+#: gimplify.c:7417
 #, gcc-internal-format
 msgid "iteration variable %qE should be private"
 msgstr "Schleifenvariable %qE sollte »private« sein"
 
-#: gimplify.c:7428
+#: gimplify.c:7431
 #, gcc-internal-format
 msgid "iteration variable %qE should not be firstprivate"
 msgstr "Schleifenvariable %qE sollte nicht »firstprivate« sein"
 
-#: gimplify.c:7431
+#: gimplify.c:7434
 #, gcc-internal-format
 msgid "iteration variable %qE should not be reduction"
 msgstr "Schleifenvariable %qE sollte nicht Reduktion sein"
 
-#: gimplify.c:7434
+#: gimplify.c:7437
 #, gcc-internal-format
 msgid "iteration variable %qE should not be linear"
 msgstr "Iterationsvariable %qE sollte nicht »linear« sein"
 
-#: gimplify.c:7437
+#: gimplify.c:7440
 #, gcc-internal-format
 msgid "iteration variable %qE should not be lastprivate"
 msgstr "Iterationsvariable %qE sollte nicht »lastprivate« sein"
 
-#: gimplify.c:7440
+#: gimplify.c:7443
 #, gcc-internal-format
 msgid "iteration variable %qE should not be private"
 msgstr "Iterationsvariable %qE sollte nicht »private« sein"
 
-#: gimplify.c:7742
+#: gimplify.c:7745
 #, gcc-internal-format
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr "%<linear%>-Klausel für Variable, die keine Schleifeniterationsvariable ist, wurde für ein mit %<distribute%> kombiniertes Konstrukt angegeben"
 
-#: gimplify.c:7949
+#: gimplify.c:7952
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr "Feld %qE der Struktur variabler Länger wird zugeordnet"
 
-#: gimplify.c:8160
+#: gimplify.c:8163
 #, gcc-internal-format
 msgid "%qE appears more than once in map clauses"
 msgstr "%qE tritt in Mapklauseln mehrfach auf"
 
-#: gimplify.c:8464
+#: gimplify.c:8467
 #, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr "»copyprivate«-Variable %qE ist im äußeren Kontext weder »threadprivate« noch »private«"
 
-#: gimplify.c:8484
+#: gimplify.c:8487
 #, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr "»%s«-Variable %qE ist im äußeren Kontext »private«"
 
-#: gimplify.c:8510
+#: gimplify.c:8513
 #, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr "%qs %<if%>-Klausel-Modifizierer anstelle %qs erwartet"
 
-#: gimplify.c:8775
+#: gimplify.c:8778
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr "%<_Atomic%> %qD in implizier %<map%>-Klausel"
 
-#: gimplify.c:8808
+#: gimplify.c:8811
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr "%<_Atomic%> %qD in impliziter %<firstprivate%>-Klausel am %<target%>-Konstrukt"
 
-#: gimplify.c:9000
+#: gimplify.c:9003
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr "%<_Atomic%> %qD in %<firstprivate%>-Klausel am %<target%>-Konstrukt"
 
-#: gimplify.c:9051
+#: gimplify.c:9054
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr "selbe Variable wird in %<firstprivate%>- und %<lastprivate%>-Klauseln am %<distribute%>-Konstrukt"
 
-#: gimplify.c:9133
+#: gimplify.c:9136
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to present_or_copy"
 msgstr "inkompatible Datenklausel mit Reduktion an %qE; wird zu »present_or_copy« befördert"
 
-#: gimplify.c:9278
+#: gimplify.c:9281
 #, gcc-internal-format
 msgid "invalid private reduction on %qE"
 msgstr "ungültige »private«-Reduktion auf %qE"
 
-#: gimplify.c:11103 omp-low.c:2791
+#: gimplify.c:11106 omp-low.c:2791
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr "%<ordered%>-Konstrukt mit %<depend%>-Klausel muss innerhalb einer Schleife mit %<ordered%>-Klausel und Parameter eng geschachtelt sein"
 
-#: gimplify.c:11121
+#: gimplify.c:11124
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr "Variable %qE ist keine Iteration der äußersten Schleife %d, jedoch %qE erwartet"
 
-#: gimplify.c:11134
+#: gimplify.c:11137
 #, gcc-internal-format
 msgid "number of variables in %<depend(sink)%> clause does not match number of iteration variables"
 msgstr "Anzahl der Variablen in %<depend(sink)%>-Klausel passt nicht zur Anzahl der Iterationsvariablen"
 
-#: gimplify.c:11147
+#: gimplify.c:11150
 #, gcc-internal-format
 msgid "more than one %<depend(source)%> clause on an %<ordered%> construct"
 msgstr "mehr als eine %<depend(source)%>-Klausel an einem %<ordered%>-Konstrukt"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79999
-#: gimplify.c:11158
+#: gimplify.c:11161
 #, gcc-internal-format
 msgid "%<depend(source)%> clause specified together with %<depend(sink:)%> clauses on the same construct"
 msgstr "%<depend(source)%>-Klausel zusammen mit %<depend(sink:)%>-Klausel an demselben Konstrukt"
 
-#: gimplify.c:12393
+#: gimplify.c:12396
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr "Gimplifikation gescheitert"
 
-#: gimplify.c:12936
+#: gimplify.c:12939
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr "%qT auf %qT erweitert beim Durchlaufen von %<...%>"
 
-#: gimplify.c:12941
+#: gimplify.c:12944
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr "(Es sollte also %qT statt %qT an %<va_arg%> übergeben werden)"
 
-#: gimplify.c:12948
+#: gimplify.c:12951
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr "Wenn dieser Code erreicht wird, wird das Programm abgebrochen"
@@ -19929,47 +19940,47 @@
 msgid "Max. number of generated reload insns per insn is achieved (%d)\n"
 msgstr "Höchstzahl der erzeugten Neuladebefehle pro Befehl ist erreicht (%d)\n"
 
-#: lto-cgraph.c:1294
+#: lto-cgraph.c:1296
 #, gcc-internal-format, gfc-internal-format
 msgid "bytecode stream: found multiple instances of cgraph node with uid %d"
 msgstr "Bytecode-Strom: Mehrere Instanzen des Cgraph-Knoten mit UID %d gefunden"
 
-#: lto-cgraph.c:1472
+#: lto-cgraph.c:1474
 #, gcc-internal-format
 msgid "bytecode stream: no caller found while reading edge"
 msgstr "Bytecode-Strom: Kein Aufrufer beim Lesen der Kante gefunden"
 
-#: lto-cgraph.c:1478
+#: lto-cgraph.c:1480
 #, gcc-internal-format
 msgid "bytecode stream: no callee found while reading edge"
 msgstr "Bytecode-Strom: Kein Gerufener beim Lesen der Kante gefunden"
 
-#: lto-cgraph.c:1552
+#: lto-cgraph.c:1554
 #, gcc-internal-format
 msgid "bytecode stream: found empty cgraph node"
 msgstr "Bytecode-Strom: Leeren Cgraph-Knoten gefunden"
 
-#: lto-cgraph.c:1730
+#: lto-cgraph.c:1732
 #, gcc-internal-format, gfc-internal-format
 msgid "At most %i profile runs is supported. Perhaps corrupted profile?"
 msgstr "Es werden höchstens %i Profildurchläufe unterstützt. Evtl. beschädigte Datei?"
 
-#: lto-cgraph.c:1817
+#: lto-cgraph.c:1819
 #, gcc-internal-format, gfc-internal-format
 msgid "Profile information in %s corrupted"
 msgstr "Profilinformation in %s ist beschädigt"
 
-#: lto-cgraph.c:1855
+#: lto-cgraph.c:1857
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO cgraph in %s"
 msgstr "LTO cgraph kann in %s nicht gefunden werden"
 
-#: lto-cgraph.c:1865
+#: lto-cgraph.c:1867
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO section refs in %s"
 msgstr "LTO-Abschnittsreferenzen können in %s nicht gefunden werden"
 
-#: lto-cgraph.c:1946
+#: lto-cgraph.c:1948
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid offload table in %s"
 msgstr "ungültige offload-Tabelle in %s"
@@ -20040,81 +20051,86 @@
 msgid "bytecode stream in file %qs generated with LTO version %d.%d instead of the expected %d.%d"
 msgstr "Bytecode-Strom in Datei %qs mit LTO-Version %d.%d statt des erwarteten %d.%d erzeugt"
 
-#: lto-wrapper.c:117
+#: lto-wrapper.c:118
 #, gcc-internal-format
 msgid "deleting LTRANS file %s: %m"
 msgstr "LTRANS-Datei %s kann nicht gelöscht werden: %m"
 
-#: lto-wrapper.c:154
+#: lto-wrapper.c:155
 #, gcc-internal-format
 msgid "malformed COLLECT_GCC_OPTIONS"
 msgstr "ungültige COLLECT_GCC_OPTIONS"
 
-#: lto-wrapper.c:308
+#: lto-wrapper.c:309
 #, gcc-internal-format, gfc-internal-format
 msgid "Option %s with different values"
 msgstr "Option %s mit unterschiedlichen Werten"
 
-#: lto-wrapper.c:392
+#: lto-wrapper.c:393
 #, gcc-internal-format, gfc-internal-format
 msgid "Option %s not used consistently in all LTO input files"
 msgstr "Option %s nicht konsistent in allen LTO-Eingabedateien verwendet"
 
-#: lto-wrapper.c:832
+#: lto-wrapper.c:833
 #, gcc-internal-format, gfc-internal-format
 msgid "problem with building target image for %s\n"
 msgstr "Problem beim Erstellen des Zielbilds für %s\n"
 
-#: lto-wrapper.c:852
+#: lto-wrapper.c:853
 #, gcc-internal-format
 msgid "reading input file"
 msgstr "Eingabedatei wird gelesen"
 
-#: lto-wrapper.c:857
+#: lto-wrapper.c:858
 #, gcc-internal-format
 msgid "writing output file"
 msgstr "Ausgabedatei wird geschrieben"
 
-#: lto-wrapper.c:889
+#: lto-wrapper.c:890
 #, gcc-internal-format
 msgid "installation error, can't find crtoffloadtable.o"
 msgstr "Installationsfehler, crtoffloadtable.o kann nicht gefunden werden"
 
-#: lto-wrapper.c:1000 lto-wrapper.c:1012
+#: lto-wrapper.c:1001 lto-wrapper.c:1013
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: %s\n"
 msgstr "%s: %s\n"
 
-#: lto-wrapper.c:1056
+#: lto-wrapper.c:1064
 #, gcc-internal-format
 msgid "environment variable COLLECT_GCC must be set"
 msgstr "Umgebungsvariable COLLECT_GCC muss gesetzt sein"
 
-#: lto-wrapper.c:1060 config/nvptx/mkoffload.c:363
+#: lto-wrapper.c:1068 config/nvptx/mkoffload.c:363
 #, gcc-internal-format
 msgid "environment variable COLLECT_GCC_OPTIONS must be set"
 msgstr "Umgebungsvariable COLLECT_GCC_OPTIONS muss gesetzt sein"
 
-#: lto-wrapper.c:1229 lto-wrapper.c:1285
+#: lto-wrapper.c:1237 lto-wrapper.c:1293
 #, gcc-internal-format
 msgid "cannot open %s: %m"
 msgstr "%s kann nicht geöffnet werden: %m"
 
-#: lto-wrapper.c:1232 lto-wrapper.c:1291
+#: lto-wrapper.c:1240 lto-wrapper.c:1299
 #, gcc-internal-format
 msgid "cannot read %s: %m"
 msgstr "%s kann nicht gelesen werden: %m"
 
-#: lto-wrapper.c:1259
+#: lto-wrapper.c:1267
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid format of %s"
 msgstr "ungültiges Format von %s"
 
-#: lto-wrapper.c:1482
+#: lto-wrapper.c:1491
 #, gcc-internal-format
 msgid "fopen: %s: %m"
 msgstr "fopen %s: %m"
 
+#: lto-wrapper.c:1508
+#, gcc-internal-format, gfc-internal-format
+msgid "Corrupted ltrans output file %s"
+msgstr "Beschädigte ltrans-Ausgabedatei %s"
+
 #: multiple_target.c:76
 #, gcc-internal-format
 msgid "the call requires ifunc, which is not supported by this target"
@@ -20466,12 +20482,12 @@
 msgid "unrecognized argument in option %qs"
 msgstr "nicht erkanntes Kommandozeilenargument in Option %qs"
 
-#: opts-common.c:1198 config/i386/i386.c:3206
+#: opts-common.c:1198 config/i386/i386.c:3209
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "gültige Argumente für %qs sind: %s; meinten Sie %qs?"
 
-#: opts-common.c:1201 config/i386/i386.c:3209
+#: opts-common.c:1201 config/i386/i386.c:3212
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "gültige Argumente für %qs sind: %s"
@@ -21068,22 +21084,22 @@
 msgid "output operand %d must use %<&%> constraint"
 msgstr "Ausgabeoperand %d muss %<&%>-Bedingung verwenden"
 
-#: regcprop.c:1187
+#: regcprop.c:1193
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad next_regno for empty chain (%u)"
 msgstr "validate_value_data: [%u] Falsches next_regno für leere Kette (%u)"
 
-#: regcprop.c:1199
+#: regcprop.c:1205
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: Loop in regno chain (%u)"
 msgstr "validate_value_data: Zyklus in regno-Kette (%u)"
 
-#: regcprop.c:1202
+#: regcprop.c:1208
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad oldest_regno (%u)"
 msgstr "validate_value_data: [%u] Falsches oldest_regno (%u)"
 
-#: regcprop.c:1214
+#: regcprop.c:1220
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Non-empty reg in chain (%s %u %i)"
 msgstr "validate_value_data: [%u] Nicht leeres Register in Kette (%s %u %i)"
@@ -21127,7 +21143,7 @@
 msgstr "Register von %qD für mehrere globale Registervariablen verwendet"
 
 #: reginfo.c:789 config/powerpcspe/powerpcspe.c:32259
-#: config/rs6000/rs6000.c:29453
+#: config/rs6000/rs6000.c:29530
 #, gcc-internal-format
 msgid "conflicts with %qD"
 msgstr "Konflikt mit %qD"
@@ -21374,177 +21390,182 @@
 msgid "function symbol is not function"
 msgstr "Interner Fehler: function symbol is not function"
 
+#: symtab.c:1005
+#, gcc-internal-format
+msgid "inconsistent `ifunc' attribute"
+msgstr "inkonsistentes `ifunc'-Attribut"
+
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.c:1006
+#: symtab.c:1013
 #, gcc-internal-format
 msgid "variable symbol is not variable"
 msgstr "Interner Fehler: variable symbol is not variable"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.c:1012
+#: symtab.c:1019
 #, gcc-internal-format
 msgid "node has unknown type"
 msgstr "Interner Fehler: node has unknown type"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.c:1021
+#: symtab.c:1028
 #, gcc-internal-format
 msgid "node not found node->decl->decl_with_vis.symtab_node"
 msgstr "Interner Fehler: node not found node->decl->decl_with_vis.symtab_node"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.c:1029
+#: symtab.c:1036
 #, gcc-internal-format
 msgid "node differs from node->decl->decl_with_vis.symtab_node"
 msgstr "Interner Fehler: node differs from node->decl->decl_with_vis.symtab_node"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.c:1038
+#: symtab.c:1045
 #, gcc-internal-format
 msgid "assembler name hash list corrupted"
 msgstr "Interner Fehler: assembler name hash list corrupted"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.c:1051
+#: symtab.c:1058
 #, gcc-internal-format
 msgid "node not found in symtab assembler name hash"
 msgstr "Interner Fehler: node not found in symtab assembler name hash"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.c:1058
+#: symtab.c:1065
 #, gcc-internal-format
 msgid "double linked list of assembler names corrupted"
 msgstr "Interner Fehler: double linked list of assembler names corrupted"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.c:1063
+#: symtab.c:1070
 #, gcc-internal-format
 msgid "node has body_removed but is definition"
 msgstr "Interner Fehler: node has body_removed but is definition"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.c:1068
+#: symtab.c:1075
 #, gcc-internal-format
 msgid "node is analyzed but it is not a definition"
 msgstr "Interner Fehler: node is analyzed but it is not a definition"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.c:1073
+#: symtab.c:1080
 #, gcc-internal-format
 msgid "node is alias but not implicit alias"
 msgstr "Interner Fehler: node is alias but not implicit alias"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.c:1078
+#: symtab.c:1085
 #, gcc-internal-format
 msgid "node is alias but not definition"
 msgstr "Interner Fehler: node is alias but not definition"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.c:1083
+#: symtab.c:1090
 #, gcc-internal-format
 msgid "node is weakref but not an transparent_alias"
 msgstr "Interner Fehler: node is weakref but not an transparent_alias"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.c:1088
+#: symtab.c:1095
 #, gcc-internal-format
 msgid "node is transparent_alias but not an alias"
 msgstr "Interner Fehler: node is transparent_alias but not an alias"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.c:1097
+#: symtab.c:1104
 #, gcc-internal-format
 msgid "node is in same_comdat_group list but has no comdat_group"
 msgstr "Interner Fehler: node is in same_comdat_group list but has no comdat_group"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.c:1102
+#: symtab.c:1109
 #, gcc-internal-format
 msgid "same_comdat_group list across different groups"
 msgstr "Interner Fehler: same_comdat_group list across different groups"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.c:1107
+#: symtab.c:1114
 #, gcc-internal-format
 msgid "mixing different types of symbol in same comdat groups is not supported"
 msgstr "Interner Fehler: mixing different types of symbol in same comdat groups is not supported"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.c:1112
+#: symtab.c:1119
 #, gcc-internal-format
 msgid "node is alone in a comdat group"
 msgstr "Interner Fehler: node is alone in a comdat group"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.c:1119
+#: symtab.c:1126
 #, gcc-internal-format
 msgid "same_comdat_group is not a circular list"
 msgstr "Interner Fehler: same_comdat_group is not a circular list"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.c:1134
+#: symtab.c:1141
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local symbol referred to by %s outside its comdat"
 msgstr "Interner Fehler: comdat-local symbol referred to by %s outside its comdat"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.c:1144
+#: symtab.c:1151
 #, gcc-internal-format
 msgid "implicit_section flag is set but section isn't"
 msgstr "Interner Fehler: implicit_section flag is set but section isn't"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.c:1151
+#: symtab.c:1158
 #, gcc-internal-format
 msgid "Both section and comdat group is set"
 msgstr "Interner Fehler: Both section and comdat group is set"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.c:1163
+#: symtab.c:1170
 #, gcc-internal-format
 msgid "Alias and target's section differs"
 msgstr "Interner Fehler: Alias and target's section differs"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.c:1170
+#: symtab.c:1177
 #, gcc-internal-format
 msgid "Alias and target's comdat groups differs"
 msgstr "Interner Fehler: Alias and target's comdat groups differs"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.c:1185
+#: symtab.c:1192
 #, gcc-internal-format
 msgid "Transparent alias and target's assembler names differs"
 msgstr "Interner Fehler: Transparent alias and target's assembler names differs"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79874
-#: symtab.c:1193
+#: symtab.c:1200
 #, gcc-internal-format
 msgid "Chained transparent aliases"
 msgstr "Interner Fehler: Chained transparent aliases"
 
-#: symtab.c:1216 symtab.c:1253
+#: symtab.c:1223 symtab.c:1260
 #, gcc-internal-format
 msgid "symtab_node::verify failed"
 msgstr "Interner Fehler: symtab_node::verify failed"
 
-#: symtab.c:1249
+#: symtab.c:1256
 #, gcc-internal-format
 msgid "Two symbols with same comdat_group are not linked by the same_comdat_group list."
 msgstr "Interner Fehler: Two symbols with same comdat_group are not linked by the same_comdat_group list."
 
-#: symtab.c:1658
+#: symtab.c:1665
 #, gcc-internal-format
 msgid "function %q+D part of alias cycle"
 msgstr "Funktion %q+D Teil des Alias-Zyklus"
 
-#: symtab.c:1660
+#: symtab.c:1667
 #, gcc-internal-format
 msgid "variable %q+D part of alias cycle"
 msgstr "Variable %q+D Teil des Alias-Zyklus"
 
-#: symtab.c:1688
+#: symtab.c:1695
 #, gcc-internal-format
 msgid "section of alias %q+D must match section of its target"
 msgstr "Abschnitt des Aliases %q+D muss zum Abschnitt seines Ziels passen"
@@ -22346,7 +22367,7 @@
 msgid "the first argument of a VEC_COND_EXPR must be of a boolean vector type of the same number of elements as the result"
 msgstr "das erste Argument eines VEC_COND_EXPR-Ausdrucks muss von booleschem Vektortyp sein und gleich viele Elemente wie das Ergebnis haben"
 
-#: tree-cfg.c:4395 c/c-typeck.c:5212
+#: tree-cfg.c:4395 c/c-typeck.c:5217
 #, gcc-internal-format
 msgid "type mismatch in conditional expression"
 msgstr "Typ passt nicht in bedingtem Ausdruck"
@@ -22719,22 +22740,22 @@
 msgid "missing edge %i->%i"
 msgstr "Fehlende Kante %i->%i"
 
-#: tree-cfg.c:9379
+#: tree-cfg.c:9388
 #, gcc-internal-format
 msgid "%<noreturn%> function does return"
 msgstr "%<noreturn%>-Funktion kehrt zurück"
 
-#: tree-cfg.c:9400 tree-cfg.c:9432
+#: tree-cfg.c:9409 tree-cfg.c:9441
 #, gcc-internal-format
 msgid "control reaches end of non-void function"
 msgstr "Kontrollfluss erreicht Ende von Nicht-void-Funktion"
 
-#: tree-cfg.c:9498 cp/cvt.c:1039
+#: tree-cfg.c:9507 cp/cvt.c:1039
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgstr "Der Rückgabewert von %qD, der mit dem Attribut warn_unused_result deklariert wurde, wird ignoriert"
 
-#: tree-cfg.c:9503 cp/cvt.c:1046
+#: tree-cfg.c:9512 cp/cvt.c:1046
 #, gcc-internal-format
 msgid "ignoring return value of function declared with attribute warn_unused_result"
 msgstr "Rückgabewert der mit dem Attribut warn_unused_result definierten Funktion wird ignoriert"
@@ -22999,46 +23020,46 @@
 msgid "stmt volatile flag not up-to-date"
 msgstr "volatile-Kennzeichen für Anweisung nicht aktuell"
 
-#: tree-ssa-strlen.c:1975
+#: tree-ssa-strlen.c:1999
 msgid "%G%qD output truncated before terminating nul copying %E byte from a string of the same length"
 msgid_plural "%G%qD output truncated before terminating nul copying %E bytes from a string of the same length"
 msgstr[0] "%G%qD Ausgabe abgeschnitten vor dem abschließenden NUL, beim Kopieren von %E Byte aus einem String derselben Länge"
 msgstr[1] "%G%qD Ausgabe abgeschnitten vor dem abschließenden NUL, beim Kopieren von %E Bytes aus einem String derselben Länge"
 
-#: tree-ssa-strlen.c:1989
+#: tree-ssa-strlen.c:2013
 msgid "%G%qD output truncated copying %E byte from a string of length %wu"
 msgid_plural "%G%qD output truncated copying %E bytes from a string of length %wu"
 msgstr[0] "%G%qD Ausgabe abgeschnitten, beim Kopieren von %E Byte aus einer Zeichenkette der Länge %wu"
 msgstr[1] "%G%qD Ausgabe abgeschnitten, beim Kopieren von %E Bytes aus einer Zeichenkette der Länge %wu"
 
-#: tree-ssa-strlen.c:1996
+#: tree-ssa-strlen.c:2020
 msgid "%G%qD output truncated copying between %wu and %wu bytes from a string of length %wu"
 msgstr "%G%qD Ausgabe abgeschnitten, beim Kopieren von %wu bis %wu Bytes aus einer Zeichenkette der Länge %wu"
 
-#: tree-ssa-strlen.c:2008
+#: tree-ssa-strlen.c:2032
 msgid "%G%qD output may be truncated copying %E byte from a string of length %wu"
 msgid_plural "%G%qD output may be truncated copying %E bytes from a string of length %wu"
 msgstr[0] "%G%qD Ausgabe möglicherweise abgeschnitten, beim Kopieren von %E Byte aus einer Zeichenkette der Länge %wu"
 msgstr[1] "%G%qD Ausgabe möglicherweise abgeschnitten, beim Kopieren von %E Bytes aus einer Zeichenkette der Länge %wu"
 
-#: tree-ssa-strlen.c:2015 tree-ssa-strlen.c:2029
+#: tree-ssa-strlen.c:2039 tree-ssa-strlen.c:2053
 msgid "%G%qD output may be truncated copying between %wu and %wu bytes from a string of length %wu"
 msgstr "%G%qD Ausgabe möglicherweise abgeschnitten, beim Kopieren von %wu bis %wu Byte aus einer Zeichenkette der Länge %wu"
 
-#: tree-ssa-strlen.c:2150
+#: tree-ssa-strlen.c:2174
 msgid "%G%qD output truncated before terminating nul copying as many bytes from a string as its length"
 msgstr "%G%qD Ausgabe abgeschnitten vor dem beendenden NUL, beim Kopieren von so vielen Bytes aus einer Zeichenkette, wie die Ausgabezeichenkette lang ist"
 
-#: tree-ssa-strlen.c:2156
+#: tree-ssa-strlen.c:2180
 msgid "%G%qD specified bound depends on the length of the source argument"
 msgstr "%G%qD angegebene Grenze hängt von der Länge des Quellarguments ab"
 
-#: tree-ssa-strlen.c:2163
+#: tree-ssa-strlen.c:2187
 #, gcc-internal-format
 msgid "length computed here"
 msgstr "Länge wird hier berechnet"
 
-#: tree-ssa-uninit.c:191 varasm.c:331
+#: tree-ssa-uninit.c:191 varasm.c:342
 #, gcc-internal-format
 msgid "%qD was declared here"
 msgstr "%qD wurde hier deklariert"
@@ -23227,27 +23248,27 @@
 msgid "target specific builtin not available"
 msgstr "zielspezifische eingebaute Funktion ist nicht verfügbar"
 
-#: tree-vect-generic.c:287
+#: tree-vect-generic.c:283
 #, gcc-internal-format
 msgid "vector operation will be expanded piecewise"
 msgstr "Vektoroperation wird stückweise ausgeweitet"
 
-#: tree-vect-generic.c:290
+#: tree-vect-generic.c:286
 #, gcc-internal-format
 msgid "vector operation will be expanded in parallel"
 msgstr "Vektoroperation wird parallel ausgeweitet"
 
-#: tree-vect-generic.c:341
+#: tree-vect-generic.c:337
 #, gcc-internal-format
 msgid "vector operation will be expanded with a single scalar operation"
 msgstr "Vektoroperation wird mit einzelner skalarer Operation ausgeweitet"
 
-#: tree-vect-generic.c:941
+#: tree-vect-generic.c:937
 #, gcc-internal-format
 msgid "vector condition will be expanded piecewise"
 msgstr "Vektorbedingung wird stückweise ausgeweitet"
 
-#: tree-vect-generic.c:1373
+#: tree-vect-generic.c:1369
 #, gcc-internal-format
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr "Vektorumverteilungsoperation wird stückweise ausgeweitet"
@@ -23257,27 +23278,27 @@
 msgid "vectorization did not happen for a simd loop"
 msgstr "Vektorisierung für eine SIMD-Schleife nicht durchgeführt"
 
-#: tree-vrp.c:4930 tree-vrp.c:4974
+#: tree-vrp.c:4931 tree-vrp.c:4975
 #, gcc-internal-format
 msgid "array subscript %E is above array bounds of %qT"
 msgstr "Arrayindex %E ist oberhalb der Arraygrenze von %qT"
 
-#: tree-vrp.c:4956
+#: tree-vrp.c:4957
 #, gcc-internal-format
 msgid "array subscript [%E, %E] is outside array bounds of %qT"
 msgstr "Arrayindex [%E, %E] ist außerhalb der Arraygrenzen von %qT"
 
-#: tree-vrp.c:4988
+#: tree-vrp.c:4989
 #, gcc-internal-format
 msgid "array subscript %E is below array bounds of %qT"
 msgstr "Arrayindex %E ist unterhalb der Arraygrenze von %qT"
 
-#: tree-vrp.c:5046
+#: tree-vrp.c:5047
 #, gcc-internal-format
 msgid "array subscript %wi is below array bounds of %qT"
 msgstr "Arrayindex %wi ist unterhalb der Arraygrenze von %qT"
 
-#: tree-vrp.c:5060
+#: tree-vrp.c:5061
 #, gcc-internal-format
 msgid "array subscript %wu is above array bounds of %qT"
 msgstr "Arrayindex %wu ist oberhalb der Arraygrenze von %qT"
@@ -23292,92 +23313,92 @@
 msgid "side-effects element in no-side-effects CONSTRUCTOR"
 msgstr "side-effects element in no-side-effects CONSTRUCTOR"
 
-#: tree.c:7852
+#: tree.c:7856
 #, gcc-internal-format
 msgid "arrays of functions are not meaningful"
 msgstr "Arrays von Funktionen sind sinnlos"
 
-#: tree.c:8019
+#: tree.c:8023
 #, gcc-internal-format
 msgid "function return type cannot be function"
 msgstr "Rückgabetyp der Funktion kann keine Funktion sein"
 
-#: tree.c:9327 tree.c:9412 tree.c:9473
+#: tree.c:9331 tree.c:9416 tree.c:9477
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: %s, have %s in %s, at %s:%d"
 msgstr "tree check: %s, have %s in %s, at %s:%d"
 
-#: tree.c:9364
+#: tree.c:9368
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected none of %s, have %s in %s, at %s:%d"
 msgstr "tree check: expected none of %s, have %s in %s, at %s:%d"
 
-#: tree.c:9377
+#: tree.c:9381
 #, gcc-internal-format
 msgid "tree check: expected class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "tree check: expected class %qs, have %qs (%s) in %s, at %s:%d"
 
-#: tree.c:9426
+#: tree.c:9430
 #, gcc-internal-format
 msgid "tree check: did not expect class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "tree check: did not expect class %qs, have %qs (%s) in %s, at %s:%d"
 
-#: tree.c:9439
+#: tree.c:9443
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected omp_clause %s, have %s in %s, at %s:%d"
 msgstr "tree check: expected omp_clause %s, have %s in %s, at %s:%d"
 
-#: tree.c:9499
+#: tree.c:9503
 #, gcc-internal-format
 msgid "tree check: expected tree that contains %qs structure, have %qs in %s, at %s:%d"
 msgstr "tree check: expected tree that contains %qs structure, have %qs in %s, at %s:%d"
 
-#: tree.c:9513
+#: tree.c:9517
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_int_cst with %d elts in %s, at %s:%d"
 msgstr "tree check: accessed elt %d of tree_int_cst with %d elts in %s, at %s:%d"
 
-#: tree.c:9525
+#: tree.c:9529
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_vec with %d elts in %s, at %s:%d"
 msgstr "tree check: accessed elt %d of tree_vec with %d elts in %s, at %s:%d"
 
-#: tree.c:9538
+#: tree.c:9542
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of %s with %d operands in %s, at %s:%d"
 msgstr "tree check: accessed operand %d of %s with %d operands in %s, at %s:%d"
 
-#: tree.c:9551
+#: tree.c:9555
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of omp_clause %s with %d operands in %s, at %s:%d"
 msgstr "tree check: accessed operand %d of omp_clause %s with %d operands in %s, at %s:%d"
 
-#: tree.c:12446
+#: tree.c:12450
 #, gcc-internal-format
 msgid "%qD is deprecated: %s"
 msgstr "%qD ist veraltet: %s"
 
-#: tree.c:12449
+#: tree.c:12453
 #, gcc-internal-format
 msgid "%qD is deprecated"
 msgstr "%qD ist veraltet"
 
-#: tree.c:12473 tree.c:12495
+#: tree.c:12477 tree.c:12499
 #, gcc-internal-format
 msgid "%qE is deprecated: %s"
 msgstr "%qE ist veraltet: %s"
 
-#: tree.c:12476 tree.c:12498
+#: tree.c:12480 tree.c:12502
 #, gcc-internal-format
 msgid "%qE is deprecated"
 msgstr "%qE ist veraltet"
 
-#: tree.c:12482 tree.c:12503
+#: tree.c:12486 tree.c:12507
 #, gcc-internal-format, gfc-internal-format
 msgid "type is deprecated: %s"
 msgstr "Typ ist veraltet: %s"
 
-#: tree.c:12485 tree.c:12506
+#: tree.c:12489 tree.c:12510
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr "Typ ist veraltet"
@@ -23402,242 +23423,242 @@
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.c:13043
+#: tree.c:13047
 #, gcc-internal-format, gfc-internal-format
 msgid "type variant differs by %s"
 msgstr "Interner Fehler: type variant differs by %s"
 
-#: tree.c:13084
+#: tree.c:13088
 #, gcc-internal-format
 msgid "type variant has different TYPE_SIZE_UNIT"
 msgstr "Typvariante hat unterschiedliche TYPE_SIZE_UNIT"
 
-#: tree.c:13086
+#: tree.c:13090
 #, gcc-internal-format
 msgid "type variant's TYPE_SIZE_UNIT"
 msgstr "TYPE_SIZE_UNIT der Typvariante"
 
-#: tree.c:13088
+#: tree.c:13092
 #, gcc-internal-format
 msgid "type's TYPE_SIZE_UNIT"
 msgstr "TYPE_SIZE_UNIT des Typs"
 
-#: tree.c:13108
+#: tree.c:13112
 #, gcc-internal-format
 msgid "type variant with TYPE_ALIAS_SET_KNOWN_P"
 msgstr "type variant with TYPE_ALIAS_SET_KNOWN_P"
 
-#: tree.c:13121
+#: tree.c:13125
 #, gcc-internal-format
 msgid "type variant has different TYPE_VFIELD"
 msgstr "type variant has different TYPE_VFIELD"
 
-#: tree.c:13157
+#: tree.c:13161
 #, gcc-internal-format
 msgid "type variant has different TYPE_BINFO"
 msgstr "type variant has different TYPE_BINFO"
 
-#: tree.c:13159
+#: tree.c:13163
 #, gcc-internal-format
 msgid "type variant's TYPE_BINFO"
 msgstr "type variant's TYPE_BINFO"
 
-#: tree.c:13161
+#: tree.c:13165
 #, gcc-internal-format
 msgid "type's TYPE_BINFO"
 msgstr "type's TYPE_BINFO"
 
-#: tree.c:13199
+#: tree.c:13203
 #, gcc-internal-format
 msgid "type variant has different TYPE_FIELDS"
 msgstr "type variant has different TYPE_FIELDS"
 
-#: tree.c:13201
+#: tree.c:13205
 #, gcc-internal-format
 msgid "first mismatch is field"
 msgstr "first mismatch is field"
 
-#: tree.c:13203
+#: tree.c:13207
 #, gcc-internal-format
 msgid "and field"
 msgstr "and field"
 
-#: tree.c:13220
+#: tree.c:13224
 #, gcc-internal-format
 msgid "type variant has different TREE_TYPE"
 msgstr "type variant has different TREE_TYPE"
 
-#: tree.c:13222 tree.c:13233
+#: tree.c:13226 tree.c:13237
 #, gcc-internal-format
 msgid "type variant's TREE_TYPE"
 msgstr "type variant's TREE_TYPE"
 
-#: tree.c:13224 tree.c:13235
+#: tree.c:13228 tree.c:13239
 #, gcc-internal-format
 msgid "type's TREE_TYPE"
 msgstr "type's TREE_TYPE"
 
-#: tree.c:13231
+#: tree.c:13235
 #, gcc-internal-format
 msgid "type is not compatible with its variant"
 msgstr "type is not compatible with its variant"
 
-#: tree.c:13534
+#: tree.c:13538
 #, gcc-internal-format
 msgid "Main variant is not defined"
 msgstr "Main variant is not defined"
 
-#: tree.c:13539
+#: tree.c:13543
 #, gcc-internal-format
 msgid "TYPE_MAIN_VARIANT has different TYPE_MAIN_VARIANT"
 msgstr "TYPE_MAIN_VARIANT has different TYPE_MAIN_VARIANT"
 
-#: tree.c:13551
+#: tree.c:13555
 #, gcc-internal-format
 msgid "TYPE_CANONICAL has different TYPE_CANONICAL"
 msgstr "TYPE_CANONICAL has different TYPE_CANONICAL"
 
-#: tree.c:13569
+#: tree.c:13573
 #, gcc-internal-format
 msgid "TYPE_CANONICAL is not compatible"
 msgstr "TYPE_CANONICAL is not compatible"
 
-#: tree.c:13577
+#: tree.c:13581
 #, gcc-internal-format
 msgid "TYPE_MODE of TYPE_CANONICAL is not compatible"
 msgstr "TYPE_MODE of TYPE_CANONICAL is not compatible"
 
-#: tree.c:13583
+#: tree.c:13587
 #, gcc-internal-format
 msgid "TYPE_CANONICAL of main variant is not main variant"
 msgstr "TYPE_CANONICAL of main variant is not main variant"
 
-#: tree.c:13599
+#: tree.c:13603
 #, gcc-internal-format
 msgid "TYPE_VFIELD is not FIELD_DECL nor TREE_LIST"
 msgstr "TYPE_VFIELD is not FIELD_DECL nor TREE_LIST"
 
-#: tree.c:13609
+#: tree.c:13613
 #, gcc-internal-format
 msgid "TYPE_NEXT_PTR_TO is not POINTER_TYPE"
 msgstr "TYPE_NEXT_PTR_TO is not POINTER_TYPE"
 
-#: tree.c:13619
+#: tree.c:13623
 #, gcc-internal-format
 msgid "TYPE_NEXT_REF_TO is not REFERENCE_TYPE"
 msgstr "TYPE_NEXT_REF_TO is not REFERENCE_TYPE"
 
-#: tree.c:13640
+#: tree.c:13644
 #, gcc-internal-format
 msgid "TYPE_BINFO is not TREE_BINFO"
 msgstr "TYPE_BINFO is not TREE_BINFO"
 
-#: tree.c:13646
+#: tree.c:13650
 #, gcc-internal-format
 msgid "TYPE_BINFO type is not TYPE_MAIN_VARIANT"
 msgstr "TYPE_BINFO type is not TYPE_MAIN_VARIANT"
 
-#: tree.c:13657
+#: tree.c:13661
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not record nor union"
 msgstr "TYPE_METHOD_BASETYPE is not record nor union"
 
-#: tree.c:13668
+#: tree.c:13672
 #, gcc-internal-format
 msgid "TYPE_OFFSET_BASETYPE is not record nor union"
 msgstr "TYPE_OFFSET_BASETYPE is not record nor union"
 
-#: tree.c:13686
+#: tree.c:13690
 #, gcc-internal-format
 msgid "TYPE_ARRAY_MAX_SIZE not INTEGER_CST"
 msgstr "TYPE_ARRAY_MAX_SIZE not INTEGER_CST"
 
-#: tree.c:13693
+#: tree.c:13697
 #, gcc-internal-format
 msgid "TYPE_MAX_VALUE_RAW non-NULL"
 msgstr "TYPE_MAXVAL_VALUE_RAW ist nicht NULL"
 
-#: tree.c:13700
+#: tree.c:13704
 #, gcc-internal-format
 msgid "TYPE_LANG_SLOT_1 (binfo) field is non-NULL"
 msgstr "TYPE_LANG_SLOT_1 (binfo) field is non-NULL"
 
-#: tree.c:13716
+#: tree.c:13720
 #, gcc-internal-format
 msgid "Enum value is not CONST_DECL or INTEGER_CST"
 msgstr "Enum value is not CONST_DECL or INTEGER_CST"
 
-#: tree.c:13724
+#: tree.c:13728
 #, gcc-internal-format
 msgid "Enum value type is not INTEGER_TYPE nor convertible to the enum"
 msgstr "Enum value type is not INTEGER_TYPE nor convertible to the enum"
 
-#: tree.c:13731
+#: tree.c:13735
 #, gcc-internal-format
 msgid "Enum value name is not IDENTIFIER_NODE"
 msgstr "Enum value name is not IDENTIFIER_NODE"
 
-#: tree.c:13741
+#: tree.c:13745
 #, gcc-internal-format
 msgid "Array TYPE_DOMAIN is not integer type"
 msgstr "Array TYPE_DOMAIN is not integer type"
 
-#: tree.c:13750
+#: tree.c:13754
 #, gcc-internal-format
 msgid "TYPE_FIELDS defined in incomplete type"
 msgstr "TYPE_FIELDS defined in incomplete type"
 
-#: tree.c:13772
+#: tree.c:13776
 #, gcc-internal-format
 msgid "Wrong tree in TYPE_FIELDS list"
 msgstr "Wrong tree in TYPE_FIELDS list"
 
-#: tree.c:13787
+#: tree.c:13791
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is %i while TYPE_CACHED_VALUES is %p"
 msgstr "TYPE_CACHED_VALUES_P is %i while TYPE_CACHED_VALUES is %p"
 
-#: tree.c:13793
+#: tree.c:13797
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES is not TREE_VEC"
 msgstr "TYPE_CACHED_VALUES is not TREE_VEC"
 
-#: tree.c:13806
+#: tree.c:13810
 #, gcc-internal-format
 msgid "wrong TYPE_CACHED_VALUES entry"
 msgstr "wrong TYPE_CACHED_VALUES entry"
 
-#: tree.c:13819
+#: tree.c:13823
 #, gcc-internal-format
 msgid "TREE_PURPOSE is non-NULL in TYPE_ARG_TYPES list"
 msgstr "TREE_PURPOSE is non-NULL in TYPE_ARG_TYPES list"
 
-#: tree.c:13825
+#: tree.c:13829
 #, gcc-internal-format
 msgid "Wrong entry in TYPE_ARG_TYPES list"
 msgstr "Wrong entry in TYPE_ARG_TYPES list"
 
-#: tree.c:13832
+#: tree.c:13836
 #, gcc-internal-format
 msgid "TYPE_VALUES_RAW field is non-NULL"
 msgstr "TYPE_VALUES_RAW field is non-NULL"
 
-#: tree.c:13844
+#: tree.c:13848
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is set while it should not"
 msgstr "Interner Fehler: TYPE_CACHED_VALUES_P is set while it should not"
 
-#: tree.c:13850
+#: tree.c:13854
 #, gcc-internal-format
 msgid "TYPE_STRING_FLAG is set on wrong type code"
 msgstr "TYPE_STRING_FLAG is set on wrong type code"
 
-#: tree.c:13860
+#: tree.c:13864
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not main variant"
 msgstr "TYPE_METHOD_BASETYPE is not main variant"
 
-#: tree.c:13867
+#: tree.c:13871
 #, gcc-internal-format
 msgid "verify_type failed"
 msgstr "verify_type failed"
@@ -23662,182 +23683,182 @@
 msgid "corrupted value profile: %s profile counter (%d out of %d) inconsistent with basic-block count (%d)"
 msgstr "kaputtes Werteprofil: %s-Profilzähler (%d von %d) ist inkonsistent zu Basisblock-Zähler (%d)"
 
-#: var-tracking.c:7166
+#: var-tracking.c:7184
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded with -fvar-tracking-assignments, retrying without"
 msgstr "Obere Größengrenze zur Variablenverfolgung mit -fvar-tracking-assignments überschritten; neuer Versuch ohne"
 
-#: var-tracking.c:7170
+#: var-tracking.c:7188
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded"
 msgstr "Grenze zur Variablenverfolgung überschritten"
 
-#: varasm.c:326
+#: varasm.c:337
 #, gcc-internal-format
 msgid "%+qD causes a section type conflict with %qD"
 msgstr "%+qD löst einen Abschnittstypkonflikt mit %qD aus"
 
-#: varasm.c:329
+#: varasm.c:340
 #, gcc-internal-format
 msgid "section type conflict with %qD"
 msgstr "Abschnittstypkonflikt mit %qD"
 
-#: varasm.c:334
+#: varasm.c:345
 #, gcc-internal-format
 msgid "%+qD causes a section type conflict"
 msgstr "%+qD löst einen Abschnittstypkonflikt aus"
 
-#: varasm.c:336
+#: varasm.c:347
 #, gcc-internal-format
 msgid "section type conflict"
 msgstr "Abschnittstypkonflikt"
 
-#: varasm.c:1019
+#: varasm.c:1030
 #, gcc-internal-format
 msgid "alignment of %q+D is greater than maximum object file alignment %d"
 msgstr "Ausrichtung von %q+D ist größer als maximale Objektdateiausrichtung %d"
 
-#: varasm.c:1172
+#: varasm.c:1183
 #, gcc-internal-format
 msgid "only zero initializers are allowed in section %qs"
 msgstr "In Abschnitt %qs sind nur 0-Initialisierungen erlaubt"
 
-#: varasm.c:1378 varasm.c:1387
+#: varasm.c:1389 varasm.c:1398
 #, gcc-internal-format
 msgid "register name not specified for %q+D"
 msgstr "für %q+D wurde kein Registername angegeben"
 
-#: varasm.c:1389
+#: varasm.c:1400
 #, gcc-internal-format
 msgid "invalid register name for %q+D"
 msgstr "ungültiger Registername für %q+D"
 
-#: varasm.c:1391
+#: varasm.c:1402
 #, gcc-internal-format
 msgid "data type of %q+D isn%'t suitable for a register"
 msgstr "Datentyp von %q+D ist nicht für Register geeignet"
 
-#: varasm.c:1394
+#: varasm.c:1405
 #, gcc-internal-format
 msgid "the register specified for %q+D cannot be accessed by the current target"
 msgstr "für %q+D angegebenes Register kann vom aktuellen Ziel nicht zugegriffen werden"
 
-#: varasm.c:1397
+#: varasm.c:1408
 #, gcc-internal-format
 msgid "the register specified for %q+D is not general enough to be used as a register variable"
 msgstr "für %q+D angegebenes Register ist nicht allgemein genug, um als eine Registervariable verwendet zu werden"
 
-#: varasm.c:1400
+#: varasm.c:1411
 #, gcc-internal-format
 msgid "register specified for %q+D isn%'t suitable for data type"
 msgstr "für %q+D angegebenes Register eignet sich nicht für Datentyp"
 
-#: varasm.c:1410
+#: varasm.c:1421
 #, gcc-internal-format
 msgid "global register variable has initial value"
 msgstr "globale Registervariable hat Anfangswert"
 
-#: varasm.c:1414
+#: varasm.c:1425
 #, gcc-internal-format
 msgid "optimization may eliminate reads and/or writes to register variables"
 msgstr "Optimierung kann Lese- und/oder Schreiboperationen auf Registervariablen entfernen"
 
-#: varasm.c:1460
+#: varasm.c:1471
 #, gcc-internal-format
 msgid "register name given for non-register variable %q+D"
 msgstr "Registername für Nicht-Registervariable %q+D angegeben"
 
-#: varasm.c:1870
+#: varasm.c:1881
 #, gcc-internal-format
 msgid "Patchable function entry > size"
 msgstr "Eintrag für patchbare Funktion > Größe"
 
-#: varasm.c:2069
+#: varasm.c:2080
 #, gcc-internal-format
 msgid "thread-local COMMON data not implemented"
 msgstr "Thread-lokale COMMON-Daten nicht implementiert"
 
-#: varasm.c:2102
+#: varasm.c:2113
 #, gcc-internal-format
 msgid "requested alignment for %q+D is greater than implemented alignment of %wu"
 msgstr "angeforderte Ausrichtung für %q+D ist größer als die implementierte Ausrichtung von %wu"
 
-#: varasm.c:2205 c/c-decl.c:5027 c/c-parser.c:1534
+#: varasm.c:2216 c/c-decl.c:5027 c/c-parser.c:1534
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t known"
 msgstr "Speichergröße von %q+D ist unbekannt"
 
-#: varasm.c:4910
+#: varasm.c:4921
 #, gcc-internal-format
 msgid "initializer for integer/fixed-point value is too complicated"
 msgstr "Initialisierung für Ganzzahl-/Gleitkommazahlwert ist zu kompliziert"
 
-#: varasm.c:4915
+#: varasm.c:4926
 #, gcc-internal-format
 msgid "initializer for floating value is not a floating constant"
 msgstr "Initialisierung für Gleitkommawert ist keine Gleitkommakonstante"
 
-#: varasm.c:5227
+#: varasm.c:5238
 #, gcc-internal-format
 msgid "invalid initial value for member %qE"
 msgstr "ungültiger Anfangswert für Element %qE"
 
-#: varasm.c:5487
+#: varasm.c:5498
 #, gcc-internal-format
 msgid "%+qD declared weak after being used"
 msgstr "%+qD als schwach deklariert, nachdem es verwendet wurde"
 
-#: varasm.c:5539
+#: varasm.c:5550
 #, gcc-internal-format
 msgid "weak declaration of %q+D being applied to a already existing, static definition"
 msgstr "schwache Deklaration von %q+D wird auf bereits existierende »static«-Definition angewandt"
 
-#: varasm.c:5575
+#: varasm.c:5586
 #, gcc-internal-format
 msgid "weak declaration of %q+D must be public"
 msgstr "schwache Deklaration von %q+D muss öffentlich sein"
 
-#: varasm.c:5579
+#: varasm.c:5590
 #, gcc-internal-format
 msgid "weak declaration of %q+D not supported"
 msgstr "schwache Deklaration von %q+D wird nicht unterstützt"
 
-#: varasm.c:5608 varasm.c:5912
+#: varasm.c:5619 varasm.c:5926
 #, gcc-internal-format
 msgid "only weak aliases are supported in this configuration"
 msgstr "in dieser Konfiguration werden nur schwache Aliase unterstützt"
 
-#: varasm.c:5802
+#: varasm.c:5813
 #, gcc-internal-format
 msgid "weakref is not supported in this configuration"
 msgstr "weakref wird in dieser Konfiguration nicht unterstützt"
 
-#: varasm.c:5834
+#: varasm.c:5846
 #, gcc-internal-format
 msgid "ifunc is not supported on this target"
 msgstr "ifunc wird auf diesem Ziel nicht unterstützt"
 
-#: varasm.c:5892
+#: varasm.c:5904
 #, gcc-internal-format
 msgid "weakref %q+D ultimately targets itself"
 msgstr "weakref %q+D zielt letztendlich auf sich selbst ab"
 
-#: varasm.c:5894
+#: varasm.c:5906
 #, gcc-internal-format
 msgid "weakref %q+D must have static linkage"
 msgstr "schwache Referenz %q+D muss statische Bindung haben"
 
-#: varasm.c:5901
+#: varasm.c:5913
 #, gcc-internal-format
 msgid "alias definitions not supported in this configuration"
 msgstr "Alias-Definitionen werden in dieser Konfiguration nicht unterstützt"
 
-#: varasm.c:5909
+#: varasm.c:5923
 #, gcc-internal-format
 msgid "ifunc is not supported in this configuration"
 msgstr "ifunc wird in dieser Konfiguration nicht unterstützt"
 
-#: varasm.c:6127 config/sol2.c:159 config/i386/winnt.c:265
+#: varasm.c:6141 config/sol2.c:159 config/i386/winnt.c:265
 #, gcc-internal-format
 msgid "visibility attribute not supported in this configuration; ignored"
 msgstr "Sichtbarkeitsattribute werden in dieser Konfiguration nicht unterstützt; ignoriert"
@@ -23913,466 +23934,471 @@
 msgid "bytecode stream: tag %s is not in the expected range [%s, %s]"
 msgstr "bytecode stream: tag %s is not in the expected range [%s, %s]"
 
-#: c-family/c-attribs.c:529
+#: c-family/c-attribs.c:524
 #, gcc-internal-format
+msgid "%qE attribute ignored for type %qT"
+msgstr "%qE-Attribut für Typ %qT ignoriert"
+
+#: c-family/c-attribs.c:536
+#, gcc-internal-format
 msgid "%qE attribute ignored for field of type %qT"
 msgstr "Attribut %qE ignoriert für Feld vom Typ %qT"
 
-#: c-family/c-attribs.c:696
+#: c-family/c-attribs.c:706
 #, gcc-internal-format
 msgid "no_sanitize argument not a string"
 msgstr "Argument no_sanitize ist keine Zeichenkette"
 
-#: c-family/c-attribs.c:826 ada/gcc-interface/utils.c:6235
+#: c-family/c-attribs.c:837 ada/gcc-interface/utils.c:6240
 #, gcc-internal-format
 msgid "%qE attribute ignored due to conflict with attribute %qs"
 msgstr "Attribut %qE steht mit Attribut %qs in Konflikt; wird ignoriert"
 
-#: c-family/c-attribs.c:875
+#: c-family/c-attribs.c:886
 #, gcc-internal-format
 msgid "%qE attribute ignored. Use -fcf-protection option to enable it"
 msgstr "Attribut %qE ignoriert, da die Option »-fcf-protection« nicht angegeben ist"
 
-#: c-family/c-attribs.c:914 c-family/c-attribs.c:920 c-family/c-attribs.c:3388
-#: c-family/c-attribs.c:3423 c-family/c-attribs.c:3429
+#: c-family/c-attribs.c:925 c-family/c-attribs.c:931 c-family/c-attribs.c:3399
+#: c-family/c-attribs.c:3434 c-family/c-attribs.c:3440
 #, gcc-internal-format
 msgid "%qE attribute ignored due to conflict with %qs attribute"
 msgstr "Attribut %qE steht mit Attribut %qs in Konflikt; wird ignoriert"
 
-#: c-family/c-attribs.c:976 brig/brig-lang.c:482 lto/lto-lang.c:288
+#: c-family/c-attribs.c:987 brig/brig-lang.c:482 lto/lto-lang.c:288
 #, gcc-internal-format
 msgid "%qE attribute has no effect on unit local functions"
 msgstr "Attribut %qE wirkt sich nicht auf einheits-lokale Funktionen aus"
 
-#: c-family/c-attribs.c:1130
+#: c-family/c-attribs.c:1141
 #, gcc-internal-format
 msgid "%qE attribute have effect only on public objects"
 msgstr "Attribut %qE wirkt sich nur auf öffentliche Objekte aus"
 
-#: c-family/c-attribs.c:1159
+#: c-family/c-attribs.c:1170
 #, gcc-internal-format
 msgid "%qE attribute only affects top level objects"
 msgstr "Attribut %qE bezieht sich nur auf Toplevel-Objekte"
 
-#: c-family/c-attribs.c:1198 c-family/c-attribs.c:2682
+#: c-family/c-attribs.c:1209 c-family/c-attribs.c:2693
 #, gcc-internal-format
 msgid "%qE attribute on function returning %<void%>"
 msgstr "Attribut %qE an einer Funktion mit Rückgabetyp %<void%>"
 
-#: c-family/c-attribs.c:1221 c-family/c-pragma.c:419
+#: c-family/c-attribs.c:1232 c-family/c-pragma.c:419
 #, gcc-internal-format
 msgid "scalar_storage_order is not supported because endianness is not uniform"
 msgstr "scalar_storage_order wird nicht unterstützt, da die Endianess nicht einheitlich ist"
 
-#: c-family/c-attribs.c:1238
+#: c-family/c-attribs.c:1249
 #, gcc-internal-format
 msgid "scalar_storage_order argument must be one of \"big-endian\" or \"little-endian\""
 msgstr "Argument für scalar_storage_order muss entweder »big-endian« oder »little-endian« sein"
 
-#: c-family/c-attribs.c:1334
+#: c-family/c-attribs.c:1345
 #, gcc-internal-format
 msgid "destructor priorities are not supported"
 msgstr "Destruktorprioritäten werden nicht unterstützt"
 
-#: c-family/c-attribs.c:1336
+#: c-family/c-attribs.c:1347
 #, gcc-internal-format
 msgid "constructor priorities are not supported"
 msgstr "Konstruktorprioritäten werden nicht unterstützt"
 
-#: c-family/c-attribs.c:1358
+#: c-family/c-attribs.c:1369
 #, gcc-internal-format, gfc-internal-format
 msgid "destructor priorities from 0 to %d are reserved for the implementation"
 msgstr "Destruktorprioritäten von 0 bis %d sind für die Implementierung vorbehalten"
 
-#: c-family/c-attribs.c:1363
+#: c-family/c-attribs.c:1374
 #, gcc-internal-format, gfc-internal-format
 msgid "constructor priorities from 0 to %d are reserved for the implementation"
 msgstr "Konstruktorprioritäten von 0 bis %d sind für die Implementierung vorbehalten"
 
-#: c-family/c-attribs.c:1371
+#: c-family/c-attribs.c:1382
 #, gcc-internal-format, gfc-internal-format
 msgid "destructor priorities must be integers from 0 to %d inclusive"
 msgstr "Destruktorprioritäten müssen Ganzzahlen von 0 bis einschließlich %d sein"
 
-#: c-family/c-attribs.c:1374
+#: c-family/c-attribs.c:1385
 #, gcc-internal-format, gfc-internal-format
 msgid "constructor priorities must be integers from 0 to %d inclusive"
 msgstr "Konstruktorprioritäten müssen Ganzzahlen von 0 bis einschließlich %d sein"
 
-#: c-family/c-attribs.c:1527
+#: c-family/c-attribs.c:1538
 #, gcc-internal-format
 msgid "unknown machine mode %qE"
 msgstr "Unbekannter Maschinenzustand %qE"
 
-#: c-family/c-attribs.c:1557
+#: c-family/c-attribs.c:1568
 #, gcc-internal-format
 msgid "specifying vector types with __attribute__ ((mode)) is deprecated"
 msgstr "Angabe von Vektortypen mit __attribute__ ((Modus)) ist veraltet"
 
-#: c-family/c-attribs.c:1560
+#: c-family/c-attribs.c:1571
 #, gcc-internal-format
 msgid "use __attribute__ ((vector_size)) instead"
 msgstr "Stattdessen __attribute__ ((Vektorgröße)) verwenden"
 
-#: c-family/c-attribs.c:1569
+#: c-family/c-attribs.c:1580
 #, gcc-internal-format
 msgid "unable to emulate %qs"
 msgstr "%qs kann nicht emuliert werden"
 
-#: c-family/c-attribs.c:1582
+#: c-family/c-attribs.c:1593
 #, gcc-internal-format
 msgid "invalid pointer mode %qs"
 msgstr "Ungültiger Zeigermodus %qs"
 
-#: c-family/c-attribs.c:1599
+#: c-family/c-attribs.c:1610
 #, gcc-internal-format
 msgid "signedness of type and machine mode %qs don%'t match"
 msgstr "Vorzeicheneigenschaft des Typen und Maschinenmodus %qs passen nicht zusammen"
 
-#: c-family/c-attribs.c:1610
+#: c-family/c-attribs.c:1621
 #, gcc-internal-format
 msgid "no data type for mode %qs"
 msgstr "Kein Datentyp für Zustand %qs"
 
-#: c-family/c-attribs.c:1620
+#: c-family/c-attribs.c:1631
 #, gcc-internal-format
 msgid "cannot use mode %qs for enumeral types"
 msgstr "Modus %qs kann nicht für Aufzählungstypen verwendet werden"
 
-#: c-family/c-attribs.c:1647
+#: c-family/c-attribs.c:1658
 #, gcc-internal-format
 msgid "mode %qs applied to inappropriate type"
 msgstr "Modus %qs auf unpassenden Typen angewendet"
 
-#: c-family/c-attribs.c:1669
+#: c-family/c-attribs.c:1680
 #, gcc-internal-format
 msgid "section attributes are not supported for this target"
 msgstr "Abschnitts-Attribute werden für dieses Ziel nicht unterstützt"
 
-#: c-family/c-attribs.c:1675
+#: c-family/c-attribs.c:1686
 #, gcc-internal-format
 msgid "section attribute not allowed for %q+D"
 msgstr "Abschnitts-Attribut nicht erlaubt für %q+D"
 
-#: c-family/c-attribs.c:1681
+#: c-family/c-attribs.c:1692
 #, gcc-internal-format
 msgid "section attribute argument not a string constant"
 msgstr "Argument des Abschnittsattributs ist keine Zeichenkettenkonstante"
 
-#: c-family/c-attribs.c:1690
+#: c-family/c-attribs.c:1701
 #, gcc-internal-format
 msgid "section attribute cannot be specified for local variables"
 msgstr "Abschnitts-Attribut kann nicht für lokale Variablen angegeben werden"
 
-#: c-family/c-attribs.c:1700 config/bfin/bfin.c:4806 config/bfin/bfin.c:4857
+#: c-family/c-attribs.c:1711 config/bfin/bfin.c:4806 config/bfin/bfin.c:4857
 #: config/bfin/bfin.c:4883 config/bfin/bfin.c:4896
 #, gcc-internal-format
 msgid "section of %q+D conflicts with previous declaration"
 msgstr "Abschnitt von %q+D in Konflikt mit vorheriger Deklaration"
 
-#: c-family/c-attribs.c:1708
+#: c-family/c-attribs.c:1719
 #, gcc-internal-format
 msgid "section of %q+D cannot be overridden"
 msgstr "Abschnitt von %q+D kann nicht aufgehoben werden"
 
-#: c-family/c-attribs.c:1773
+#: c-family/c-attribs.c:1784
 #, gcc-internal-format, gfc-internal-format
 msgid "requested alignment %d is larger than %d"
 msgstr "verlangte Ausrichtung %d ist größer als %d"
 
-#: c-family/c-attribs.c:1866
+#: c-family/c-attribs.c:1877
 #, gcc-internal-format
 msgid "alignment may not be specified for %q+D"
 msgstr "Für %q+D darf keine Ausrichtung angegeben werden"
 
-#: c-family/c-attribs.c:1886
+#: c-family/c-attribs.c:1897
 #, gcc-internal-format
 msgid "ignoring attribute %<%E (%u)%> because it conflicts with attribute %<%E (%u)%>"
 msgstr "Attribut %<%E (%u)%> wird ignoriert, da es mit Attribut %<%E (%u)%> in Konflikt steht"
 
 #. Do not error out for attribute warn_if_not_aligned.
-#: c-family/c-attribs.c:1891 c-family/c-attribs.c:1920
+#: c-family/c-attribs.c:1902 c-family/c-attribs.c:1931
 #, gcc-internal-format
 msgid "alignment for %q+D must be at least %d"
 msgstr "Ausrichtung für %q+D muss mindestens %d sein"
 
-#: c-family/c-attribs.c:1916
+#: c-family/c-attribs.c:1927
 #, gcc-internal-format
 msgid "alignment for %q+D was previously specified as %d and may not be decreased"
 msgstr "Ausrichtung für %q+D wurde zuvor als %d angegeben und kann nicht verringert werden"
 
-#: c-family/c-attribs.c:1943
+#: c-family/c-attribs.c:1954
 #, gcc-internal-format
 msgid "%<warn_if_not_aligned%> may not be specified for %q+D"
 msgstr "Für %q+D darf %<warn_if_not_aligned%> nicht angegeben werden"
 
-#: c-family/c-attribs.c:1986
+#: c-family/c-attribs.c:1997
 #, gcc-internal-format
 msgid "inline function %q+D declared weak"
 msgstr "»inline«-Funktion %q+D als »schwach« deklariert"
 
-#: c-family/c-attribs.c:1991
+#: c-family/c-attribs.c:2002
 #, gcc-internal-format
 msgid "indirect function %q+D cannot be declared weak"
 msgstr "indirekte Funktion %q+D kann nicht als »schwach« deklariert werden"
 
-#: c-family/c-attribs.c:2015
+#: c-family/c-attribs.c:2026
 #, gcc-internal-format
 msgid "%qE attribute is only applicable on functions"
 msgstr "Attribut %qE bezieht sich nur auf Funktionen"
 
-#: c-family/c-attribs.c:2046
+#: c-family/c-attribs.c:2057
 #, gcc-internal-format
 msgid "%q+D defined both normally and as %qE attribute"
 msgstr "%q+D sowohl normal als auch als Attribut %qE definiert"
 
-#: c-family/c-attribs.c:2054
+#: c-family/c-attribs.c:2065
 #, gcc-internal-format
 msgid "weak %q+D cannot be defined %qE"
 msgstr "schwaches %q+D kann nicht als %qE definiert werden"
 
-#: c-family/c-attribs.c:2071 c-family/c-attribs.c:2582
+#: c-family/c-attribs.c:2082 c-family/c-attribs.c:2593
 #, gcc-internal-format
 msgid "attribute %qE argument not a string"
 msgstr "Attributargument von %qE ist keine Zeichenkette"
 
-#: c-family/c-attribs.c:2106
+#: c-family/c-attribs.c:2117
 #, gcc-internal-format
 msgid "%+qD declared alias after being used"
 msgstr "%+qD als »alias« deklariert, nachdem es verwendet wurde"
 
-#: c-family/c-attribs.c:2108
+#: c-family/c-attribs.c:2119
 #, gcc-internal-format
 msgid "%+qD declared ifunc after being used"
 msgstr "%+D als »ifunc« deklariert, nachdem es verwendet wurde"
 
-#: c-family/c-attribs.c:2159
+#: c-family/c-attribs.c:2170
 #, gcc-internal-format
 msgid "indirect function %q+D cannot be declared weakref"
 msgstr "indirekte Funktion %q+D kann nicht als »weakref« deklariert werden"
 
-#: c-family/c-attribs.c:2181
+#: c-family/c-attribs.c:2192
 #, gcc-internal-format
 msgid "weakref attribute must appear before alias attribute"
 msgstr "Attribut weakref muss vor Attribut alias auftreten"
 
-#: c-family/c-attribs.c:2193
+#: c-family/c-attribs.c:2204
 #, gcc-internal-format
 msgid "%+qD declared weakref after being used"
 msgstr "%+qD als »weakref« deklariert, nachdem es verwendet wurde"
 
-#: c-family/c-attribs.c:2217
+#: c-family/c-attribs.c:2228
 #, gcc-internal-format
 msgid "%qE attribute ignored on non-class types"
 msgstr "Attribut %qE ignoriert für Nicht-Klassen-Typen"
 
-#: c-family/c-attribs.c:2223
+#: c-family/c-attribs.c:2234
 #, gcc-internal-format
 msgid "%qE attribute ignored because %qT is already defined"
 msgstr "Attribut %qE ignoriert, da %qT bereits definiert ist"
 
-#: c-family/c-attribs.c:2236
+#: c-family/c-attribs.c:2247
 #, gcc-internal-format
 msgid "visibility argument not a string"
 msgstr "Sichtbarkeitsargument ist keine Zeichenkette"
 
-#: c-family/c-attribs.c:2248
+#: c-family/c-attribs.c:2259
 #, gcc-internal-format
 msgid "%qE attribute ignored on types"
 msgstr "Attribut %qE für Typen ignoriert"
 
-#: c-family/c-attribs.c:2264
+#: c-family/c-attribs.c:2275
 #, gcc-internal-format
 msgid "visibility argument must be one of \"default\", \"hidden\", \"protected\" or \"internal\""
 msgstr "Sichtbarkeitsargument muss »default«, »hidden«, »protected« oder »internal« sein"
 
-#: c-family/c-attribs.c:2275
+#: c-family/c-attribs.c:2286
 #, gcc-internal-format
 msgid "%qD redeclared with different visibility"
 msgstr "%qD mit anderer Sichtbarkeit redeklariert"
 
-#: c-family/c-attribs.c:2278 c-family/c-attribs.c:2282
+#: c-family/c-attribs.c:2289 c-family/c-attribs.c:2293
 #, gcc-internal-format
 msgid "%qD was declared %qs which implies default visibility"
 msgstr "%qD wurde als %qs deklariert, was Standardsichtbarkeit mit sich bringt"
 
-#: c-family/c-attribs.c:2320
+#: c-family/c-attribs.c:2331
 #, gcc-internal-format
 msgid "tls_model argument not a string"
 msgstr "Argument für tls_model ist keine Zeichenkette"
 
-#: c-family/c-attribs.c:2333
+#: c-family/c-attribs.c:2344
 #, gcc-internal-format
 msgid "tls_model argument must be one of \"local-exec\", \"initial-exec\", \"local-dynamic\" or \"global-dynamic\""
 msgstr "Argument für tls_model muss »local-exec«, »initial-exec«, »local-dynamic« oder »global-dynamic« sein"
 
-#: c-family/c-attribs.c:2353 c-family/c-attribs.c:2656
-#: c-family/c-attribs.c:3497 config/m32c/m32c.c:2944
+#: c-family/c-attribs.c:2364 c-family/c-attribs.c:2667
+#: c-family/c-attribs.c:3508 config/m32c/m32c.c:2944
 #, gcc-internal-format
 msgid "%qE attribute applies only to functions"
 msgstr "Attribut %qE kann nur auf Funktionen angewandt werden"
 
-#: c-family/c-attribs.c:2417
+#: c-family/c-attribs.c:2428
 #, gcc-internal-format
 msgid "alloc_size parameter outside range"
 msgstr "Parameter alloc_size außerhalb des Wertebereiches"
 
-#: c-family/c-attribs.c:2443
+#: c-family/c-attribs.c:2454
 #, gcc-internal-format
 msgid "alloc_align parameter outside range"
 msgstr "Parameter für »alloc_size« außerhalb des Wertebereiches"
 
-#: c-family/c-attribs.c:2467
+#: c-family/c-attribs.c:2478
 #, gcc-internal-format
 msgid "assume_aligned parameter not integer constant"
 msgstr "Parameter für »assume_aligned« ist keine Ganzzahlkonstante"
 
-#: c-family/c-attribs.c:2595
+#: c-family/c-attribs.c:2606
 #, gcc-internal-format
 msgid "only %<inbranch%> and %<notinbranch%> flags are allowed for %<__simd__%> attribute"
 msgstr "nur die Schalter %<inbranch%> und %<notinbranch%> sind für das %<__simd__%>-Attribut erlaubt"
 
-#: c-family/c-attribs.c:2662 c-family/c-attribs.c:3503
+#: c-family/c-attribs.c:2673 c-family/c-attribs.c:3514
 #, gcc-internal-format
 msgid "can%'t set %qE attribute after definition"
 msgstr "Attribut %qE kann nicht nach der Definition gesetzt werden"
 
-#: c-family/c-attribs.c:2727
+#: c-family/c-attribs.c:2738
 #, gcc-internal-format
 msgid "%qE attribute duplicated"
 msgstr "doppeltes Attribut %qE"
 
-#: c-family/c-attribs.c:2729
+#: c-family/c-attribs.c:2740
 #, gcc-internal-format
 msgid "%qE attribute follows %qE"
 msgstr "Attribut %qE folgt auf %qE"
 
-#: c-family/c-attribs.c:2828
+#: c-family/c-attribs.c:2839
 #, gcc-internal-format
 msgid "type was previously declared %qE"
 msgstr "Typ war vorher als %qE deklariert"
 
-#: c-family/c-attribs.c:2841 cp/class.c:4397
+#: c-family/c-attribs.c:2852 cp/class.c:4401
 #, gcc-internal-format
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
 msgstr "%<transaction_safe_dynamic%> kann nur für virtuelle Funktionen angegeben werden"
 
-#: c-family/c-attribs.c:2899
+#: c-family/c-attribs.c:2910
 #, gcc-internal-format
 msgid "%qE argument not an identifier"
 msgstr "Argument %qE ist kein Bezeichner"
 
-#: c-family/c-attribs.c:2910
+#: c-family/c-attribs.c:2921
 #, gcc-internal-format
 msgid "%qD is not compatible with %qD"
 msgstr "%qD ist mit %qD unverträglich"
 
-#: c-family/c-attribs.c:2913
+#: c-family/c-attribs.c:2924
 #, gcc-internal-format
 msgid "%qE argument is not a function"
 msgstr "Argument %qE ist keine Funktion"
 
-#: c-family/c-attribs.c:2961
+#: c-family/c-attribs.c:2972
 #, gcc-internal-format
 msgid "deprecated message is not a string"
 msgstr "Veraltete Meldung ist keine Zeichenkette"
 
-#: c-family/c-attribs.c:3002
+#: c-family/c-attribs.c:3013
 #, gcc-internal-format
 msgid "%qE attribute ignored for %qE"
 msgstr "Attribut %qE ignoriert für %qE"
 
-#: c-family/c-attribs.c:3065
+#: c-family/c-attribs.c:3076
 #, gcc-internal-format
 msgid "invalid vector type for attribute %qE"
 msgstr "Ungültiger Vektortyp für Attribut %qE"
 
-#: c-family/c-attribs.c:3071 ada/gcc-interface/utils.c:3896
+#: c-family/c-attribs.c:3082 ada/gcc-interface/utils.c:3899
 #, gcc-internal-format
 msgid "vector size not an integral multiple of component size"
 msgstr "Vektorgröße kein ganzzahliges Vielfaches der Komponentengröße"
 
-#: c-family/c-attribs.c:3077 ada/gcc-interface/utils.c:3903
+#: c-family/c-attribs.c:3088 ada/gcc-interface/utils.c:3906
 #, gcc-internal-format
 msgid "zero vector size"
 msgstr "Vektorgröße Null"
 
-#: c-family/c-attribs.c:3085
+#: c-family/c-attribs.c:3096
 #, gcc-internal-format
 msgid "number of components of the vector not a power of two"
 msgstr "Komponentenanzahl des Vektors ist keine Zweierpotenz"
 
-#: c-family/c-attribs.c:3118 ada/gcc-interface/utils.c:6092
+#: c-family/c-attribs.c:3129 ada/gcc-interface/utils.c:6098
 #, gcc-internal-format
 msgid "nonnull attribute without arguments on a non-prototype"
 msgstr "Nicht-Null-Attribut ohne Argumente für einen Nicht-Prototyp"
 
-#: c-family/c-attribs.c:3137 ada/gcc-interface/utils.c:6106
+#: c-family/c-attribs.c:3148 ada/gcc-interface/utils.c:6112
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument has invalid operand number (argument %lu)"
 msgstr "Nicht-Null-Argument hat ungültige Operandennummer (Argument %lu)"
 
-#: c-family/c-attribs.c:3159 ada/gcc-interface/utils.c:6128
+#: c-family/c-attribs.c:3170 ada/gcc-interface/utils.c:6134
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument with out-of-range operand number (argument %lu, operand %lu)"
 msgstr "Nicht-Null-Argument mit Operandennummer außerhalb des Wertebereiches (Argument %lu, Operand %lu)"
 
-#: c-family/c-attribs.c:3168 ada/gcc-interface/utils.c:6137
+#: c-family/c-attribs.c:3179 ada/gcc-interface/utils.c:6143
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument references non-pointer operand (argument %lu, operand %lu)"
 msgstr "Nicht-Null-Argument referenziert Nicht-Zeiger-Operanden (Argument %lu, Operand %lu)"
 
-#: c-family/c-attribs.c:3208
+#: c-family/c-attribs.c:3219
 #, gcc-internal-format
 msgid "%qE attribute ignored on objects of type %qT"
 msgstr "Attribut %qE wird für Objekte vom Typ %qT ignoriert"
 
-#: c-family/c-attribs.c:3216
+#: c-family/c-attribs.c:3227
 #, gcc-internal-format
 msgid "%qE attribute does not apply to functions"
 msgstr "Attribut %qE ist nicht auf Funktionen anwendbar"
 
-#: c-family/c-attribs.c:3273
+#: c-family/c-attribs.c:3284
 #, gcc-internal-format
 msgid "cleanup argument not an identifier"
 msgstr "Argument für cleanup ist kein Bezeichner"
 
-#: c-family/c-attribs.c:3280
+#: c-family/c-attribs.c:3291
 #, gcc-internal-format
 msgid "cleanup argument not a function"
 msgstr "Argument für cleanup ist keine Funktion"
 
-#: c-family/c-attribs.c:3317
+#: c-family/c-attribs.c:3328
 #, gcc-internal-format
 msgid "%qE attribute requires prototypes with named arguments"
 msgstr "Attribut %qE benötigt Prototypen mit benannten Argumenten"
 
-#: c-family/c-attribs.c:3325
+#: c-family/c-attribs.c:3336
 #, gcc-internal-format
 msgid "%qE attribute only applies to variadic functions"
 msgstr "Attribut %qE gilt nur für variadische Funktionen"
 
-#: c-family/c-attribs.c:3341 ada/gcc-interface/utils.c:6179
+#: c-family/c-attribs.c:3352 ada/gcc-interface/utils.c:6185
 #, gcc-internal-format
 msgid "requested position is not an integer constant"
 msgstr "Angeforderte Position ist keine Ganzzahlkonstante"
 
-#: c-family/c-attribs.c:3349 ada/gcc-interface/utils.c:6186
+#: c-family/c-attribs.c:3360 ada/gcc-interface/utils.c:6192
 #, gcc-internal-format
 msgid "requested position is less than zero"
 msgstr "Angeforderte Position ist kleiner als Null"
 
-#: c-family/c-attribs.c:3404
+#: c-family/c-attribs.c:3415
 #, gcc-internal-format
 msgid "empty string in attribute %<target%>"
 msgstr "Leere Zeichenkette in Attribut %<target%>"
 
-#: c-family/c-attribs.c:3520
+#: c-family/c-attribs.c:3531
 #, gcc-internal-format
 msgid "returns_nonnull attribute on a function not returning a pointer"
 msgstr "»returns_nonnull«-Attribut an einer Funktion, die keinen Zeiger zurückgibt"
 
-#: c-family/c-attribs.c:3535
+#: c-family/c-attribs.c:3546
 #, gcc-internal-format
 msgid "%qE attribute is only valid on %<struct%> type"
 msgstr "Attribut %qE kann nur auf %<struct%>-Typen angewandt werden"
@@ -24417,12 +24443,12 @@
 msgid "__builtin_shuffle argument vector(s) inner type must have the same size as inner type of the mask"
 msgstr "Innere Typen des/der Argumentvektors/en und Maske von __builtin_shuffle müssen gleiche Größe haben"
 
-#: c-family/c-common.c:1262 c-family/c-warn.c:1194
+#: c-family/c-common.c:1262 c-family/c-warn.c:1202
 #, gcc-internal-format
 msgid "unsigned conversion from %qT to %qT changes value from %qE to %qE"
 msgstr "Vorzeichenlose Umwandlung von %qT nach %qT ändert den Wert von %qE nach %qE"
 
-#: c-family/c-common.c:1267 c-family/c-warn.c:1202
+#: c-family/c-common.c:1267 c-family/c-warn.c:1210
 #, gcc-internal-format
 msgid "unsigned conversion from %qT to %qT changes the value of %qE"
 msgstr "Vorzeichenlose Umwandlung von %qT nach %qT ändert den Wert von %qE"
@@ -24552,7 +24578,7 @@
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "Um Zuweisung, die als Wahrheitswert verwendet wird, werden Klammern empfohlen"
 
-#: c-family/c-common.c:3518 c/c-decl.c:4325 c/c-decl.c:6430 c/c-typeck.c:14177
+#: c-family/c-common.c:3518 c/c-decl.c:4325 c/c-decl.c:6450 c/c-typeck.c:14182
 #, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr "Ungültige Verwendung von %<restrict%>"
@@ -24632,7 +24658,7 @@
 msgid "duplicate case value"
 msgstr "Doppelter case-Wert"
 
-#: c-family/c-common.c:4867 c-family/c-warn.c:2216
+#: c-family/c-common.c:4867 c-family/c-warn.c:2225
 #, gcc-internal-format
 msgid "previously used here"
 msgstr "Bereits hier verwendet"
@@ -24677,193 +24703,193 @@
 msgid "missing sentinel in function call"
 msgstr "Wächter in Funktionsaufruf fehlt"
 
-#: c-family/c-common.c:5411
+#: c-family/c-common.c:5409
 #, gcc-internal-format, gfc-internal-format
 msgid "null argument where non-null required (argument %lu)"
 msgstr "Null-Argument, wo Nicht-Null erwartet (Argument %lu)"
 
-#: c-family/c-common.c:5506 c-family/c-common.c:5553
+#: c-family/c-common.c:5504 c-family/c-common.c:5551
 #, gcc-internal-format
 msgid "bad option %qs to attribute %<optimize%>"
 msgstr "schlechte Option %qs für Attribut %<optimize%>"
 
-#: c-family/c-common.c:5509 c-family/c-common.c:5557
+#: c-family/c-common.c:5507 c-family/c-common.c:5555
 #, gcc-internal-format
 msgid "bad option %qs to pragma %<optimize%>"
 msgstr "schlechte Option %qs für Pragma %<optimize%>"
 
-#: c-family/c-common.c:5589
+#: c-family/c-common.c:5587
 #, gcc-internal-format
 msgid "%<fallthrough%> attribute specified multiple times"
 msgstr "%<fallthrough%>-Attribut ist mehrfach angegeben"
 
-#: c-family/c-common.c:5593
+#: c-family/c-common.c:5591
 #, gcc-internal-format
 msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr "%<fallthrough%>-Attribut mit einem Parameter angegeben"
 
-#: c-family/c-common.c:5733 c-family/c-common.c:6485 c-family/c-common.c:6558
+#: c-family/c-common.c:5731 c-family/c-common.c:6477 c-family/c-common.c:6550
 #: c/c-typeck.c:3555
 #, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr "Zu wenige Argumente für Funktion %qE"
 
-#: c-family/c-common.c:5738 c-family/c-common.c:6584 c/c-typeck.c:3284
+#: c-family/c-common.c:5736 c-family/c-common.c:6576 c/c-typeck.c:3284
 #, gcc-internal-format
 msgid "too many arguments to function %qE"
 msgstr "zu viele Argumente für Funktion %qE"
 
-#: c-family/c-common.c:5769
+#: c-family/c-common.c:5767
 #, gcc-internal-format
 msgid "third argument to function %qE must be a constant integer"
 msgstr "Drittes Argument für Funktion %qE muss eine konstante Ganzzahl sein"
 
-#: c-family/c-common.c:5794
+#: c-family/c-common.c:5792
 #, gcc-internal-format
 msgid "second argument to function %qE must be a constant integer power of 2 between %qi and %qu bits"
 msgstr "zweites Argument für Funktion %qE muss eine konstante Zweierpotenz zwischen %qi und %qu Bits sein"
 
-#: c-family/c-common.c:5815 c-family/c-common.c:5859
+#: c-family/c-common.c:5813 c-family/c-common.c:5857
 #, gcc-internal-format
 msgid "non-floating-point argument in call to function %qE"
 msgstr "Nicht-Gleitkomma-Argument in Aufruf von Funktion %qE"
 
-#: c-family/c-common.c:5838
+#: c-family/c-common.c:5836
 #, gcc-internal-format
 msgid "non-floating-point arguments in call to function %qE"
 msgstr "Nicht-Gleitkomma-Argumente in Aufruf von Funktion %qE"
 
-#: c-family/c-common.c:5852
+#: c-family/c-common.c:5850
 #, gcc-internal-format
 msgid "non-const integer argument %u in call to function %qE"
 msgstr "Nicht-konstantes Ganzzahl-Argument %u in Aufruf von Funktion %qE"
 
-#: c-family/c-common.c:5872
+#: c-family/c-common.c:5870
 #, gcc-internal-format
 msgid "non-integer argument 3 in call to function %qE"
 msgstr "Nicht-Ganzzahl-Argument 3 in Aufruf von Funktion %qE"
 
-#: c-family/c-common.c:5889 c-family/c-common.c:5925
+#: c-family/c-common.c:5887 c-family/c-common.c:5923
 #, gcc-internal-format
 msgid "argument %u in call to function %qE does not have integral type"
 msgstr "Argument %u in Aufruf von %qE muss ein Ganzzahltyp sein"
 
-#: c-family/c-common.c:5896
+#: c-family/c-common.c:5894
 #, gcc-internal-format
 msgid "argument 3 in call to function %qE does not have pointer to integral type"
 msgstr "Argument 3 in Aufruf von %qE muss Zeiger auf Ganzzahltyp sein"
 
-#: c-family/c-common.c:5902
+#: c-family/c-common.c:5900
 #, gcc-internal-format
 msgid "argument 3 in call to function %qE has pointer to enumerated type"
 msgstr "Argument 3 in Aufruf von %qE darf kein Zeiger auf enum-Typ sein"
 
-#: c-family/c-common.c:5908
+#: c-family/c-common.c:5906
 #, gcc-internal-format
 msgid "argument 3 in call to function %qE has pointer to boolean type"
 msgstr "Argument 3 in Aufruf von %qE darf kein Zeiger auf booleschen Typ sein"
 
-#: c-family/c-common.c:5931
+#: c-family/c-common.c:5929
 #, gcc-internal-format
 msgid "argument 3 in call to function %qE has enumerated type"
 msgstr "Argument 3 in Aufruf von %qE darf kein enum-Typ sein"
 
-#: c-family/c-common.c:5937
+#: c-family/c-common.c:5935
 #, gcc-internal-format
 msgid "argument 3 in call to function %qE has boolean type"
 msgstr "Argument 3 in Aufruf von %qE darf kein boolescher Typ sein"
 
-#: c-family/c-common.c:6184
+#: c-family/c-common.c:6183
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to static data member %qD"
 msgstr "%<offsetof%> kann nicht auf statisches Datenelement %qD angewendet werden"
 
-#: c-family/c-common.c:6189
+#: c-family/c-common.c:6188
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> when %<operator[]%> is overloaded"
 msgstr "%<offsetof%> kann nicht angewandt werden, wenn %<operator[]%> überladen ist"
 
-#: c-family/c-common.c:6196
+#: c-family/c-common.c:6195
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to a non constant address"
 msgstr "%<offsetof%> kann nicht auf nicht-konstante Adresse angewandt werden"
 
-#: c-family/c-common.c:6209
+#: c-family/c-common.c:6208
 #, gcc-internal-format
 msgid "attempt to take address of bit-field structure member %qD"
 msgstr "Versuch, die Adresse des Bitfeldstrukturelements %qD zu ermitteln"
 
-#: c-family/c-common.c:6261
+#: c-family/c-common.c:6260
 #, gcc-internal-format
 msgid "index %E denotes an offset greater than size of %qT"
 msgstr "Index %E markiert einen Offset größer als die Größe von %qT"
 
-#: c-family/c-common.c:6427 cp/init.c:3004 cp/init.c:3023
+#: c-family/c-common.c:6419 cp/init.c:3020 cp/init.c:3039
 #, gcc-internal-format
 msgid "size of array is too large"
 msgstr "Arraygröße ist zu groß"
 
-#: c-family/c-common.c:6517
+#: c-family/c-common.c:6509
 #, gcc-internal-format
 msgid "operand type %qT is incompatible with argument %d of %qE"
 msgstr "Operandentyp %qT ist inkompatibel mit Argument %d von %qE"
 
-#: c-family/c-common.c:6651
+#: c-family/c-common.c:6643
 #, gcc-internal-format
 msgid "incorrect number of arguments to function %qE"
 msgstr "Falsche Anzahl der Argumente für Funktion %qE"
 
-#: c-family/c-common.c:6665
+#: c-family/c-common.c:6657
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a non-void pointer type"
 msgstr "Argument 1 von %qE muss ein Nicht-Void-Zeigertyp sein"
 
-#: c-family/c-common.c:6674
+#: c-family/c-common.c:6666
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a constant size type"
 msgstr "Argument 1 von %qE muss ein Zeiger auf Typen konstanter Größe sein"
 
-#: c-family/c-common.c:6685
+#: c-family/c-common.c:6677
 #, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a nonzero size object"
 msgstr "Argument 1 von %qE muss ein Zeiger auf Objekt breiter als Null sein"
 
-#: c-family/c-common.c:6706
+#: c-family/c-common.c:6698
 #, gcc-internal-format
 msgid "argument %d of %qE must be a pointer type"
 msgstr "Argument %d von %qE muss eine Zeigertyp sein"
 
-#: c-family/c-common.c:6714
+#: c-family/c-common.c:6706
 #, gcc-internal-format
 msgid "argument %d of %qE must be a pointer to a constant size type"
 msgstr "Argument %d von %qE muss ein Zeiger auf Typen konstanter Größe sein"
 
-#: c-family/c-common.c:6720
+#: c-family/c-common.c:6712
 #, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a function"
 msgstr "Argument %d von %qE darf kein Zeiger auf eine Funktion sein"
 
-#: c-family/c-common.c:6728
+#: c-family/c-common.c:6720
 #, gcc-internal-format
 msgid "size mismatch in argument %d of %qE"
 msgstr "Unpassende Größe in Argument %d von %qE"
 
-#: c-family/c-common.c:6740
+#: c-family/c-common.c:6732
 #, gcc-internal-format
 msgid "non-integer memory model argument %d of %qE"
 msgstr "Nicht-Ganzzahlargument %d für Speichermodell von %qE"
 
-#: c-family/c-common.c:6753
+#: c-family/c-common.c:6745
 #, gcc-internal-format
 msgid "invalid memory model argument %d of %qE"
 msgstr "ungültiges Argument %d für Speichermodell von %qE"
 
-#: c-family/c-common.c:7672
+#: c-family/c-common.c:7664
 #, gcc-internal-format
 msgid "index value is out of bound"
 msgstr "Indexwert ist außerhalb der Grenzen"
 
-#: c-family/c-common.c:7714 c-family/c-common.c:7763 c-family/c-common.c:7779
+#: c-family/c-common.c:7706 c-family/c-common.c:7755 c-family/c-common.c:7771
 #, gcc-internal-format
 msgid "conversion of scalar %qT to vector %qT involves truncation"
 msgstr "Umwandlung von Skalar %qT in Vektor %qT führt zum Abschneiden"
@@ -24870,22 +24896,22 @@
 
 #. Reject arguments that are built-in functions with
 #. no library fallback.
-#: c-family/c-common.c:7867
+#: c-family/c-common.c:7859
 #, gcc-internal-format
 msgid "built-in function %qE must be directly called"
 msgstr "eingebaute Funktion %qE muss direkt aufgerufen werden"
 
-#: c-family/c-common.c:7889 c/c-decl.c:6177
+#: c-family/c-common.c:7881 c/c-decl.c:6197
 #, gcc-internal-format
 msgid "size of array %qE is too large"
 msgstr "Arraygröße von %qE ist zu groß"
 
-#: c-family/c-common.c:7891 c/c-decl.c:6180
+#: c-family/c-common.c:7883 c/c-decl.c:6200
 #, gcc-internal-format
 msgid "size of unnamed array is too large"
 msgstr "Größe des unbenannten Arrays ist zu groß"
 
-#: c-family/c-common.c:7921
+#: c-family/c-common.c:7913
 #, gcc-internal-format
 msgid "environment variable SOURCE_DATE_EPOCH must expand to a non-negative integer less than or equal to %wd"
 msgstr "Umgebungsvariable SOURCE_DATE_EPOCH muss ganzzahlig sein und zwischen 0 und %wd liegen"
@@ -25407,7 +25433,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr "%<#pragma omp atomic capture%> verwendet zwei unterschiedliche Variablen für Speicher"
 
-#: c-family/c-omp.c:557 cp/semantics.c:8186
+#: c-family/c-omp.c:557 cp/semantics.c:8189
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "ungültiger Typ für Schleifenvariable %qE"
@@ -25422,22 +25448,22 @@
 msgid "%qE is not initialized"
 msgstr "%qE ist nicht initialisiert"
 
-#: c-family/c-omp.c:599 cp/semantics.c:8076
+#: c-family/c-omp.c:599 cp/semantics.c:8079
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "Steuerprädikat fehlt"
 
-#: c-family/c-omp.c:704 cp/semantics.c:7732
+#: c-family/c-omp.c:704 cp/semantics.c:7735
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "Steuerprädikat ungültig"
 
-#: c-family/c-omp.c:711 cp/semantics.c:8082
+#: c-family/c-omp.c:711 cp/semantics.c:8085
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "Erhöhungsausdruck fehlt"
 
-#: c-family/c-omp.c:775 cp/semantics.c:7847
+#: c-family/c-omp.c:775 cp/semantics.c:7850
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "Erhöhungsausdruck ungültig"
@@ -25492,112 +25518,127 @@
 msgid "%<-Wabi=1%> is not supported, using =2"
 msgstr "%<-Wabi=1%> wird nicht unterstützt; stattdessen wird »=2« verwendet"
 
-#: c-family/c-opts.c:612 fortran/cpp.c:350
+#: c-family/c-opts.c:610 fortran/cpp.c:350
 #, gcc-internal-format
 msgid "output filename specified twice"
 msgstr "Ausgabedatei doppelt angegeben"
 
-#: c-family/c-opts.c:799
+#: c-family/c-opts.c:797
 #, gcc-internal-format
 msgid "-fexcess-precision=standard for C++"
 msgstr "-fexcess-precision=standard für C++"
 
-#: c-family/c-opts.c:834
+#: c-family/c-opts.c:832
 #, gcc-internal-format
 msgid "-fno-gnu89-inline is only supported in GNU99 or C99 mode"
 msgstr "-fno-gnu89-inline wird nur im Modus GNU99 oder C99 unterstützt"
 
-#: c-family/c-opts.c:880
+#: c-family/c-opts.c:878
 #, gcc-internal-format
 msgid "-Wformat-y2k ignored without -Wformat"
 msgstr "-Wformat-y2k wird ohne -Wformat ignoriert"
 
-#: c-family/c-opts.c:882
+#: c-family/c-opts.c:880
 #, gcc-internal-format
 msgid "-Wformat-extra-args ignored without -Wformat"
 msgstr "-Wformat-extra-args wird ohne -Wformat ignoriert"
 
-#: c-family/c-opts.c:884
+#: c-family/c-opts.c:882
 #, gcc-internal-format
 msgid "-Wformat-zero-length ignored without -Wformat"
 msgstr "-Wformat-zero-length wird ohne -Wformat ignoriert"
 
-#: c-family/c-opts.c:886
+#: c-family/c-opts.c:884
 #, gcc-internal-format
 msgid "-Wformat-nonliteral ignored without -Wformat"
 msgstr "-Wformat-nonliteral wird ohne -Wformat ignoriert"
 
-#: c-family/c-opts.c:888
+#: c-family/c-opts.c:886
 #, gcc-internal-format
 msgid "-Wformat-contains-nul ignored without -Wformat"
 msgstr "-Wformat-contains-nul wird ohne -Wformat ignoriert"
 
-#: c-family/c-opts.c:890
+#: c-family/c-opts.c:888
 #, gcc-internal-format
 msgid "-Wformat-security ignored without -Wformat"
 msgstr "-Wformat-security wird ohne -Wformat ignoriert"
 
-#: c-family/c-opts.c:928
+#: c-family/c-opts.c:918
 #, gcc-internal-format
 msgid "%<-fabi-compat-version=1%> is not supported, using =2"
 msgstr "%<-fabi-compat-version=1%> wird nicht unterstützt; stattdessen wird »=2« verwendet"
 
-#: c-family/c-opts.c:988
+#: c-family/c-opts.c:944
 #, gcc-internal-format
+msgid "-Wabi won't warn about anything"
+msgstr "-Wabi wird vor nichts warnen"
+
+#: c-family/c-opts.c:946
+#, gcc-internal-format
+msgid "-Wabi warns about differences from the most up-to-date ABI, which is also used by default"
+msgstr "-Wabi warnt vor Abweichungen von der aktuellsten ABI, die ebenfalls standardmäßig verwendet wird"
+
+#: c-family/c-opts.c:949
+#, gcc-internal-format
+msgid "use e.g. -Wabi=11 to warn about changes from GCC 7"
+msgstr "Verwenden Sie zum Beispiel -Wabi=11, um vor Änderungen von GCC 7 zu warnen"
+
+#: c-family/c-opts.c:1003
+#, gcc-internal-format
 msgid "external TLS initialization functions not supported on this target"
 msgstr "externe Funktionen zur TLS-Initialisierung werden auf diesem Ziel nicht unterstützt"
 
-#: c-family/c-opts.c:1001
+#: c-family/c-opts.c:1016
 #, gcc-internal-format, gfc-internal-format
 msgid "too many filenames given.  Type %s --help for usage"
 msgstr "zu viele Dateinamen angegeben. Für Hilfe »%s --help« eingeben"
 
-#: c-family/c-opts.c:1016
+#: c-family/c-opts.c:1031
 #, gcc-internal-format
 msgid "opening output file %s: %m"
 msgstr "Ausgabedatei »%s« kann nicht geöffnet werden: %m"
 
-#: c-family/c-opts.c:1036
+#: c-family/c-opts.c:1051
 #, gcc-internal-format, gfc-internal-format
 msgid "the \"%s\" debug format cannot be used with pre-compiled headers"
 msgstr "Das Debug-Format »%s« kann nicht mit vorkompilierten Headers verwendet werden"
 
-#: c-family/c-opts.c:1190
+#: c-family/c-opts.c:1205
 #, gcc-internal-format
 msgid "opening dependency file %s: %m"
 msgstr "Abhängigkeitsdatei »%s« kann nicht geöffnet werden: %m"
 
-#: c-family/c-opts.c:1201
+#: c-family/c-opts.c:1216
 #, gcc-internal-format
 msgid "closing dependency file %s: %m"
 msgstr "Abhängigkeitsdatei »%s« kann nicht geschlossen werden: %m"
 
-#: c-family/c-opts.c:1204
+#: c-family/c-opts.c:1219
 #, gcc-internal-format
 msgid "when writing output to %s: %m"
 msgstr "beim Schreiben der Ausgabe nach %s: %m"
 
-#: c-family/c-opts.c:1284
+#: c-family/c-opts.c:1299
 #, gcc-internal-format
 msgid "to generate dependencies you must specify either -M or -MM"
 msgstr "um Abhängigkeiten zu erzeugen, müssen Sie entweder -M oder -MM angeben"
 
-#: c-family/c-opts.c:1307
+#: c-family/c-opts.c:1322
 #, gcc-internal-format
 msgid "-MG may only be used with -M or -MM"
 msgstr "-MG darf nur mit -M oder -MM verwendet werden"
 
-#: c-family/c-opts.c:1340
+#: c-family/c-opts.c:1355
 #, gcc-internal-format
 msgid "-fdirectives-only is incompatible with -Wunused_macros"
 msgstr "-fdirectives-only ist mit -Wunused_macros unverträglich"
 
-#: c-family/c-opts.c:1342
+#: c-family/c-opts.c:1357
 #, gcc-internal-format
 msgid "-fdirectives-only is incompatible with -traditional"
 msgstr "-fdirectives-only ist mit -traditional unverträglich"
 
-#: c-family/c-opts.c:1534
+#: c-family/c-opts.c:1549
 #, gcc-internal-format
 msgid "too late for # directive to set debug directory"
 msgstr "zu spät für »#«-Direktive, um Debug-Verzeichnis festzulegen"
@@ -25982,725 +26023,725 @@
 msgid "wrong type argument to %s"
 msgstr "Argument falschen Typs für %s"
 
-#: c-family/c-warn.c:53 c-family/c-warn.c:66 cp/constexpr.c:1847
+#: c-family/c-warn.c:54 c-family/c-warn.c:67 cp/constexpr.c:1847
 #: cp/constexpr.c:4099
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "Überlauf in Konstanten-Ausdruck"
 
-#: c-family/c-warn.c:93
+#: c-family/c-warn.c:94
 #, gcc-internal-format
 msgid "integer overflow in expression %qE of type %qT results in %qE"
 msgstr "Ganzzahlüberlauf in Ausdruck %qE des Typs %qT ergibt %qE"
 
-#: c-family/c-warn.c:95
+#: c-family/c-warn.c:96
 #, gcc-internal-format
 msgid "integer overflow in expression of type %qT results in %qE"
 msgstr "Ganzzahlüberlauf in Ausdruck des Typs %qT ergibt %qE"
 
-#: c-family/c-warn.c:101
+#: c-family/c-warn.c:102
 #, gcc-internal-format
 msgid "floating point overflow in expression %qE of type %qT results in %qE"
 msgstr "Gleitkommaüberlauf in Ausdruck %qE des Typs %qT ergibt %qE"
 
-#: c-family/c-warn.c:103
+#: c-family/c-warn.c:104
 #, gcc-internal-format
 msgid "floating point overflow in expression of type %qT results in %qE"
 msgstr "Gleitkommaüberlauf in Ausdruck des Typs %qT ergibt %qE"
 
-#: c-family/c-warn.c:109
+#: c-family/c-warn.c:110
 #, gcc-internal-format
 msgid "fixed-point overflow in expression %qE of type %qT results in %qE"
 msgstr "Festkommaüberlauf in Ausdruck %qE des Typs %qT ergibt %qE"
 
-#: c-family/c-warn.c:111
+#: c-family/c-warn.c:112
 #, gcc-internal-format
 msgid "fixed-point overflow in expression of type %qT results in %qE"
 msgstr "Festkommaüberlauf in Ausdruck des Typs %qT ergibt %qE"
 
-#: c-family/c-warn.c:117
+#: c-family/c-warn.c:118
 #, gcc-internal-format
 msgid "vector overflow in expression %qE of type %qT results in %qE"
 msgstr "Vektorüberlauf in Ausdruck %qE des Typs %qT ergibt %qE"
 
-#: c-family/c-warn.c:119
+#: c-family/c-warn.c:120
 #, gcc-internal-format
 msgid "vector overflow in expression of type %qT results in %qE"
 msgstr "Vektorüberlauf in Ausdruck des Typs %qT ergibt %qE"
 
-#: c-family/c-warn.c:126
+#: c-family/c-warn.c:127
 #, gcc-internal-format
 msgid "complex integer overflow in expression %qE of type %qT results in %qE"
 msgstr "Überlauf von komplexen Ganzzahlen in Ausdruck %qE des Typs %qT ergibt %qE"
 
-#: c-family/c-warn.c:128
+#: c-family/c-warn.c:129
 #, gcc-internal-format
 msgid "complex integer overflow in expression of type %qT results in %qE"
 msgstr "Überlauf von komplexen Ganzzahlen in Ausdruck des Typs %qT ergibt %qE"
 
-#: c-family/c-warn.c:132
+#: c-family/c-warn.c:133
 #, gcc-internal-format
 msgid "complex floating point overflow in expression %qE of type %qT results in %qE"
 msgstr "Überlauf von komplexen Gleitkommazahlen in Ausdruck %qE des Typs %qT ergibt %qE"
 
-#: c-family/c-warn.c:134
+#: c-family/c-warn.c:135
 #, gcc-internal-format
 msgid "complex floating point overflow in expression of type %qT results in %qE"
 msgstr "Überlauf von komplexen Gleitkommazahlen in Ausdruck des Typs %qT ergibt %qE"
 
-#: c-family/c-warn.c:216
+#: c-family/c-warn.c:217
 #, gcc-internal-format
 msgid "logical %<or%> applied to non-boolean constant"
 msgstr "Logisches %<or%> auf Nicht-Boolesche Konstante angewandt"
 
-#: c-family/c-warn.c:219
+#: c-family/c-warn.c:220
 #, gcc-internal-format
 msgid "logical %<and%> applied to non-boolean constant"
 msgstr "logisches %<und%> auf nicht-boolesche Konstante angewendet"
 
-#: c-family/c-warn.c:289
+#: c-family/c-warn.c:290
 #, gcc-internal-format
 msgid "logical %<or%> of collectively exhaustive tests is always true"
 msgstr "logisches %<oder%> gemeinsam erschöpfender Tests ist immer »wahr«"
 
-#: c-family/c-warn.c:293
+#: c-family/c-warn.c:294
 #, gcc-internal-format
 msgid "logical %<and%> of mutually exclusive tests is always false"
 msgstr "logisches %<und%> sich gegenseitig ausschließender Tests ist immer »falsch«"
 
-#: c-family/c-warn.c:303
+#: c-family/c-warn.c:304
 #, gcc-internal-format
 msgid "logical %<or%> of equal expressions"
 msgstr "logisches Oder von gleichen Ausdrücken"
 
-#: c-family/c-warn.c:306
+#: c-family/c-warn.c:307
 #, gcc-internal-format
 msgid "logical %<and%> of equal expressions"
 msgstr "logisches Und von gleichen Ausdrücken"
 
-#: c-family/c-warn.c:384
+#: c-family/c-warn.c:385
 #, gcc-internal-format
 msgid "bitwise comparison always evaluates to false"
 msgstr "Bitweiser Vergleich ergibt immer »false«"
 
-#: c-family/c-warn.c:387
+#: c-family/c-warn.c:388
 #, gcc-internal-format
 msgid "bitwise comparison always evaluates to true"
 msgstr "Bitweiser Vergleich ergibt immer »true«"
 
-#: c-family/c-warn.c:441
+#: c-family/c-warn.c:442
 #, gcc-internal-format
 msgid "self-comparison always evaluates to true"
 msgstr "Vergleich mit sich selbst ergibt immer »true«"
 
-#: c-family/c-warn.c:444
+#: c-family/c-warn.c:445
 #, gcc-internal-format
 msgid "self-comparison always evaluates to false"
 msgstr "Vergleich mit sich selbst ergibt immer »false«"
 
-#: c-family/c-warn.c:494
+#: c-family/c-warn.c:495
 #, gcc-internal-format
 msgid "logical not is only applied to the left hand side of comparison"
 msgstr "logisches Nicht bezieht sich nur auf die linke Seite des Vergleichs"
 
-#: c-family/c-warn.c:502
+#: c-family/c-warn.c:503
 #, gcc-internal-format
 msgid "add parentheses around left hand side expression to silence this warning"
 msgstr "klammern Sie den Ausdruck auf der linken Seite ein, um diese Warnung zu beheben"
 
-#: c-family/c-warn.c:636
+#: c-family/c-warn.c:637
 #, gcc-internal-format
 msgid "type-punning to incomplete type might break strict-aliasing rules"
 msgstr "Type-Punning auf unvollständigen Typen kann strict-aliasing-Regeln verletzen"
 
-#: c-family/c-warn.c:654
+#: c-family/c-warn.c:655
 #, gcc-internal-format
 msgid "dereferencing type-punned pointer will break strict-aliasing rules"
 msgstr "Dereferenzierung eines Type-Pun-Zeigers verletzt strict-aliasing-Regeln"
 
-#: c-family/c-warn.c:662 c-family/c-warn.c:680
+#: c-family/c-warn.c:663 c-family/c-warn.c:681
 #, gcc-internal-format
 msgid "dereferencing type-punned pointer might break strict-aliasing rules"
 msgstr "Dereferenzierung eines Type-Pun-Zeigers könnte strict-aliasing-Regeln verletzen"
 
-#: c-family/c-warn.c:803
+#: c-family/c-warn.c:811
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to use the size of the destination?"
 msgstr "Argument für %<sizeof%> in Aufruf von %qD ist der gleiche Ausdruck wie die Quelle; meinten Sie die Größe des Ziels?"
 
-#: c-family/c-warn.c:834
+#: c-family/c-warn.c:842
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the destination; did you mean to remove the addressof?"
 msgstr "Argument für %<sizeof%> in Aufruf von %qD ist der gleiche Ausdruck wie das Ziel; sollte addressof entfernt werden?"
 
-#: c-family/c-warn.c:841
+#: c-family/c-warn.c:849
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the destination; did you mean to provide an explicit length?"
 msgstr "Argument für %<sizeof%> in Aufruf von %qD ist der gleiche Ausdruck wie das Ziel; sollte ausdrückliche Länge angegeben werden?"
 
-#: c-family/c-warn.c:846
+#: c-family/c-warn.c:854
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the destination; did you mean to dereference it?"
 msgstr "Argument für %<sizeof%> in Aufruf von %qD ist der gleiche Ausdruck wie das Ziel; sollte es dereferenziert werden?"
 
-#: c-family/c-warn.c:858
+#: c-family/c-warn.c:866
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the destination; expected %qT or an explicit length"
 msgstr "Argument für %<sizeof%> in Aufruf von %qD ist vom gleichen Zeigertyp %qT wie das Ziel; %qT oder ausdrückliche Länge erwartet"
 
-#: c-family/c-warn.c:874
+#: c-family/c-warn.c:882
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to remove the addressof?"
 msgstr "Argument für %<sizeof%> in Aufruf von %qD ist der gleiche Ausdruck wie die Quelle; sollte addressof entfernt werden?"
 
-#: c-family/c-warn.c:881
+#: c-family/c-warn.c:889
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to provide an explicit length?"
 msgstr "Argument für %<sizeof%> in Aufruf von %qD ist der gleiche Ausdruck wie die Quelle; sollte ausdrückliche Länge angegeben werden?"
 
-#: c-family/c-warn.c:886
+#: c-family/c-warn.c:894
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to dereference it?"
 msgstr "Argument für %<sizeof%> in Aufruf von %qD ist der gleiche Ausdruck wie die Quelle; sollte es dereferenziert werden?"
 
-#: c-family/c-warn.c:898
+#: c-family/c-warn.c:906
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the source; expected %qT or an explicit length"
 msgstr "Argument für %<sizeof%> in Aufruf von %qD ist vom gleichen Zeigertyp %qT wie die Quelle; %qT oder ausdrückliche Länge erwartet"
 
-#: c-family/c-warn.c:914
+#: c-family/c-warn.c:922
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the first source; did you mean to remove the addressof?"
 msgstr "Argument für %<sizeof%> in Aufruf von %qD ist der gleiche Ausdruck wie die erste Quelle; sollte addressof entfernt werden?"
 
-#: c-family/c-warn.c:921
+#: c-family/c-warn.c:929
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the first source; did you mean to provide an explicit length?"
 msgstr "Argument für %<sizeof%> in Aufruf von %qD ist der gleiche Ausdruck wie die erste Quelle; sollte ausdrückliche Länge angegeben werden?"
 
-#: c-family/c-warn.c:926
+#: c-family/c-warn.c:934
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the first source; did you mean to dereference it?"
 msgstr "Argument für %<sizeof%> in Aufruf von %qD ist der gleiche Ausdruck wie die erste Quelle; sollte es dereferenziert werden?"
 
-#: c-family/c-warn.c:938
+#: c-family/c-warn.c:946
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the first source; expected %qT or an explicit length"
 msgstr "Argument für %<sizeof%> in Aufruf von %qD ist vom gleichen Zeigertyp %qT wie die erste Quelle; %qT oder ausdrückliche Länge erwartet"
 
-#: c-family/c-warn.c:954
+#: c-family/c-warn.c:962
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the second source; did you mean to remove the addressof?"
 msgstr "Argument für %<sizeof%> in Aufruf von %qD ist der gleiche Ausdruck wie die zweite Quelle; sollte addressof entfernt werden?"
 
-#: c-family/c-warn.c:961
+#: c-family/c-warn.c:969
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the second source; did you mean to provide an explicit length?"
 msgstr "Argument für %<sizeof%> in Aufruf von %qD ist der gleiche Ausdruck wie die zweite Quelle; sollte ausdrückliche Länge angegeben werden?"
 
-#: c-family/c-warn.c:966
+#: c-family/c-warn.c:974
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the second source; did you mean to dereference it?"
 msgstr "Argument für %<sizeof%> in Aufruf von %qD ist der gleiche Ausdruck wie die zweite Quelle; sollte es dereferenziert werden?"
 
-#: c-family/c-warn.c:978
+#: c-family/c-warn.c:986
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the second source; expected %qT or an explicit length"
 msgstr "Argument für %<sizeof%> in Aufruf von %qD ist vom gleichen Zeigertyp %qT wie die zweite Quelle; %qT oder ausdrückliche Länge erwartet"
 
-#: c-family/c-warn.c:1007 c-family/c-warn.c:1014
+#: c-family/c-warn.c:1015 c-family/c-warn.c:1022
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified parameter type %qT of %q+D"
 msgstr "%<_Atomic%>-qualifizierter Parametertyp %qT von %q+D"
 
-#: c-family/c-warn.c:1024
+#: c-family/c-warn.c:1032
 #, gcc-internal-format
 msgid "first argument of %q+D should be %<int%>"
 msgstr "erstes Argument von %q+D sollte %<int%> sein"
 
-#: c-family/c-warn.c:1033
+#: c-family/c-warn.c:1041
 #, gcc-internal-format
 msgid "second argument of %q+D should be %<char **%>"
 msgstr "zweites Argument von %q+D sollte %<char **%> sein"
 
-#: c-family/c-warn.c:1042
+#: c-family/c-warn.c:1050
 #, gcc-internal-format
 msgid "third argument of %q+D should probably be %<char **%>"
 msgstr "drittes Argument von %q+D sollte wahrscheinlich %<char **%> sein"
 
-#: c-family/c-warn.c:1053
+#: c-family/c-warn.c:1061
 #, gcc-internal-format
 msgid "%q+D takes only zero or two arguments"
 msgstr "%q+D benötigt entweder null oder zwei Argumente"
 
-#: c-family/c-warn.c:1057
+#: c-family/c-warn.c:1065
 #, gcc-internal-format
 msgid "%q+D declared as variadic function"
 msgstr "%q+D als variadische Funktion deklariert"
 
-#: c-family/c-warn.c:1099
+#: c-family/c-warn.c:1107
 #, gcc-internal-format
 msgid "conversion to %qT from boolean expression"
 msgstr "Umwandlung in %qT aus booleschem Ausdruck"
 
-#: c-family/c-warn.c:1117 c-family/c-warn.c:1192
+#: c-family/c-warn.c:1125 c-family/c-warn.c:1200
 #, gcc-internal-format
 msgid "conversion from %qT to %qT changes value from %qE to %qE"
 msgstr "Umwandlung von %qT in %qT ändert Wert von %qE nach %qE"
 
-#: c-family/c-warn.c:1121 c-family/c-warn.c:1200
+#: c-family/c-warn.c:1129 c-family/c-warn.c:1208
 #, gcc-internal-format
 msgid "conversion from %qT to %qT changes the value of %qE"
 msgstr "Umformung von %qT nach %qT ändert den Wert von %qE"
 
-#: c-family/c-warn.c:1141
+#: c-family/c-warn.c:1149
 #, gcc-internal-format
 msgid "conversion from %qT to %qT discards imaginary component"
 msgstr "Umwandlung von %qT nach %qT verwirft imaginäre Komponente"
 
-#: c-family/c-warn.c:1153
+#: c-family/c-warn.c:1161
 #, gcc-internal-format
 msgid "conversion from %qT to %qT may change value"
 msgstr "Umwandlung von %qT nach %qT könnte den Wert ändern"
 
-#: c-family/c-warn.c:1213 c-family/c-warn.c:1230 c-family/c-warn.c:1247
+#: c-family/c-warn.c:1221 c-family/c-warn.c:1238 c-family/c-warn.c:1255
 #, gcc-internal-format
 msgid "overflow in conversion from %qT to %qT changes value from %qE to %qE"
 msgstr "Überlauf in Umwandlung von %qT nach %qT ändert den Wert von %qE in %qE"
 
-#: c-family/c-warn.c:1218 c-family/c-warn.c:1235 c-family/c-warn.c:1252
+#: c-family/c-warn.c:1226 c-family/c-warn.c:1243 c-family/c-warn.c:1260
 #, gcc-internal-format
 msgid "overflow in conversion from %qT to %qT changes the value of %qE"
 msgstr "Überlauf in Umwandlung von %qT nach %qT ändert den Wert von %qE"
 
-#: c-family/c-warn.c:1282
+#: c-family/c-warn.c:1290
 #, gcc-internal-format
 msgid "case value %qs not in enumerated type"
 msgstr "case-Wert %qs nicht in Aufzählungstyp"
 
-#: c-family/c-warn.c:1287
+#: c-family/c-warn.c:1295
 #, gcc-internal-format
 msgid "case value %qs not in enumerated type %qT"
 msgstr "case-Wert %qs nicht in Aufzählungstyp %qT"
 
-#: c-family/c-warn.c:1348
+#: c-family/c-warn.c:1356
 #, gcc-internal-format
 msgid "switch missing default case"
 msgstr "Die Standardfallbehandlung in switch fehlt"
 
-#: c-family/c-warn.c:1393
+#: c-family/c-warn.c:1401
 #, gcc-internal-format
 msgid "switch condition has boolean value"
 msgstr "switch-Bedingung hat booleschen Wert"
 
-#: c-family/c-warn.c:1466
+#: c-family/c-warn.c:1474
 #, gcc-internal-format
 msgid "enumeration value %qE not handled in switch"
 msgstr "Aufzählungswert %qE wird nicht von switch behandelt"
 
-#: c-family/c-warn.c:1494
+#: c-family/c-warn.c:1502
 #, gcc-internal-format
 msgid "the omitted middle operand in ?: will always be %<true%>, suggest explicit middle operand"
 msgstr "Der ausgelassene mittlere Operand in ?: wird immer %<wahr%> sein; ausdrücklicher mittlerer Operand wird empfohlen"
 
-#: c-family/c-warn.c:1515
+#: c-family/c-warn.c:1523
 #, gcc-internal-format
 msgid "assignment of member %qD in read-only object"
 msgstr "Zuweisung von Element %qD in schreibgeschütztem Objekt"
 
-#: c-family/c-warn.c:1517
+#: c-family/c-warn.c:1525
 #, gcc-internal-format
 msgid "increment of member %qD in read-only object"
 msgstr "Erhöhung des Elements %qD in schreibgeschütztem Objekt"
 
-#: c-family/c-warn.c:1519
+#: c-family/c-warn.c:1527
 #, gcc-internal-format
 msgid "decrement of member %qD in read-only object"
 msgstr "Verringerung des Elements %qD in schreibgeschütztem Objekt"
 
-#: c-family/c-warn.c:1521
+#: c-family/c-warn.c:1529
 #, gcc-internal-format
 msgid "member %qD in read-only object used as %<asm%> output"
 msgstr "Element %qD in schreibgeschütztem Objekt als %<asm%>-Ausgabe verwendet"
 
-#: c-family/c-warn.c:1525
+#: c-family/c-warn.c:1533
 #, gcc-internal-format
 msgid "assignment of read-only member %qD"
 msgstr "Zuweisung des schreibgeschützten Elementes %qD"
 
-#: c-family/c-warn.c:1526
+#: c-family/c-warn.c:1534
 #, gcc-internal-format
 msgid "increment of read-only member %qD"
 msgstr "Erhöhung des schreibgeschützten Elementes %qD"
 
-#: c-family/c-warn.c:1527
+#: c-family/c-warn.c:1535
 #, gcc-internal-format
 msgid "decrement of read-only member %qD"
 msgstr "Verringerung des schreibgeschützten Elementes %qD"
 
-#: c-family/c-warn.c:1528
+#: c-family/c-warn.c:1536
 #, gcc-internal-format
 msgid "read-only member %qD used as %<asm%> output"
 msgstr "schreibgeschütztes Element %qD als %<asm%>-Ausgabe verwendet"
 
-#: c-family/c-warn.c:1532
+#: c-family/c-warn.c:1540
 #, gcc-internal-format
 msgid "assignment of read-only variable %qD"
 msgstr "Zuweisung der schreibgeschützten Variable %qD"
 
-#: c-family/c-warn.c:1533
+#: c-family/c-warn.c:1541
 #, gcc-internal-format
 msgid "increment of read-only variable %qD"
 msgstr "Erhöhung der schreibgeschützten Variable %qD"
 
-#: c-family/c-warn.c:1534
+#: c-family/c-warn.c:1542
 #, gcc-internal-format
 msgid "decrement of read-only variable %qD"
 msgstr "Verringerung der schreibgeschützten Variable %qD"
 
-#: c-family/c-warn.c:1535
+#: c-family/c-warn.c:1543
 #, gcc-internal-format
 msgid "read-only variable %qD used as %<asm%> output"
 msgstr "schreibgeschützte Variable %qD als %<asm%>-Ausgabe verwendet"
 
-#: c-family/c-warn.c:1538
+#: c-family/c-warn.c:1546
 #, gcc-internal-format
 msgid "assignment of read-only parameter %qD"
 msgstr "Zuweisung des schreibgeschützten Parameters %qD"
 
-#: c-family/c-warn.c:1539
+#: c-family/c-warn.c:1547
 #, gcc-internal-format
 msgid "increment of read-only parameter %qD"
 msgstr "Erhöhung des schreibgeschützten Parameters %qD"
 
-#: c-family/c-warn.c:1540
+#: c-family/c-warn.c:1548
 #, gcc-internal-format
 msgid "decrement of read-only parameter %qD"
 msgstr "Verringerung des schreibgeschützten Parameters %qD"
 
-#: c-family/c-warn.c:1541
+#: c-family/c-warn.c:1549
 #, gcc-internal-format
 msgid "read-only parameter %qD use as %<asm%> output"
 msgstr "schreibgeschützter Parameter %qD als %<asm%>-Ausgabe verwendet"
 
-#: c-family/c-warn.c:1546
+#: c-family/c-warn.c:1554
 #, gcc-internal-format
 msgid "assignment of read-only named return value %qD"
 msgstr "Zuweisung des schreibgeschützten benannten Rückgabewertes %qD"
 
-#: c-family/c-warn.c:1548
+#: c-family/c-warn.c:1556
 #, gcc-internal-format
 msgid "increment of read-only named return value %qD"
 msgstr "Erhöhung des schreibgeschützten benannten Rückgabewertes %qD"
 
-#: c-family/c-warn.c:1550
+#: c-family/c-warn.c:1558
 #, gcc-internal-format
 msgid "decrement of read-only named return value %qD"
 msgstr "Verringerung des schreibgeschützten benannten Rückgabewertes %qD"
 
-#: c-family/c-warn.c:1552
+#: c-family/c-warn.c:1560
 #, gcc-internal-format
 msgid "read-only named return value %qD used as %<asm%>output"
 msgstr "schreibgeschützter benannter Rückgabewert %qD als %<asm%>-Ausgabe verwendet"
 
-#: c-family/c-warn.c:1557
+#: c-family/c-warn.c:1565
 #, gcc-internal-format
 msgid "assignment of function %qD"
 msgstr "Zuweisung der Funktion %qD"
 
-#: c-family/c-warn.c:1558
+#: c-family/c-warn.c:1566
 #, gcc-internal-format
 msgid "increment of function %qD"
 msgstr "Erhöhung der Funktion %qD"
 
-#: c-family/c-warn.c:1559
+#: c-family/c-warn.c:1567
 #, gcc-internal-format
 msgid "decrement of function %qD"
 msgstr "Verringerung der Funktion %qD"
 
-#: c-family/c-warn.c:1560
+#: c-family/c-warn.c:1568
 #, gcc-internal-format
 msgid "function %qD used as %<asm%> output"
 msgstr "Funktion %qD als %<asm%>-Ausgabe verwendet"
 
-#: c-family/c-warn.c:1563 c/c-typeck.c:4762
+#: c-family/c-warn.c:1571 c/c-typeck.c:4767
 #, gcc-internal-format
 msgid "assignment of read-only location %qE"
 msgstr "Zuweisung der schreibgeschützten Speicherstelle %qE"
 
-#: c-family/c-warn.c:1564 c/c-typeck.c:4765
+#: c-family/c-warn.c:1572 c/c-typeck.c:4770
 #, gcc-internal-format
 msgid "increment of read-only location %qE"
 msgstr "Erhöhung der schreibgeschützten Speicherstelle %qE"
 
-#: c-family/c-warn.c:1565 c/c-typeck.c:4768
+#: c-family/c-warn.c:1573 c/c-typeck.c:4773
 #, gcc-internal-format
 msgid "decrement of read-only location %qE"
 msgstr "Verringerung der schreibgeschützten Speicherstelle %qE"
 
-#: c-family/c-warn.c:1566
+#: c-family/c-warn.c:1574
 #, gcc-internal-format
 msgid "read-only location %qE used as %<asm%> output"
 msgstr "schreibgeschützte Stelle %qE als %<asm%>-Ausgabe verwendet"
 
-#: c-family/c-warn.c:1580
+#: c-family/c-warn.c:1588
 #, gcc-internal-format
 msgid "lvalue required as left operand of assignment"
 msgstr "Als linker Operand einer Zuweisung wird L-Wert erfordert"
 
-#: c-family/c-warn.c:1583
+#: c-family/c-warn.c:1591
 #, gcc-internal-format
 msgid "lvalue required as increment operand"
 msgstr "Als Erhöhungsoperand wird L-Wert erfordert"
 
-#: c-family/c-warn.c:1586
+#: c-family/c-warn.c:1594
 #, gcc-internal-format
 msgid "lvalue required as decrement operand"
 msgstr "Als Verringerungsoperand wird L-Wert erfordert"
 
-#: c-family/c-warn.c:1589
+#: c-family/c-warn.c:1597
 #, gcc-internal-format
 msgid "lvalue required as unary %<&%> operand"
 msgstr "Als Operand für unäres %<&%> wird L-Wert erfordert"
 
-#: c-family/c-warn.c:1592
+#: c-family/c-warn.c:1600
 #, gcc-internal-format
 msgid "lvalue required in asm statement"
 msgstr "In asm-Anweisung wird L-Wert erfordert"
 
-#: c-family/c-warn.c:1609
+#: c-family/c-warn.c:1617
 #, gcc-internal-format
 msgid "invalid type argument (have %qT)"
 msgstr "ungültiger Typ %qT"
 
-#: c-family/c-warn.c:1613
+#: c-family/c-warn.c:1621
 #, gcc-internal-format
 msgid "invalid type argument of array indexing (have %qT)"
 msgstr "ungültiger Typ %qT für Arrayindex"
 
-#: c-family/c-warn.c:1618
+#: c-family/c-warn.c:1626
 #, gcc-internal-format
 msgid "invalid type argument of unary %<*%> (have %qT)"
 msgstr "ungültiger Typ %qT für unäres %<*%>"
 
-#: c-family/c-warn.c:1623
+#: c-family/c-warn.c:1631
 #, gcc-internal-format
 msgid "invalid type argument of %<->%> (have %qT)"
 msgstr "ungültiger Typ %qT für %<->%>"
 
-#: c-family/c-warn.c:1628
+#: c-family/c-warn.c:1636
 #, gcc-internal-format
 msgid "invalid type argument of %<->*%> (have %qT)"
 msgstr "ungültiger Typ %qT für %<->*%>"
 
-#: c-family/c-warn.c:1633
+#: c-family/c-warn.c:1641
 #, gcc-internal-format
 msgid "invalid type argument of implicit conversion (have %qT)"
 msgstr "ungültiger Argumenttyp %qT für implizite Umwandlung"
 
-#: c-family/c-warn.c:1654
+#: c-family/c-warn.c:1662
 #, gcc-internal-format
 msgid "array subscript has type %<char%>"
 msgstr "Arrayindex hat Typ %<char%>"
 
-#: c-family/c-warn.c:1689 c-family/c-warn.c:1692
+#: c-family/c-warn.c:1697 c-family/c-warn.c:1700
 #, gcc-internal-format
 msgid "suggest parentheses around %<+%> inside %<<<%>"
 msgstr "Klammern um %<+%> innerhalb von %<<<%> empfohlen"
 
-#: c-family/c-warn.c:1695 c-family/c-warn.c:1698
+#: c-family/c-warn.c:1703 c-family/c-warn.c:1706
 #, gcc-internal-format
 msgid "suggest parentheses around %<-%> inside %<<<%>"
 msgstr "Klammern um %<-%> innerhalb von %<<<%>"
 
-#: c-family/c-warn.c:1704 c-family/c-warn.c:1707
+#: c-family/c-warn.c:1712 c-family/c-warn.c:1715
 #, gcc-internal-format
 msgid "suggest parentheses around %<+%> inside %<>>%>"
 msgstr "Klammern um %<+%> innerhalb von %<>>%> empfohlen"
 
-#: c-family/c-warn.c:1710 c-family/c-warn.c:1713
+#: c-family/c-warn.c:1718 c-family/c-warn.c:1721
 #, gcc-internal-format
 msgid "suggest parentheses around %<-%> inside %<>>%>"
 msgstr "Klammern um %<-%> innerhalb von %<>>%> empfohlen"
 
-#: c-family/c-warn.c:1719 c-family/c-warn.c:1722
+#: c-family/c-warn.c:1727 c-family/c-warn.c:1730
 #, gcc-internal-format
 msgid "suggest parentheses around %<&&%> within %<||%>"
 msgstr "Klammern um %<&&%> innerhalb von %<||%> empfohlen"
 
-#: c-family/c-warn.c:1729 c-family/c-warn.c:1733
+#: c-family/c-warn.c:1737 c-family/c-warn.c:1741
 #, gcc-internal-format
 msgid "suggest parentheses around arithmetic in operand of %<|%>"
 msgstr "Klammern um Arithmetik in Operand von %<|%> empfohlen"
 
-#: c-family/c-warn.c:1737 c-family/c-warn.c:1740
+#: c-family/c-warn.c:1745 c-family/c-warn.c:1748
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<|%>"
 msgstr "Klammern um Vergleich in Operand von %<|%> empfohlen"
 
-#: c-family/c-warn.c:1745
+#: c-family/c-warn.c:1753
 #, gcc-internal-format
 msgid "suggest parentheses around operand of %<!%> or change %<|%> to %<||%> or %<!%> to %<~%>"
 msgstr "Klammern um Operand von %<!%> empfohlen, oder Änderung von %<|%> in %<||%> oder %<!%> in %<~%>"
 
-#: c-family/c-warn.c:1753 c-family/c-warn.c:1757
+#: c-family/c-warn.c:1761 c-family/c-warn.c:1765
 #, gcc-internal-format
 msgid "suggest parentheses around arithmetic in operand of %<^%>"
 msgstr "Klammern um Arithmetik in Operand von %<^%> empfohlen"
 
-#: c-family/c-warn.c:1761 c-family/c-warn.c:1764
+#: c-family/c-warn.c:1769 c-family/c-warn.c:1772
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<^%>"
 msgstr "Klammern um Vergleich in Operand von %<^%> empfohlen"
 
-#: c-family/c-warn.c:1770 c-family/c-warn.c:1773
+#: c-family/c-warn.c:1778 c-family/c-warn.c:1781
 #, gcc-internal-format
 msgid "suggest parentheses around %<+%> in operand of %<&%>"
 msgstr "Klammern um %<+%> in Operand von %<&%> empfohlen"
 
-#: c-family/c-warn.c:1776 c-family/c-warn.c:1779
+#: c-family/c-warn.c:1784 c-family/c-warn.c:1787
 #, gcc-internal-format
 msgid "suggest parentheses around %<-%> in operand of %<&%>"
 msgstr "Klammern um %<-%> in Operand von %<&%> empfohlen"
 
-#: c-family/c-warn.c:1783 c-family/c-warn.c:1786
+#: c-family/c-warn.c:1791 c-family/c-warn.c:1794
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<&%>"
 msgstr "Klammern um Vergleich in Operand von %<&%> empfohlen"
 
-#: c-family/c-warn.c:1791
+#: c-family/c-warn.c:1799
 #, gcc-internal-format
 msgid "suggest parentheses around operand of %<!%> or change %<&%> to %<&&%> or %<!%> to %<~%>"
 msgstr "Klammern um Operand von %<!%> empfohlen, oder Änderung von %<&%> in %<&&%> oder %<!%> in %<~%>"
 
-#: c-family/c-warn.c:1798 c-family/c-warn.c:1801
+#: c-family/c-warn.c:1806 c-family/c-warn.c:1809
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<==%>"
 msgstr "Klammern um Vergleich in Operand von %<==%> empfohlen"
 
-#: c-family/c-warn.c:1806 c-family/c-warn.c:1809
+#: c-family/c-warn.c:1814 c-family/c-warn.c:1817
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<!=%>"
 msgstr "Klammern um Vergleich in Operand von %<!=%> empfohlen"
 
-#: c-family/c-warn.c:1819 c-family/c-warn.c:1825
+#: c-family/c-warn.c:1827 c-family/c-warn.c:1833
 #, gcc-internal-format
 msgid "comparisons like %<X<=Y<=Z%> do not have their mathematical meaning"
 msgstr "Vergleiche wie %<X<=Y<=Z%> haben nicht ihre mathematische Bedeutung"
 
-#: c-family/c-warn.c:1841
+#: c-family/c-warn.c:1849
 #, gcc-internal-format
 msgid "label %q+D defined but not used"
 msgstr "Marke %q+D definiert, aber nicht verwendet"
 
-#: c-family/c-warn.c:1843
+#: c-family/c-warn.c:1851
 #, gcc-internal-format
 msgid "label %q+D declared but not defined"
 msgstr "Marke %q+D deklariert, aber nicht definiert"
 
-#: c-family/c-warn.c:1866
+#: c-family/c-warn.c:1874
 #, gcc-internal-format
 msgid "division by zero"
 msgstr "Division durch Null"
 
-#: c-family/c-warn.c:1886
+#: c-family/c-warn.c:1894
 #, gcc-internal-format
 msgid "%<memset%> used with constant zero length parameter; this could be due to transposed parameters"
 msgstr "%<memset%> mit konstanter Länge 0 verwendet; das könnte heißen, dass die Parameter vertauscht sind"
 
-#: c-family/c-warn.c:1909
+#: c-family/c-warn.c:1918
 #, gcc-internal-format
 msgid "%<memset%> used with length equal to number of elements without multiplication by element size"
 msgstr "im Aufruf von %<memset%> ist die Länge gleich der Anzahl der Elemente angegeben, ohne sie mit der Elementgröße zu multiplizieren"
 
-#: c-family/c-warn.c:1948 c/c-typeck.c:11499 c/c-typeck.c:11667
+#: c-family/c-warn.c:1957 c/c-typeck.c:11504 c/c-typeck.c:11672
 #: cp/typeck.c:5048
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr "Vergleich zwischen den Typen %qT und %qT"
 
-#: c-family/c-warn.c:1998
+#: c-family/c-warn.c:2007
 #, gcc-internal-format
 msgid "comparison of integer expressions of different signedness: %qT and %qT"
 msgstr "Vergleich von Ganzzahlausdrücken, von denen nur einer ein Vorzeichen hat: %qT und %qT"
 
-#: c-family/c-warn.c:2051
+#: c-family/c-warn.c:2060
 #, gcc-internal-format
 msgid "promoted ~unsigned is always non-zero"
 msgstr "weitergegebenes ~vorzeichenlos ist immer Nicht-Null"
 
-#: c-family/c-warn.c:2054
+#: c-family/c-warn.c:2063
 #, gcc-internal-format
 msgid "comparison of promoted ~unsigned with constant"
 msgstr "Vergleich von weitergegebenem ~unsigned mit Konstante"
 
-#: c-family/c-warn.c:2064
+#: c-family/c-warn.c:2073
 #, gcc-internal-format
 msgid "comparison of promoted ~unsigned with unsigned"
 msgstr "Vergleich von weitergegebenem ~unsigned mit unsigned"
 
-#: c-family/c-warn.c:2118
+#: c-family/c-warn.c:2127
 #, gcc-internal-format
 msgid "unused parameter %qD"
 msgstr "unverwendeter Parameter %qD"
 
-#: c-family/c-warn.c:2180
+#: c-family/c-warn.c:2189
 #, gcc-internal-format
 msgid "typedef %qD locally defined but not used"
 msgstr "typedef %qD lokal definiert, aber nicht verwendet"
 
-#: c-family/c-warn.c:2215
+#: c-family/c-warn.c:2224
 #, gcc-internal-format
 msgid "duplicated %<if%> condition"
 msgstr "doppelte %<if%>-Bedingung"
 
-#: c-family/c-warn.c:2244
+#: c-family/c-warn.c:2253
 #, gcc-internal-format
 msgid "optimization attribute on %qD follows definition but the attribute doesn%'t match"
 msgstr "Optimierungsattribut von %qD folgt auf die Definition, aber die Attribute passen nicht zusammen"
 
-#: c-family/c-warn.c:2254
+#: c-family/c-warn.c:2261
 #, gcc-internal-format
 msgid "inline declaration of %qD follows declaration with attribute %qs"
 msgstr "inline-Deklaration von %qD folgt Deklaration mit Attribut %qs"
 
-#: c-family/c-warn.c:2259
+#: c-family/c-warn.c:2266
 #, gcc-internal-format
 msgid "declaration of %q+D with attribute %qs follows inline declaration"
 msgstr "Deklaration von %q+D mit Attribut %qs folgt auf inline-Deklaration"
 
-#: c-family/c-warn.c:2306
+#: c-family/c-warn.c:2313
 #, gcc-internal-format
 msgid "result of %qE requires %u bits to represent, but %qT only has %u bits"
 msgstr "Ergebnis von %qE erfordert %u Bits, aber %qT hat nur %u Bits"
 
-#: c-family/c-warn.c:2344 c-family/c-warn.c:2368
+#: c-family/c-warn.c:2351 c-family/c-warn.c:2375
 #, gcc-internal-format
 msgid "comparison of constant %qE with boolean expression is always false"
 msgstr "Vergleich der Konstanten %qE mit booleschem Ausdruck ist stets »false«"
 
-#: c-family/c-warn.c:2347 c-family/c-warn.c:2365
+#: c-family/c-warn.c:2354 c-family/c-warn.c:2372
 #, gcc-internal-format
 msgid "comparison of constant %qE with boolean expression is always true"
 msgstr "Vergleich der Konstanten %qE mit booleschem Ausdruck ist stets »true«"
 
-#: c-family/c-warn.c:2415
+#: c-family/c-warn.c:2422
 msgid "passing argument %i to restrict-qualified parameter aliases with argument %Z"
 msgid_plural "passing argument %i to restrict-qualified parameter aliases with arguments %Z"
 msgstr[0] "Argument %i ist als »restrict« markiert, wird aber auch in Argument %Z übergeben"
 msgstr[1] "Argument %i ist als »restrict« markiert, wird aber auch in Argumenten %Z übergeben"
 
-#: c-family/c-warn.c:2480 c/c-typeck.c:5288 cp/call.c:5365
+#: c-family/c-warn.c:2487 c/c-typeck.c:5293 cp/call.c:5365
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr "diese Bedingung hat identische Zweige"
 
-#: c-family/c-warn.c:2586
+#: c-family/c-warn.c:2593
 #, gcc-internal-format
 msgid "macro expands to multiple statements"
 msgstr "Makro expandiert zu mehreren Anweisungen"
 
-#: c-family/c-warn.c:2587
+#: c-family/c-warn.c:2594
 #, gcc-internal-format
 msgid "some parts of macro expansion are not guarded by this %qs clause"
 msgstr "Einige Teile des expandierten Makros sind nicht von diesem %qs-Konstrukt erfasst"
@@ -26715,7 +26756,7 @@
 msgid "too many input files"
 msgstr "zu viele Eingabedateien"
 
-#: common/config/aarch64/aarch64-common.c:319 config/aarch64/aarch64.c:10686
+#: common/config/aarch64/aarch64-common.c:319 config/aarch64/aarch64.c:10702
 #, gcc-internal-format
 msgid "unknown value %qs for -mcpu"
 msgstr "unbekannter Wert %qs für -mcpu"
@@ -26746,13 +26787,13 @@
 msgstr "unbekannte Option an %%:target_mode_check weitergegeben"
 
 #: common/config/arm/arm-common.c:322 common/config/arm/arm-common.c:376
-#: common/config/arm/arm-common.c:423 config/aarch64/aarch64.c:10639
+#: common/config/arm/arm-common.c:423 config/aarch64/aarch64.c:10655
 #, gcc-internal-format
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr "gültige Argumente sind: %s; meinten Sie %qs?"
 
 #: common/config/arm/arm-common.c:325 common/config/arm/arm-common.c:379
-#: common/config/arm/arm-common.c:426 config/aarch64/aarch64.c:10642
+#: common/config/arm/arm-common.c:426 config/aarch64/aarch64.c:10658
 #, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s"
 msgstr "gültige Argumente sind: %s"
@@ -27227,12 +27268,12 @@
 msgid "profiler support for VxWorks"
 msgstr "Profilerunterstützung für VxWorks"
 
-#: config/aarch64/aarch64-builtins.c:1109 config/arm/arm-builtins.c:2262
+#: config/aarch64/aarch64-builtins.c:1109 config/arm/arm-builtins.c:2272
 #, gcc-internal-format
 msgid "%Kargument %d must be a constant immediate"
 msgstr "%KArgument %d muss eine direkt angegebene Konstante sein"
 
-#: config/aarch64/aarch64-builtins.c:1180 config/arm/arm-builtins.c:2492
+#: config/aarch64/aarch64-builtins.c:1180 config/arm/arm-builtins.c:2502
 #, gcc-internal-format
 msgid "%Klane index must be a constant immediate"
 msgstr "%KSpurindex muss eine direkt angegebene Konstante sein"
@@ -27243,180 +27284,180 @@
 msgstr "%KGesamtgröße und Elementgröße müssen positive, direkt angegebene Konstanten sein"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79924
-#: config/aarch64/aarch64.c:1053
+#: config/aarch64/aarch64.c:1069
 #, gcc-internal-format
 msgid "%qs is incompatible with %s %s"
 msgstr "%qs ist mit »%s« »%s« unverträglich"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79924
-#: config/aarch64/aarch64.c:1055
+#: config/aarch64/aarch64.c:1071
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with %s %s"
 msgstr "%qs Feature-Modifizierer ist inkompatibel zu »%s« »%s«"
 
-#: config/aarch64/aarch64.c:3772
+#: config/aarch64/aarch64.c:3788
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr "Stapelsonde für SVE-Rahmen"
 
-#: config/aarch64/aarch64.c:10287
+#: config/aarch64/aarch64.c:10303
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown flag passed in -moverride=%s (%s)"
 msgstr "unbekanntes Flag wurde in »-moverride=%s« übergeben (%s)"
 
-#: config/aarch64/aarch64.c:10331
+#: config/aarch64/aarch64.c:10347
 #, gcc-internal-format, gfc-internal-format
 msgid "%s string ill-formed\n"
 msgstr "Zeichenkette für %s falsch geformt\n"
 
-#: config/aarch64/aarch64.c:10388
+#: config/aarch64/aarch64.c:10404
 #, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr "Tuning-Zeichenkette fehlt in Option »%s«"
 
-#: config/aarch64/aarch64.c:10406
+#: config/aarch64/aarch64.c:10422
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown tuning option (%s)"
 msgstr "unbekannte Tuning-Option »%s«"
 
-#: config/aarch64/aarch64.c:10683
+#: config/aarch64/aarch64.c:10699
 #, gcc-internal-format
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr "fehlender CPU-Name in %<-mcpu=%s%>"
 
-#: config/aarch64/aarch64.c:10690
+#: config/aarch64/aarch64.c:10706
 #, gcc-internal-format
 msgid "invalid feature modifier in %<-mcpu=%s%>"
 msgstr "unbekannter Feature-Modifizierer in %<-mcpu=%s%>"
 
-#: config/aarch64/aarch64.c:10717
+#: config/aarch64/aarch64.c:10733
 #, gcc-internal-format
 msgid "missing arch name in %<-march=%s%>"
 msgstr "fehlender Architekturname in %<-march=%s%>"
 
-#: config/aarch64/aarch64.c:10720
+#: config/aarch64/aarch64.c:10736
 #, gcc-internal-format
 msgid "unknown value %qs for -march"
 msgstr "unbekannter Wert %qs für -march"
 
-#: config/aarch64/aarch64.c:10724
+#: config/aarch64/aarch64.c:10740
 #, gcc-internal-format
 msgid "invalid feature modifier in %<-march=%s%>"
 msgstr "unbekannter Feature-Modifizierer in %<-march=%s%>"
 
-#: config/aarch64/aarch64.c:10750
+#: config/aarch64/aarch64.c:10766
 #, gcc-internal-format
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr "fehlender CPU-Name in %<-mtune=%s%>"
 
-#: config/aarch64/aarch64.c:10753
+#: config/aarch64/aarch64.c:10769
 #, gcc-internal-format
 msgid "unknown value %qs for -mtune"
 msgstr "unbekannter Wert %qs für -mtune"
 
-#: config/aarch64/aarch64.c:10871 config/arm/arm.c:3173
+#: config/aarch64/aarch64.c:10887 config/arm/arm.c:3173
 #, gcc-internal-format, gfc-internal-format
 msgid "switch -mcpu=%s conflicts with -march=%s switch"
 msgstr "Schalter -mcpu=%s steht mit dem Schalter -march=%s in Konflikt"
 
-#: config/aarch64/aarch64.c:10906
+#: config/aarch64/aarch64.c:10922
 #, gcc-internal-format
 msgid "assembler does not support -mabi=ilp32"
 msgstr "Assembler unterstützt »-mabi=ilp32« nicht"
 
-#: config/aarch64/aarch64.c:10913
+#: config/aarch64/aarch64.c:10929
 #, gcc-internal-format
 msgid "return address signing is only supported for -mabi=lp64"
 msgstr "Signieren der Rückgabeadresse wird nur für -mabi=lp64 unterstützt"
 
-#: config/aarch64/aarch64.c:10975
+#: config/aarch64/aarch64.c:10991
 #, gcc-internal-format
 msgid "code model %qs with -f%s"
 msgstr "Codemodell %qs mit -f%s"
 
-#: config/aarch64/aarch64.c:11138
+#: config/aarch64/aarch64.c:11154
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr "fehlender Name für Pragma oder Attribut %<target(\"arch=\")%>"
 
-#: config/aarch64/aarch64.c:11141
+#: config/aarch64/aarch64.c:11157
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"arch=\")%> pragma or attribute"
 msgstr "ungültiger Name (%qs) für Pragma oder Attribut %<target(\"arch=\")%>"
 
-#: config/aarch64/aarch64.c:11145 config/aarch64/aarch64.c:11184
-#: config/aarch64/aarch64.c:11257
+#: config/aarch64/aarch64.c:11161 config/aarch64/aarch64.c:11200
+#: config/aarch64/aarch64.c:11273
 #, gcc-internal-format
 msgid "invalid value (\"%s\") in %<target()%> pragma or attribute"
 msgstr "unbekannter Wert (%qs) für Pragma oder Attribut %<target()%>"
 
-#: config/aarch64/aarch64.c:11177
+#: config/aarch64/aarch64.c:11193
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr "fehlender Name für Pragma oder Attribut %<target(\"cpu=\")%>"
 
-#: config/aarch64/aarch64.c:11180
+#: config/aarch64/aarch64.c:11196
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"cpu=\")%> pragma or attribute"
 msgstr "ungültiger Name (%qs) für Pragma oder Attribut %<target(\"cpu=\")%>"
 
-#: config/aarch64/aarch64.c:11213
+#: config/aarch64/aarch64.c:11229
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"tune=\")%> pragma or attribute"
 msgstr "ungültiger Name (%qs) für Pragma oder Attribut %<target(\"tune=\")%>"
 
-#: config/aarch64/aarch64.c:11253
+#: config/aarch64/aarch64.c:11269
 #, gcc-internal-format
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr "fehlender Wert für Pragma oder Attribut %<target()%>"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79868
-#: config/aarch64/aarch64.c:11306 config/aarch64/aarch64.c:11483
+#: config/aarch64/aarch64.c:11322 config/aarch64/aarch64.c:11499
 #, gcc-internal-format
 msgid "malformed %<target()%> pragma or attribute"
 msgstr "falsch geformtes Pragma oder Attribut %<target()%>"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79868
-#: config/aarch64/aarch64.c:11354
+#: config/aarch64/aarch64.c:11370
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr "Pragma oder Attribut %<target(\"%s\")%> akzeptiert keine Argumente"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79868
-#: config/aarch64/aarch64.c:11362
+#: config/aarch64/aarch64.c:11378
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr "Pragma oder Attribut %<target(\"%s\")%> erlaubt keine negierte Form"
 
-#: config/aarch64/aarch64.c:11416
+#: config/aarch64/aarch64.c:11432
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr "Pragma oder Attribut %<target(\"%s=%s\")%> ist nicht gültig"
 
-#: config/aarch64/aarch64.c:11473 config/arm/arm.c:30742
-#: config/i386/i386.c:5440 config/powerpcspe/powerpcspe.c:39760
-#: config/rs6000/rs6000.c:36904 config/s390/s390.c:15746
+#: config/aarch64/aarch64.c:11489 config/arm/arm.c:30742
+#: config/i386/i386.c:5443 config/powerpcspe/powerpcspe.c:39760
+#: config/rs6000/rs6000.c:36960 config/s390/s390.c:15746
 #, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "Argument für Attribut %<target%> ist keine Zeichenkette"
 
-#: config/aarch64/aarch64.c:11500
+#: config/aarch64/aarch64.c:11516
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr "Pragma oder Attribut %<target(\"%s\")%> ist nicht gültig"
 
-#: config/aarch64/aarch64.c:11509
+#: config/aarch64/aarch64.c:11525
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr "falsch geformtes Pragma oder Attribut %<target(\"%s\")%>"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79872
-#: config/aarch64/aarch64.c:13571
+#: config/aarch64/aarch64.c:13587
 #, gcc-internal-format
 msgid "%Klane %wd out of range %wd - %wd"
 msgstr "%KSpur %wd außerhalb des Wertebereiches %wd bis %wd"
 
-#: config/aarch64/aarch64.c:13573
+#: config/aarch64/aarch64.c:13589
 #, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr "Spur %wd ist außerhalb des Wertebereiches %wd bis %wd"
@@ -27476,8 +27517,8 @@
 msgid "bad value %qs for -mmemory-latency"
 msgstr "Falscher Wert %qs für -mmemory-latency"
 
-#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6526
-#: config/arc/arc.c:6800 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
+#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6517
+#: config/arc/arc.c:6791 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
 #: config/tilepro/tilepro.c:3108
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -27588,11 +27629,11 @@
 #: config/arm/arm.c:7029 config/avr/avr.c:9718 config/avr/avr.c:9734
 #: config/bfin/bfin.c:4705 config/bfin/bfin.c:4766 config/bfin/bfin.c:4795
 #: config/epiphany/epiphany.c:491 config/h8300/h8300.c:5459
-#: config/i386/i386.c:6452 config/i386/i386.c:12479 config/i386/i386.c:41424
-#: config/i386/i386.c:41474 config/i386/i386.c:41544 config/m68k/m68k.c:780
+#: config/i386/i386.c:6455 config/i386/i386.c:12482 config/i386/i386.c:41418
+#: config/i386/i386.c:41468 config/i386/i386.c:41538 config/m68k/m68k.c:780
 #: config/mcore/mcore.c:3070 config/nvptx/nvptx.c:4611
 #: config/powerpcspe/powerpcspe.c:35785 config/riscv/riscv.c:2698
-#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:32982
+#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:33038
 #: config/rx/rx.c:2719 config/rx/rx.c:2745 config/s390/s390.c:1056
 #: config/s390/s390.c:1143 config/sh/sh.c:8428 config/sh/sh.c:8446
 #: config/sh/sh.c:8470 config/sh/sh.c:8541 config/sh/sh.c:8564
@@ -27602,133 +27643,133 @@
 msgid "%qE attribute only applies to functions"
 msgstr "Attribut %qE bezieht sich nur auf Funktionen"
 
-#: config/arc/arc.c:6425
+#: config/arc/arc.c:6416
 #, gcc-internal-format
 msgid "__builtin_arc_aligned with non-constant alignment"
 msgstr "%<__builtin_arc_aligned%> mit variabler Ausrichtung"
 
-#: config/arc/arc.c:6433
+#: config/arc/arc.c:6424
 #, gcc-internal-format
 msgid "invalid alignment value for __builtin_arc_aligned"
 msgstr "Ungültiger Ausrichtungswert für %<__builtin_arc_aligned%>"
 
-#: config/arc/arc.c:6596
+#: config/arc/arc.c:6587
 #, gcc-internal-format
 msgid "operand 1 should be an unsigned 3-bit immediate"
 msgstr "Operand 1 sollte eine vorzeichenlose 3-Bit-Konstante sein"
 
-#: config/arc/arc.c:6637 config/arc/arc.c:6734
+#: config/arc/arc.c:6628 config/arc/arc.c:6725
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (I0-I7)"
 msgstr "Operand 2 sollte ein vorzeichenloser 3-Bit-Wert sein (I0–I7)"
 
-#: config/arc/arc.c:6670 config/arc/arc.c:6702
+#: config/arc/arc.c:6661 config/arc/arc.c:6693
 #, gcc-internal-format
 msgid "operand 1 should be an unsigned 3-bit value (I0-I7)"
 msgstr "Operand 1 sollte ein vorzeichenloser 3-Bit-Wert sein (I0–I7)"
 
-#: config/arc/arc.c:6674 config/arc/arc.c:6706
+#: config/arc/arc.c:6665 config/arc/arc.c:6697
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 8-bit value"
 msgstr "Operand 2 sollte ein vorzeichenloser 8-Bit-Wert sein"
 
-#: config/arc/arc.c:6738
+#: config/arc/arc.c:6729
 #, gcc-internal-format
 msgid "operand 3 should be an unsigned 8-bit value"
 msgstr "Operand 3 sollte ein vorzeichenloser 8-Bit-Wert sein"
 
-#: config/arc/arc.c:6771
+#: config/arc/arc.c:6762
 #, gcc-internal-format
 msgid "operand 4 should be an unsigned 8-bit value (0-255)"
 msgstr "Operand 4 sollte ein vorzeichenloser 8-Bit-Wert sein (0–255)"
 
-#: config/arc/arc.c:6775
+#: config/arc/arc.c:6766
 #, gcc-internal-format
 msgid "operand 3 should be an unsigned 3-bit value (I0-I7)"
 msgstr "Operand 3 sollte ein vorzeichenloser 3-Bit-Wert sein (I0–I7)"
 
-#: config/arc/arc.c:6782
+#: config/arc/arc.c:6773
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (subreg 0-7)"
 msgstr "Operand 2 sollte ein vorzeichenloser 3-Bit-Wert sein (subreg 0–7)"
 
-#: config/arc/arc.c:6785
+#: config/arc/arc.c:6776
 #, gcc-internal-format
 msgid "operand 2 should be an even 3-bit value (subreg 0,2,4,6)"
 msgstr "Operand 2 sollte ein gerader 3-Bit-Wert sein (subreg 0,2,4,6)"
 
-#: config/arc/arc.c:6832
+#: config/arc/arc.c:6823
 #, gcc-internal-format, gfc-internal-format
 msgid "builtin requires an immediate for operand %d"
 msgstr "Operand %d der eingebauten Funktion muss konstant sein"
 
-#: config/arc/arc.c:6837
+#: config/arc/arc.c:6828
 #, gcc-internal-format, gfc-internal-format
 msgid "operand %d should be a 6 bit unsigned immediate"
 msgstr "Operand %d sollte eine vorzeichenlose 6-Bit-Konstante sein"
 
-#: config/arc/arc.c:6841
+#: config/arc/arc.c:6832
 #, gcc-internal-format, gfc-internal-format
 msgid "operand %d should be a 8 bit unsigned immediate"
 msgstr "Operand %d sollte eine vorzeichenlose 8-Bit-Konstante sein"
 
-#: config/arc/arc.c:6845
+#: config/arc/arc.c:6836
 #, gcc-internal-format, gfc-internal-format
 msgid "operand %d should be a 3 bit unsigned immediate"
 msgstr "Operand %d sollte eine vorzeichenlose 3-Bit-Konstante sein"
 
-#: config/arc/arc.c:6848
+#: config/arc/arc.c:6839
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown builtin immediate operand type for operand %d"
 msgstr "unbekannter eingebauter direkter Operandentyp für Operand %d"
 
-#: config/arc/arc.c:6899
+#: config/arc/arc.c:6890
 #, gcc-internal-format
 msgid "register number must be a compile-time constant. Try giving higher optimization levels"
 msgstr "Registernummer muss bereits zur Kompilierzeit eine Konstante sein. Probieren Sie eine stärkere Optimierungsstufe"
 
-#: config/arc/arc.c:7685
+#: config/arc/arc.c:7747
 #, gcc-internal-format
 msgid "Insn addresses not set after shorten_branches"
 msgstr "Befehlsadresse nicht festgelegt, nachdem shorten_branches aufgerufen wurde"
 
-#: config/arc/arc.c:7894
+#: config/arc/arc.c:7956
 #, gcc-internal-format
 msgid "insn addresses not freed"
 msgstr "Befehlsadressen nicht freigegeben"
 
-#: config/arc/arc.c:10682
+#: config/arc/arc.c:10670
 #, gcc-internal-format
 msgid "%qE attribute only valid for ARCv2 architecture"
 msgstr "Attribut %qE ist nur für die Architektur ARCv2 gültig"
 
-#: config/arc/arc.c:10690 config/arc/arc.c:10729
+#: config/arc/arc.c:10678 config/arc/arc.c:10717
 #, gcc-internal-format
 msgid "argument of %qE attribute is missing"
 msgstr "Argument des Attributs %qE fehlt"
 
-#: config/arc/arc.c:10701 config/arc/arc.c:10740 config/arc/arc.c:10842
+#: config/arc/arc.c:10689 config/arc/arc.c:10728 config/arc/arc.c:10830
 #: config/avr/avr.c:9790
 #, gcc-internal-format
 msgid "%qE attribute allows only an integer constant argument"
 msgstr "Attribut %qE erlaubt nur eine Ganzzahlkonstante als Argument"
 
-#: config/arc/arc.c:10721
+#: config/arc/arc.c:10709
 #, gcc-internal-format
 msgid "%qE attribute only valid for ARC EM architecture"
 msgstr "Attribut %qE ist nur für die ARC-EM-Architektur gültig"
 
-#: config/arc/arc.c:10776
+#: config/arc/arc.c:10764
 #, gcc-internal-format
 msgid "%qE attribute only applies to types"
 msgstr "Attribut %qE kann nur auf Typen angewandt werden"
 
-#: config/arc/arc.c:10782
+#: config/arc/arc.c:10770
 #, gcc-internal-format
 msgid "argument of %qE attribute ignored"
 msgstr "Argument des Attributs %qE wird ignoriert"
 
-#: config/arc/arc.c:10832 config/avr/avr.c:9777 config/bfin/bfin.c:4827
+#: config/arc/arc.c:10820 config/avr/avr.c:9777 config/bfin/bfin.c:4827
 #: config/i386/winnt.c:63 config/msp430/msp430.c:2018
 #: config/nvptx/nvptx.c:4634
 #, gcc-internal-format
@@ -27735,174 +27776,174 @@
 msgid "%qE attribute only applies to variables"
 msgstr "Attribut %qE bezieht sich nur auf Variablen"
 
-#: config/arm/arm-builtins.c:2370
+#: config/arm/arm-builtins.c:2380
 #, gcc-internal-format
 msgid "this builtin is not supported for this target"
 msgstr "diese eingebaute Funktion wird auf diesem Ziel nicht unterstützt"
 
-#: config/arm/arm-builtins.c:2475
+#: config/arm/arm-builtins.c:2485
 #, gcc-internal-format
 msgid "You must enable NEON instructions (e.g. -mfloat-abi=softfp -mfpu=neon) to use these intrinsics."
 msgstr "Um diese intrinsischen Funktionen zu verwenden, müssen Sie NEON-Befehle einschalten (zum Beispiel mit »-mfloat-abi=softfp -mfpu=neon«)."
 
-#: config/arm/arm-builtins.c:2513
+#: config/arm/arm-builtins.c:2523
 #, gcc-internal-format
 msgid "You must enable VFP instructions to use these intrinsics."
 msgstr "Um diese intrinsischen Funktionen zu verwenden, müssen Sie VFP-Befehle einschalten."
 
-#: config/arm/arm-builtins.c:2573
+#: config/arm/arm-builtins.c:2583
 #, gcc-internal-format
 msgid "You must enable crypto instructions (e.g. include -mfloat-abi=softfp -mfpu=crypto-neon...) to use these intrinsics."
 msgstr "Um diese intrinsischen Funktionen zu verwenden, müssen Sie Krypto-Befehle einschalten (zum Beispiel mit »-mfloat-abi=softfp -mfpu=crypto-neon«)"
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:2633 config/arm/arm-builtins.c:2737
+#: config/arm/arm-builtins.c:2643 config/arm/arm-builtins.c:2747
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr "Wähler muss »immediate« sein"
 
-#: config/arm/arm-builtins.c:2641 config/arm/arm-builtins.c:2686
-#: config/arm/arm-builtins.c:2744 config/arm/arm-builtins.c:2753
+#: config/arm/arm-builtins.c:2651 config/arm/arm-builtins.c:2696
+#: config/arm/arm-builtins.c:2754 config/arm/arm-builtins.c:2763
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr "der Wertebereich des Selektors sollte 0 bis 7 sein"
 
-#: config/arm/arm-builtins.c:2646 config/arm/arm-builtins.c:2755
+#: config/arm/arm-builtins.c:2656 config/arm/arm-builtins.c:2765
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr "der Wertebereich des Selektors sollte 0 bis 3 sein"
 
-#: config/arm/arm-builtins.c:2651 config/arm/arm-builtins.c:2757
+#: config/arm/arm-builtins.c:2661 config/arm/arm-builtins.c:2767
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr "der Wertebereich des Selektors sollte 0 bis 1 sein"
 
-#: config/arm/arm-builtins.c:2823
+#: config/arm/arm-builtins.c:2833
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr "Maske muss »immediate« sein"
 
-#: config/arm/arm-builtins.c:2828
+#: config/arm/arm-builtins.c:2838
 #, gcc-internal-format
 msgid "the range of mask should be in 0 to 255"
 msgstr "der Wertebereich der Maske ist 0 bis 255"
 
-#: config/arm/arm-builtins.c:3016
+#: config/arm/arm-builtins.c:3026
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr "der Wertebereich des Zählers ist 0 bis 32. Bitte intrinsisches _mm_rori_pi16 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3018
+#: config/arm/arm-builtins.c:3028
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr "der Wertebereich des Zählers ist 0 bis 32. Bitte intrinsisches _mm_rori_pi32 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3020
+#: config/arm/arm-builtins.c:3030
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr "der Wertebereich des Zählers ist 0 bis 32. Bitte intrinsisches _mm_ror_pi16 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3022
+#: config/arm/arm-builtins.c:3032
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr "der Wertebereich des Zählers ist 0 bis 32. Bitte intrinsisches _mm_ror_pi32 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3028
+#: config/arm/arm-builtins.c:3038
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr "der Wertebereich des Zählers ist 0 bis 64. Bitte intrinsisches _mm_rori_si64 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3030
+#: config/arm/arm-builtins.c:3040
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr "der Wertebereich des Zählers ist 0 bis 64. Bitte intrinsisches _mm_ror_si64 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3035
+#: config/arm/arm-builtins.c:3045
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_srli_pi16 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3037
+#: config/arm/arm-builtins.c:3047
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_srli_pi32 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3039
+#: config/arm/arm-builtins.c:3049
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_srli_si64 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3041
+#: config/arm/arm-builtins.c:3051
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_slli_pi16 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3043
+#: config/arm/arm-builtins.c:3053
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_slli_pi32 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3045
+#: config/arm/arm-builtins.c:3055
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_slli_si64 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3047
+#: config/arm/arm-builtins.c:3057
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_srai_pi16 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3049
+#: config/arm/arm-builtins.c:3059
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_srai_pi32 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3051
+#: config/arm/arm-builtins.c:3061
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_srai_si64 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3053
+#: config/arm/arm-builtins.c:3063
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_srl_pi16 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3055
+#: config/arm/arm-builtins.c:3065
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_srl_pi32 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3057
+#: config/arm/arm-builtins.c:3067
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_srl_si64 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3059
+#: config/arm/arm-builtins.c:3069
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_sll_pi16 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3061
+#: config/arm/arm-builtins.c:3071
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_sll_pi32 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3063
+#: config/arm/arm-builtins.c:3073
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_sll_si64 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3065
+#: config/arm/arm-builtins.c:3075
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_sra_pi16 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3067
+#: config/arm/arm-builtins.c:3077
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_sra_pi32 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3069
+#: config/arm/arm-builtins.c:3079
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_sra_si64 im Code prüfen."
@@ -28812,551 +28853,551 @@
 msgid "can%'t set position in PCH file: %m"
 msgstr "Position in PCH-Datei kann nicht gesetzt werden: %m"
 
-#: config/i386/i386.c:3177
+#: config/i386/i386.c:3180
 #, gcc-internal-format
 msgid "wrong argument %qs to option %qs"
 msgstr "falsches Argument %qs für Option %qs"
 
-#: config/i386/i386.c:3183
+#: config/i386/i386.c:3186
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr "Größenbereiche der Option %qs sollten aufsteigend sein"
 
-#: config/i386/i386.c:3193
+#: config/i386/i386.c:3196
 #, gcc-internal-format
 msgid "wrong strategy name %qs specified for option %qs"
 msgstr "falscher Strategiename %qs für Option %qs angegeben"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3219
+#: config/i386/i386.c:3222
 #, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr "Strategiename %qs für Option %qs angegeben, wird jedoch für 32-Bit-Code nicht unterstützt"
 
-#: config/i386/i386.c:3232
+#: config/i386/i386.c:3235
 #, gcc-internal-format
 msgid "unknown alignment %qs specified for option %qs"
 msgstr "unbekannte Ausrichtung %qs für Option %qs angegeben"
 
-#: config/i386/i386.c:3242
+#: config/i386/i386.c:3245
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr "der Maximalwert für den letzten Größenbereich sollte für Option %qs -1 sein"
 
-#: config/i386/i386.c:3249
+#: config/i386/i386.c:3252
 #, gcc-internal-format
 msgid "too many size ranges specified in option %qs"
 msgstr "zu viele Größenbereiche in Option %qs angegeben"
 
-#: config/i386/i386.c:3302
+#: config/i386/i386.c:3305
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown parameter to option -mtune-ctrl: %s"
 msgstr "Unbekannter Parameter für Option »-mtune-ctrl«: %s"
 
-#: config/i386/i386.c:3726
+#: config/i386/i386.c:3729
 #, gcc-internal-format
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "Intel-MCU-psABI wird im %s-Modus nicht unterstützt"
 
-#: config/i386/i386.c:3775
+#: config/i386/i386.c:3778
 #, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "%<-mtune=x86-64%> ist veraltet; stattdessen entsprechend %<-mtune=k8%> oder %<-mtune=generic%> verwenden"
 
-#: config/i386/i386.c:3777
+#: config/i386/i386.c:3780
 #, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr "%<target(\"tune=x86-64\")%> ist veraltet; stattdessen entsprechend %<target(\"tune=k8\")%> oder %<target(\"tune=generic\")%> verwenden"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3804
+#: config/i386/i386.c:3807
 #, gcc-internal-format
 msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgstr "-mstringop-strategy=rep_8byte wird für 32-Bit-Code nicht unterstützt"
 
-#: config/i386/i386.c:3821
+#: config/i386/i386.c:3824
 #, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "Adressmodus %qs wird im %s-Bit-Modus nicht unterstützt"
 
-#: config/i386/i386.c:3833
+#: config/i386/i386.c:3836
 #, gcc-internal-format
 msgid "-mabi=ms not supported with X32 ABI"
 msgstr "-mabi=ms wird in der X32-ABI nicht unterstützt"
 
-#: config/i386/i386.c:3851 config/i386/i386.c:3860 config/i386/i386.c:3872
-#: config/i386/i386.c:3883 config/i386/i386.c:3894
+#: config/i386/i386.c:3854 config/i386/i386.c:3863 config/i386/i386.c:3875
+#: config/i386/i386.c:3886 config/i386/i386.c:3897
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "Codemodell %qs wird im %s-Bit-Modus nicht unterstützt"
 
-#: config/i386/i386.c:3863 config/i386/i386.c:3875
+#: config/i386/i386.c:3866 config/i386/i386.c:3878
 #, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "Codemodell %qs wird im x32-Modus nicht unterstützt"
 
-#: config/i386/i386.c:3881 config/i386/i386.c:3890 config/i386/i386.c:5213
+#: config/i386/i386.c:3884 config/i386/i386.c:3893 config/i386/i386.c:5216
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "Codemodell %s unterstützt keinen PIC-Modus"
 
-#: config/i386/i386.c:3918
+#: config/i386/i386.c:3921
 #, gcc-internal-format
 msgid "-masm=intel not supported in this configuration"
 msgstr "-masm=intel wird in dieser Konfiguration nicht unterstützt"
 
-#: config/i386/i386.c:3923
+#: config/i386/i386.c:3926
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "%i-Bit-Modus nicht einkompiliert"
 
-#: config/i386/i386.c:3932
+#: config/i386/i386.c:3935
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr "%<generic%>-CPU kann nur für %<-mtune=%>-Schalter verwendet werden"
 
-#: config/i386/i386.c:3934
+#: config/i386/i386.c:3937
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "%<generic%>-CPU kann nur für %<target(\"tune=\")%>-Schalter verwendet werden"
 
-#: config/i386/i386.c:3941
+#: config/i386/i386.c:3944
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr "%<intel%>-CPU kann nur für %<-mtune%>-Schalter verwendet werden"
 
-#: config/i386/i386.c:3943
+#: config/i386/i386.c:3946
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "%<intel%>-CPU kann nur für %<target(\"tune=\")%>-Attribut verwendet werden"
 
-#: config/i386/i386.c:3951 config/i386/i386.c:4265
+#: config/i386/i386.c:3954 config/i386/i386.c:4268
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "Die ausgewählte CPU unterstützt nicht den x86-64 Befehlssatz"
 
-#: config/i386/i386.c:4197 config/i386/i386.c:4200
+#: config/i386/i386.c:4200 config/i386/i386.c:4203
 #, gcc-internal-format
 msgid "Intel MPX does not support x32"
 msgstr "Intel MPX unterstützt x32 nicht"
 
-#: config/i386/i386.c:4205
+#: config/i386/i386.c:4208
 #, gcc-internal-format
 msgid "bad value (%qs) for %<-march=%> switch"
 msgstr "falscher Wert (%qs) für Schalter %<-march=%>"
 
-#: config/i386/i386.c:4206
+#: config/i386/i386.c:4209
 #, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"arch=\")%> attribute"
 msgstr "unbekannter Wert (%qs) für %<target(\"arch=\")%>-Attribut"
 
-#: config/i386/i386.c:4228
+#: config/i386/i386.c:4231
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "gültige Argumente für %<-march=%> sind: %s; meinten Sie %qs?"
 
-#: config/i386/i386.c:4230
+#: config/i386/i386.c:4233
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr "gültige Argumente für %<target(\"arch=\")%> sind: %s; meinten Sie %qs?"
 
-#: config/i386/i386.c:4235
+#: config/i386/i386.c:4238
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "gültige Argumente für %<-march=%> sind: %s"
 
-#: config/i386/i386.c:4236
+#: config/i386/i386.c:4239
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "gültige Argumente für %<target(\"arch=\")%> sind: %s"
 
-#: config/i386/i386.c:4284
+#: config/i386/i386.c:4287
 #, gcc-internal-format
 msgid "bad value (%qs) for %<-mtune=%> switch"
 msgstr "falscher Wert (%qs) für Schalter %<-mtune=%>"
 
-#: config/i386/i386.c:4285
+#: config/i386/i386.c:4288
 #, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"tune=\")%> attribute"
 msgstr "unbekannter Wert %qs für %<target(\"tune=\")%>-Attribut"
 
-#: config/i386/i386.c:4305
+#: config/i386/i386.c:4308
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "gültige Argumente für %<-mtune=%> sind: %s; meinten Sie %qs?"
 
-#: config/i386/i386.c:4307
+#: config/i386/i386.c:4310
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr "gültige Argumente für %<target(\"tune=\")%> sind: %s; meinten Sie %qs?"
 
-#: config/i386/i386.c:4312
+#: config/i386/i386.c:4315
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "gültige Argumente für %<-mtune=%> sind: %s"
 
-#: config/i386/i386.c:4313
+#: config/i386/i386.c:4316
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "gültige Argumente für %<target(\"tune\")%> sind: %s"
 
-#: config/i386/i386.c:4379
+#: config/i386/i386.c:4382
 #, gcc-internal-format
 msgid "-mregparm is ignored in 64-bit mode"
 msgstr "-mregparm wird im 64-Bit-Modus ignoriert"
 
-#: config/i386/i386.c:4381
+#: config/i386/i386.c:4384
 #, gcc-internal-format
 msgid "-mregparm is ignored for Intel MCU psABI"
 msgstr "-mregparm wird für Intel-MCU-psABI ignoriert"
 
-#: config/i386/i386.c:4384
+#: config/i386/i386.c:4387
 #, gcc-internal-format, gfc-internal-format
 msgid "-mregparm=%d is not between 0 and %d"
 msgstr "-mregparm=%d ist nicht zwischen 0 und %d"
 
-#: config/i386/i386.c:4417
+#: config/i386/i386.c:4420
 #, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "%<-mrtd%> wird im 64-Bit-Modus ignoriert"
 
-#: config/i386/i386.c:4418
+#: config/i386/i386.c:4421
 #, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "%<target(\"rtd\")%> wird im 64-Bit-Modus ignoriert"
 
-#: config/i386/i386.c:4497
+#: config/i386/i386.c:4500
 #, gcc-internal-format
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "-mpreferred-stack-boundary wird für dieses Ziel nicht unterstützt"
 
-#: config/i386/i386.c:4500
+#: config/i386/i386.c:4503
 #, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d ist nicht zwischen %d und %d"
 
-#: config/i386/i386.c:4523
+#: config/i386/i386.c:4526
 #, gcc-internal-format, gfc-internal-format
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr "-mincoming-stack-boundary=%d ist nicht zwischen %d und 12"
 
-#: config/i386/i386.c:4536
+#: config/i386/i386.c:4539
 #, gcc-internal-format
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "-mnop-mcount ist nicht mit diesem Ziel kompatibel"
 
-#: config/i386/i386.c:4539
+#: config/i386/i386.c:4542
 #, gcc-internal-format
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr "-mnop-mcount ist für -fPIC nicht implementiert"
 
-#: config/i386/i386.c:4545
+#: config/i386/i386.c:4548
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "%<-msseregparm%> verwendet, ohne dass SSE eingeschaltet ist"
 
-#: config/i386/i386.c:4546
+#: config/i386/i386.c:4549
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "%<target(\"sseregparm\")%> verwendet, ohne dass SSE eingeschaltet ist"
 
-#: config/i386/i386.c:4556
+#: config/i386/i386.c:4559
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "SSE-Befehlssatz ausgeschaltet, es wird 387-Arithmetik verwendet"
 
-#: config/i386/i386.c:4563
+#: config/i386/i386.c:4566
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "387-Befehlssatz ausgeschaltet, es wird SSE-Arithmetik verwendet"
 
-#: config/i386/i386.c:4613
+#: config/i386/i386.c:4616
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr "Stapel-Überprüfung erfordert %<-maccumulate-outgoing-args%> für Korrektheit"
 
-#: config/i386/i386.c:4615
+#: config/i386/i386.c:4618
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr "Stapel-Überprüfung erfordert %<target(\"accumulate-outgoing-args\")%> für Korrektheit"
 
-#: config/i386/i386.c:4629
+#: config/i386/i386.c:4632
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr "feststehendes ebp-Register erfordert %<-maccumulate-outgoing-args%>"
 
-#: config/i386/i386.c:4631
+#: config/i386/i386.c:4634
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr "feststehendes ebp-Register erfordert %<target(\"accumulate-outgoing-args\")%>"
 
-#: config/i386/i386.c:4741
+#: config/i386/i386.c:4744
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr "-mfentry wird für 32 Bit in Kombination mit -fpic nicht unterstützt"
 
-#: config/i386/i386.c:4744
+#: config/i386/i386.c:4747
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr "-mno-fentry ist nicht mit SEH verträglich"
 
-#: config/i386/i386.c:4748
+#: config/i386/i386.c:4751
 #, gcc-internal-format
 msgid "-mcall-ms2sysv-xlogues isn%'t currently supported with SEH"
 msgstr "-mcall-ms2sysv-xlogues wird derzeit nicht zusammen mit SEH unterstützt"
 
-#: config/i386/i386.c:4813 config/powerpcspe/powerpcspe.c:5663
+#: config/i386/i386.c:4816 config/powerpcspe/powerpcspe.c:5663
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown option for -mrecip=%s"
 msgstr "unbekannte Option für -mrecip=%s"
 
-#: config/i386/i386.c:4870 config/powerpcspe/powerpcspe.c:5339
+#: config/i386/i386.c:4873 config/powerpcspe/powerpcspe.c:5339
 #, gcc-internal-format
 msgid "%qs is not a valid number in -mstack-protector-guard-offset="
 msgstr "%qs ist keine gültige Zahl in -mstack-protector-guard-offset="
 
-#: config/i386/i386.c:4875 config/powerpcspe/powerpcspe.c:5344
+#: config/i386/i386.c:4878 config/powerpcspe/powerpcspe.c:5344
 #, gcc-internal-format
 msgid "%qs is not a valid offset in -mstack-protector-guard-offset="
 msgstr "%qs ist kein gültiger Offset in »-mstack-protector-guard-offset=«"
 
-#: config/i386/i386.c:4907 config/powerpcspe/powerpcspe.c:5356
+#: config/i386/i386.c:4910 config/powerpcspe/powerpcspe.c:5356
 #, gcc-internal-format
 msgid "%qs is not a valid base register in -mstack-protector-guard-reg="
 msgstr "%qs ist kein gültiges Basisregister in -mstack-protector-guard-reg="
 
-#: config/i386/i386.c:5506 config/i386/i386.c:5553 config/s390/s390.c:15812
+#: config/i386/i386.c:5509 config/i386/i386.c:5556 config/s390/s390.c:15812
 #: config/s390/s390.c:15862 config/s390/s390.c:15879
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr "attribute(target(\"%s\")) ist unbekannt"
 
-#: config/i386/i386.c:5534
+#: config/i386/i386.c:5537
 #, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr "option(\"%s\") wurde bereits spezifiziert"
 
-#: config/i386/i386.c:5837
+#: config/i386/i386.c:5840
 #, gcc-internal-format
 msgid "interrupt and naked attributes are not compatible"
 msgstr "die Attribute %<interrupt%> und %<naked%> sind nicht kompatibel"
 
-#: config/i386/i386.c:5852
+#: config/i386/i386.c:5855
 #, gcc-internal-format
 msgid "Only DWARF debug format is supported for interrupt service routine."
 msgstr "Nur das DWARF-Debugformat ist für Interrupt-Service-Routinen unterstützt."
 
-#: config/i386/i386.c:5901
+#: config/i386/i386.c:5904
 #, gcc-internal-format
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "%<-mindirect-branch=%s%> und %<-mcmodel=large%> sind nicht kompatibel"
 
-#: config/i386/i386.c:5913
+#: config/i386/i386.c:5916
 #, gcc-internal-format
 msgid "%<-mindirect-branch=thunk-extern%>, %<-fcf-protection=branch%> and %<-fcheck-pointer-bounds%> are not compatible"
 msgstr "%<-mindirect-branch=thunk-extern%>, %<-fcf-protection=branch%> und %<-fcheck-pointer-bounds%> sind nicht kompatibel"
 
-#: config/i386/i386.c:5949
+#: config/i386/i386.c:5952
 #, gcc-internal-format
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "%<-mfunction-return=%s%> und %<-mcmodel=large%> sind nicht kompatibel"
 
-#: config/i386/i386.c:6047
+#: config/i386/i386.c:6050
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in %s service routine"
 msgstr "%s-Befehle sind in »%s«-Serviceroutine nicht erlaubt"
 
-#: config/i386/i386.c:6051
+#: config/i386/i386.c:6054
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in function with no_caller_saved_registers attribute"
 msgstr "%s-Befehle sind in Funktionen mit »no_caller_saved_registers«-Attribut nicht erlaubt"
 
-#: config/i386/i386.c:6465 config/i386/i386.c:6516
+#: config/i386/i386.c:6468 config/i386/i386.c:6519
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "Attribute fastcall und regparm sind nicht verträglich"
 
-#: config/i386/i386.c:6470
+#: config/i386/i386.c:6473
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "Attribute regparam und thiscall sind nicht verträglich"
 
-#: config/i386/i386.c:6477 config/i386/i386.c:41444
+#: config/i386/i386.c:6480 config/i386/i386.c:41438
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "Attribut %qE benötigt eine Ganzzahlkonstante als Argument"
 
-#: config/i386/i386.c:6483
+#: config/i386/i386.c:6486
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "Argument für Attribut %qE ist größer als %d"
 
-#: config/i386/i386.c:6508 config/i386/i386.c:6551
+#: config/i386/i386.c:6511 config/i386/i386.c:6554
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "Attribute fastcall und cdecl sind nicht verträglich"
 
-#: config/i386/i386.c:6512
+#: config/i386/i386.c:6515
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "Attribute fastcall und stdcall sind nicht verträglich"
 
-#: config/i386/i386.c:6520 config/i386/i386.c:6569
+#: config/i386/i386.c:6523 config/i386/i386.c:6572
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "Attribute fastcall und thiscall sind nicht verträglich"
 
-#: config/i386/i386.c:6530 config/i386/i386.c:6547
+#: config/i386/i386.c:6533 config/i386/i386.c:6550
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "Attribute stdcall und cdecl sind nicht verträglich"
 
-#: config/i386/i386.c:6534
+#: config/i386/i386.c:6537
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "Attribute stdcall und fastcall sind nicht verträglich"
 
-#: config/i386/i386.c:6538 config/i386/i386.c:6565
+#: config/i386/i386.c:6541 config/i386/i386.c:6568
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "Attribute stdcall und thiscall sind nicht verträglich"
 
-#: config/i386/i386.c:6555 config/i386/i386.c:6573
+#: config/i386/i386.c:6558 config/i386/i386.c:6576
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "Attribute cdecl und thiscall sind nicht verträglich"
 
-#: config/i386/i386.c:6561
+#: config/i386/i386.c:6564
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "Attribut %qE wird für Nicht-Klassen-Methode verwendet"
 
-#: config/i386/i386.c:6805
+#: config/i386/i386.c:6808
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "Aufruf von %qD mit Attribut sseregparam, ohne dass SSE/SSE2 eingeschaltet ist"
 
-#: config/i386/i386.c:6808
+#: config/i386/i386.c:6811
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "Aufruf von %qT mit Attribut sseregparam, ohne dass SSE/SSE2 eingeschaltet ist"
 
-#: config/i386/i386.c:7126
+#: config/i386/i386.c:7129
 #, gcc-internal-format
 msgid "X32 does not support ms_abi attribute"
 msgstr "X32 unterstützt »ms_abi«-Attribut nicht"
 
-#: config/i386/i386.c:7160
+#: config/i386/i386.c:7163
 #, gcc-internal-format
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr "ms_hook_prologue ist mit geschachtelter Funktion nicht verträglich"
 
-#: config/i386/i386.c:7502
+#: config/i386/i386.c:7505
 #, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr "AVX512F-Vektorargument ohne eingeschaltetes AVX512F ändert das ABI"
 
-#: config/i386/i386.c:7508
+#: config/i386/i386.c:7511
 #, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr "AVX512F-Vektorrückgabe ohne eingeschaltetes AVX512F ändert das ABI"
 
-#: config/i386/i386.c:7522
+#: config/i386/i386.c:7525
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr "AVX-Vektorargument ohne eingeschaltetes AVX ändert das ABI"
 
-#: config/i386/i386.c:7528
+#: config/i386/i386.c:7531
 #, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr "AVX-Vektorrückgabe ohne eingeschaltetes AVX ändert das ABI"
 
-#: config/i386/i386.c:7544
+#: config/i386/i386.c:7547
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr "SSE-Vektorargument ohne eingeschaltetes SSE ändert das ABI"
 
-#: config/i386/i386.c:7550
+#: config/i386/i386.c:7553
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr "SSE-Vektorrückgabe ohne eingeschaltetes SSE ändert das ABI"
 
-#: config/i386/i386.c:7566
+#: config/i386/i386.c:7569
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr "MMX-Vektorargument ohne eingeschaltetes MMX ändert das ABI"
 
-#: config/i386/i386.c:7572
+#: config/i386/i386.c:7575
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr "MMX-Vektorrückgabe ohne eingeschaltetes MMX ändert das ABI"
 
-#: config/i386/i386.c:7754
+#: config/i386/i386.c:7757
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr "Das ABI der Struct-Übergabe mit einem flexiblen Arrayelement hat sich in GCC 4.4 geändert"
 
-#: config/i386/i386.c:7871
+#: config/i386/i386.c:7874
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr "Das ABI der Union-Übergabe mit »long double« hat sich in GCC 4.4 geändert"
 
-#: config/i386/i386.c:7989
+#: config/i386/i386.c:7992
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr "Das ABI der Strukturübergabe mit komplexem Gleitkommaelement hat sich in GCC 4.4 geändert"
 
-#: config/i386/i386.c:8152
+#: config/i386/i386.c:8155
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr "SSE-Registerrückgabe mit SSE ausgeschaltet"
 
-#: config/i386/i386.c:8158
+#: config/i386/i386.c:8161
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr "SSE-Registerargument mit SSE ausgeschaltet"
 
-#: config/i386/i386.c:8174
+#: config/i386/i386.c:8177
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr "x87-Registerrückgabe mit ausgeschaltetem x87"
 
-#: config/i386/i386.c:8471 config/i386/i386.c:8750 config/i386/i386.c:9276
+#: config/i386/i386.c:8474 config/i386/i386.c:8753 config/i386/i386.c:9279
 #, gcc-internal-format
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr "Aufruf von %qD mit SSE-Aufrufkonvention, ohne dass SSE/SSE2 eingeschaltet ist"
 
-#: config/i386/i386.c:8473 config/i386/i386.c:8752 config/i386/i386.c:9278
+#: config/i386/i386.c:8476 config/i386/i386.c:8755 config/i386/i386.c:9281
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr "dies ist ein GCC-Bug; ein Workaround ist, die aufgerufene Funktion mit dem »used«-Attribut zu markieren"
 
-#: config/i386/i386.c:9178
+#: config/i386/i386.c:9181
 #, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr "Das ABI der Parameterübergabe mit %d-Byte-Ausrichtung hat sich in GCC 4.6 geändert"
 
-#: config/i386/i386.c:11601
+#: config/i386/i386.c:11604
 #, gcc-internal-format, gfc-internal-format
 msgid "-mcall-ms2sysv-xlogues is not compatible with %s"
 msgstr "-mcall-ms2sysv-xlogues ist nicht kompatibel mit %s"
 
-#: config/i386/i386.c:13593
+#: config/i386/i386.c:13596
 #, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr "Attribut ms_hook_prologue ist mit -mfentry für 32 Bit nicht verträglich"
 
-#: config/i386/i386.c:13683
+#: config/i386/i386.c:13686
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr "Dynamic Realign Argument Pointer (DRAP) wird in Interrupt-Service-Routinen nicht unterstützt. Ein Workaround ist, Funktionen mit Aggregat-Rückgabetypen zu vermeiden."
 
-#: config/i386/i386.c:14970
+#: config/i386/i386.c:14973
 #, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr "-fsplit-stack unterstützt nicht fastcall mit geschachtelter Funktion"
 
-#: config/i386/i386.c:14990
+#: config/i386/i386.c:14993
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
 msgstr "-fsplit-stack unterstützt nicht 2 Registerparameter für eine geschachtelte Funktion"
@@ -29363,311 +29404,311 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:15001
+#: config/i386/i386.c:15004
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr "-fsplit-stack unterstützt nicht 3 Registerparameter"
 
-#: config/i386/i386.c:17939
+#: config/i386/i386.c:17942
 #, gcc-internal-format
 msgid "'V' modifier on non-integer register"
 msgstr "V-Modifikator an nicht-ganzzahligem Register"
 
-#: config/i386/i386.c:17950 config/i386/i386.c:17964
+#: config/i386/i386.c:17953 config/i386/i386.c:17967
 #, gcc-internal-format
 msgid "unsupported size for integer register"
 msgstr "nicht unterstützte Größe für Ganzzahlregister"
 
-#: config/i386/i386.c:17996
+#: config/i386/i386.c:17999
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr "erweiterte Register haben keine oberen Hälften"
 
-#: config/i386/i386.c:18011
+#: config/i386/i386.c:18014
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr "nicht unterstützte Operandengröße für erweitertes Register"
 
-#: config/i386/i386.c:18202
+#: config/i386/i386.c:18205
 #, gcc-internal-format
 msgid "non-integer operand used with operand code 'z'"
 msgstr "Nicht-Ganzzahl-Operand mit Operandencode »z« verwendet"
 
-#: config/i386/i386.c:28467
+#: config/i386/i386.c:28470
 #, gcc-internal-format
 msgid "interrupt service routine can't be called directly"
 msgstr "Interrupt-Dienst-Routinen können nicht direkt aufgerufen werden"
 
-#: config/i386/i386.c:29995
+#: config/i386/i386.c:29998
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in -fabi-version=12 (GCC 8)"
 msgstr "das ABI zum Übergeben von leeren Klassen (%qT) als Parametern ändert sich mit -fabi-version=12 (GCC 8)"
 
-#: config/i386/i386.c:32435
+#: config/i386/i386.c:32438
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr "Kein Dispatcher für versionierte Attribute gefunden"
 
-#: config/i386/i386.c:32485
+#: config/i386/i386.c:32488
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for %s"
 msgstr "Kein Dispatcher für %s gefunden"
 
-#: config/i386/i386.c:32495
+#: config/i386/i386.c:32498
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr "Kein Dispatcher für versionierte Attribute gefunden: %s"
 
-#: config/i386/i386.c:32657
+#: config/i386/i386.c:32660
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr "Funktionsversionen können nicht als gnu_inline markiert werden, Körper müssen generiert werden"
 
-#: config/i386/i386.c:32662 config/i386/i386.c:32938
-#: config/rs6000/rs6000.c:37850
+#: config/i386/i386.c:32665 config/i386/i386.c:32941
+#: config/rs6000/rs6000.c:37906
 #, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "Multiversionierung virtueller Funktionen wird nicht unterstützt"
 
-#: config/i386/i386.c:32795 config/rs6000/rs6000.c:37607
+#: config/i386/i386.c:32798 config/rs6000/rs6000.c:37663
 #, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "Multiversionierung erfordert »ifunc«, was in dieser Konfiguration nicht unterstützt wird"
 
-#: config/i386/i386.c:33207
+#: config/i386/i386.c:33210
 #, gcc-internal-format
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr "Parameter für eingebaute Funktion muss Zeichenkettenkonstante oder Literal sein"
 
-#: config/i386/i386.c:33232 config/i386/i386.c:33282
+#: config/i386/i386.c:33235 config/i386/i386.c:33285
 #, gcc-internal-format, gfc-internal-format
 msgid "Parameter to builtin not valid: %s"
 msgstr "Parameter für eingebaute Funktion ist ungültig: %s"
 
-#: config/i386/i386.c:33975 config/i386/i386.c:35415
+#: config/i386/i386.c:33978 config/i386/i386.c:35418
 #, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "Das letzte Argument muss ein 2-Bit-Immediate sein"
 
-#: config/i386/i386.c:34370
+#: config/i386/i386.c:34373
 #, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "fünftes Argument muss ein 8-Bit-Immediate sein"
 
-#: config/i386/i386.c:34465
+#: config/i386/i386.c:34468
 #, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "drittes Argument muss ein 8-Bit-Immediate sein"
 
-#: config/i386/i386.c:35346
+#: config/i386/i386.c:35349
 #, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "Das letzte Argument muss ein 1-Bit-Immediate sein"
 
-#: config/i386/i386.c:35361
+#: config/i386/i386.c:35364
 #, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "das letzte Argument muss ein 3-Bit-Immediate sein"
 
-#: config/i386/i386.c:35394
+#: config/i386/i386.c:35397
 #, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "Das letzte Argument muss ein 4-Bit-Immediate sein"
 
-#: config/i386/i386.c:35434
+#: config/i386/i386.c:35437
 #, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "Das letzte Argument muss ein 1-Bit-Immediate sein"
 
-#: config/i386/i386.c:35447
+#: config/i386/i386.c:35450
 #, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "Das letzte Argument muss ein 5-Bit-Immediate sein"
 
-#: config/i386/i386.c:35457
+#: config/i386/i386.c:35460
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "Das vorletzte Argument muss ein 8-Bit-Immediate sein"
 
-#: config/i386/i386.c:35462 config/i386/i386.c:36249
+#: config/i386/i386.c:35465 config/i386/i386.c:36252
 #, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "Das letzte Argument muss ein 8-Bit-Immediate sein"
 
-#: config/i386/i386.c:35596
+#: config/i386/i386.c:35599
 #, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr "das dritte Argument muss eine Vergleichskonstante sein"
 
-#: config/i386/i386.c:35601
+#: config/i386/i386.c:35604
 #, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr "Falscher Vergleichsmodus"
 
-#: config/i386/i386.c:35607 config/i386/i386.c:35814
+#: config/i386/i386.c:35610 config/i386/i386.c:35817
 #, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr "Falscher Rundungsoperand"
 
-#: config/i386/i386.c:35796
+#: config/i386/i386.c:35799
 #, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "Der direkte Argument muss ein 4-Bit-Immediate sein"
 
-#: config/i386/i386.c:35802
+#: config/i386/i386.c:35805
 #, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "Das direkte Argument muss ein 5-Bit-Immediate sein"
 
-#: config/i386/i386.c:35805
+#: config/i386/i386.c:35808
 #, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "Das direkte Argument muss ein 8-Bit-Immediate sein"
 
-#: config/i386/i386.c:36247
+#: config/i386/i386.c:36250
 #, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "Das letzte Argument muss ein 32-Bit-Immediate sein"
 
-#: config/i386/i386.c:36329 config/powerpcspe/powerpcspe.c:16219
-#: config/rs6000/rs6000.c:15304
+#: config/i386/i386.c:36332 config/powerpcspe/powerpcspe.c:16219
+#: config/rs6000/rs6000.c:15348
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr "Selektor eine Ganzzahlkonstante im Bereich 0..%wi sein"
 
-#: config/i386/i386.c:36539
+#: config/i386/i386.c:36542
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr "%qE erfordert unbekannte ISA-Option"
 
-#: config/i386/i386.c:36543
+#: config/i386/i386.c:36546
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "%qE erfordert ISA-Option %s"
 
-#: config/i386/i386.c:37381
+#: config/i386/i386.c:37375
 #, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "das letzte Argument muss ein Immediate sein"
 
-#: config/i386/i386.c:38108 config/i386/i386.c:38290
+#: config/i386/i386.c:38102 config/i386/i386.c:38284
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "Das letzte muss Skalierung 1, 2, 4, 8 sein"
 
-#: config/i386/i386.c:38343
+#: config/i386/i386.c:38337
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "Das vierte Argument muss Skalierung 1, 2, 4, 8 sein"
 
-#: config/i386/i386.c:38349
+#: config/i386/i386.c:38343
 #, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr "Falscher Hinweis-Operand"
 
-#: config/i386/i386.c:38368
+#: config/i386/i386.c:38362
 #, gcc-internal-format
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr "Das Argument für xabort muss ein 8-Bit-Immediate sein"
 
-#: config/i386/i386.c:41431
+#: config/i386/i386.c:41425
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "Attribut %qE nur für 32 Bit verfügbar"
 
-#: config/i386/i386.c:41452
+#: config/i386/i386.c:41446
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "Argument des Attributes %qE ist weder Null noch Eins"
 
-#: config/i386/i386.c:41485 config/i386/i386.c:41494
+#: config/i386/i386.c:41479 config/i386/i386.c:41488
 #, gcc-internal-format
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr "Attribute ms_abi und sysv_abi sind nicht verträglich"
 
-#: config/i386/i386.c:41530 config/powerpcspe/powerpcspe.c:35868
-#: config/rs6000/rs6000.c:33065
+#: config/i386/i386.c:41524 config/powerpcspe/powerpcspe.c:35868
+#: config/rs6000/rs6000.c:33121
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "%qE-inkompatibles Attribut wird ignoriert"
 
-#: config/i386/i386.c:41555 config/i386/i386.c:41577 config/ia64/ia64.c:815
+#: config/i386/i386.c:41549 config/i386/i386.c:41571 config/ia64/ia64.c:815
 #: config/s390/s390.c:1153
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "Attribut %qE erfordert eine Zeichenkettenkonstante als Argument"
 
-#: config/i386/i386.c:41565 config/i386/i386.c:41587 config/s390/s390.c:1182
+#: config/i386/i386.c:41559 config/i386/i386.c:41581 config/s390/s390.c:1182
 #, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "Argument des Attributes %qE ist nicht (keep|thunk|thunk-inline|thunk-extern)"
 
-#: config/i386/i386.c:41619
+#: config/i386/i386.c:41613
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr "in Interrupt-Service-Routinen sollte das erste Argument ein Zeiger sein"
 
-#: config/i386/i386.c:41626
+#: config/i386/i386.c:41620
 #, gcc-internal-format, gfc-internal-format
 msgid "interrupt service routine should have unsigned %sint as the second argument"
 msgstr "in Interrupt-Service-Routinen sollte das zweite Argument vom Typ »unsigned %sint« sein"
 
-#: config/i386/i386.c:41636
+#: config/i386/i386.c:41630
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr "Interrupt-Service-Routine darf nur ein Zeiger- und ein optionales Ganzzahl-Argument haben"
 
-#: config/i386/i386.c:41639
+#: config/i386/i386.c:41633
 #, gcc-internal-format
 msgid "interrupt service routine can't have non-void return value"
 msgstr "Interrupt-Service-Routine muss den Rückgabetyp »void« haben"
 
-#: config/i386/i386.c:44676
+#: config/i386/i386.c:44670
 #, gcc-internal-format
 msgid "alternatives not allowed in asm flag output"
 msgstr "Alternativen sind in asm-Flag-Ausgabe nicht erlaubt"
 
-#: config/i386/i386.c:44740
+#: config/i386/i386.c:44734
 #, gcc-internal-format
 msgid "unknown asm flag output %qs"
 msgstr "unbekannte Ausgabe %qs des asm-Schalters"
 
-#: config/i386/i386.c:44769
+#: config/i386/i386.c:44763
 #, gcc-internal-format
 msgid "invalid type for asm flag output"
 msgstr "ungültiger Typ für asm-Flag-Ausgabe"
 
-#: config/i386/i386.c:50634
+#: config/i386/i386.c:50628
 #, gcc-internal-format
 msgid "unknown architecture specific memory model"
 msgstr "Unbekanntes architekturspezifisches Speichermodell"
 
-#: config/i386/i386.c:50641
+#: config/i386/i386.c:50635
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr "HLE_ACQUIRE nicht mit ACQUIRE oder stärkerem Speichermodell verwendet"
 
-#: config/i386/i386.c:50647
+#: config/i386/i386.c:50641
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr "HLE_RELEASE nicht mit RELEASE oder stärkerem Speichermodell verwendet"
 
-#: config/i386/i386.c:50671 config/i386/i386.c:50787
+#: config/i386/i386.c:50665 config/i386/i386.c:50781
 #, gcc-internal-format, gfc-internal-format
 msgid "unsupported simdlen %d"
 msgstr "nicht unterstützte simdlen %d"
 
-#: config/i386/i386.c:50690
+#: config/i386/i386.c:50684
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd"
 msgstr "nicht unterstützter Rückgabetyp %qT für SIMD"
 
-#: config/i386/i386.c:50712
+#: config/i386/i386.c:50706
 #, gcc-internal-format
 msgid "unsupported argument type %qT for simd"
 msgstr "nicht unterstützter Argumenttyp %qT für SIMD"
 
-#: config/i386/i386.c:51033
+#: config/i386/i386.c:51027
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr "Zeigerprüfer benötigt MPX-Unterstützung auf diesem Ziel. Verwenden Sie »-mmpx«, um MPX einzuschalten."
@@ -29888,7 +29929,7 @@
 msgstr "interrupt_thread ist nur auf Fido verfügbar"
 
 #: config/m68k/m68k.c:1128 config/powerpcspe/powerpcspe.c:28512
-#: config/rs6000/rs6000.c:25791
+#: config/rs6000/rs6000.c:25868
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "Ausdruck der Stapelgrenze wird nicht unterstützt"
@@ -30467,58 +30508,58 @@
 
 #. Trampoline is not supported on reduced-set registers yet.
 #: config/nds32/nds32.c:2327 config/nds32/nds32.c:2381
-#: config/nds32/nds32.c:3127 config/nds32/nds32.c:3201
-#: config/nds32/nds32.c:3216 config/nds32/nds32.c:3222
-#: config/nds32/nds32.c:3284 config/nds32/nds32.c:3290
-#: config/nds32/nds32.c:3322
+#: config/nds32/nds32.c:3128 config/nds32/nds32.c:3202
+#: config/nds32/nds32.c:3217 config/nds32/nds32.c:3223
+#: config/nds32/nds32.c:3285 config/nds32/nds32.c:3291
+#: config/nds32/nds32.c:3323
 #, gcc-internal-format
 msgid "a nested function is not supported for reduced registers"
 msgstr "geschachtelte Funktionen werden bei reduzierter Registeranzahl nicht unterstützt"
 
 #. The enum index value for array size is out of range.
-#: config/nds32/nds32.c:3025
+#: config/nds32/nds32.c:3026
 #, gcc-internal-format
 msgid "intrinsic register index is out of range"
 msgstr "intrinsischer Registerindex ist außerhalb des gültigen Bereichs"
 
-#: config/nds32/nds32.c:3041 config/nds32/nds32.c:3048
-#: config/nds32/nds32.c:3055 config/nds32/nds32.c:3062
-#: config/nds32/nds32.c:3069
+#: config/nds32/nds32.c:3042 config/nds32/nds32.c:3049
+#: config/nds32/nds32.c:3056 config/nds32/nds32.c:3063
+#: config/nds32/nds32.c:3070
 #, gcc-internal-format
 msgid "CCTL intrinsic function subtype out of range!"
 msgstr "Untertyp der intrinsischen CCTL-Funktion ist außerhalb des gültigen Bereichs"
 
-#: config/nds32/nds32.c:3508
+#: config/nds32/nds32.c:3509
 #, gcc-internal-format
 msgid "invalid id value for interrupt/exception attribute"
 msgstr "ungültiger ID-Wert für Interrupt-/Exception-Attribut"
 
-#: config/nds32/nds32.c:3536
+#: config/nds32/nds32.c:3537
 #, gcc-internal-format
 msgid "invalid id value for reset attribute"
 msgstr "ungültiger ID-Wert für »reset«-Attribut"
 
-#: config/nds32/nds32.c:3552
+#: config/nds32/nds32.c:3553
 #, gcc-internal-format
 msgid "invalid nmi function for reset attribute"
 msgstr "ungültige NMI-Funktion für »reset«-Attribut"
 
-#: config/nds32/nds32.c:3565
+#: config/nds32/nds32.c:3566
 #, gcc-internal-format
 msgid "invalid warm function for reset attribute"
 msgstr "ungültige »warm«-Funktion für »reset«-Attribut"
 
-#: config/nds32/nds32.c:3638
+#: config/nds32/nds32.c:3639
 #, gcc-internal-format
 msgid "Disable FPU ISA, the ABI option must be enable '-mfloat-abi=soft'"
 msgstr "FPU-ISA ausschalten, die ABI-Option muss mit »-mfloat-abi=soft« eingeschaltet werden"
 
-#: config/nds32/nds32.c:3641
+#: config/nds32/nds32.c:3642
 #, gcc-internal-format
 msgid "'-mabi=2fp+' option only support when FPU available, must be enable '-mext-fpu-sp' or '-mext-fpu-dp'"
 msgstr "die Option »-mabi=2fp+« wird nur unterstützt, wenn eine FPU verfügbar ist, das kann durch die Optionen »-mext-fpu-sp« oder »-mext-fpu-dp« eingeschaltet werden"
 
-#: config/nds32/nds32.c:3647
+#: config/nds32/nds32.c:3648
 #, gcc-internal-format
 msgid "position-independent code not supported"
 msgstr "lageunabhängiger Code nicht unterstützt"
@@ -30852,12 +30893,12 @@
 msgid "junk at end of #pragma longcall"
 msgstr "Ausschuss am Ende von #pragma longcall"
 
-#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6154
+#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6152
 #, gcc-internal-format
 msgid "vec_lvsl is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr "vec_lvsl ist für Little-Endian veraltet; verwenden Sie Zuweisungen für unausgerichtete Speicherzugriffe"
 
-#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6158
+#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6156
 #, gcc-internal-format
 msgid "vec_lvsr is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr "vec_lvsr ist für Little-Endian veraltet; verwenden Sie Zuweisungen für unausgerichtete Speicherzugriffe"
@@ -30907,7 +30948,7 @@
 msgid "vec_insert only accepts 3 arguments"
 msgstr "vec_insert akzeptiert nur 3 Argumente"
 
-#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6868
+#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6866
 #, gcc-internal-format
 msgid "passing arg %d of %qE discards qualifiers from pointer target type"
 msgstr "Übergabe des Arguments %d von %qE entfernt Kennzeichner von Zeiger-Ziel-Typ"
@@ -30992,7 +31033,7 @@
 msgid "target attribute or pragma changes SPE ABI"
 msgstr "Ziel-Attribut oder Pragma ändert SPE ABI"
 
-#: config/powerpcspe/powerpcspe.c:4351 config/rs6000/rs6000.c:4223
+#: config/powerpcspe/powerpcspe.c:4351 config/rs6000/rs6000.c:4243
 #, gcc-internal-format
 msgid "AltiVec not supported in this target"
 msgstr "AltiVec wird für dieses Ziel nicht unterstützt"
@@ -31138,7 +31179,7 @@
 msgid "-mvsx-small-integer requires -mpower8-vector, -mupper-regs-di, and -mdirect-move"
 msgstr "-mvsx-small-integer erfordert -mpower8-vector, -mupper-regs-di, und -mdirect-move"
 
-#: config/powerpcspe/powerpcspe.c:4959 config/rs6000/rs6000.c:4601
+#: config/powerpcspe/powerpcspe.c:4959 config/rs6000/rs6000.c:4628
 #, gcc-internal-format
 msgid "target attribute or pragma changes long double size"
 msgstr "Ziel-Attribut oder Pragma ändert Größe von long double"
@@ -31179,22 +31220,22 @@
 msgstr "unbekannte ABI-Typ (%s) für Vektorisierungsbibliothek bei Schalter -mveclibabi="
 
 #: config/powerpcspe/powerpcspe.c:5140 config/powerpcspe/powerpcspe.c:5155
-#: config/rs6000/rs6000.c:4766 config/rs6000/rs6000.c:4781
+#: config/rs6000/rs6000.c:4791 config/rs6000/rs6000.c:4806
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr "Ziel-Attribut oder Pragma ändert AltiVec ABI"
 
-#: config/powerpcspe/powerpcspe.c:5168 config/rs6000/rs6000.c:4794
+#: config/powerpcspe/powerpcspe.c:5168 config/rs6000/rs6000.c:4819
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr "Ziel-Attribut oder Pragma ändert darwin64 ABI"
 
-#: config/powerpcspe/powerpcspe.c:5234 config/rs6000/rs6000.c:4828
+#: config/powerpcspe/powerpcspe.c:5234 config/rs6000/rs6000.c:4853
 #, gcc-internal-format
 msgid "target attribute or pragma changes single precision floating point"
 msgstr "Ziel-Attribut oder Pragma ändert Gleitkomma mit einfacher Genauigkeit"
 
-#: config/powerpcspe/powerpcspe.c:5237 config/rs6000/rs6000.c:4831
+#: config/powerpcspe/powerpcspe.c:5237 config/rs6000/rs6000.c:4856
 #, gcc-internal-format
 msgid "target attribute or pragma changes double precision floating point"
 msgstr "Ziel-Attribut oder Pragma ändert Gleitkomma mit doppelter Genauigkeit"
@@ -31204,12 +31245,12 @@
 msgid "-mstack-protector-guard=tls needs a valid base register"
 msgstr "-mstack-protector-guard=tls erfordert ein gültiges Basisregister"
 
-#: config/powerpcspe/powerpcspe.c:8415 config/rs6000/rs6000.c:7925
+#: config/powerpcspe/powerpcspe.c:8415 config/rs6000/rs6000.c:7950
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr "das Layout von Aggregaten, die Vektoren mit %d-Byte-Ausrichtung enthalten, hat sich in GCC 5 geändert"
 
-#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11237
+#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11269
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC-Vektor per Referenz zurückgegeben: Nicht-Standard-ABI-Erweiterung ohne Kompatibilitätsgarantie"
@@ -31219,7 +31260,7 @@
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "Wert kann nicht in Vektorregister zurückgegeben werden, da AltiVec-Befehle ausgeschaltet sind; -maltivec schaltet sie ein"
 
-#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11595
+#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11633
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr "das ABI der Parameterübergabe für Aggregate mit %d-Byte-Ausrichtung hat sich in GCC 5 geändert"
@@ -31229,12 +31270,12 @@
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "Argument kann nicht in Vektorregister übergegeben werden, da AltiVec-Befehle ausgeschaltet sind; -maltivec schaltet sie ein"
 
-#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12604
+#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12648
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr "das ABI für die Übergabe von homogenen float-Aggregaten hat sich in GCC 5 geändert"
 
-#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12779
+#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12823
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC-Vektor per Referenz übergegeben: Nicht-Standard-ABI-Erweiterung ohne Kompatibilitätsgarantie"
@@ -31244,28 +31285,28 @@
 msgid "internal error: builtin function %s already processed"
 msgstr "internal error: builtin function %s already processed"
 
-#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:13971
+#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:14015
 #, gcc-internal-format
 msgid "argument 1 must be an 8-bit field value"
 msgstr "Argument 1 muss ein 8-Bit-Feldwert sein"
 
-#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14015
+#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14059
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "Argument 1 muss ein vorzeichenbehaftetes 5-Bit-Symbol sein"
 
 #: config/powerpcspe/powerpcspe.c:14934 config/powerpcspe/powerpcspe.c:16803
-#: config/rs6000/rs6000.c:14101
+#: config/rs6000/rs6000.c:14145
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "Argument 2 muss ein vorzeichenloses 5-Bit-Symbol sein"
 
-#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14119
+#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14163
 #, gcc-internal-format
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "Argument 1 muss ein vorzeichenloses 6-Bit-Literal sein"
 
-#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14135
+#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14179
 #, gcc-internal-format
 msgid "argument 2 must be a 7-bit unsigned literal"
 msgstr "Argument 2 muss ein vorzeichenloses 7-Bit-Literal sein"
@@ -31285,12 +31326,12 @@
 msgid "builtin %s is only valid in 64-bit mode"
 msgstr "Eingebaute Funktion %s kann nur im 64-Bit-Modus verwendet werden"
 
-#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14791
+#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14835
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %d must be an unsigned literal"
 msgstr "Argument %d muss ein vorzeichenloses Literal sein"
 
-#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14793
+#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14837
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "Argument %d ist ein vorzeichenloses Literal, aber außerhalb des gültigen Bereichs"
@@ -31312,53 +31353,53 @@
 msgid "hwcap %s is an invalid argument to builtin %s"
 msgstr "hwcap %s ist ein ungültiges Argument für eingebaute Funktion %s"
 
-#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15065
+#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15109
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "Argument 3 muss ein vorzeichenloses 4-Bit-Symbol sein"
 
-#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15090
+#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15134
 #, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "Argument 3 muss ein vorzeichenloses 2-Bit-Symbol sein"
 
-#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15110
+#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15154
 #, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "Argument 3 muss ein vorzeichenloses 1-Bit-Symbol sein"
 
-#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15122
+#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15166
 #, gcc-internal-format
 msgid "argument 1 must be 0 or 2"
 msgstr "Argument 1 muss 0 oder 2 sein"
 
-#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15134
+#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15178
 #, gcc-internal-format
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "Argument 1 muss ein vorzeichenloses 1-Bit-Literal sein"
 
-#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15148
+#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15192
 #, gcc-internal-format
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "Argument 2 muss ein vorzeichenloses 6-Bit-Literal sein"
 
-#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15160
+#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15204
 #, gcc-internal-format
 msgid "argument 2 must be 0 or 1"
 msgstr "Argument 2 muss 0 oder 1 sein"
 
-#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15168
+#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15212
 #, gcc-internal-format
 msgid "argument 3 must be in the range 0..15"
 msgstr "Argument 3 muss im Bereich 0..15 liegen"
 
-#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15237
-#: config/rs6000/rs6000.c:15569
+#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15281
+#: config/rs6000/rs6000.c:15613
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "Argument für %qs muss ein vorzeichenloses 2-Bit-Symbol sein"
 
-#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15394
+#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15438
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr "ungelöste Überladung des eingebauten Altivec %qF"
@@ -31483,7 +31524,7 @@
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr "internal error: builtin function %s, argument %d had unexpected argument type %s"
 
-#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25758
+#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25835
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr "Stapelrahmen zu groß"
@@ -31493,12 +31534,12 @@
 msgid "-fsplit-stack uses register r29"
 msgstr "-fsplit-stack verwendet Register r29"
 
-#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29459
+#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29536
 #, gcc-internal-format
 msgid "Stack frame larger than 2G is not supported for -fsplit-stack"
 msgstr "Stapelrahmen größer als 2G wird für -fsplit-stack nicht unterstützt"
 
-#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30447
+#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30524
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "kein Profiling von 64-bit-Code für dieses ABI"
@@ -31508,22 +31549,22 @@
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr "Bei Verwendung der Option -mno-pointers-to-nested-functions kann nicht die Adresse einer geschachtelten Funktion verwendet werden."
 
-#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32830
+#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32907
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "Verwendung von %<long double%> in AltiVec-Typen ist ungültig"
 
-#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32832
+#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32909
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "Verwendung boolescher Typen in AltiVec-Typen ist ungültig"
 
-#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32834
+#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32911
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "Verwendung von %<complex%> in AltiVec-Typen ist ungültig"
 
-#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32836
+#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32913
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr "Verwendung dezimaler Gleitkommatypen in AltiVec-Typen ist ungültig"
@@ -31533,7 +31574,7 @@
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr "Verwendung von %<long%> in AltiVec-Typen ist für 64-Bit-Code ohne -mvsx ungültig"
 
-#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32845
+#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32922
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "Verwendung von %<long%> in AltiVec-Typen ist veraltet; %<int%> verwenden"
@@ -32077,71 +32118,71 @@
 "Der Kernel hat einen nicht unterstützten CPU-Namen zurückgegeben: %s\n"
 "Bitte geben Sie den CPU-Namen explizit an. Gültige CPU-Namen sind: %s"
 
-#: config/rs6000/rs6000-c.c:6168 config/rs6000/rs6000-c.c:6219
-#: config/rs6000/rs6000-c.c:6489 config/rs6000/rs6000-c.c:6555
-#: config/rs6000/rs6000-c.c:6916 config/rs6000/rs6000-c.c:6963
+#: config/rs6000/rs6000-c.c:6166 config/rs6000/rs6000-c.c:6217
+#: config/rs6000/rs6000-c.c:6487 config/rs6000/rs6000-c.c:6553
+#: config/rs6000/rs6000-c.c:6914 config/rs6000/rs6000-c.c:6961
 #, gcc-internal-format
 msgid "builtin %qs only accepts 2 arguments"
 msgstr "Eingebaute Funktion %qs akzeptiert genau 2 Argumente"
 
-#: config/rs6000/rs6000-c.c:6292 config/rs6000/rs6000-c.c:6375
-#: config/rs6000/rs6000-c.c:6736
+#: config/rs6000/rs6000-c.c:6290 config/rs6000/rs6000-c.c:6373
+#: config/rs6000/rs6000-c.c:6734
 #, gcc-internal-format
 msgid "builtin %qs only accepts 3 arguments"
 msgstr "Eingebaute Funktion %qs akzeptiert genau 3 Argumente"
 
-#: config/rs6000/rs6000-c.c:6484
+#: config/rs6000/rs6000-c.c:6482
 #, gcc-internal-format
 msgid "builtin %qs only accepts 1 argument"
 msgstr "Eingebaute Funktion %qs akzeptiert genau 1 Argument"
 
-#: config/rs6000/rs6000-c.c:7054
+#: config/rs6000/rs6000-c.c:7052
 #, gcc-internal-format
 msgid "builtin %qs requires builtin %qs"
 msgstr "eingebaute Funktion %qs erfordert eingebaute Funktion %qs"
 
-#: config/rs6000/rs6000-c.c:7058
+#: config/rs6000/rs6000-c.c:7056
 #, gcc-internal-format
 msgid "builtin function %qs not supported in this compiler configuration"
 msgstr "Eingebaute Funktion %qs wird in dieser Compiler-Konfiguration nicht unterstützt"
 
-#: config/rs6000/rs6000-c.c:7068
+#: config/rs6000/rs6000-c.c:7066
 #, gcc-internal-format
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr "ungültige Parameterkombination für AltiVec-spezifisches intrinsisches %qs"
 
-#: config/rs6000/rs6000.c:3754 config/rs6000/rs6000.c:3757
-#: config/rs6000/rs6000.c:3760
+#: config/rs6000/rs6000.c:3772 config/rs6000/rs6000.c:3775
+#: config/rs6000/rs6000.c:3778
 #, gcc-internal-format
 msgid "%qs requires %qs or %qs"
 msgstr "%qs erfordert %qs oder %qs"
 
-#: config/rs6000/rs6000.c:3861
+#: config/rs6000/rs6000.c:3879
 #, gcc-internal-format
 msgid "%qs requires PowerPC64 architecture, enabling"
 msgstr "%qs erfordert PowerPC64-Architektur, wird eingeschaltet"
 
-#: config/rs6000/rs6000.c:4037
+#: config/rs6000/rs6000.c:4057
 #, gcc-internal-format
 msgid "%qs command-line option is deprecated"
 msgstr "Kommandozeilenoption %qs ist veraltet"
 
-#: config/rs6000/rs6000.c:4048
+#: config/rs6000/rs6000.c:4068
 #, gcc-internal-format
 msgid "%qs is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr "%qs wird für 64-Bit-Darwin nicht unterstützt; es ist mit den installierten C- und C++-Bibliotheken unverträglich"
 
-#: config/rs6000/rs6000.c:4147
+#: config/rs6000/rs6000.c:4167
 #, gcc-internal-format
 msgid "will not generate %qs instructions because assembler lacks %qs support"
 msgstr "%qs-Befehle werden nicht erzeugt, da der Assembler %qs nicht unterstützt"
 
-#: config/rs6000/rs6000.c:4240
+#: config/rs6000/rs6000.c:4260
 #, gcc-internal-format
 msgid "%qs is not supported on little endian systems"
 msgstr "%qs wird auf »little endian«-Systemen nicht unterstützt"
 
-#: config/rs6000/rs6000.c:4333
+#: config/rs6000/rs6000.c:4353
 #, gcc-internal-format
 msgid "power9 target option is incompatible with %<%s=<xxx>%> for <xxx> less than power9"
 msgstr "power9-Zieloption ist mit %<%s=<xxx>%> für <xxx> kleiner als power9 inkompatibel"
@@ -32148,7 +32189,7 @@
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:4341
+#: config/rs6000/rs6000.c:4361
 #, gcc-internal-format
 msgid "%qs incompatible with explicitly disabled options"
 msgstr "%qs inkompatibel mit explizit ausgeschalteten Optionen"
@@ -32157,240 +32198,241 @@
 #. error messages.  However, if users have managed to select
 #. power9-fusion without selecting power8-fusion, they
 #. already know about undocumented flags.
-#: config/rs6000/rs6000.c:4366 config/rs6000/rs6000.c:4373
-#: config/rs6000/rs6000.c:4380 config/rs6000/rs6000.c:4388
-#: config/rs6000/rs6000.c:4407 config/rs6000/rs6000.c:4464
-#: config/rs6000/rs6000.c:4468 config/rs6000/rs6000.c:4485
-#: config/rs6000/rs6000.c:4538 config/rs6000/rs6000.c:4565
-#: config/rs6000/rs6000.c:4580 config/rs6000/rs6000.c:4588
-#: config/rs6000/rs6000.c:4684
+#: config/rs6000/rs6000.c:4386 config/rs6000/rs6000.c:4393
+#: config/rs6000/rs6000.c:4400 config/rs6000/rs6000.c:4408
+#: config/rs6000/rs6000.c:4427 config/rs6000/rs6000.c:4484
+#: config/rs6000/rs6000.c:4488 config/rs6000/rs6000.c:4505
+#: config/rs6000/rs6000.c:4558 config/rs6000/rs6000.c:4585
+#: config/rs6000/rs6000.c:4600 config/rs6000/rs6000.c:4608
+#: config/rs6000/rs6000.c:4709
 #, gcc-internal-format
 msgid "%qs requires %qs"
 msgstr "%qs erfordert %qs"
 
-#: config/rs6000/rs6000.c:4625
+#: config/rs6000/rs6000.c:4650
 #, gcc-internal-format
 msgid "Using IEEE extended precision long double"
 msgstr "IEEE long double mit erweiterter Genauigkeit wird verwendet"
 
-#: config/rs6000/rs6000.c:4627
+#: config/rs6000/rs6000.c:4652
 #, gcc-internal-format
 msgid "Using IBM extended precision long double"
 msgstr "IBM long double mit erweiterter Genauigkeit wird verwendet"
 
-#: config/rs6000/rs6000.c:4644
+#: config/rs6000/rs6000.c:4669
 #, gcc-internal-format
 msgid "%qs requires VSX support"
 msgstr "%qs erfordert VSX-Unterstützung"
 
-#: config/rs6000/rs6000.c:4653
+#: config/rs6000/rs6000.c:4678
 #, gcc-internal-format
 msgid "The -mfloat128 option may not be fully supported"
 msgstr "Die Option -mfloat128 wird möglicherweise nicht vollständig unterstützt"
 
-#: config/rs6000/rs6000.c:4676
+#: config/rs6000/rs6000.c:4701
 #, gcc-internal-format
 msgid "%qs requires full ISA 3.0 support"
 msgstr "%qs erfordert vollständige Unterstützung von ISA 3.0"
 
-#: config/rs6000/rs6000.c:4743
+#: config/rs6000/rs6000.c:4768
 #, gcc-internal-format
 msgid "unknown vectorization library ABI type (%qs) for %qs switch"
 msgstr "unbekannter ABI-Typ (%qs) für Vektorisierungsbibliothek für Schalter %qs"
 
-#: config/rs6000/rs6000.c:4930
+#: config/rs6000/rs6000.c:4955
 #, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr "%qs ist in %qs keine gültige Zahl"
 
-#: config/rs6000/rs6000.c:4935
+#: config/rs6000/rs6000.c:4960
 #, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr "%qs ist in %qs kein gültiger Offset"
 
-#: config/rs6000/rs6000.c:4947
+#: config/rs6000/rs6000.c:4972
 #, gcc-internal-format
 msgid "%qs is not a valid base register in %qs"
 msgstr "%qs ist in %qs kein gültiges Basisregister"
 
-#: config/rs6000/rs6000.c:4955
+#: config/rs6000/rs6000.c:4980
 #, gcc-internal-format
 msgid "%qs needs a valid base register"
 msgstr "%qs erfordert ein gültiges Basisregister"
 
-#: config/rs6000/rs6000.c:5253
+#: config/rs6000/rs6000.c:5278
 #, gcc-internal-format
 msgid "unknown option for %<%s=%s%>"
 msgstr "unbekannte Option für %<%s=%s%>"
 
-#: config/rs6000/rs6000.c:5290
+#: config/rs6000/rs6000.c:5315
 #, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr "%qs ist veraltet und wird unter keinen Umständen empfohlen"
 
-#: config/rs6000/rs6000.c:11401
+#: config/rs6000/rs6000.c:11439
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr "Wert kann nicht in Vektorregister zurückgegeben werden, da AltiVec-Befehle ausgeschaltet sind; %qs schaltet sie ein"
 
-#: config/rs6000/rs6000.c:11862
+#: config/rs6000/rs6000.c:11906
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr "Argument kann nicht in Vektorregister übergegeben werden, da AltiVec-Befehle ausgeschaltet sind; %qs schaltet sie ein"
 
-#: config/rs6000/rs6000.c:13572
+#: config/rs6000/rs6000.c:13616
 #, gcc-internal-format
 msgid "internal error: builtin function %qs already processed"
 msgstr "internal error: builtin function %qs already processed"
 
-#: config/rs6000/rs6000.c:14150
+#: config/rs6000/rs6000.c:14194
 #, gcc-internal-format
 msgid "argument 2 must be a 1-bit unsigned literal"
 msgstr "Argument 2 muss ein vorzeichenloses 1-Bit-Literal sein"
 
-#: config/rs6000/rs6000.c:14189
+#: config/rs6000/rs6000.c:14233
 #, gcc-internal-format
 msgid "argument 1 of %qs must be a constant"
 msgstr "Argument 1 von %qs muss eine Konstante sein"
 
-#: config/rs6000/rs6000.c:14247 config/rs6000/rs6000.c:15898
+#: config/rs6000/rs6000.c:14291 config/rs6000/rs6000.c:15942
 #, gcc-internal-format
 msgid "argument 1 of %qs is out of range"
 msgstr "Argument 1 von %qs ist außerhalb des Wertebereiches"
 
-#: config/rs6000/rs6000.c:14742
+#: config/rs6000/rs6000.c:14786
 #, gcc-internal-format
 msgid "builtin %qs is only valid in 64-bit mode"
 msgstr "eingebaute Funktion %qs kann nur im 64-Bit-Modus verwendet werden"
 
-#: config/rs6000/rs6000.c:14939
+#: config/rs6000/rs6000.c:14983
 #, gcc-internal-format
 msgid "builtin %qs only accepts a string argument"
 msgstr "eingebaute Funktion %qs akzeptiert nur ein Zeichenkettenargument"
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000.c:14958
+#: config/rs6000/rs6000.c:15002
 #, gcc-internal-format
 msgid "cpu %qs is an invalid argument to builtin %qs"
 msgstr "CPU %qs ist ein ungültiges Argument für eingebaute Funktion %qs"
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000.c:14986
+#: config/rs6000/rs6000.c:15030
 #, gcc-internal-format
 msgid "%s %qs is an invalid argument to builtin %qs"
 msgstr "%s %qs ist ein ungültiges Argument für eingebaute Funktion %qs"
 
-#: config/rs6000/rs6000.c:15012
+#: config/rs6000/rs6000.c:15056
 #, gcc-internal-format
 msgid "builtin %qs needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr "eingebaute Funktion %qs erfordert GLIBC (2.23 oder neuer), die Hardware-Fähigkeits-Bits exportiert"
 
-#: config/rs6000/rs6000.c:15616
+#: config/rs6000/rs6000.c:15660
 #, gcc-internal-format
 msgid "second argument to %qs must be 0..12"
 msgstr "zweites Argument für %qs muss im Bereich 0..12 liegen"
 
-#: config/rs6000/rs6000.c:15631
+#: config/rs6000/rs6000.c:15675
 #, gcc-internal-format
 msgid "third argument to %qs must be 0..12"
 msgstr "drittes Argument für %qs muss im Bereich 0..12 liegen"
 
-#: config/rs6000/rs6000.c:15850
+#: config/rs6000/rs6000.c:15894
 #, gcc-internal-format, gfc-internal-format
 msgid "argument 1 of %s must be a constant"
 msgstr "Argument 1 von %s muss eine Konstante sein"
 
-#: config/rs6000/rs6000.c:15932
+#: config/rs6000/rs6000.c:15976
 #, gcc-internal-format
 msgid "builtin function %qs is only valid for the cell processor"
 msgstr "eingebaute Funktion %qs ist nur für den Cell-Prozessor gültig"
 
-#: config/rs6000/rs6000.c:15934 config/rs6000/rs6000.c:15936
-#: config/rs6000/rs6000.c:15938 config/rs6000/rs6000.c:15940
-#: config/rs6000/rs6000.c:15946 config/rs6000/rs6000.c:15948
-#: config/rs6000/rs6000.c:15955 config/rs6000/rs6000.c:15962
-#: config/rs6000/rs6000.c:15969 config/rs6000/rs6000.c:15975
+#: config/rs6000/rs6000.c:15978 config/rs6000/rs6000.c:15980
+#: config/rs6000/rs6000.c:15982 config/rs6000/rs6000.c:15984
+#: config/rs6000/rs6000.c:15990 config/rs6000/rs6000.c:15992
+#: config/rs6000/rs6000.c:15999 config/rs6000/rs6000.c:16006
+#: config/rs6000/rs6000.c:16011 config/rs6000/rs6000.c:16014
+#: config/rs6000/rs6000.c:16018 config/rs6000/rs6000.c:16024
 #, gcc-internal-format
 msgid "builtin function %qs requires the %qs option"
 msgstr "eingebaute Funktion %qs erfordert die Option %qs"
 
-#: config/rs6000/rs6000.c:15943 config/rs6000/rs6000.c:15952
-#: config/rs6000/rs6000.c:15959 config/rs6000/rs6000.c:15966
+#: config/rs6000/rs6000.c:15987 config/rs6000/rs6000.c:15996
+#: config/rs6000/rs6000.c:16003
 #, gcc-internal-format
 msgid "builtin function %qs requires the %qs and %qs options"
 msgstr "eingebaute Funktion %qs erfordert die Optionen %qs und %qs"
 
-#: config/rs6000/rs6000.c:15972
+#: config/rs6000/rs6000.c:16021
 #, gcc-internal-format
 msgid "builtin function %qs requires ISA 3.0 IEEE 128-bit floating point"
 msgstr "eingebaute Funktion %qs erfordert ISA 3.0 IEEE 128-Bit-Gleitkommazahlen"
 
-#: config/rs6000/rs6000.c:15978
+#: config/rs6000/rs6000.c:16027
 #, gcc-internal-format
 msgid "builtin function %qs requires the %qs (or newer), and %qs or %qs options"
 msgstr "eingebaute Funktion %qs erfordert die Optionen %qs (oder neuer), sowie %qs oder %qs"
 
-#: config/rs6000/rs6000.c:15982
+#: config/rs6000/rs6000.c:16031
 #, gcc-internal-format
 msgid "builtin function %qs is not supported with the current options"
 msgstr "eingebaute Funktion %qs wird mit den aktuellen Optionen nicht unterstützt"
 
-#: config/rs6000/rs6000.c:18218
+#: config/rs6000/rs6000.c:18290
 #, gcc-internal-format
 msgid "internal error: builtin function %qs had an unexpected return type %qs"
 msgstr "internal error: builtin function %qs had an unexpected return type %qs"
 
-#: config/rs6000/rs6000.c:18235
+#: config/rs6000/rs6000.c:18307
 #, gcc-internal-format
 msgid "internal error: builtin function %qs, argument %d had unexpected argument type %qs"
 msgstr "internal error: builtin function %qs, argument %d had unexpected argument type %qs"
 
-#: config/rs6000/rs6000.c:29451
+#: config/rs6000/rs6000.c:29528
 #, gcc-internal-format
 msgid "%qs uses register r29"
 msgstr "%qs verwendet Register r29"
 
-#: config/rs6000/rs6000.c:32748
+#: config/rs6000/rs6000.c:32825
 #, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "Bei Verwendung der Option %qs kann die Adresse von geschachtelten Funktionen nicht verwendet werden"
 
-#: config/rs6000/rs6000.c:32842
+#: config/rs6000/rs6000.c:32919
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "Verwendung von %<long%> in AltiVec-Typen ist für 64-Bit-Code ohne %qs ungültig"
 
-#: config/rs6000/rs6000.c:32850
+#: config/rs6000/rs6000.c:32927
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "Verwendung von %<long long%> in AltiVec-Typen ist ohne %qs ungültig"
 
-#: config/rs6000/rs6000.c:32853
+#: config/rs6000/rs6000.c:32930
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "Verwendung von %<double%> in AltiVec-Typen ist ohne %qs ungültig"
 
-#: config/rs6000/rs6000.c:36876
+#: config/rs6000/rs6000.c:36932
 #, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "ungültige CPU %qs für %s%qs%s"
 
-#: config/rs6000/rs6000.c:36879
+#: config/rs6000/rs6000.c:36935
 #, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr "%s%qs%s ist nicht erlaubt"
 
-#: config/rs6000/rs6000.c:36881
+#: config/rs6000/rs6000.c:36937
 #, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr "%s%qs%s ist ungültig"
 
-#: config/rs6000/rs6000.c:37416
+#: config/rs6000/rs6000.c:37472
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr "%<-mno-%s%> schaltet %<-m%s%> aus"
 
-#: config/rs6000/rs6000.c:37575
+#: config/rs6000/rs6000.c:37631
 #, gcc-internal-format
 msgid "target_clones attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr "das Attribut %<target_clones%> erfordert GLIBC (2.23 oder neuer), die Hardware-Fähigkeits-Bits exportiert"
@@ -33129,48 +33171,48 @@
 msgid "subprogram %q+F not marked Inline"
 msgstr "Unterprogramm %q+F nicht als Inline markiert"
 
-#: ada/gcc-interface/trans.c:6404
+#: ada/gcc-interface/trans.c:6401
 #, gcc-internal-format
 msgid "out-of-bounds access may be optimized away"
 msgstr "Zugriff außerhalb der Grenzen könnte wegoptimiert werden"
 
-#: ada/gcc-interface/trans.c:6406
+#: ada/gcc-interface/trans.c:6403
 #, gcc-internal-format
 msgid "containing loop"
 msgstr "enthaltene Schleife"
 
-#: ada/gcc-interface/utils.c:3887
+#: ada/gcc-interface/utils.c:3890
 #, gcc-internal-format
 msgid "invalid element type for attribute %qs"
 msgstr "ungültiger Elementtyp für Attribut %qs"
 
-#: ada/gcc-interface/utils.c:3911
+#: ada/gcc-interface/utils.c:3914
 #, gcc-internal-format
 msgid "number of components of vector not a power of two"
 msgstr "Komponentenanzahl des Vektors ist keine Zweierpotenz"
 
-#: ada/gcc-interface/utils.c:6037 ada/gcc-interface/utils.c:6215
-#: ada/gcc-interface/utils.c:6322
+#: ada/gcc-interface/utils.c:6043 ada/gcc-interface/utils.c:6220
+#: ada/gcc-interface/utils.c:6327
 #, gcc-internal-format
 msgid "%qs attribute ignored"
 msgstr "Attribut %qs wird ignoriert"
 
-#: ada/gcc-interface/utils.c:6158
+#: ada/gcc-interface/utils.c:6164
 #, gcc-internal-format
 msgid "%qs attribute requires prototypes with named arguments"
 msgstr "Attribut %qs benötigt Prototypen mit benannten Argumenten"
 
-#: ada/gcc-interface/utils.c:6167
+#: ada/gcc-interface/utils.c:6173
 #, gcc-internal-format
 msgid "%qs attribute only applies to variadic functions"
 msgstr "Attribut %qs gilt nur für variadische Funktionen"
 
-#: ada/gcc-interface/utils.c:6282
+#: ada/gcc-interface/utils.c:6287
 #, gcc-internal-format
 msgid "%qE attribute has no effect"
 msgstr "Attribut %qE hat keinen Effekt"
 
-#: ada/gcc-interface/utils.c:6406
+#: ada/gcc-interface/utils.c:6411
 #, gcc-internal-format
 msgid "attribute %qs applies to array types only"
 msgstr "Attribut %qs bezieht sich nur auf Arraytypen"
@@ -33185,7 +33227,7 @@
 #. an unprototyped function, it is compile-time undefined;
 #. making it a constraint in that case was rejected in
 #. DR#252.
-#: c/c-convert.c:101 c/c-typeck.c:2175 c/c-typeck.c:6507 c/c-typeck.c:12138
+#: c/c-convert.c:101 c/c-typeck.c:2175 c/c-typeck.c:6512 c/c-typeck.c:12143
 #: cp/typeck.c:2027 cp/typeck.c:7977 cp/typeck.c:8742
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
@@ -33246,7 +33288,7 @@
 msgid "type of array %q+D completed incompatibly with implicit initialization"
 msgstr "Typ des Arrays %q+D vervollständigt Unverträglichkeit mit impliziter Initialisierung"
 
-#: c/c-decl.c:1567 c/c-decl.c:6701 c/c-decl.c:7574 c/c-decl.c:8381
+#: c/c-decl.c:1567 c/c-decl.c:6721 c/c-decl.c:7594 c/c-decl.c:8401
 #, gcc-internal-format
 msgid "originally defined here"
 msgstr "ursprünglich hier definiert"
@@ -33651,16 +33693,11 @@
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.c:4548 c/c-decl.c:7147
+#: c/c-decl.c:4548 c/c-decl.c:7167
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr "%<[*]%> außerhalb des Bereichs des Funktionsprototypen nicht erlaubt"
 
-#: c/c-decl.c:4635 cp/decl2.c:1520
-#, gcc-internal-format
-msgid "%q+D in declare target directive does not have mappable type"
-msgstr "%q+D in »declare target«-Direktive hat keinen zuordenbaren Typ"
-
 #: c/c-decl.c:4693
 #, gcc-internal-format
 msgid "%q+D is usually a function"
@@ -33686,7 +33723,7 @@
 #. of VLAs themselves count as VLAs, it does not make
 #. sense to permit them to be initialized given that
 #. ordinary VLAs may not be initialized.
-#: c/c-decl.c:4732 c/c-decl.c:4747 c/c-typeck.c:7630
+#: c/c-decl.c:4732 c/c-decl.c:4747 c/c-typeck.c:7635
 #, gcc-internal-format
 msgid "variable-sized object may not be initialized"
 msgstr "Objekt variabler Größe darf nicht initialisiert werden"
@@ -33746,202 +33783,207 @@
 msgid "uninitialized const %qD is invalid in C++"
 msgstr "nicht initialisiertes const %qD ist in C++ ungültig"
 
-#: c/c-decl.c:5268
+#: c/c-decl.c:5224 cp/decl.c:7318
 #, gcc-internal-format
+msgid "%q+D in declare target directive does not have mappable type"
+msgstr "%q+D in »declare target«-Direktive hat keinen zuordenbaren Typ"
+
+#: c/c-decl.c:5288
+#, gcc-internal-format
 msgid "ISO C forbids forward parameter declarations"
 msgstr "ISO-C verbietet Vorwärtsdeklaration für Parameter"
 
-#: c/c-decl.c:5371
+#: c/c-decl.c:5391
 #, gcc-internal-format
 msgid "defining a type in a compound literal is invalid in C++"
 msgstr "Definition eines Typs in einem zusammengesetzten Literal ist in C++ ungültig"
 
-#: c/c-decl.c:5425 c/c-decl.c:5440
+#: c/c-decl.c:5445 c/c-decl.c:5460
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant"
 msgstr "Breite des Bitfeldes %qs ist keine Ganzzahlkonstante"
 
-#: c/c-decl.c:5435
+#: c/c-decl.c:5455
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant expression"
 msgstr "Breite des Bitfeldes %qs ist kein Ganzzahlkonstantenausdruck"
 
-#: c/c-decl.c:5446
+#: c/c-decl.c:5466
 #, gcc-internal-format
 msgid "negative width in bit-field %qs"
 msgstr "Negative Breite in Bitfeld %qs"
 
-#: c/c-decl.c:5451
+#: c/c-decl.c:5471
 #, gcc-internal-format
 msgid "zero width for bit-field %qs"
 msgstr "Breite Null für Bitfeld %qs"
 
-#: c/c-decl.c:5461
+#: c/c-decl.c:5481
 #, gcc-internal-format
 msgid "bit-field %qs has invalid type"
 msgstr "Bitfeld %qs hat ungültigen Typen"
 
-#: c/c-decl.c:5467
+#: c/c-decl.c:5487
 #, gcc-internal-format
 msgid "cannot declare bit-field %qs with %<warn_if_not_aligned%> type"
 msgstr "Bitfeld %qs kann nicht mit %<warn_if_not_aligned%>-Typ deklariert werden"
 
-#: c/c-decl.c:5478
+#: c/c-decl.c:5498
 #, gcc-internal-format
 msgid "type of bit-field %qs is a GCC extension"
 msgstr "Typ des Bitfeldes %qs ist eine Erweiterung des GCC"
 
-#: c/c-decl.c:5484
+#: c/c-decl.c:5504
 #, gcc-internal-format
 msgid "width of %qs exceeds its type"
 msgstr "Breite von %qs überschreitet dessen Typen"
 
-#: c/c-decl.c:5497
+#: c/c-decl.c:5517
 #, gcc-internal-format
 msgid "%qs is narrower than values of its type"
 msgstr "%qs ist schmaler als die Werte seines Typs"
 
-#: c/c-decl.c:5512
+#: c/c-decl.c:5532
 #, gcc-internal-format
 msgid "ISO C90 forbids array %qE whose size can%'t be evaluated"
 msgstr "ISO-C90 verbietet Array %qE, dessen Größe nicht ausgewertet werden kann"
 
-#: c/c-decl.c:5515
+#: c/c-decl.c:5535
 #, gcc-internal-format
 msgid "ISO C90 forbids array whose size can%'t be evaluated"
 msgstr "ISO-C90 verbietet Array, dessen Größe nicht ausgewertet werden kann"
 
-#: c/c-decl.c:5522
+#: c/c-decl.c:5542
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array %qE"
 msgstr "ISO-C90 verbietet Array %qE variabler Größe"
 
-#: c/c-decl.c:5524
+#: c/c-decl.c:5544
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array"
 msgstr "ISO-C90 verbietet Array variabler Größe"
 
-#: c/c-decl.c:5733 c/c-decl.c:6107 c/c-decl.c:6117
+#: c/c-decl.c:5753 c/c-decl.c:6127 c/c-decl.c:6137
 #, gcc-internal-format
 msgid "variably modified %qE at file scope"
 msgstr "variabel modifiziertes %qE im Dateibereich"
 
-#: c/c-decl.c:5735
+#: c/c-decl.c:5755
 #, gcc-internal-format
 msgid "variably modified field at file scope"
 msgstr "variabel modifiziertes Feld im Dateibereich"
 
-#: c/c-decl.c:5755
+#: c/c-decl.c:5775
 #, gcc-internal-format
 msgid "type defaults to %<int%> in declaration of %qE"
 msgstr "%<int%> ist Standardtyp in Deklaration von %qE"
 
-#: c/c-decl.c:5759
+#: c/c-decl.c:5779
 #, gcc-internal-format
 msgid "type defaults to %<int%> in type name"
 msgstr "%<int%> ist Standardtyp in Typ-Deklaration"
 
-#: c/c-decl.c:5791
+#: c/c-decl.c:5811
 #, gcc-internal-format
 msgid "duplicate %<const%>"
 msgstr "doppeltes %<const%>"
 
-#: c/c-decl.c:5793
+#: c/c-decl.c:5813
 #, gcc-internal-format
 msgid "duplicate %<restrict%>"
 msgstr "doppeltes %<restrict%>"
 
-#: c/c-decl.c:5795
+#: c/c-decl.c:5815
 #, gcc-internal-format
 msgid "duplicate %<volatile%>"
 msgstr "doppeltes %<volatile%>"
 
-#: c/c-decl.c:5797
+#: c/c-decl.c:5817
 #, gcc-internal-format
 msgid "duplicate %<_Atomic%>"
 msgstr "doppeltes %<_Atomic%>"
 
-#: c/c-decl.c:5800
+#: c/c-decl.c:5820
 #, gcc-internal-format, gfc-internal-format
 msgid "conflicting named address spaces (%s vs %s)"
 msgstr "in Konflikt stehende benannte Adressräume (%s und %s)"
 
-#: c/c-decl.c:5823 c/c-parser.c:2821
+#: c/c-decl.c:5843 c/c-parser.c:2821
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified array type"
 msgstr "%<_Atomic%>-qualifizierter Arraytyp"
 
-#: c/c-decl.c:5837
+#: c/c-decl.c:5857
 #, gcc-internal-format
 msgid "function definition declared %<auto%>"
 msgstr "Funktionsdefinition deklarierte %<auto%>"
 
-#: c/c-decl.c:5839
+#: c/c-decl.c:5859
 #, gcc-internal-format
 msgid "function definition declared %<register%>"
 msgstr "Funktionsdefinition deklarierte %<register%>"
 
-#: c/c-decl.c:5841
+#: c/c-decl.c:5861
 #, gcc-internal-format
 msgid "function definition declared %<typedef%>"
 msgstr "Funktionsdefinition deklarierte %<typedef%>"
 
-#: c/c-decl.c:5843
+#: c/c-decl.c:5863
 #, gcc-internal-format
 msgid "function definition declared %qs"
 msgstr "Funktionsdefinition deklarierte %qs"
 
-#: c/c-decl.c:5861
+#: c/c-decl.c:5881
 #, gcc-internal-format
 msgid "storage class specified for structure field %qE"
 msgstr "Speicherklasse für Strukturfeld %qE angegeben"
 
-#: c/c-decl.c:5864
+#: c/c-decl.c:5884
 #, gcc-internal-format
 msgid "storage class specified for structure field"
 msgstr "Speicherklasse für Strukturfeld angegeben"
 
-#: c/c-decl.c:5868
+#: c/c-decl.c:5888
 #, gcc-internal-format
 msgid "storage class specified for parameter %qE"
 msgstr "Speicherklasse für Parameter %qE angegeben"
 
-#: c/c-decl.c:5871
+#: c/c-decl.c:5891
 #, gcc-internal-format
 msgid "storage class specified for unnamed parameter"
 msgstr "Speicherklasse für unbenannten Parameter angegeben"
 
-#: c/c-decl.c:5874 cp/decl.c:10935
+#: c/c-decl.c:5894 cp/decl.c:10959
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "Speicherklasse für Typnamen angegeben"
 
-#: c/c-decl.c:5891
+#: c/c-decl.c:5911
 #, gcc-internal-format
 msgid "%qE initialized and declared %<extern%>"
 msgstr "%qE initialisiert und als %<extern%> deklariert"
 
-#: c/c-decl.c:5895
+#: c/c-decl.c:5915
 #, gcc-internal-format
 msgid "%qE has both %<extern%> and initializer"
 msgstr "%qE hat sowohl %<extern%> als auch Initialisierung"
 
-#: c/c-decl.c:5900
+#: c/c-decl.c:5920
 #, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<auto%>"
 msgstr "Deklaration von %qE in Datei-Sichtbarkeitsbereich spezifiziert %<auto%>"
 
-#: c/c-decl.c:5904
+#: c/c-decl.c:5924
 #, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<register%>"
 msgstr "Deklaration von %qE in Datei-Sichtbarkeitsbereich spezifiziert %<register%>"
 
-#: c/c-decl.c:5909
+#: c/c-decl.c:5929
 #, gcc-internal-format
 msgid "nested function %qE declared %<extern%>"
 msgstr "geschachtelte Funktion %qE als %<extern%> deklariert"
 
-#: c/c-decl.c:5912
+#: c/c-decl.c:5932
 #, gcc-internal-format
 msgid "function-scope %qE implicitly auto and declared %qs"
 msgstr "Funktions-Gültigkeitsbereich %qE ist implizit auto, jedoch als %qs deklariert"
@@ -33949,701 +33991,701 @@
 #. Only the innermost declarator (making a parameter be of
 #. array type which is converted to pointer type)
 #. may have static or type qualifiers.
-#: c/c-decl.c:5959 c/c-decl.c:6328
+#: c/c-decl.c:5979 c/c-decl.c:6348
 #, gcc-internal-format
 msgid "static or type qualifiers in non-parameter array declarator"
 msgstr "»static« oder Typkennzeichner in Nicht-Parameter-Arraydeklarator"
 
-#: c/c-decl.c:6007
+#: c/c-decl.c:6027
 #, gcc-internal-format
 msgid "declaration of %qE as array of voids"
 msgstr "Deklaration von %qE als Array von voids"
 
-#: c/c-decl.c:6009
+#: c/c-decl.c:6029
 #, gcc-internal-format
 msgid "declaration of type name as array of voids"
 msgstr "Deklaration eines Typnamen als Array von voids"
 
-#: c/c-decl.c:6016
+#: c/c-decl.c:6036
 #, gcc-internal-format
 msgid "declaration of %qE as array of functions"
 msgstr "Deklaration von %qE als Array von Funktionen"
 
-#: c/c-decl.c:6019
+#: c/c-decl.c:6039
 #, gcc-internal-format
 msgid "declaration of type name as array of functions"
 msgstr "Deklaration eines Typnamen als Array von Funktionen"
 
-#: c/c-decl.c:6027 c/c-decl.c:8085
+#: c/c-decl.c:6047 c/c-decl.c:8105
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr "ungültige Verwendung einer Struktur mit flexiblem Arrayelement"
 
-#: c/c-decl.c:6053
+#: c/c-decl.c:6073
 #, gcc-internal-format
 msgid "size of array %qE has non-integer type"
 msgstr "Arraygröße von %qE hat Nicht-Ganzzahltyp"
 
-#: c/c-decl.c:6057
+#: c/c-decl.c:6077
 #, gcc-internal-format
 msgid "size of unnamed array has non-integer type"
 msgstr "Größe eines unbenannten Arrays hat Nicht-Ganzzahltyp"
 
-#: c/c-decl.c:6064
+#: c/c-decl.c:6084
 #, gcc-internal-format
 msgid "size of array %qE has incomplete type"
 msgstr "Arraygröße von %qE hat unvollständigen Typ"
 
-#: c/c-decl.c:6067
+#: c/c-decl.c:6087
 #, gcc-internal-format
 msgid "size of unnamed array has incomplete type"
 msgstr "Größe eines unbenannten Arrays hat unvollständigen Typ"
 
-#: c/c-decl.c:6078
+#: c/c-decl.c:6098
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array %qE"
 msgstr "ISO-C verbietet Array %qE der Größe null"
 
-#: c/c-decl.c:6081
+#: c/c-decl.c:6101
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array"
 msgstr "ISO-C verbietet Array der Größe null"
 
-#: c/c-decl.c:6090
+#: c/c-decl.c:6110
 #, gcc-internal-format
 msgid "size of array %qE is negative"
 msgstr "Größe des Arrays %qE ist negativ"
 
-#: c/c-decl.c:6092
+#: c/c-decl.c:6112
 #, gcc-internal-format
 msgid "size of unnamed array is negative"
 msgstr "Größe des unbenannten Arrays ist negativ"
 
-#: c/c-decl.c:6216 c/c-decl.c:6871
+#: c/c-decl.c:6236 c/c-decl.c:6891
 #, gcc-internal-format
 msgid "ISO C90 does not support flexible array members"
 msgstr "ISO-C90 unterstützt keine flexiblen Arrays als Elemente"
 
 #. C99 6.7.5.2p4
-#: c/c-decl.c:6238
+#: c/c-decl.c:6258
 #, gcc-internal-format
 msgid "%<[*]%> not in a declaration"
 msgstr "%<[*]%> nicht in einer Deklaration"
 
-#: c/c-decl.c:6251
+#: c/c-decl.c:6271
 #, gcc-internal-format
 msgid "array type has incomplete element type %qT"
 msgstr "Arraytyp hat unvollständigen Elementtypen %qT"
 
-#: c/c-decl.c:6257
+#: c/c-decl.c:6277
 #, gcc-internal-format
 msgid "declaration of %qE as multidimensional array must have bounds for all dimensions except the first"
 msgstr "Deklaration von %qE als multidimensionales Array muss für alle Dimensionen außer der ersten Grenzen haben"
 
-#: c/c-decl.c:6261
+#: c/c-decl.c:6281
 #, gcc-internal-format
 msgid "declaration of multidimensional array must have bounds for all dimensions except the first"
 msgstr "Deklaration von multidimensionalem Array muss für alle Dimensionen außer der ersten Grenzen haben"
 
-#: c/c-decl.c:6364
+#: c/c-decl.c:6384
 #, gcc-internal-format
 msgid "%qE declared as function returning a function"
 msgstr "%qE als Funktion, die eine Funktion zurückgibt, deklariert"
 
-#: c/c-decl.c:6367
+#: c/c-decl.c:6387
 #, gcc-internal-format
 msgid "type name declared as function returning a function"
 msgstr "Typname als Funktion, die eine Funktion zurückgibt, deklariert"
 
-#: c/c-decl.c:6374
+#: c/c-decl.c:6394
 #, gcc-internal-format
 msgid "%qE declared as function returning an array"
 msgstr "%qE als Funktion, die ein Array zurückgibt, deklariert"
 
-#: c/c-decl.c:6377
+#: c/c-decl.c:6397
 #, gcc-internal-format
 msgid "type name declared as function returning an array"
 msgstr "Typname als Funktion, die ein Array zurückgibt, deklariert"
 
-#: c/c-decl.c:6418
+#: c/c-decl.c:6438
 #, gcc-internal-format
 msgid "function definition has qualified void return type"
 msgstr "Funktionsdefinition hat qualifizierten void-Rückgabetypen"
 
-#: c/c-decl.c:6421 cp/decl.c:11201
+#: c/c-decl.c:6441 cp/decl.c:11225
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "Typkennzeichner an Funktions-Rückgabewert ignoriert"
 
-#: c/c-decl.c:6459 c/c-decl.c:6668 c/c-decl.c:6721 c/c-decl.c:6805
-#: c/c-decl.c:6926 c/c-parser.c:2823
+#: c/c-decl.c:6479 c/c-decl.c:6688 c/c-decl.c:6741 c/c-decl.c:6825
+#: c/c-decl.c:6946 c/c-parser.c:2823
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified function type"
 msgstr "%<_Atomic%>-qualifizierter Funktionstyp"
 
-#: c/c-decl.c:6465 c/c-decl.c:6674 c/c-decl.c:6810 c/c-decl.c:6931
+#: c/c-decl.c:6485 c/c-decl.c:6694 c/c-decl.c:6830 c/c-decl.c:6951
 #, gcc-internal-format
 msgid "ISO C forbids qualified function types"
 msgstr "ISO-C verbietet qualifizierte Funktionstypen"
 
-#: c/c-decl.c:6559
+#: c/c-decl.c:6579
 #, gcc-internal-format
 msgid "%qs combined with %<auto%> qualifier for %qE"
 msgstr "%qs mit Qualifizierer %<auto%> für %qE kombiniert"
 
-#: c/c-decl.c:6563
+#: c/c-decl.c:6583
 #, gcc-internal-format
 msgid "%qs combined with %<register%> qualifier for %qE"
 msgstr "%qs mit Qualifizierer %<register%> für %qE kombiniert"
 
-#: c/c-decl.c:6569
+#: c/c-decl.c:6589
 #, gcc-internal-format
 msgid "%qs specified for auto variable %qE"
 msgstr "%qs für »auto«-Variable %qE angegeben"
 
-#: c/c-decl.c:6585
+#: c/c-decl.c:6605
 #, gcc-internal-format
 msgid "%qs specified for parameter %qE"
 msgstr "%qs für Parameter %qE angegeben"
 
-#: c/c-decl.c:6588
+#: c/c-decl.c:6608
 #, gcc-internal-format
 msgid "%qs specified for unnamed parameter"
 msgstr "%qs für unbenannten Parameter angegeben"
 
-#: c/c-decl.c:6594
+#: c/c-decl.c:6614
 #, gcc-internal-format
 msgid "%qs specified for structure field %qE"
 msgstr "%qs für Strukturfeld %qE angegeben"
 
-#: c/c-decl.c:6597
+#: c/c-decl.c:6617
 #, gcc-internal-format
 msgid "%qs specified for structure field"
 msgstr "%qs für Strukturfeld angegeben"
 
-#: c/c-decl.c:6612
+#: c/c-decl.c:6632
 #, gcc-internal-format
 msgid "bit-field %qE has atomic type"
 msgstr "Bitfeld %qE hat atomaren Typen"
 
-#: c/c-decl.c:6614
+#: c/c-decl.c:6634
 #, gcc-internal-format
 msgid "bit-field has atomic type"
 msgstr "Bitfeld hat atomaren Typen"
 
-#: c/c-decl.c:6623
+#: c/c-decl.c:6643
 #, gcc-internal-format
 msgid "alignment specified for typedef %qE"
 msgstr "Ausrichtung für typedef %qE angegeben"
 
-#: c/c-decl.c:6625
+#: c/c-decl.c:6645
 #, gcc-internal-format
 msgid "alignment specified for %<register%> object %qE"
 msgstr "Ausrichtung für %<register%>-Objekt %qE angegeben"
 
-#: c/c-decl.c:6630
+#: c/c-decl.c:6650
 #, gcc-internal-format
 msgid "alignment specified for parameter %qE"
 msgstr "Ausrichtung für Parameter %qE angegeben"
 
-#: c/c-decl.c:6632
+#: c/c-decl.c:6652
 #, gcc-internal-format
 msgid "alignment specified for unnamed parameter"
 msgstr "Ausrichtung für unbenannten Parameter angegeben"
 
-#: c/c-decl.c:6637
+#: c/c-decl.c:6657
 #, gcc-internal-format
 msgid "alignment specified for bit-field %qE"
 msgstr "Ausrichtung für Bitfeld %qE angegeben"
 
-#: c/c-decl.c:6639
+#: c/c-decl.c:6659
 #, gcc-internal-format
 msgid "alignment specified for unnamed bit-field"
 msgstr "Ausrichtung für unbenanntes Bitfeld angegeben"
 
-#: c/c-decl.c:6642
+#: c/c-decl.c:6662
 #, gcc-internal-format
 msgid "alignment specified for function %qE"
 msgstr "Ausrichtung für Funktion %qE angegeben"
 
-#: c/c-decl.c:6649
+#: c/c-decl.c:6669
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of %qE"
 msgstr "%<_Alignas%>-Spezifizierer können nicht die Ausrichtung von %qE reduzieren"
 
-#: c/c-decl.c:6652
+#: c/c-decl.c:6672
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of unnamed field"
 msgstr "%<_Alignas%>-Spezifizierer können nicht die Ausrichtung eines unbenannten Feldes reduzieren"
 
-#: c/c-decl.c:6683
+#: c/c-decl.c:6703
 #, gcc-internal-format
 msgid "typedef %q+D declared %<inline%>"
 msgstr "typedef %q+D als %<inline%> deklariert"
 
-#: c/c-decl.c:6685
+#: c/c-decl.c:6705
 #, gcc-internal-format
 msgid "typedef %q+D declared %<_Noreturn%>"
 msgstr "typedef %q+D als %<_Noreturn%> deklariert"
 
-#: c/c-decl.c:6727
+#: c/c-decl.c:6747
 #, gcc-internal-format
 msgid "ISO C forbids const or volatile function types"
 msgstr "ISO-C verbietet const- oder volatile-Funktionstypen"
 
 #. C99 6.7.2.1p8
-#: c/c-decl.c:6738
+#: c/c-decl.c:6758
 #, gcc-internal-format
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "Ein Element einer Struktur oder Union kann nicht variabel modifizierten Typ haben"
 
-#: c/c-decl.c:6755 cp/decl.c:9989
+#: c/c-decl.c:6775 cp/decl.c:10010
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "Variable oder Feld %qE als »void« deklariert"
 
-#: c/c-decl.c:6795
+#: c/c-decl.c:6815
 #, gcc-internal-format
 msgid "attributes in parameter array declarator ignored"
 msgstr "Attribute in Parameterarraydeklarator ignoriert"
 
-#: c/c-decl.c:6837
+#: c/c-decl.c:6857
 #, gcc-internal-format
 msgid "parameter %q+D declared %<inline%>"
 msgstr "Parameter %q+D als %<inline%> deklariert"
 
-#: c/c-decl.c:6839
+#: c/c-decl.c:6859
 #, gcc-internal-format
 msgid "parameter %q+D declared %<_Noreturn%>"
 msgstr "Parameter %q+D als %<_Noreturn%> deklariert"
 
-#: c/c-decl.c:6852
+#: c/c-decl.c:6872
 #, gcc-internal-format
 msgid "field %qE declared as a function"
 msgstr "Feld %qE als Funktion deklariert"
 
-#: c/c-decl.c:6859
+#: c/c-decl.c:6879
 #, gcc-internal-format
 msgid "field %qE has incomplete type"
 msgstr "Feld %qE hat unvollständigen Typen"
 
-#: c/c-decl.c:6861
+#: c/c-decl.c:6881
 #, gcc-internal-format
 msgid "unnamed field has incomplete type"
 msgstr "unbenanntes Feld hat unvollständigen Typen"
 
-#: c/c-decl.c:6897 c/c-decl.c:6908 c/c-decl.c:6911
+#: c/c-decl.c:6917 c/c-decl.c:6928 c/c-decl.c:6931
 #, gcc-internal-format
 msgid "invalid storage class for function %qE"
 msgstr "ungültige Speicherklasse für Funktion %qE"
 
-#: c/c-decl.c:6968
+#: c/c-decl.c:6988
 #, gcc-internal-format
 msgid "cannot inline function %<main%>"
 msgstr "%<main%> ist nicht als »inline« möglich"
 
-#: c/c-decl.c:6970
+#: c/c-decl.c:6990
 #, gcc-internal-format
 msgid "%<main%> declared %<_Noreturn%>"
 msgstr "%<main%> als %<_Noreturn%> deklariert"
 
-#: c/c-decl.c:6981
+#: c/c-decl.c:7001
 #, gcc-internal-format
 msgid "ISO C99 does not support %<_Noreturn%>"
 msgstr "ISO-C99 unterstützt nicht %<_Noreturn%>"
 
-#: c/c-decl.c:6984
+#: c/c-decl.c:7004
 #, gcc-internal-format
 msgid "ISO C90 does not support %<_Noreturn%>"
 msgstr "ISO-C90 unterstützt nicht %<_Noreturn%>"
 
-#: c/c-decl.c:7013
+#: c/c-decl.c:7033
 #, gcc-internal-format
 msgid "variable previously declared %<static%> redeclared %<extern%>"
 msgstr "als %<extern%> redeklarierte Variable war bereits als %<static%> deklariert"
 
-#: c/c-decl.c:7023
+#: c/c-decl.c:7043
 #, gcc-internal-format
 msgid "variable %q+D declared %<inline%>"
 msgstr "Variable %q+D als %<inline%> deklariert"
 
-#: c/c-decl.c:7025
+#: c/c-decl.c:7045
 #, gcc-internal-format
 msgid "variable %q+D declared %<_Noreturn%>"
 msgstr "Variable %q+D als %<_Noreturn%> deklariert"
 
-#: c/c-decl.c:7060
+#: c/c-decl.c:7080
 #, gcc-internal-format
 msgid "non-nested function with variably modified type"
 msgstr "nicht geschachtelte Funktion mit variabel modifiziertem Typen"
 
-#: c/c-decl.c:7062
+#: c/c-decl.c:7082
 #, gcc-internal-format
 msgid "object with variably modified type must have no linkage"
 msgstr "Objekt mit variabel geändertem Typ darf keine Bindung haben"
 
-#: c/c-decl.c:7153 c/c-decl.c:8821
+#: c/c-decl.c:7173 c/c-decl.c:8841
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr "Funktionsdeklaration ist kein Prototyp"
 
-#: c/c-decl.c:7163
+#: c/c-decl.c:7183
 #, gcc-internal-format
 msgid "parameter names (without types) in function declaration"
 msgstr "Parameternamen (ohne Typen) in Funktionsdeklaration"
 
-#: c/c-decl.c:7201
+#: c/c-decl.c:7221
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has incomplete type"
 msgstr "Parameter %u (%q+D) hat unvollständigen Typen"
 
-#: c/c-decl.c:7205
+#: c/c-decl.c:7225
 #, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has incomplete type"
 msgstr "Parameter %u hat unvollständigen Typen"
 
-#: c/c-decl.c:7216
+#: c/c-decl.c:7236
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has void type"
 msgstr "Parameter %u (%q+D) hat void-Typen"
 
-#: c/c-decl.c:7220
+#: c/c-decl.c:7240
 #, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has void type"
 msgstr "Parameter %u hat void-Typen"
 
-#: c/c-decl.c:7294
+#: c/c-decl.c:7314
 #, gcc-internal-format
 msgid "%<void%> as only parameter may not be qualified"
 msgstr "%<void%> kann nicht als einzelner Parameter qualifiziert werden"
 
-#: c/c-decl.c:7298 c/c-decl.c:7334
+#: c/c-decl.c:7318 c/c-decl.c:7354
 #, gcc-internal-format
 msgid "%<void%> must be the only parameter"
 msgstr "%<void%> muss der einzige Parameter sein"
 
-#: c/c-decl.c:7328
+#: c/c-decl.c:7348
 #, gcc-internal-format
 msgid "parameter %q+D has just a forward declaration"
 msgstr "Parameter %q+D hat nur eine Vorwärtsdeklaration"
 
-#: c/c-decl.c:7374
+#: c/c-decl.c:7394
 #, gcc-internal-format
 msgid "%<%s %E%> declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr "das innerhalb der Parameterliste deklarierte %<%s %E%> ist außerhalb dieser Definition oder Deklaration nicht sichtbar"
 
-#: c/c-decl.c:7380
+#: c/c-decl.c:7400
 #, gcc-internal-format, gfc-internal-format
 msgid "anonymous %s declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr "das innerhalb der Parameterliste deklarierte anonyme »%s« ist außerhalb dieser Definition oder Deklaration nicht sichtbar"
 
-#: c/c-decl.c:7482
+#: c/c-decl.c:7502
 #, gcc-internal-format
 msgid "enum type defined here"
 msgstr "»enum«-Typ hier definiert"
 
-#: c/c-decl.c:7488
+#: c/c-decl.c:7508
 #, gcc-internal-format
 msgid "struct defined here"
 msgstr "»struct« wurde hier definiert"
 
-#: c/c-decl.c:7494
+#: c/c-decl.c:7514
 #, gcc-internal-format
 msgid "union defined here"
 msgstr "»union« wurde hier definiert"
 
-#: c/c-decl.c:7570
+#: c/c-decl.c:7590
 #, gcc-internal-format
 msgid "redefinition of %<union %E%>"
 msgstr "Redefinition von %<union %E%>"
 
-#: c/c-decl.c:7572
+#: c/c-decl.c:7592
 #, gcc-internal-format
 msgid "redefinition of %<struct %E%>"
 msgstr "Redefinition von %<struct %E%>"
 
-#: c/c-decl.c:7581
+#: c/c-decl.c:7601
 #, gcc-internal-format
 msgid "nested redefinition of %<union %E%>"
 msgstr "Verschachtelte Redefinition von %<union %E%>"
 
-#: c/c-decl.c:7583
+#: c/c-decl.c:7603
 #, gcc-internal-format
 msgid "nested redefinition of %<struct %E%>"
 msgstr "Verschachtelte Redefinition von %<struct %E%>"
 
-#: c/c-decl.c:7613 c/c-decl.c:8400
+#: c/c-decl.c:7633 c/c-decl.c:8420
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr "Typdefinition in Ausdruck %qs ist in C++ ungültig"
 
-#: c/c-decl.c:7680 cp/decl.c:4802
+#: c/c-decl.c:7700 cp/decl.c:4802
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "Deklaration deklariert nichts"
 
-#: c/c-decl.c:7685
+#: c/c-decl.c:7705
 #, gcc-internal-format
 msgid "ISO C99 doesn%'t support unnamed structs/unions"
 msgstr "ISO-C99 unterstützt keine namenlosen structs/unions"
 
-#: c/c-decl.c:7688
+#: c/c-decl.c:7708
 #, gcc-internal-format
 msgid "ISO C90 doesn%'t support unnamed structs/unions"
 msgstr "ISO-C90 unterstützt keine namenlosen structs/unions"
 
-#: c/c-decl.c:7781 c/c-decl.c:7799 c/c-decl.c:7860
+#: c/c-decl.c:7801 c/c-decl.c:7819 c/c-decl.c:7880
 #, gcc-internal-format
 msgid "duplicate member %q+D"
 msgstr "doppeltes Element %q+D"
 
-#: c/c-decl.c:7886
+#: c/c-decl.c:7906
 #, gcc-internal-format
 msgid "empty struct has size 0 in C, size 1 in C++"
 msgstr "leere Struktur hat Größe 0 in C, aber 1 in C++"
 
-#: c/c-decl.c:7889
+#: c/c-decl.c:7909
 #, gcc-internal-format
 msgid "empty union has size 0 in C, size 1 in C++"
 msgstr "leere Union hat Größe 0 in C, aber 1 in C++"
 
-#: c/c-decl.c:7994
+#: c/c-decl.c:8014
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr "Union hat keine benannten Elemente"
 
-#: c/c-decl.c:7996
+#: c/c-decl.c:8016
 #, gcc-internal-format
 msgid "union has no members"
 msgstr "Union hat keine Elemente"
 
-#: c/c-decl.c:8001
+#: c/c-decl.c:8021
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr "struct hat keine benannten Elemente"
 
-#: c/c-decl.c:8003
+#: c/c-decl.c:8023
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr "struct hat keine Elemente"
 
-#: c/c-decl.c:8064 cp/decl.c:12069
+#: c/c-decl.c:8084 cp/decl.c:12093
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "flexibles Arrayelement in Union"
 
-#: c/c-decl.c:8070
+#: c/c-decl.c:8090
 #, gcc-internal-format
 msgid "flexible array member not at end of struct"
 msgstr "flexibles Arrayelement nicht am Ende von struct"
 
-#: c/c-decl.c:8076
+#: c/c-decl.c:8096
 #, gcc-internal-format
 msgid "flexible array member in a struct with no named members"
 msgstr "flexibles Arrayelement in einer Struktur ohne benannte Elemente"
 
-#: c/c-decl.c:8107
+#: c/c-decl.c:8127
 #, gcc-internal-format
 msgid "type %qT is too large"
 msgstr "Typ %qT ist zu groß"
 
-#: c/c-decl.c:8230
+#: c/c-decl.c:8250
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr "union kann nicht transparent gemacht werden"
 
-#: c/c-decl.c:8372
+#: c/c-decl.c:8392
 #, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr "Verschachtelte Redefinition von %<enum %E%>"
 
 #. This enum is a named one that has been declared already.
-#: c/c-decl.c:8379
+#: c/c-decl.c:8399
 #, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr "Redeklaration von %<enum %E%>"
 
-#: c/c-decl.c:8458 cp/decl.c:14423
+#: c/c-decl.c:8478 cp/decl.c:14447
 #, gcc-internal-format
 msgid "specified mode too small for enumeral values"
 msgstr "angegebener Modus zu klein für Aufzählungswerte"
 
-#: c/c-decl.c:8473
+#: c/c-decl.c:8493
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr "Aufzählungswerte überschreiten Wertebereich des größten Ganzzahltypen"
 
-#: c/c-decl.c:8587 c/c-decl.c:8603
+#: c/c-decl.c:8607 c/c-decl.c:8623
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr "Aufzählungswert für %qE ist keine Ganzzahlkonstante"
 
-#: c/c-decl.c:8598
+#: c/c-decl.c:8618
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr "Aufzählungswert für %qE ist kein Ganzzahlkonstantenausdruck"
 
-#: c/c-decl.c:8622
+#: c/c-decl.c:8642
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr "Überlauf in Aufzählungswerten"
 
-#: c/c-decl.c:8630
+#: c/c-decl.c:8650
 #, gcc-internal-format
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "ISO-C beschränkt Aufzählungswerte auf Bereich von %<int%>"
 
-#: c/c-decl.c:8715 cp/decl.c:5104 cp/decl.c:14955
+#: c/c-decl.c:8735 cp/decl.c:5104 cp/decl.c:14979
 #, gcc-internal-format
 msgid "inline function %qD given attribute noinline"
 msgstr "inline-Funktion %qD wurde das Attribut »noinline« gegeben"
 
-#: c/c-decl.c:8733
+#: c/c-decl.c:8753
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr "Rückgabetyp ist unvollständig"
 
-#: c/c-decl.c:8744
+#: c/c-decl.c:8764
 #, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr "Rückgabetyp ist auf %<int%> voreingestellt"
 
-#: c/c-decl.c:8771
+#: c/c-decl.c:8791
 #, gcc-internal-format
 msgid "%q+D defined as variadic function without prototype"
 msgstr "%q+D ist als variadische Funktion ohne Prototyp definiert"
 
-#: c/c-decl.c:8830
+#: c/c-decl.c:8850
 #, gcc-internal-format
 msgid "no previous prototype for %qD"
 msgstr "kein vorheriger Prototyp für %qD"
 
-#: c/c-decl.c:8839
+#: c/c-decl.c:8859
 #, gcc-internal-format
 msgid "%qD was used with no prototype before its definition"
 msgstr "%qD wurde vor seiner Definition ohne Prototyp verwendet"
 
-#: c/c-decl.c:8847 cp/decl.c:15090
+#: c/c-decl.c:8867 cp/decl.c:15114
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "keine vorherige Deklaration für %qD"
 
-#: c/c-decl.c:8857
+#: c/c-decl.c:8877
 #, gcc-internal-format
 msgid "%qD was used with no declaration before its definition"
 msgstr "%qD wurde vor seiner Definition ohne Deklaration verwendet"
 
-#: c/c-decl.c:8876
+#: c/c-decl.c:8896
 #, gcc-internal-format
 msgid "return type of %qD is not %<int%>"
 msgstr "Rückgabetyp von %qD ist nicht %<int%>"
 
-#: c/c-decl.c:8878
+#: c/c-decl.c:8898
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr "%<_Atomic%>-qualifizierter Rückgabetyp von %qD"
 
-#: c/c-decl.c:8885
+#: c/c-decl.c:8905
 #, gcc-internal-format
 msgid "%qD is normally a non-static function"
 msgstr "%qD ist normalerweise eine nicht-statische Funktion"
 
-#: c/c-decl.c:8922
+#: c/c-decl.c:8942
 #, gcc-internal-format
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr "Parameterdeklarationen alten Stils in Prototyp-Funktionsdeklaration"
 
-#: c/c-decl.c:8937
+#: c/c-decl.c:8957
 #, gcc-internal-format
 msgid "traditional C rejects ISO C style function definitions"
 msgstr "traditionelles C weist Funktionsdefinitionen im ISO-C-Stil zurück"
 
-#: c/c-decl.c:8953
+#: c/c-decl.c:8973
 #, gcc-internal-format
 msgid "parameter name omitted"
 msgstr "Parametername ausgelassen"
 
-#: c/c-decl.c:8990
+#: c/c-decl.c:9010
 #, gcc-internal-format
 msgid "old-style function definition"
 msgstr "Funktionsdefinition im alten Stil"
 
-#: c/c-decl.c:8999
+#: c/c-decl.c:9019
 #, gcc-internal-format
 msgid "parameter name missing from parameter list"
 msgstr "Parametername fehlt in Parameterliste"
 
-#: c/c-decl.c:9015
+#: c/c-decl.c:9035
 #, gcc-internal-format
 msgid "%qD declared as a non-parameter"
 msgstr "%qD als Nicht-Parameter deklariert"
 
-#: c/c-decl.c:9023
+#: c/c-decl.c:9043
 #, gcc-internal-format
 msgid "multiple parameters named %qD"
 msgstr "mehrere Parameter wurden %qD genannt"
 
-#: c/c-decl.c:9032
+#: c/c-decl.c:9052
 #, gcc-internal-format
 msgid "parameter %qD declared with void type"
 msgstr "Parameter %qD als void deklariert"
 
-#: c/c-decl.c:9061 c/c-decl.c:9066
+#: c/c-decl.c:9081 c/c-decl.c:9086
 #, gcc-internal-format
 msgid "type of %qD defaults to %<int%>"
 msgstr "Typ von %qD ist auf %<int%> voreingestellt"
 
-#: c/c-decl.c:9086
+#: c/c-decl.c:9106
 #, gcc-internal-format
 msgid "parameter %qD has incomplete type"
 msgstr "Parameter %qD hat unvollständigen Typen"
 
-#: c/c-decl.c:9093
+#: c/c-decl.c:9113
 #, gcc-internal-format
 msgid "declaration for parameter %qD but no such parameter"
 msgstr "Deklaration für nicht vorhandenen Parameter %qD"
 
-#: c/c-decl.c:9146
+#: c/c-decl.c:9166
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr "Anzahl der Argumente passt nicht zum eingebauten Prototypen"
 
-#: c/c-decl.c:9157
+#: c/c-decl.c:9177
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr "Anzahl der Argumente passt nicht zum Prototypen"
 
-#: c/c-decl.c:9160 c/c-decl.c:9207 c/c-decl.c:9221
+#: c/c-decl.c:9180 c/c-decl.c:9227 c/c-decl.c:9241
 #, gcc-internal-format
 msgid "prototype declaration"
 msgstr "Prototyp-Deklaration"
 
-#: c/c-decl.c:9199
+#: c/c-decl.c:9219
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr "weitergegebenes Argument %qD passt nicht zu eingebautem Prototypen"
 
-#: c/c-decl.c:9204
+#: c/c-decl.c:9224
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr "weitergegebenes Argument %qD passt nicht zum Prototypen"
 
-#: c/c-decl.c:9214
+#: c/c-decl.c:9234
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr "Argument %qD passt nicht zu eingebautem Prototypen"
 
-#: c/c-decl.c:9219
+#: c/c-decl.c:9239
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr "Argument %qD passt nicht zum Prototypen"
 
-#: c/c-decl.c:9470 cp/decl.c:15873
+#: c/c-decl.c:9490 cp/decl.c:15897
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "keine return-Anweisung in nicht void zurückgebender Funktion"
 
-#: c/c-decl.c:9490 cp/decl.c:15905
+#: c/c-decl.c:9510 cp/decl.c:15929
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "Parameter %qD gesetzt, jedoch nicht verwendet"
@@ -34651,247 +34693,247 @@
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:9586
+#: c/c-decl.c:9606
 #, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "Anfangsdeklarationen in %<for%>-Schleifen sind nur im C99- oder C11-Modus erlaubt"
 
-#: c/c-decl.c:9591
+#: c/c-decl.c:9611
 #, gcc-internal-format
 msgid "use option -std=c99, -std=gnu99, -std=c11 or -std=gnu11 to compile your code"
 msgstr "-std=c99, -std=gnu99, -std=c11 oder -std=gnu11 verwenden, um den Code zu übersetzen"
 
-#: c/c-decl.c:9626
+#: c/c-decl.c:9646
 #, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "Deklaration der »static«-Variablen %qD in Anfangsdeklaration einer %<for%>-Schleife"
 
-#: c/c-decl.c:9630
+#: c/c-decl.c:9650
 #, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "Deklaration der %<extern%>-Variablen %qD in Anfangsdeklaration einer %<for%>-Schleife"
 
-#: c/c-decl.c:9637
+#: c/c-decl.c:9657
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "%<struct %E%> in Anfangsdeklaration einer %<for%>-Schleife deklariert"
 
-#: c/c-decl.c:9642
+#: c/c-decl.c:9662
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "%<union %E%> in Anfangsdeklaration einer %<for%>-Schleife deklariert"
 
-#: c/c-decl.c:9646
+#: c/c-decl.c:9666
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "%<enum %E%> in Anfangsdeklaration einer %<for%>-Schleife deklariert"
 
-#: c/c-decl.c:9650
+#: c/c-decl.c:9670
 #, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "Deklaration der Nicht-Variablen %qD in Anfangsdeklaration einer %<for%>-Schleife"
 
-#: c/c-decl.c:9900
+#: c/c-decl.c:9920
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr "Inkompatible Adressraumkennzeichen %qs und %qs"
 
-#: c/c-decl.c:9958 c/c-decl.c:9965
+#: c/c-decl.c:9978 c/c-decl.c:9985
 #, gcc-internal-format
 msgid "duplicate %qE declaration specifier"
 msgstr "Doppelter Deklarationsspezifizierer %qE"
 
-#: c/c-decl.c:9992 c/c-decl.c:10376 c/c-decl.c:10766
+#: c/c-decl.c:10012 c/c-decl.c:10396 c/c-decl.c:10786
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr "zwei oder mehr Datentypen in Deklaration"
 
-#: c/c-decl.c:10004 cp/parser.c:28261
+#: c/c-decl.c:10024 cp/parser.c:28258
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> ist für GCC zu lang"
 
-#: c/c-decl.c:10017
+#: c/c-decl.c:10037
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO-C90 unterstützt nicht %<long long%>"
 
-#: c/c-decl.c:10246 c/c-parser.c:8848
+#: c/c-decl.c:10266 c/c-parser.c:8848
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO-C90 unterstützt keine komplexen Typen"
 
-#: c/c-decl.c:10292
+#: c/c-decl.c:10312
 #, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr "ISO-C unterstützt keine sättigenden Typen"
 
-#: c/c-decl.c:10363 c/c-decl.c:10923
+#: c/c-decl.c:10383 c/c-decl.c:10943
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "doppeltes %qE"
 
-#: c/c-decl.c:10419
+#: c/c-decl.c:10439
 #, gcc-internal-format
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO-C unterstützt die Typen %<__int%d%> nicht"
 
-#: c/c-decl.c:10441
+#: c/c-decl.c:10461
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr "%<__int%d%> wird für dieses Ziel nicht unterstützt"
 
-#: c/c-decl.c:10484
+#: c/c-decl.c:10504
 #, gcc-internal-format
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO-C90 unterstützt keine booleschen Typen"
 
-#: c/c-decl.c:10603
+#: c/c-decl.c:10623
 #, gcc-internal-format
 msgid "ISO C does not support the %<_Float%d%s%> type"
 msgstr "ISO-C unterstützt den Typen %<_Float%d%s%> nicht"
 
-#: c/c-decl.c:10653
+#: c/c-decl.c:10673
 #, gcc-internal-format
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "%<_Float%d%s%> wird für dieses Ziel nicht unterstützt"
 
-#: c/c-decl.c:10724
+#: c/c-decl.c:10744
 #, gcc-internal-format
 msgid "ISO C does not support decimal floating point"
 msgstr "ISO-C unterstützt kein dezimales Gleitkomma"
 
-#: c/c-decl.c:10747 c/c-decl.c:11013 c/c-parser.c:7842
+#: c/c-decl.c:10767 c/c-decl.c:11033 c/c-parser.c:7842
 #, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "Festkommatypen werden für dieses Ziel nicht unterstützt"
 
-#: c/c-decl.c:10749
+#: c/c-decl.c:10769
 #, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO-C unterstützt keine Ganzzahltypen"
 
-#: c/c-decl.c:10784
+#: c/c-decl.c:10804
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr "Nachschlagen von %qD würde in C++ ein Feld, keinen Typen zurückgeben"
 
-#: c/c-decl.c:10797
+#: c/c-decl.c:10817
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr "%qE ist kein typedef oder eingebauter Typ"
 
-#: c/c-decl.c:10845
+#: c/c-decl.c:10865
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qE ist nicht am Anfang einer Deklaration"
 
-#: c/c-decl.c:10866
+#: c/c-decl.c:10886
 #, gcc-internal-format
 msgid "%qE used with %<auto%>"
 msgstr "%qE mit %<auto%> verwendet"
 
-#: c/c-decl.c:10868
+#: c/c-decl.c:10888
 #, gcc-internal-format
 msgid "%qE used with %<register%>"
 msgstr "%qE mit %<register%> verwendet"
 
-#: c/c-decl.c:10870
+#: c/c-decl.c:10890
 #, gcc-internal-format
 msgid "%qE used with %<typedef%>"
 msgstr "%qE mit %<typedef%> verwendet"
 
-#: c/c-decl.c:10884 c/c-parser.c:7360
+#: c/c-decl.c:10904 c/c-parser.c:7360
 #, gcc-internal-format
 msgid "ISO C99 does not support %qE"
 msgstr "ISO-C99 unterstützt nicht %qE"
 
-#: c/c-decl.c:10887 c/c-parser.c:7363
+#: c/c-decl.c:10907 c/c-parser.c:7363
 #, gcc-internal-format
 msgid "ISO C90 does not support %qE"
 msgstr "ISO-C90 unterstützt nicht %qE"
 
-#: c/c-decl.c:10899
+#: c/c-decl.c:10919
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<__thread%> vor %<extern%>"
 
-#: c/c-decl.c:10908
+#: c/c-decl.c:10928
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<__thread%> vor %<static%>"
 
-#: c/c-decl.c:10921
+#: c/c-decl.c:10941
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr "doppeltes %<_Thread_local%> oder %<__thread%>"
 
-#: c/c-decl.c:10929
+#: c/c-decl.c:10949
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr "mehrere Speicherklassen in Deklaration"
 
-#: c/c-decl.c:10937
+#: c/c-decl.c:10957
 #, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr "%qs mit %qE verwendet"
 
-#: c/c-decl.c:11010
+#: c/c-decl.c:11030
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "%<_Sat%> ohne %<_Fract%> oder %<_Accum%> verwendet"
 
-#: c/c-decl.c:11025
+#: c/c-decl.c:11045
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO-C unterstützt nicht %<double complex%> bedeutendes einfaches %<complex%>"
 
-#: c/c-decl.c:11076 c/c-decl.c:11092 c/c-decl.c:11118
+#: c/c-decl.c:11096 c/c-decl.c:11112 c/c-decl.c:11138
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO-C unterstützt keine komplexen Ganzzahltypen"
 
-#: c/c-decl.c:11514 cp/semantics.c:5348
+#: c/c-decl.c:11534 cp/semantics.c:5351
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr "%<#pragma omp declare reduction%>-Kombinierer verweist auf Variable %qD, die weder %<omp_out%> noch %<omp_in%> ist"
 
-#: c/c-decl.c:11518 cp/semantics.c:5352
+#: c/c-decl.c:11538 cp/semantics.c:5355
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr "%<#pragma omp declare reduction%>-Initialisierung verweist auf Variable %qD, die weder %<omp_priv%> noch %<omp_orig%> ist"
 
-#: c/c-fold.c:385 c/c-typeck.c:11426 cp/typeck.c:4680
+#: c/c-fold.c:385 c/c-typeck.c:11431 cp/typeck.c:4680
 #, gcc-internal-format
 msgid "left shift of negative value"
 msgstr "left shift of negative value"
 
-#: c/c-fold.c:395 c/c-typeck.c:11435 cp/typeck.c:4688
+#: c/c-fold.c:395 c/c-typeck.c:11440 cp/typeck.c:4688
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "Links-Schiebe-Weite ist negativ"
 
-#: c/c-fold.c:396 c/c-typeck.c:11365 cp/typeck.c:4633
+#: c/c-fold.c:396 c/c-typeck.c:11370 cp/typeck.c:4633
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "Rechts-Schiebe-Weite ist negativ"
 
-#: c/c-fold.c:404 c/c-typeck.c:11454 cp/typeck.c:4696
+#: c/c-fold.c:404 c/c-typeck.c:11459 cp/typeck.c:4696
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "Links-Schiebe-Weite >= Breite des Typs"
 
-#: c/c-fold.c:405 c/c-typeck.c:11389 cp/typeck.c:4641
+#: c/c-fold.c:405 c/c-typeck.c:11394 cp/typeck.c:4641
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "Rechts-Schiebe-Weite >= Breite des Typs"
 
-#: c/c-fold.c:412 c/c-typeck.c:11446
+#: c/c-fold.c:412 c/c-typeck.c:11451
 #, gcc-internal-format
 msgid "left shift count >= width of vector element"
 msgstr "Links-Schiebe-Weite >= Breite des Vektorelements"
 
-#: c/c-fold.c:413 c/c-typeck.c:11376
+#: c/c-fold.c:413 c/c-typeck.c:11381
 #, gcc-internal-format
 msgid "right shift count >= width of vector element"
 msgstr "Rechts-Schiebe-Weite >= Breite des Vektorelements"
@@ -34911,7 +34953,7 @@
 msgid "to match this %qs"
 msgstr "andere Fundstelle von %qs ist hier"
 
-#: c/c-parser.c:1216 cp/parser.c:28484
+#: c/c-parser.c:1216 cp/parser.c:28481
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr "Zeilenende erwartet"
@@ -34952,7 +34994,7 @@
 msgstr "unbekannter Typname: %qE"
 
 #: c/c-parser.c:1848 c/c-parser.c:11129 c/c-parser.c:16147 c/c-parser.c:16585
-#: c/c-parser.c:17061 cp/parser.c:36007 cp/parser.c:38993
+#: c/c-parser.c:17061 cp/parser.c:36004 cp/parser.c:38990
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "Deklarationsspezifizierer erwartet"
@@ -34967,7 +35009,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "%<;%>, Bezeichner oder %<(%> erwartet"
 
-#: c/c-parser.c:1906 cp/parser.c:30161 cp/parser.c:30235
+#: c/c-parser.c:1906 cp/parser.c:30158 cp/parser.c:30232
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "Präfixattribute werden für Methoden ignoriert"
@@ -35021,7 +35063,7 @@
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr "%<__auto_type%> kann nur mit einem einzelnen Deklarator verwendet werden"
 
-#: c/c-parser.c:2220 cp/parser.c:13002 cp/parser.c:13159
+#: c/c-parser.c:2220 cp/parser.c:12999 cp/parser.c:13156
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "%<,%> oder %<;%> erwartet"
@@ -35049,7 +35091,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO-C90 unterstützt nicht %<_Static_assert%>"
 
-#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38634
+#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38631
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr "Zeichenkettenliteral erwartet"
@@ -35113,13 +35155,13 @@
 #: c/c-parser.c:10745 c/c-parser.c:10798 c/c-parser.c:10814 c/c-parser.c:10860
 #: c/c-parser.c:11496 c/c-parser.c:11537 c/c-parser.c:13445 c/c-parser.c:13681
 #: c/c-parser.c:15544 c/c-parser.c:18218 c/gimple-parser.c:1058
-#: c/gimple-parser.c:1096 cp/parser.c:28487 cp/parser.c:31013
-#: cp/parser.c:31043 cp/parser.c:31113 cp/parser.c:33230 cp/parser.c:38350
+#: c/gimple-parser.c:1096 cp/parser.c:28484 cp/parser.c:31010
+#: cp/parser.c:31040 cp/parser.c:31110 cp/parser.c:33227 cp/parser.c:38347
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "Bezeichner erwartet"
 
-#: c/c-parser.c:2995 cp/parser.c:18384
+#: c/c-parser.c:2995 cp/parser.c:18381
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "Komma am Ende der Aufzählungsliste"
@@ -35288,12 +35330,12 @@
 msgid "expected statement"
 msgstr "Anweisung erwartet"
 
-#: c/c-parser.c:5639 cp/parser.c:12516
+#: c/c-parser.c:5639 cp/parser.c:12513
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "geschweifte Klammern um leeren Körper in einer %<if%>-Anweisung empfohlen"
 
-#: c/c-parser.c:5681 cp/parser.c:12519
+#: c/c-parser.c:5681 cp/parser.c:12516
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "geschweifte Klammern um leeren Körper in einer %<else%>-Anweisung empfohlen"
@@ -35631,7 +35673,7 @@
 msgid "%<__builtin_complex%> operands of different types"
 msgstr "Operanden von %<__builtin_complex%> unterschiedlichen Typs"
 
-#: c/c-parser.c:8891 cp/parser.c:6918
+#: c/c-parser.c:8891 cp/parser.c:6921
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_shuffle%>"
 msgstr "falsche Anzahl der Argumente für %<__builtin_shuffle%>"
@@ -35691,76 +35733,76 @@
 msgid "no type or storage class may be specified here,"
 msgstr "hier darf kein Typ oder Speicherklasse angegeben werden,"
 
-#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31073
+#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31070
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "unbekanntes Eigenschaftsattribut"
 
-#: c/c-parser.c:10682 cp/parser.c:31033
+#: c/c-parser.c:10682 cp/parser.c:31030
 #, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "fehlendes %<=%> (hinter Attribut %<getter%>)"
 
-#: c/c-parser.c:10685 cp/parser.c:31036
+#: c/c-parser.c:10685 cp/parser.c:31033
 #, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "fehlendes %<=%> (hinter Attribut %<setter%>)"
 
-#: c/c-parser.c:10699 cp/parser.c:31051
+#: c/c-parser.c:10699 cp/parser.c:31048
 #, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "das %<setter%>-Attribut darf nur einmal angegeben werden"
 
-#: c/c-parser.c:10704 cp/parser.c:31057
+#: c/c-parser.c:10704 cp/parser.c:31054
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr "Setter-Name muss mit %<:%> beendet werden"
 
-#: c/c-parser.c:10711 cp/parser.c:31065
+#: c/c-parser.c:10711 cp/parser.c:31062
 #, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "das %<getter%>-Attribut darf nur einmal angegeben werden"
 
-#: c/c-parser.c:10905 cp/parser.c:38674
+#: c/c-parser.c:10905 cp/parser.c:38671
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr "%<#pragma GCC unroll%> erfordert einen Zuweisungsausdruck, der zu einer nichtnegativen Ganzzahlkonstante kleiner als %u evaluiert"
 
 #: c/c-parser.c:10949 c/c-parser.c:16582 c/c-parser.c:16840 c/c-parser.c:16899
-#: c/c-parser.c:16983 cp/parser.c:36004 cp/parser.c:36298 cp/parser.c:36386
-#: cp/parser.c:36457 cp/parser.c:38721 cp/parser.c:38736 cp/parser.c:38752
-#: cp/parser.c:38768 cp/parser.c:38784 cp/parser.c:38811 cp/parser.c:38824
-#: cp/parser.c:38847 cp/parser.c:38860
+#: c/c-parser.c:16983 cp/parser.c:36001 cp/parser.c:36295 cp/parser.c:36383
+#: cp/parser.c:36454 cp/parser.c:38718 cp/parser.c:38733 cp/parser.c:38749
+#: cp/parser.c:38765 cp/parser.c:38781 cp/parser.c:38808 cp/parser.c:38821
+#: cp/parser.c:38844 cp/parser.c:38857
 #, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<#pragma %s%> darf nur in Verbundanweisungen verwendet werden"
 
-#: c/c-parser.c:10972 cp/parser.c:38837
+#: c/c-parser.c:10972 cp/parser.c:38834
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<#pragma acc routine%> darf nur im Datei-Gültigkeitsbereich auftreten"
 
-#: c/c-parser.c:11050 cp/parser.c:38918
+#: c/c-parser.c:11050 cp/parser.c:38915
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<#pragma omp section%> darf nur in %<#pragma omp sections%>-Konstrukt verwendet werden"
 
-#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38947 cp/parser.c:38980
+#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38944 cp/parser.c:38977
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "for-, while- oder do-Anweisung erwartet"
 
-#: c/c-parser.c:11111 cp/parser.c:38711
+#: c/c-parser.c:11111 cp/parser.c:38708
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%> muss zuerst kommen"
 
-#: c/c-parser.c:11421 cp/parser.c:31457
+#: c/c-parser.c:11421 cp/parser.c:31454
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "zu viele %qs-Klauseln"
 
-#: c/c-parser.c:11443 cp/parser.c:31994
+#: c/c-parser.c:11443 cp/parser.c:31991
 #, gcc-internal-format
 msgid "expected integer expression before ')'"
 msgstr "Ganzzahlausdruck vor »)« erwartet"
@@ -35775,53 +35817,53 @@
 msgid "%qD is not a variable"
 msgstr "%qD ist keine Variable"
 
-#: c/c-parser.c:11746 cp/semantics.c:6808
+#: c/c-parser.c:11746 cp/semantics.c:6811
 #, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "%qD ist keine Zeigervariable"
 
-#: c/c-parser.c:11788 cp/parser.c:32073
+#: c/c-parser.c:11788 cp/parser.c:32070
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr "Collapse-Argument erfordert positiven konstanten Ganzzahlausdruck"
 
-#: c/c-parser.c:11865 cp/parser.c:32137
+#: c/c-parser.c:11865 cp/parser.c:32134
 #, gcc-internal-format
 msgid "expected %<none%> or %<present%>"
 msgstr "%<none%> oder %<present%> erwartet"
 
-#: c/c-parser.c:11867 cp/parser.c:32139
+#: c/c-parser.c:11867 cp/parser.c:32136
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "%<none%> oder %<shared%> erwartet"
 
-#: c/c-parser.c:11968 cp/parser.c:32242
+#: c/c-parser.c:11968 cp/parser.c:32239
 #, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "%<data%>, %<update%>, %<enter%> oder %<exit%> erwartet"
 
-#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32260
-#: cp/parser.c:36290 cp/parser.c:36378
+#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32257
+#: cp/parser.c:36287 cp/parser.c:36375
 #, gcc-internal-format
 msgid "expected %<data%>"
 msgstr "%<data%> erwartet"
 
-#: c/c-parser.c:12035 cp/parser.c:32313
+#: c/c-parser.c:12035 cp/parser.c:32310
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr "zu viele %<if%>-Klauseln mit %qs-Modifizierer"
 
-#: c/c-parser.c:12042 cp/parser.c:32320
+#: c/c-parser.c:12042 cp/parser.c:32317
 #, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr "zu viele %<if%>-Klauseln"
 
-#: c/c-parser.c:12044 cp/parser.c:32322
+#: c/c-parser.c:12044 cp/parser.c:32319
 #, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr "zu viele %<if%>-Klauseln ohne Modifizierer"
 
-#: c/c-parser.c:12050 cp/parser.c:32328
+#: c/c-parser.c:12050 cp/parser.c:32325
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr "wenn eine der %<if%>-Klauseln einen Modifizierer verwendet, müssen alle %<if%>-Klauseln Modifizierer verwenden"
@@ -35843,82 +35885,82 @@
 msgid "%<num_tasks%> value must be positive"
 msgstr "Wert von %<num_tasks%> muss positiv sein"
 
-#: c/c-parser.c:12229 cp/semantics.c:6992
+#: c/c-parser.c:12229 cp/semantics.c:6995
 #, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr "Wert von %<grainsize%> muss positiv sein"
 
-#: c/c-parser.c:12276 cp/semantics.c:7021
+#: c/c-parser.c:12276 cp/semantics.c:7024
 #, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr "Wert von %<priority%> muss positiv sein"
 
-#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32545 cp/parser.c:32552
+#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32542 cp/parser.c:32549
 #, gcc-internal-format
 msgid "expected %<tofrom%>"
 msgstr "%<tofrom%> erwartet"
 
-#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32561 cp/parser.c:32568
+#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32558 cp/parser.c:32565
 #, gcc-internal-format
 msgid "expected %<scalar%>"
 msgstr "%<scalar%> erwartet"
 
-#: c/c-parser.c:12425 cp/semantics.c:6299
+#: c/c-parser.c:12425 cp/semantics.c:6302
 #, gcc-internal-format
 msgid "%qs expression must be integral"
 msgstr "%qs-Ausdruck muss ganzzahlig sein"
 
-#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6331
+#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6334
 #, gcc-internal-format
 msgid "%qs value must be positive"
 msgstr "Wert %qs muss positiv sein"
 
-#: c/c-parser.c:12499 cp/parser.c:31853
+#: c/c-parser.c:12499 cp/parser.c:31850
 #, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "zu viele %<static%>-Argumente"
 
-#: c/c-parser.c:12533 cp/parser.c:31886
+#: c/c-parser.c:12533 cp/parser.c:31883
 #, gcc-internal-format
 msgid "unexpected argument"
 msgstr "unerwartetes Argument"
 
-#: c/c-parser.c:12699 cp/semantics.c:7120
+#: c/c-parser.c:12699 cp/semantics.c:7123
 #, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "%<tile%>-Argument muss eine positive, ganzzahlige Konstante sein"
 
-#: c/c-parser.c:12765 cp/parser.c:32626
+#: c/c-parser.c:12765 cp/parser.c:32623
 #, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr "%<ordered%>-Argument muss ein positiver, ganzzahliger Ausdruck sein"
 
-#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37643
+#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37640
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "%<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> oder Bezeichner erwartet"
 
-#: c/c-parser.c:12967 cp/parser.c:32840
+#: c/c-parser.c:12967 cp/parser.c:32837
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "widersprüchliche Modifizierer %<monotonic%> und %<nonmonotonic%> angegeben"
 
-#: c/c-parser.c:13021 cp/parser.c:32856
+#: c/c-parser.c:13021 cp/parser.c:32853
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "Ablauf %<runtime%> akzeptiert keinen Parameter %<chunk_size%>"
 
-#: c/c-parser.c:13025 cp/parser.c:32859
+#: c/c-parser.c:13025 cp/parser.c:32856
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "Ablauf %<auto%> akzeptiert keinen Parameter %<chunk_size%>"
 
-#: c/c-parser.c:13037 cp/semantics.c:6389
+#: c/c-parser.c:13037 cp/semantics.c:6392
 #, gcc-internal-format
 msgid "chunk size value must be positive"
 msgstr "Wert der Chunkgröße muss positiv sein"
 
-#: c/c-parser.c:13060 cp/parser.c:32879
+#: c/c-parser.c:13060 cp/parser.c:32876
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "ungültige Ablaufart"
@@ -35928,12 +35970,12 @@
 msgid "%<num_teams%> value must be positive"
 msgstr "Wert von %<num_teams%> muss positiv sein"
 
-#: c/c-parser.c:13226 cp/semantics.c:6479
+#: c/c-parser.c:13226 cp/semantics.c:6482
 #, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr "Wert von %<thread_limit%> muss positiv sein"
 
-#: c/c-parser.c:13271 cp/semantics.c:6589
+#: c/c-parser.c:13271 cp/semantics.c:6592
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr "Ausdruck für %<aligned%>-Klausel erfordert positiven konstanten Ganzzahlausdruck"
@@ -35953,17 +35995,17 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr "Ausdruck der %<simdlen%>-Klausel erfordert positiven konstanten Ganzzahlausdruck"
 
-#: c/c-parser.c:13584 cp/parser.c:33374 cp/parser.c:33599
+#: c/c-parser.c:13584 cp/parser.c:33371 cp/parser.c:33596
 #, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "ungültige Abhängigkeitsart"
 
-#: c/c-parser.c:13669 cp/parser.c:33447
+#: c/c-parser.c:13669 cp/parser.c:33444
 #, gcc-internal-format
 msgid "invalid map kind"
 msgstr "ungültige Zuordnungsart"
 
-#: c/c-parser.c:13767 cp/parser.c:33546
+#: c/c-parser.c:13767 cp/parser.c:33543
 #, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "ungültige »dist_schedule«-Art"
@@ -35973,67 +36015,67 @@
 msgid "invalid proc_bind kind"
 msgstr "ungültige »proc_bind«-Art"
 
-#: c/c-parser.c:14059 cp/parser.c:33825
+#: c/c-parser.c:14059 cp/parser.c:33822
 #, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr "Klausel %<#pragma acc%> erwartet"
 
-#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33836 cp/parser.c:34143
+#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33833 cp/parser.c:34140
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs ist für %qs ungültig"
 
-#: c/c-parser.c:14214 cp/parser.c:34010
+#: c/c-parser.c:14214 cp/parser.c:34007
 #, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "%qs muss die erste Klausel von %qs sein"
 
-#: c/c-parser.c:14334 cp/parser.c:34132
+#: c/c-parser.c:14334 cp/parser.c:34129
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "Klausel %<#pragma omp%> erwartet"
 
-#: c/c-parser.c:14472 cp/parser.c:36803
+#: c/c-parser.c:14472 cp/parser.c:36800
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr "keine gültigen Klauseln in %<#pragma acc declare%> angegeben"
 
-#: c/c-parser.c:14482 cp/parser.c:36813
+#: c/c-parser.c:14482 cp/parser.c:36810
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr "Arrayabschnitt in %<#pragma acc declare%>"
 
-#: c/c-parser.c:14502 cp/parser.c:36833
+#: c/c-parser.c:14502 cp/parser.c:36830
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr "In %<#pragma acc declare link%> muss %qD eine globale Variable sein"
 
-#: c/c-parser.c:14513 cp/parser.c:36844
+#: c/c-parser.c:14513 cp/parser.c:36841
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr "ungültige OpenACC-Klausel im Datei-Gültigkeitsbereich"
 
-#: c/c-parser.c:14520 cp/parser.c:36851
+#: c/c-parser.c:14520 cp/parser.c:36848
 #, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "ungültige Verwendung der %<extern%>-Variable %qD in %<#pragma acc declare%>"
 
-#: c/c-parser.c:14528 cp/parser.c:36859
+#: c/c-parser.c:14528 cp/parser.c:36856
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "ungültige Verwendung der %<global%>-Variable %qD in %<#pragma acc declare%>"
 
-#: c/c-parser.c:14540 cp/parser.c:36871
+#: c/c-parser.c:14540 cp/parser.c:36868
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr "Variable %qD wird in %<#pragma acc declare%> mehr als einmal verwendet"
 
-#: c/c-parser.c:14632 cp/parser.c:36957
+#: c/c-parser.c:14632 cp/parser.c:36954
 #, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "hinter %<#pragma acc %s%> wird %<data%> erwartet"
 
-#: c/c-parser.c:14648 cp/parser.c:36974
+#: c/c-parser.c:14648 cp/parser.c:36971
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr "%<#pragma acc %s data%> hat keine Datenverschiebeklausel"
@@ -36048,7 +36090,7 @@
 msgid "expected function name"
 msgstr "Funktionsname erwartet"
 
-#: c/c-parser.c:14893 cp/parser.c:38064
+#: c/c-parser.c:14893 cp/parser.c:38061
 #, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr "%qD bezeichnet keine Funktion"
@@ -36058,42 +36100,42 @@
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr "%<#pragma acc routine%> muss direkt vor einer Funktionsdeklaration oder -definition auftreten"
 
-#: c/c-parser.c:14953 cp/parser.c:38118 cp/parser.c:38160
+#: c/c-parser.c:14953 cp/parser.c:38115 cp/parser.c:38157
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr "%<#pragma acc routine%> muss direkt vor einer Deklaration oder Definition einer einzelnen Funktion auftreten"
 
-#: c/c-parser.c:14970 cp/parser.c:38174
+#: c/c-parser.c:14970 cp/parser.c:38171
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> already applied to %qD"
 msgstr "%<#pragma acc routine%> wird bereits auf %qD angewendet"
 
-#: c/c-parser.c:14979 cp/parser.c:38183
+#: c/c-parser.c:14979 cp/parser.c:38180
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr "%<#pragma acc routine%> muss vor Verwendung angewendet werden"
 
-#: c/c-parser.c:14980 cp/parser.c:38184
+#: c/c-parser.c:14980 cp/parser.c:38181
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<#pragma acc routine%> muss vor Definition angewendet werden"
 
-#: c/c-parser.c:15023 cp/parser.c:37152
+#: c/c-parser.c:15023 cp/parser.c:37149
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr "%<#pragma acc update%> muss mindestens eine %<device%>- oder %<host%>- or %<self%>-Klausel enthalten"
 
-#: c/c-parser.c:15435 cp/parser.c:34511 cp/parser.c:34537
+#: c/c-parser.c:15435 cp/parser.c:34508 cp/parser.c:34534
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "ungültige Form von %<#pragma omp atomic%>"
 
-#: c/c-parser.c:15439 cp/parser.c:34568 cp/parser.c:34584
+#: c/c-parser.c:15439 cp/parser.c:34565 cp/parser.c:34581
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "ungültiger Operator für %<#pragma omp atomic%>"
 
-#: c/c-parser.c:15488 cp/semantics.c:8401 cp/semantics.c:8411
+#: c/c-parser.c:15488 cp/semantics.c:8404 cp/semantics.c:8414
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr "%<#pragma omp atomic capture%> verwendet zwei unterschiedliche Ausdrücke für Speicher"
@@ -36103,22 +36145,22 @@
 msgid "expected %<(%> or end of line"
 msgstr "%<(%> oder Zeilenende erwartet"
 
-#: c/c-parser.c:15619 cp/parser.c:35103
+#: c/c-parser.c:15619 cp/parser.c:35100
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr "%<ordered%>-Klauselparameter ist weniger als %<collapse%>"
 
-#: c/c-parser.c:15630 cp/parser.c:35114
+#: c/c-parser.c:15630 cp/parser.c:35111
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr "%<linear%>-Klausel darf nicht zusammen mit %<ordered%>-Klausel mit einem Parameter angegeben werden"
 
-#: c/c-parser.c:15648 cp/parser.c:35141
+#: c/c-parser.c:15648 cp/parser.c:35138
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "für Anweisung erwartet"
 
-#: c/c-parser.c:15718 cp/semantics.c:8066 cp/semantics.c:8153
+#: c/c-parser.c:15718 cp/semantics.c:8069 cp/semantics.c:8156
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "Schleifendeklaration oder Initialisierung erwartet"
@@ -36128,72 +36170,72 @@
 msgid "not enough perfectly nested loops"
 msgstr "nicht genügend perfekt geschachtelte Schleifen"
 
-#: c/c-parser.c:15862 cp/parser.c:35364
+#: c/c-parser.c:15862 cp/parser.c:35361
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr "zusammengelegte Schleifen sind nicht perfekt geschachtelt"
 
-#: c/c-parser.c:15909 cp/parser.c:35184 cp/parser.c:35226 cp/pt.c:16385
+#: c/c-parser.c:15909 cp/parser.c:35181 cp/parser.c:35223 cp/pt.c:16407
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "Schleifenvariable %qD sollte nicht »firstprivate« sein"
 
-#: c/c-parser.c:16000 cp/parser.c:35437
+#: c/c-parser.c:16000 cp/parser.c:35434
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "%<ordered%>-Klausel mit Parameter darf nicht beim %qs-Konstruk angegeben werden"
 
-#: c/c-parser.c:16166 cp/parser.c:35600
+#: c/c-parser.c:16166 cp/parser.c:35597
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr "%<#pragma omp ordered%> mit %<depend%>-Klausel darf nur in Verbundanweisungen verwendet werden"
 
-#: c/c-parser.c:16374 cp/parser.c:35799
+#: c/c-parser.c:16374 cp/parser.c:35796
 #, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "%<for%> hinter %qs erwartet"
 
-#: c/c-parser.c:16573 cp/parser.c:35995
+#: c/c-parser.c:16573 cp/parser.c:35992
 #, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "%<point%> erwartet"
 
-#: c/c-parser.c:16793 cp/parser.c:36232
+#: c/c-parser.c:16793 cp/parser.c:36229
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target data%> mit Zuordnungstyp außer %<to%>, %<from%>, %<tofrom%> oder %<alloc%> an %<map%>-Klausel"
 
-#: c/c-parser.c:16806 cp/parser.c:36245
+#: c/c-parser.c:16806 cp/parser.c:36242
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp target data%> muss mindestens eine %<map%>-Klausel enthalten"
 
-#: c/c-parser.c:16853 cp/parser.c:36470
+#: c/c-parser.c:16853 cp/parser.c:36467
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr "%<#pragma omp target update%> muss mindestens eine %<from%>- oder %<to%>-Klausel enthalten"
 
-#: c/c-parser.c:16925 cp/parser.c:36325
+#: c/c-parser.c:16925 cp/parser.c:36322
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target enter data%> mit Zuordnungstyp außer %<to%> oder %<alloc%> an %<map%>-Klausel"
 
-#: c/c-parser.c:16937 cp/parser.c:36337
+#: c/c-parser.c:16937 cp/parser.c:36334
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp target enter data%> muss mindestens eine %<map%>-Klausel enthalten"
 
-#: c/c-parser.c:17011 cp/parser.c:36414
+#: c/c-parser.c:17011 cp/parser.c:36411
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr "%<#pragma omp target exit data%> mit Zuordnungstyp außer %<from%>, %<release%> oder %<delete%> an %<map%>-Klausel"
 
-#: c/c-parser.c:17024 cp/parser.c:36427
+#: c/c-parser.c:17024 cp/parser.c:36424
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp target exit data%> muss mindestens eine %<map%>-Klausel enthalten"
 
-#: c/c-parser.c:17238 cp/parser.c:36680
+#: c/c-parser.c:17238 cp/parser.c:36677
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target%> mit Zuordnungstyp außer %<to%>, %<from%>, %<tofrom%> oder %<alloc%> an %<map%>-Klausel"
@@ -36213,32 +36255,32 @@
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr "hinter %<#pragma omp declare simd%> muss direkt eine Funktionsdeklaration oder -definition stehen"
 
-#: c/c-parser.c:17395 cp/parser.c:37273
+#: c/c-parser.c:17395 cp/parser.c:37270
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr "hinter %<#pragma omp declare simd%> muss direkt eine einzelne Funktionsdeklaration oder -definition stehen"
 
-#: c/c-parser.c:17474 cp/parser.c:37343
+#: c/c-parser.c:17474 cp/parser.c:37340
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> with clauses in between %<#pragma omp declare target%> without clauses and %<#pragma omp end declare target%>"
 msgstr "%<#pragma omp declare target%> mit Klauseln zwischen %<#pragma omp declare target%> ohne Klauseln und %<#pragma omp end declare target%>"
 
-#: c/c-parser.c:17493 cp/parser.c:37362
+#: c/c-parser.c:17493 cp/parser.c:37359
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr "%qD ist sowohl in %<link%>- als auch %<to%>-Klauseln des Deklarationsziels angegeben"
 
-#: c/c-parser.c:17534 cp/parser.c:37409
+#: c/c-parser.c:17534 cp/parser.c:37406
 #, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "%<target%> erwartet"
 
-#: c/c-parser.c:17541 cp/parser.c:37416
+#: c/c-parser.c:17541 cp/parser.c:37413
 #, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "%<declare%> erwartet"
 
-#: c/c-parser.c:17547 cp/parser.c:37423
+#: c/c-parser.c:17547 cp/parser.c:37420
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr "%<#pragma opt end declare target%> ohne zugehöriges %<#pragma omp declare target%>"
@@ -36293,47 +36335,47 @@
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr "eins der Argumente für den Initialisierungsaufruf sollte %<&omp_priv%> sein"
 
-#: c/c-parser.c:17947 cp/parser.c:37868
+#: c/c-parser.c:17947 cp/parser.c:37865
 #, gcc-internal-format
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr "%<simd%> oder %<reduction%> oder %<target%> erwartet"
 
-#: c/c-parser.c:18162 cp/semantics.c:7531
+#: c/c-parser.c:18162 cp/semantics.c:7534
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE nach erster Verwendung als %<threadprivate%> deklariert"
 
-#: c/c-parser.c:18164 cp/semantics.c:7533
+#: c/c-parser.c:18164 cp/semantics.c:7536
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "automatische Variable %qE kann nicht %<threadprivate%> sein"
 
-#: c/c-parser.c:18168 cp/semantics.c:7535
+#: c/c-parser.c:18168 cp/semantics.c:7538
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%<threadprivate%> %qE hat unvollständigen Typen"
 
-#: c/c-parser.c:18368 cp/parser.c:38565
+#: c/c-parser.c:18368 cp/parser.c:38562
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr "%<__transaction_cancel%> ohne eingeschaltete Unterstützung für transaktionsbasierten Speicher"
 
-#: c/c-parser.c:18374 cp/parser.c:38571
+#: c/c-parser.c:18374 cp/parser.c:38568
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr "%<__transaction_cancel%> innerhalb eines %<__transaction_relaxed%>"
 
-#: c/c-parser.c:18383 cp/parser.c:38580
+#: c/c-parser.c:18383 cp/parser.c:38577
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr "äußeres %<__transaction_cancel%> nicht innerhalb des äußeren %<__transaction_atomic%>"
 
-#: c/c-parser.c:18385 cp/parser.c:38583
+#: c/c-parser.c:18385 cp/parser.c:38580
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr "  oder einer %<transaction_may_cancel_outer%>-Funktion"
 
-#: c/c-parser.c:18391 cp/parser.c:38589
+#: c/c-parser.c:18391 cp/parser.c:38586
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr "%<__transaction_cancel%> nicht innerhalb von %<__transaction_atomic%>"
@@ -36348,7 +36390,7 @@
 msgid "%qD has an incomplete type %qT"
 msgstr "%qD hat unvollständigen Typ %qT"
 
-#: c/c-typeck.c:237 c/c-typeck.c:9994 c/c-typeck.c:10036 cp/call.c:4147
+#: c/c-typeck.c:237 c/c-typeck.c:9999 c/c-typeck.c:10041 cp/call.c:4147
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "falsche Verwendung eines void-Ausdruckes"
@@ -36424,12 +36466,12 @@
 msgid "converting an array compound literal to a pointer is ill-formed in C++"
 msgstr "Umwandlung eines zusammengesetzten Arrayliterals ist in C++ ungültig"
 
-#: c/c-typeck.c:2417 c/c-typeck.c:8641
+#: c/c-typeck.c:2417 c/c-typeck.c:8646
 #, gcc-internal-format
 msgid "%qT has no member named %qE; did you mean %qE?"
 msgstr "%qT hat kein Element namens %qE; meinten Sie %qE?"
 
-#: c/c-typeck.c:2421 c/c-typeck.c:8645
+#: c/c-typeck.c:2421 c/c-typeck.c:8650
 #, gcc-internal-format
 msgid "%qT has no member named %qE"
 msgstr "%qT hat kein Element namens %qE"
@@ -36627,457 +36669,457 @@
 msgid "pointer to a function used in subtraction"
 msgstr "Zeiger auf eine Funktion in Subtraktion verwendet"
 
-#: c/c-typeck.c:3847
+#: c/c-typeck.c:3852
 #, gcc-internal-format
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "Arithmetik mit Zeiger auf unvollständigen Typen"
 
-#: c/c-typeck.c:3852 cp/typeck.c:5562
+#: c/c-typeck.c:3857 cp/typeck.c:5562
 #, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr "Arithmetik mit Zeiger auf leeres Aggregat"
 
-#: c/c-typeck.c:4283
+#: c/c-typeck.c:4288
 #, gcc-internal-format
 msgid "%<~%> on a boolean expression"
 msgstr "%<~%> auf booleschem Ausdruck"
 
-#: c/c-typeck.c:4287
+#: c/c-typeck.c:4292
 #, gcc-internal-format
 msgid "did you mean to use logical not?"
 msgstr "meinten Sie ein logisches Nicht (%<!%>)?"
 
-#: c/c-typeck.c:4296
+#: c/c-typeck.c:4301
 #, gcc-internal-format
 msgid "ISO C does not support %<~%> for complex conjugation"
 msgstr "ISO-C unterstützt nicht %<~%> für komplexe Konjugation"
 
-#: c/c-typeck.c:4335
+#: c/c-typeck.c:4340
 #, gcc-internal-format
 msgid "wrong type argument to unary exclamation mark"
 msgstr "Argument falschen Typs für unäres Ausrufungszeichen"
 
-#: c/c-typeck.c:4393
+#: c/c-typeck.c:4398
 #, gcc-internal-format
 msgid "increment of enumeration value is invalid in C++"
 msgstr "Schrittweite von Aufzählungswerten (enum) ist in C++ ungültig"
 
-#: c/c-typeck.c:4396
+#: c/c-typeck.c:4401
 #, gcc-internal-format
 msgid "decrement of enumeration value is invalid in C++"
 msgstr "Verringerung von Aufzählungswerten (enum) ist in C++ ungültig"
 
-#: c/c-typeck.c:4403
+#: c/c-typeck.c:4408
 #, gcc-internal-format
 msgid "increment of a boolean expression"
 msgstr "Inkrementieren eines booleschen Ausdrucks"
 
-#: c/c-typeck.c:4406
+#: c/c-typeck.c:4411
 #, gcc-internal-format
 msgid "decrement of a boolean expression"
 msgstr "Dekrementieren eines booleschen Ausdrucks"
 
-#: c/c-typeck.c:4422
+#: c/c-typeck.c:4427
 #, gcc-internal-format
 msgid "ISO C does not support %<++%> and %<--%> on complex types"
 msgstr "ISO-C unterstützt kein %<++%> und %<--%> für komplexe Typen"
 
-#: c/c-typeck.c:4447 c/c-typeck.c:4481
+#: c/c-typeck.c:4452 c/c-typeck.c:4486
 #, gcc-internal-format
 msgid "wrong type argument to increment"
 msgstr "Argument falschen Typs für Inkrementierung"
 
-#: c/c-typeck.c:4449 c/c-typeck.c:4484
+#: c/c-typeck.c:4454 c/c-typeck.c:4489
 #, gcc-internal-format
 msgid "wrong type argument to decrement"
 msgstr "Argument falschen Typs für Dekrementierung"
 
-#: c/c-typeck.c:4469
+#: c/c-typeck.c:4474
 #, gcc-internal-format
 msgid "increment of pointer to an incomplete type %qT"
 msgstr "Inkrementieren eines Zeigers auf unvollständigen Typ %qT"
 
-#: c/c-typeck.c:4473
+#: c/c-typeck.c:4478
 #, gcc-internal-format
 msgid "decrement of pointer to an incomplete type %qT"
 msgstr "Dekrementieren eines Zeigers auf unvollständigen Typ %qT"
 
-#: c/c-typeck.c:4577
+#: c/c-typeck.c:4582
 #, gcc-internal-format
 msgid "taking address of expression of type %<void%>"
 msgstr "Adresse des Ausdrucks des Typs %<void%> wird genommen"
 
-#: c/c-typeck.c:4636
+#: c/c-typeck.c:4641
 #, gcc-internal-format
 msgid "cannot take address of bit-field %qD"
 msgstr "die Adresse des Bit-Feldes %qD kann nicht ermittelt werden"
 
-#: c/c-typeck.c:4649
+#: c/c-typeck.c:4654
 #, gcc-internal-format
 msgid "cannot take address of scalar with reverse storage order"
 msgstr "Adresse eines Skalars mit umgekehrter Speicherreihenfolge kann nicht ermittelt werden"
 
-#: c/c-typeck.c:4657
+#: c/c-typeck.c:4662
 #, gcc-internal-format
 msgid "address of array with reverse scalar storage order requested"
 msgstr "Adresse eines Arrays mit umgekehrter Speicherreihenfolge angefordert"
 
-#: c/c-typeck.c:4838
+#: c/c-typeck.c:4843
 #, gcc-internal-format
 msgid "global register variable %qD used in nested function"
 msgstr "globale Register-Variable %qD in verschachtelter Funktion verwendet"
 
-#: c/c-typeck.c:4841
+#: c/c-typeck.c:4846
 #, gcc-internal-format
 msgid "register variable %qD used in nested function"
 msgstr "Register-Variable %qD in verschachtelter Funktion verwendet"
 
-#: c/c-typeck.c:4846
+#: c/c-typeck.c:4851
 #, gcc-internal-format
 msgid "address of global register variable %qD requested"
 msgstr "Adresse der globalen Variablen %qD angefordert"
 
-#: c/c-typeck.c:4848
+#: c/c-typeck.c:4853
 #, gcc-internal-format
 msgid "address of register variable %qD requested"
 msgstr "Adresse der Register-Variablen %qD angefordert"
 
-#: c/c-typeck.c:4951
+#: c/c-typeck.c:4956
 #, gcc-internal-format
 msgid "non-lvalue array in conditional expression"
 msgstr "Nicht-L-Wert-Array in bedingtem Ausdruck"
 
-#: c/c-typeck.c:5033
+#: c/c-typeck.c:5038
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other result of conditional"
 msgstr "implizite Umwandlung von %qT in %qT um an anderes Ergebnis von Bedingung anzupassen"
 
-#: c/c-typeck.c:5092 c/c-typeck.c:5098
+#: c/c-typeck.c:5097 c/c-typeck.c:5103
 #, gcc-internal-format
 msgid "operand of ?: changes signedness from %qT to %qT due to unsignedness of other operand"
 msgstr "Operand von ?: wechselt das Vorzeichen von %qT nach %qT, aufgrund der Vorzeichenlosigkeit des anderen Operanden"
 
-#: c/c-typeck.c:5115
+#: c/c-typeck.c:5120
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr with only one void side"
 msgstr "ISO-C verbietet bedingten Ausdruck mit nur einer void-Seite"
 
-#: c/c-typeck.c:5132
+#: c/c-typeck.c:5137
 #, gcc-internal-format
 msgid "pointers to disjoint address spaces used in conditional expression"
 msgstr "Zeiger auf disjunkte Adressräume in bedingtem Ausdruck verwendet"
 
-#: c/c-typeck.c:5143 c/c-typeck.c:5160
+#: c/c-typeck.c:5148 c/c-typeck.c:5165
 #, gcc-internal-format
 msgid "pointer to array loses qualifier in conditional expression"
 msgstr "Zeiger auf Array verliert durch den Bedingungsausdruck Qualifizierer"
 
-#: c/c-typeck.c:5148 c/c-typeck.c:5165
+#: c/c-typeck.c:5153 c/c-typeck.c:5170
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr between %<void *%> and function pointer"
 msgstr "ISO-C verbietet bedingten Ausdruck zwischen %<void *%> und Funktionszeiger"
 
-#: c/c-typeck.c:5178
+#: c/c-typeck.c:5183
 #, gcc-internal-format
 msgid "pointer type mismatch in conditional expression"
 msgstr "Zeigertyp passt nicht in bedingtem Ausdruck"
 
-#: c/c-typeck.c:5187 c/c-typeck.c:5198
+#: c/c-typeck.c:5192 c/c-typeck.c:5203
 #, gcc-internal-format
 msgid "pointer/integer type mismatch in conditional expression"
 msgstr "Zeiger-/Ganzzahltyp passt nicht in bedingtem Ausdruck"
 
-#: c/c-typeck.c:5336
+#: c/c-typeck.c:5341
 #, gcc-internal-format
 msgid "left-hand operand of comma expression has no effect"
 msgstr "linker Operand des Komma-Ausdrucks hat keinen Effekt"
 
-#: c/c-typeck.c:5354 c/c-typeck.c:10636
+#: c/c-typeck.c:5359 c/c-typeck.c:10641
 #, gcc-internal-format
 msgid "right-hand operand of comma expression has no effect"
 msgstr "rechter Operand des Komma-Ausdrucks hat keinen Effekt"
 
-#: c/c-typeck.c:5423
+#: c/c-typeck.c:5428
 msgid "cast adds %q#v qualifier to function type"
 msgstr "Typumwandlung fügt Qualifizierer %q#v zu Funktionstyp hinzu"
 
-#: c/c-typeck.c:5429
+#: c/c-typeck.c:5434
 msgid "cast discards %qv qualifier from pointer target type"
 msgstr "Typumwandlung streicht Qualifizierer %qv von Zeiger-Zieltyp"
 
-#: c/c-typeck.c:5464
+#: c/c-typeck.c:5469
 #, gcc-internal-format
 msgid "to be safe all intermediate pointers in cast from %qT to %qT must be %<const%> qualified"
 msgstr "zur Sicherheit müssen alle vorübergehenden Zeiger in Umwandlung von %qT in %qT mit %<const%> qualifiziert sein"
 
-#: c/c-typeck.c:5554
+#: c/c-typeck.c:5559
 #, gcc-internal-format
 msgid "cast specifies array type"
 msgstr "Typkonvertierung gibt Arraytyp an"
 
-#: c/c-typeck.c:5560
+#: c/c-typeck.c:5565
 #, gcc-internal-format
 msgid "cast specifies function type"
 msgstr "Typkonvertierung gibt Funktionstyp an"
 
-#: c/c-typeck.c:5575
+#: c/c-typeck.c:5580
 #, gcc-internal-format
 msgid "ISO C forbids casting nonscalar to the same type"
 msgstr "ISO-C verbietet Typkonvertierung von Nicht-Skalar auf selben Typen"
 
-#: c/c-typeck.c:5595
+#: c/c-typeck.c:5600
 #, gcc-internal-format
 msgid "ISO C forbids casts to union type"
 msgstr "ISO-C verbietet Typkonvertierung auf union-Typ"
 
-#: c/c-typeck.c:5605
+#: c/c-typeck.c:5610
 #, gcc-internal-format
 msgid "cast to union type from type not present in union"
 msgstr "Typkonvertierung in union-Typ von nicht in union vorhandenem Typen"
 
-#: c/c-typeck.c:5640
+#: c/c-typeck.c:5645
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint generic address space pointer"
 msgstr "Umwandlung in %s-Adressraumzeiger aus getrenntem allgemeinen Adressraumzeiger"
 
-#: c/c-typeck.c:5645
+#: c/c-typeck.c:5650
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to generic address space pointer from disjoint %s address space pointer"
 msgstr "Umwandlung in allgemeinen Adressraumzeiger von getrenntem %s-Adressraumzeiger"
 
-#: c/c-typeck.c:5650
+#: c/c-typeck.c:5655
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint %s address space pointer"
 msgstr "Umwandlung in %s-Adressraumzeiger von getrenntem %s-Adressraumzeiger"
 
-#: c/c-typeck.c:5670
+#: c/c-typeck.c:5675
 #, gcc-internal-format
 msgid "cast increases required alignment of target type"
 msgstr "Typkonvertierung erfordert Ausrichtung des Zieltyps"
 
-#: c/c-typeck.c:5681
+#: c/c-typeck.c:5686
 #, gcc-internal-format
 msgid "cast from pointer to integer of different size"
 msgstr "Typkonvertierung von Zeiger auf Ganzzahl anderer Breite"
 
-#: c/c-typeck.c:5686
+#: c/c-typeck.c:5691
 #, gcc-internal-format
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "Typumwandlung von Funktionsaufruf des Typs %qT in unpassenden Typen %qT"
 
-#: c/c-typeck.c:5695 cp/typeck.c:7811
+#: c/c-typeck.c:5700 cp/typeck.c:7811
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "Typkonvertierung in Zeiger von Ganzzahl anderer Breite"
 
-#: c/c-typeck.c:5709
+#: c/c-typeck.c:5714
 #, gcc-internal-format
 msgid "ISO C forbids conversion of function pointer to object pointer type"
 msgstr "ISO-C verbietet Konvertierung von Funktionszeigern in Objektzeigertyp"
 
-#: c/c-typeck.c:5718
+#: c/c-typeck.c:5723
 #, gcc-internal-format
 msgid "ISO C forbids conversion of object pointer to function pointer type"
 msgstr "ISO-C verbietet Konvertierung von Objektzeigertypen in Funktionszeigertyp"
 
-#: c/c-typeck.c:5728
+#: c/c-typeck.c:5733
 #, gcc-internal-format
 msgid "cast between incompatible function types from %qT to %qT"
 msgstr "unvollständiger Funktionstyp %qT kann nicht nach %qT umgewandelt werden"
 
-#: c/c-typeck.c:5815
+#: c/c-typeck.c:5820
 #, gcc-internal-format
 msgid "defining a type in a cast is invalid in C++"
 msgstr "Definition eines Typs in einer Umwandlung ist in C++ ungültig"
 
-#: c/c-typeck.c:5856
+#: c/c-typeck.c:5861
 #, gcc-internal-format
 msgid "assignment to expression with array type"
 msgstr "Zuweisung an Ausdruck von Arraytyp"
 
-#: c/c-typeck.c:5982
+#: c/c-typeck.c:5987
 #, gcc-internal-format
 msgid "enum conversion in assignment is invalid in C++"
 msgstr "enum-Umwandlung in Zuweisung ist in C++ ungültig"
 
-#: c/c-typeck.c:6180 c/c-typeck.c:6202 c/c-typeck.c:6226
+#: c/c-typeck.c:6185 c/c-typeck.c:6207 c/c-typeck.c:6231
 #, gcc-internal-format
 msgid "(near initialization for %qs)"
 msgstr "(nahe der Initialisierung für %qs)"
 
-#: c/c-typeck.c:6241
+#: c/c-typeck.c:6246
 #, gcc-internal-format
 msgid "array initialized from parenthesized string constant"
 msgstr "Array mit geklammerter Zeichenkettenkonstante initialisiert"
 
-#: c/c-typeck.c:6284 c/c-typeck.c:6476 c/c-typeck.c:6908
+#: c/c-typeck.c:6289 c/c-typeck.c:6481 c/c-typeck.c:6913
 #, gcc-internal-format
 msgid "expected %qT but argument is of type %qT"
 msgstr "%qT erwartet, aber Argument hat Typ %qT"
 
-#: c/c-typeck.c:6471
+#: c/c-typeck.c:6476
 #, gcc-internal-format
 msgid "enum conversion when passing argument %d of %qE is invalid in C++"
 msgstr "Enum-Umwandlung bei Übergabe des Arguments %d von %qE ist in C++ ungültig"
 
-#: c/c-typeck.c:6480
+#: c/c-typeck.c:6485
 #, gcc-internal-format
 msgid "enum conversion from %qT to %qT in assignment is invalid in C++"
 msgstr "enum-Umwandlung von %qT nach %qT in Zuweisung ist in C++ ungültig"
 
-#: c/c-typeck.c:6484
+#: c/c-typeck.c:6489
 #, gcc-internal-format
 msgid "enum conversion from %qT to %qT in initialization is invalid in C++"
 msgstr "enum-Umwandlung von %qT nach %qT in Initialisierung ist in C++ ungültig"
 
-#: c/c-typeck.c:6489
+#: c/c-typeck.c:6494
 #, gcc-internal-format
 msgid "enum conversion from %qT to %qT in return is invalid in C++"
 msgstr "enum-Umwandlung von %qT nach %qT in Rückgabe ist in C++ ungültig"
 
-#: c/c-typeck.c:6523
+#: c/c-typeck.c:6528
 #, gcc-internal-format
 msgid "cannot pass rvalue to reference parameter"
 msgstr "R-Wert kann nicht an Referenzparameter übergeben werden"
 
-#: c/c-typeck.c:6656 c/c-typeck.c:6942
+#: c/c-typeck.c:6661 c/c-typeck.c:6947
 msgid "passing argument %d of %qE makes %q#v qualified function pointer from unqualified"
 msgstr "Übergabe des Arguments %d von %qE erzeugt aus unqualifiziertem einen qualifizierten Funktionszeiger %q#v"
 
-#: c/c-typeck.c:6659 c/c-typeck.c:6945
+#: c/c-typeck.c:6664 c/c-typeck.c:6950
 msgid "assignment makes %q#v qualified function pointer from unqualified"
 msgstr "Zuweisung erzeugt aus unqualifiziertem einen qualifizierten Funktionszeiger %q#v"
 
-#: c/c-typeck.c:6662 c/c-typeck.c:6947
+#: c/c-typeck.c:6667 c/c-typeck.c:6952
 msgid "initialization makes %q#v qualified function pointer from unqualified"
 msgstr "Initialisierung erzeugt aus unqualifiziertem einen qualifizierten Funktionszeiger %q#v"
 
-#: c/c-typeck.c:6665 c/c-typeck.c:6949
+#: c/c-typeck.c:6670 c/c-typeck.c:6954
 msgid "return makes %q#v qualified function pointer from unqualified"
 msgstr "return erzeugt aus unqualifiziertem einen qualifizierten Funktionszeiger %q#v"
 
-#: c/c-typeck.c:6673 c/c-typeck.c:6840 c/c-typeck.c:6883
+#: c/c-typeck.c:6678 c/c-typeck.c:6845 c/c-typeck.c:6888
 msgid "passing argument %d of %qE discards %qv qualifier from pointer target type"
 msgstr "Übergabe des Arguments %d von %qE entfernt Kennzeichner %qv von Zeiger-Ziel-Typ"
 
-#: c/c-typeck.c:6675 c/c-typeck.c:6842 c/c-typeck.c:6885
+#: c/c-typeck.c:6680 c/c-typeck.c:6847 c/c-typeck.c:6890
 msgid "assignment discards %qv qualifier from pointer target type"
 msgstr "Zuweisung streicht Qualifizierer %qv von Zeiger-Zieltyp"
 
-#: c/c-typeck.c:6677 c/c-typeck.c:6844 c/c-typeck.c:6887
+#: c/c-typeck.c:6682 c/c-typeck.c:6849 c/c-typeck.c:6892
 msgid "initialization discards %qv qualifier from pointer target type"
 msgstr "Initialisierung streicht Qualifizierer %qv von Zeiger-Zieltyp"
 
-#: c/c-typeck.c:6679 c/c-typeck.c:6846 c/c-typeck.c:6889
+#: c/c-typeck.c:6684 c/c-typeck.c:6851 c/c-typeck.c:6894
 msgid "return discards %qv qualifier from pointer target type"
 msgstr "return streicht Qualifizierer %qv von Zeiger-Zieltyp"
 
-#: c/c-typeck.c:6688
+#: c/c-typeck.c:6693
 #, gcc-internal-format
 msgid "ISO C prohibits argument conversion to union type"
 msgstr "ISO-C verbietet Argumentkonvertierung in union-Typ"
 
-#: c/c-typeck.c:6750
+#: c/c-typeck.c:6755
 #, gcc-internal-format
 msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgstr "Anfrage zur impliziten für Umwandlung von %qT in %qT ist in C++ nicht erlaubt"
 
-#: c/c-typeck.c:6762
+#: c/c-typeck.c:6767
 #, gcc-internal-format
 msgid "passing argument %d of %qE from pointer to non-enclosed address space"
 msgstr "Übergabe des Arguments %d von %qE von Zeiger auf nicht eingeschlossenen Adressbereich"
 
-#: c/c-typeck.c:6766
+#: c/c-typeck.c:6771
 #, gcc-internal-format
 msgid "assignment from pointer to non-enclosed address space"
 msgstr "Zuweisung von Zeiger auf nicht eingeschlossenen Adressbereich"
 
-#: c/c-typeck.c:6770
+#: c/c-typeck.c:6775
 #, gcc-internal-format
 msgid "initialization from pointer to non-enclosed address space"
 msgstr "Initialisierung von Zeiger auf nicht enthaltenen Adressraum"
 
-#: c/c-typeck.c:6774
+#: c/c-typeck.c:6779
 #, gcc-internal-format
 msgid "return from pointer to non-enclosed address space"
 msgstr "Rückgabe von Pointer auf nicht enthaltenen Adressraum"
 
-#: c/c-typeck.c:6792
+#: c/c-typeck.c:6797
 #, gcc-internal-format
 msgid "argument %d of %qE might be a candidate for a format attribute"
 msgstr "Argument %d von %qE könnte Kandidat für Formatattribut sein"
 
-#: c/c-typeck.c:6798
+#: c/c-typeck.c:6803
 #, gcc-internal-format
 msgid "assignment left-hand side might be a candidate for a format attribute"
 msgstr "Links-Zuweisung könnte Kandidat für Formatattribut sein"
 
-#: c/c-typeck.c:6803
+#: c/c-typeck.c:6808
 #, gcc-internal-format
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "Linke-Initialisierung könnte Kandidat für Formatattribut sein"
 
-#: c/c-typeck.c:6808 cp/typeck.c:8891
+#: c/c-typeck.c:6813 cp/typeck.c:8891
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "Rückgabetyp könnte Kandidat für Formatattribut sein"
 
-#: c/c-typeck.c:6857
+#: c/c-typeck.c:6862
 #, gcc-internal-format
 msgid "ISO C forbids passing argument %d of %qE between function pointer and %<void *%>"
 msgstr "ISO-C verbietet Übergabe des Arguments %d von %qE zwischen Funktionszeiger und %<void *%>"
 
-#: c/c-typeck.c:6860
+#: c/c-typeck.c:6865
 #, gcc-internal-format
 msgid "ISO C forbids assignment between function pointer and %<void *%>"
 msgstr "ISO-C verbietet Zuweisung zwischen Funktionszeiger und %<void *%>"
 
-#: c/c-typeck.c:6862
+#: c/c-typeck.c:6867
 #, gcc-internal-format
 msgid "ISO C forbids initialization between function pointer and %<void *%>"
 msgstr "ISO-C verbietet Initialisierung zwischen Funktionszeiger und %<void *%>"
 
-#: c/c-typeck.c:6864
+#: c/c-typeck.c:6869
 #, gcc-internal-format
 msgid "ISO C forbids return between function pointer and %<void *%>"
 msgstr "ISO-C verbietet return zwischen Funktionszeiger und %<void *%>"
 
-#: c/c-typeck.c:6904
+#: c/c-typeck.c:6909
 #, gcc-internal-format
 msgid "pointer targets in passing argument %d of %qE differ in signedness"
 msgstr "Zeigerziele bei Übergabe des Arguments %d von %qE unterscheiden sich im Vorzeichenbesitz"
 
-#: c/c-typeck.c:6913
+#: c/c-typeck.c:6918
 #, gcc-internal-format
 msgid "pointer targets in assignment from %qT to %qT differ in signedness"
 msgstr "Zeigerziele in Zuweisung von %qT nach %qT unterscheiden sich im Vorzeichenbesitz"
 
-#: c/c-typeck.c:6918
+#: c/c-typeck.c:6923
 #, gcc-internal-format
 msgid "pointer targets in initialization of %qT from %qT differ in signedness"
 msgstr "Zeigerziele in Initialisierung von %qT nach %qT unterscheiden sich im Vorzeichenbesitz"
 
-#: c/c-typeck.c:6923
+#: c/c-typeck.c:6928
 #, gcc-internal-format
 msgid "pointer targets in returning %qT from a function with return type %qT differ in signedness"
 msgstr "Zeigerziele in Rückgabe von %qT aus einer Funktion mit Rückgabetyp %qT unterscheiden sich im Vorzeichenbesitz"
 
-#: c/c-typeck.c:6961
+#: c/c-typeck.c:6966
 #, gcc-internal-format
 msgid "passing argument %d of %qE from incompatible pointer type"
 msgstr "Übergabe des Arguments %d von %qE von inkompatiblem Zeigertyp"
 
-#: c/c-typeck.c:6967
+#: c/c-typeck.c:6972
 #, gcc-internal-format
 msgid "assignment to %qT from incompatible pointer type %qT"
 msgstr "Zuweisung an %qT von inkompatiblem Zeigertyp %qT"
 
-#: c/c-typeck.c:6972
+#: c/c-typeck.c:6977
 #, gcc-internal-format
 msgid "initialization of %qT from incompatible pointer type %qT"
 msgstr "Initialisierung von %qT von inkompatiblem Zeigertyp %qT"
 
-#: c/c-typeck.c:6977
+#: c/c-typeck.c:6982
 #, gcc-internal-format
 msgid "returning %qT from a function with incompatible return type %qT"
 msgstr "Rückgabe von %qT aus einer Funktion mit inkompatiblem Rückgabetyp %qT"
@@ -37084,782 +37126,782 @@
 
 #. ??? This should not be an error when inlining calls to
 #. unprototyped functions.
-#: c/c-typeck.c:6991 c/c-typeck.c:7514 cp/typeck.c:2063
+#: c/c-typeck.c:6996 c/c-typeck.c:7519 cp/typeck.c:2063
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "ungültige Verwendung eines Nicht-L-Wert-Arrays"
 
-#: c/c-typeck.c:7004
+#: c/c-typeck.c:7009
 #, gcc-internal-format
 msgid "passing argument %d of %qE makes pointer from integer without a cast"
 msgstr "Übergabe des Arguments %d von %qE wandelt eine Zahl in einen Zeiger um, ohne explizite Typkonvertierung"
 
-#: c/c-typeck.c:7010
+#: c/c-typeck.c:7015
 #, gcc-internal-format
 msgid "assignment to %qT from %qT makes pointer from integer without a cast"
 msgstr "Zuweisung an %qT von %qT wandelt eine Zahl in einen Zeiger um, ohne explizite Typkonvertierung"
 
-#: c/c-typeck.c:7015
+#: c/c-typeck.c:7020
 #, gcc-internal-format
 msgid "initialization of %qT from %qT makes pointer from integer without a cast"
 msgstr "Initialisierung von %qT von %qT wandelt eine Zahl in einen Zeiger um, ohne explizite Typkonvertierung"
 
-#: c/c-typeck.c:7019
+#: c/c-typeck.c:7024
 #, gcc-internal-format
 msgid "returning %qT from a function with return type %qT makes pointer from integer without a cast"
 msgstr "Rückgabe von %qT aus einer Funktion mit Rückgabetyp %qT wandelt eine Zahl in einen Zeiger um, ohne explizite Typkonvertierung"
 
-#: c/c-typeck.c:7035
+#: c/c-typeck.c:7040
 #, gcc-internal-format
 msgid "passing argument %d of %qE makes integer from pointer without a cast"
 msgstr "Übergabe des Arguments %d von %qE wandelt eine Zahl in einen Zeiger um, ohne explizite Typkonvertierung"
 
-#: c/c-typeck.c:7041
+#: c/c-typeck.c:7046
 #, gcc-internal-format
 msgid "assignment to %qT from %qT makes integer from pointer without a cast"
 msgstr "Zuweisung an %qT aus %qT wandelt einen Zeiger in eine Ganzzahl um, ohne explizite Typkonvertierung"
 
-#: c/c-typeck.c:7046
+#: c/c-typeck.c:7051
 #, gcc-internal-format
 msgid "initialization of %qT from %qT makes integer from pointer without a cast"
 msgstr "Initialisierung eines %qT aus %qT wandelt einen Zeiger in eine Zahl um, ohne explizite Typkonvertierung"
 
-#: c/c-typeck.c:7050
+#: c/c-typeck.c:7055
 #, gcc-internal-format
 msgid "returning %qT from a function with return type %qT makes integer from pointer without a cast"
 msgstr "Rückgabe von %qT aus einer Funktion mit Rückgabetyp %qT wandelt einen Zeiger in eine Zahl um, ohne explizite Typkonvertierung"
 
-#: c/c-typeck.c:7073
+#: c/c-typeck.c:7078
 #, gcc-internal-format
 msgid "incompatible type for argument %d of %qE"
 msgstr "Inkompatibler Typ für Argument %d von %qE"
 
-#: c/c-typeck.c:7078
+#: c/c-typeck.c:7083
 #, gcc-internal-format
 msgid "incompatible types when assigning to type %qT from type %qT"
 msgstr "unverträgliche Typen bei Zuweisung an Typ %qT von Typ %qT"
 
-#: c/c-typeck.c:7083
+#: c/c-typeck.c:7088
 #, gcc-internal-format
 msgid "incompatible types when initializing type %qT using type %qT"
 msgstr "inkompatible Typen bei Initialisierung von Typ %qT mit Typ %qT"
 
-#: c/c-typeck.c:7088
+#: c/c-typeck.c:7093
 #, gcc-internal-format
 msgid "incompatible types when returning type %qT but %qT was expected"
 msgstr "unverträgliche Typen bei Rückgabe von Typ %qT, aber %qT wurde erwartet"
 
-#: c/c-typeck.c:7152
+#: c/c-typeck.c:7157
 #, gcc-internal-format
 msgid "traditional C rejects automatic aggregate initialization"
 msgstr "traditionelles C lehnt automatische Gesamt-Initialisierung ab"
 
-#: c/c-typeck.c:7388 c/c-typeck.c:8284 cp/typeck2.c:1045
+#: c/c-typeck.c:7393 c/c-typeck.c:8289 cp/typeck2.c:1045
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "Initialisierung eines flexiblen Array-Elements"
 
-#: c/c-typeck.c:7398 cp/typeck2.c:1059
+#: c/c-typeck.c:7403 cp/typeck2.c:1059
 #, gcc-internal-format
 msgid "char-array initialized from wide string"
 msgstr "char-Array mit wide-Zeichenkette initialisiert"
 
-#: c/c-typeck.c:7407
+#: c/c-typeck.c:7412
 #, gcc-internal-format
 msgid "wide character array initialized from non-wide string"
 msgstr "Array von wide character mit Nicht-wide-Zeichenkette initialisiert"
 
-#: c/c-typeck.c:7413
+#: c/c-typeck.c:7418
 #, gcc-internal-format
 msgid "wide character array initialized from incompatible wide string"
 msgstr "Array von wide character mit unverträglicher wide-Zeichenkette initialisiert"
 
-#: c/c-typeck.c:7446
+#: c/c-typeck.c:7451
 #, gcc-internal-format
 msgid "array of inappropriate type initialized from string constant"
 msgstr "Array unpassenden Typs mit Zeichenkettenkonstante initialisiert"
 
-#: c/c-typeck.c:7533 c/c-typeck.c:7557 c/c-typeck.c:7560 c/c-typeck.c:7568
-#: c/c-typeck.c:7608 c/c-typeck.c:9131 c/c-typeck.c:9181
+#: c/c-typeck.c:7538 c/c-typeck.c:7562 c/c-typeck.c:7565 c/c-typeck.c:7573
+#: c/c-typeck.c:7613 c/c-typeck.c:9136 c/c-typeck.c:9186
 #, gcc-internal-format
 msgid "initializer element is not constant"
 msgstr "Initialisierungselement ist nicht konstant"
 
-#: c/c-typeck.c:7542
+#: c/c-typeck.c:7547
 #, gcc-internal-format
 msgid "array initialized from non-constant array expression"
 msgstr "Array mit nicht konstantem Arrayausdruck initialisiert"
 
-#: c/c-typeck.c:7573 c/c-typeck.c:7621 c/c-typeck.c:9191
+#: c/c-typeck.c:7578 c/c-typeck.c:7626 c/c-typeck.c:9196
 #, gcc-internal-format
 msgid "initializer element is not a constant expression"
 msgstr "Initialisierungselement ist kein konstanter Ausdruck"
 
-#: c/c-typeck.c:7615 c/c-typeck.c:9186
+#: c/c-typeck.c:7620 c/c-typeck.c:9191
 #, gcc-internal-format
 msgid "initializer element is not computable at load time"
 msgstr "Initialisierungs-Element ist zur Lade-Zeit nicht berechenbar"
 
-#: c/c-typeck.c:7634
+#: c/c-typeck.c:7639
 #, gcc-internal-format
 msgid "invalid initializer"
 msgstr "ungültige Initialisierung"
 
-#: c/c-typeck.c:7912 cp/decl.c:6396
+#: c/c-typeck.c:7917 cp/decl.c:6396
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "opake Vektortypen können nicht initialisiert werden"
 
-#: c/c-typeck.c:8132
+#: c/c-typeck.c:8137
 #, gcc-internal-format
 msgid "extra brace group at end of initializer"
 msgstr "zusätzliche geschweifte Klammern am Ende der Initialisierung"
 
-#: c/c-typeck.c:8215
+#: c/c-typeck.c:8220
 #, gcc-internal-format
 msgid "braces around scalar initializer"
 msgstr "geschweifte Klammern um Skalar-Initialisierung"
 
-#: c/c-typeck.c:8281 c/c-typeck.c:9615 cp/typeck2.c:1084 cp/typeck2.c:1297
+#: c/c-typeck.c:8286 c/c-typeck.c:9620 cp/typeck2.c:1084 cp/typeck2.c:1297
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "Initialisierung eines flexiblen Array-Elements in geschachteltem Kontext"
 
-#: c/c-typeck.c:8318
+#: c/c-typeck.c:8323
 #, gcc-internal-format
 msgid "missing braces around initializer"
 msgstr "geschweifte Klammern fehlen um Initialisierung"
 
-#: c/c-typeck.c:8341
+#: c/c-typeck.c:8346
 #, gcc-internal-format
 msgid "missing initializer for field %qD of %qT"
 msgstr "fehlende Initialisierung für Feld %qD von %qT fehlt"
 
-#: c/c-typeck.c:8365
+#: c/c-typeck.c:8370
 #, gcc-internal-format
 msgid "empty scalar initializer"
 msgstr "leere Skalar-Initialisierung"
 
-#: c/c-typeck.c:8370
+#: c/c-typeck.c:8375
 #, gcc-internal-format
 msgid "extra elements in scalar initializer"
 msgstr "zusätzliche Elemente in Skalar-Initialisierung"
 
-#: c/c-typeck.c:8483 c/c-typeck.c:8565
+#: c/c-typeck.c:8488 c/c-typeck.c:8570
 #, gcc-internal-format
 msgid "array index in non-array initializer"
 msgstr "Arrayindex in Nicht-Array-Initialisierung"
 
-#: c/c-typeck.c:8488 c/c-typeck.c:8627
+#: c/c-typeck.c:8493 c/c-typeck.c:8632
 #, gcc-internal-format
 msgid "field name not in record or union initializer"
 msgstr "Feldname nicht in Datensatz- oder union-Initialisierung"
 
-#: c/c-typeck.c:8538
+#: c/c-typeck.c:8543
 #, gcc-internal-format
 msgid "array index in initializer not of integer type"
 msgstr "Arrayindex in Initialisierung hat nicht Ganzzahltyp"
 
-#: c/c-typeck.c:8547 c/c-typeck.c:8556
+#: c/c-typeck.c:8552 c/c-typeck.c:8561
 #, gcc-internal-format
 msgid "array index in initializer is not an integer constant expression"
 msgstr "Arrayindex in Initialisierung ist kein konstanter Ganzzahlausdruck"
 
-#: c/c-typeck.c:8561 c/c-typeck.c:8563
+#: c/c-typeck.c:8566 c/c-typeck.c:8568
 #, gcc-internal-format
 msgid "nonconstant array index in initializer"
 msgstr "nichtkonstanter Arrayindex in Initialisierung"
 
-#: c/c-typeck.c:8567 c/c-typeck.c:8570
+#: c/c-typeck.c:8572 c/c-typeck.c:8575
 #, gcc-internal-format
 msgid "array index in initializer exceeds array bounds"
 msgstr "Arrayindex in Initialisierung überschreitet Arraygrenzen"
 
-#: c/c-typeck.c:8589
+#: c/c-typeck.c:8594
 #, gcc-internal-format
 msgid "empty index range in initializer"
 msgstr "leerer Indexbereich in Initialisierung"
 
-#: c/c-typeck.c:8598
+#: c/c-typeck.c:8603
 #, gcc-internal-format
 msgid "array index range in initializer exceeds array bounds"
 msgstr "Arrayindexbereich in Initialisierung überschreitet Arraygrenzen"
 
-#: c/c-typeck.c:8700 c/c-typeck.c:8730 c/c-typeck.c:9274
+#: c/c-typeck.c:8705 c/c-typeck.c:8735 c/c-typeck.c:9279
 #, gcc-internal-format
 msgid "initialized field with side-effects overwritten"
 msgstr "initialisiertes Feld mit Seiteneffekten überschrieben"
 
-#: c/c-typeck.c:8704 c/c-typeck.c:8734 c/c-typeck.c:9277
+#: c/c-typeck.c:8709 c/c-typeck.c:8739 c/c-typeck.c:9282
 #, gcc-internal-format
 msgid "initialized field overwritten"
 msgstr "initialisiertes Feld überschrieben"
 
-#: c/c-typeck.c:9208
+#: c/c-typeck.c:9213
 #, gcc-internal-format
 msgid "enum conversion in initialization is invalid in C++"
 msgstr "enum-Umwandlung in Initialisierung ist in C++ ungültig"
 
-#: c/c-typeck.c:9496
+#: c/c-typeck.c:9501
 #, gcc-internal-format
 msgid "excess elements in char array initializer"
 msgstr "Elementüberschreitung in char-Array-Initialisierung"
 
-#: c/c-typeck.c:9503 c/c-typeck.c:9574
+#: c/c-typeck.c:9508 c/c-typeck.c:9579
 #, gcc-internal-format
 msgid "excess elements in struct initializer"
 msgstr "Elementüberschreitung in struct-Initialisierung"
 
-#: c/c-typeck.c:9518
+#: c/c-typeck.c:9523
 #, gcc-internal-format
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr "positionelle Initialisierung eines Feldes in %<struct%>, die mit dem %<designated_init%>-Attribut deklariert wurde"
 
-#: c/c-typeck.c:9589
+#: c/c-typeck.c:9594
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr "nicht-statische Initialisierung eines flexiblen Arrayelements"
 
-#: c/c-typeck.c:9687
+#: c/c-typeck.c:9692
 #, gcc-internal-format
 msgid "excess elements in union initializer"
 msgstr "Elementüberschreitung in union-Initialisierung"
 
-#: c/c-typeck.c:9709
+#: c/c-typeck.c:9714
 #, gcc-internal-format
 msgid "traditional C rejects initialization of unions"
 msgstr "traditionelles C lehnt Initialisierung von unions ab"
 
-#: c/c-typeck.c:9777
+#: c/c-typeck.c:9782
 #, gcc-internal-format
 msgid "excess elements in array initializer"
 msgstr "Elementüberschreitung in Arrayinitialisierung"
 
-#: c/c-typeck.c:9811
+#: c/c-typeck.c:9816
 #, gcc-internal-format
 msgid "excess elements in vector initializer"
 msgstr "Elementüberschreitung in Vektorinitialisierung"
 
-#: c/c-typeck.c:9843
+#: c/c-typeck.c:9848
 #, gcc-internal-format
 msgid "excess elements in scalar initializer"
 msgstr "Elementüberschreitung in Skalarinitialisierung"
 
-#: c/c-typeck.c:10086
+#: c/c-typeck.c:10091
 #, gcc-internal-format
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO-C verbietet %<goto *expr;%>"
 
-#: c/c-typeck.c:10113 c/gimple-parser.c:1604 cp/typeck.c:9113
+#: c/c-typeck.c:10118 c/gimple-parser.c:1604 cp/typeck.c:9113
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "als %<noreturn%> deklarierte Funktion hat %<return%>-Anweisung"
 
-#: c/c-typeck.c:10139 c/c-typeck.c:10143
+#: c/c-typeck.c:10144 c/c-typeck.c:10148
 #, gcc-internal-format
 msgid "%<return%> with no value, in function returning non-void"
 msgstr "%<return%> ohne Wert in nicht-void zurückgebender Funktion"
 
-#: c/c-typeck.c:10157 c/gimple-parser.c:1614
+#: c/c-typeck.c:10162 c/gimple-parser.c:1614
 #, gcc-internal-format
 msgid "%<return%> with a value, in function returning void"
 msgstr "%<return%> mit Wert in void zurückgebender Funktion"
 
-#: c/c-typeck.c:10160
+#: c/c-typeck.c:10165
 #, gcc-internal-format
 msgid "ISO C forbids %<return%> with expression, in function returning void"
 msgstr "ISO-C verbietet %<return%> mit Ausdruck, in void zurückgebender Funktion"
 
-#: c/c-typeck.c:10236
+#: c/c-typeck.c:10241
 #, gcc-internal-format
 msgid "function returns address of label"
 msgstr "Funktion liefert Adresse einer Sprungmarke zurück"
 
-#: c/c-typeck.c:10327 cp/semantics.c:1171
+#: c/c-typeck.c:10332 cp/semantics.c:1171
 #, gcc-internal-format
 msgid "switch quantity not an integer"
 msgstr "switch-Größe ist keine Ganzzahl"
 
-#: c/c-typeck.c:10352
+#: c/c-typeck.c:10357
 #, gcc-internal-format
 msgid "%<long%> switch expression not converted to %<int%> in ISO C"
 msgstr "%<long%> switch-Ausdruck nicht nach »int« konvertiert in ISO C"
 
-#: c/c-typeck.c:10390 c/c-typeck.c:10398
+#: c/c-typeck.c:10395 c/c-typeck.c:10403
 #, gcc-internal-format
 msgid "case label is not an integer constant expression"
 msgstr "»case«-Marke ist kein konstanter Ganzzahlausdruck"
 
-#: c/c-typeck.c:10404 cp/parser.c:11067
+#: c/c-typeck.c:10409 cp/parser.c:11067
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "case-Marke nicht innerhalb einer switch-Anweisung"
 
-#: c/c-typeck.c:10406
+#: c/c-typeck.c:10411
 #, gcc-internal-format
 msgid "%<default%> label not within a switch statement"
 msgstr "%<default%>-Marke nicht innerhalb einer switch-Anweisung"
 
-#: c/c-typeck.c:10578 cp/parser.c:12356
+#: c/c-typeck.c:10583 cp/parser.c:12353
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "break-Anweisung nicht innerhalb einer Schleife oder »switch«"
 
-#: c/c-typeck.c:10580 cp/parser.c:12379
+#: c/c-typeck.c:10585 cp/parser.c:12376
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "continue-Anweisung nicht innerhalb einer Schleife"
 
-#: c/c-typeck.c:10585 cp/parser.c:12369
+#: c/c-typeck.c:10590 cp/parser.c:12366
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr "break-Anweisung mit OpenMP für Schleife verwendet"
 
-#: c/c-typeck.c:10590
+#: c/c-typeck.c:10595
 #, gcc-internal-format
 msgid "break statement within %<#pragma simd%> loop body"
 msgstr "break-Anweisung innerhalb einer %<#pragma simd%>-Schleife"
 
-#: c/c-typeck.c:10592
+#: c/c-typeck.c:10597
 #, gcc-internal-format
 msgid "continue statement within %<#pragma simd%> loop body"
 msgstr "continue-Anweisung innerhalb einer %<#pragma simd%>-Schleife"
 
-#: c/c-typeck.c:10618 cp/cp-gimplify.c:432
+#: c/c-typeck.c:10623 cp/cp-gimplify.c:432
 #, gcc-internal-format
 msgid "statement with no effect"
 msgstr "Anweisung ohne Effekt"
 
-#: c/c-typeck.c:10662
+#: c/c-typeck.c:10667
 #, gcc-internal-format
 msgid "expression statement has incomplete type"
 msgstr "Ausdrucksanweisung hat unvollständigen Typ"
 
-#: c/c-typeck.c:11476 c/c-typeck.c:11644 cp/typeck.c:5017
+#: c/c-typeck.c:11481 c/c-typeck.c:11649 cp/typeck.c:5017
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr "Vergleich von Vektoren mit verschiedenen Element-Typen"
 
-#: c/c-typeck.c:11484 c/c-typeck.c:11652 cp/typeck.c:5030
+#: c/c-typeck.c:11489 c/c-typeck.c:11657 cp/typeck.c:5030
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr "Vergleich von Vektoren mit unterschiedlicher Elementanzahl"
 
-#: c/c-typeck.c:11509 c/c-typeck.c:11677 cp/typeck.c:5058
+#: c/c-typeck.c:11514 c/c-typeck.c:11682 cp/typeck.c:5058
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr "kein ganzzahliger Typ mit derselben Größe wie %qT gefunden"
 
-#: c/c-typeck.c:11523 cp/typeck.c:4743
+#: c/c-typeck.c:11528 cp/typeck.c:4743
 #, gcc-internal-format
 msgid "comparing floating point with == or != is unsafe"
 msgstr "Vergleich von Gleitkomma mit == oder != ist unsicher"
 
-#: c/c-typeck.c:11541 c/c-typeck.c:11562
+#: c/c-typeck.c:11546 c/c-typeck.c:11567
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<false%> for the address of %qD will never be NULL"
 msgstr "Vergleich wird stets als %<false%> ausgewertet da die Adresse von %qD nie NULL wird"
 
-#: c/c-typeck.c:11547 c/c-typeck.c:11568
+#: c/c-typeck.c:11552 c/c-typeck.c:11573
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<true%> for the address of %qD will never be NULL"
 msgstr "Vergleich wird stets als %<true%> ausgewertet da die Adresse von %qD nie NULL wird"
 
-#: c/c-typeck.c:11589 c/c-typeck.c:11718
+#: c/c-typeck.c:11594 c/c-typeck.c:11723
 #, gcc-internal-format
 msgid "comparison of pointers to disjoint address spaces"
 msgstr "Vergleich von Zeigern auf disjunkte Adressräume"
 
-#: c/c-typeck.c:11596 c/c-typeck.c:11602
+#: c/c-typeck.c:11601 c/c-typeck.c:11607
 #, gcc-internal-format
 msgid "ISO C forbids comparison of %<void *%> with function pointer"
 msgstr "ISO-C verbietet Vergleich von %<void *%> mit Funktionszeiger"
 
-#: c/c-typeck.c:11609 c/c-typeck.c:11728
+#: c/c-typeck.c:11614 c/c-typeck.c:11733
 #, gcc-internal-format
 msgid "comparison of distinct pointer types lacks a cast"
 msgstr "in Vergleich verschiedener Zeigertypen fehlt Typkonvertierung"
 
-#: c/c-typeck.c:11621 c/c-typeck.c:11626 c/c-typeck.c:11754 c/c-typeck.c:11759
+#: c/c-typeck.c:11626 c/c-typeck.c:11631 c/c-typeck.c:11759 c/c-typeck.c:11764
 #, gcc-internal-format
 msgid "comparison between pointer and integer"
 msgstr "Vergleich zwischen Zeiger und Ganzzahl"
 
-#: c/c-typeck.c:11706
+#: c/c-typeck.c:11711
 #, gcc-internal-format
 msgid "comparison of complete and incomplete pointers"
 msgstr "Vergleich von vollständigen und unvollständigen Zeigern"
 
-#: c/c-typeck.c:11708
+#: c/c-typeck.c:11713
 #, gcc-internal-format
 msgid "ISO C forbids ordered comparisons of pointers to functions"
 msgstr "ISO-C verbietet geordnete Vergleiche zwischen Zeigern auf Funktionen"
 
-#: c/c-typeck.c:11713
+#: c/c-typeck.c:11718
 #, gcc-internal-format
 msgid "ordered comparison of pointer with null pointer"
 msgstr "geordneter Vergleich von Zeiger mit Null-Zeiger"
 
-#: c/c-typeck.c:11736 c/c-typeck.c:11739 c/c-typeck.c:11746 c/c-typeck.c:11749
+#: c/c-typeck.c:11741 c/c-typeck.c:11744 c/c-typeck.c:11751 c/c-typeck.c:11754
 #: cp/typeck.c:5081 cp/typeck.c:5088
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "geordneter Vergleich von Zeiger mit Ganzzahlnull"
 
-#: c/c-typeck.c:11811
+#: c/c-typeck.c:11816
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
 msgstr "implizite Umwandlung von %qT in %qT zur Anpassung an anderen Operanden des Binärausdrucks"
 
-#: c/c-typeck.c:12126
+#: c/c-typeck.c:12131
 #, gcc-internal-format
 msgid "used array that cannot be converted to pointer where scalar is required"
 msgstr "Array, das nicht in Zeiger umgewandelt werden kann, anstelle des geforderten Skalars verwendet"
 
-#: c/c-typeck.c:12130
+#: c/c-typeck.c:12135
 #, gcc-internal-format
 msgid "used struct type value where scalar is required"
 msgstr "Wert eines struct-Typs anstelle des geforderten Skalars verwendet"
 
-#: c/c-typeck.c:12134
+#: c/c-typeck.c:12139
 #, gcc-internal-format
 msgid "used union type value where scalar is required"
 msgstr "Wert eines union-Typs anstelle des geforderten Skalars verwendet"
 
-#: c/c-typeck.c:12150
+#: c/c-typeck.c:12155
 #, gcc-internal-format
 msgid "used vector type where scalar is required"
 msgstr "Vektortyp verwendet, wo Skalars benötigt wird"
 
-#: c/c-typeck.c:12340 cp/semantics.c:8508
+#: c/c-typeck.c:12345 cp/semantics.c:8511
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp cancel%> muss eine der Klauseln %<parallel%>, %<for%>, %<sections%> oder %<taskgroup%> angeben"
 
-#: c/c-typeck.c:12379 cp/semantics.c:8545
+#: c/c-typeck.c:12384 cp/semantics.c:8548
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp cancellation point%> muss eine der Klauseln %<parallel%>, %<for%>, %<sections%> oder %<taskgroup%> angeben"
 
-#: c/c-typeck.c:12423 c/c-typeck.c:13581 c/c-typeck.c:13642 c/c-typeck.c:13704
+#: c/c-typeck.c:12428 c/c-typeck.c:13586 c/c-typeck.c:13647 c/c-typeck.c:13709
 #, gcc-internal-format
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "%<_Atomic%>-Ausdruck %qE in %qs-Klausel"
 
-#: c/c-typeck.c:12436 c/c-typeck.c:13628 cp/semantics.c:4546
-#: cp/semantics.c:6717
+#: c/c-typeck.c:12441 c/c-typeck.c:13633 cp/semantics.c:4549
+#: cp/semantics.c:6720
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr "Bitfeld %qE in %qs-Klausel"
 
-#: c/c-typeck.c:12445 c/c-typeck.c:13652 cp/semantics.c:4556
-#: cp/semantics.c:6735
+#: c/c-typeck.c:12450 c/c-typeck.c:13657 cp/semantics.c:4559
+#: cp/semantics.c:6738
 #, gcc-internal-format
 msgid "%qE is a member of a union"
 msgstr "%qE ist ein Element eines Union-Typs"
 
-#: c/c-typeck.c:12455 cp/semantics.c:4570 cp/semantics.c:6760
+#: c/c-typeck.c:12460 cp/semantics.c:4573 cp/semantics.c:6763
 #, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD in %qs-Klausel muss eine Variable sein"
 
-#: c/c-typeck.c:12459 c/c-typeck.c:13669 cp/semantics.c:4574
-#: cp/semantics.c:6763
+#: c/c-typeck.c:12464 c/c-typeck.c:13674 cp/semantics.c:4577
+#: cp/semantics.c:6766
 #, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qE in %qs-Klausel muss eine Variable sein"
 
-#: c/c-typeck.c:12466
+#: c/c-typeck.c:12471
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %qs clause"
 msgstr "%<_Atomic%>-Deklaration %qD in %qs-Klausel"
 
-#: c/c-typeck.c:12475 c/c-typeck.c:13676 c/c-typeck.c:13778
-#: cp/semantics.c:4591 cp/semantics.c:6769 cp/semantics.c:6931
+#: c/c-typeck.c:12480 c/c-typeck.c:13681 c/c-typeck.c:13783
+#: cp/semantics.c:4594 cp/semantics.c:6772 cp/semantics.c:6934
 #, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD in %qs-Klausel ist eine threadprivate Variable"
 
-#: c/c-typeck.c:12511 cp/semantics.c:4623
+#: c/c-typeck.c:12516 cp/semantics.c:4626
 #, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr "Untere Grenze %qE des Arrayabschnitts muss Ganzzahltyp haben"
 
-#: c/c-typeck.c:12518 cp/semantics.c:4630
+#: c/c-typeck.c:12523 cp/semantics.c:4633
 #, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr "Länge %qE des Arrayabschnitts muss Ganzzahltyp haben"
 
-#: c/c-typeck.c:12545 c/c-typeck.c:12609 c/c-typeck.c:12867
-#: cp/semantics.c:4666 cp/semantics.c:4730
+#: c/c-typeck.c:12550 c/c-typeck.c:12614 c/c-typeck.c:12872
+#: cp/semantics.c:4669 cp/semantics.c:4733
 #, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr "Arrayabschnitt der Länge 0 in %qs-Klausel"
 
-#: c/c-typeck.c:12564 cp/semantics.c:4685
+#: c/c-typeck.c:12569 cp/semantics.c:4688
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr "für Arraytyp mit unbekannten Grenzen muss ein Längenausdruck angegeben werden"
 
-#: c/c-typeck.c:12572 cp/semantics.c:4693
+#: c/c-typeck.c:12577 cp/semantics.c:4696
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr "negative untere Grenze in Arrayabschnitt in %qs-Klausel"
 
-#: c/c-typeck.c:12581 c/c-typeck.c:12691 cp/semantics.c:4702
-#: cp/semantics.c:4812
+#: c/c-typeck.c:12586 c/c-typeck.c:12696 cp/semantics.c:4705
+#: cp/semantics.c:4815
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr "Arrayabschnitt mit negativer Länge in %qs-Klausel"
 
-#: c/c-typeck.c:12598 cp/semantics.c:4719
+#: c/c-typeck.c:12603 cp/semantics.c:4722
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr "untere Grenze %qE geht über Abschnittsgröße in %qs-Klausel hinaus"
 
-#: c/c-typeck.c:12635 cp/semantics.c:4756
+#: c/c-typeck.c:12640 cp/semantics.c:4759
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr "Länge %qE geht über Abschnittsgröße in %qs-Klausel hinaus"
 
-#: c/c-typeck.c:12650 cp/semantics.c:4771
+#: c/c-typeck.c:12655 cp/semantics.c:4774
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr "obere Grenze %qE geht über Abschnittsgröße in %qs-Klausel hinaus"
 
-#: c/c-typeck.c:12683 cp/semantics.c:4804
+#: c/c-typeck.c:12688 cp/semantics.c:4807
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr "für Zeigertyp muss der Längenausdruck angegeben werden"
 
-#: c/c-typeck.c:12701 c/c-typeck.c:12810 cp/semantics.c:4822
-#: cp/semantics.c:4934
+#: c/c-typeck.c:12706 c/c-typeck.c:12815 cp/semantics.c:4825
+#: cp/semantics.c:4937
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr "Arrayabschnitt ist in %qs-Klausel nicht zusammenhängend"
 
-#: c/c-typeck.c:12709 cp/semantics.c:4830
+#: c/c-typeck.c:12714 cp/semantics.c:4833
 #, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr "%qE hat weder Zeiger- noch Arraytyp"
 
-#: c/c-typeck.c:13103 c/c-typeck.c:13113
+#: c/c-typeck.c:13108 c/c-typeck.c:13118
 #, gcc-internal-format
 msgid "%qD in %<reduction%> clause is a zero size array"
 msgstr "%qD in %<reduction%>-Klausel ist ein Array der Länge 0"
 
-#: c/c-typeck.c:13130
+#: c/c-typeck.c:13135
 #, gcc-internal-format
 msgid "%<_Atomic%> %qE in %<reduction%> clause"
 msgstr "%<_Atomic%> %qE in %<reduction%>-Klausel"
 
-#: c/c-typeck.c:13178
+#: c/c-typeck.c:13183
 #, gcc-internal-format
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "%qE hat ungültigen Typ für %<reduction(%s)%>"
 
-#: c/c-typeck.c:13187 cp/semantics.c:5755
+#: c/c-typeck.c:13192 cp/semantics.c:5758
 #, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr "benutzerdefinierte Reduktion für %qE nicht gefunden"
 
-#: c/c-typeck.c:13275
+#: c/c-typeck.c:13280
 #, gcc-internal-format
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "Elementtyp variabler Länge in %<reduction%>-Klausel eines Arrays"
 
-#: c/c-typeck.c:13293 c/c-typeck.c:13836 cp/semantics.c:7249
+#: c/c-typeck.c:13298 c/c-typeck.c:13841 cp/semantics.c:7252
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr "%<nowait%>-Klausel darf nicht zusammen mit %<copyprivate%> verwendet werden"
 
-#: c/c-typeck.c:13305 cp/semantics.c:7289
+#: c/c-typeck.c:13310 cp/semantics.c:7292
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE muss für %<copyin%> %<threadprivate%> sein"
 
-#: c/c-typeck.c:13319 cp/semantics.c:5929
+#: c/c-typeck.c:13324 cp/semantics.c:5932
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr "Modifizierer sollte an %<simd%>- oder %<for%>-Konstrukten nicht in %<linear%>-Klausel angegeben werden"
 
-#: c/c-typeck.c:13327
+#: c/c-typeck.c:13332
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with type %qT"
 msgstr "»linear«-Klausel auf Variable vom Typ %qT angewendet, die weder Ganzzahl noch Zeiger ist"
 
-#: c/c-typeck.c:13335
+#: c/c-typeck.c:13340
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr "%<_Atomic%> %qD in %<linear%>-Klausel"
 
-#: c/c-typeck.c:13354 cp/semantics.c:5999
+#: c/c-typeck.c:13359 cp/semantics.c:6002
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr "Schrittweite %qE der %<linear%>-Klausel muss konstant oder ein Parameter sein"
 
-#: c/c-typeck.c:13384 c/c-typeck.c:13771 cp/semantics.c:6083
-#: cp/semantics.c:6924
+#: c/c-typeck.c:13389 c/c-typeck.c:13776 cp/semantics.c:6086
+#: cp/semantics.c:6927
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE ist in Klausel %qs keine Variable"
 
-#: c/c-typeck.c:13393 cp/semantics.c:6092
+#: c/c-typeck.c:13398 cp/semantics.c:6095
 #, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr "%qD tritt in Reduktionsklauseln mehrfach auf"
 
-#: c/c-typeck.c:13404 c/c-typeck.c:13434 c/c-typeck.c:13463
+#: c/c-typeck.c:13409 c/c-typeck.c:13439 c/c-typeck.c:13468
 #, gcc-internal-format
 msgid "%qE appears more than once in data clauses"
 msgstr "%qE tritt in dieser Datenklausel mehrfach auf"
 
-#: c/c-typeck.c:13411 c/c-typeck.c:13440 c/c-typeck.c:13600 c/c-typeck.c:13714
-#: c/c-typeck.c:13720 c/c-typeck.c:13733 c/c-typeck.c:13742
-#: cp/semantics.c:6102 cp/semantics.c:6109 cp/semantics.c:6160
-#: cp/semantics.c:6166 cp/semantics.c:6203 cp/semantics.c:6680
-#: cp/semantics.c:6817 cp/semantics.c:6823 cp/semantics.c:6836
-#: cp/semantics.c:6845
+#: c/c-typeck.c:13416 c/c-typeck.c:13445 c/c-typeck.c:13605 c/c-typeck.c:13719
+#: c/c-typeck.c:13725 c/c-typeck.c:13738 c/c-typeck.c:13747
+#: cp/semantics.c:6105 cp/semantics.c:6112 cp/semantics.c:6163
+#: cp/semantics.c:6169 cp/semantics.c:6206 cp/semantics.c:6683
+#: cp/semantics.c:6820 cp/semantics.c:6826 cp/semantics.c:6839
+#: cp/semantics.c:6848
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr "%qD tritt in Datenklausel mehrfach auf"
 
-#: c/c-typeck.c:13413 c/c-typeck.c:13442 c/c-typeck.c:13722 c/c-typeck.c:13744
-#: cp/semantics.c:6111 cp/semantics.c:6168 cp/semantics.c:6825
-#: cp/semantics.c:6847
+#: c/c-typeck.c:13418 c/c-typeck.c:13447 c/c-typeck.c:13727 c/c-typeck.c:13749
+#: cp/semantics.c:6114 cp/semantics.c:6171 cp/semantics.c:6828
+#: cp/semantics.c:6850
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr "%qD tritt in Daten- und Zuordnungsklauseln mehrfach auf"
 
-#: c/c-typeck.c:13427 cp/semantics.c:6154
+#: c/c-typeck.c:13432 cp/semantics.c:6157
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "%qE ist in Klausel %<firstprivate%> keine Variable"
 
-#: c/c-typeck.c:13456 cp/semantics.c:6197
+#: c/c-typeck.c:13461 cp/semantics.c:6200
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "%qE ist in Klausel %<lastprivate%> keine Variable"
 
-#: c/c-typeck.c:13475 cp/semantics.c:6545
+#: c/c-typeck.c:13480 cp/semantics.c:6548
 #, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "%qE ist %<aligned%>-Klausel keine Variable"
 
-#: c/c-typeck.c:13482
+#: c/c-typeck.c:13487
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array"
 msgstr "%qE in %<aligned%>-Klausel ist weder Zeiger noch Array"
 
-#: c/c-typeck.c:13489
+#: c/c-typeck.c:13494
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<aligned%> clause"
 msgstr "%<_Atomic%> %qD in %<aligned%>-Klausel"
 
-#: c/c-typeck.c:13496
+#: c/c-typeck.c:13501
 #, gcc-internal-format
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr "%qE tritt in %<aligned%>-Klausel mehrfach auf"
 
-#: c/c-typeck.c:13551 cp/semantics.c:6627
+#: c/c-typeck.c:13556 cp/semantics.c:6630
 #, gcc-internal-format
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr "%qE ist in %<depends%>-Klausel keine Variable"
 
-#: c/c-typeck.c:13573 cp/semantics.c:6658
+#: c/c-typeck.c:13578 cp/semantics.c:6661
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr "Arrayabschnitt in %qs-Klausel hat keinen zuordenbaren Typ"
 
-#: c/c-typeck.c:13597 c/c-typeck.c:13731 cp/semantics.c:6677
-#: cp/semantics.c:6834
+#: c/c-typeck.c:13602 c/c-typeck.c:13736 cp/semantics.c:6680
+#: cp/semantics.c:6837
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD tritt in Bewegungsklausel mehrfach auf"
 
-#: c/c-typeck.c:13603 c/c-typeck.c:13735 cp/semantics.c:6683
-#: cp/semantics.c:6838
+#: c/c-typeck.c:13608 c/c-typeck.c:13740 cp/semantics.c:6686
+#: cp/semantics.c:6841
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD tritt in Zuordnungsklauseln mehrfach auf"
 
-#: c/c-typeck.c:13635 cp/semantics.c:6724
+#: c/c-typeck.c:13640 cp/semantics.c:6727
 #, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qE in %qs-Klausel hat keinen zuordenbaren Typ"
 
-#: c/c-typeck.c:13695 c/c-typeck.c:13785 cp/semantics.c:6799
-#: cp/semantics.c:6938
+#: c/c-typeck.c:13700 c/c-typeck.c:13790 cp/semantics.c:6802
+#: cp/semantics.c:6941
 #, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD in %qs-Klausel hat keinen zuordenbaren Typ"
 
-#: c/c-typeck.c:13766 cp/semantics.c:6918
+#: c/c-typeck.c:13771 cp/semantics.c:6921
 #, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE in %qs-Klausel ist weder Variablen- noch Funktionsname"
 
-#: c/c-typeck.c:13794 cp/semantics.c:6947
+#: c/c-typeck.c:13799 cp/semantics.c:6950
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qE tritt in derselben %<declare target%>-Direktive mehrfach auf"
 
-#: c/c-typeck.c:13808 cp/semantics.c:6962
+#: c/c-typeck.c:13813 cp/semantics.c:6965
 #, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD in %<uniform%>-Klausel ist kein Argument"
 
-#: c/c-typeck.c:13811 cp/semantics.c:6964
+#: c/c-typeck.c:13816 cp/semantics.c:6967
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qE in %<uniform%>-Klausel ist kein Argument"
 
-#: c/c-typeck.c:13826
+#: c/c-typeck.c:13831
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "Variable %qs ist weder Zeiger noch Array"
 
-#: c/c-typeck.c:13900 cp/semantics.c:6359
+#: c/c-typeck.c:13905 cp/semantics.c:6362
 #, gcc-internal-format
 msgid "%<nonmonotonic%> modifier specified for %qs schedule kind"
 msgstr "%<nonmonotonic%>-Modifizierer für Planungsart %qs angegeben"
 
-#: c/c-typeck.c:13931 cp/semantics.c:7141
+#: c/c-typeck.c:13936 cp/semantics.c:7144
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr "%<inbranch%>-Klausel ist inkompatibel mit %<notinbranch%>"
 
-#: c/c-typeck.c:13981 cp/semantics.c:7332
+#: c/c-typeck.c:13986 cp/semantics.c:7335
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE ist vorbestimmt %qs für %qs"
 
-#: c/c-typeck.c:14001 cp/semantics.c:7223
+#: c/c-typeck.c:14006 cp/semantics.c:7226
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr "%<simdlen%>-Klauselwert ist größer als %<safelen%>-Klauselwert"
 
-#: c/c-typeck.c:14013 cp/semantics.c:7236
+#: c/c-typeck.c:14018 cp/semantics.c:7239
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr "%<nonmonotonic%>-Planungsmodifizierer zusammen mit %<ordered%>-Klausel angegeben"
 
-#: c/c-typeck.c:14031 cp/semantics.c:7203
+#: c/c-typeck.c:14036 cp/semantics.c:7206
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr "%<linear%>-Klauselschritt ist ein Parameter %qD, der nicht in der %<uniform%>-Klausel angegeben ist"
 
-#: c/c-typeck.c:14204
+#: c/c-typeck.c:14209
 #, gcc-internal-format
 msgid "cannot use %<va_arg%> with reverse storage order"
 msgstr "%<va_arg%> kann nicht zusammen mit umgedreher Speicherreihenfolge verwendet werden"
 
-#: c/c-typeck.c:14209
+#: c/c-typeck.c:14214
 #, gcc-internal-format
 msgid "second argument to %<va_arg%> is of incomplete type %qT"
 msgstr "zweites Argument für %<va_arg%> ist vom unvollständigen Typ %qT"
 
-#: c/c-typeck.c:14215
+#: c/c-typeck.c:14220
 #, gcc-internal-format
 msgid "C++ requires promoted type, not enum type, in %<va_arg%>"
 msgstr "C++ erfordert weitergegebenen Typ, nicht Enum-Typ, in %<va_arg%>"
@@ -37973,7 +38015,7 @@
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "  keine bekannte Umwandlung für Argument %d von %qH nach %qI"
 
-#: cp/call.c:3441 cp/pt.c:6495
+#: cp/call.c:3441 cp/pt.c:6509
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -38263,7 +38305,7 @@
 msgid "%q#D is private within this context"
 msgstr "%q#D ist in diesem Zusammenhang »private«"
 
-#: cp/call.c:6478 cp/decl.c:7343
+#: cp/call.c:6478 cp/decl.c:7364
 #, gcc-internal-format
 msgid "declared private here"
 msgstr "hier als »private« deklariert"
@@ -38273,7 +38315,7 @@
 msgid "%q#D is protected within this context"
 msgstr "%q#D ist in diesem Zusammenhang »protected«"
 
-#: cp/call.c:6486 cp/decl.c:7344
+#: cp/call.c:6486 cp/decl.c:7365
 #, gcc-internal-format
 msgid "declared protected here"
 msgstr "hier als »protected« deklariert"
@@ -38572,7 +38614,7 @@
 msgid "call to non-function %qD"
 msgstr "Aufruf der Nicht-Funktion %qD"
 
-#: cp/call.c:9119 cp/pt.c:15053 cp/typeck.c:2901
+#: cp/call.c:9119 cp/pt.c:15075 cp/typeck.c:2901
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "Konstruktor %<%T::%D%> kann nicht direkt aufgerufen werden"
@@ -38780,262 +38822,262 @@
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr "Es kann nicht von %<final%>-Basis %qT in abgeleiteten Typ %qT abgeleitet werden"
 
-#: cp/class.c:2098
+#: cp/class.c:2103
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr "alle Elementfunktionen in Klasse %qT sind privat"
 
-#: cp/class.c:2110
+#: cp/class.c:2115
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr "%q#T definiert nur einen privaten Destruktor und hat keine »friends«"
 
-#: cp/class.c:2152
+#: cp/class.c:2156
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr "%q#T definiert nur private Konstruktoren und hat keine »friends«"
 
-#: cp/class.c:2156
+#: cp/class.c:2160
 #, gcc-internal-format
 msgid "%q#D is public, but requires an existing %q#T object"
 msgstr "%q#D ist %<public%>, benötigt jedoch ein existierendes Objekt vom Typ %q#T"
 
-#: cp/class.c:2430
+#: cp/class.c:2434
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr "%qD wurde nicht eindeutig und endgültig in %qT überschrieben"
 
-#: cp/class.c:2785
+#: cp/class.c:2789
 #, gcc-internal-format
 msgid "%qD can be marked override"
 msgstr "%qD kann als »override« markiert werden"
 
-#: cp/class.c:2797
+#: cp/class.c:2801
 #, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr "%q+#D als %<final%> markiert, ist aber nicht »virtual«"
 
-#: cp/class.c:2799
+#: cp/class.c:2803
 #, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr "%q+#D als %<override%> markiert, überschreibt aber nicht"
 
-#: cp/class.c:2861
+#: cp/class.c:2865
 #, gcc-internal-format
 msgid "%qD was hidden"
 msgstr "%qD war versteckt"
 
-#: cp/class.c:2863
+#: cp/class.c:2867
 #, gcc-internal-format
 msgid "  by %qD"
 msgstr "  von %qD"
 
-#: cp/class.c:2896
+#: cp/class.c:2900
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "%q#D ungültig; eine anonyme Union kann nur nicht-statische Datenelemente haben"
 
-#: cp/class.c:2906 cp/name-lookup.c:3293 cp/parser.c:19720
+#: cp/class.c:2910 cp/name-lookup.c:3293 cp/parser.c:19717
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr "diese Flexibilität ist veraltet und wird demnächst entfernt"
 
-#: cp/class.c:3097
+#: cp/class.c:3101
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr "die Auslassung in %qD wurde nicht vererbt"
 
-#: cp/class.c:3213
+#: cp/class.c:3217
 #, gcc-internal-format
 msgid "bit-field %q+#D with non-integral type"
 msgstr "Bit-Feld %q+#D mit Nicht-Ganzzahl-Typ"
 
-#: cp/class.c:3229
+#: cp/class.c:3233
 #, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr "Breite des Bitfeldes %q+D ist keine Ganzzahlkonstante"
 
-#: cp/class.c:3234
+#: cp/class.c:3238
 #, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr "negative Breite in Bitfeld %q+D"
 
-#: cp/class.c:3239
+#: cp/class.c:3243
 #, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr "Breite Null für Bitfeld %q+D"
 
-#: cp/class.c:3249
+#: cp/class.c:3253
 #, gcc-internal-format
 msgid "width of %qD exceeds its type"
 msgstr "Breite von %qD übersteigt seinen Typen"
 
-#: cp/class.c:3255
+#: cp/class.c:3259
 #, gcc-internal-format
 msgid "%qD is too small to hold all values of %q#T"
 msgstr "%qD ist zu klein, um alle Werte von %q#T aufzunehmen"
 
-#: cp/class.c:3316
+#: cp/class.c:3320
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr "Element %q+#D mit Konstruktor nicht erlaubt in Union"
 
-#: cp/class.c:3319
+#: cp/class.c:3323
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr "Element %q+#D mit Destruktor nicht erlaubt in Union"
 
-#: cp/class.c:3321
+#: cp/class.c:3325
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr "Element %q+#D mit Copy-Zuweisungsoperator ist nicht erlaubt in Union"
 
-#: cp/class.c:3325
+#: cp/class.c:3329
 #, gcc-internal-format
 msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgstr "uneingeschränkte »Unions« nur mit -std=c++11 oder -std=gnu++11 verfügbar"
 
-#: cp/class.c:3453
+#: cp/class.c:3457
 #, gcc-internal-format
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr "%q+D kann in C++98 nicht static sein, da es ein Union-Element ist"
 
-#: cp/class.c:3460
+#: cp/class.c:3464
 #, gcc-internal-format
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr "nicht-statisches Datenelement %q+D in einer Union darf keinen Referenztypen %qT haben"
 
-#: cp/class.c:3470
+#: cp/class.c:3474
 #, gcc-internal-format
 msgid "field %q+D invalidly declared function type"
 msgstr "Feld %q+D deklarierte ungültigerweise einen Funktionstypen"
 
-#: cp/class.c:3476
+#: cp/class.c:3480
 #, gcc-internal-format
 msgid "field %q+D invalidly declared method type"
 msgstr "Feld %q+D deklarierte ungültigerweise einen Methodentypen"
 
-#: cp/class.c:3536
+#: cp/class.c:3540
 #, gcc-internal-format
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr "»packed«-Attribut für ungepacktes nicht-POD-Feld %q#D wird ignoriert"
 
-#: cp/class.c:3585
+#: cp/class.c:3589
 #, gcc-internal-format
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr "Element %q+D darf nicht gleichzeitig als %<const%> und %<mutable%> deklariert sein"
 
-#: cp/class.c:3591
+#: cp/class.c:3595
 #, gcc-internal-format
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr "Element %q+D darf nicht als %<mutable%>-Referenz deklariert sein"
 
-#: cp/class.c:3617
+#: cp/class.c:3621
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr "in Union %qT werden mehrere Felder initialisiert"
 
-#: cp/class.c:3658
+#: cp/class.c:3662
 #, gcc-internal-format
 msgid "field %q#D with same name as class"
 msgstr "Feld %q#D mit gleichem Namen wie Klasse"
 
-#: cp/class.c:3681
+#: cp/class.c:3685
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr "%q#T hat Zeigertypen als Elemente"
 
-#: cp/class.c:3686
+#: cp/class.c:3690
 #, gcc-internal-format
 msgid "  but does not override %<%T(const %T&)%>"
 msgstr "  aber überschreibt nicht %<%T(const %T&)%>"
 
-#: cp/class.c:3688
+#: cp/class.c:3692
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr "  oder %<operator=(const %T&)%>"
 
-#: cp/class.c:3692
+#: cp/class.c:3696
 #, gcc-internal-format
 msgid "  but does not override %<operator=(const %T&)%>"
 msgstr "  aber überschreibt nicht %<operator=(const %T&)%>"
 
-#: cp/class.c:4097
+#: cp/class.c:4101
 #, gcc-internal-format
 msgid "alignment of %qD increased in -fabi-version=9 (GCC 5.2)"
 msgstr "Ausrichtung von %qD wurde in -fabi-version=9 (GCC 5.2) erhöht"
 
-#: cp/class.c:4100
+#: cp/class.c:4104
 #, gcc-internal-format
 msgid "alignment of %qD will increase in -fabi-version=9"
 msgstr "Ausrichtung von %qD wird in »-fabi-version=9« ansteigen"
 
-#: cp/class.c:4378
+#: cp/class.c:4382
 #, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "Initialisierung für nicht-virtuelle Methode %q+D angegeben"
 
-#: cp/class.c:4813
+#: cp/class.c:4817
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr "Methode überschreibt Methoden %<transaction_pure%> und %qE"
 
-#: cp/class.c:4834
+#: cp/class.c:4838
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr "als %qE deklarierte Methode überschreibt Methode %qE"
 
-#: cp/class.c:5350 cp/constexpr.c:237
+#: cp/class.c:5367 cp/constexpr.c:237
 #, gcc-internal-format
 msgid "enclosing class of %<constexpr%> non-static member function %q+#D is not a literal type"
 msgstr "umschließende Klasse der %<constexpr%> nicht-statischen Elementfunktion %q+#D ist kein Literaltyp"
 
-#: cp/class.c:5374
+#: cp/class.c:5391
 #, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr "%q+T ist kein Literal, denn: "
 
-#: cp/class.c:5377
+#: cp/class.c:5394
 #, gcc-internal-format
 msgid "  %qT is a closure type, which is only literal in C++17 and later"
 msgstr "  %qT is a Closure-Typ und ist erst ab C++17 literal"
 
-#: cp/class.c:5380
+#: cp/class.c:5397
 #, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr "  %q+T hat einen nicht-trivialen Destruktor"
 
-#: cp/class.c:5387
+#: cp/class.c:5404
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no %<constexpr%> constructor that is not a copy or move constructor"
 msgstr "  %q+T ist kein Aggregat, hat keinen trivialen Standardkonstruktor und hat keinen %<constexpr%>-Konstruktor, der kein Kopier- oder Bewegungskonstruktor ist"
 
-#: cp/class.c:5420
+#: cp/class.c:5437
 #, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "  Basisklasse %qT von %q+T ist kein Literal"
 
-#: cp/class.c:5435
+#: cp/class.c:5452
 #, gcc-internal-format
 msgid "  non-static data member %qD has non-literal type"
 msgstr "  nicht-statisches Datenelement %qD hat nicht-literalen Typ"
 
-#: cp/class.c:5442
+#: cp/class.c:5459
 #, gcc-internal-format
 msgid "  non-static data member %qD has volatile type"
 msgstr "  nicht-statisches Datenelement %qD hat nicht-literalen Typ"
 
-#: cp/class.c:5561
+#: cp/class.c:5578
 #, gcc-internal-format
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "Basisklasse %q#T hat einen zugänglichen nicht-virtuellen Destruktor"
 
-#: cp/class.c:5590
+#: cp/class.c:5607
 #, gcc-internal-format
 msgid "non-static reference %q#D in class without a constructor"
 msgstr "nicht-statische Referenz %q#D in Klasse ohne Konstruktor"
 
-#: cp/class.c:5596
+#: cp/class.c:5613
 #, gcc-internal-format
 msgid "non-static const member %q#D in class without a constructor"
 msgstr "nicht-statisches const-Element %q#D in Klasse ohne einen Konstruktor"
@@ -39042,152 +39084,152 @@
 
 #. If the function is defaulted outside the class, we just
 #. give the synthesis error.
-#: cp/class.c:5624
+#: cp/class.c:5641
 #, gcc-internal-format
 msgid "%q+D declared to take const reference, but implicit declaration would take non-const"
 msgstr "%q+D mit Eingabe einer konstanten Referenz deklariert, aber implizite Deklaration würde nicht-Konstante annehmen"
 
-#: cp/class.c:5898
+#: cp/class.c:5915
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr "direkte Basis %qT ist in %qT durch Mehrdeutigkeit unzugänglich"
 
-#: cp/class.c:5910
+#: cp/class.c:5927
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr "virtuelle Basis %qT ist in %qT durch Mehrdeutigkeit unzugänglich"
 
-#: cp/class.c:6133
+#: cp/class.c:6150
 #, gcc-internal-format
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr "Offset von %qD ist ABI-unverträglich und kann sich in zukünftigen GCC-Versionen ändern"
 
-#: cp/class.c:6291
+#: cp/class.c:6308
 #, gcc-internal-format
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr "Größe des Typs %qT ist zu groß (%qE Bytes)"
 
-#: cp/class.c:6576
+#: cp/class.c:6593
 #, gcc-internal-format
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr "ungültige Verwendung von %q#T mit Array der Größe 0 in %q#D"
 
-#: cp/class.c:6578
+#: cp/class.c:6595
 #, gcc-internal-format
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr "ungültige Verwendung von %q#T mit flexiblem Arrayelement in %q#T"
 
-#: cp/class.c:6583
+#: cp/class.c:6600
 #, gcc-internal-format
 msgid "array member %q#D declared here"
 msgstr "Arrayelement %q#D hier deklariert"
 
-#: cp/class.c:6610
+#: cp/class.c:6627
 #, gcc-internal-format
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr "Arrayelement %qD mit Länge 0 befindet sich nicht am Ende von %q#T"
 
-#: cp/class.c:6612
+#: cp/class.c:6629
 #, gcc-internal-format
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr "Arrayelement %qD mit Länge 0 in ansonsten leerem %q#T"
 
-#: cp/class.c:6620 cp/class.c:6650
+#: cp/class.c:6637 cp/class.c:6667
 #, gcc-internal-format
 msgid "in the definition of %q#T"
 msgstr "in der Definition von %q#T"
 
-#: cp/class.c:6628
+#: cp/class.c:6645
 #, gcc-internal-format
 msgid "flexible array member %qD not at end of %q#T"
 msgstr "flexibles Arrayelement %qD nicht am Ende von %q#T"
 
-#: cp/class.c:6630
+#: cp/class.c:6647
 #, gcc-internal-format
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr "flexibles Arrayelement %qD in ansonsten leerem %q#T"
 
-#: cp/class.c:6648
+#: cp/class.c:6665
 #, gcc-internal-format
 msgid "next member %q#D declared here"
 msgstr "nächstes Feld %q#D hier deklariert"
 
-#: cp/class.c:6760 cp/parser.c:23239
+#: cp/class.c:6777 cp/parser.c:23236
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "Redefinition von %q#T"
 
-#: cp/class.c:6897
+#: cp/class.c:6914
 #, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "%q#T hat virtuelle Funktionen und erreichbaren nicht-virtuellen Destruktor"
 
-#: cp/class.c:6925
+#: cp/class.c:6942
 #, gcc-internal-format
 msgid "type transparent %q#T does not have any fields"
 msgstr "typtransparentes %q#T hat keine Felder"
 
-#: cp/class.c:6931
+#: cp/class.c:6948
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr "typtransparente Klasse %qT hat Basisklassen"
 
-#: cp/class.c:6935
+#: cp/class.c:6952
 #, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr "typtransparente Klasse %qT hat virtuelle Funktionen"
 
-#: cp/class.c:6941
+#: cp/class.c:6958
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr "typtransparentes %q#T kann nicht transparent gemacht werden, weil der Typ des ersten Feldes anderes ABI als gesamte Klasse hat"
 
-#: cp/class.c:7071
+#: cp/class.c:7088
 #, gcc-internal-format
 msgid "definition of %qD does not match %<#include <initializer_list>%>"
 msgstr "Definition von %qD entspricht nicht %<#include <initializer_list>%>"
 
-#: cp/class.c:7082
+#: cp/class.c:7099
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr "Lesen der struct konnte wegen Syntaxfehlern nicht beendet werden"
 
-#: cp/class.c:7582
+#: cp/class.c:7599
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "Sprachen-Zeichenkette %<\"%E\"%> nicht erkannt"
 
-#: cp/class.c:7672
+#: cp/class.c:7689
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr "überladene Funktion %qD konnte nicht durch Umwandlung in Typ %qT aufgelöst werden"
 
-#: cp/class.c:7817
+#: cp/class.c:7834
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr "bei der Umwandlung der Funktion %qD in den Typ %q#T gab es keine Übereinstimmungen"
 
-#: cp/class.c:7844
+#: cp/class.c:7861
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "Umwandung der überladenen Funktion %qD in den Typ %q#T ist mehrdeutig"
 
-#: cp/class.c:7870
+#: cp/class.c:7887
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "Zeiger auf Element %qD wird angenommen"
 
-#: cp/class.c:7873
+#: cp/class.c:7890
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(ein Zeiger auf ein Element kann nur mit %<»&%E%> erzeugt werden)"
 
-#: cp/class.c:7948 cp/class.c:7990
+#: cp/class.c:7965 cp/class.c:8007
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "zu wenig Typinformationen"
 
-#: cp/class.c:7968
+#: cp/class.c:7985
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "%qE kann nicht vom Typ %qT in den Typ %qT umgewandelt werden"
@@ -39197,12 +39239,12 @@
 #. A name N used in a class S shall refer to the same declaration
 #. in its context and when re-evaluated in the completed scope of
 #. S.
-#: cp/class.c:8235
+#: cp/class.c:8252
 #, gcc-internal-format
 msgid "declaration of %q#D"
 msgstr "Deklaration von %q#D"
 
-#: cp/class.c:8237
+#: cp/class.c:8254
 #, gcc-internal-format
 msgid "changes meaning of %qD from %q#D"
 msgstr "verändert die Bedeutung von %qD von %q#D"
@@ -39593,17 +39635,17 @@
 msgid "unexpected AST of kind %s"
 msgstr "unerwarteter AST der Art %s"
 
-#: cp/cp-gimplify.c:1415
+#: cp/cp-gimplify.c:1416
 #, gcc-internal-format
 msgid "throw will always call terminate()"
 msgstr "throw wird immer terminate() aufrufen"
 
-#: cp/cp-gimplify.c:1418
+#: cp/cp-gimplify.c:1419
 #, gcc-internal-format
 msgid "in C++11 destructors default to noexcept"
 msgstr "in C++11 sind Destruktoren per Default »noexcept«"
 
-#: cp/cp-gimplify.c:1429
+#: cp/cp-gimplify.c:1430
 #, gcc-internal-format
 msgid "in C++11 this throw will terminate because destructors default to noexcept"
 msgstr "in C++11 löst das ein »throw« aus, da Destruktoren per Default »noexcept« sind"
@@ -40007,7 +40049,7 @@
 msgid "redeclaration %qD differs in %<constexpr%> from previous declaration"
 msgstr "Redeklaration %qD unterscheidet sich in %<constexpr%> von vorheriger Deklaration"
 
-#: cp/decl.c:1304 cp/decl.c:13843
+#: cp/decl.c:1304 cp/decl.c:13867
 #, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr "vorherige Deklaration %qD"
@@ -40331,7 +40373,7 @@
 msgid "  enters OpenMP structured block"
 msgstr "  tritt in OpenMP-strukturierten Block ein"
 
-#: cp/decl.c:3434 cp/parser.c:12366 cp/parser.c:12387
+#: cp/decl.c:3434 cp/parser.c:12363 cp/parser.c:12384
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr "ungültiger Ausgang von strukturiertem OpenMP-Block"
@@ -40341,7 +40383,7 @@
 msgid "%qD is not a type"
 msgstr "%qD ist kein Typ"
 
-#: cp/decl.c:3838 cp/parser.c:6366
+#: cp/decl.c:3838 cp/parser.c:6369
 #, gcc-internal-format
 msgid "%qD used without template parameters"
 msgstr "%qD ohne Template-Parameter verwendet"
@@ -40717,8 +40759,8 @@
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr "C99-Bezeichner %qE außerhalb von Aggregatinitialisierung"
 
-#: cp/decl.c:6011 cp/decl.c:6234 cp/typeck2.c:1310 cp/typeck2.c:1590
-#: cp/typeck2.c:1638 cp/typeck2.c:1685
+#: cp/decl.c:6011 cp/decl.c:6234 cp/typeck2.c:1310 cp/typeck2.c:1593
+#: cp/typeck2.c:1641 cp/typeck2.c:1688
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "zu viele Initialisierer für %qT"
@@ -40793,12 +40835,12 @@
 msgid "assignment (not initialization) in declaration"
 msgstr "Zuweisung (nicht Initialisierung) in Deklaration"
 
-#: cp/decl.c:6873 cp/decl.c:12605
+#: cp/decl.c:6873 cp/decl.c:12629
 #, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO-C++17 erlaubt Speicherklassenangabe %<register%> nicht"
 
-#: cp/decl.c:6877 cp/decl.c:12609
+#: cp/decl.c:6877 cp/decl.c:12633
 #, gcc-internal-format
 msgid "%<register%> storage class specifier used"
 msgstr "%<register%>-Speicherklassenangabe verwendet"
@@ -40823,42 +40865,42 @@
 msgid "function %q#D is initialized like a variable"
 msgstr "Funktion %q#D ist wie eine Variable initialisiert"
 
-#: cp/decl.c:7329
+#: cp/decl.c:7350
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "Klassentyp %qT kann nicht dekomponiert werden, da er ein unbenanntes Strukturelement hat"
 
-#: cp/decl.c:7332
+#: cp/decl.c:7353
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr "Klassentyp %qT kann nicht dekomponiert werden, da er ein unbenanntes Unionelement hat"
 
-#: cp/decl.c:7339
+#: cp/decl.c:7360
 #, gcc-internal-format
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "unzugreifbares Element %qD von %qT kann nicht dekomponiert werden"
 
-#: cp/decl.c:7365
+#: cp/decl.c:7386
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr "Klassentyp %qT kann nicht dekomponiert werden, da sowohl er als auch seine Basisklasse %qT nichtstatische Datenelemente haben"
 
-#: cp/decl.c:7374
+#: cp/decl.c:7395
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr "Klassentyp %qT kann nicht dekomponiert werden, da seine Basisklassen %qT und %qT nichtstatische Datenelemente haben"
 
-#: cp/decl.c:7592
+#: cp/decl.c:7613
 #, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr "Strukturierte Bindung verweist auf unvollständigen Typen %qT"
 
-#: cp/decl.c:7608
+#: cp/decl.c:7629
 #, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr "Array mit variabler Länge %qT kann nicht dekomponiert werden"
 
-#: cp/decl.c:7617 cp/decl.c:7702
+#: cp/decl.c:7638 cp/decl.c:7723
 #, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
@@ -40865,7 +40907,7 @@
 msgstr[0] "%u Name für strukturelle Bindung angegeben"
 msgstr[1] "%u Namen für strukturelle Bindung angegeben"
 
-#: cp/decl.c:7621
+#: cp/decl.c:7642
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
@@ -40872,7 +40914,7 @@
 msgstr[0] "nur %u Name für strukturelle Bindung angegeben"
 msgstr[1] "nur %u Namen für strukturelle Bindung angegeben"
 
-#: cp/decl.c:7624
+#: cp/decl.c:7645
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
@@ -40879,878 +40921,878 @@
 msgstr[0] "während %qT in %wu Element zerlegt wird"
 msgstr[1] "während %qT in %wu Elemente zerlegt wird"
 
-#: cp/decl.c:7669
+#: cp/decl.c:7690
 #, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr "Vektor %qT variabler Länge kann nicht zerlegt werden"
 
-#: cp/decl.c:7695
+#: cp/decl.c:7716
 #, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "%<std::tuple_size<%T>::value%> ist kein konstanter Ganzzahlausdruck"
 
-#: cp/decl.c:7704
+#: cp/decl.c:7725
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr "während %qT in %E Elemente zerlegt wird"
 
-#: cp/decl.c:7725
+#: cp/decl.c:7746
 #, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr "in Initialisierung der Variable %qD für strukturierte Bindung"
 
-#: cp/decl.c:7751
+#: cp/decl.c:7772
 #, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr "Union-Typ %qT kann nicht dekomponiert werden"
 
-#: cp/decl.c:7756
+#: cp/decl.c:7777
 #, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "nicht-Array-nicht-Klassentyp %qT kann nicht dekomponiert werden"
 
-#: cp/decl.c:7761
+#: cp/decl.c:7782
 #, gcc-internal-format
 msgid "cannot decompose lambda closure type %qT"
 msgstr "Lambda-Abschluss-Typ %qT kann nicht dekomponiert werden"
 
-#: cp/decl.c:7765
+#: cp/decl.c:7786
 #, gcc-internal-format
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "Strukturierte Bindung verweist auf unvollständigen Klassentypen %qT"
 
-#: cp/decl.c:7774
+#: cp/decl.c:7795
 #, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "Klassentyp %qT ohne nicht-static-Datenelemente kann nicht dekomponiert werden"
 
-#: cp/decl.c:8213
+#: cp/decl.c:8234
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr "nicht-lokale %<__thread%>-Variable %qD erfordert dynamische Initialisierung"
 
-#: cp/decl.c:8216
+#: cp/decl.c:8237
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr "nicht-lokale %<__thread%>-Variable %qD hat einen nicht-trivialen Destruktor"
 
-#: cp/decl.c:8222
+#: cp/decl.c:8243
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr "%<thread_local%> in C++11 erlaubt dynamische Initialisierung und Zerstörung"
 
-#: cp/decl.c:8450
+#: cp/decl.c:8471
 #, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "Initialisierung gibt nicht die Größe von %qT an"
 
-#: cp/decl.c:8454
+#: cp/decl.c:8475
 #, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "Arraygröße fehlt in %qT"
 
-#: cp/decl.c:8457
+#: cp/decl.c:8478
 #, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "Array %qT der Größe null"
 
-#: cp/decl.c:8473
+#: cp/decl.c:8494
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "Destruktor für fremde Klasse %qT kann kein Element sein"
 
-#: cp/decl.c:8475
+#: cp/decl.c:8496
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "Konstruktor für fremde Klasse %qT kann kein Element sein"
 
-#: cp/decl.c:8499
+#: cp/decl.c:8520
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD als eine %<virtual%> Variable deklariert"
 
-#: cp/decl.c:8501
+#: cp/decl.c:8522
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "Funktionsspezifizierer %<const%> und %<volatile%> an %qD ungültig in Variablendeklaration"
 
-#: cp/decl.c:8506
+#: cp/decl.c:8527
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD als ein %<virtual%> Parameter deklariert"
 
-#: cp/decl.c:8508
+#: cp/decl.c:8529
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD als ein %<inline%> Parameter deklariert"
 
-#: cp/decl.c:8510
+#: cp/decl.c:8531
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "Funktionsspezifizierer %<const%> und %<volatile%> an %qD ungültig in Parameterdeklaration"
 
-#: cp/decl.c:8515
+#: cp/decl.c:8536
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD als ein %<virtual%> Typ deklariert"
 
-#: cp/decl.c:8517
+#: cp/decl.c:8538
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD als ein %<inline%> Typ deklariert"
 
-#: cp/decl.c:8519
+#: cp/decl.c:8540
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "Funktionsspezifizierer %<const%> und %<volatile%> an %qD ungültig in Typdeklaration"
 
-#: cp/decl.c:8524
+#: cp/decl.c:8545
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD als ein %<virtual%> Feld deklariert"
 
-#: cp/decl.c:8526
+#: cp/decl.c:8547
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD als ein %<inline%> Feld deklariert"
 
-#: cp/decl.c:8528
+#: cp/decl.c:8549
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "Funktionsspezifizierer %<const%> und %<volatile%> an %qD ungültig in Felddeklaration"
 
-#: cp/decl.c:8535
+#: cp/decl.c:8556
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D als »friend« deklariert"
 
-#: cp/decl.c:8542
+#: cp/decl.c:8563
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D mit einer Ausnahmespezifikation deklariert"
 
-#: cp/decl.c:8574
+#: cp/decl.c:8595
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "Deklaration von %qD ist nicht in einem Namensbereich um %qT"
 
-#: cp/decl.c:8614
+#: cp/decl.c:8635
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "statische Elementfunktion %q#D mit Typqualifizierern deklariert"
 
-#: cp/decl.c:8624
+#: cp/decl.c:8645
 #, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr "Konzept %q#D mit Funktionsparametern deklariert"
 
-#: cp/decl.c:8630
+#: cp/decl.c:8651
 #, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr "Konzept %q#D mit hergeleitetem Rückgabetyp deklariert"
 
-#: cp/decl.c:8632
+#: cp/decl.c:8653
 #, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "Konzept %q#D mit nicht-%<bool%>-Rückgabetyp %qT"
 
-#: cp/decl.c:8703
+#: cp/decl.c:8724
 #, gcc-internal-format
 msgid "concept %qD has no definition"
 msgstr "Konzept %qD hat keine Definition"
 
-#: cp/decl.c:8772
+#: cp/decl.c:8793
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "Definition der expliziten Spezialisierung %qD in friend-Deklaration"
 
 #. Something like `template <class T> friend void f<T>()'.
-#: cp/decl.c:8782
+#: cp/decl.c:8803
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "ungültige Verwendung der Template-ID %qD in Deklaration des ursprünglichen Templates"
 
-#: cp/decl.c:8800
+#: cp/decl.c:8821
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "Standardargumente sind nicht in Deklaration der friend-Template-Spezialisierung %qD erlaubt"
 
-#: cp/decl.c:8808
+#: cp/decl.c:8829
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "%<inline%> ist nicht in Deklaration der friend-Template-Spezialisierung %qD erlaubt"
 
-#: cp/decl.c:8857
+#: cp/decl.c:8878
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "%<::main%> kann nicht als Template deklariert werden"
 
-#: cp/decl.c:8859
+#: cp/decl.c:8880
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "%<::main%> kann nicht inline deklariert werden"
 
-#: cp/decl.c:8861
+#: cp/decl.c:8882
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be %<constexpr%>"
 msgstr "%<::main%> kann nicht als %<constexpr%> deklariert werden"
 
-#: cp/decl.c:8863
+#: cp/decl.c:8884
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "%<::main%> kann nicht statisch deklariert werden"
 
-#: cp/decl.c:8920
+#: cp/decl.c:8941
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "statische Elementfunktion %qD kann nicht CV-Qualifizierer haben"
 
-#: cp/decl.c:8921
+#: cp/decl.c:8942
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "Nicht-Elementfunktion %qD kann nicht CV-Qualifizierer haben"
 
-#: cp/decl.c:8929
+#: cp/decl.c:8950
 #, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "statische Elementfunktion %qD kann keinen ref-Qualifizierer haben"
 
-#: cp/decl.c:8930
+#: cp/decl.c:8951
 #, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "Nicht-Elementfunktion %qD kann keinen ref-Qualifizierer haben"
 
-#: cp/decl.c:8940
+#: cp/decl.c:8961
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared at namespace scope"
 msgstr "Herleitungshinweis %qD muss im Gültigkeitsbereich des Namensbereiches auftreten"
 
-#: cp/decl.c:8946
+#: cp/decl.c:8967
 #, gcc-internal-format
 msgid "deduction guide %qD must not have a function body"
 msgstr "Herleitungshinweis %qD darf keinen Funktionskörper haben"
 
-#: cp/decl.c:8959
+#: cp/decl.c:8980
 #, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr "literaler Operator mit C-Bindung"
 
-#: cp/decl.c:8969
+#: cp/decl.c:8990
 #, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "%qD hat ungültige Argumentliste"
 
-#: cp/decl.c:8977
+#: cp/decl.c:8998
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr "Ganzzahl-Suffix %qs durch Implementierung überdeckt"
 
-#: cp/decl.c:8983
+#: cp/decl.c:9004
 #, gcc-internal-format
 msgid "floating point suffix %qs shadowed by implementation"
 msgstr "Gleitkomma-Suffix %qs durch Implementierung überdeckt"
 
-#: cp/decl.c:8991
+#: cp/decl.c:9012
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr "Literale Operator-Suffixe ohne vorangehendes %<_%> sind für zukünftige Standardisierungen reserviert"
 
-#: cp/decl.c:8996
+#: cp/decl.c:9017
 #, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "%qD muss eine Nicht-Elementfunktion sein"
 
-#: cp/decl.c:9076
+#: cp/decl.c:9097
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> muss %<int%> zurückgeben"
 
-#: cp/decl.c:9116
+#: cp/decl.c:9137
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "Definition des implizit deklarierten %qD"
 
-#: cp/decl.c:9121
+#: cp/decl.c:9142
 #, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "Definition des explizit standardisierten %q+D"
 
-#: cp/decl.c:9123
+#: cp/decl.c:9144
 #, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr "%q#D wurde hat hier ausdrücklichen Standardwert bekommen"
 
-#: cp/decl.c:9140
+#: cp/decl.c:9161
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "keine Elementfunktion %q#D in Klasse %qT deklariert"
 
-#: cp/decl.c:9329
+#: cp/decl.c:9350
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "%<::main%> kann nicht als globale Variable deklariert werden"
 
-#: cp/decl.c:9337
+#: cp/decl.c:9358
 #, gcc-internal-format
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "eine Nicht-Template-Variable kann nicht %<concept%> sein"
 
-#: cp/decl.c:9344
+#: cp/decl.c:9365
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr "Konzept muss Typ %<bool%> haben"
 
-#: cp/decl.c:9464
+#: cp/decl.c:9485
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "Initialisierung innerhalb der Klasse des statischen Datenelements %q#D mit unvollständigem Typ"
 
-#: cp/decl.c:9468
+#: cp/decl.c:9489
 #, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "%<constexpr%> erforderlich für Initialisierung innerhalb der Klasse des statischen Datenelements %q#D mit nicht eingebautem Typ"
 
-#: cp/decl.c:9472
+#: cp/decl.c:9493
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "Initialisierung innerhalb der Klasse des statischen Datenelements %q#D mit nicht eingebautem Typ"
 
-#: cp/decl.c:9486
+#: cp/decl.c:9507
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "ungültige Initialisierung innerhalb der Klasse des statischen Datenelements vom nicht eingebauten Typen %qT"
 
-#: cp/decl.c:9493
+#: cp/decl.c:9514
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ISO-C++ verbietet Initialisierung des nicht konstanten statischen Elements %qD in der Klasse"
 
-#: cp/decl.c:9498
+#: cp/decl.c:9519
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO-C++ verbietet Initialisierung der Elementkonstante %qD vom nicht eingebauten Typen %qT"
 
-#: cp/decl.c:9598
+#: cp/decl.c:9619
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "Arraygröße von %qD hat nicht-ganzzahligen Typen %qT"
 
-#: cp/decl.c:9600
+#: cp/decl.c:9621
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "Arraygröße hat nicht-ganzzahligen Typen %qT"
 
-#: cp/decl.c:9630 cp/decl.c:9680
+#: cp/decl.c:9651 cp/decl.c:9701
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "Größe des Arrays ist kein konstanter Ganzzahlausdruck"
 
-#: cp/decl.c:9646
+#: cp/decl.c:9667
 #, gcc-internal-format
 msgid "size of array %qD is negative"
 msgstr "Größe des Arrays %qD ist negativ"
 
-#: cp/decl.c:9648 cp/init.c:3651
+#: cp/decl.c:9669 cp/init.c:3667
 #, gcc-internal-format
 msgid "size of array is negative"
 msgstr "Größe des Arrays ist negativ"
 
-#: cp/decl.c:9662
+#: cp/decl.c:9683
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO-C++ verbietet Array %qD der Größe null"
 
-#: cp/decl.c:9664
+#: cp/decl.c:9685
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO-C++ verbietet Array der Größe null"
 
-#: cp/decl.c:9677
+#: cp/decl.c:9698
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "Größe des Arrays %qD ist kein konstanter Ganzzahlausdruck"
 
-#: cp/decl.c:9686
+#: cp/decl.c:9707
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO-C++ verbietet Array %qD variabler Länge"
 
-#: cp/decl.c:9688
+#: cp/decl.c:9709
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO-C++ verbietet Array variabler Länge"
 
-#: cp/decl.c:9694
+#: cp/decl.c:9715
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr "Array %qD variabler Länge wird verwendet"
 
-#: cp/decl.c:9697
+#: cp/decl.c:9718
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr "Array variabler Größe wird verwendet"
 
-#: cp/decl.c:9746
+#: cp/decl.c:9767
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "Überlauf in Arraygröße"
 
-#: cp/decl.c:9799
+#: cp/decl.c:9820
 #, gcc-internal-format
 msgid "%qD declared as array of %qT"
 msgstr "%qD als Array von %qT deklariert"
 
-#: cp/decl.c:9809
+#: cp/decl.c:9830
 #, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "Deklaration von %qD als Array von voids"
 
-#: cp/decl.c:9811
+#: cp/decl.c:9832
 #, gcc-internal-format
 msgid "creating array of void"
 msgstr "Array von void wird erzeugt"
 
-#: cp/decl.c:9816
+#: cp/decl.c:9837
 #, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "Deklaration von %qD als Array von Funktionen"
 
-#: cp/decl.c:9818
+#: cp/decl.c:9839
 #, gcc-internal-format
 msgid "creating array of functions"
 msgstr "Array von Funktionen wird erzeugt"
 
-#: cp/decl.c:9823
+#: cp/decl.c:9844
 #, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "Deklaration von %qD als Array von Referenzen"
 
-#: cp/decl.c:9825
+#: cp/decl.c:9846
 #, gcc-internal-format
 msgid "creating array of references"
 msgstr "Feld von Referenzen wird erzeugt"
 
-#: cp/decl.c:9830
+#: cp/decl.c:9851
 #, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "Deklaration von %qD als Feld von Funktionselementen"
 
-#: cp/decl.c:9832
+#: cp/decl.c:9853
 #, gcc-internal-format
 msgid "creating array of function members"
 msgstr "Feld von Funktionselementen wird erzeugt"
 
-#: cp/decl.c:9846
+#: cp/decl.c:9867
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "Deklaration von %qD als multidimensionales Feld muss für alle Dimensionen außer der ersten Grenzen haben"
 
-#: cp/decl.c:9850
+#: cp/decl.c:9871
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "multidimensionales Feld muss für alle Dimensionen außer der ersten Grenzen haben"
 
-#: cp/decl.c:9909
+#: cp/decl.c:9930
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "Angabe des Rückgabetyps für Konstruktor ist ungültig"
 
-#: cp/decl.c:9912
+#: cp/decl.c:9933
 #, gcc-internal-format
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "Qualifizierer sind bei Konstruktordeklarationen nicht erlaubt"
 
-#: cp/decl.c:9922
+#: cp/decl.c:9943
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "Angabe des Rückgabetyps für Destruktor ist ungültig"
 
-#: cp/decl.c:9925
+#: cp/decl.c:9946
 #, gcc-internal-format
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "Qualifizierer sind bei Destruktordeklarationen nicht erlaubt"
 
-#: cp/decl.c:9937
+#: cp/decl.c:9958
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "Rückgabetyp für %<operator %T%> angegeben"
 
-#: cp/decl.c:9940
+#: cp/decl.c:9961
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "Qualifizierer sind bei Deklaration von %<operator %T%> nicht erlaubt"
 
-#: cp/decl.c:9948
+#: cp/decl.c:9969
 #, gcc-internal-format
 msgid "return type specified for deduction guide"
 msgstr "Rückgabetyp für Herleitungshinweis angegeben"
 
-#: cp/decl.c:9951
+#: cp/decl.c:9972
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "Qualifizierer sind bei Deklaration von Herleitungshinweis nicht erlaubt"
 
-#: cp/decl.c:9955
+#: cp/decl.c:9976
 #, gcc-internal-format
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "Template-Template-Parameter %qT in Deklaration von Ableitungshinweis"
 
-#: cp/decl.c:9964
+#: cp/decl.c:9985
 #, gcc-internal-format
 msgid "decl-specifier in declaration of deduction guide"
 msgstr "decl-specifier in Deklaration von Ableitungshinweis"
 
-#: cp/decl.c:9985
+#: cp/decl.c:10006
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "unbenannte Variable oder Feld als »void« deklariert"
 
-#: cp/decl.c:9992
+#: cp/decl.c:10013
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "Variable oder Feld als »void« deklariert"
 
-#: cp/decl.c:10007
+#: cp/decl.c:10028
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "%<inline%>-Spezifizierer ungültig für Variable %qD mit Gültigkeitsbereich Block"
 
-#: cp/decl.c:10013
+#: cp/decl.c:10034
 #, gcc-internal-format
 msgid "inline variables are only available with -std=c++17 or -std=gnu++17"
 msgstr "»inline«-Variablen sind nur mit -std=c++17 oder -std=gnu++17 verfügbar"
 
-#: cp/decl.c:10268
+#: cp/decl.c:10292
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "ungültige Verwendung des qualifizierten Namens %<::%D%>"
 
-#: cp/decl.c:10271 cp/decl.c:10291
+#: cp/decl.c:10295 cp/decl.c:10315
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "ungültige Verwendung des qualifizierten Namens %<%T::%D%>"
 
-#: cp/decl.c:10274
+#: cp/decl.c:10298
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "ungültige Verwendung des qualifizierten Namens %<%D::%D%>"
 
-#: cp/decl.c:10283
+#: cp/decl.c:10307
 #, gcc-internal-format
 msgid "%q#T is not a class or a namespace"
 msgstr "%q#T ist keine Klasse oder Namensbereich"
 
-#: cp/decl.c:10305 cp/decl.c:10398 cp/decl.c:10407 cp/decl.c:11970
+#: cp/decl.c:10329 cp/decl.c:10422 cp/decl.c:10431 cp/decl.c:11994
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "Deklaration von %qD als Nicht-Funktion"
 
-#: cp/decl.c:10311
+#: cp/decl.c:10335
 #, gcc-internal-format
 msgid "declaration of %qD as non-member"
 msgstr "Deklaration von %qD als Nicht-Element"
 
-#: cp/decl.c:10339
+#: cp/decl.c:10363
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "Deklarator-ID fehlt: reserviertes Wort %qD wird verwendet"
 
-#: cp/decl.c:10390
+#: cp/decl.c:10414
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "Funktionsdefinition deklariert keine Parameter"
 
-#: cp/decl.c:10415
+#: cp/decl.c:10439
 #, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "Deklaration von %qD als %<typedef%>"
 
-#: cp/decl.c:10420
+#: cp/decl.c:10444
 #, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "Deklaration von %qD als Parameter"
 
-#: cp/decl.c:10454
+#: cp/decl.c:10478
 #, gcc-internal-format
 msgid "%<concept%> cannot appear in a typedef declaration"
 msgstr "%<concept%> darf nicht in typedef-Deklarationen auftreten"
 
-#: cp/decl.c:10460
+#: cp/decl.c:10484
 #, gcc-internal-format
 msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgstr "%<constexpr%> kann nicht in typedef-Deklaration auftreten"
 
-#: cp/decl.c:10468
+#: cp/decl.c:10492
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "zwei oder mehr Datentypen in Deklaration von %qs"
 
-#: cp/decl.c:10474
+#: cp/decl.c:10498
 #, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr "in Konflikt stehende Spezifikationen für Deklaration von %qs"
 
-#: cp/decl.c:10515
+#: cp/decl.c:10539
 #, gcc-internal-format
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO-C++ unterstützt nicht, dass einfaches %<complex%> %<double complex%> bedeutet"
 
-#: cp/decl.c:10564 cp/decl.c:10567 cp/decl.c:10570
+#: cp/decl.c:10588 cp/decl.c:10591 cp/decl.c:10594
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO-C++ verbietet Deklaration von %qs ohne Typ"
 
-#: cp/decl.c:10586
+#: cp/decl.c:10610
 #, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr "%<__int%d%> wird von diesem Ziel nicht unterstützt"
 
-#: cp/decl.c:10592
+#: cp/decl.c:10616
 #, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO-C++ unterstützt %<__int%d%> for %qs nicht"
 
-#: cp/decl.c:10614 cp/decl.c:10634
+#: cp/decl.c:10638 cp/decl.c:10658
 #, gcc-internal-format
 msgid "%<signed%> or %<unsigned%> invalid for %qs"
 msgstr "%<signed%> oder %<unsigned%> ungültig für %qs"
 
-#: cp/decl.c:10616
+#: cp/decl.c:10640
 #, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgstr "%<signed%> und %<unsigned%> für %qs gleichzeitig angegeben"
 
-#: cp/decl.c:10618
+#: cp/decl.c:10642
 #, gcc-internal-format
 msgid "%<long long%> invalid for %qs"
 msgstr "%<long long%> ungültig für %qs"
 
-#: cp/decl.c:10620
+#: cp/decl.c:10644
 #, gcc-internal-format
 msgid "%<long%> invalid for %qs"
 msgstr "%<long%> ungültig für %qs"
 
-#: cp/decl.c:10622
+#: cp/decl.c:10646
 #, gcc-internal-format
 msgid "%<short%> invalid for %qs"
 msgstr "%<short%> ungültig für %qs"
 
-#: cp/decl.c:10624
+#: cp/decl.c:10648
 #, gcc-internal-format
 msgid "%<long%> or %<short%> invalid for %qs"
 msgstr "%<long%> oder %<short%> ungültig für %qs"
 
-#: cp/decl.c:10626
+#: cp/decl.c:10650
 #, gcc-internal-format
 msgid "%<long%>, %<int%>, %<short%>, or %<char%> invalid for %qs"
 msgstr "%<long%>, %<int%>, %<short%> oder %<char%> ungültig für %qs"
 
-#: cp/decl.c:10628
+#: cp/decl.c:10652
 #, gcc-internal-format
 msgid "%<long%> or %<short%> specified with char for %qs"
 msgstr "%<long%> oder %<short%> mit »char« für %qs angegeben"
 
-#: cp/decl.c:10630
+#: cp/decl.c:10654
 #, gcc-internal-format
 msgid "%<long%> and %<short%> specified together for %qs"
 msgstr "%<long%> und %<short%> für %qs gleichzeitig angegeben"
 
-#: cp/decl.c:10636
+#: cp/decl.c:10660
 #, gcc-internal-format
 msgid "%<short%> or %<long%> invalid for %qs"
 msgstr "%<short%> oder %<long%> ungültig für %qs"
 
-#: cp/decl.c:10644
+#: cp/decl.c:10668
 #, gcc-internal-format
 msgid "long, short, signed or unsigned used invalidly for %qs"
 msgstr "long, short, signed oder unsigned ungültig verwendet für %qs"
 
-#: cp/decl.c:10712
+#: cp/decl.c:10736
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "complex ungültig für %qs"
 
-#: cp/decl.c:10751
+#: cp/decl.c:10775
 #, gcc-internal-format
 msgid "template placeholder type %qT must be followed by a simple declarator-id"
 msgstr "Template-Platzhaltertyp %qT muss von einer einfachen declarator-id gefolgt sein"
 
-#: cp/decl.c:10769
+#: cp/decl.c:10793
 #, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "Element %qD kann nicht gleichzeitig %<virtual%> und %<static%> sein"
 
-#: cp/decl.c:10775
+#: cp/decl.c:10799
 #, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<constexpr%>"
 msgstr "Element %qD kann nicht gleichzeitig %<virtual%> und %<constexpr%> sein"
 
-#: cp/decl.c:10785
+#: cp/decl.c:10809
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "»typedef«-Deklaration in Parameterdeklaration ungültig"
 
-#: cp/decl.c:10790
+#: cp/decl.c:10814
 #, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "Speicherklasse für Template-Parameter %qs angegeben"
 
-#: cp/decl.c:10796
+#: cp/decl.c:10820
 #, gcc-internal-format
 msgid "storage class specifiers invalid in parameter declarations"
 msgstr "Speicherklassenangaben sind in Parameterdeklarationen ungültig"
 
-#: cp/decl.c:10800
+#: cp/decl.c:10824
 #, gcc-internal-format
 msgid "a parameter cannot be declared %<concept%>"
 msgstr "ein Parameter kann nicht als %<concept%> deklariert sein"
 
-#: cp/decl.c:10805
+#: cp/decl.c:10829
 #, gcc-internal-format
 msgid "a parameter cannot be declared %<constexpr%>"
 msgstr "ein Parameter kann nicht als %<constexpr%> deklariert sein"
 
-#: cp/decl.c:10815
+#: cp/decl.c:10839
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "%<virtual%> außerhalb einer Klassendeklaration"
 
-#: cp/decl.c:10825
+#: cp/decl.c:10849
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<inline%>"
 msgstr "Deklaration für strukturierte Bindung darf nicht als %<inline%> deklariert werden"
 
-#: cp/decl.c:10828
+#: cp/decl.c:10852
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<typedef%>"
 msgstr "Deklaration für strukturierte Bindung darf nicht als %<typedef%> deklariert werden"
 
-#: cp/decl.c:10830
+#: cp/decl.c:10854
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<constexpr%>"
 msgstr "Deklaration für strukturierte Bindung darf nicht als %<constexpr%> deklariert werden"
 
-#: cp/decl.c:10834
+#: cp/decl.c:10858
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr "Deklaration für strukturierte Bindung darf nicht als %qs deklariert werden"
 
-#: cp/decl.c:10839
+#: cp/decl.c:10863
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<concept%>"
 msgstr "Deklaration für strukturierte Bindung darf nicht als %<concept%> deklariert werden"
 
-#: cp/decl.c:10845
+#: cp/decl.c:10869
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<register%>"
 msgstr "Deklaration für strukturierte Bindung darf nicht als %<register%> deklariert werden"
 
-#: cp/decl.c:10849
+#: cp/decl.c:10873
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<static%>"
 msgstr "Deklaration für strukturierte Bindung darf nicht als %<static%> deklariert werden"
 
-#: cp/decl.c:10853
+#: cp/decl.c:10877
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<extern%>"
 msgstr "Deklaration für strukturierte Bindung darf nicht als %<extern%> deklariert werden"
 
-#: cp/decl.c:10857
+#: cp/decl.c:10881
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<mutable%>"
 msgstr "Deklaration für strukturierte Bindung darf nicht als %<mutable%> deklariert werden"
 
-#: cp/decl.c:10861
+#: cp/decl.c:10885
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr "Deklaration für strukturierte Bindung darf nicht als %<auto%> (C++98) deklariert werden"
 
-#: cp/decl.c:10872
+#: cp/decl.c:10896
 #, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr "Deklaration für strukturierte Bindung darf nicht vom Typen %qT sein"
 
-#: cp/decl.c:10875
+#: cp/decl.c:10899
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr "Typ muss cv-qualifizierter %<auto%> oder Referenz auf cv-qualifizierten %<auto%> sein"
 
-#: cp/decl.c:10906
+#: cp/decl.c:10930
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "mehrere Speicherklassen in Deklaration von %qs"
 
-#: cp/decl.c:10929
+#: cp/decl.c:10953
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "Speicherklasse %qs angegeben"
 
-#: cp/decl.c:10933
+#: cp/decl.c:10957
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "Speicherklasse für Parameter %qs angegeben"
 
-#: cp/decl.c:10946
+#: cp/decl.c:10970
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "geschachtelte Funktion %qs als %<extern%> deklariert"
 
-#: cp/decl.c:10950
+#: cp/decl.c:10974
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "Deklaration höchster Ebene von %qs gibt %<auto%> an"
 
-#: cp/decl.c:10957
+#: cp/decl.c:10981
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "Funktions-Gültigkeitsbereich %qs ist implizit auto und deklarierte %<__thread%>"
 
-#: cp/decl.c:10969
+#: cp/decl.c:10993
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "Speicherklassenangaben sind in friend-Funktionsdeklarationen ungültig"
 
-#: cp/decl.c:11050
+#: cp/decl.c:11074
 #, gcc-internal-format
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "unnötige Klammern in Deklaration von %qs"
 
-#: cp/decl.c:11098
+#: cp/decl.c:11122
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr "»requires«-Klausel für Rückgabetyp"
 
-#: cp/decl.c:11118
+#: cp/decl.c:11142
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr "Funktion %qs verwendet Typspezifikation %<auto%> ohne folgenden Rückgabetypen"
 
-#: cp/decl.c:11121
+#: cp/decl.c:11145
 #, gcc-internal-format
 msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgstr "hergeleiteter Rückgabetyp nur mit -std=c++14 oder -std=gnu++14 verfügbar"
 
-#: cp/decl.c:11127
+#: cp/decl.c:11151
 #, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr "virtuelle Funktionen kann keinen hergeleiteten Rückgabetyp haben"
 
-#: cp/decl.c:11134
+#: cp/decl.c:11158
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr "Funktion %qs mit folgendem Rückgabetypen hat %qT als seinen Typ statt einfaches %<auto%>"
 
-#: cp/decl.c:11147
+#: cp/decl.c:11171
 #, gcc-internal-format
 msgid "deduced class type %qD in function return type"
 msgstr "hergeleiteter Klassentyp %qD in Rückgabetyp von Funktion"
 
-#: cp/decl.c:11156
+#: cp/decl.c:11180
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr "Herleitungshinweis für %qT muss angehängten Rückgabetyp haben"
 
-#: cp/decl.c:11169
+#: cp/decl.c:11193
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr "angehängter Rückgabetyp %qT den Ableitungshinweises ist keine Spezialisierung von %qT"
@@ -41757,459 +41799,459 @@
 
 #. Not using maybe_warn_cpp0x because this should
 #. always be an error.
-#: cp/decl.c:11180
+#: cp/decl.c:11204
 #, gcc-internal-format
 msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgstr "folgender Rückgabetyp nur mit -std=c++11 oder -std=gnu++11 verfügbar"
 
-#: cp/decl.c:11183
+#: cp/decl.c:11207
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr "Funktion %qs mit folgendem Rückgabetypen nicht mit Typspezifikation %<auto%> deklariert"
 
-#: cp/decl.c:11212
+#: cp/decl.c:11236
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs als Funktion, die eine Funktion zurückgibt, deklariert"
 
-#: cp/decl.c:11218
+#: cp/decl.c:11242
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs als Funktion, die ein Feld zurückgibt, deklariert"
 
-#: cp/decl.c:11247
+#: cp/decl.c:11271
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "Destruktor kann keine statische Elementfunktion sein"
 
-#: cp/decl.c:11248
+#: cp/decl.c:11272
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "Konstruktor kann keine statische Elementfunktion sein"
 
-#: cp/decl.c:11252
+#: cp/decl.c:11276
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "Destruktoren dürfen nicht CV-qualifiziert sein"
 
-#: cp/decl.c:11253
+#: cp/decl.c:11277
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "Konstruktoren dürfen nicht CV-qualifiziert sein"
 
-#: cp/decl.c:11261
+#: cp/decl.c:11285
 #, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr "Destruktoren dürfen nicht ref-qualifiziert sein"
 
-#: cp/decl.c:11262
+#: cp/decl.c:11286
 #, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr "Konstruktoren dürfen nicht ref-qualifiziert sein"
 
-#: cp/decl.c:11280
+#: cp/decl.c:11304
 #, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "Konstruktoren dürfen nicht als %<virtual%> deklariert sein"
 
 #. Cannot be both friend and virtual.
-#: cp/decl.c:11295
+#: cp/decl.c:11319
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "virtuelle Funktionen können keine friends sein"
 
-#: cp/decl.c:11299
+#: cp/decl.c:11323
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "friend-Deklaration nicht in Klassendefinition"
 
-#: cp/decl.c:11301
+#: cp/decl.c:11325
 #, gcc-internal-format
 msgid "can%'t define friend function %qs in a local class definition"
 msgstr "friend-Funktion %qs kann nicht in einer lokalen Klassendefinition definiert werden"
 
-#: cp/decl.c:11313
+#: cp/decl.c:11337
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr "eine Umwandlungsfunktion darf keinen angehängten Rückgabetyp haben"
 
-#: cp/decl.c:11339
+#: cp/decl.c:11363
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "Destruktoren dürfen keine Parameter haben"
 
-#: cp/decl.c:11379
+#: cp/decl.c:11403
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "Zeiger auf %q#T kann nicht deklariert werden"
 
-#: cp/decl.c:11392 cp/decl.c:11399
+#: cp/decl.c:11416 cp/decl.c:11423
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "Referenz auf %q#T kann nicht deklariert werden"
 
-#: cp/decl.c:11401
+#: cp/decl.c:11425
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "Zeiger auf Element %q#T kann nicht deklariert werden"
 
-#: cp/decl.c:11430
+#: cp/decl.c:11454
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "Referenz auf qualifizierten Funktionstypen %qT kann nicht deklariert werden"
 
-#: cp/decl.c:11431
+#: cp/decl.c:11455
 #, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "Zeiger auf qualifizierten Funktionstypen %qT kann nicht deklariert werden"
 
-#: cp/decl.c:11504
+#: cp/decl.c:11528
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr "Referenz auf %q#T kann nicht deklariert werden, da letzteres weder Typedef noch Templatetyp-Argument ist"
 
-#: cp/decl.c:11574
+#: cp/decl.c:11598
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "Template-ID %qD als Deklarator verwendet"
 
-#: cp/decl.c:11599
+#: cp/decl.c:11623
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "Elementfunktionen sind implizite »friends« ihrer Klasse"
 
-#: cp/decl.c:11605
+#: cp/decl.c:11629
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "zusätzliche Qualifizierung %<%T::%> an Element %qs"
 
-#: cp/decl.c:11635
+#: cp/decl.c:11659
 #, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "Elementfunktion %<%T::%s%> kann nicht innerhalb von %qT definiert werden"
 
-#: cp/decl.c:11637
+#: cp/decl.c:11661
 #, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "Elementfunktion %<%T::%s%> kann nicht innerhalb von %qT deklariert werden"
 
-#: cp/decl.c:11645
+#: cp/decl.c:11669
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "Element %<%T::%s%> kann nicht in %qT deklariert werden"
 
-#: cp/decl.c:11685
+#: cp/decl.c:11709
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "Nicht-Parameter %qs kann kein Parameterpack sein"
 
-#: cp/decl.c:11693
+#: cp/decl.c:11717
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "Datenelement darf nicht variabel modifizierten Typ %qT haben"
 
-#: cp/decl.c:11695
+#: cp/decl.c:11719
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "Parameter darf nicht variabel modifizierten Typ %qT haben"
 
-#: cp/decl.c:11706
+#: cp/decl.c:11730
 #, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "%<explicit%> außerhalb einer Klassendeklaration"
 
-#: cp/decl.c:11709
+#: cp/decl.c:11733
 #, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr "%<explicit%> in »friend«-Deklaration"
 
-#: cp/decl.c:11712
+#: cp/decl.c:11736
 #, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "nur Deklarationen von Konstruktoren und Umwandlungsoperatoren können %<explicit%> sein"
 
-#: cp/decl.c:11721
+#: cp/decl.c:11745
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "Nicht-Element %qs kann nicht als %<mutable%> deklariert sein"
 
-#: cp/decl.c:11726
+#: cp/decl.c:11750
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "Nicht-Objekt-Element %qs kann nicht als %<mutable%> deklariert sein"
 
-#: cp/decl.c:11732
+#: cp/decl.c:11756
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "Funktion %qs kann nicht als %<mutable%> deklariert sein"
 
-#: cp/decl.c:11737
+#: cp/decl.c:11761
 #, gcc-internal-format
 msgid "static %qs cannot be declared %<mutable%>"
 msgstr "statisches %qs kann nicht als %<mutable%> deklariert sein"
 
-#: cp/decl.c:11742
+#: cp/decl.c:11766
 #, gcc-internal-format
 msgid "const %qs cannot be declared %<mutable%>"
 msgstr "Konstante %qs kann nicht als %<mutable%> deklariert sein"
 
-#: cp/decl.c:11747
+#: cp/decl.c:11771
 #, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "Referenz %qs kann nicht als %<mutable%> deklariert sein"
 
-#: cp/decl.c:11778
+#: cp/decl.c:11802
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "»typedef« als %<auto%> deklariert"
 
-#: cp/decl.c:11783
+#: cp/decl.c:11807
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr "requires-clause an Typedef"
 
-#: cp/decl.c:11787
+#: cp/decl.c:11811
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "typedef-Name darf kein Spezifizierer mit geschachteltem Namen sein"
 
-#: cp/decl.c:11813
+#: cp/decl.c:11837
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ISO-C++ verbietet geschachtelten Typen %qD mit gleichem Namen wie umschließende Klasse"
 
-#: cp/decl.c:11900
+#: cp/decl.c:11924
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "%<inline%> für friend-Klassen-Deklaration angegeben"
 
-#: cp/decl.c:11908
+#: cp/decl.c:11932
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "Template-Parameter können keine »friends« sein"
 
-#: cp/decl.c:11910
+#: cp/decl.c:11934
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "friend-Deklaration erfordert Klassenschlüssel, d.h. %<friend class %T::%D%>"
 
-#: cp/decl.c:11914
+#: cp/decl.c:11938
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "friend-Deklaration erfordert Klassenschlüssel, d.h. %<friend %#T%>"
 
-#: cp/decl.c:11927
+#: cp/decl.c:11951
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "Versuch, die Klasse %qT zu einem »friend« des globalen Gültigkeitsbereiches zu machen"
 
-#: cp/decl.c:11947
+#: cp/decl.c:11971
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "ungültige Qualifizierer an Nicht-Element-Funktionstyp"
 
-#: cp/decl.c:11951
+#: cp/decl.c:11975
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr "requires-clause an type-id"
 
-#: cp/decl.c:11961
+#: cp/decl.c:11985
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "abstrakter Deklarator %qT als Deklaration verwendet"
 
-#: cp/decl.c:11976
+#: cp/decl.c:12000
 #, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "»requires«-Klausel in Deklaration von Nichtfunktionstyp %qT"
 
-#: cp/decl.c:11995
+#: cp/decl.c:12019
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "%<::%> kann nicht in Parameterdeklaration verwendet werden"
 
-#: cp/decl.c:12001
+#: cp/decl.c:12025
 #, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "%<auto%>-Parameter darf in diesem Kontext nicht verwendet werden"
 
-#: cp/decl.c:12003
+#: cp/decl.c:12027
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "Parameter als %<auto%> deklariert"
 
-#: cp/decl.c:12052 cp/parser.c:3270
+#: cp/decl.c:12076 cp/parser.c:3270
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "ungültige Verwendung des Template-Namens %qE ohne eine Argumentliste"
 
-#: cp/decl.c:12056
+#: cp/decl.c:12080
 #, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr "nicht-statisches Datenelement mit Platzhalter %qT deklariert"
 
-#: cp/decl.c:12080
+#: cp/decl.c:12104
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO-C++ verbietet flexibles Arrayelement %qs"
 
-#: cp/decl.c:12083
+#: cp/decl.c:12107
 #, gcc-internal-format
 msgid "ISO C++ forbids flexible array members"
 msgstr "ISO-C++ verbietet flexible Arrayelemente"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:12099
+#: cp/decl.c:12123
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "ungültige Verwendung von %<::%>"
 
-#: cp/decl.c:12121
+#: cp/decl.c:12145
 #, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "Deklaration der Funktion %qD in ungültigem Kontext"
 
-#: cp/decl.c:12130
+#: cp/decl.c:12154
 #, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "Funktion %qD wurde innerhalb einer Union als »virtual« deklariert"
 
-#: cp/decl.c:12139
+#: cp/decl.c:12163
 #, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%qD kann nicht als »virtual« deklariert werden, da es immer statisch ist"
 
-#: cp/decl.c:12153
+#: cp/decl.c:12177
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "Qualifizierten Namen in Friend-Deklaration für Destruktor %qD erwartet"
 
-#: cp/decl.c:12160
+#: cp/decl.c:12184
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "Deklaration von %qD als Element %qT"
 
-#: cp/decl.c:12166
+#: cp/decl.c:12190
 #, gcc-internal-format
 msgid "a destructor cannot be %<concept%>"
 msgstr "ein Destruktor kann nicht %<concept%> sein"
 
-#: cp/decl.c:12171
+#: cp/decl.c:12195
 #, gcc-internal-format
 msgid "a destructor cannot be %<constexpr%>"
 msgstr "Destruktor kann nicht %<constexpr%> sein"
 
-#: cp/decl.c:12177
+#: cp/decl.c:12201
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "Qualifizierten Namen in Friend-Deklaration für Konstruktor %qD erwartet"
 
-#: cp/decl.c:12185
+#: cp/decl.c:12209
 #, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr "ein Konstruktor kann nicht %<concept%> sein"
 
-#: cp/decl.c:12190
+#: cp/decl.c:12214
 #, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr "ein Konzept kann keine Elementfunktion sein"
 
-#: cp/decl.c:12199
+#: cp/decl.c:12223
 #, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr "Spezialisierung des Variablentemplates %qD als Funktion deklariert"
 
-#: cp/decl.c:12202
+#: cp/decl.c:12226
 #, gcc-internal-format
 msgid "variable template declared here"
 msgstr "Variablentemplate hier deklariert"
 
-#: cp/decl.c:12257
+#: cp/decl.c:12281
 #, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr "Feld %qD hat unvollständigen Typen %qT"
 
-#: cp/decl.c:12262
+#: cp/decl.c:12286
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "Name %qT hat unvollständigen Typen"
 
-#: cp/decl.c:12272
+#: cp/decl.c:12296
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE ist weder eine Funktion noch Elementfunktion; kann nicht als »friend« deklariert werden"
 
-#: cp/decl.c:12318
+#: cp/decl.c:12342
 #, gcc-internal-format
 msgid "static data member %qE declared %<concept%>"
 msgstr "statisches Datenelement %qE als %<constexpr%> deklariert"
 
-#: cp/decl.c:12322
+#: cp/decl.c:12346
 #, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "statisches Datenelement %qD (%<constexpr%>) muss Initialisierung haben"
 
-#: cp/decl.c:12350
+#: cp/decl.c:12374
 #, gcc-internal-format
 msgid "non-static data member %qE declared %<concept%>"
 msgstr "nicht-statisches Datenelement %qE als %<concept%> deklariert"
 
-#: cp/decl.c:12354
+#: cp/decl.c:12378
 #, gcc-internal-format
 msgid "non-static data member %qE declared %<constexpr%>"
 msgstr "nicht-statisches Datenelement %qE als %<constexpr%> deklariert"
 
-#: cp/decl.c:12409
+#: cp/decl.c:12433
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "Speicherklasse %<auto%> ungültig für Funktion %qs"
 
-#: cp/decl.c:12411
+#: cp/decl.c:12435
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "Speicherklasse %<register%> ungültig für Funktion %qs"
 
-#: cp/decl.c:12415
+#: cp/decl.c:12439
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "Speicherklasse %<__thread%> ungültig für Funktion %qs"
 
-#: cp/decl.c:12418
+#: cp/decl.c:12442
 #, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "Speicherklasse %<thread_local%> ungültig für Funktion %qs"
 
-#: cp/decl.c:12423
+#: cp/decl.c:12447
 #, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "virt-Spezifikation in %qs ist außerhalb einer Klassendefinition nicht erlaubt"
 
-#: cp/decl.c:12434
+#: cp/decl.c:12458
 #, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "%<static%> ist für außerhalb des globalen Gültigkeitsbereiches deklarierte Funktion %qs ungültig"
 
-#: cp/decl.c:12438
+#: cp/decl.c:12462
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "%<inline%> ungültig für außerhalb des globalen Gültigkeitsbereiches deklarierte Funktion %qs"
 
-#: cp/decl.c:12446
+#: cp/decl.c:12470
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "virtuelle Nicht-Klassen-Funktion %qs"
 
-#: cp/decl.c:12453
+#: cp/decl.c:12477
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "%qs nicht in Klassen-Gültigkeitsbereich definiert"
 
-#: cp/decl.c:12454
+#: cp/decl.c:12478
 #, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "%qs in einem Nicht-Klassen-Gültigkeitsbereich definiert"
 
-#: cp/decl.c:12489
+#: cp/decl.c:12513
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "Elementfunktion %qD kann nicht deklariert werden, statische Bindung zu haben"
@@ -42216,77 +42258,77 @@
 
 #. 7.1.1: There can be no static function declarations within a
 #. block.
-#: cp/decl.c:12497
+#: cp/decl.c:12521
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "statische Funktion innerhalb anderer Funktion kann nicht deklariert werden"
 
-#: cp/decl.c:12533
+#: cp/decl.c:12557
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "%<static%> darf nicht bei der Definition (im Gegensatz zu Deklaration) eines statischen Datenelementes verwendet werden"
 
-#: cp/decl.c:12540
+#: cp/decl.c:12564
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "statisches Element %qD als %<register%> deklariert"
 
-#: cp/decl.c:12546
+#: cp/decl.c:12570
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "Element %q#D kann nicht explizit deklariert werden, externe Bindung zu haben"
 
-#: cp/decl.c:12553
+#: cp/decl.c:12577
 #, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "Deklaration der %<constexpr%>-Variable %qD ist keine Definition"
 
-#: cp/decl.c:12574
+#: cp/decl.c:12598
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "Deklaration von %q#D hat keine Initialisierung"
 
-#: cp/decl.c:12585
+#: cp/decl.c:12609
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs initialisiert und als %<extern%> deklariert"
 
-#: cp/decl.c:12589
+#: cp/decl.c:12613
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs hat sowohl %<extern%> als auch Initialisierung"
 
-#: cp/decl.c:12754
+#: cp/decl.c:12778
 #, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "Standardargument %qE verwendet %qD"
 
-#: cp/decl.c:12757
+#: cp/decl.c:12781
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "Standardargument %qE verwendet lokale Variable %qD"
 
-#: cp/decl.c:12841
+#: cp/decl.c:12865
 #, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "ungültige Verwendung von cv-qualifiziertem Typ %qT in Parameterdeklaration"
 
-#: cp/decl.c:12845
+#: cp/decl.c:12869
 #, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "ungültige Verwendung von Typ %<void%> in Parameterdeklaration"
 
-#: cp/decl.c:12868
+#: cp/decl.c:12892
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "Parameter %qD deklariert ungültigerweise Methodentyp"
 
-#: cp/decl.c:12895
+#: cp/decl.c:12919
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "Parameter %qD bezieht Zeiger auf Feld mit unbekannter Grenze %qT ein"
 
-#: cp/decl.c:12897
+#: cp/decl.c:12921
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "Parameter %qD bezieht Referenz auf Feld mit unbekannter Grenze %qT ein"
@@ -42306,169 +42348,169 @@
 #. or implicitly defined), there's no need to worry about their
 #. existence.  Theoretically, they should never even be
 #. instantiated, but that's hard to forestall.
-#: cp/decl.c:13150
+#: cp/decl.c:13174
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "ungültiger Konstruktor; wahrscheinlich war %<%T (const %T&)%> gemeint"
 
-#: cp/decl.c:13228
+#: cp/decl.c:13252
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD darf nicht innerhalb eines Namensbereiches definiert werden"
 
-#: cp/decl.c:13234
+#: cp/decl.c:13258
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD darf nicht als »static« deklariert werden"
 
-#: cp/decl.c:13261
+#: cp/decl.c:13285
 #, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr "%qD muss eine nichtstatische Elementfunktion sein"
 
-#: cp/decl.c:13267
+#: cp/decl.c:13291
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD muss entweder eine nichtstatische Elementfunktion oder eine Nicht-Element-Funktion sein"
 
-#: cp/decl.c:13277
+#: cp/decl.c:13301
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD muss ein Argument von einem Klassen- oder Aufzählungstyp haben"
 
 #. 13.4.0.3
-#: cp/decl.c:13303
+#: cp/decl.c:13327
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading operator ?:"
 msgstr "ISO-C++ verbietet Überladen des Operators ?:"
 
 #. Variadic.
-#: cp/decl.c:13314
+#: cp/decl.c:13338
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "»%qD« darf keine variable Argumentanzahl haben"
 
-#: cp/decl.c:13338
+#: cp/decl.c:13362
 #, gcc-internal-format
 msgid "%qD must have either zero or one argument"
 msgstr "%qD muss entweder null oder ein Argument nehmen"
 
-#: cp/decl.c:13339
+#: cp/decl.c:13363
 #, gcc-internal-format
 msgid "%qD must have either one or two arguments"
 msgstr "%qD muss entweder ein oder zwei Argumente nehmen"
 
-#: cp/decl.c:13350
+#: cp/decl.c:13374
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "Suffix-%qD muss %<int%> als sein Argument nehmen"
 
-#: cp/decl.c:13351
+#: cp/decl.c:13375
 #, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "Suffix-%qD muss %<int%> als sein zweites Argument nehmen"
 
-#: cp/decl.c:13361
+#: cp/decl.c:13385
 #, gcc-internal-format
 msgid "%qD must have no arguments"
 msgstr "%qD darf keine Argumente nehmen"
 
-#: cp/decl.c:13362 cp/decl.c:13371
+#: cp/decl.c:13386 cp/decl.c:13395
 #, gcc-internal-format
 msgid "%qD must have exactly one argument"
 msgstr "%qD muss genau ein Argument nehmen"
 
-#: cp/decl.c:13372
+#: cp/decl.c:13396
 #, gcc-internal-format
 msgid "%qD must have exactly two arguments"
 msgstr "%qD muss genau zwei Argumente nehmen"
 
-#: cp/decl.c:13389 cp/decl.c:13392
+#: cp/decl.c:13413 cp/decl.c:13416
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD kann keine Standardargumente haben"
 
-#: cp/decl.c:13419
+#: cp/decl.c:13443
 #, gcc-internal-format
 msgid "conversion to a reference to void will never use a type conversion operator"
 msgstr "Umwandlung in Referenz auf void wird nie einen Typumwandlungsoperator verwenden"
 
-#: cp/decl.c:13421
+#: cp/decl.c:13445
 #, gcc-internal-format
 msgid "conversion to void will never use a type conversion operator"
 msgstr "Umwandlung in void wird nie einen Typumwandlungsoperator verwenden"
 
-#: cp/decl.c:13428
+#: cp/decl.c:13452
 #, gcc-internal-format
 msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgstr "Umwandlung in Referenz auf gleichen Typ wird nie einen Typumwandlungsoperator verwenden"
 
-#: cp/decl.c:13430
+#: cp/decl.c:13454
 #, gcc-internal-format
 msgid "conversion to the same type will never use a type conversion operator"
 msgstr "Umwandlung in gleichen Typ wird nie einen Typumwandlungsoperator verwenden"
 
-#: cp/decl.c:13438
+#: cp/decl.c:13462
 #, gcc-internal-format
 msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgstr "Umwandlung in Referenz auf Basisklasse wird nie einen Typumwandlungsoperator verwenden"
 
-#: cp/decl.c:13440
+#: cp/decl.c:13464
 #, gcc-internal-format
 msgid "conversion to a base class will never use a type conversion operator"
 msgstr "Umwandlung in Basisklasse wird nie einen Typumwandlungsoperator verwenden"
 
-#: cp/decl.c:13455
+#: cp/decl.c:13479
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "benutzerdefiniertes %qD wertet immer beide Argumente aus"
 
-#: cp/decl.c:13474
+#: cp/decl.c:13498
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "Präfix-%qD sollte %qT zurückgeben"
 
-#: cp/decl.c:13480
+#: cp/decl.c:13504
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "Suffix-%qD sollte %qT zurückgeben"
 
-#: cp/decl.c:13492
+#: cp/decl.c:13516
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD sollte Wert zurückgeben"
 
-#: cp/decl.c:13547
+#: cp/decl.c:13571
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "Templatetyp-Parameter %qT wird nach %qs verwendet"
 
-#: cp/decl.c:13570
+#: cp/decl.c:13594
 #, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "Templatespezialisierung alias %qT hinter %qs wird verwendet"
 
-#: cp/decl.c:13573
+#: cp/decl.c:13597
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "typedef-Name %qD wird nach %qs verwendet"
 
-#: cp/decl.c:13575
+#: cp/decl.c:13599
 #, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "%qD hat eine vorherige Deklaration hier"
 
-#: cp/decl.c:13583
+#: cp/decl.c:13607
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "%qT als %qs verwendet"
 
-#: cp/decl.c:13584 cp/decl.c:13591
+#: cp/decl.c:13608 cp/decl.c:13615
 #, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr "%qT hat hier eine vorherige Deklaration"
 
-#: cp/decl.c:13590
+#: cp/decl.c:13614
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "%qT als enum verwendet"
@@ -42480,94 +42522,94 @@
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:13605
+#: cp/decl.c:13629
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "Template-Argument für %<%s %T%> benötigt"
 
-#: cp/decl.c:13659 cp/name-lookup.c:4652
+#: cp/decl.c:13683 cp/name-lookup.c:4652
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD hat den gleichen Namen wie die Klasse, in der es deklariert wurde"
 
-#: cp/decl.c:13689 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6425
-#: cp/pt.c:9209
+#: cp/decl.c:13713 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6428
+#: cp/pt.c:9223
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT ist kein Template"
 
-#: cp/decl.c:13694
+#: cp/decl.c:13718
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr "Sie könnten ein explizites %<%T::%> hinzufügen"
 
-#: cp/decl.c:13703 cp/name-lookup.c:4079 cp/name-lookup.c:4086
-#: cp/name-lookup.c:4939 cp/parser.c:6376 cp/parser.c:26300
+#: cp/decl.c:13727 cp/name-lookup.c:4079 cp/name-lookup.c:4086
+#: cp/name-lookup.c:4939 cp/parser.c:6379 cp/parser.c:26297
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "Referenz auf %qD ist mehrdeutig"
 
-#: cp/decl.c:13806
+#: cp/decl.c:13830
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "Verwendung des enum %q#D ohne vorherige Deklaration"
 
-#: cp/decl.c:13842
+#: cp/decl.c:13866
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "Redeklaration von %qT als Nicht-Template"
 
-#: cp/decl.c:13982
+#: cp/decl.c:14006
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "abgeleitete Union %qT ist ungültig"
 
-#: cp/decl.c:13989
+#: cp/decl.c:14013
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr "%qT ist mit mehreren direkten Basisklassen definiert"
 
-#: cp/decl.c:14000
+#: cp/decl.c:14024
 #, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr "%qT ist mit direkter virtueller Basisklasse definiert"
 
-#: cp/decl.c:14025
+#: cp/decl.c:14049
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "Basistyp %qT ist kein struct- oder Klassentyp"
 
-#: cp/decl.c:14055
+#: cp/decl.c:14079
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "rekursiver Typ %qT nicht definiert"
 
-#: cp/decl.c:14057
+#: cp/decl.c:14081
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "doppelter Basistyp %qT ungültig"
 
-#: cp/decl.c:14202
+#: cp/decl.c:14226
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr "falsche Zuordnung zwischen innerhalb und außerhalb eines Gültigkeitsbereiches in enum %q#T"
 
-#: cp/decl.c:14205 cp/decl.c:14213 cp/decl.c:14225 cp/parser.c:18284
+#: cp/decl.c:14229 cp/decl.c:14237 cp/decl.c:14249 cp/parser.c:18281
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "vorherige Definition hier"
 
-#: cp/decl.c:14210
+#: cp/decl.c:14234
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr "falsche Zuordnung des zugrunde liegenden Typs in enum %q#T"
 
-#: cp/decl.c:14222
+#: cp/decl.c:14246
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr "anderer zugrunde liegender Typ in enum %q#T"
 
-#: cp/decl.c:14300
+#: cp/decl.c:14324
 #, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr "zugrunde liegender Typ %qT von %qT muss ein ganzzahliger Typ sein"
@@ -42576,77 +42618,77 @@
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:14447
+#: cp/decl.c:14471
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "kein Ganzzahltyp kann alle Aufzählungswerte für %qT darstellen"
 
-#: cp/decl.c:14619
+#: cp/decl.c:14643
 #, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "Aufzählungswert für %qD muss ganzzahligen oder Aufzählungstyp ohne Gültigkeitsbereich haben"
 
-#: cp/decl.c:14629
+#: cp/decl.c:14653
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "Aufzählungswert für %qD ist keine Ganzzahlkonstante"
 
-#: cp/decl.c:14678
+#: cp/decl.c:14702
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "erhöhter Aufzählungswert ist zu groß für %<unsigned long%>"
 
-#: cp/decl.c:14679
+#: cp/decl.c:14703
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "erhöhter Aufzählungswert ist zu groß für %<long%>"
 
-#: cp/decl.c:14690
+#: cp/decl.c:14714
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "Überlauf in Aufzählungswerten bei %qD"
 
-#: cp/decl.c:14710
+#: cp/decl.c:14734
 #, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "Aufzählungswert %qE ist außerhalb des Gültigkeitsbereichs des zugrundeliegenden Typen %qT"
 
-#: cp/decl.c:14821
+#: cp/decl.c:14845
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "Rückgabetyp %q#T ist unvollständig"
 
-#: cp/decl.c:14999 cp/typeck.c:9286
+#: cp/decl.c:15023 cp/typeck.c:9286
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> sollte eine Referenz auf %<*this%> zurückgeben"
 
-#: cp/decl.c:15344
+#: cp/decl.c:15368
 #, gcc-internal-format
 msgid "invalid function declaration"
 msgstr "ungültige Funktionsdeklaration"
 
-#: cp/decl.c:15786
+#: cp/decl.c:15810
 #, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr "keine return-Anweisungen in %qT zurückgebender Funktion"
 
-#: cp/decl.c:15788 cp/typeck.c:9166
+#: cp/decl.c:15812 cp/typeck.c:9166
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "nur einfacher Rückgabetyp %<auto%> kann zu %<void%> hergeleitet werden"
 
-#: cp/decl.c:15996
+#: cp/decl.c:16020
 #, gcc-internal-format
 msgid "invalid member function declaration"
 msgstr "ungültige Elementfunktionsdeklaration"
 
-#: cp/decl.c:16010
+#: cp/decl.c:16034
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD ist bereits in Klasse %qT definiert"
 
-#: cp/decl.c:16386
+#: cp/decl.c:16410
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr "Verwendung von %qD vor Herleitung von %<auto%>"
@@ -42686,7 +42728,7 @@
 msgid "deleting %qT is undefined"
 msgstr "Löschen von %qT ist nicht definiert"
 
-#: cp/decl2.c:585 cp/pt.c:5552
+#: cp/decl2.c:585 cp/pt.c:5566
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "Templatedeklaration von %q#D"
@@ -42699,7 +42741,7 @@
 #. [temp.mem]
 #.
 #. A destructor shall not be a member template.
-#: cp/decl2.c:640 cp/pt.c:5511
+#: cp/decl2.c:640 cp/pt.c:5525
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "Destruktor %qD als Element-Template deklariert"
@@ -42873,47 +42915,47 @@
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "%<operator delete%> nimmt Typ %qT als ersten Parameter"
 
-#: cp/decl2.c:2660
+#: cp/decl2.c:2650
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type has no linkage"
 msgstr "%qT hat ein Feld %qD, dessen Typ keine Bindung hat"
 
-#: cp/decl2.c:2664
+#: cp/decl2.c:2654
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr "%qT hat ein Feld %qD, dessen Typ vom Typ %qT abhängt, der wiederum keine Bindung hat"
 
-#: cp/decl2.c:2669
+#: cp/decl2.c:2659
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr "%qT hat ein Feld %qD, dessen Typ den anonymen Namensbereich verwendet"
 
-#: cp/decl2.c:2677
+#: cp/decl2.c:2667
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr "%qT mit bedeutenderer Sichtbarkeit als der Typ seines Feldes %qD deklariert"
 
-#: cp/decl2.c:2695
+#: cp/decl2.c:2685
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type has no linkage"
 msgstr "%qT hat Basis %qT, dessen Typ keine Bindung hat"
 
-#: cp/decl2.c:2699
+#: cp/decl2.c:2689
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type depends on the type %qT which has no linkage"
 msgstr "%qT hat Basis %qT, dessen Typ von Typ %qT abhängt, der wiederum keine Bindung hat"
 
-#: cp/decl2.c:2704
+#: cp/decl2.c:2694
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr "%qT hat Basis %qT, dessen Typ den anonymen Namensbereich verwendet"
 
-#: cp/decl2.c:2711
+#: cp/decl2.c:2701
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr "%qT mit bedeutenderer Sichtbarkeit als seine Basis %qT deklariert"
 
-#: cp/decl2.c:4309
+#: cp/decl2.c:4299
 #, gcc-internal-format
 msgid "%q#D, declared using unnamed type, is used but never defined"
 msgstr "%q#D (durch einen unbenannten Typen deklariert) wird verwendet, aber nirgends definiert"
@@ -42922,62 +42964,62 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4318
+#: cp/decl2.c:4308
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr "unbenannter Typ ohne Bindung wird verwendet, um Variable %q#D mit Bindung zu deklarieren"
 
-#: cp/decl2.c:4322
+#: cp/decl2.c:4312
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr "unbenannter Typ ohne Bindung wird verwendet, um Funktion %q#D mit Bindung zu deklarieren"
 
-#: cp/decl2.c:4326
+#: cp/decl2.c:4316
 #, gcc-internal-format
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr "%q#D verweist nicht auf den unqualifizierten Typen und wird daher nicht zum Binden verwendet"
 
-#: cp/decl2.c:4334
+#: cp/decl2.c:4324
 #, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "%q#D (durch lokalen Typen %qT deklariert) wird verwendet, aber nirgends definiert"
 
-#: cp/decl2.c:4338
+#: cp/decl2.c:4328
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr "Typ %qT ohne Bindung verwendet, um Variable %q#D mit Bindung zu deklarieren"
 
-#: cp/decl2.c:4341
+#: cp/decl2.c:4331
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "Typ %qT ohne Bindung für Funktionsdeklaration %q#D mit Bindung deklariert"
 
-#: cp/decl2.c:4529
+#: cp/decl2.c:4519
 #, gcc-internal-format
 msgid "mangling of %q#D as %qE conflicts with a previous mangle"
 msgstr "Mangeln von %q#D als %qE steht mit einer vorherigen Mangelung in Konflikt"
 
-#: cp/decl2.c:4532
+#: cp/decl2.c:4522
 #, gcc-internal-format
 msgid "previous mangling %q#D"
 msgstr "vorherige Mangelung von %q#D"
 
-#: cp/decl2.c:4534
+#: cp/decl2.c:4524
 #, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr "Eine spätere Option -fabi-version= (oder =0) verhindert diesen Fehler mit einer Änderung im Mangeln"
 
-#: cp/decl2.c:4606 cp/decl2.c:4609
+#: cp/decl2.c:4596 cp/decl2.c:4599
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr "das Programm sollte auch %qD definieren"
 
-#: cp/decl2.c:4956
+#: cp/decl2.c:4946
 #, gcc-internal-format
 msgid "inline function %qD used but never defined"
 msgstr "inline-Funktion %qD verwendet, aber nirgendwo definiert"
 
-#: cp/decl2.c:5143
+#: cp/decl2.c:5133
 #, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr "Standardargument fehlt für Parameter %P von %q+#D"
@@ -42984,17 +43026,17 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5251
+#: cp/decl2.c:5241
 #, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr "Lambda, das %<…%> verwendendet, wird in Funktionszeiger umgewandelt"
 
-#: cp/decl2.c:5254
+#: cp/decl2.c:5244
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "gelöschte Funktion %qD wird verwendet"
 
-#: cp/decl2.c:5307
+#: cp/decl2.c:5297
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr "Verwendung von eingebautem Parameterpack %qD außerhalb eines Templates"
@@ -43280,333 +43322,333 @@
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr "rekursive Instanziierung von Vorgabeinitialisierer für Element %qD"
 
-#: cp/init.c:613
+#: cp/init.c:629
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr "Vorgabeinitialisierer für Element %qD erforderlich vor dem Ende der umschließenden Klasse"
 
-#: cp/init.c:615
+#: cp/init.c:631
 #, gcc-internal-format
 msgid "defined here"
 msgstr "hier definiert"
 
-#: cp/init.c:673
+#: cp/init.c:689
 #, gcc-internal-format
 msgid "initializer for flexible array member %q#D"
 msgstr "Initialisierung eines flexiblen Arrayelements %q#D"
 
-#: cp/init.c:699
+#: cp/init.c:715
 #, gcc-internal-format
 msgid "%qD should be initialized in the member initialization list"
 msgstr "%qD sollte in Elementinitialisierungsliste initialisiert werden"
 
-#: cp/init.c:720
+#: cp/init.c:736
 #, gcc-internal-format
 msgid "%qD is initialized with itself"
 msgstr "%qD wird mit sich selbst initialisiert"
 
-#: cp/init.c:831
+#: cp/init.c:847
 #, gcc-internal-format
 msgid "invalid initializer for array member %q#D"
 msgstr "ungültige Initialisierung für Arrayelement %q#D"
 
-#: cp/init.c:845 cp/init.c:869 cp/init.c:2410 cp/method.c:1368
+#: cp/init.c:861 cp/init.c:885 cp/init.c:2427 cp/method.c:1368
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr "nicht initialisiertes konstantes Element in %q#T"
 
-#: cp/init.c:847 cp/init.c:864 cp/init.c:871 cp/init.c:2395 cp/init.c:2423
+#: cp/init.c:863 cp/init.c:880 cp/init.c:887 cp/init.c:2412 cp/init.c:2440
 #: cp/method.c:1371 cp/method.c:1382
 #, gcc-internal-format
 msgid "%q#D should be initialized"
 msgstr "%q#D sollte initialisiert werden"
 
-#: cp/init.c:862 cp/init.c:2382 cp/method.c:1379
+#: cp/init.c:878 cp/init.c:2399 cp/method.c:1379
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr "nicht initialisiertes Referenzelement in %q#T"
 
-#: cp/init.c:1041
+#: cp/init.c:1057
 #, gcc-internal-format
 msgid "%qD will be initialized after"
 msgstr "%qD wird initialisiert nach"
 
-#: cp/init.c:1044
+#: cp/init.c:1060
 #, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr "Basis %qT wird initialisiert nach"
 
-#: cp/init.c:1048
+#: cp/init.c:1064
 #, gcc-internal-format
 msgid "  %q#D"
 msgstr "  %q#D"
 
-#: cp/init.c:1050
+#: cp/init.c:1066
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr "  Basis %qT"
 
-#: cp/init.c:1052
+#: cp/init.c:1068
 #, gcc-internal-format
 msgid "  when initialized here"
 msgstr "  während es hier initialisiert wurde"
 
-#: cp/init.c:1069
+#: cp/init.c:1085
 #, gcc-internal-format
 msgid "multiple initializations given for %qD"
 msgstr "mehrere Initialisierungen für %qD angegeben"
 
-#: cp/init.c:1073
+#: cp/init.c:1089
 #, gcc-internal-format
 msgid "multiple initializations given for base %qT"
 msgstr "mehrere Initialisierungen für Basis %qT angegeben"
 
-#: cp/init.c:1158
+#: cp/init.c:1174
 #, gcc-internal-format
 msgid "initializations for multiple members of %qT"
 msgstr "Initialisierungen für mehrere Elemente von %qT"
 
-#: cp/init.c:1255
+#: cp/init.c:1271
 #, gcc-internal-format
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr "Basisklasse %q#T sollte explizit im Kopierkonstruktor initialisiert werden"
 
-#: cp/init.c:1482 cp/init.c:1501
+#: cp/init.c:1498 cp/init.c:1517
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr "Klasse %qT hat keinen Feldnamen %qD"
 
-#: cp/init.c:1488
+#: cp/init.c:1504
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr "%q#D« ist ein statisches Datenelement; es kann nur bei seiner Definition initialisiert werden"
 
-#: cp/init.c:1495
+#: cp/init.c:1511
 #, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr "%q#D ist kein Nicht-static-Datenelement von %qT"
 
-#: cp/init.c:1534
+#: cp/init.c:1550
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr "unbenannte Initialisierung für %qT, das keine Basisklassen hat"
 
-#: cp/init.c:1542
+#: cp/init.c:1558
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr "unbenannte Initialisierung für %qT, das Mehrfachvererbung verwendet"
 
-#: cp/init.c:1589
+#: cp/init.c:1605
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr "%qD ist sowohl eine direkte Basis als auch eine indirekte virtuelle Basis"
 
-#: cp/init.c:1597
+#: cp/init.c:1613
 #, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr "Typ %qT ist keine direkte oder virtuelle Basis von %qT"
 
-#: cp/init.c:1600
+#: cp/init.c:1616
 #, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr "Typ %qT ist keine direkte Basis von %qT"
 
-#: cp/init.c:1710 cp/init.c:4386 cp/typeck2.c:1175
+#: cp/init.c:1727 cp/init.c:4402 cp/typeck2.c:1175
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "Array muss mit Initialisierung mit umgebenden geschweiften Klammern initialisiert werden"
 
-#: cp/init.c:2019 cp/semantics.c:3268
+#: cp/init.c:2036 cp/semantics.c:3271
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qT ist kein Klassentyp"
 
-#: cp/init.c:2075
+#: cp/init.c:2092
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr "unvollständiger Typ %qT hat kein Element %qD"
 
-#: cp/init.c:2089
+#: cp/init.c:2106
 #, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr "ungültiger Zeiger auf Bitfeld %qD"
 
-#: cp/init.c:2175 cp/typeck.c:1893
+#: cp/init.c:2192 cp/typeck.c:1893
 #, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "ungültige Verwendung der nicht-statischen Elementfunktion %qD"
 
-#: cp/init.c:2182 cp/semantics.c:1835
+#: cp/init.c:2199 cp/semantics.c:1835
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "ungültige Verwendung des nicht-statischen Datenelementes %qD"
 
-#: cp/init.c:2379
+#: cp/init.c:2396
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr "nicht initialisiertes Referenzelement in %q#T verwendet %<new%> ohne new-Initialisierung"
 
-#: cp/init.c:2387
+#: cp/init.c:2404
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "nicht initialisiertes Referenzelement in Basis %q#T von %q#T verwendet %<new%> ohne new-Initialisierung"
 
-#: cp/init.c:2391
+#: cp/init.c:2408
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr "nicht initialisiertes Referenzelement in Basis %q#T von %q#T"
 
-#: cp/init.c:2407
+#: cp/init.c:2424
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr "nicht initialisiertes konstantes Element in %q#T verwendet %<new%> ohne new-Initialisierung"
 
-#: cp/init.c:2415
+#: cp/init.c:2432
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "nicht initialisiertes konstantes Element in Basis %q#T von %q#T verwendet %<new%> ohne new-Initialisierung"
 
-#: cp/init.c:2419
+#: cp/init.c:2436
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr "nicht initialisiertes konstantes Element in Basis %q#T von %q#T"
 
-#: cp/init.c:2710
+#: cp/init.c:2727
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr "Placement-New konstruiert ein Objekt vom Typ %<%T [%wu]%> und Größe %qwu in einer Region von Typ %qT und Größe %qwi"
 
-#: cp/init.c:2721
+#: cp/init.c:2738
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr "Placement-New konstruiert ein Array vom Typ %qT und Größe %qwu in einer Region von Typ %qT und Größe %qwi"
 
-#: cp/init.c:2732
+#: cp/init.c:2749
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr "Placement-New konstruiert ein Objekt vom Typ %qT und Größe %qwu in einer Region von Typ %qT und Größe %qwi"
 
-#: cp/init.c:2880
+#: cp/init.c:2896
 #, gcc-internal-format
 msgid "integer overflow in array size"
 msgstr "Ganzzahlüberlauf in Arraygröße"
 
-#: cp/init.c:2890
+#: cp/init.c:2906
 #, gcc-internal-format
 msgid "array size in new-expression must be constant"
 msgstr "Arraygröße in »new«-Ausdruck muss konstant sein"
 
-#: cp/init.c:2904
+#: cp/init.c:2920
 #, gcc-internal-format
 msgid "variably modified type not allowed in new-expression"
 msgstr "im »new«-Ausdruck ist kein variabel modifizierter Typ erlaubt"
 
-#: cp/init.c:2920
+#: cp/init.c:2936
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by typedef"
 msgstr "nichtkonstante Länge für neues Array muss direkt angegeben werden, nicht über typedef"
 
-#: cp/init.c:2922
+#: cp/init.c:2938
 #, gcc-internal-format
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr "Nichtkonstante Länge in Array-new muss ohne Klammern um die Typ-ID angegeben werden"
 
-#: cp/init.c:2932
+#: cp/init.c:2948
 #, gcc-internal-format
 msgid "invalid type %<void%> for new"
 msgstr "ungültiger Typ %<void%> für %<new%>"
 
-#: cp/init.c:2975
+#: cp/init.c:2991
 #, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr "nicht initialisierte Konstante in %<new%> von %q#T"
 
-#: cp/init.c:3101
+#: cp/init.c:3117
 #, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr "Kein passendes %qD in Klasse %qT gefunden"
 
-#: cp/init.c:3108 cp/search.c:1023
+#: cp/init.c:3124 cp/search.c:1026
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "Abfrage des Elementes %qD ist mehrdeutig"
 
-#: cp/init.c:3181
+#: cp/init.c:3197
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr "%<new%> für Typ %qT mit erweiterter Ausrichtung %d"
 
-#: cp/init.c:3184
+#: cp/init.c:3200
 #, gcc-internal-format
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr "verwendet %qD, das jedoch keinen Ausrichtungsparameter hat"
 
-#: cp/init.c:3187
+#: cp/init.c:3203
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr "verwenden Sie %<-faligned-new%>, um die C++17-Unterstützung für überausgerichtetes New einzuschalten"
 
-#: cp/init.c:3370
+#: cp/init.c:3386
 #, gcc-internal-format
 msgid "parenthesized initializer in array new"
 msgstr "geklammerte Initialisierung in Array-»new«"
 
-#: cp/init.c:3633
+#: cp/init.c:3649
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr "Größe des Arrays bei »new« muss Ganzzahltyp haben"
 
-#: cp/init.c:3665
+#: cp/init.c:3681
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr "»new« kann nicht auf Referenztyp angewendet werden"
 
-#: cp/init.c:3674
+#: cp/init.c:3690
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr "»new« kann nicht auf Funktionstyp angewendet werden"
 
-#: cp/init.c:3743
+#: cp/init.c:3759
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete [] operator:"
 msgstr "mögliches Problem bei Aufruf des »delete[]«-Operators erkannt"
 
-#: cp/init.c:3747
+#: cp/init.c:3763
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete [] will be called, even if they are declared when the class is defined"
 msgstr "weder der Destruktor noch der klassenspezifische Operator »delete[]« wird aufgerufen, auch wenn sie bei der Klassendefinition deklariert werden"
 
-#: cp/init.c:4295
+#: cp/init.c:4311
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "Initialisierung endet vorzeitig"
 
-#: cp/init.c:4599
+#: cp/init.c:4615
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr "unbekannte Arraygröße in »delete«"
 
-#: cp/init.c:4623
+#: cp/init.c:4639
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete operator:"
 msgstr "mögliches Problem bei Aufruf des »delete«-Operators erkannt"
 
-#: cp/init.c:4628
+#: cp/init.c:4644
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
 msgstr "weder der Destruktor noch der klassenspezifische Operator »delete« wird aufgerufen, auch wenn sie bei der Klassendefinition deklariert werden"
 
-#: cp/init.c:4642
+#: cp/init.c:4658
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr "Löschen des Objekts mit abstraktem Klassentyp %qT mit nicht-virtuellem Destruktor bewirkt undefiniertes Verhalten"
 
-#: cp/init.c:4647
+#: cp/init.c:4663
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr "Löschen des Objekts mit polymorphem Klassentyp %qT mit nicht-virtuellem Destruktor bewirkt möglicherweise undefiniertes Verhalten"
 
-#: cp/init.c:4954
+#: cp/init.c:4970
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "Typ für Vektor-»delete« ist weder Zeiger- noch Arraytyp"
@@ -44078,7 +44120,7 @@
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "Attribut %qD an nicht-»inline«-Namensraum wird ignoriert"
 
-#: cp/name-lookup.c:5111 cp/name-lookup.c:7065
+#: cp/name-lookup.c:5111 cp/name-lookup.c:7073
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "Attribut-Anweisung %qD wird ignoriert"
@@ -44126,53 +44168,53 @@
 msgid "it was later defined here"
 msgstr "es wurde später hier definiert"
 
-#: cp/name-lookup.c:6687
+#: cp/name-lookup.c:6695
 #, gcc-internal-format
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn't a template"
 msgstr "Deklaration von %<std::initializer_list%> entspricht nicht %<#include <initializer_list>%>, ist kein Template"
 
-#: cp/name-lookup.c:7059
+#: cp/name-lookup.c:7067
 #, gcc-internal-format
 msgid "strong using directive no longer supported"
 msgstr "starke %<using%>-Direktive wird nicht mehr unterstützt"
 
-#: cp/name-lookup.c:7062
+#: cp/name-lookup.c:7070
 #, gcc-internal-format
 msgid "you may use an inline namespace instead"
 msgstr "Sie können stattdessen einen %<inline%>-Namensraum verwenden"
 
-#: cp/name-lookup.c:7079
+#: cp/name-lookup.c:7087
 #, gcc-internal-format
 msgid "attributes ignored on local using directive"
 msgstr "Attribute werden an lokaler %<using%>-Direktive ignoriert"
 
-#: cp/name-lookup.c:7163
+#: cp/name-lookup.c:7171
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "Namensbereich-Alias %qD ist hier nicht erlaubt, %qD angenommen"
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:7183
+#: cp/name-lookup.c:7191
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot nest more than %d namespaces"
 msgstr "es können maximal %d Namensräume geschachtelt werden"
 
-#: cp/name-lookup.c:7218
+#: cp/name-lookup.c:7226
 #, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr "ein %<inline%>-Namensraum muss bei der ersten Definition angegeben werden"
 
-#: cp/name-lookup.c:7219
+#: cp/name-lookup.c:7227
 #, gcc-internal-format
 msgid "%qD defined here"
 msgstr "%qD hier definiert"
 
-#: cp/name-lookup.c:7292
+#: cp/name-lookup.c:7300
 #, gcc-internal-format
 msgid "XXX entering pop_everything ()\n"
 msgstr "XXX Eintritt in pop_everything ()\n"
 
-#: cp/name-lookup.c:7301
+#: cp/name-lookup.c:7309
 #, gcc-internal-format
 msgid "XXX leaving pop_everything ()\n"
 msgstr "XXX pop_everything () wird verlassen\n"
@@ -44192,7 +44234,7 @@
 msgid "LEXER_DEBUGGING_ENABLED_P is not set to true"
 msgstr "LEXER_DEBUGGING_ENABLED_P is not set to true"
 
-#: cp/parser.c:1352 cp/parser.c:37254
+#: cp/parser.c:1352 cp/parser.c:37251
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr "%<#pragma omp declare simd%> ist nicht direkt gefolgt von Funktionsdeklaration oder -definition"
@@ -44217,7 +44259,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr "Abfrage des Elementes %qE in Nicht-Klassentyp %qT"
 
-#: cp/parser.c:2949 cp/parser.c:18221
+#: cp/parser.c:2949 cp/parser.c:18218
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "%<%T::%E%> wurde nicht deklariert"
@@ -44297,7 +44339,7 @@
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "ISO-C++ verbietet Gleitkommaliterale in Konstanten-Ausdrücken"
 
-#: cp/parser.c:3143 cp/pt.c:17853
+#: cp/parser.c:3143 cp/pt.c:17890
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr "Eine Typumwandlung, die weder zu ganzzahligen noch Aufzählungstypen führt, kann nicht in einem Konstantenausdruck auftreten"
@@ -44519,7 +44561,7 @@
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr "literaler Operator für Zeichenketten %qD mit Argumenten %qT, %qT konnte nicht gefunden werden"
 
-#: cp/parser.c:4587 cp/parser.c:12940
+#: cp/parser.c:4587 cp/parser.c:12937
 #, gcc-internal-format
 msgid "expected declaration"
 msgstr "Deklaration erwartet"
@@ -44569,7 +44611,7 @@
 msgid "fold-expressions only available with -std=c++17 or -std=gnu++17"
 msgstr "Faltungsausdrücke sind nur mit -std=c++17 oder -std=gnu++17 verfügbar"
 
-#: cp/parser.c:5275 cp/parser.c:5452 cp/parser.c:5630 cp/semantics.c:3612
+#: cp/parser.c:5275 cp/parser.c:5452 cp/parser.c:5633 cp/semantics.c:3615
 #, gcc-internal-format
 msgid "expected primary-expression"
 msgstr "übergeordneter Ausdruck erwartet"
@@ -44589,92 +44631,92 @@
 msgid "local variable %qD may not appear in this context"
 msgstr "lokale Variable %qD darf in diesem Kontext nicht auftauchen"
 
-#: cp/parser.c:5787
+#: cp/parser.c:5790
 #, gcc-internal-format
 msgid "expected id-expression"
 msgstr "ID-Ausdruck erwartet"
 
-#: cp/parser.c:5919
+#: cp/parser.c:5922
 #, gcc-internal-format
 msgid "scope %qT before %<~%> is not a class-name"
 msgstr "Bereich %qT vor %<~%> ist kein Klassenname"
 
-#: cp/parser.c:5948 cp/parser.c:7860
+#: cp/parser.c:5951 cp/parser.c:7860
 #, gcc-internal-format
 msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgstr "%<~auto%> ist nur mit -std=c++14 oder -std=gnu++14 verfügbar"
 
-#: cp/parser.c:6059
+#: cp/parser.c:6062
 #, gcc-internal-format
 msgid "declaration of %<~%T%> as member of %qT"
 msgstr "Deklaration von %<~%T%> als Element von %qT"
 
-#: cp/parser.c:6074
+#: cp/parser.c:6077
 #, gcc-internal-format
 msgid "typedef-name %qD used as destructor declarator"
 msgstr "typedef-Name %qD als Destruktor-Deklarator verwendet"
 
-#: cp/parser.c:6111 cp/parser.c:20249
+#: cp/parser.c:6114 cp/parser.c:20246
 #, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr "unqualifizierte ID erwartet"
 
-#: cp/parser.c:6220
+#: cp/parser.c:6223
 #, gcc-internal-format
 msgid "found %<:%> in nested-name-specifier, expected %<::%>"
 msgstr "%<:%> in Spezifikation mit geschachteltem Namen gefunden, %<::%> erwartet"
 
-#: cp/parser.c:6288
+#: cp/parser.c:6291
 #, gcc-internal-format
 msgid "decltype evaluates to %qT, which is not a class or enumeration type"
 msgstr "decltype wird zu %qT ausgewertet, was keine Klasse oder Aufzählungstyp ist"
 
-#: cp/parser.c:6314
+#: cp/parser.c:6317
 #, gcc-internal-format
 msgid "function template-id %qD in nested-name-specifier"
 msgstr "Bezeichner %qD für Funktionstemplate ist geschachteltem Namens-Spezifizierer"
 
-#: cp/parser.c:6322
+#: cp/parser.c:6325
 #, gcc-internal-format
 msgid "variable template-id %qD in nested-name-specifier"
 msgstr "Bezeichner %qD für Variablentemplate ist geschachteltem Namens-Spezifizierer"
 
-#: cp/parser.c:6426 cp/typeck.c:2684 cp/typeck.c:2687 cp/typeck.c:2704
+#: cp/parser.c:6429 cp/typeck.c:2684 cp/typeck.c:2687 cp/typeck.c:2704
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD ist kein Template"
 
-#: cp/parser.c:6504
+#: cp/parser.c:6507
 #, gcc-internal-format
 msgid "expected nested-name-specifier"
 msgstr "Spezifikation mit geschachteltem Namen erwartet"
 
-#: cp/parser.c:6711 cp/parser.c:8950
+#: cp/parser.c:6714 cp/parser.c:8950
 #, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr "Typen dürfen nicht in Typumwandlungen definiert werden"
 
-#: cp/parser.c:6797
+#: cp/parser.c:6800
 #, gcc-internal-format
 msgid "types may not be defined in a %<typeid%> expression"
 msgstr "Typen dürfen nicht in einem %<typeid%>-Ausdruck definiert werden"
 
-#: cp/parser.c:6889
+#: cp/parser.c:6892
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "falsche Anzahl von Argumenten für %<__builtin_addressof%>"
 
-#: cp/parser.c:6901 cp/pt.c:18416
+#: cp/parser.c:6904 cp/pt.c:18453
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "falsche Anzahl von Argumenten für %<__builtin_launder%>"
 
-#: cp/parser.c:6995
+#: cp/parser.c:6998
 #, gcc-internal-format
 msgid "ISO C++ forbids compound-literals"
 msgstr "ISO-C++ verbietet zusammengesetzte Literale"
 
-#: cp/parser.c:7054
+#: cp/parser.c:7057
 #, gcc-internal-format
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr "zwei aufeinander folgende %<[%> dürfen nur ein Attribut einführen"
@@ -44804,7 +44846,7 @@
 msgid "capture of non-variable %qE"
 msgstr "Erfassung von Nicht-Variable %qE"
 
-#: cp/parser.c:10391 cp/parser.c:10401 cp/semantics.c:3453 cp/semantics.c:3465
+#: cp/parser.c:10391 cp/parser.c:10401 cp/semantics.c:3456 cp/semantics.c:3468
 #, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "%q#D hier deklariert"
@@ -44889,7 +44931,7 @@
 msgid "init-statement in selection statements only available with -std=c++17 or -std=gnu++17"
 msgstr "»init-statement in Auswahlanweisungen« ist nur mit -std=c++17 oder -std=gnu++17 verfügbar"
 
-#: cp/parser.c:11546 cp/parser.c:28490
+#: cp/parser.c:11546 cp/parser.c:28487
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "Auswahl-Anweisung erwartet"
@@ -44909,557 +44951,557 @@
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr "unvereinbare Anfang-/Ende-Typen in bereichsbasierter %<for%>-Anweisung: %qT und %qT"
 
-#: cp/parser.c:12250 cp/parser.c:28493
+#: cp/parser.c:12250 cp/parser.c:28490
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "Iterationsanweisung erwartet"
 
-#: cp/parser.c:12298
+#: cp/parser.c:12297
 #, gcc-internal-format
 msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
 msgstr "Bereichsbasierte %<for%>-Schleifen sind nur mit -std=c++11 oder -std=gnu++11 verfügbar"
 
-#: cp/parser.c:12426
+#: cp/parser.c:12423
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr "%<goto%> in %<constexpr%>-Funktion"
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:12434
+#: cp/parser.c:12431
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO-C++ verbietet berechnete Gotos"
 
-#: cp/parser.c:12447 cp/parser.c:28496
+#: cp/parser.c:12444 cp/parser.c:28493
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "Sprunganweisung erwartet"
 
-#: cp/parser.c:12620 cp/parser.c:23584
+#: cp/parser.c:12617 cp/parser.c:23581
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "zusätzliches %<;%>"
 
-#: cp/parser.c:12863
+#: cp/parser.c:12860
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr "%<__label__%> nicht am Anfang eines Blocks"
 
-#: cp/parser.c:13083
+#: cp/parser.c:13080
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr "Nicht-Variable %qD in Deklaration mit mehr als einem Deklarator mit Platzhaltertyp"
 
-#: cp/parser.c:13103
+#: cp/parser.c:13100
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr "widersprüchliche Herleitung für %qT: %qT und dann %qT"
 
-#: cp/parser.c:13124
+#: cp/parser.c:13121
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr "Vermischung von Deklarationen und Funktionsdefinitionen ist verboten"
 
-#: cp/parser.c:13148
+#: cp/parser.c:13145
 #, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr "in einer for-Bereichs-Deklaration dürfen keine Typen definiert werden"
 
-#: cp/parser.c:13203
+#: cp/parser.c:13200
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr "Initialisierung in bereichsbasierter %<for%>-Schleife"
 
-#: cp/parser.c:13206
+#: cp/parser.c:13203
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr "mehrere Deklarationen in bereichsbasierter %<for%>-Schleife"
 
-#: cp/parser.c:13257
+#: cp/parser.c:13254
 #, gcc-internal-format
 msgid "structured bindings only available with -std=c++17 or -std=gnu++17"
 msgstr "strukturierte Bindungen sind nur mit -std=c++17 oder -std=gnu++17 verfügbar"
 
-#: cp/parser.c:13306
+#: cp/parser.c:13303
 #, gcc-internal-format
 msgid "empty structured binding declaration"
 msgstr "leere Deklaration für strukturierte Bindung"
 
-#: cp/parser.c:13324
+#: cp/parser.c:13321
 #, gcc-internal-format
 msgid "invalid initializer for structured binding declaration"
 msgstr "ungültige Initialisierung für strukturierte Bindungsdeklaration"
 
-#: cp/parser.c:13491
+#: cp/parser.c:13488
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr "%<friend%> außerhalb einer Klasse verwendet"
 
-#: cp/parser.c:13558
+#: cp/parser.c:13555
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr "Bedeutung von %<auto%> ändert in C++11 die Bedeutung; Bitte entfernen"
 
-#: cp/parser.c:13594
+#: cp/parser.c:13591
 #, gcc-internal-format
 msgid "decl-specifier invalid in condition"
 msgstr "decl-Spezifizierung in Bedingung ungültig"
 
-#: cp/parser.c:13600
+#: cp/parser.c:13597
 #, gcc-internal-format
 msgid "%qD invalid in lambda"
 msgstr "%qD ungültig in Lambda"
 
-#: cp/parser.c:13693
+#: cp/parser.c:13690
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "Klassendefinition darf nicht als »friend« deklariert sein"
 
-#: cp/parser.c:13763 cp/parser.c:24064
+#: cp/parser.c:13760 cp/parser.c:24061
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr "Templates dürfen nicht %<virtual%> sein"
 
-#: cp/parser.c:13805
+#: cp/parser.c:13802
 #, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr "ungültige Bindungsspezifikation"
 
-#: cp/parser.c:13909
+#: cp/parser.c:13906
 #, gcc-internal-format
 msgid "static_assert without a message only available with -std=c++17 or -std=gnu++17"
 msgstr "static_assert ohne Text ist nur mit -std=c++17 oder -std=gnu++17 verfügbar"
 
-#: cp/parser.c:14111
+#: cp/parser.c:14108
 #, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr "Typen dürfen nicht in %<decltype%>-Ausdrücken definiert werden"
 
-#: cp/parser.c:14264
+#: cp/parser.c:14261
 #, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr "Typen dürfen nicht in einem »conversion-type-id« definiert werden"
 
-#: cp/parser.c:14291
+#: cp/parser.c:14288
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "ungültige Verwendung von %<auto%> in Umwandlungsoperator"
 
-#: cp/parser.c:14295
+#: cp/parser.c:14292
 #, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr "Verwendung von %<auto%> in Umwandlungsoperator von Elementtemplate kann niemals hergeleitet werden"
 
-#: cp/parser.c:14379
+#: cp/parser.c:14376
 #, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr "nur Konstruktoren nehmen Elementinitialisierungen"
 
-#: cp/parser.c:14406
+#: cp/parser.c:14403
 #, gcc-internal-format
 msgid "cannot expand initializer for member %qD"
 msgstr "Initialisierung für Element %qD kann nicht expandiert werden"
 
-#: cp/parser.c:14418 cp/pt.c:24255
+#: cp/parser.c:14415 cp/pt.c:24333
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "Speicherinitialisierung für %qD folgt Konstruktordelegation"
 
-#: cp/parser.c:14430 cp/pt.c:24267
+#: cp/parser.c:14427 cp/pt.c:24345
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr "Konstruktordelegation folgt Speicherinitialisierung für %qD"
 
-#: cp/parser.c:14482
+#: cp/parser.c:14479
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr "veraltete Basisklasseninitialisierung"
 
-#: cp/parser.c:14552
+#: cp/parser.c:14549
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr "Schlüsselwort %<typename%> in diesem Kontext nicht erlaubt (eine qualifizierte Elementinitialisierung ist implizit ein Typ)"
 
-#: cp/parser.c:14927
+#: cp/parser.c:14924
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr "unerwartetes Schlüsselwort; entfernen Sie Leerzeichen zwischen Anführungszeichen und Suffixbezeichner"
 
-#: cp/parser.c:14933
+#: cp/parser.c:14930
 #, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr "Suffixbezeichner erwartet"
 
-#: cp/parser.c:14942
+#: cp/parser.c:14939
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr "hinter Schlüsselwort %<operator%> wird leere Zeichenkette erwartet"
 
-#: cp/parser.c:14948
+#: cp/parser.c:14945
 #, gcc-internal-format
 msgid "invalid encoding prefix in literal operator"
 msgstr "ungültiges Encoding-Präfix in Literal-Operator"
 
-#: cp/parser.c:14975
+#: cp/parser.c:14972
 #, gcc-internal-format
 msgid "expected operator"
 msgstr "Operator erwartet"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:15020
+#: cp/parser.c:15017
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "Schlüsselwort %<export%> nicht implementiert, und wird ignoriert"
 
-#: cp/parser.c:15190
+#: cp/parser.c:15187
 #, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr "ungültiger beschränkter Typparameter"
 
-#: cp/parser.c:15198
+#: cp/parser.c:15195
 #, gcc-internal-format
 msgid "cv-qualified type parameter"
 msgstr "cv-qualifizierter Typparameter"
 
-#: cp/parser.c:15283
+#: cp/parser.c:15280
 #, gcc-internal-format
 msgid "variadic constraint introduced without %<...%>"
 msgstr "variadische Einschränkung ohne %<...%> eingeführt"
 
-#: cp/parser.c:15347
+#: cp/parser.c:15344
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "ungültige Verwendung von %<auto%> in Default-Templateargument"
 
-#: cp/parser.c:15582 cp/parser.c:15668 cp/parser.c:21694
+#: cp/parser.c:15579 cp/parser.c:15665 cp/parser.c:21691
 #, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "Templateparameterpack %qD kann kein Standardargument haben"
 
-#: cp/parser.c:15586 cp/parser.c:15672
+#: cp/parser.c:15583 cp/parser.c:15669
 #, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr "Template-Parameterpacks können keine Standardargumente haben"
 
-#: cp/parser.c:15738
+#: cp/parser.c:15735
 #, gcc-internal-format
 msgid "expected template-id"
 msgstr "Template-ID erwartet"
 
-#: cp/parser.c:15798
+#: cp/parser.c:15795
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "%<<::%> kann keine Templateargumentliste einleiten"
 
-#: cp/parser.c:15802
+#: cp/parser.c:15799
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr "%<<:%> ist eine andere Schreibweise für %<[%>. Leerraum zwischen %<<%> und %<::%> einfügen"
 
-#: cp/parser.c:15806
+#: cp/parser.c:15803
 #, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr "(bei Verwendung von %<-fpermissive%>, %<-std=c++11%> oder %<-std=gnu++11%> wird G++ den Code akzeptieren)"
 
-#: cp/parser.c:15924
+#: cp/parser.c:15921
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "Syntaxfehler in Templateargumentliste"
 
 #. The name does not name a template.
-#: cp/parser.c:15992 cp/parser.c:16122 cp/parser.c:16337
+#: cp/parser.c:15989 cp/parser.c:16119 cp/parser.c:16334
 #, gcc-internal-format
 msgid "expected template-name"
 msgstr "Templatename erwartet"
 
 #. Explain what went wrong.
-#: cp/parser.c:16038
+#: cp/parser.c:16035
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr "Nicht-Template %qD als Template verwendet"
 
-#: cp/parser.c:16040
+#: cp/parser.c:16037
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr "%<%T::template %D%> verwenden, um dies als Template zu kennzeichnen"
 
-#: cp/parser.c:16189
+#: cp/parser.c:16186
 #, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr "Parameterbündel vor %<...%> erwartet"
 
-#: cp/parser.c:16298 cp/parser.c:16316 cp/parser.c:16483
+#: cp/parser.c:16295 cp/parser.c:16313 cp/parser.c:16480
 #, gcc-internal-format
 msgid "expected template-argument"
 msgstr "Templateargument erwartet"
 
-#: cp/parser.c:16458
+#: cp/parser.c:16455
 #, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr "ungültiges Templateargument ohne Typ"
 
-#: cp/parser.c:16585
+#: cp/parser.c:16582
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "explizite Instanziierung darf kein %<inline%> verwenden"
 
-#: cp/parser.c:16589
+#: cp/parser.c:16586
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "explizite Instanziierung darf kein %<constexpr%> verwenden"
 
-#: cp/parser.c:16648
+#: cp/parser.c:16645
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr "Templatespezialisierung mit C-Bindung angegeben"
 
-#: cp/parser.c:16869
+#: cp/parser.c:16866
 #, gcc-internal-format
 msgid "expected type specifier"
 msgstr "Typspezifizierer erwartet"
 
-#: cp/parser.c:17053
+#: cp/parser.c:17050
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "Verwendung von %<auto%> in Lambda-Parameterdeklaration benötigt -std=c++14 oder -std=gnu++14"
 
-#: cp/parser.c:17059
+#: cp/parser.c:17056
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "Verwendung von %<auto%> in Parameterdeklaration benötigt -std=c++14 oder -std=gnu++14"
 
-#: cp/parser.c:17064
+#: cp/parser.c:17061
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -fconcepts"
 msgstr "Verwendung von %<auto%> in Parameterdeklaration benötigt -fconcepts"
 
-#: cp/parser.c:17209
+#: cp/parser.c:17206
 #, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "Template-ID für Typ erwartet"
 
-#: cp/parser.c:17278
+#: cp/parser.c:17275
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr "Typ-Name erwartet"
 
-#: cp/parser.c:17631
+#: cp/parser.c:17628
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr "ausführliche Typ-Spezifikation für einen enum mit Gültigkeitsbereich darf nicht das Schlüsselwort %qD verwenden"
 
-#: cp/parser.c:17854
+#: cp/parser.c:17851
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "Deklaration %qD deklariert nichts"
 
-#: cp/parser.c:17942
+#: cp/parser.c:17939
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "Attribute an instanziiertem Typen ignoriert"
 
-#: cp/parser.c:17946
+#: cp/parser.c:17943
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "Attribute an Templateinstanziierung ignoriert"
 
-#: cp/parser.c:17951
+#: cp/parser.c:17948
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr "Attribute an Spezifizierer ausführlichen Typs ignoriert, der keine Vorwärtsdeklaration ist"
 
-#: cp/parser.c:18085
+#: cp/parser.c:18082
 #, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "%qD ist ein Aufzählungstemplate"
 
-#: cp/parser.c:18096
+#: cp/parser.c:18093
 #, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr "%qD benennt keinen Aufzählungstyp in %qT"
 
-#: cp/parser.c:18111
+#: cp/parser.c:18108
 #, gcc-internal-format
 msgid "unnamed scoped enum is not allowed"
 msgstr "unbenanntes »enum« mit Gültigkeitsbereich ist nicht erlaubt"
 
-#: cp/parser.c:18166
+#: cp/parser.c:18163
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "%<;%> oder %<{%> erwartet"
 
-#: cp/parser.c:18215
+#: cp/parser.c:18212
 #, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "Aufzählungsliste kann nicht zu Template-Instanziierung hinzugefügt werden"
 
-#: cp/parser.c:18229
+#: cp/parser.c:18226
 #, gcc-internal-format
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "geschachtelter Namensgeber %qT für enum-Deklaration benennt weder Klasse noch Namensraum"
 
-#: cp/parser.c:18241 cp/parser.c:23070
+#: cp/parser.c:18238 cp/parser.c:23067
 #, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "Deklaration von %qD in Namensraum %qD, der nicht %qD einschließt"
 
-#: cp/parser.c:18246 cp/parser.c:23075
+#: cp/parser.c:18243 cp/parser.c:23072
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "Deklaration von %qD in %qD, das nicht %qD einschließt"
 
-#: cp/parser.c:18258 cp/parser.c:23089
+#: cp/parser.c:18255 cp/parser.c:23086
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr "zusätzliche Qualifizierung nicht erlaubt"
 
-#: cp/parser.c:18282
+#: cp/parser.c:18279
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "mehrfache Definition von %q#T"
 
-#: cp/parser.c:18295
+#: cp/parser.c:18292
 #, gcc-internal-format
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO-C++ verbietet leere unbenannte Aufzählung"
 
-#: cp/parser.c:18315
+#: cp/parser.c:18312
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr "intransparente Enum-Spezifikation ohne Namen"
 
-#: cp/parser.c:18318
+#: cp/parser.c:18315
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr "intransparente Enum-Spezifikation muss einfachen Bezeichner verwenden"
 
-#: cp/parser.c:18497
+#: cp/parser.c:18494
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD ist kein Namensbereichs-Name"
 
-#: cp/parser.c:18503
+#: cp/parser.c:18500
 #, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "Namensraumname erwartet"
 
-#: cp/parser.c:18570
+#: cp/parser.c:18567
 #, gcc-internal-format
 msgid "nested namespace definitions only available with -std=c++17 or -std=gnu++17"
 msgstr "verschachtelte Namensraumdefinitionen sind nur mit -std=c++17 oder -std=gnu++17 verfügbar"
 
-#: cp/parser.c:18578
+#: cp/parser.c:18575
 #, gcc-internal-format
 msgid "nested namespace name required"
 msgstr "Name eines geschachtelten Namensraums erwartet"
 
-#: cp/parser.c:18583
+#: cp/parser.c:18580
 #, gcc-internal-format
 msgid "namespace name required"
 msgstr "Name eines Namensraums erwartet"
 
-#: cp/parser.c:18587
+#: cp/parser.c:18584
 #, gcc-internal-format
 msgid "a nested namespace definition cannot have attributes"
 msgstr "eine verschachtelte Namensraum-Definition darf keine Attribute haben"
 
-#: cp/parser.c:18590
+#: cp/parser.c:18587
 #, gcc-internal-format
 msgid "a nested namespace definition cannot be inline"
 msgstr "eine verschachtelte Namensraumdefinition darf nicht inline sein"
 
-#: cp/parser.c:18597
+#: cp/parser.c:18594
 #, gcc-internal-format
 msgid "namespace %qD entered"
 msgstr "Namensbereich %qD betreten"
 
-#: cp/parser.c:18652
+#: cp/parser.c:18649
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "%<namespace%>-Definition ist hier nicht erlaubt"
 
-#: cp/parser.c:18803
+#: cp/parser.c:18800
 #, gcc-internal-format
 msgid "pack expansion in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr "Pack-Expansion in using-Deklaration ist nur mit -std=c++17 oder -std=gnu++17 verfügbar"
 
-#: cp/parser.c:18818
+#: cp/parser.c:18815
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "eine Template-ID darf nicht in »using«-Deklaration auftreten"
 
-#: cp/parser.c:18865
+#: cp/parser.c:18862
 #, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr "kommagetrennte Liste in using-Deklaration ist nur mit -std=c++17 oder -std=gnu++17 verfügbar"
 
-#: cp/parser.c:18875
+#: cp/parser.c:18872
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr "Zugriffsdeklarationen sind zugunsten von %<using%>-Deklarationen veraltet; Vorschlag: %<using%> hinzufügen"
 
-#: cp/parser.c:18940
+#: cp/parser.c:18937
 #, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "Typen dürfen nicht in Alias-Templatedeklarationen definiert werden"
 
-#: cp/parser.c:19106
+#: cp/parser.c:19103
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr "%<asm%> in %<constexpr%>-Funktion"
 
-#: cp/parser.c:19493
+#: cp/parser.c:19490
 #, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "eine Funktionsdefinition ist hier nicht erlaubt"
 
-#: cp/parser.c:19504
+#: cp/parser.c:19501
 #, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr "asm-Spezifikation ist bei Funktionsdefinition nicht erlaubt"
 
-#: cp/parser.c:19508
+#: cp/parser.c:19505
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "bei einer Funktionsdefinition sind keine Attribute erlaubt"
 
-#: cp/parser.c:19559
+#: cp/parser.c:19556
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr "Konstruktor, Destruktor oder Typumwandlung erwartet"
 
 #. Anything else is an error.
-#: cp/parser.c:19598 cp/parser.c:21906
+#: cp/parser.c:19595 cp/parser.c:21903
 #, gcc-internal-format
 msgid "expected initializer"
 msgstr "Initialisierung erwartet"
 
-#: cp/parser.c:19679
+#: cp/parser.c:19676
 #, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "Initialisierung für Funktion bereitgestellt"
 
-#: cp/parser.c:19713
+#: cp/parser.c:19710
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "Attribute hinter geklammerter Initialisierung werden ignoriert"
 
-#: cp/parser.c:19727
+#: cp/parser.c:19724
 #, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr "Nicht-Funktion %qD als implizites Template deklariert"
 
-#: cp/parser.c:20169
+#: cp/parser.c:20166
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "Arraygrenze ist keine Ganzzahlkonstante"
 
-#: cp/parser.c:20295
+#: cp/parser.c:20292
 #, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr "Element des abhängigen Typedef %qT kann nicht definiert werden"
 
-#: cp/parser.c:20299
+#: cp/parser.c:20296
 #, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "%<%T::%E%> ist kein Typ"
@@ -45468,17 +45510,17 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:20328
+#: cp/parser.c:20325
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr "ungültiger Deklarator"
 
-#: cp/parser.c:20336
+#: cp/parser.c:20333
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "ungültige Verwendung des Konstruktors als Template"
 
-#: cp/parser.c:20338
+#: cp/parser.c:20335
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr "%<%T::%D%> statt %<%T::%D%> verwenden, um den Konstruktor mit qualifiziertem Namen zu benennen"
@@ -45485,382 +45527,382 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:20410
+#: cp/parser.c:20407
 #, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr "qualified-id in Deklaration"
 
-#: cp/parser.c:20435
+#: cp/parser.c:20432
 #, gcc-internal-format
 msgid "expected declarator"
 msgstr "Deklarator erwartet"
 
-#: cp/parser.c:20554
+#: cp/parser.c:20551
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD ist ein Namensbereich"
 
-#: cp/parser.c:20556
+#: cp/parser.c:20553
 #, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "Zeiger auf Element der Nicht-Klasse %q#T kann nicht erzeugt werden"
 
-#: cp/parser.c:20577
+#: cp/parser.c:20574
 #, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "Ptr-Operator erwartet"
 
-#: cp/parser.c:20638
+#: cp/parser.c:20635
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "doppelter CV-Qualifizierer"
 
-#: cp/parser.c:20692
+#: cp/parser.c:20689
 #, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr "mehrere ref-qualifier"
 
-#: cp/parser.c:20729
+#: cp/parser.c:20726
 #, gcc-internal-format
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr "%qE benötigt %<-fgnu-tm%>"
 
-#: cp/parser.c:20787
+#: cp/parser.c:20784
 #, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "doppelter Virt-Spezifizierer"
 
-#: cp/parser.c:21025
+#: cp/parser.c:21022
 #, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr "fehlende Templateargumente nach %qT"
 
-#: cp/parser.c:21031 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2090
+#: cp/parser.c:21028 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2093
 #, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr "ungültige Verwendung von %qT"
 
-#: cp/parser.c:21052
+#: cp/parser.c:21049
 #, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "in Template-Argumenten dürfen keine Typen definiert werden"
 
-#: cp/parser.c:21057
+#: cp/parser.c:21054
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "ungültige Verwendung von %<auto%> in Templateargument"
 
-#: cp/parser.c:21145
+#: cp/parser.c:21142
 #, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "Typspezifikation erwartet"
 
-#: cp/parser.c:21429
+#: cp/parser.c:21426
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "%<,%> oder %<...%> erwartet"
 
-#: cp/parser.c:21504
+#: cp/parser.c:21501
 #, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr "Typen dürfen nicht in Parametertypen definiert werden"
 
-#: cp/parser.c:21678
+#: cp/parser.c:21675
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "Standardargumente sind nur für Funktionsparameter zugelassen"
 
-#: cp/parser.c:21696
+#: cp/parser.c:21693
 #, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "Parameterpack %qD kann kein Standardargument haben"
 
-#: cp/parser.c:21702
+#: cp/parser.c:21699
 #, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr "Templateparameterpack kann kein Standardargument haben"
 
-#: cp/parser.c:21704
+#: cp/parser.c:21701
 #, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr "Parameterpack kann kein Standardargument haben"
 
-#: cp/parser.c:22131
+#: cp/parser.c:22128
 #, gcc-internal-format
 msgid "C++ designated initializers only available with -std=c++2a or -std=gnu++2a"
 msgstr "erweiterte Initialisierungsliste ist nur mit -std=c++2a oder -std=gnu++2a verfügbar"
 
-#: cp/parser.c:22151
+#: cp/parser.c:22148
 #, gcc-internal-format
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr "ISO-C++ erlaubt keine benannten Initialisierungen (GNU)"
 
-#: cp/parser.c:22189
+#: cp/parser.c:22186
 #, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO-C++ erlaubt keine benannten Initialisierungen von C99"
 
-#: cp/parser.c:22203
+#: cp/parser.c:22200
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr "entweder sollten alle Initialisierer-Klauseln benannt sein oder gar keine"
 
-#: cp/parser.c:22228
+#: cp/parser.c:22225
 #, gcc-internal-format
 msgid "%<...%> not allowed in designated initializer list"
 msgstr "%<...%> ist in benannten Initialisierungen nicht erlaubt"
 
-#: cp/parser.c:22266
+#: cp/parser.c:22263
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr "%<.%s%>-Name wird mehrfach in derselben Initialisierungsliste verwendet"
 
-#: cp/parser.c:22322 cp/parser.c:22448
+#: cp/parser.c:22319 cp/parser.c:22445
 #, gcc-internal-format
 msgid "expected class-name"
 msgstr "Klassenname erwartet"
 
-#: cp/parser.c:22650
+#: cp/parser.c:22647
 #, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "%<;%> hinter Klassendefinition erwartet"
 
-#: cp/parser.c:22653
+#: cp/parser.c:22650
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "%<;%> hinter Strukturdefinition erwartet"
 
-#: cp/parser.c:22656
+#: cp/parser.c:22653
 #, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "%<;%> hinter Uniondefinition erwartet"
 
-#: cp/parser.c:23012
+#: cp/parser.c:23009
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "%<{%> oder %<:%> erwartet"
 
-#: cp/parser.c:23023
+#: cp/parser.c:23020
 #, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "für eine Klasse kann kein %<override%> angegeben werden"
 
-#: cp/parser.c:23031
+#: cp/parser.c:23028
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr "globale Qualifizierung von Klassenname ist ungültig"
 
-#: cp/parser.c:23038
+#: cp/parser.c:23035
 #, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "qualifizierter Name benennt keine Klasse"
 
-#: cp/parser.c:23050
+#: cp/parser.c:23047
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr "Schlüsselwort %<template%> nicht innerhalb des Klassenkopfnamens erlaubt"
 
-#: cp/parser.c:23056
+#: cp/parser.c:23053
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "ungültiger Klassenname in Deklaration von %qD"
 
-#: cp/parser.c:23114
+#: cp/parser.c:23111
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "einer expliziten Spezialisierung muss %<template <>%> vorausgehen"
 
-#: cp/parser.c:23146
+#: cp/parser.c:23143
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "Funktions-Template %qD als Klassentemplate redeklariert"
 
-#: cp/parser.c:23182
+#: cp/parser.c:23179
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr "Typnamen-Typ kann nicht aufgelöst werden"
 
-#: cp/parser.c:23241
+#: cp/parser.c:23238
 #, gcc-internal-format
 msgid "previous definition of %q#T"
 msgstr "vorherige Definition von %q#T"
 
-#: cp/parser.c:23331 cp/parser.c:28499
+#: cp/parser.c:23328 cp/parser.c:28496
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr "Klassenschlüssel erwartet"
 
-#: cp/parser.c:23355
+#: cp/parser.c:23352
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++17 or -std=gnu++17"
 msgstr "ISO-C++ verbietet Typname-Schlüssel in Template-Template-Parameter; verwenden Sie -std=c++17 oder -std=gnu++17"
 
-#: cp/parser.c:23359
+#: cp/parser.c:23356
 #, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "%<class%> oder %<typename%> erwartet"
 
-#: cp/parser.c:23605
+#: cp/parser.c:23602
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr "in C++03 muss bei Deklaration eines »friend« ein Klassenschlüssel verwendet werden"
 
-#: cp/parser.c:23623
+#: cp/parser.c:23620
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "»friend«-Deklaration benennt keine Klasse oder Funktion"
 
-#: cp/parser.c:23641
+#: cp/parser.c:23638
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr "Speicherklasse an anonymem Aggregat im Klassenbereich ist nicht erlaubt"
 
-#: cp/parser.c:23738
+#: cp/parser.c:23735
 #, gcc-internal-format
 msgid "default member initializers for bit-fields only available with -std=c++2a or -std=gnu++2a"
 msgstr "Defaultinitialisierer für Bitfeld-Elemente sind nur mit -std=c++2a oder -std=gnu++2a verfügbar"
 
-#: cp/parser.c:23745
+#: cp/parser.c:23742
 #, gcc-internal-format
 msgid "default member initializer for unnamed bit-field"
 msgstr "Defaultinitialisierer für unbenanntes Bitfeld-Element"
 
-#: cp/parser.c:23758
+#: cp/parser.c:23755
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr "ISO C++ erlaubt Bitfeld-Attribute nur vor dem %<:%>-Token"
 
-#: cp/parser.c:23903
+#: cp/parser.c:23900
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr "reiner Spezifizierer bei Funktionsdefinition"
 
-#: cp/parser.c:23923
+#: cp/parser.c:23920
 #, gcc-internal-format
 msgid "extra %<;%> after in-class function definition"
 msgstr "zusätzliches %<;%> hinter Funktionsdefinition innerhalb einer Klasse"
 
-#: cp/parser.c:23970
+#: cp/parser.c:23967
 #, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr "überflüssiges %<,%> am Ende der Elementdeklaration"
 
-#: cp/parser.c:23984
+#: cp/parser.c:23981
 #, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "%<;%> am Ende von Elementdeklaration erwartet"
 
-#: cp/parser.c:24058
+#: cp/parser.c:24055
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr "ungültige reine Spezifikation (nur %<= 0%> ist erlaubt)"
 
-#: cp/parser.c:24093
+#: cp/parser.c:24090
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "eine geschweift geklammerte Initialisierung ist hier nicht erlaubt"
 
-#: cp/parser.c:24223
+#: cp/parser.c:24220
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr "%<virtual%> mehr als einmal in Basisspezifikation angegeben"
 
-#: cp/parser.c:24243
+#: cp/parser.c:24240
 #, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr "mehr als ein Zugriff in Basisspezifikation angegeben"
 
-#: cp/parser.c:24267
+#: cp/parser.c:24264
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "Schlüsselwort %<typename%> nicht außerhalb von Templates erlaubt"
 
-#: cp/parser.c:24270
+#: cp/parser.c:24267
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "Schlüsselwort %<typename%> nicht erlaubt in diesem Kontext (die Basisklasse ist implizit ein Typ)"
 
-#: cp/parser.c:24364 cp/parser.c:24442
+#: cp/parser.c:24361 cp/parser.c:24439
 #, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "Typen dürfen nicht in einer Ausnahmespezifikation definiert werden"
 
-#: cp/parser.c:24450
+#: cp/parser.c:24447
 #, gcc-internal-format
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "ISO C++17 erlaubt keine dynamischen Ausnahmespezifikationen"
 
-#: cp/parser.c:24456
+#: cp/parser.c:24453
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr "dynamische Ausnahmespezifikationen sind in C++11 veraltet"
 
-#: cp/parser.c:24500
+#: cp/parser.c:24497
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "ungültige Verwendung von %<auto%> in Ausnahmespezifikation"
 
-#: cp/parser.c:24539
+#: cp/parser.c:24536
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr "%<try%> in %<constexpr%>-Funktion"
 
-#: cp/parser.c:24650
+#: cp/parser.c:24647
 #, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr "Typen dürfen nicht in Ausnahmedeklarationen definiert werden"
 
-#: cp/parser.c:25203
+#: cp/parser.c:25200
 #, gcc-internal-format
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr "Attribut, das Präfix verwendet, wird zusammen mit Gültigkeitsbereich-Attribut-Token verwendet"
 
-#: cp/parser.c:25217
+#: cp/parser.c:25214
 #, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr "Bezeichner für den Attributnamen erwartet"
 
-#: cp/parser.c:25301
+#: cp/parser.c:25298
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr "Attribut %<noreturn%> darf höchstens einmal in einer Attributliste auftreten"
 
-#: cp/parser.c:25305
+#: cp/parser.c:25302
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr "Attribut %<deprecated%> darf höchstens einmal in einer Attributliste auftreten"
 
-#: cp/parser.c:25342
+#: cp/parser.c:25339
 #, gcc-internal-format
 msgid "expected attribute before %<...%>"
 msgstr "Attribut vor %<...%> erwartet"
 
-#: cp/parser.c:25403
+#: cp/parser.c:25400
 #, gcc-internal-format
 msgid "attribute using prefix only available with -std=c++17 or -std=gnu++17"
 msgstr "Attribut mit Präfix ist nur mit -std=c++17 oder -std=gnu++17 verfügbar"
 
-#: cp/parser.c:25721
+#: cp/parser.c:25718
 #, gcc-internal-format
 msgid "%<requires%> only available with -fconcepts"
 msgstr "%<requires%> ist nur mit -fconcepts verfügbar"
 
-#: cp/parser.c:25753
+#: cp/parser.c:25750
 #, gcc-internal-format
 msgid "a requires expression cannot appear outside a template"
 msgstr "ein requires-Ausdruck darf nicht außerhalb eines Templates auftreten"
 
-#: cp/parser.c:26467
+#: cp/parser.c:26464
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr "spezialisierendes Element %<%T::%E%> erfordert Syntax %<template<>%>"
 
-#: cp/parser.c:26472
+#: cp/parser.c:26469
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "ungültige Deklaration von %<%T::%E%>"
 
-#: cp/parser.c:26476
+#: cp/parser.c:26473
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "zu wenige Templateparameterlisten"
@@ -45869,453 +45911,453 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:26483
+#: cp/parser.c:26480
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "zu viele Templateparameterlisten"
 
-#: cp/parser.c:26832
+#: cp/parser.c:26829
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "benannte Rückgabewerte werden nicht mehr unterstützt"
 
-#: cp/parser.c:26991
+#: cp/parser.c:26988
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr "Literales Operatortemplate %qD hat ungültige Parameterliste. Nicht-Typ Templateargumentpack <char…> oder <typename CharT, CharT…> erwartet"
 
-#: cp/parser.c:26996
+#: cp/parser.c:26993
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr "Literales Operatortemplate %qD hat ungültige Parameterliste. Template für Nicht-Typ Argumentpack <char...> erwartet"
 
-#: cp/parser.c:27066
+#: cp/parser.c:27063
 #, gcc-internal-format
 msgid "empty introduction-list"
 msgstr "leere introduction-list"
 
-#: cp/parser.c:27090
+#: cp/parser.c:27087
 #, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr "kein passendes Konzept für template-introduction"
 
-#: cp/parser.c:27112
+#: cp/parser.c:27109
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "ungültige Deklaration eines Elementtemplates in lokaler Klasse"
 
-#: cp/parser.c:27121
+#: cp/parser.c:27118
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "Template mit C-Bindung"
 
-#: cp/parser.c:27141
+#: cp/parser.c:27138
 #, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "ungültige explizite Spezialisierung"
 
-#: cp/parser.c:27245
+#: cp/parser.c:27242
 #, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "Templatedeklaration von %<typedef%>"
 
-#: cp/parser.c:27296
+#: cp/parser.c:27293
 #, gcc-internal-format
 msgid "a class template declaration must not declare anything else"
 msgstr "eine Klassen-Templatedeklaration darf nichts anderes deklarieren"
 
-#: cp/parser.c:27342
+#: cp/parser.c:27339
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "explizite Template-Spezialisierung kann keine Speicherklasse haben"
 
-#: cp/parser.c:27650
+#: cp/parser.c:27647
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%<>>%> sollte innerhalb einer geschachtelten Templateargumentliste %<> >%> sein"
 
-#: cp/parser.c:27663
+#: cp/parser.c:27660
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "falsches %<>>%>; %<>%> verwenden, um eine Templateargumentliste zu beenden"
 
-#: cp/parser.c:27958
+#: cp/parser.c:27955
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr "Argument von %<sizeof...%> muss mit Klammern umschlossen werden"
 
-#: cp/parser.c:28118
+#: cp/parser.c:28115
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "ungültige Verwendung von %qD in Spezifizierung der Bindung"
 
-#: cp/parser.c:28133
+#: cp/parser.c:28130
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> vor %qD"
 
-#: cp/parser.c:28267
+#: cp/parser.c:28264
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO-C++ 1998 unterstützt nicht %<long long%>"
 
-#: cp/parser.c:28275
+#: cp/parser.c:28272
 #, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "sowohl %<__thread%> als auch %<thread_local%> angegeben"
 
-#: cp/parser.c:28280
+#: cp/parser.c:28277
 #, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "doppeltes %qD"
 
-#: cp/parser.c:28304
+#: cp/parser.c:28301
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "doppeltes %qs"
 
-#: cp/parser.c:28356
+#: cp/parser.c:28353
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "%<new%> erwartet"
 
-#: cp/parser.c:28359
+#: cp/parser.c:28356
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "%<delete%> erwartet"
 
-#: cp/parser.c:28362
+#: cp/parser.c:28359
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "%<return%> erwartet"
 
-#: cp/parser.c:28368
+#: cp/parser.c:28365
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "%<extern%> erwartet"
 
-#: cp/parser.c:28371
+#: cp/parser.c:28368
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "%<static_assert%> erwartet"
 
-#: cp/parser.c:28374
+#: cp/parser.c:28371
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "%<decltype%> erwartet"
 
-#: cp/parser.c:28377
+#: cp/parser.c:28374
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "%<operator%> erwartet"
 
-#: cp/parser.c:28380
+#: cp/parser.c:28377
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "%<class%> erwartet"
 
-#: cp/parser.c:28383
+#: cp/parser.c:28380
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "%<template%> erwartet"
 
-#: cp/parser.c:28386
+#: cp/parser.c:28383
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "%<namespace%> erwartet"
 
-#: cp/parser.c:28389
+#: cp/parser.c:28386
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "%<using%> erwartet"
 
-#: cp/parser.c:28392
+#: cp/parser.c:28389
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "%<asm%> erwartet"
 
-#: cp/parser.c:28395
+#: cp/parser.c:28392
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "%<try%> erwartet"
 
-#: cp/parser.c:28398
+#: cp/parser.c:28395
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "%<catch%> erwartet"
 
-#: cp/parser.c:28401
+#: cp/parser.c:28398
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "%<throw%> erwartet"
 
-#: cp/parser.c:28404
+#: cp/parser.c:28401
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "%<__label__%> erwartet"
 
-#: cp/parser.c:28407
+#: cp/parser.c:28404
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "%<@try%> erwartet"
 
-#: cp/parser.c:28410
+#: cp/parser.c:28407
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "%<@synchronized%> erwartet"
 
-#: cp/parser.c:28413
+#: cp/parser.c:28410
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "%<@throw%> erwartet"
 
-#: cp/parser.c:28416
+#: cp/parser.c:28413
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "%<__transaction_atomic%> erwartet"
 
-#: cp/parser.c:28419
+#: cp/parser.c:28416
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "%<__transaction_relaxed%> erwartet"
 
-#: cp/parser.c:28451
+#: cp/parser.c:28448
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "%<::%> erwartet"
 
-#: cp/parser.c:28463
+#: cp/parser.c:28460
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "%<...%> erwartet"
 
-#: cp/parser.c:28466
+#: cp/parser.c:28463
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "%<*%> erwartet"
 
-#: cp/parser.c:28469
+#: cp/parser.c:28466
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "%<~%> erwartet"
 
-#: cp/parser.c:28475
+#: cp/parser.c:28472
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "%<:%> oder %<::%> erwartet"
 
-#: cp/parser.c:28502
+#: cp/parser.c:28499
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "%<class%>, %<typename%> oder %<template%> erwartet"
 
-#: cp/parser.c:28772
+#: cp/parser.c:28769
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "Markierung %qs bei Benennung von %q#T verwendet"
 
-#: cp/parser.c:28777
+#: cp/parser.c:28774
 #, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "%q#T wurde vorher hier deklariert"
 
-#: cp/parser.c:28798
+#: cp/parser.c:28795
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD mit anderem Zugriff redeklariert"
 
-#: cp/parser.c:28819
+#: cp/parser.c:28816
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "in C++98 ist %<template%> (zum eindeutig machen) nur innerhalb von Templates erlaubt"
 
-#: cp/parser.c:29062
+#: cp/parser.c:29059
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "Datei endet in Standardargument"
 
-#: cp/parser.c:29303 cp/parser.c:30620 cp/parser.c:30808
+#: cp/parser.c:29300 cp/parser.c:30617 cp/parser.c:30805
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "unpassendes Objective-C++-Konstrukt %<@%D%>"
 
-#: cp/parser.c:29372
+#: cp/parser.c:29369
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr "Objective-C++-Nachrichtenempfänger erwartet"
 
-#: cp/parser.c:29442
+#: cp/parser.c:29439
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr "Objective-C++ Nachrichtenargument(e) erwartet"
 
-#: cp/parser.c:29473
+#: cp/parser.c:29470
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "%<@encode%> muss als Argument einen Typen angeben"
 
-#: cp/parser.c:29883
+#: cp/parser.c:29880
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "Ungültiger Objective-C++-Selektorname"
 
-#: cp/parser.c:29958 cp/parser.c:29976
+#: cp/parser.c:29955 cp/parser.c:29973
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr "Objective-C++ Methodendeklaration erwartet"
 
-#: cp/parser.c:29970 cp/parser.c:30035
+#: cp/parser.c:29967 cp/parser.c:30032
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "Methodenattribute müssen am Ende angegeben werden"
 
-#: cp/parser.c:30078
+#: cp/parser.c:30075
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr "überflüssiges %qs zwischen Objective-C++ Methoden"
 
-#: cp/parser.c:30284 cp/parser.c:30291 cp/parser.c:30298
+#: cp/parser.c:30281 cp/parser.c:30288 cp/parser.c:30295
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "ungültiger Typ für Instanzvariable"
 
-#: cp/parser.c:30413
+#: cp/parser.c:30410
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "Bezeichner nach %<@protocol%> erwartet"
 
-#: cp/parser.c:30585
+#: cp/parser.c:30582
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr "Attribute dürfen nicht vor dem Objective-C++-Schlüsselwort %<@%D%> angegeben werden"
 
-#: cp/parser.c:30592
+#: cp/parser.c:30589
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "Präfix-Attribute vor %<@%D%> werden ignoriert"
 
-#: cp/parser.c:30867 cp/parser.c:30874 cp/parser.c:30881
+#: cp/parser.c:30864 cp/parser.c:30871 cp/parser.c:30878
 #, gcc-internal-format
 msgid "invalid type for property"
 msgstr "ungültiger Typ für Eigenschaft"
 
-#: cp/parser.c:32011
+#: cp/parser.c:32008
 #, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr "%<wait%>-Ausdruck muss ganzzahlig sein"
 
-#: cp/parser.c:32724
+#: cp/parser.c:32721
 #, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr "ungültiger reduction-identifier"
 
-#: cp/parser.c:34911
+#: cp/parser.c:34908
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr "geklammerte Initialisierung ist in OpenMP-%<for%>-Schleife nicht erlaubt"
 
-#: cp/parser.c:35231 cp/pt.c:16392
+#: cp/parser.c:35228 cp/pt.c:16414
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "Schleifenvariable %qD sollte keine Reduktion sein"
 
-#: cp/parser.c:35316
+#: cp/parser.c:35313
 #, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr "zu wenige for-Schleifen um sie einzuklappen"
 
-#: cp/parser.c:37521
+#: cp/parser.c:37518
 #, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr "ungültige Initialisierungsklausel"
 
-#: cp/parser.c:37549
+#: cp/parser.c:37546
 #, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "»id-expression (arguments)« erwartet"
 
-#: cp/parser.c:37561
+#: cp/parser.c:37558
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr "eins der Aufrufargumente für die Initialisierung sollte %<omp_priv%> oder %<&omp_priv%> sein"
 
-#: cp/parser.c:37662
+#: cp/parser.c:37659
 #, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr "neue Typen dürfen nicht in einem Rückgabetyp definiert werden"
 
-#: cp/parser.c:37682 cp/semantics.c:5405
+#: cp/parser.c:37679 cp/semantics.c:5408
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr "vordeklarierter arithmetischer Typ %qT in %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:37687 cp/semantics.c:5414
+#: cp/parser.c:37684 cp/semantics.c:5417
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr "Funktions- oder Arraytyp %qT in %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:37690 cp/pt.c:12944 cp/semantics.c:5420
+#: cp/parser.c:37687 cp/pt.c:12966 cp/semantics.c:5423
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr "Referenztyp %qT in %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:37693 cp/semantics.c:5426
+#: cp/parser.c:37690 cp/semantics.c:5429
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr "const-, volatile- oder __restrict-qualifizierter Typ %qT in %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:38047
+#: cp/parser.c:38044
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr "%<#pragma acc routine%> benennt eine Menge von Überladungen"
 
-#: cp/parser.c:38057
+#: cp/parser.c:38054
 #, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr "%qD bezeichnet keine Funktion innerhalb eines Namensraum"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:38392
+#: cp/parser.c:38389
 #, gcc-internal-format
 msgid "atomic_cancel"
 msgstr "atomic_cancel"
 
-#: cp/parser.c:38435 cp/semantics.c:8575
+#: cp/parser.c:38432 cp/semantics.c:8578
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr "%<__transaction_relaxed%> ohne eingeschaltete Unterstützung für transaktionsgebundenen Speicher"
 
-#: cp/parser.c:38437 cp/semantics.c:8577
+#: cp/parser.c:38434 cp/semantics.c:8580
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr "%<__transaction_atomic%> ohne eingeschaltete Unterstützung für transaktionsgebundenen Speicher"
 
-#: cp/parser.c:38631
+#: cp/parser.c:38628
 #, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "Ausschuss am Ende von %<#pragma GCC pch_preprocess%>"
 
-#: cp/parser.c:38927
+#: cp/parser.c:38924
 #, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "%<#pragma GCC ivdep%> muss innerhalb einer Funktion sein"
 
-#: cp/parser.c:38959
+#: cp/parser.c:38956
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr "%<#pragma GCC unroll%> muss innerhalb einer Funktion sein"
 
-#: cp/parser.c:39039
+#: cp/parser.c:39036
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "Optimierungen zwischen Modulen noch nicht implementiert für C++"
 
-#: cp/parser.c:39295
+#: cp/parser.c:39292
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr "Implizite Templates dürfen nicht %<virtual%> sein"
 
-#: cp/parser.c:39351
+#: cp/parser.c:39348
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr "%<extern \"C\"%>-Bindung beginnt hier"
@@ -46402,7 +46444,7 @@
 msgid "specialization of %qD after instantiation"
 msgstr "Spezialisierung von %qD nach Instanziierung"
 
-#: cp/pt.c:1954 cp/semantics.c:5274
+#: cp/pt.c:1954 cp/semantics.c:5277
 #, gcc-internal-format
 msgid "%s %#qD"
 msgstr "%s %#qD"
@@ -46568,107 +46610,107 @@
 msgid "argument to __integer_pack must be between 0 and %d"
 msgstr "Argument von __integer_pack muss zwischen 0 und %d liegen"
 
-#: cp/pt.c:3942
+#: cp/pt.c:3955
 #, gcc-internal-format
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr "Expansion der Basisinitialisierung %qT enthält keine Parameterpacks"
 
-#: cp/pt.c:4010
+#: cp/pt.c:4023
 #, gcc-internal-format
 msgid "expansion pattern %qT contains no argument packs"
 msgstr "Expansionsmuster %qT enthält keine Argumentpacks"
 
-#: cp/pt.c:4012
+#: cp/pt.c:4025
 #, gcc-internal-format
 msgid "expansion pattern %qE contains no argument packs"
 msgstr "Expansionsmuster %qE enthält keine Argumentpacks"
 
-#: cp/pt.c:4063
+#: cp/pt.c:4077
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr "Parameterbündel nicht mit %<...%> aufgelöst:"
 
-#: cp/pt.c:4080 cp/pt.c:4835
+#: cp/pt.c:4094 cp/pt.c:4849
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
 
-#: cp/pt.c:4082
+#: cp/pt.c:4096
 #, gcc-internal-format
 msgid "        <anonymous>"
 msgstr "        <anonym>"
 
-#: cp/pt.c:4208
+#: cp/pt.c:4222
 #, gcc-internal-format
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr "Deklaration des Templateparameters %q+D überdeckt einen Templateparameter"
 
-#: cp/pt.c:4211
+#: cp/pt.c:4225
 #, gcc-internal-format
 msgid "declaration of %q+#D shadows template parameter"
 msgstr "Deklaration von %q+#D überdeckt einen Templateparameter"
 
-#: cp/pt.c:4213
+#: cp/pt.c:4227
 #, gcc-internal-format
 msgid "template parameter %qD declared here"
 msgstr "Templateparameter %qD hier deklariert"
 
-#: cp/pt.c:4771
+#: cp/pt.c:4785
 #, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr "Spezialisierung des Variablenkonzepts %q#D"
 
-#: cp/pt.c:4830
+#: cp/pt.c:4844
 #, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr "Templateparameter nicht in partieller Spezialisierung herleitbar:"
 
-#: cp/pt.c:4854
+#: cp/pt.c:4868
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr "Teilspezialisierung %q+D spezialisiert keine Templateargumente; um das primäre Template zu definieren, entfernen Sie die Templateargumentliste"
 
-#: cp/pt.c:4858
+#: cp/pt.c:4872
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr "Teilspezialisierung %q+D spezialisiert keine Templateargumente und ist nicht eingeschränkter als das primäre Template; um das primäre Template zu definieren, entfernen Sie die Templateargumentliste"
 
-#: cp/pt.c:4862 cp/pt.c:4873
+#: cp/pt.c:4876 cp/pt.c:4887
 #, gcc-internal-format
 msgid "primary template here"
 msgstr "ursprüngliches Template hier"
 
-#: cp/pt.c:4870
+#: cp/pt.c:4884
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr "partielle Spezialisierung ist nicht näher spezialisiert als das ursprüngliche Template, da es mehrere Parameter mit einer »pack«-Erweiterung ersetzt"
 
-#: cp/pt.c:4885
+#: cp/pt.c:4899
 #, gcc-internal-format
 msgid "partial specialization %qD is not more specialized than"
 msgstr "Teilspezialisierung %qD ist nicht spezialisierter als"
 
-#: cp/pt.c:4887
+#: cp/pt.c:4901
 #, gcc-internal-format
 msgid "primary template %qD"
 msgstr "primäres Template %qD"
 
-#: cp/pt.c:4934
+#: cp/pt.c:4948
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr "Argument %qE für Parameterpack muss am Ende der Templateargumentliste sein"
 
-#: cp/pt.c:4937
+#: cp/pt.c:4951
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr "Argument %qT für Parameterpack muss am Ende der Templateargumentliste sein"
 
-#: cp/pt.c:4958
+#: cp/pt.c:4972
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr "Templateargument %qE betrifft Templateparameter"
 
-#: cp/pt.c:5004
+#: cp/pt.c:5018
 #, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
@@ -46675,17 +46717,17 @@
 msgstr[0] "Typ %qT des Templatearguments %qE hängt von Templateparameter ab"
 msgstr[1] "Typ %qT des Templatearguments %qE hängt von Templateparametern ab"
 
-#: cp/pt.c:5066
+#: cp/pt.c:5080
 #, gcc-internal-format
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "Deklaration von %qD macht vorherige Template-Instanziierung für %qD mehrdeutig"
 
-#: cp/pt.c:5070
+#: cp/pt.c:5084
 #, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "teilweise Spezialisierung von %qD nach Instanziierung von %qD"
 
-#: cp/pt.c:5247
+#: cp/pt.c:5261
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "kein Standard-Argument für %qD"
@@ -46693,47 +46735,47 @@
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5269
+#: cp/pt.c:5283
 #, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "Parameterpack %q+D muss am Ende der Templateparameterliste sein"
 
-#: cp/pt.c:5305
+#: cp/pt.c:5319
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "Standardtemplateargumente dürfen in friend-Redeklaration eines Funktionstemplates nicht verwendet werden"
 
-#: cp/pt.c:5308
+#: cp/pt.c:5322
 #, gcc-internal-format
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "Standardtemplateargumente dürfen in friend-Deklaration nicht verwendet werden"
 
-#: cp/pt.c:5311
+#: cp/pt.c:5325
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without -std=c++11 or -std=gnu++11"
 msgstr "Standardtemplateargumente dürfen in Funktionstemplates nicht ohne -std=c++11 und -std=gnu++11 verwendet werden"
 
-#: cp/pt.c:5314
+#: cp/pt.c:5328
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr "Standardtemplateargumente dürfen in teilweiser Spezialisierung nicht verwendet werden"
 
-#: cp/pt.c:5317 cp/pt.c:5375
+#: cp/pt.c:5331 cp/pt.c:5389
 #, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "Standardargument für Template-Parameter für %qD umschließende Klasse"
 
-#: cp/pt.c:5489
+#: cp/pt.c:5503
 #, gcc-internal-format
 msgid "template %qD declared"
 msgstr "Template %qD deklariert"
 
-#: cp/pt.c:5496
+#: cp/pt.c:5510
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "Templateklasse ohne Namen"
 
-#: cp/pt.c:5504
+#: cp/pt.c:5518
 #, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr "Element-Template %qD darf keine virt-Spezifizierer haben"
@@ -46743,57 +46785,57 @@
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5526
+#: cp/pt.c:5540
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "ungültige Templatedeklaration von %qD"
 
-#: cp/pt.c:5669
+#: cp/pt.c:5683
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "Template-Definition eines Nicht-Templates %q#D"
 
-#: cp/pt.c:5712
+#: cp/pt.c:5726
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "%d Ebenen von Template-Parametern für %q#D erwartet, %d erhalten"
 
-#: cp/pt.c:5726
+#: cp/pt.c:5740
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "%d Template-Parameter für %q#D erhalten"
 
-#: cp/pt.c:5729
+#: cp/pt.c:5743
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "%d Template-Parameter für %q#T erhalten"
 
-#: cp/pt.c:5731
+#: cp/pt.c:5745
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  aber %d benötigt"
 
-#: cp/pt.c:5752
+#: cp/pt.c:5766
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "Template-Argumente für %qD passen nicht zum ursprünglichen Template %qD"
 
-#: cp/pt.c:5755
+#: cp/pt.c:5769
 #, gcc-internal-format
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "verwenden Sie %<template<>%> für eine explizite Spezialisierung"
 
-#: cp/pt.c:5882
+#: cp/pt.c:5896
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT ist kein Template-Typ"
 
-#: cp/pt.c:5895
+#: cp/pt.c:5909
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "keine Templatespezifizierer in Deklaration von %qD angegeben"
 
-#: cp/pt.c:5906
+#: cp/pt.c:5920
 #, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
@@ -46800,7 +46842,7 @@
 msgstr[0] "mit %d Template-Parameter redeklariert"
 msgstr[1] "mit %d Template-Parametern redeklariert"
 
-#: cp/pt.c:5910
+#: cp/pt.c:5924
 #, gcc-internal-format
 msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
@@ -46807,12 +46849,12 @@
 msgstr[0] "vorherige Deklaration %qD verwendete %d Template-Parameter"
 msgstr[1] "vorherige Deklaration %qD verwendete %d Template-Parameter"
 
-#: cp/pt.c:5947
+#: cp/pt.c:5961
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "Template-Parameter %q+#D"
 
-#: cp/pt.c:5948
+#: cp/pt.c:5962
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "hier als %q#D redeklariert"
@@ -46821,117 +46863,117 @@
 #.
 #. A template-parameter may not be given default arguments
 #. by two different declarations in the same scope.
-#: cp/pt.c:5958
+#: cp/pt.c:5972
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "Redefinition des Standardarguments für %q#D"
 
-#: cp/pt.c:5960
+#: cp/pt.c:5974
 #, gcc-internal-format
 msgid "original definition appeared here"
 msgstr "ursprüngliche Definition trat hier auf"
 
-#: cp/pt.c:5988
+#: cp/pt.c:6002
 #, gcc-internal-format
 msgid "redeclaration %q#D with different constraints"
 msgstr "Redeklaration %q#D mit unterschiedlichen Constraints"
 
-#: cp/pt.c:5991
+#: cp/pt.c:6005
 #, gcc-internal-format
 msgid "original declaration appeared here"
 msgstr "ursprüngliche Deklaration trat hier auf"
 
-#: cp/pt.c:6250 cp/pt.c:6318
+#: cp/pt.c:6264 cp/pt.c:6332
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT"
 
-#: cp/pt.c:6253
+#: cp/pt.c:6267
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr "es muss die Adresse einer Funktion mit externer Bindung sein"
 
-#: cp/pt.c:6256
+#: cp/pt.c:6270
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr "es muss der Name einer Funktion mit externer Bindung sein"
 
-#: cp/pt.c:6268
+#: cp/pt.c:6282
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, weil %qD keine Bindung hat"
 
-#: cp/pt.c:6272
+#: cp/pt.c:6286
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, weil %qD keine externe Bindung hat"
 
-#: cp/pt.c:6321
+#: cp/pt.c:6335
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "es muss ein Zeiger auf ein Element der Form %<&X::Y%> sein"
 
-#: cp/pt.c:6323
+#: cp/pt.c:6337
 #, gcc-internal-format
 msgid "because it is a member of %qT"
 msgstr "da es ein Element von %qT ist"
 
-#: cp/pt.c:6383
+#: cp/pt.c:6397
 #, gcc-internal-format
 msgid "  couldn't deduce template parameter %qD"
 msgstr " Template-Parameter %qD konnte nicht ermittelt werden"
 
-#: cp/pt.c:6392
+#: cp/pt.c:6406
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr " Typen %qT und %qT haben unverträgliche CV-Qualifizierer"
 
-#: cp/pt.c:6401
+#: cp/pt.c:6415
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr " unpassende Typen %qT und %qT"
 
-#: cp/pt.c:6410
+#: cp/pt.c:6424
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr " Templateparameter %qD ist kein Parameterpack wie Argument %qD"
 
-#: cp/pt.c:6421
+#: cp/pt.c:6435
 #, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr " Templateargumente %qE passt nicht zum konstanten Zeiger auf Element %qE"
 
-#: cp/pt.c:6431
+#: cp/pt.c:6445
 #, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr " %qE entspricht nicht %qE"
 
-#: cp/pt.c:6440
+#: cp/pt.c:6454
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr " unpassende Herleitung von Parameterpack mit %qT und %qT"
 
-#: cp/pt.c:6452
+#: cp/pt.c:6466
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr " hergeleitete Typen für Parameter %qT stehen in Konflikt (%qT und %qT)"
 
-#: cp/pt.c:6456
+#: cp/pt.c:6470
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr " hergeleitete Werte für Nicht-Typ-Parameter %qE stehen in Konflikt (%qE und %qE)"
 
-#: cp/pt.c:6467
+#: cp/pt.c:6481
 #, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr " Arraytyp %qT mit veränderlicher Größe ist kein gültiges Templateargument"
 
-#: cp/pt.c:6478
+#: cp/pt.c:6492
 #, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr " Typ %qT von Elementfunktion ist kein gültiges Templateargument"
 
-#: cp/pt.c:6490
+#: cp/pt.c:6504
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
@@ -46938,292 +46980,292 @@
 msgstr[0] "  Kandidat erwartet mindestens %d Argument, %d angegeben"
 msgstr[1] "  Kandidat erwartet mindestens %d Argumente, %d angegeben"
 
-#: cp/pt.c:6521
+#: cp/pt.c:6535
 #, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr " %qE (Typ %qT) kann nicht in den Typ %qT umgewandelt werden"
 
-#: cp/pt.c:6534
+#: cp/pt.c:6548
 #, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr " %qT ist mehrdeutige Basisklasse von %qT"
 
-#: cp/pt.c:6538
+#: cp/pt.c:6552
 #, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr " %qT ist nicht vom Typ %qT abgeleitet"
 
-#: cp/pt.c:6549
+#: cp/pt.c:6563
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr " Templateparameter eines Template-Templatearguments sind mit anderen hergeleiteten Templateargumenten unverträglich"
 
-#: cp/pt.c:6559
+#: cp/pt.c:6573
 #, gcc-internal-format
 msgid "  can't deduce a template for %qT from non-template type %qT"
 msgstr " für %qT kann kein Template aus Nicht-Templatetyp %qT hergeleitet werden"
 
-#: cp/pt.c:6569
+#: cp/pt.c:6583
 #, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
 msgstr " Template-Argument %qE passt nicht zu %qE"
 
-#: cp/pt.c:6609
+#: cp/pt.c:6623
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, da Zeichenkettensymbole in diesem Zusammenhang nicht verwendet werden können"
 
-#: cp/pt.c:6758
+#: cp/pt.c:6772
 #, gcc-internal-format
 msgid "in template argument for type %qT"
 msgstr "in Templateargument für Typ %qT"
 
-#: cp/pt.c:6772
+#: cp/pt.c:6786
 #, gcc-internal-format
 msgid "template argument %qE for type %qT not a constant integer"
 msgstr "Templateargument %qE für Typ %qT ist keine konstante Ganzzahl"
 
-#: cp/pt.c:6833
+#: cp/pt.c:6847
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qD ist kein gültiges Templateargument, weil %qD eine Variable und nicht die Adresse einer Variable ist"
 
-#: cp/pt.c:6841
+#: cp/pt.c:6855
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qE ist kein gültiges Templateargument für %qT, da es keine Adresse einer Variable ist"
 
-#: cp/pt.c:6857
+#: cp/pt.c:6871
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, weil %qE keine Variable ist"
 
-#: cp/pt.c:6864
+#: cp/pt.c:6878
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr "%qE ist kein gültiges Templateargument des Typs %qT, weil %qD keine externe Bindung hat"
 
-#: cp/pt.c:6873
+#: cp/pt.c:6887
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, weil %qD keine Bindung hat"
 
-#: cp/pt.c:6888
+#: cp/pt.c:6902
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument"
 msgstr "die Adresse von %qD ist kein gültiges Templateargument"
 
-#: cp/pt.c:6897
+#: cp/pt.c:6911
 #, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr "die Adresse des %qT-Teilobjekts von %qD ist kein gültiges Templateargument"
 
-#: cp/pt.c:6904
+#: cp/pt.c:6918
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "die Adresse von %qD ist kein gültiges Templateargument, weil sie keine statische Lebensdauer hat"
 
-#: cp/pt.c:6933
+#: cp/pt.c:6947
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, da es in CV-Qualifikation in Konflikt steht"
 
-#: cp/pt.c:6941
+#: cp/pt.c:6955
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, weil es kein L-Wert ist"
 
-#: cp/pt.c:6959
+#: cp/pt.c:6973
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%q#D ist kein gültiges Templateargument für Typ %qT, weil eine Referenzvariable keine konstante Adresse hat"
 
-#: cp/pt.c:6975
+#: cp/pt.c:6989
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an object with linkage"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, weil es kein Objekt mit Bindung ist"
 
-#: cp/pt.c:6986
+#: cp/pt.c:7000
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because object %qD does not have linkage"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, weil Objekt %qD keine Bindung hat"
 
-#: cp/pt.c:7036
+#: cp/pt.c:7050
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, weil es ein Zeiger ist"
 
-#: cp/pt.c:7038
+#: cp/pt.c:7052
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "stattdessen %qE verwenden"
 
-#: cp/pt.c:7092
+#: cp/pt.c:7106
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, weil es vom Typ %qT ist"
 
-#: cp/pt.c:7654
+#: cp/pt.c:7668
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "Attribute an Templateargument %qT werden ignoriert"
 
-#: cp/pt.c:7670
+#: cp/pt.c:7684
 #, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr "Attribute an Templateargument %qE werden ignoriert"
 
-#: cp/pt.c:7805
+#: cp/pt.c:7819
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "eingegebener Klassenname %qD als Template-Templateargument verwendet"
 
-#: cp/pt.c:7834
+#: cp/pt.c:7848
 #, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "ungültige Verwendung des Destruktors %qE als Typ"
 
-#: cp/pt.c:7839
+#: cp/pt.c:7853
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "um auf ein Typelement eines Templateparameters zu verweisen, %<typename %E%> verwenden"
 
-#: cp/pt.c:7855 cp/pt.c:7877 cp/pt.c:7931
+#: cp/pt.c:7869 cp/pt.c:7891 cp/pt.c:7945
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "Typ/Wert des Arguments %d passt nicht in Template-Parameterliste für %qD"
 
-#: cp/pt.c:7860
+#: cp/pt.c:7874
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  Konstante des Typs %qT erwartet, %qT erhalten"
 
-#: cp/pt.c:7865
+#: cp/pt.c:7879
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  Klassentemplate erwartet, %qE erhalten"
 
-#: cp/pt.c:7868
+#: cp/pt.c:7882
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  einen Typ erwartet, %qE erhalten"
 
-#: cp/pt.c:7882
+#: cp/pt.c:7896
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  einen Typ erwartet, %qT erhalten"
 
-#: cp/pt.c:7885
+#: cp/pt.c:7899
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  Klassentemplate erwartet, %qT erhalten"
 
-#: cp/pt.c:7935
+#: cp/pt.c:7949
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  ein Template des Typs %qD erwartet, %qT erhalten"
 
-#: cp/pt.c:7949
+#: cp/pt.c:7963
 #, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "unpassende Beschränkungen für Argument %d in Template-Parameterliste für %qD"
 
-#: cp/pt.c:7952
+#: cp/pt.c:7966
 #, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr "  %qD erwartet, %qD erhalten"
 
-#: cp/pt.c:8012
+#: cp/pt.c:8026
 #, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "Templateargument %qE konnte nicht von %qT in %qT umgewandelt werden"
 
-#: cp/pt.c:8149 cp/pt.c:8465
+#: cp/pt.c:8163 cp/pt.c:8479
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "Templateargument %d ist ungültig"
 
-#: cp/pt.c:8164 cp/pt.c:8298
+#: cp/pt.c:8178 cp/pt.c:8312
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "falsche Anzahl der Templateargumente (%d, sollte %d sein)"
 
-#: cp/pt.c:8294
+#: cp/pt.c:8308
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "falsche Anzahl der Templateargumente (%d, sollte mindestens %d sein)"
 
-#: cp/pt.c:8303
+#: cp/pt.c:8317
 #, gcc-internal-format
 msgid "provided for %qD"
 msgstr "für %qD bereitgestellt"
 
-#: cp/pt.c:8328
+#: cp/pt.c:8342
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr "gepacktes Expansionsargument für Parameter %qD ohne »pack« von Alias-Template %qD"
 
-#: cp/pt.c:8332
+#: cp/pt.c:8346
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "gepacktes Expansionsargument für Parameter %qD ohne »pack« von Konzept %qD"
 
-#: cp/pt.c:8431
+#: cp/pt.c:8445
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr "jegliche Instanziierung mit nichtleerer Parameterpackung wäre unzulässig"
 
-#: cp/pt.c:9054
+#: cp/pt.c:9068
 #, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%q#D ist kein Funktionstemplate"
 
-#: cp/pt.c:9221
+#: cp/pt.c:9235
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "Nicht-Template-Typ %qT als Template verwendet"
 
-#: cp/pt.c:9223
+#: cp/pt.c:9237
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "Für Template-Deklaration %q+D"
 
-#: cp/pt.c:9346
+#: cp/pt.c:9360
 #, gcc-internal-format
 msgid "template constraint failure"
 msgstr "Template-Einschränkung fehlgeschlagen"
 
-#: cp/pt.c:9697
+#: cp/pt.c:9718
 #, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr "Verwendung des ungültigen Variablentemplates %qE"
 
-#: cp/pt.c:10125
+#: cp/pt.c:10148
 #, gcc-internal-format, gfc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr "Instanziierungstiefe für Templates überschreitet Höchstwert %d (-ftemplate-depth= verwenden, um dies zu erhöhen)"
 
-#: cp/pt.c:11202
+#: cp/pt.c:11225
 #, gcc-internal-format
 msgid "flexible array member %qD in union"
 msgstr "flexibles Arrayelement %qD in Union"
 
-#: cp/pt.c:11691
+#: cp/pt.c:11713
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr "Falten einer leeren Expansion über %O"
 
-#: cp/pt.c:12160
+#: cp/pt.c:12182
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr "Argumentpacklängen passen nicht bei Expansion von %qT"
 
-#: cp/pt.c:12163
+#: cp/pt.c:12185
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr "Argumentpacklängen passen nicht bei Expansion von %qE"
 
-#: cp/pt.c:12747
+#: cp/pt.c:12769
 #, gcc-internal-format
 msgid "  when instantiating default argument for call to %qD"
 msgstr "  bei Instanziierung des Standardarguments für Aufruf von %qD"
@@ -47241,276 +47283,276 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:13708
+#: cp/pt.c:13730
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "Variable %qD hat Funktionstyp"
 
-#: cp/pt.c:13881
+#: cp/pt.c:13903
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "ungültiger Parametertyp %qT"
 
-#: cp/pt.c:13883
+#: cp/pt.c:13905
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "in Deklaration %q+D"
 
-#: cp/pt.c:14001
+#: cp/pt.c:14023
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "Funktion gibt ein Array zurück"
 
-#: cp/pt.c:14003
+#: cp/pt.c:14025
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "Funktion gibt eine Funktion"
 
-#: cp/pt.c:14043
+#: cp/pt.c:14065
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "Erzeugung eines Zeigers auf Elementfunktion des Nicht-Klassentyps %qT"
 
-#: cp/pt.c:14637
+#: cp/pt.c:14659
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "Referenz auf »void« wird gebildet"
 
-#: cp/pt.c:14639
+#: cp/pt.c:14661
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "Zeiger auf Referenztyp %qT wird geformt"
 
-#: cp/pt.c:14641
+#: cp/pt.c:14663
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "Referenz auf Referenztyp %qT wird geformt"
 
-#: cp/pt.c:14654
+#: cp/pt.c:14676
 #, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "Zeiger auf qualifizierten Funktionstypen %qT wird geformt"
 
-#: cp/pt.c:14657
+#: cp/pt.c:14679
 #, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "Referenz auf qualifizierten Funktionstypen %qT wird geformt"
 
-#: cp/pt.c:14705
+#: cp/pt.c:14727
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "Zeiger auf Element des Nicht-Klassentypen %qT wird erzeugt"
 
-#: cp/pt.c:14711
+#: cp/pt.c:14733
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "Zeiger auf Elementreferenztyp %qT wird erzeugt"
 
-#: cp/pt.c:14717
+#: cp/pt.c:14739
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "Zeiger auf Element mit Typ »void« wird erzeugt"
 
-#: cp/pt.c:14783
+#: cp/pt.c:14805
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "Array von %qT wird erzeugt"
 
-#: cp/pt.c:14816
+#: cp/pt.c:14838
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT ist kein Klassen-, Struktur- oder Union-Typ"
 
-#: cp/pt.c:14853
+#: cp/pt.c:14875
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT wird in %qT aufgelöst, was kein Aufzählungstyp ist"
 
-#: cp/pt.c:14861
+#: cp/pt.c:14883
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr "%qT wird in %qT aufgelöst, was kein Klassentyp ist"
 
-#: cp/pt.c:14925
+#: cp/pt.c:14947
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr "leere Initialisierung in »init-capture« für Lambda"
 
-#: cp/pt.c:15000
+#: cp/pt.c:15022
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "Verwendung von %qs in Template"
 
-#: cp/pt.c:15178
+#: cp/pt.c:15200
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "qualifizierender Typ %qT passt nicht zum Destruktornamen ~%qT"
 
-#: cp/pt.c:15193
+#: cp/pt.c:15215
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "Abhängigenname %qE wird als Nicht-Typ erkannt, aber die Instanziierung liefert einen Typ"
 
-#: cp/pt.c:15195
+#: cp/pt.c:15217
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "%<typename %E%> sagen, wenn ein Typ gemeint ist"
 
-#: cp/pt.c:15394
+#: cp/pt.c:15416
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "ungültiges Feld %qD wird verwendet"
 
-#: cp/pt.c:15883 cp/pt.c:17386
+#: cp/pt.c:15905 cp/pt.c:17408
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "falsche Verwendung eines Packauflösungs-Ausdruckes"
 
-#: cp/pt.c:15887 cp/pt.c:17390
+#: cp/pt.c:15909 cp/pt.c:17412
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "%<...%> verwenden, um Argumentpack aufzulösen"
 
-#: cp/pt.c:18334
+#: cp/pt.c:18371
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr "%qD wurde in diesem Gültigkeitsbereich nicht deklariert, und bei argumentabhängiger Suche am Ort der Instanziierung wurden keine Deklarationen gefunden"
 
-#: cp/pt.c:18362
+#: cp/pt.c:18399
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr "Deklarationen in abhängiger Basis %qT wurden bei unqualifizierter Suche nicht gefunden"
 
-#: cp/pt.c:18367
+#: cp/pt.c:18404
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "stattdessen %<this->%D%> verwenden"
 
-#: cp/pt.c:18370
+#: cp/pt.c:18407
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "stattdessen %<%T::%D%> verwenden"
 
-#: cp/pt.c:18375
+#: cp/pt.c:18412
 #, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "%qD hier deklariert, später in der Übersetzungseinheit"
 
-#: cp/pt.c:18712
+#: cp/pt.c:18752
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT ist keine Klasse oder Namensbereich"
 
-#: cp/pt.c:18715
+#: cp/pt.c:18755
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD ist keine Klasse oder Namensbereich"
 
-#: cp/pt.c:19026
+#: cp/pt.c:19066
 #, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr "%qT ist/verwendet anonymen Typen"
 
-#: cp/pt.c:19028
+#: cp/pt.c:19068
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "Templateargument für %qD verwendet lokalen Typ %qT"
 
-#: cp/pt.c:19038
+#: cp/pt.c:19078
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT ist ein variabel modifizierter Typ"
 
-#: cp/pt.c:19053
+#: cp/pt.c:19093
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "Ganzzahlausdruck %qE ist nicht konstant"
 
-#: cp/pt.c:19071
+#: cp/pt.c:19111
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  Versuch, %qD zu instanziieren"
 
-#: cp/pt.c:22972
+#: cp/pt.c:23050
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "mehrdeutige Template-Instanziierung für %q#T"
 
-#: cp/pt.c:22974
+#: cp/pt.c:23052
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "mehrdeutige Template-Instanziierung für %q#D"
 
-#: cp/pt.c:22980
+#: cp/pt.c:23058
 msgid "%s %#qS"
 msgstr "%s %#qS"
 
-#: cp/pt.c:23004 cp/pt.c:23091
+#: cp/pt.c:23082 cp/pt.c:23169
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "explizite Instanziierung des Nicht-Templates %q#D"
 
-#: cp/pt.c:23023
+#: cp/pt.c:23101
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD ist kein statisches Datenelement eines Klassentemplates"
 
-#: cp/pt.c:23029 cp/pt.c:23086
+#: cp/pt.c:23107 cp/pt.c:23164
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "kein passendes Template für %qD gefunden"
 
-#: cp/pt.c:23034
+#: cp/pt.c:23112
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "Typ %qT für explizite Instanziierung %qD passt nicht zum deklarierten Typ %qT"
 
-#: cp/pt.c:23042
+#: cp/pt.c:23120
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "explizite Instanziierung von %q#D"
 
-#: cp/pt.c:23078
+#: cp/pt.c:23156
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "doppelte explizite Instanziierung von %q#D"
 
-#: cp/pt.c:23101 cp/pt.c:23187
+#: cp/pt.c:23179 cp/pt.c:23265
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO-C++ 1998 verbietet die Verwendung von %<extern%> bei expliziten Instanziierungen"
 
-#: cp/pt.c:23106 cp/pt.c:23204
+#: cp/pt.c:23184 cp/pt.c:23282
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "Speicherklasse %qD auf Templateinstanziierung angewendet"
 
-#: cp/pt.c:23163
+#: cp/pt.c:23241
 #, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "explizite Instanziierung des Nicht-Klassen-Templates %qD"
 
-#: cp/pt.c:23165
+#: cp/pt.c:23243
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "explizite Instanziierung des Nicht-Templatetyps %qT"
 
-#: cp/pt.c:23174
+#: cp/pt.c:23252
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "explizite Instanziierung von %q#T vor Definition des Templates"
 
-#: cp/pt.c:23192
+#: cp/pt.c:23270
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO-C++ verbietet die Verwendung von %qE bei expliziten Instanziierungen"
 
-#: cp/pt.c:23238
+#: cp/pt.c:23316
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "doppelte explizite Instanziierung von %q#T"
 
-#: cp/pt.c:23536
+#: cp/pt.c:23614
 #, gcc-internal-format
 msgid "exception specification of %qD depends on itself"
 msgstr "Ausnahmen-Angabe von %qD hängt von sich selbst ab"
@@ -47522,107 +47564,107 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:23842
+#: cp/pt.c:23920
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "explizite Instanziierung von %qD, aber keine Definition verfügbar"
 
-#: cp/pt.c:24043
+#: cp/pt.c:24121
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr "Instanziierungstiefe für Templates überschreitet Höchstwert %d (-ftemplate-depth= verwenden, um dies zu erhöhen) bei Instanziierung von %q+D, möglicherweise von Erzeugung der virtuellen Tabelle"
 
-#: cp/pt.c:24418
+#: cp/pt.c:24496
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "ungültiger Nicht-Typ-Parameter für Template"
 
-#: cp/pt.c:24420
+#: cp/pt.c:24498
 #, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T ist kein gültiger Typ für einen Nicht-Typ-Parameter eines Templates"
 
-#: cp/pt.c:25723
+#: cp/pt.c:25802
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "Schlüsselwort %<template%> nicht innerhalb der declarator-id erlaubt"
 
-#: cp/pt.c:25961
+#: cp/pt.c:26040
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr "Ermittlung aus geschweift geklammerter Initialisierungsliste erfordert %<#include <initializer_list>%>"
 
-#: cp/pt.c:26440
+#: cp/pt.c:26519
 #, gcc-internal-format
 msgid "non-class template %qT used without template arguments"
 msgstr "Nicht-Klassen-Template %qT ohne Template-Argumente verwendet"
 
-#: cp/pt.c:26586
+#: cp/pt.c:26665
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr "Templateargumente für die Kopierinitialisierung von %qT können nicht abgeleitet werden, da es keine expliziten Ableitungshinweise oder benutzerdeklarierten Konstruktoren gibt"
 
-#: cp/pt.c:26593
+#: cp/pt.c:26672
 #, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "Templateargumente für %qT können nicht abgeleitet werden, da es keine Ableitungshinweise gibt"
 
-#: cp/pt.c:26607
+#: cp/pt.c:26686
 #, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "Argumentherleitung für Klassentemplate gescheitert:"
 
-#: cp/pt.c:26614
+#: cp/pt.c:26693
 #, gcc-internal-format
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "Explizite Herleitungshinweise werden nicht für »copy-initialization« berücksichtigt"
 
-#: cp/pt.c:26676
+#: cp/pt.c:26755
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr "direct-list-initialization von %<auto%> erfordert genau ein Element"
 
-#: cp/pt.c:26679
+#: cp/pt.c:26758
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr "um %<std::initializer_list%> herzuleiten, verwenden Sie einen copy-list-initialization (also mit %<=%> vor dem %<{%>)"
 
-#: cp/pt.c:26711
+#: cp/pt.c:26790
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr "%qT als Typ statt als einfaches %<decltype(auto)%>"
 
-#: cp/pt.c:26746
+#: cp/pt.c:26825
 #, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "Lambda-Rückgabewert von %qE kann nicht hergeleitet werden"
 
-#: cp/pt.c:26748
+#: cp/pt.c:26827
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "%qT kann nicht aus %qE hergeleitet werden"
 
-#: cp/pt.c:26781
+#: cp/pt.c:26860
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr "Platzhalter-Beschränkungen nicht erfüllt"
 
-#: cp/pt.c:26785
+#: cp/pt.c:26864
 #, gcc-internal-format
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "hergeleiteter Initialisierer erfüllt die Platzhalter-Beschränkungen nicht"
 
-#: cp/pt.c:26789
+#: cp/pt.c:26868
 #, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "hergeleiteter Rückgabetyp erfüllt die Platzhalter-Beschränkungen nicht"
 
-#: cp/pt.c:26793
+#: cp/pt.c:26872
 #, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "hergeleiteter Ausdruckstyp erfüllt die Platzhalterbeschränkungen nicht"
 
-#: cp/pt.c:26912
+#: cp/pt.c:26991
 #, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr "ungültige Verwendung von %qT in Templateargument"
@@ -47677,77 +47719,77 @@
 msgid "cannot dynamic_cast %qE (of type %q#T) to type %q#T (%s)"
 msgstr "dynamic_cast %qE (des Typs %q#T) in Typ %q#T (%s) kann nicht vorgenommen werden"
 
-#: cp/search.c:240
+#: cp/search.c:243
 #, gcc-internal-format
 msgid "%qT is an ambiguous base of %qT"
 msgstr "%qT ist mehrdeutige Basis von %qT"
 
-#: cp/search.c:256
+#: cp/search.c:259
 #, gcc-internal-format
 msgid "%qT is an inaccessible base of %qT"
 msgstr "%qT ist eine nicht erreichbare Basis von %qT"
 
-#: cp/search.c:1905
+#: cp/search.c:1908
 #, gcc-internal-format
 msgid "invalid covariant return type for %q#D"
 msgstr "ungültiger kovarianter Rückgabetyp für %q#D"
 
-#: cp/search.c:1907 cp/search.c:1922 cp/search.c:1928 cp/search.c:1957
+#: cp/search.c:1910 cp/search.c:1925 cp/search.c:1931 cp/search.c:1960
 #, gcc-internal-format
 msgid "overridden function is %q#D"
 msgstr "übersteuerte Funktion ist %q#D"
 
-#: cp/search.c:1920
+#: cp/search.c:1923
 #, gcc-internal-format
 msgid "invalid covariant return type for %q+#D"
 msgstr "ungültiger kovarianter Rückgabetyp für %q+#D"
 
-#: cp/search.c:1926
+#: cp/search.c:1929
 #, gcc-internal-format
 msgid "conflicting return type specified for %q+#D"
 msgstr "in Konflikt stehenden Rückgabetyp für %q+#D angegeben"
 
-#: cp/search.c:1942
+#: cp/search.c:1945
 #, gcc-internal-format
 msgid "looser throw specifier for %q+#F"
 msgstr "lockerer »throw«-Spezifizierer für %q+#F"
 
-#: cp/search.c:1944
+#: cp/search.c:1947
 #, gcc-internal-format
 msgid "overridden function is %q#F"
 msgstr "übersteuerte Funktion ist %q#F"
 
-#: cp/search.c:1955
+#: cp/search.c:1958
 #, gcc-internal-format
 msgid "conflicting type attributes specified for %q+#D"
 msgstr "in Konflikt stehenden Typattribute für %q+#D angegeben"
 
-#: cp/search.c:1972
+#: cp/search.c:1975
 #, gcc-internal-format
 msgid "%qD declared %<transaction_safe_dynamic%>"
 msgstr "%qD als %<transaction_safe_dynamic%> deklariert"
 
-#: cp/search.c:1974
+#: cp/search.c:1977
 #, gcc-internal-format
 msgid "overriding %qD declared %<transaction_safe%>"
 msgstr "übersteuert %qD, was als %<transaction_safe%> deklariert ist"
 
-#: cp/search.c:1981
+#: cp/search.c:1984
 #, gcc-internal-format
 msgid "deleted function %q+D overriding non-deleted function"
 msgstr "gelöschte Funktion %q+D übersteuert nicht gelöschte Funktion"
 
-#: cp/search.c:1984 cp/search.c:1992 cp/search.c:2000
+#: cp/search.c:1987 cp/search.c:1995 cp/search.c:2003
 #, gcc-internal-format
 msgid "overridden function is %qD"
 msgstr "übersteuerte Funktion ist %qD"
 
-#: cp/search.c:1989
+#: cp/search.c:1992
 #, gcc-internal-format
 msgid "non-deleted function %q+D overriding deleted function"
 msgstr "nicht gelöschte Funktion %q+D übersteuert gelöschte Funktion"
 
-#: cp/search.c:1998
+#: cp/search.c:2001
 #, gcc-internal-format
 msgid "virtual function %q+D overriding final function"
 msgstr "virtuelle Funktion %q+D übersteuert final-Funktion"
@@ -47754,12 +47796,12 @@
 
 #. A static member function cannot match an inherited
 #. virtual member function.
-#: cp/search.c:2082
+#: cp/search.c:2085
 #, gcc-internal-format
 msgid "%q+#D cannot be declared"
 msgstr "%q+#D kann nicht deklariert werden"
 
-#: cp/search.c:2083
+#: cp/search.c:2086
 #, gcc-internal-format
 msgid "  since %q+#D declared in base class"
 msgstr "  denn %q+#D ist in Basisklasse deklariert"
@@ -47799,576 +47841,591 @@
 msgid "invalid use of member %qD in static member function"
 msgstr "ungültige Verwendung des Elementes %qD in statischer Elementfunktion"
 
-#: cp/semantics.c:2153
+#: cp/semantics.c:2156
 #, gcc-internal-format
 msgid "a statement expression is an insufficient context for overload resolution"
 msgstr "ein Anweisungsausdruck reicht nicht als Kontext für Überladungs-Auflösung nicht aus"
 
-#: cp/semantics.c:2540
+#: cp/semantics.c:2543
 #, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr "Argumente für Destruktor sind nicht erlaubt"
 
-#: cp/semantics.c:2622
+#: cp/semantics.c:2625
 #, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr "%<this%> ist für statische Elementfunktionen nicht verfügbar"
 
-#: cp/semantics.c:2624
+#: cp/semantics.c:2627
 #, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr "ungültige Verwendung von %<this%> in Nicht-Element-Funktion"
 
-#: cp/semantics.c:2626
+#: cp/semantics.c:2629
 #, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr "ungültige Verwendung von %<this%> auf höchster Ebene"
 
-#: cp/semantics.c:2648
+#: cp/semantics.c:2651
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "ungültiger angegebener Gültigkeitsbereich in Pseudodestruktor-Name"
 
-#: cp/semantics.c:2656 cp/typeck.c:2604
+#: cp/semantics.c:2659 cp/typeck.c:2604
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "qualifizierter Typ %qT passt nicht zum Destruktornamen ~%qT"
 
-#: cp/semantics.c:2678
+#: cp/semantics.c:2681
 #, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr "%qE ist nicht vom Typ %qT"
 
-#: cp/semantics.c:2751
+#: cp/semantics.c:2754
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr "zusammengesetztes Literal vom Nicht-Objekt-Typ %qT"
 
-#: cp/semantics.c:2892
+#: cp/semantics.c:2895
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr "Templatetypparameter müssen das Schlüsselwort %<class%> oder %<typename%> verwenden"
 
-#: cp/semantics.c:2942
+#: cp/semantics.c:2945
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr "ungültige Verwendung des Typs %qT als Standardwert für einen Template-Templateparameter"
 
-#: cp/semantics.c:2945
+#: cp/semantics.c:2948
 #, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr "ungültiges Standardargument für einen Template-Templateparameter"
 
-#: cp/semantics.c:2962
+#: cp/semantics.c:2965
 #, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr "Definition von %q#T in Templateparameterliste"
 
-#: cp/semantics.c:2993
+#: cp/semantics.c:2996
 #, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr "ungültige Definition des qualifizierten Typen %qT"
 
-#: cp/semantics.c:3263
+#: cp/semantics.c:3266
 #, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "ungültige Spezifizierung der Basisklasse"
 
-#: cp/semantics.c:3423
+#: cp/semantics.c:3426
 #, gcc-internal-format
 msgid "cannot capture member %qD of anonymous union"
 msgstr "Element %qD von unbenannter Union kann nicht eingefangen werden"
 
-#: cp/semantics.c:3443 cp/semantics.c:9269
+#: cp/semantics.c:3446 cp/semantics.c:9272
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qD ist nicht eingefangen"
 
-#: cp/semantics.c:3448
+#: cp/semantics.c:3451
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr "das Lambda hat keinen »capture-default«"
 
-#: cp/semantics.c:3450
+#: cp/semantics.c:3453
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr "Lambda in lokaler Klasse %q+T kann Variablen aus dem umschließenden Kontext nicht einfangen"
 
-#: cp/semantics.c:3462
+#: cp/semantics.c:3465
 #, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr "Verwendung lokaler Variable mit automatischer Speicherklasse aus enthaltender Funktion"
 
-#: cp/semantics.c:3464
+#: cp/semantics.c:3467
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr "Verwendung eines Parameters aus enthaltender Funktion"
 
-#: cp/semantics.c:3596
+#: cp/semantics.c:3599
 #, gcc-internal-format
 msgid "use of parameter outside function body"
 msgstr "Verwendung eines Parameters außerhalb des Funktionskörpers"
 
-#: cp/semantics.c:3606
+#: cp/semantics.c:3609
 #, gcc-internal-format
 msgid "missing template arguments"
 msgstr "fehlende Templateargumente"
 
-#: cp/semantics.c:3633
+#: cp/semantics.c:3636
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr "Templateparameter %qD vom Typ %qT ist in ganzzahligem Konstantenausdruck nicht erlaubt, da er nicht Ganzzahl- oder Aufzählungstyp hat"
 
-#: cp/semantics.c:3664
+#: cp/semantics.c:3667
 #, gcc-internal-format
 msgid "use of namespace %qD as expression"
 msgstr "Verwendung des Namensbereiches %qD als Ausdruck"
 
-#: cp/semantics.c:3669
+#: cp/semantics.c:3672
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr "Verwendung des Klassentemplates %qT als Ausdruck"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:3675
+#: cp/semantics.c:3678
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "Abfrage des Elementes %qD ist im Gitter der Mehrfachvererbung mehrdeutig"
 
-#: cp/semantics.c:3702
+#: cp/semantics.c:3705
 #, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "%qD kann nicht in Konstanten-Ausdruck auftreten"
 
-#: cp/semantics.c:3841
+#: cp/semantics.c:3844
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "Typ von %qE ist unbekannt"
 
-#: cp/semantics.c:3870
+#: cp/semantics.c:3873
 #, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr "%qT ist kein Aufzählungstyp"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4009
+#: cp/semantics.c:4012
 #, gcc-internal-format
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr "Parameterpack __bases nur in Templatedeklaration gültig"
 
-#: cp/semantics.c:4038
+#: cp/semantics.c:4041
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr "%<offsetof%> kann nicht auf Destruktor %<~%T%> angewandt werden"
 
-#: cp/semantics.c:4052
+#: cp/semantics.c:4055
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "%<offsetof%> kann nicht auf Elementfunktion %qD angewandt werden"
 
-#: cp/semantics.c:4056
+#: cp/semantics.c:4059
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function"
 msgstr "%<offsetof%> kann nicht auf Elementfunktion angewandt werden"
 
-#: cp/semantics.c:4061
+#: cp/semantics.c:4064
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr "%<offsetof%> kann nicht auf Aufzähler %qD angewandt werden"
 
-#: cp/semantics.c:4072
+#: cp/semantics.c:4075
 #, gcc-internal-format
 msgid "offsetof within non-standard-layout type %qT is conditionally-supported"
 msgstr "offsetof innerhalb von »non-standard-layout«-Typ %qT ist bedingt unterstützt"
 
-#: cp/semantics.c:4583 cp/semantics.c:6069 cp/semantics.c:6140
-#: cp/semantics.c:6183 cp/semantics.c:6533 cp/semantics.c:6632
-#: cp/semantics.c:6775
+#: cp/semantics.c:4586 cp/semantics.c:6072 cp/semantics.c:6143
+#: cp/semantics.c:6186 cp/semantics.c:6536 cp/semantics.c:6635
+#: cp/semantics.c:6778
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr "%<this%> ist in OpenMP nur innerhalb von %<declare simd%>-Klauseln erlaubt"
 
-#: cp/semantics.c:5271
+#: cp/semantics.c:5274
 #, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr "benutzerdefinierte Reduktionsauflösung ist mehrdeutig"
 
-#: cp/semantics.c:5544
+#: cp/semantics.c:5547
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr "%qE in %<reduction%>-Klausel ist ein Array der Länge 0"
 
-#: cp/semantics.c:5592
+#: cp/semantics.c:5595
 #, gcc-internal-format
 msgid "%qE has const type for %<reduction%>"
 msgstr "%qE hat konstanten Typ für %<reduction%>"
 
-#: cp/semantics.c:5707
+#: cp/semantics.c:5710
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr "benutzerdefinierte Reduktion mit Konstruktorinitialisierung für Basisklasse %qT"
 
-#: cp/semantics.c:5941
+#: cp/semantics.c:5944
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr "»linear«-Klausel mit Modifizierer %qs wird auf Nicht-Referenz-Variable mit Typ %qT angewandt"
 
-#: cp/semantics.c:5955
+#: cp/semantics.c:5958
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr "»linear«-Klausel wird auf Variable vom Typ %qT angewandt, die weder ganzzahlig noch Zeiger ist"
 
-#: cp/semantics.c:5977
+#: cp/semantics.c:5980
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr "Ausdruck für »linear«-Schrittweite muss ganzzahlig sein"
 
-#: cp/semantics.c:6080
+#: cp/semantics.c:6083
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD ist in Klausel %qs keine Variable"
 
-#: cp/semantics.c:6152
+#: cp/semantics.c:6155
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "%qD ist in Klausel %<firstprivate%> keine Variable"
 
-#: cp/semantics.c:6195
+#: cp/semantics.c:6198
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "%qD ist in Klausel %<lastprivate%> keine Variable"
 
-#: cp/semantics.c:6240
+#: cp/semantics.c:6243
 #, gcc-internal-format
 msgid "%<gang%> static expression must be integral"
 msgstr "statischer %<gang%>-Ausdruck muss ganzzahlig sein"
 
-#: cp/semantics.c:6254
+#: cp/semantics.c:6257
 #, gcc-internal-format
 msgid "%<gang%> static value must be positive"
 msgstr "statischer %<gang%>-Ausdruck muss positiv sein"
 
-#: cp/semantics.c:6288
+#: cp/semantics.c:6291
 #, gcc-internal-format
 msgid "%<gang%> num expression must be integral"
 msgstr "Ausdruck für %<gang%>-Nummer muss ganzzahlig sein"
 
-#: cp/semantics.c:6291
+#: cp/semantics.c:6294
 #, gcc-internal-format
 msgid "%<vector%> length expression must be integral"
 msgstr "Ausdruck für %<vector%>-Länge muss ganzzahlig sein"
 
-#: cp/semantics.c:6295
+#: cp/semantics.c:6298
 #, gcc-internal-format
 msgid "%<worker%> num expression must be integral"
 msgstr "Ausdruck für %<worker%>-Nummer muss ganzzahlig sein"
 
-#: cp/semantics.c:6317
+#: cp/semantics.c:6320
 #, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr "Wert von %<gang%> muss positiv sein"
 
-#: cp/semantics.c:6321
+#: cp/semantics.c:6324
 #, gcc-internal-format
 msgid "%<vector%> length value must be positive"
 msgstr "Wert der %<vector%>-Länge muss positiv sein"
 
-#: cp/semantics.c:6326
+#: cp/semantics.c:6329
 #, gcc-internal-format
 msgid "%<worker%> num value must be positive"
 msgstr "Wert der %<worker%>-Nummer muss positiv sein"
 
-#: cp/semantics.c:6376
+#: cp/semantics.c:6379
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr "Plan-Teilgrößenausdruck muss bestimmt sein"
 
-#: cp/semantics.c:6406
+#: cp/semantics.c:6409
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr "Ausdruck für %qs-Länge muss ganzzahlig sein"
 
-#: cp/semantics.c:6419
+#: cp/semantics.c:6422
 #, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "Ausdruck für %qs-Länge muss ganzzahlig, positiv und konstant sein"
 
-#: cp/semantics.c:6438
+#: cp/semantics.c:6441
 #, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr "%<async%>-Ausdruck muss ganzzahlig sein"
 
-#: cp/semantics.c:6466
+#: cp/semantics.c:6469
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr "%<thread_limit%>-Ausdruck muss ganzzahlig sein"
 
-#: cp/semantics.c:6495
+#: cp/semantics.c:6498
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr "%<device%>-ID muss ganzzahlig sein"
 
-#: cp/semantics.c:6516
+#: cp/semantics.c:6519
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr "Ausdruck für %<dist_schedule%>-Chunkgröße muss ganzzahlig sein"
 
-#: cp/semantics.c:6543
+#: cp/semantics.c:6546
 #, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qD ist in %<aligned%>-Klausel keine Variable"
 
-#: cp/semantics.c:6557
+#: cp/semantics.c:6560
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr "%qE in %<aligned%>-Klausel ist weder Zeiger noch Array noch Referenz auf Zeiger oder Array"
 
-#: cp/semantics.c:6563
+#: cp/semantics.c:6566
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr "%qD tritt in %<aligned%>-Klausel mehrfach auf"
 
-#: cp/semantics.c:6576
+#: cp/semantics.c:6579
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr "Ausdruck für Ausrichtung der %<aligned%>-Klausel muss ganzzahlig sein"
 
-#: cp/semantics.c:6625
+#: cp/semantics.c:6628
 #, gcc-internal-format
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr "%qD ist in %<depend%>-Klausel keine Variable"
 
-#: cp/semantics.c:6910
+#: cp/semantics.c:6913
 #, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr "Template %qE in Klausel %qs"
 
-#: cp/semantics.c:6914
+#: cp/semantics.c:6917
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr "überladener Funktionsname %qE in Klausel %qs"
 
-#: cp/semantics.c:6979
+#: cp/semantics.c:6982
 #, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr "Ausdruck für %<grainsize%> muss ganzzahlig sein"
 
-#: cp/semantics.c:7008
+#: cp/semantics.c:7011
 #, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr "Ausdruck für %<priority%> muss ganzzahlig sein"
 
-#: cp/semantics.c:7037
+#: cp/semantics.c:7040
 #, gcc-internal-format
 msgid "%<num_tasks%> expression must be integral"
 msgstr "Ausdruck für %<num_tasks%> muss ganzzahlig sein"
 
-#: cp/semantics.c:7066
+#: cp/semantics.c:7069
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr "Variable %qs ist weder Zeiger noch Array noch Referenz auf Zeiger oder Array"
 
-#: cp/semantics.c:7105
+#: cp/semantics.c:7108
 #, gcc-internal-format
 msgid "%<tile%> argument needs integral type"
 msgstr "Argument für %<tile%> erfordert ganzzahligen Typ"
 
-#: cp/semantics.c:7524
+#: cp/semantics.c:7527
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr "%<threadprivate%> %qD ist weder Datei-, Namens- noch Blockbereichsvariable"
 
-#: cp/semantics.c:7538
+#: cp/semantics.c:7541
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "%<threadprivate%> Direktive %qE nicht in Definition von %qT"
 
-#: cp/semantics.c:7743
+#: cp/semantics.c:7746
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr "Unterschied zwischen %qE und %qD hat keinen Ganzzahltyp"
 
-#: cp/semantics.c:8171
+#: cp/semantics.c:8174
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr "%<#pragma omp simd%> zusammen mit Iterationsvariable %qE verwendet"
 
-#: cp/semantics.c:8398 cp/semantics.c:8408
+#: cp/semantics.c:8401 cp/semantics.c:8411
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr "%<#pragma omp atomic update%> verwendet zwei unterschiedliche Ausdrücke für Speicher"
 
-#: cp/semantics.c:8702
+#: cp/semantics.c:8705
 #, gcc-internal-format
 msgid "static assertion failed"
 msgstr "statische Behauptung gescheitert"
 
-#: cp/semantics.c:8704
+#: cp/semantics.c:8707
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr "statische Erklärung gescheitert: %s"
 
-#: cp/semantics.c:8709
+#: cp/semantics.c:8712
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "Nicht-konstante Bedingung für statische Behauptung"
 
-#: cp/semantics.c:8739
+#: cp/semantics.c:8742
 #, gcc-internal-format
 msgid "argument to decltype must be an expression"
 msgstr "Argument für decltype muss ein Ausdruck sein"
 
-#: cp/semantics.c:8767
+#: cp/semantics.c:8770
 #, gcc-internal-format
 msgid "decltype cannot resolve address of overloaded function"
 msgstr "decltype kann die Adresse der überladenen Funktion nicht auflösen"
 
-#: cp/semantics.c:9308
+#: cp/semantics.c:9311
 #, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "Operand des Faltungsausdrucks hat keine unexpandierten Parameterpackungen"
 
-#: cp/semantics.c:9361
+#: cp/semantics.c:9364
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "beide Argumente in binärer Faltung haben unexpandierte Parameterpackungen"
 
-#: cp/semantics.c:9363
+#: cp/semantics.c:9366
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr "keine unexpandierten Parameterpackungen in binärer Faltung"
 
-#: cp/semantics.c:9381
+#: cp/semantics.c:9384
 #, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "Argument, das kein Zeiger ist, in %<__builtin_launder%>"
 
-#: cp/tree.c:1276
+#: cp/tree.c:1295
 #, gcc-internal-format
 msgid "%qV qualifiers cannot be applied to %qT"
 msgstr "%qV-Qualifizierer können nicht auf %qT angewendet werden"
 
-#: cp/tree.c:1788
+#: cp/tree.c:1807
 #, gcc-internal-format
 msgid "lambda-expression in a constant expression"
 msgstr "Lambda-Ausdruck in konstantem Ausdruck"
 
-#: cp/tree.c:1792
+#: cp/tree.c:1811
 #, gcc-internal-format
 msgid "statement-expression in a constant expression"
 msgstr "Anweisungs-Ausdruck in konstantem Ausdruck"
 
-#: cp/tree.c:4050
+#: cp/tree.c:4083
 #, gcc-internal-format
-msgid "the calling convention for %qT changes in -fabi-version=12 (GCC 8)"
-msgstr "die Aufrufkonvention für %qT ändert sich mit -fabi-version=12 (GCC 8)"
+msgid "-fabi-version=13 (GCC 8.2) fixes the calling convention for %qT, which was accidentally changed in 8.1"
+msgstr "-fabi-version=13 (GCC 8.2) korrigiert die Aufrufkonvention für %qT, die in 8.1 versehentlich geändert wurde"
 
-#: cp/tree.c:4055
+#: cp/tree.c:4087
 #, gcc-internal-format
+msgid "-fabi-version=12 (GCC 8.1) accidentally changes the calling convention for %qT"
+msgstr "-fabi-version=12 (GCC 8.1) ändert versehentlich die Aufrufkonvention für %qT"
+
+#: cp/tree.c:4090
+#, gcc-internal-format
+msgid " declared here"
+msgstr " hier deklariert"
+
+#: cp/tree.c:4094
+#, gcc-internal-format
+msgid "the calling convention for %qT changes in -fabi-version=13 (GCC 8.2)"
+msgstr "die Aufrufkonvention für %qT ändert sich mit -fabi-version=13 (GCC 8.2)"
+
+#: cp/tree.c:4096
+#, gcc-internal-format
 msgid " because all of its copy and move constructors are deleted"
 msgstr " da alle seine Kopier- und Verschiebekonstruktoren gelöscht sind"
 
-#: cp/tree.c:4416
+#: cp/tree.c:4464
 #, gcc-internal-format
 msgid "%qE attribute applied to %qD with void return type"
 msgstr "Attribut %qE auf %qD mit Rückgabetyp »void« angewendet"
 
-#: cp/tree.c:4423
+#: cp/tree.c:4471
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr "Attribut %qE kann nur auf Funktionen oder auf Klasse- oder Aufzählungstypen angewendet werden"
 
-#: cp/tree.c:4475
+#: cp/tree.c:4523
 #, gcc-internal-format
 msgid "requested init_priority is not an integer constant"
 msgstr "angeforderte »init_priority« muss ganzzahlig und konstant sein"
 
-#: cp/tree.c:4497
+#: cp/tree.c:4545
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr "nur Attribut %qE kann für Definitionen von Objekten eines Klassentyps im Datei-Gültigkeitsbereich verwendet werden"
 
-#: cp/tree.c:4505
+#: cp/tree.c:4553
 #, gcc-internal-format
 msgid "requested init_priority is out of range"
 msgstr "angefordertes init_priority ist außerhalb des Wertebereiches"
 
-#: cp/tree.c:4515
+#: cp/tree.c:4563
 #, gcc-internal-format
 msgid "requested init_priority is reserved for internal use"
 msgstr "angefordertes init_priority ist für interne Verwendung reserviert"
 
-#: cp/tree.c:4526
+#: cp/tree.c:4574
 #, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr "Attribut %qE wird auf dieser Plattform nicht unterstützt"
 
-#: cp/tree.c:4553
+#: cp/tree.c:4601
 #, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %qE"
 msgstr "Redeklaration von %qD fügt ABI-Marke %qE hinzu"
 
-#: cp/tree.c:4573
+#: cp/tree.c:4621
 #, gcc-internal-format
 msgid "the %qE attribute requires arguments"
 msgstr "Attribut %qE erfordert Argumente"
 
-#: cp/tree.c:4584
+#: cp/tree.c:4632
 #, gcc-internal-format
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "Argumente für Attribut %qE müssen enge Zeichenkettenliterale sein"
 
-#: cp/tree.c:4597 cp/tree.c:4610
+#: cp/tree.c:4645 cp/tree.c:4658
 #, gcc-internal-format
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "Argumente für Attribut %qE müssen gültige Bezeichner enthalten"
 
-#: cp/tree.c:4599
+#: cp/tree.c:4647
 #, gcc-internal-format
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "%<%c%> ist kein gültiges Anfangszeichen für einen Bezeichner"
 
-#: cp/tree.c:4612
+#: cp/tree.c:4660
 #, gcc-internal-format
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "%<%c%> ist kein gültiges Zeichen in einem Bezeichner"
 
-#: cp/tree.c:4636
+#: cp/tree.c:4684
 #, gcc-internal-format
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "Attribut %qE auf Nicht-Klassen-, Nicht-Enum-Typ %qT angewendet"
 
-#: cp/tree.c:4642
+#: cp/tree.c:4690
 #, gcc-internal-format
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "Attribut %qE auf %qT nach seiner Definition angewendet"
 
-#: cp/tree.c:4649
+#: cp/tree.c:4697
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "%qE-Attribut wird für Templateinstanziierung %qT ignoriert"
 
-#: cp/tree.c:4656
+#: cp/tree.c:4704
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "%qE-Attribut wird für Templatespezialisierung %qT ignoriert"
 
-#: cp/tree.c:4678
+#: cp/tree.c:4726
 #, gcc-internal-format
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "%qE-Attribut wird auf %qD angewendet, das weder Funktion noch Variable ist"
 
-#: cp/tree.c:4684
+#: cp/tree.c:4732
 #, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "Attribut %qE wird auf »extern \"C\"«-Deklaration %qD angewendet"
 
-#: cp/tree.c:5440
+#: cp/tree.c:5488
 #, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "Null als Nullzeigerkonstante"
 
-#: cp/tree.c:5453
+#: cp/tree.c:5501
 #, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr "lang_* check: failed in %s, at %s:%d"
@@ -49453,107 +49510,107 @@
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "Aggregat des Typs %qT kann nicht mit zusammengesetztem Literal initialisiert werden"
 
-#: cp/typeck2.c:1496 cp/typeck2.c:1523
+#: cp/typeck2.c:1499 cp/typeck2.c:1526
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "Initialisierung für Element %qD fehlt"
 
-#: cp/typeck2.c:1504
+#: cp/typeck2.c:1507
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "Element %qD ist nicht initialisierte Referenz"
 
-#: cp/typeck2.c:1511
+#: cp/typeck2.c:1514
 #, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr "Element %qD mit nicht initialisierten Feldern"
 
-#: cp/typeck2.c:1587
+#: cp/typeck2.c:1590
 #, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "Designator-Reihenfolge für Feld %qD passt nicht zur ursprünglichen Deklaration in %qT"
 
-#: cp/typeck2.c:1660
+#: cp/typeck2.c:1663
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "kein Feld %qD in initialisierter Union gefunden"
 
-#: cp/typeck2.c:1671
+#: cp/typeck2.c:1674
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "Indexwert statt Feldname in Union-Initialisierung"
 
-#: cp/typeck2.c:1858
+#: cp/typeck2.c:1861
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "ringförmige Zeigerdelegation erkannt"
 
-#: cp/typeck2.c:1872
+#: cp/typeck2.c:1875
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "Basisoperand von %<->%> hat Nicht-Zeiger-Typ %qT"
 
-#: cp/typeck2.c:1898
+#: cp/typeck2.c:1901
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "Ergebnis von %<operator->()%> ergibt Nicht-Zeiger-Ergebnis"
 
-#: cp/typeck2.c:1900
+#: cp/typeck2.c:1903
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "Basisoperand von %<->%> ist kein Zeiger"
 
-#: cp/typeck2.c:1927
+#: cp/typeck2.c:1930
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE kann nicht als Elementzeiger verwendet werden, da es vom Typ %qT ist"
 
-#: cp/typeck2.c:1936
+#: cp/typeck2.c:1939
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "Elementzeiger %qE kann nicht auf %qE angewandt werden, da letzteres vom Nicht-Klassen-Typ %qT ist"
 
-#: cp/typeck2.c:1958
+#: cp/typeck2.c:1961
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "Zeiger auf Elementtyp %qT mit Objekttyp %qT inkompatibel"
 
-#: cp/typeck2.c:2018
+#: cp/typeck2.c:2021
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "Typ für Zeiger auf Elementfunktion %qT braucht einen rvalue"
 
-#: cp/typeck2.c:2029
+#: cp/typeck2.c:2032
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "Typ für Zeiger auf Elementfunktion %qT braucht einen lvalue"
 
-#: cp/typeck2.c:2037
+#: cp/typeck2.c:2040
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++2a"
 msgstr "Typ für Zeiger auf Elementfunktion %qT braucht vor C++2a einen lvalue"
 
-#: cp/typeck2.c:2080
+#: cp/typeck2.c:2083
 #, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "funktionale Umwandlung in Arraytyp %qT"
 
-#: cp/typeck2.c:2096
+#: cp/typeck2.c:2099
 #, gcc-internal-format
 msgid "cannot deduce template arguments for %qT from ()"
 msgstr "Templateargumente für %qT von () können nicht hergeleitet werden"
 
-#: cp/typeck2.c:2114
+#: cp/typeck2.c:2117
 #, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "ungültige Wert-Initialisierung von Referenztyp"
 
-#: cp/typeck2.c:2341
+#: cp/typeck2.c:2344
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "Aufruf der Funktion %qD, die unvollständigen Typen %q#T wirft"
 
-#: cp/typeck2.c:2344
+#: cp/typeck2.c:2347
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "Aufruf einer Funktion, die unvollständigen Typen %q#T wirft"
@@ -49781,11 +49838,11 @@
 msgstr "Feldreferenz bei %C kann nicht mehr als %d Dimensionen haben"
 
 #: fortran/array.c:221 fortran/array.c:661 fortran/check.c:2849
-#: fortran/check.c:5222 fortran/check.c:5260 fortran/check.c:5302
-#: fortran/check.c:5329 fortran/check.c:5529 fortran/match.c:1821
+#: fortran/check.c:5225 fortran/check.c:5263 fortran/check.c:5305
+#: fortran/check.c:5332 fortran/check.c:5532 fortran/match.c:1821
 #: fortran/match.c:3174 fortran/match.c:3516 fortran/match.c:3712
-#: fortran/simplify.c:2909 fortran/simplify.c:2939 fortran/simplify.c:5764
-#: fortran/simplify.c:7658
+#: fortran/simplify.c:2909 fortran/simplify.c:2939 fortran/simplify.c:5769
+#: fortran/simplify.c:7663
 #, gcc-internal-format
 msgid "Coarrays disabled at %C, use %<-fcoarray=%> to enable"
 msgstr "Coarrays bei %C ausgeschaltet, %<-fcoarray=%> schaltet sie ein"
@@ -49921,124 +49978,129 @@
 msgid "DO-iterator %qs at %L is inside iterator of the same name"
 msgstr "DO-Iterator %qs bei %L ist innerhalb eines Iterators mit gleichem Namen"
 
-#: fortran/array.c:1073 fortran/array.c:1255
+#: fortran/array.c:1073 fortran/array.c:1264
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in array constructor at %C"
 msgstr "Syntaxfehler in Feldkonstruktor bei %C"
 
-#: fortran/array.c:1129
+#: fortran/array.c:1105
 #, gcc-internal-format, gfc-internal-format
+msgid "NULL() at %C cannot appear in an array constructor"
+msgstr "NULL() bei %C darf nicht in einem Feld-Konstruktor erscheinen"
+
+#: fortran/array.c:1138
+#, gcc-internal-format, gfc-internal-format
 msgid "[...] style array constructors at %C"
 msgstr "Feldkonstruktoren im [...]-Stil bei %C"
 
-#: fortran/array.c:1149
+#: fortran/array.c:1158
 #, gcc-internal-format, gfc-internal-format
 msgid "Array constructor including type specification at %C"
 msgstr "Feldkonstruktor mit Typspezifikation bei %C"
 
-#: fortran/array.c:1155 fortran/match.c:4148
+#: fortran/array.c:1164 fortran/match.c:4148
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-spec at %L cannot contain a deferred type parameter"
 msgstr "Typspezifikation bei %L kann keine Parameter mit aufgeschobenem Typ haben"
 
-#: fortran/array.c:1163
+#: fortran/array.c:1172
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-spec at %L cannot contain an asterisk for a type parameter"
 msgstr "Typspezifikation bei %L darf kein Sternchen für einen Typparameter enthalten"
 
-#: fortran/array.c:1181
+#: fortran/array.c:1190
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty array constructor at %C is not allowed"
 msgstr "Leerer Feldkonstruktor bei %C ist nicht erlaubt"
 
-#: fortran/array.c:1218 fortran/array.c:1228
+#: fortran/array.c:1227 fortran/array.c:1237
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible typespec for array element at %L"
 msgstr "Unverträgliche Typangabe für Feldelement bei %L"
 
-#: fortran/array.c:1302
+#: fortran/array.c:1311
 #, gcc-internal-format, gfc-internal-format
 msgid "Element in %s array constructor at %L is %s"
 msgstr "Element in Feldkonstruktor %s bei %L ist %s"
 
-#: fortran/array.c:1633
+#: fortran/array.c:1642
 #, gcc-internal-format, gfc-internal-format
 msgid "Iterator step at %L cannot be zero"
 msgstr "Iteratorschritt bei %L kann nicht Null sein"
 
-#: fortran/array.c:1770
+#: fortran/array.c:1779
 #, gcc-internal-format
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit.   See %<-fmax-array-constructor%> option"
 msgstr "Die Anzahl der Elemente im Feldkonstruktor bei %L erfordert Erhöhung der erlaubten oberen Grenze %d. Siehe Option %<-fmax-array-constructor%>"
 
-#: fortran/array.c:1940
+#: fortran/array.c:1949
 #, gcc-internal-format, gfc-internal-format
 msgid "AC-IMPLIED-DO initial expression references control variable at %L"
 msgstr "erster Ausdruck von AC-IMPLIED-DO referenziert Steuervariable bei %L"
 
-#: fortran/array.c:1947
+#: fortran/array.c:1956
 #, gcc-internal-format, gfc-internal-format
 msgid "AC-IMPLIED-DO final expression references control variable at %L"
 msgstr "letzter Ausdruck von AC-IMPLIED-DO referenziert Steuervariable bei %L"
 
-#: fortran/array.c:1954
+#: fortran/array.c:1963
 #, gcc-internal-format, gfc-internal-format
 msgid "AC-IMPLIED-DO step expression references control variable at %L"
 msgstr "Schrittausdruck von AC-IMPLIED-DO referenziert Steuervariable bei %L"
 
-#: fortran/array.c:1966
+#: fortran/array.c:1975
 #, gcc-internal-format, gfc-internal-format
 msgid "Array constructor value at %L shall not be unlimited polymorphic [F2008: C4106]"
 msgstr "Wert für Feldkonstruktor bei %L darf nicht unbegrenzt polymorph sein [F2008: C4106]"
 
-#: fortran/array.c:2055
+#: fortran/array.c:2067
 #, gcc-internal-format, gfc-internal-format
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor at %L"
 msgstr "Unterschiedliche CHARACTER-Längen (%ld, %ld) in Feldkonstruktor bei %L"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/array.c:2174
+#: fortran/array.c:2186
 #, gcc-internal-format
 msgid "spec_dimen_size(): Bad dimension"
 msgstr "spec_dimen_size(): Bad dimension"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/array.c:2233
+#: fortran/array.c:2245
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimension"
 msgstr "gfc_ref_dimen_size(): Bad dimension"
 
-#: fortran/array.c:2237
+#: fortran/array.c:2249
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array dimension at %L"
 msgstr "Ungültige Felddimension bei %L"
 
-#: fortran/array.c:2264 fortran/data.c:552 fortran/data.c:571
-#: fortran/data.c:585 fortran/data.c:714
+#: fortran/array.c:2276 fortran/data.c:563 fortran/data.c:582
+#: fortran/data.c:596 fortran/data.c:725
 #, gcc-internal-format
 msgid "Simplification error"
 msgstr "Interner Fehler: Simplification error"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/array.c:2376
+#: fortran/array.c:2388
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimen_type"
 msgstr "Interner Fehler: gfc_ref_dimen_size(): Bad dimen_type"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/array.c:2427
+#: fortran/array.c:2439
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad dimension"
 msgstr "Interner Fehler: gfc_array_dimen_size(): Bad dimension"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/array.c:2472
+#: fortran/array.c:2484
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad EXPR_ARRAY expr"
 msgstr "Interner Fehler: gfc_array_dimen_size(): Bad EXPR_ARRAY expr"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/array.c:2620
+#: fortran/array.c:2632
 #, gcc-internal-format
 msgid "gfc_find_array_ref(): No ref found"
 msgstr "Interner Fehler: gfc_find_array_ref(): No ref found"
@@ -50090,7 +50152,7 @@
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or PROCEDURE"
 msgstr "Argument %qs für intrinsisches %qs bei %L muss INTEGER oder PROCEDURE sein"
 
-#: fortran/check.c:205 fortran/check.c:6658
+#: fortran/check.c:205 fortran/check.c:6661
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a constant"
 msgstr "Argument %qs des intrinsischen %qs bei %L muss eine Konstante sein"
@@ -50205,7 +50267,7 @@
 msgid "Unequal character lengths (%ld/%ld) in %s at %L"
 msgstr "Ungleiche Zeichenlängen (%ld, %ld) in %s bei %L"
 
-#: fortran/check.c:946 fortran/check.c:6602
+#: fortran/check.c:946 fortran/check.c:6605
 #, gcc-internal-format
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have the same type"
 msgstr "Argumente %qs und %qs des intrinsischen %qs bei %L müssen denselben Typ haben"
@@ -50440,9 +50502,9 @@
 msgstr "Argument %qs des intrinsischen %qs bei %L muss vom Typ integer, read oder character sein"
 
 #: fortran/check.c:1939 fortran/check.c:2525 fortran/check.c:2628
-#: fortran/check.c:2835 fortran/check.c:2880 fortran/check.c:4256
-#: fortran/check.c:4390 fortran/check.c:4445 fortran/check.c:5515
-#: fortran/check.c:5644
+#: fortran/check.c:2835 fortran/check.c:2880 fortran/check.c:4259
+#: fortran/check.c:4393 fortran/check.c:4448 fortran/check.c:5518
+#: fortran/check.c:5647
 #, gcc-internal-format
 msgid "%qs intrinsic with KIND argument at %L"
 msgstr "intrinsisches %qs mit KIND-Argument bei %L"
@@ -50637,7 +50699,7 @@
 msgid "NULL intrinsic with allocatable MOLD at %L"
 msgstr "intrinsisches NULL mit reservierbarem MOLD bei %L"
 
-#: fortran/check.c:3768 fortran/check.c:5591
+#: fortran/check.c:3768 fortran/check.c:5594
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must provide at least as many elements as there are .TRUE. values in %qs (%ld/%d)"
 msgstr "Argument %qs des intrinsischen %qs bei %L muss mindestens so viele Elemente haben wie es .TRUE.-Werte %qs (%ld/%d) gibt"
@@ -50657,374 +50719,374 @@
 msgid "%qs argument of %qs intrinsic at %L must not be a subobject of %qs"
 msgstr "Argument %qs des intrinsischen %qs bei %L darf kein Unterobjekt von %qs sein"
 
-#: fortran/check.c:3901
+#: fortran/check.c:3904
 #, gcc-internal-format, gfc-internal-format
 msgid "The argument of the RANK intrinsic at %L must be a data object"
 msgstr "Argument des intrinsischen RANK bei %L muss ein Datenobjekt sein"
 
-#: fortran/check.c:4005
+#: fortran/check.c:4008
 #, gcc-internal-format
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L must be an array of constant size"
 msgstr "Argument »shape« des intrinsischen »reshape« bei %L muss ein Feld konstanter Größe sein"
 
-#: fortran/check.c:4015
+#: fortran/check.c:4018
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L is empty"
 msgstr "Argument %qs des intrinsischen %qs bei %L ist leer"
 
-#: fortran/check.c:4022
+#: fortran/check.c:4025
 #, gcc-internal-format
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L has more than %d elements"
 msgstr "Argument »shape« des intrinsischen »reshape« bei %L hat mehr als %d Elemente"
 
-#: fortran/check.c:4039
+#: fortran/check.c:4042
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has negative element (%d)"
 msgstr "Argument %qs des intrinsischen %qs bei %L hat negatives Element (%d)"
 
-#: fortran/check.c:4071
+#: fortran/check.c:4074
 #, gcc-internal-format, gfc-internal-format
 msgid "Element %d of actual argument of RESHAPE at %L cannot be negative"
 msgstr "Element %d des tatsächlichen Arguments von RESHAPE bei %L darf nicht negativ sein"
 
-#: fortran/check.c:4109
+#: fortran/check.c:4112
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has wrong number of elements (%d/%d)"
 msgstr "Argument %qs des intrinsischen %qs bei %L hat falsche Anzahl der Elemente (%d/%d)"
 
-#: fortran/check.c:4127
+#: fortran/check.c:4130
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has out-of-range dimension (%d)"
 msgstr "Argument %qs des intrinsischen %qs bei %L hat Dimension außerhalb des Wertebereiches (%d)"
 
-#: fortran/check.c:4136
+#: fortran/check.c:4139
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has invalid permutation of dimensions (dimension %qd duplicated)"
 msgstr "Argument %qs des intrinsischen %qs bei %L hat ungültige Permutation der Dimensionen (Dimension %qd doppelt)"
 
-#: fortran/check.c:4172
+#: fortran/check.c:4175
 #, gcc-internal-format, gfc-internal-format
 msgid "Without padding, there are not enough elements in the intrinsic RESHAPE source at %L to match the shape"
 msgstr "Ohne Auffüllen gibt es nicht genügend Elemente in intrinsischer RESHAPE-Quelle bei %L, um zur Form zu passen"
 
-#: fortran/check.c:4189 fortran/check.c:4208
+#: fortran/check.c:4192 fortran/check.c:4211
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L cannot be of type %s"
 msgstr "Argument %qs des intrinsischen %qs bei %L kann nicht Typ %s haben"
 
-#: fortran/check.c:4199 fortran/check.c:4218
+#: fortran/check.c:4202 fortran/check.c:4221
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of an extensible type"
 msgstr "Argument %qs des intrinsischen %qs bei %L muss erweiterbaren Typ haben"
 
-#: fortran/check.c:4317
+#: fortran/check.c:4320
 #, gcc-internal-format
 msgid "SELECTED_REAL_KIND with neither %<P%> nor %<R%> argument at %L"
 msgstr "SELECTED_REAL_KIND ohne Argument »P« oder »R« bei %L"
 
-#: fortran/check.c:4348
+#: fortran/check.c:4351
 #, gcc-internal-format
 msgid "%qs intrinsic with RADIX argument at %L"
 msgstr "intrinsisches %qs mit RADIX-Argument bei %L"
 
-#: fortran/check.c:4383
+#: fortran/check.c:4386
 #, gcc-internal-format
 msgid "%<source%> argument of %<shape%> intrinsic at %L must not be an assumed size array"
 msgstr "Argument »source« des intrinsischen »shape« bei %L darf kein Feld impliziter Größe sein"
 
-#: fortran/check.c:4460 fortran/check.c:6641
+#: fortran/check.c:4463 fortran/check.c:6644
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be a procedure"
 msgstr "Argument %qs des intrinsischen %qs bei %L darf keine Prozedur sein"
 
-#: fortran/check.c:4473 fortran/check.c:4612 fortran/check.c:6633
+#: fortran/check.c:4476 fortran/check.c:4615 fortran/check.c:6636
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be TYPE(*)"
 msgstr "Argument %qs des intrinsischen %qs bei %L darf nicht TYPE(*) sein"
 
-#: fortran/check.c:4484 fortran/check.c:4624
+#: fortran/check.c:4487 fortran/check.c:4627
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be an assumed-size array"
 msgstr "Argument %qs des intrinsischen %qs bei %L darf kein Feld impliziter Größe sein"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/check.c:4554
+#: fortran/check.c:4557
 #, gcc-internal-format
 msgid "is_c_interoperable(): gfc_simplify_expr failed"
 msgstr "is_c_interoperable(): gfc_simplify_expr failed"
 
-#: fortran/check.c:4603
+#: fortran/check.c:4606
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be an interoperable data entity: %s"
 msgstr "Argument %qs des intrinsischen %qs bei %L muss austauschbare Datenentität sein: %s"
 
-#: fortran/check.c:4642
+#: fortran/check.c:4645
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_1 at %L to C_ASSOCIATED shall have the type TYPE(C_PTR) or TYPE(C_FUNPTR)"
 msgstr "Argument C_PTR_1 bei %L für C_ASSOCIATED muss den Typ TYPE(C_PTR) oder TYPE(C_FUNPTR) haben"
 
-#: fortran/check.c:4656
+#: fortran/check.c:4659
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_2 at %L to C_ASSOCIATED shall have the same type as C_PTR_1: %s instead of %s"
 msgstr "Argument C_PTR_2 bei %L für C_ASSOCIATED muss denselben Typ wie C_PTR_1 haben: %s statt %s"
 
-#: fortran/check.c:4680
+#: fortran/check.c:4683
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_POINTER shall have the type TYPE(C_PTR)"
 msgstr "Argument CPTR bei %L für C_F_POINTER muss den Typen TYPE(C_PTR) haben"
 
-#: fortran/check.c:4692
+#: fortran/check.c:4695
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER must be a pointer"
 msgstr "Argument FPTR bei %L für C_F_POINTER muss ein Zeiger sein"
 
-#: fortran/check.c:4699
+#: fortran/check.c:4702
 #, gcc-internal-format, gfc-internal-format
 msgid "FPTR argument at %L to C_F_POINTER shall not be polymorphic"
 msgstr "Argument FPTR für C_F_POINTER bei %L darf nicht polymorph sein"
 
-#: fortran/check.c:4706
+#: fortran/check.c:4709
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER shall not be coindexed"
 msgstr "Argument FPTR für C_F_POINTER bei %L darf nicht koindiziert sein"
 
-#: fortran/check.c:4713
+#: fortran/check.c:4716
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected SHAPE argument at %L to C_F_POINTER with scalar FPTR"
 msgstr "Unerwartetes SHAPE-Argument bei %L für C_F_POINTER mit skalarem FPTR"
 
-#: fortran/check.c:4719
+#: fortran/check.c:4722
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected SHAPE argument to C_F_POINTER with array FPTR at %L"
 msgstr "SHAPE-Argument für C_F_POINTER mit Array-FPTR bei %L erwartet"
 
-#: fortran/check.c:4738
+#: fortran/check.c:4741
 #, gcc-internal-format, gfc-internal-format
 msgid "SHAPE argument at %L to C_F_POINTER must have the same size as the RANK of FPTR"
 msgstr "SHAPE-Argument bei %L für C_F_POINTER muss dieselbe Größe haben wie der RANK des FPTR"
 
-#: fortran/check.c:4748
+#: fortran/check.c:4751
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic FPTR at %L to C_F_POINTER"
 msgstr "Polymorpher FPTR bei %L für C_F_POINTER"
 
-#: fortran/check.c:4753
+#: fortran/check.c:4756
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array FPTR at %L to C_F_POINTER: %s"
 msgstr "Unverträglicher Feld-FPTR bei %L für C_F_POINTER: %s"
 
-#: fortran/check.c:4769
+#: fortran/check.c:4772
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_PROCPOINTER shall have the type TYPE(C_FUNPTR)"
 msgstr "Argument CPTR bei %L für C_F_PROCPOINTER muss den Typen TYPE(C_FUNPTR) haben"
 
-#: fortran/check.c:4781
+#: fortran/check.c:4784
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall be a procedure pointer"
 msgstr "Argument FPTR bei %L für C_F_PROCPOINTER muss ein Prozedurzeiger sein"
 
-#: fortran/check.c:4788
+#: fortran/check.c:4791
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall not be coindexed"
 msgstr "Argument FPTR bei %L für C_F_PROCPOINTER darf nicht koindiziert sein"
 
-#: fortran/check.c:4794
+#: fortran/check.c:4797
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure pointer at %L to C_F_PROCPOINTER"
 msgstr "Unverträglicher Prozedurzeiger bei %L für C_F_PROCPOINTER"
 
-#: fortran/check.c:4808
+#: fortran/check.c:4811
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall not be coindexed"
 msgstr "Argument X bei %L für C_FUNLOC darf nicht koindiziert sein"
 
-#: fortran/check.c:4823
+#: fortran/check.c:4826
 #, gcc-internal-format
 msgid "Function result %qs at %L is invalid as X argument to C_FUNLOC"
 msgstr "Funktionsergebnis %qs bei %L ist als X-Argument für C_FUNLOC ungültig"
 
-#: fortran/check.c:4831
+#: fortran/check.c:4834
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall be a procedure or a procedure pointer"
 msgstr "Argument X bei %L für C_FUNLOC muss eine Prozedur oder ein Prozedurzeiger sein"
 
-#: fortran/check.c:4837
+#: fortran/check.c:4840
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure at %L to C_FUNLOC"
 msgstr "Unverträgliche Prozedur bei %L für C_FUNLOC"
 
-#: fortran/check.c:4851
+#: fortran/check.c:4854
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall not be coindexed"
 msgstr "Argument X bei %L für C_LOC darf nicht koindiziert sein"
 
-#: fortran/check.c:4857
+#: fortran/check.c:4860
 #, gcc-internal-format, gfc-internal-format
 msgid "X argument at %L to C_LOC shall not be polymorphic"
 msgstr "X-Argument bei %L für C_LOC darf nicht polymorph sein"
 
-#: fortran/check.c:4868
+#: fortran/check.c:4871
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall have either the POINTER or the TARGET attribute"
 msgstr "Argument X bei %L für C_LOC muss entweder POINTER- oder TARGET-Attribut haben"
 
-#: fortran/check.c:4876
+#: fortran/check.c:4879
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall be not be a zero-sized string"
 msgstr "Argument X bei %L für C_LOC darf keine Zeichenkette der Länge 0 sein"
 
-#: fortran/check.c:4885
+#: fortran/check.c:4888
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument at %L to C_LOC shall not be polymorphic"
 msgstr "Argument bei %L für C_LOC darf nicht polymorph sein"
 
-#: fortran/check.c:4892
+#: fortran/check.c:4895
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array at %L as argument to C_LOC: %s"
 msgstr "Unverträgliches Feld bei %L als Argument für C_LOC: %s"
 
-#: fortran/check.c:4903
+#: fortran/check.c:4906
 #, gcc-internal-format, gfc-internal-format
 msgid "Array of interoperable type at %L to C_LOC which is nonallocatable and neither assumed size nor explicit size"
 msgstr "Feld von interoperablem Typ bei %L für C_LOC; es ist nichtallozierbar und hat weder angenommene noch explizite Größe"
 
-#: fortran/check.c:4908
+#: fortran/check.c:4911
 #, gcc-internal-format, gfc-internal-format
 msgid "Array section at %L to C_LOC"
 msgstr "Feldabschnitt bei %L für C_LOC"
 
-#: fortran/check.c:4936
+#: fortran/check.c:4939
 #, gcc-internal-format, gfc-internal-format
 msgid "non double precision REAL argument to %s intrinsic at %L"
 msgstr "REAL-Argument ohne doppelte Genauigkeit für intrinsisches %s bei %L"
 
-#: fortran/check.c:4949
+#: fortran/check.c:4952
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be less than rank %d"
 msgstr "Argument %qs für intrinsisches %qs bei %L muss geringer als Rang %d sein"
 
-#: fortran/check.c:4968
+#: fortran/check.c:4971
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L is not a valid dimension index"
 msgstr "Argument %qs des intrinsischen %qs bei %L ist kein gültiger Dimensionsindex"
 
-#: fortran/check.c:5231
+#: fortran/check.c:5234
 #, gcc-internal-format, gfc-internal-format
 msgid "%s argument to IMAGE_INDEX must be a rank one array at %L"
 msgstr "Argument »%s« für IMAGE_INDEX muss Feld mit Rang 1 bei %L sein"
 
-#: fortran/check.c:5242
+#: fortran/check.c:5245
 #, gcc-internal-format, gfc-internal-format
 msgid "The number of array elements of the SUB argument to IMAGE_INDEX at %L shall be %d (corank) not %d"
 msgstr "Die Anzahl der Feldelemente des SUB-Arguments für IMAGE_INDEX bei %L muss %d (Korang) sein, nicht %d"
 
-#: fortran/check.c:5275
+#: fortran/check.c:5278
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to NUM_IMAGES at %L"
 msgstr "Argument DISTANCE= für NUM_IMAGES bei %L"
 
-#: fortran/check.c:5288
+#: fortran/check.c:5291
 #, gcc-internal-format, gfc-internal-format
 msgid "FAILED= argument to NUM_IMAGES at %L"
 msgstr "Argument FAILED= für NUM_IMAGES bei %L"
 
-#: fortran/check.c:5312
+#: fortran/check.c:5315
 #, gcc-internal-format, gfc-internal-format
 msgid "TEAM argument at %L to the intrinsic TEAM_NUMBER shall be of type TEAM_TYPE"
 msgstr "TEAM-Argument bei %L für die intrinsische TEAM_NUMBER muss vom Typ TEAM_TYPE sein"
 
-#: fortran/check.c:5338
+#: fortran/check.c:5341
 #, gcc-internal-format, gfc-internal-format
 msgid "DIM argument without COARRAY argument not allowed for THIS_IMAGE intrinsic at %L"
 msgstr "DIM-Argument ohne COARRAY-Argument ist für intrinsisches THIS_IMAGE bei %L nicht erlaubt"
 
-#: fortran/check.c:5345
+#: fortran/check.c:5348
 #, gcc-internal-format, gfc-internal-format
 msgid "The DISTANCE argument may not be specified together with the COARRAY or DIM argument in intrinsic at %L"
 msgstr "Das DISTANCE-Argument darf in intrinsischer Routine bei %L nicht zusammen mit COARRAY- oder DIM-Argument angegeben werden"
 
-#: fortran/check.c:5356
+#: fortran/check.c:5359
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected DIM argument with noncoarray argument at %L"
 msgstr "Unerwartetes DIM-Argument mit Nicht-COARRAY-Argument bei %L"
 
-#: fortran/check.c:5374
+#: fortran/check.c:5377
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to THIS_IMAGE at %L"
 msgstr "Argument DISTANCE= für THIS_IMAGE bei %L"
 
-#: fortran/check.c:5454
+#: fortran/check.c:5457
 #, gcc-internal-format
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L must not be %s"
 msgstr "Argument %<MOLD%> des intrinsischen %<TRANSFER%> bei %L darf nicht %s sein"
 
-#: fortran/check.c:5483
+#: fortran/check.c:5486
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic TRANSFER at %L has partly undefined result: source size %ld < result size %ld"
 msgstr "Intrinsisches TRANSFER bei %L hat teilweise undefiniertes Ergebnis: Quellgröße %ld < Ergebnisgröße %ld"
 
-#: fortran/check.c:5605
+#: fortran/check.c:5608
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must have the same rank as %qs or be a scalar"
 msgstr "Argument %qs des intrinsischen %qs bei %L muss den selben Rang wie %qs haben oder skalar sein"
 
-#: fortran/check.c:5618
+#: fortran/check.c:5621
 #, gcc-internal-format
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have identical shape."
 msgstr "Argumente %qs und %qs des intrinsischen %qs bei %L müssen gleiche Form haben."
 
-#: fortran/check.c:5861 fortran/check.c:5893
+#: fortran/check.c:5864 fortran/check.c:5896
 #, gcc-internal-format
 msgid "Size of %qs argument of %qs intrinsic at %L too small (%i/%i)"
 msgstr "Größe des Arguments %qs des intrinsischen %qs bei %L ist zu klein (%i/%i)"
 
-#: fortran/check.c:5901
+#: fortran/check.c:5904
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many arguments to %s at %L"
 msgstr "Zu viele Argumente für %s bei %L"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/check.c:5919
+#: fortran/check.c:5922
 #, gcc-internal-format
 msgid "fe_runtime_error string must be null terminated"
 msgstr "fe_runtime_error string must be null terminated"
 
-#: fortran/check.c:5931
+#: fortran/check.c:5934
 #, gcc-internal-format, gfc-internal-format
 msgid "fe_runtime_error: Wrong number of arguments (%d instead of %d)"
 msgstr "fe_runtime_error: Wrong number of arguments (%d instead of %d)"
 
-#: fortran/check.c:5971
+#: fortran/check.c:5974
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr "Das COUNT-Argument für SYSTEM_CLOCK bei %L hat nicht-Standard-Art"
 
-#: fortran/check.c:5990
+#: fortran/check.c:5993
 #, gcc-internal-format, gfc-internal-format
 msgid "Real COUNT_RATE argument to SYSTEM_CLOCK at %L"
 msgstr "Reelles COUNT_RATE-Argument für SYSTEM_CLOCK bei %L"
 
-#: fortran/check.c:6000
+#: fortran/check.c:6003
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT_RATE argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr "Das COUNT_RATE-Argument für SYSTEM_CLOCK bei %L hat nicht-Standard-Art"
 
-#: fortran/check.c:6017
+#: fortran/check.c:6020
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT_MAX argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr "Das COUNT_MAX-Argument für SYSTEM_CLOCK bei %L hat nicht-Standard-Art"
 
-#: fortran/check.c:6234
+#: fortran/check.c:6237
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of a kind not wider than the default kind (%d)"
 msgstr "Argument %qs des intrinsischen %qs bei %L darf von der Art nicht breiter als der Standard (%d) sein"
 
-#: fortran/check.c:6586 fortran/check.c:6594
+#: fortran/check.c:6589 fortran/check.c:6597
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or LOGICAL"
 msgstr "Argument %qs für intrinsisches %qs bei %L muss INTEGER oder LOGICAL sein"
 
-#: fortran/check.c:6625
+#: fortran/check.c:6628
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic function NULL at %L cannot be an actual argument to STORAGE_SIZE, because it returns a disassociated pointer"
 msgstr "Intrinsische Funktion NULL bei %L kann kein tatsächliches Argument für STORAGE_SIZE sein, da es einen disassoziierten Zeiger zurückgibt"
@@ -51036,7 +51098,7 @@
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:727 fortran/decl.c:3636 fortran/decl.c:10066
+#: fortran/class.c:727 fortran/decl.c:3655 fortran/decl.c:10091
 #, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr "Höchste Erweiterungsstufe mit Typ %qs bei %L erreicht"
@@ -51061,43 +51123,48 @@
 msgid "non-constant array in DATA statement %L"
 msgstr "Nichtkonstantes Feld in DATA-Anweisung %L"
 
-#: fortran/data.c:137
+#: fortran/data.c:140
 #, gcc-internal-format, gfc-internal-format
 msgid "failure to simplify substring reference in DATA statement at %L"
 msgstr "Fehlschlag bei Vereinfachung der Teil-Zeichenketten-Referenz in DATA-Anweisung bei %L"
 
-#: fortran/data.c:170
+#: fortran/data.c:173
 #, gcc-internal-format, gfc-internal-format
 msgid "Unused initialization string at %L because variable has zero length"
 msgstr "Unbenutzte Initialisierungszeichenkette bei %L, da die Variable die Länge 0 hat"
 
-#: fortran/data.c:176
+#: fortran/data.c:179
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization string at %L was truncated to fit the variable (%ld/%ld)"
 msgstr "Initialisierungszeichenkette bei %L wurde abgeschnitten, um zur Variable zu passen (%ld/%ld)"
 
-#: fortran/data.c:265
+#: fortran/data.c:268
 #, gcc-internal-format
 msgid "%qs at %L already is initialized at %L"
 msgstr "%qs bei %L wurde bereits bei %L initialisiert"
 
-#: fortran/data.c:289
+#: fortran/data.c:292
 #, gcc-internal-format, gfc-internal-format
 msgid "Data element below array lower bound at %L"
 msgstr "Datenelement unterhalb der unteren Feldgrenze bei %L"
 
-#: fortran/data.c:306 fortran/data.c:395
+#: fortran/data.c:309 fortran/data.c:398
 #, gcc-internal-format, gfc-internal-format
 msgid "Data element above array upper bound at %L"
 msgstr "Datenelement oberhalb der oberen Feldgrenze bei %L"
 
-#: fortran/data.c:336 fortran/data.c:505
+#: fortran/data.c:339 fortran/data.c:496
 #, gcc-internal-format
 msgid "re-initialization of %qs at %L"
 msgstr "Reinitialisierung von %qs bei %L"
 
+#: fortran/data.c:515
+#, gcc-internal-format
+msgid "Nonpointer object %qs with default initialization shall not appear in a DATA statement at %L"
+msgstr "Nichtzeiger-Objekt %qs mit Standard-Initialisierung darf nicht in einer DATA-Anweisung bei %L erscheinen"
+
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/data.c:727
+#: fortran/data.c:738
 #, gcc-internal-format
 msgid "TODO: Vector sections in data statements"
 msgstr "TODO: Vector sections in data statements"
@@ -51122,786 +51189,786 @@
 msgid "Invalid initializer %s in Data statement at %C"
 msgstr "Ungültige Initialisierung %s in Data-Anweisung bei %C"
 
-#: fortran/decl.c:536
+#: fortran/decl.c:537
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C is not allowed in a PURE procedure"
 msgstr "Initialisierung bei %C ist in PURE-Prozedur nicht erlaubt"
 
-#: fortran/decl.c:573
+#: fortran/decl.c:574
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %C cannot appear within an INTERFACE"
 msgstr "DATA-Anweisung bei %C kann nicht innerhalb von INTERFACE auftreten"
 
-#: fortran/decl.c:597
+#: fortran/decl.c:598
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid substring in data-implied-do at %L in DATA statement"
 msgstr "Ungültige Teilzeichenkette in data-implied-do in DATA-Anweisung bei %L"
 
-#: fortran/decl.c:619
+#: fortran/decl.c:620
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %C is not allowed in a PURE procedure"
 msgstr "DATA-Anweisung bei %C ist in PURE-Prozedur nicht erlaubt"
 
-#: fortran/decl.c:664
+#: fortran/decl.c:662
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty old style initializer list at %C"
 msgstr "Leere Initialisierungsliste im alten Stil bei %C"
 
-#: fortran/decl.c:684
+#: fortran/decl.c:671
 #, gcc-internal-format, gfc-internal-format
+msgid "Array in initializer list at %L must have an explicit shape"
+msgstr "Feld in der Initialisierungsliste bei %L muss eine explizite Form haben"
+
+#: fortran/decl.c:694
+#, gcc-internal-format, gfc-internal-format
 msgid "Repeat spec invalid in scalar initializer at %C"
 msgstr "Ungültige Wiederholungsangabe in Skalar-Initialisierung bei %C"
 
-#: fortran/decl.c:689
+#: fortran/decl.c:699
 #, gcc-internal-format, gfc-internal-format
 msgid "Repeat spec must be an integer at %C"
 msgstr "Wiederholungsangabe bei %C muss eine Ganzzahl sein"
 
-#: fortran/decl.c:698
+#: fortran/decl.c:710
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected data constant after repeat spec at %C"
 msgstr "Datenkonstante nach Wiederholungsangabe bei %C erwartet"
 
-#: fortran/decl.c:729
+#: fortran/decl.c:742
 #, gcc-internal-format, gfc-internal-format
 msgid "End of scalar initializer expected at %C"
 msgstr "Ende der skalaren Initialisierung bei %C erwartet"
 
-#: fortran/decl.c:758
+#: fortran/decl.c:773
 #, gcc-internal-format, gfc-internal-format
-msgid "Expected constant array-spec in initializer list at %L"
-msgstr "Konstante Feldangabe erwartet in Initialisierungsliste bei %L"
-
-#: fortran/decl.c:767
-#, gcc-internal-format, gfc-internal-format
 msgid "Not enough elements in array initializer at %C"
 msgstr "Nicht genug Element in Feldinitialisierung bei %C"
 
-#: fortran/decl.c:769
+#: fortran/decl.c:775
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many elements in array initializer at %C"
 msgstr "Zu viele Elemente in Feldinitialisierung bei %C"
 
-#: fortran/decl.c:790
+#: fortran/decl.c:795
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in old style initializer list at %C"
 msgstr "Syntaxfehler in Initialisierungsliste im alten Stil bei %C"
 
-#: fortran/decl.c:812
+#: fortran/decl.c:821
 #, gcc-internal-format, gfc-internal-format
 msgid "The assumed-rank array at %C shall not have a codimension"
 msgstr "Das Feld vermuteten Ranges bei %C darf keine Kodimension haben"
 
-#: fortran/decl.c:876
+#: fortran/decl.c:885
 #, gcc-internal-format, gfc-internal-format
 msgid "Sum of array rank %d and corank %d at %C exceeds maximum allowed dimensions of %d"
 msgstr "Die Summe aus Feldrang %d und Korang %d bei %C übersteigt die Höchstanzahl %d an Dimensionen"
 
-#: fortran/decl.c:900
+#: fortran/decl.c:909
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad INTENT specification at %C"
 msgstr "Falsche INTENT-Spezifikation bei %C"
 
-#: fortran/decl.c:921
+#: fortran/decl.c:930
 #, gcc-internal-format, gfc-internal-format
 msgid "deferred type parameter at %C"
 msgstr "Parameter mit zurückgestelltem Typ bei %C"
 
-#: fortran/decl.c:1004 fortran/resolve.c:11705
+#: fortran/decl.c:1013 fortran/resolve.c:11725
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr "Skalarer INTEGER-Ausdruck bei %L erwartet"
 
-#: fortran/decl.c:1030
+#: fortran/decl.c:1039
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style character length at %C"
 msgstr "Zeichenlänge alten Stils bei %C"
 
-#: fortran/decl.c:1061
+#: fortran/decl.c:1070
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in character length specification at %C"
 msgstr "Syntaxfehler in Zeichenlängenangabe bei %C"
 
-#: fortran/decl.c:1212 fortran/decl.c:1217 fortran/decl.c:1266
+#: fortran/decl.c:1221 fortran/decl.c:1226 fortran/decl.c:1275
 #, gcc-internal-format
 msgid "Procedure %qs at %C is already defined at %L"
 msgstr "Prozedur %qs bei %C wurde bereits bei %L definiert"
 
-#: fortran/decl.c:1222
+#: fortran/decl.c:1231
 #, gcc-internal-format
 msgid "Contained procedure %qs at %C clashes with procedure defined at %L"
 msgstr "Enthaltene Prozedur %qs bei %C steht in Konflikt mit Prozedur, die bei %L definiert wurde"
 
-#: fortran/decl.c:1231
+#: fortran/decl.c:1240
 #, gcc-internal-format
 msgid "Name %qs at %C is already defined as a generic interface at %L"
 msgstr "Name %qs bei %C ist bereits als eine allgemeine Schnittstelle bei %L definiert"
 
-#: fortran/decl.c:1244
+#: fortran/decl.c:1253
 #, gcc-internal-format
 msgid "Procedure %qs at %C has an explicit interface from a previous declaration"
 msgstr "Prozedur %qs bei %C hat eine explizite Schnittstelle aus einer vorherigen Deklaration"
 
-#: fortran/decl.c:1257
+#: fortran/decl.c:1266
 #, gcc-internal-format
 msgid "Procedure %qs defined in interface body at %L clashes with internal procedure defined at %C"
 msgstr "Die Prozedur %qs, die im Interface-Körper bei %L definiert ist, passt nicht zu der internen Prozedur bei %C"
 
-#: fortran/decl.c:1335
+#: fortran/decl.c:1344
 #, gcc-internal-format
 msgid "Procedure %qs at %L must have the BIND(C) attribute to be C interoperable"
 msgstr "Prozedur %qs bei %L muss das BIND(C)-Attribut haben, um mit C interoperabel zu sein"
 
-#: fortran/decl.c:1362
+#: fortran/decl.c:1371
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because derived type %qs is not C interoperable"
 msgstr "Variable %qs bei %L ist ein Scheinargument für die BIND(C)-Prozedur %qs, jedoch nicht interoperabel mit C, da der abgeleitete Typ %qs nicht mit C interoperabel ist"
 
-#: fortran/decl.c:1369
+#: fortran/decl.c:1378
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because it is polymorphic"
 msgstr "Variable %qs bei %L ist ein Scheinargument für die BIND(C)-Prozedur %qs, jedoch nicht interoperabel mit C, da sie polymorph ist"
 
-#: fortran/decl.c:1376
+#: fortran/decl.c:1385
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument of the BIND(C) procedure %qs but may not be C interoperable"
 msgstr "Variable %qs bei %L ist ein Scheinargument für die BIND(C)-Prozedur %qs, könnte jedoch unverträglich mit C sein"
 
-#: fortran/decl.c:1391
+#: fortran/decl.c:1400
 #, gcc-internal-format
 msgid "Character argument %qs at %L must be length 1 because procedure %qs is BIND(C)"
 msgstr "Zeichenargument %qs bei %L muss Länge 1 haben, da Prozedur %qs BIND(C) ist"
 
-#: fortran/decl.c:1404
+#: fortran/decl.c:1413
 #, gcc-internal-format
 msgid "Variable %qs at %L with ALLOCATABLE attribute in procedure %qs with BIND(C)"
 msgstr "Variable %qs bei %L mit OPTIONAL-Attribut in Prozedur %qs, die BIND(C) ist"
 
-#: fortran/decl.c:1412
+#: fortran/decl.c:1421
 #, gcc-internal-format
 msgid "Variable %qs at %L with POINTER attribute in procedure %qs with BIND(C)"
 msgstr "Variable %qs bei %L mit OPTIONAL-Attribut in Prozedur %qs, die BIND(C) ist"
 
-#: fortran/decl.c:1421
+#: fortran/decl.c:1430
 #, gcc-internal-format
 msgid "Scalar variable %qs at %L with POINTER or ALLOCATABLE in procedure %qs with BIND(C) is not yet supported"
 msgstr "Skalare Variable %qs bei %L mit POINTER oder ALLOCATABLE in Prozedur %qs mit BIND(C) wird noch nicht unterstützt"
 
-#: fortran/decl.c:1430
+#: fortran/decl.c:1439
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the OPTIONAL and the VALUE attribute because procedure %qs is BIND(C)"
 msgstr "Variable %qs bei %L kann nicht gleichzeitig die Attribute OPTIONAL und VALUE haben, da Prozedur %qs BIND(C) ist"
 
-#: fortran/decl.c:1437
+#: fortran/decl.c:1446
 #, gcc-internal-format
 msgid "Variable %qs at %L with OPTIONAL attribute in procedure %qs which is BIND(C)"
 msgstr "Variable %qs bei %L mit OPTIONAL-Attribut in Prozedur %qs, die jedoch BIND(C) ist"
 
-#: fortran/decl.c:1448
+#: fortran/decl.c:1457
 #, gcc-internal-format
 msgid "Assumed-shape array %qs at %L as dummy argument to the BIND(C) procedure %qs at %L"
 msgstr "Feld mit angenommener Form %qs bei %L als Scheinargument für die BIND(C)-Prozedur %qs bei %L"
 
-#: fortran/decl.c:1516
+#: fortran/decl.c:1525
 #, gcc-internal-format
 msgid "Symbol %qs at %C also declared as a type at %L"
 msgstr "Symbol %qs bei %C ist bereits bei %L als ein Typ deklariert"
 
-#: fortran/decl.c:1575
+#: fortran/decl.c:1584
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %C must be declared with a C interoperable kind since common block %qs is BIND(C)"
 msgstr "Variable %qs in gemeinsamem Block %qs bei %C muss mit einer mit C interoperablen Art deklariert sein, da der gemeinsame Block %qs BIND(C) ist"
 
-#: fortran/decl.c:1615
+#: fortran/decl.c:1624
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER length must be a constant at %L"
 msgstr "CHARACTER-Länge bei %L muss konstant sein"
 
-#: fortran/decl.c:1630
+#: fortran/decl.c:1639
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression at %L is being truncated (%ld/%ld)"
 msgstr "CHARACTER-Ausdruck bei %L wird abgeschnitten (%ld/%ld)"
 
-#: fortran/decl.c:1638
+#: fortran/decl.c:1647
 #, gcc-internal-format, gfc-internal-format
 msgid "The CHARACTER elements of the array constructor at %L must have the same length (%ld/%ld)"
 msgstr "Die CHARACTER-Elemente des Feldkonstruktors bei %L müssen dieselbe Länge haben (%ld/%ld)"
 
-#: fortran/decl.c:1729
+#: fortran/decl.c:1738
 #, gcc-internal-format
 msgid "Initializer not allowed for PARAMETER %qs at %C"
 msgstr "Initialisierer nicht erlaubt für PARAMETER %qs bei %C"
 
-#: fortran/decl.c:1739
+#: fortran/decl.c:1748
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER at %L is missing an initializer"
 msgstr "Fehlende Initialisierung für PARAMETER bei %L"
 
-#: fortran/decl.c:1749
+#: fortran/decl.c:1758
 #, gcc-internal-format
 msgid "Variable %qs at %C with an initializer already appears in a DATA statement"
 msgstr "Variable %qs bei %C mit Initialisierung tritt bereits in einer DATA-Anweisung auf"
 
-#: fortran/decl.c:1792
+#: fortran/decl.c:1801
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot initialize parameter array at %L with variable length elements"
 msgstr "Parameter-Feld bei %L kann nicht mit Elementen variabler Länge initialisiert werden"
 
-#: fortran/decl.c:1861
+#: fortran/decl.c:1870
 #, gcc-internal-format, gfc-internal-format
 msgid "Can't initialize implied-shape array at %L with scalar"
 msgstr "Feld mit implizierter Form bei %L kann nicht mit Skalar initialisiert werden"
 
-#: fortran/decl.c:1896
+#: fortran/decl.c:1905
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-constant lower bound in implied-shape declaration at %L"
 msgstr "Nicht-konstante untere Grenze in Deklaration mit impliziter Form bei %L"
 
-#: fortran/decl.c:1982 fortran/decl.c:1989
+#: fortran/decl.c:1991 fortran/decl.c:1998
 #, gcc-internal-format, gfc-internal-format
 msgid "Component at %C must have the POINTER attribute"
 msgstr "Komponente bei %C muss ein POINTER-Attribut haben"
 
-#: fortran/decl.c:1998
+#: fortran/decl.c:2007
 #, gcc-internal-format
 msgid "Component %qs with CLASS at %C must be allocatable or pointer"
 msgstr "Komponente %qs mit CLASS bei %C muss allozierbar oder Zeiger sein"
 
-#: fortran/decl.c:2007
+#: fortran/decl.c:2016
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr "Feldkomponente der Struktur bei %C muss explizite oder aufgeschobene Form haben"
 
-#: fortran/decl.c:2031 fortran/symbol.c:2230
+#: fortran/decl.c:2040 fortran/symbol.c:2244
 #, gcc-internal-format
 msgid "Component %qs at %C already declared at %L"
 msgstr "Komponente %qs bei %C bereits bei %L deklariert"
 
-#: fortran/decl.c:2079
+#: fortran/decl.c:2088
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer array component of structure at %C must have a deferred shape"
 msgstr "Zeigerfeld-Komponente der Struktur bei %C muss eine aufgeschobene Form haben"
 
-#: fortran/decl.c:2088
+#: fortran/decl.c:2097
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component of structure at %C must have a deferred shape"
 msgstr "Allozierbare Komponente der Struktur bei %C muss eine aufgeschobene Form haben"
 
-#: fortran/decl.c:2097
+#: fortran/decl.c:2106
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have an explicit shape"
 msgstr "Feldkomponente der Struktur bei %C muss eine explizite Form haben"
 
-#: fortran/decl.c:2114
+#: fortran/decl.c:2123
 #, gcc-internal-format
 msgid "Type parameter %qs at %C has no corresponding entry in the type parameter name list at %L"
 msgstr "Typparameter %qs bei %C hat keinen zugehörigen Eintrag in der Typparameter-Namensliste bei %L"
 
-#: fortran/decl.c:2171
+#: fortran/decl.c:2180
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C is ambiguous"
 msgstr "NULL()-Initialisierung bei %C ist mehrdeutig"
 
-#: fortran/decl.c:2188
+#: fortran/decl.c:2197
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C may not have MOLD"
 msgstr "NULL()-Initialisierung bei %C könnte kein MOLD haben"
 
-#: fortran/decl.c:2205
+#: fortran/decl.c:2214
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of pointer at %C is not allowed in a PURE procedure"
 msgstr "Initialisierung des Zeigers bei %C ist nicht in einer PURE-Prozedur erlaubt"
 
-#: fortran/decl.c:2226
+#: fortran/decl.c:2235
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in pointer initialization at %C"
 msgstr "Fehler in Zeigerinitialisierung bei %C"
 
-#: fortran/decl.c:2233
+#: fortran/decl.c:2242
 #, gcc-internal-format, gfc-internal-format
 msgid "non-NULL pointer initialization at %C"
 msgstr "Nicht-NULL-Zeigerinitialisierung bei %C"
 
-#: fortran/decl.c:2256
+#: fortran/decl.c:2265
 #, gcc-internal-format
 msgid "RESULT variable %qs at %L prohibits FUNCTION name %qs at %C from appearing in a specification statement"
 msgstr "Die RESULT-Variable %qs bei %L verbietet, dass der FUNCTION-Name %qs bei %C in einer Spezifikationsanweisung auftritt"
 
-#: fortran/decl.c:2318
+#: fortran/decl.c:2327
 #, gcc-internal-format
 msgid "%qs not allowed outside STRUCTURE at %C"
 msgstr "%qs ist außerhalb der STRUCTURE bei %C nicht erlaubt"
 
-#: fortran/decl.c:2320
+#: fortran/decl.c:2329
 #, gcc-internal-format
 msgid "%qs at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr "%qs bei %C ist eine DEC-Erweiterung, muss mit »-fdec-structure« eingeschaltet werden"
 
-#: fortran/decl.c:2327
+#: fortran/decl.c:2336
 #, gcc-internal-format
 msgid "%qs entity cannot have attributes at %C"
 msgstr "Entität %qs bei %C kann keine Argumente haben"
 
-#: fortran/decl.c:2367
+#: fortran/decl.c:2376
 #, gcc-internal-format
 msgid "Non-PARAMETER symbol %qs at %L can't be implied-shape"
 msgstr "Nicht-PARAMETER-Symbol %qs bei %L kann nicht implizite Form haben"
 
-#: fortran/decl.c:2377
+#: fortran/decl.c:2386
 #, gcc-internal-format, gfc-internal-format
 msgid "Implied-shape array at %L"
 msgstr "Feld mit impliziter Form bei %L"
 
-#: fortran/decl.c:2422
+#: fortran/decl.c:2431
 #, gcc-internal-format, gfc-internal-format
 msgid "Explicit shaped array with nonconstant bounds at %C"
 msgstr "Feld mit expliziter Form, aber nichtkonstanten Grenzen bei %C"
 
-#: fortran/decl.c:2501
+#: fortran/decl.c:2510
 #, gcc-internal-format
 msgid "%qs at %C is a redefinition of the declaration in the corresponding interface for MODULE PROCEDURE %qs"
 msgstr "%qs bei %C ist eine Redefinition der Deklaration in der entsprechenden Schnittstelle für MODUL PROCEDURE %qs"
 
-#: fortran/decl.c:2512
+#: fortran/decl.c:2521
 #, gcc-internal-format
 msgid "%qs entity cannot have an initializer at %C"
 msgstr "Entität %qs bei %C kann keine Initialisierung haben"
 
-#: fortran/decl.c:2538 fortran/decl.c:8369
+#: fortran/decl.c:2547 fortran/decl.c:8388
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr "Doppelte Feldspezifikation für Cray-Zeigerende bei %C"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/decl.c:2546
+#: fortran/decl.c:2555
 #, gcc-internal-format
 msgid "Couldn't set pointee array spec."
 msgstr "Couldn't set pointee array spec."
 
-#: fortran/decl.c:2609
+#: fortran/decl.c:2618
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style initialization at %C"
 msgstr "Initialisierung im alten Stil bei %C"
 
-#: fortran/decl.c:2617
+#: fortran/decl.c:2626
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr "Ungültige Initialisierung im alten Stil für abgeleitete Typkomponente bei %C"
 
-#: fortran/decl.c:2630
+#: fortran/decl.c:2639
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in old style initialization of %s at %C"
 msgstr "Syntaxfehler in Initialisierung im alten Stil von %s bei %C"
 
-#: fortran/decl.c:2650 fortran/decl.c:6661
+#: fortran/decl.c:2659 fortran/decl.c:6680
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr "Initialisierung bei %C ist nicht für eine Zeigervariable"
 
-#: fortran/decl.c:2663
+#: fortran/decl.c:2672
 #, gcc-internal-format
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr "Zeigerinitialisierung bei %C benötigt %<=>%>, nicht %<=%>"
 
-#: fortran/decl.c:2672 fortran/decl.c:10240
+#: fortran/decl.c:2681 fortran/decl.c:10265
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr "Initialisierungsausdruck bei %C erwartet"
 
-#: fortran/decl.c:2679
+#: fortran/decl.c:2688
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr "Initialisierung einer Variablen bei %C ist in einer PURE-Prozedur nicht erlaubt"
 
-#: fortran/decl.c:2696
+#: fortran/decl.c:2705
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr "Initialisierung einer allozierbaren Komponente bei %C ist nicht erlaubt"
 
-#: fortran/decl.c:2710
+#: fortran/decl.c:2719
 #, gcc-internal-format, gfc-internal-format
 msgid "The component with KIND or LEN attribute at %C does not not appear in the type parameter list at %L"
 msgstr "Die Komponente bei %C mit KIND- oder LEN-Attribut erscheint nicht in der Typparameterliste bei %L"
 
-#: fortran/decl.c:2718
+#: fortran/decl.c:2727
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C that appears in the type parameter list at %L has neither the KIND nor LEN attribute"
 msgstr "Die Komponente bei %C, die in der Typparameterliste bei %L erscheint, hat weder KIND- noch LEN-Attribut"
 
-#: fortran/decl.c:2726
+#: fortran/decl.c:2735
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C which is a type parameter must be a scalar"
 msgstr "Die Komponente bei %C, die ein Typparameter ist, muss ein Skalar sein"
 
-#: fortran/decl.c:2789 fortran/decl.c:2825
+#: fortran/decl.c:2798 fortran/decl.c:2834
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr "Deklaration %s*%d im alten Stil wird bei %C nicht unterstützt"
 
-#: fortran/decl.c:2831
+#: fortran/decl.c:2840
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr "Nicht-Standard Typ-Deklaration %s*%d bei %C"
 
-#: fortran/decl.c:2890 fortran/decl.c:2967
+#: fortran/decl.c:2899 fortran/decl.c:2976
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis at %C"
 msgstr "Fehlende rechte Klammer bei %C"
 
-#: fortran/decl.c:2903 fortran/decl.c:3038
+#: fortran/decl.c:2912 fortran/decl.c:3047
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr "Initialisierungsausdruck bei %C erwartet"
 
-#: fortran/decl.c:2911 fortran/decl.c:3044
+#: fortran/decl.c:2920 fortran/decl.c:3053
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr "Skalaren Initialisierungsausdruck bei %C erwartet"
 
-#: fortran/decl.c:2941 fortran/decl.c:3657
+#: fortran/decl.c:2950 fortran/decl.c:3676
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr "Die Art %d wird für Typ %s bei %C nicht unterstützt"
 
-#: fortran/decl.c:2954
+#: fortran/decl.c:2963
 #, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr "Typ-Parameter nach C-Art ist für Typ %s, aber Typ bei %L ist %s"
 
-#: fortran/decl.c:2965
+#: fortran/decl.c:2974
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr "Fehlende rechte Klammer oder Komma bei %C"
 
-#: fortran/decl.c:3070
+#: fortran/decl.c:3079
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr "Die Art %d wird für CHARACTER bei %C nicht unterstützt"
 
-#: fortran/decl.c:3202
+#: fortran/decl.c:3211
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr "Syntaxfehler in CHARACTER-Deklaration bei %C"
 
-#: fortran/decl.c:3291
+#: fortran/decl.c:3310
 #, gcc-internal-format, gfc-internal-format
 msgid "RECORD at %C is an extension, enable it with -fdec-structure"
 msgstr "RECORD bei %C ist eine Erweiterung, muss mit »-fdec-structure« eingeschaltet werden"
 
-#: fortran/decl.c:3304
+#: fortran/decl.c:3323
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected after RECORD at %C"
 msgstr "Strukturname nach RECORD bei %C erwartet"
 
-#: fortran/decl.c:3417
+#: fortran/decl.c:3436
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C cannot contain both ASSUMED and DEFERRED parameters"
 msgstr "Die Typparameter-Angabenliste bei %C kann nicht gleichzeitig ASSUMED- und DEFERRED-Parameter enthalten"
 
-#: fortran/decl.c:3441
+#: fortran/decl.c:3460
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C does not contain enough parameter expressions"
 msgstr "Die Typparameter-Angabenliste bei %C enthält nicht genug Parameterausdrücke"
 
-#: fortran/decl.c:3465
+#: fortran/decl.c:3484
 #, gcc-internal-format
 msgid "The derived parameter %qs at %C does not have a default value"
 msgstr "Der abgeleitete Parameter %qs bei %C hat keinen Vorgabewert"
 
-#: fortran/decl.c:3497
+#: fortran/decl.c:3516
 #, gcc-internal-format, gfc-internal-format
 msgid "The parameter expression at %C must be of INTEGER type and not %s type"
 msgstr "Der Parameterausdruck bei %C muss vom Typ INTEGER sein, nicht %s"
 
-#: fortran/decl.c:3525
+#: fortran/decl.c:3544
 #, gcc-internal-format
 msgid "The KIND parameter %qs at %C cannot either be ASSUMED or DEFERRED"
 msgstr "Der KIND-Parameter %qs bei %C darf weder ASSUMED noch DEFERRED sein"
 
-#: fortran/decl.c:3532
+#: fortran/decl.c:3551
 #, gcc-internal-format
 msgid "The value for the KIND parameter %qs at %C does not reduce to a constant expression"
 msgstr "Der Wert für den KIND-Parameter %qs bei %C lässt sich nicht auf einen konstanten Ausdruck reduzieren"
 
-#: fortran/decl.c:3547
+#: fortran/decl.c:3566
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C contains too many parameter expressions"
 msgstr "Die Typparameter-Angabenliste bei %C enthält zu viele Parameterausdrücke"
 
-#: fortran/decl.c:3556
+#: fortran/decl.c:3575
 #, gcc-internal-format, gfc-internal-format
 msgid "Parameterized derived type at %C is ambiguous"
 msgstr "Der parametrisierte abgeleitete Typ bei %C ist mehrdeutig"
 
-#: fortran/decl.c:3819
+#: fortran/decl.c:3838
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type at %C"
 msgstr "BYTE-Typ bei %C"
 
-#: fortran/decl.c:3824
+#: fortran/decl.c:3843
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr "Bei %C verwendeter BYTE-Typ ist auf der Zielmaschine nicht verfügbar"
 
-#: fortran/decl.c:3846
+#: fortran/decl.c:3865
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C is not allowed for components"
 msgstr "Vermuteter Typ bei %C ist für Komponenten nicht erlaubt"
 
-#: fortran/decl.c:3849
+#: fortran/decl.c:3868
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr "Vermuteter Typ bei %C"
 
-#: fortran/decl.c:3872 fortran/decl.c:3903 fortran/decl.c:3932
-#: fortran/decl.c:4216
+#: fortran/decl.c:3891 fortran/decl.c:3922 fortran/decl.c:3951
+#: fortran/decl.c:4235
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr "TYPE mit intrinsischer Typspezifikation bei %C"
 
-#: fortran/decl.c:3928
+#: fortran/decl.c:3947
 #, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr "DOUBLE COMPLEX bei %C"
 
-#: fortran/decl.c:3971 fortran/decl.c:4107 fortran/decl.c:4119
-#: fortran/decl.c:4133 fortran/decl.c:4611 fortran/decl.c:4619
+#: fortran/decl.c:3990 fortran/decl.c:4126 fortran/decl.c:4138
+#: fortran/decl.c:4152 fortran/decl.c:4630 fortran/decl.c:4638
 #, gcc-internal-format
 msgid "Type name %qs at %C is ambiguous"
 msgstr "Typname %qs bei %C ist mehrdeutig"
 
-#: fortran/decl.c:4066
+#: fortran/decl.c:4085
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS statement at %C"
 msgstr "CLASS-Anweisung bei %C"
 
-#: fortran/decl.c:4148
+#: fortran/decl.c:4167
 #, gcc-internal-format
 msgid "Type name %qs at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr "Typname %qs bei %C in Konflikt mit vorher deklarierter Entität bei %L, die den gleichen Namen hat"
 
-#: fortran/decl.c:4287
+#: fortran/decl.c:4306
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr "Doppelte IMPLICIT NONE-Anweisung bei %C"
 
-#: fortran/decl.c:4296
+#: fortran/decl.c:4315
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr "IMPORT NONE mit Angabenliste bei %C"
 
-#: fortran/decl.c:4355
+#: fortran/decl.c:4374
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr "Fehlender Zeichenbereich in IMPLICIT bei %C"
 
-#: fortran/decl.c:4401
+#: fortran/decl.c:4420
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr "Buchstaben in IMPLICIT-Anweisung bei %C müssen in alphabetischer Reihenfolge sein"
 
-#: fortran/decl.c:4454
+#: fortran/decl.c:4473
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr "IMPLICIT-Anweisung bei %C folgt auf IMPLICIT NONE (Typ-)Anweisung"
 
-#: fortran/decl.c:4464
+#: fortran/decl.c:4483
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr "Leere IMPLICIT-Anweisung bei %C"
 
-#: fortran/decl.c:4570
+#: fortran/decl.c:4589
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr "IMPORT-Anweisung bei %C ist nur in einem INTERFACE-Körper erlaubt"
 
-#: fortran/decl.c:4577
+#: fortran/decl.c:4596
 #, gcc-internal-format, gfc-internal-format
 msgid "F2008: C1210 IMPORT statement at %C is not permitted in a module procedure interface body"
 msgstr "F2008: C1210 IMPORT-Anweisung bei %C ist im Körper einer Schnittstelle für Modulprozedur nicht erlaubt"
 
-#: fortran/decl.c:4582
+#: fortran/decl.c:4601
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C"
 msgstr "IMPORT-Anweisung bei %C"
 
-#: fortran/decl.c:4596
+#: fortran/decl.c:4615
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr "Liste benannter Einträge bei %C erwartet"
 
-#: fortran/decl.c:4625
+#: fortran/decl.c:4644
 #, gcc-internal-format
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr "IMPORT %qs aus Host-Sichtbarkeitseinheit bei %C nicht möglich - existiert nicht."
 
-#: fortran/decl.c:4632
+#: fortran/decl.c:4651
 #, gcc-internal-format
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr "%qs bereits aus Host-Sichtbarkeitseinheit bei %C IMPORTiert"
 
-#: fortran/decl.c:4673
+#: fortran/decl.c:4692
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IMPORT statement at %C"
 msgstr "Syntaxfehler in IMPORT-Anweisung bei %C"
 
-#: fortran/decl.c:5010
+#: fortran/decl.c:5029
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing codimension specification at %C"
 msgstr "Fehlende Kodimensionsangabe bei %C"
 
-#: fortran/decl.c:5012
+#: fortran/decl.c:5031
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr "Fehlende Dimensionsangabe bei %C"
 
-#: fortran/decl.c:5107
+#: fortran/decl.c:5126
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr "Doppeltes Attribut %s bei %L"
 
-#: fortran/decl.c:5124
+#: fortran/decl.c:5143
 #, gcc-internal-format
 msgid "%s at %L is a DEC extension, enable with %<-fdec-static%>"
 msgstr "%s bei %L ist eine DEC-Erweiterung, muss mit %<-fdec-static%> eingeschaltet werden"
 
-#: fortran/decl.c:5141
+#: fortran/decl.c:5160
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr "Attribut ALLOCATABLE bei %C in einer TYPE-Definition"
 
-#: fortran/decl.c:5150
+#: fortran/decl.c:5169
 #, gcc-internal-format, gfc-internal-format
 msgid "KIND attribute at %C in a TYPE definition"
 msgstr "KIND-Attribut bei %C in einer TYPE-Definition"
 
-#: fortran/decl.c:5158
+#: fortran/decl.c:5177
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be INTEGER"
 msgstr "Komponente mit KIND-Attribut bei %C muss ein INTEGER sein"
 
-#: fortran/decl.c:5165
+#: fortran/decl.c:5184
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be default integer kind (%d)"
 msgstr "Komponente mit KIND-Attribut bei %C muss per Default Ganzzahlart (%d) sein"
 
-#: fortran/decl.c:5174
+#: fortran/decl.c:5193
 #, gcc-internal-format, gfc-internal-format
 msgid "LEN attribute at %C in a TYPE definition"
 msgstr "LEN-Attribut bei %C in einer TYPE-Definition"
 
-#: fortran/decl.c:5182
+#: fortran/decl.c:5201
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be INTEGER"
 msgstr "Komponente mit LEN-Attribut bei %C muss INTEGER sein"
 
-#: fortran/decl.c:5189
+#: fortran/decl.c:5208
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be default integer kind (%d)"
 msgstr "Komponente mit LEN-Attribut bei %C muss per Default Ganzzahlart (%d) sein"
 
-#: fortran/decl.c:5198
+#: fortran/decl.c:5217
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr "Attribut bei %L ist in TYPE-Definition nicht erlaubt"
 
-#: fortran/decl.c:5216
+#: fortran/decl.c:5235
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr "Attribut %s bei %L in einer TYPE-Definition"
 
-#: fortran/decl.c:5226
+#: fortran/decl.c:5245
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr "Attribut %s bei %L ist außerhalb des Spezifikationsabschnitts eines Moduls nicht erlaubt"
 
-#: fortran/decl.c:5236
+#: fortran/decl.c:5255
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed outside a TYPE definition"
 msgstr "Attribut bei %L ist außerhalb einer TYPE-Definition nicht erlaubt"
 
-#: fortran/decl.c:5249
+#: fortran/decl.c:5268
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr "ASYNCHRONOUS-Attribut bei %C"
 
-#: fortran/decl.c:5260
+#: fortran/decl.c:5279
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr "CONTIGUOUS-Attribut bei %C"
 
-#: fortran/decl.c:5315 fortran/decl.c:8673
+#: fortran/decl.c:5334 fortran/decl.c:8692
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr "PROTECTED bei %C nur in Spezifikationsabschnitts eines Moduls erlaubt"
 
-#: fortran/decl.c:5321
+#: fortran/decl.c:5340
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute at %C"
 msgstr "PROTECTED-Attribut bei %C"
 
-#: fortran/decl.c:5355
+#: fortran/decl.c:5374
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE attribute at %C"
 msgstr "VALUE-Attribut bei %C"
 
-#: fortran/decl.c:5362
+#: fortran/decl.c:5381
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
 msgstr "VOLATILE-Attribut bei %C"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/decl.c:5369
+#: fortran/decl.c:5388
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr "match_attr_spec(): Bad attribute"
 
-#: fortran/decl.c:5410
+#: fortran/decl.c:5429
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr "Mehrere Bezeichner mit einzelner Spezifikation NAME= bei %C angegeben"
 
-#: fortran/decl.c:5508
+#: fortran/decl.c:5527
 #, gcc-internal-format
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr "Implizit deklarierte BIND(C)-Funktion %qs bei %L ist möglicherweise nicht interoperabel mit C"
 
-#: fortran/decl.c:5530
+#: fortran/decl.c:5549
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr "Variable %qs in gemeinsamem Block %qs bei %L könnte inkompatibel mit C sein, obwohl gemeinsamer Block %qs BIND(C) ist"
 
-#: fortran/decl.c:5539
+#: fortran/decl.c:5558
 #, gcc-internal-format
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr "Typdeklaration %qs bei %L ist nicht C-kompatibel, aber sie ist BIND(C)"
 
-#: fortran/decl.c:5543
+#: fortran/decl.c:5562
 #, gcc-internal-format
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr "Variable %qs bei %L könnte mit C inkompatibel sein, aber sie ist BIND(C)"
 
-#: fortran/decl.c:5555
+#: fortran/decl.c:5574
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr "Variable %qs in gemeinsamem Block %qs bei %L kann nicht mit BIND(C) deklariert werden, da sie nicht global ist"
 
-#: fortran/decl.c:5569
+#: fortran/decl.c:5588
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr "Variable %qs bei %L kann nicht gleichzeitig die Attribute POINTER und BIND(C) haben"
 
-#: fortran/decl.c:5577
+#: fortran/decl.c:5596
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr "Variable %qs bei %L kann nicht gleichzeitig die Attribute ALLOCATABLE und BIND(C) haben"
 
-#: fortran/decl.c:5589
+#: fortran/decl.c:5608
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr "Rückgabetyp der BIND(C)-Funktion %qs bei %L kann kein Feld sein"
 
-#: fortran/decl.c:5597
+#: fortran/decl.c:5616
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be a character string"
 msgstr "Rückgabetyp der BIND(C)-Funktion %qs bei %L kann keine Zeichenkette sein"
@@ -51908,953 +51975,958 @@
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:5608
+#: fortran/decl.c:5627
 #, gcc-internal-format
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr "Symbol %qs bei %L ist als PRIVATE markiert, aber wurde mit Bindung %qs markiert"
 
-#: fortran/decl.c:5682
+#: fortran/decl.c:5701
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr "Entweder Entität oder Name eines gemeinsamen Blocks für Attribut-Spezifikationsanweisung bei %C erforderlich"
 
-#: fortran/decl.c:5727
+#: fortran/decl.c:5746
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr "Entität oder Name eines gemeinsamen Blocks für Attribut-Spezifikationsanweisung bei %C fehlt"
 
-#: fortran/decl.c:5734
+#: fortran/decl.c:5753
 #, gcc-internal-format
 msgid "Missing symbol"
 msgstr "Fehlendes Symbol"
 
-#: fortran/decl.c:5763
+#: fortran/decl.c:5782
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) statement at %C"
 msgstr "BIND(C)-Anweisung bei %C"
 
-#: fortran/decl.c:5850
+#: fortran/decl.c:5869
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr "Abgeleiteter Typ bei %C wurde vorher nicht definiert und kann daher nicht in einer abgeleiteten Typdefinition auftreten"
 
-#: fortran/decl.c:5892
+#: fortran/decl.c:5911
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in anonymous structure declaration at %C"
 msgstr "Syntaxfehler in anonymer Struktur-Deklaration bei %C"
 
-#: fortran/decl.c:5901
+#: fortran/decl.c:5920
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr "Syntaxfehler in Daten-Deklaration bei %C"
 
-#: fortran/decl.c:5951
+#: fortran/decl.c:5970
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C"
 msgstr "MODULE-Präfix bei %C"
 
-#: fortran/decl.c:5996
+#: fortran/decl.c:6015
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPURE procedure at %C"
 msgstr "IMPURE-Prozedur bei %C"
 
-#: fortran/decl.c:6008
+#: fortran/decl.c:6027
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr "PURE und IMPURE dürfen bei %C nicht gleichzeitig stehen"
 
-#: fortran/decl.c:6054
+#: fortran/decl.c:6073
 #, gcc-internal-format, gfc-internal-format
 msgid "ELEMENTAL prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr "ELEMENTAL-Präfix fehlt in MODULE-PROCEDURE-Schnittstelle bei %L"
 
-#: fortran/decl.c:6061
+#: fortran/decl.c:6080
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr "PURE-Präfix fehlt in MODULE-PROCEDURE-Schnittstelle bei %L"
 
-#: fortran/decl.c:6068
+#: fortran/decl.c:6087
 #, gcc-internal-format, gfc-internal-format
 msgid "RECURSIVE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr "RECURSIVE-Präfix fehlt in MODULE-PROCEDURE-Schnittstelle bei %L"
 
-#: fortran/decl.c:6134 fortran/primary.c:1820
+#: fortran/decl.c:6153 fortran/primary.c:1820
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate-return argument at %C"
 msgstr "Argument für Alternativrückgabe bei %C"
 
-#: fortran/decl.c:6140 fortran/decl.c:6148
+#: fortran/decl.c:6159 fortran/decl.c:6167
 #, gcc-internal-format, gfc-internal-format
 msgid "A parameter name is required at %C"
 msgstr "Bei %C wird ein Parametername erwartet"
 
-#: fortran/decl.c:6188
+#: fortran/decl.c:6207
 #, gcc-internal-format
 msgid "Name %qs at %C is the name of the procedure"
 msgstr "Name %qs bei %C ist der Name der Prozedur"
 
-#: fortran/decl.c:6201
+#: fortran/decl.c:6220
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected parameter list in type declaration at %C"
 msgstr "Parameterliste in Typdeklaration bei %C erwartet"
 
-#: fortran/decl.c:6204
+#: fortran/decl.c:6223
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr "Unerwartete Angaben in formaler Argumentliste bei %C"
 
-#: fortran/decl.c:6222
+#: fortran/decl.c:6241
 #, gcc-internal-format
 msgid "Duplicate name %qs in parameter list at %C"
 msgstr "Doppelter Name %qs in Parameterliste bei %C"
 
-#: fortran/decl.c:6225
+#: fortran/decl.c:6244
 #, gcc-internal-format
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr "Doppeltes Symbol %qs in formaler Argumentliste bei %C"
 
-#: fortran/decl.c:6264
+#: fortran/decl.c:6283
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in MODULE PROCEDURE formal argument names (%s/%s) at %C"
 msgstr "Konflikt in formalen Argumentnamen (%s/%s) von MODULE PROCEDURE bei %C"
 
-#: fortran/decl.c:6270
+#: fortran/decl.c:6289
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in number of MODULE PROCEDURE formal arguments at %C"
 msgstr "Konflikt in Anzahl der formalen Argumente von MODULE PROCEDURE bei %C"
 
-#: fortran/decl.c:6309
+#: fortran/decl.c:6328
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr "RESULT-Variable bei %C muss vom Funktionsnamen verschieden sein"
 
-#: fortran/decl.c:6386
+#: fortran/decl.c:6405
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr "Unerwartete Angaben hinter Funktionsdeklaration bei %C"
 
-#: fortran/decl.c:6396 fortran/decl.c:7494
+#: fortran/decl.c:6415 fortran/decl.c:7513
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr "BIND(C)-Attribut bei %L kann nicht für eine interne Prozedur angegeben werden"
 
-#: fortran/decl.c:6600
+#: fortran/decl.c:6619
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr "BIND(C)-Attribut bei %C erfordert eine Schnittstelle mit BIND(C)"
 
-#: fortran/decl.c:6607
+#: fortran/decl.c:6626
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr "BIND(C)-Prozedur mit NAME darf kein POINTER-Attribut bei %C haben"
 
-#: fortran/decl.c:6613
+#: fortran/decl.c:6632
 #, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr "Scheinprozedur bei %C kann kein BIND(C)-Attribut mit NAME haben"
 
-#: fortran/decl.c:6636
+#: fortran/decl.c:6655
 #, gcc-internal-format
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr "Prozedur %qs bei %L hat bereits grundlegenden Typen %s"
 
-#: fortran/decl.c:6682 fortran/decl.c:6870 fortran/decl.c:10723
+#: fortran/decl.c:6701 fortran/decl.c:6889 fortran/decl.c:10748
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr "Syntaxfehler in PROCEDURE-Anweisung bei %C"
 
-#: fortran/decl.c:6731 fortran/decl.c:10623
+#: fortran/decl.c:6750 fortran/decl.c:10648
 #, gcc-internal-format
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr "%<::%> nach Bindeattributen bei %C erwartet"
 
-#: fortran/decl.c:6738
+#: fortran/decl.c:6757
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr "NOPASS oder explizite Schnittstelle bei %C erforderlich"
 
-#: fortran/decl.c:6742
+#: fortran/decl.c:6761
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component at %C"
 msgstr "Prozedurzeiger-Komponente bei %C"
 
-#: fortran/decl.c:6814
+#: fortran/decl.c:6833
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in procedure pointer component at %C"
 msgstr "Syntaxfehler in Prozedurzeiger-Komponente bei %C"
 
-#: fortran/decl.c:6832
+#: fortran/decl.c:6851
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr "PROCEDURE bei %C muss in einer allgemeinen Schnittstelle sein"
 
-#: fortran/decl.c:6841 fortran/decl.c:9392
+#: fortran/decl.c:6860 fortran/decl.c:9411
 #, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr "»::« in MODULE PROCEDURE-Anweisung bei %L"
 
-#: fortran/decl.c:6911
+#: fortran/decl.c:6930
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE statement at %C"
 msgstr "PROCEDURE-Anweisung bei %C"
 
-#: fortran/decl.c:6983
+#: fortran/decl.c:7002
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr "Formale Argumentliste in Funktionsdefinition bei %C erwartet"
 
-#: fortran/decl.c:7007 fortran/decl.c:7011 fortran/decl.c:7266
-#: fortran/decl.c:7270 fortran/decl.c:7462 fortran/decl.c:7466
-#: fortran/symbol.c:1875
+#: fortran/decl.c:7026 fortran/decl.c:7030 fortran/decl.c:7285
+#: fortran/decl.c:7289 fortran/decl.c:7481 fortran/decl.c:7485
+#: fortran/symbol.c:1889
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr "BIND(C)-Attribut bei %L kann nur für Variablen oder gemeinsame Blöcke verwendet werden"
 
-#: fortran/decl.c:7164
+#: fortran/decl.c:7183
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C"
 msgstr "ENTRY-Anweisung bei %C"
 
-#: fortran/decl.c:7173
+#: fortran/decl.c:7192
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr "ENTRY-Anweisung bei %C kann nicht innerhalb eines PROGRAMmes auftreten"
 
-#: fortran/decl.c:7176
+#: fortran/decl.c:7195
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr "ENTRY-Anweisung bei %C kann nicht innerhalb eines MODULEs auftreten"
 
-#: fortran/decl.c:7179
+#: fortran/decl.c:7198
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SUBMODULE"
 msgstr "ENTRY-Anweisung bei %C kann nicht innerhalb eines SUBMODULEs auftreten"
 
-#: fortran/decl.c:7182
+#: fortran/decl.c:7201
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr "ENTRY-Anweisung bei %C kann nicht innerhalb von BLOCK DATA auftreten"
 
-#: fortran/decl.c:7186 fortran/decl.c:7231
+#: fortran/decl.c:7205 fortran/decl.c:7250
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr "ENTRY-Anweisung bei %C kann nicht innerhalb von INTERFACE auftreten"
 
-#: fortran/decl.c:7190
+#: fortran/decl.c:7209
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a STRUCTURE block"
 msgstr "ENTRY-Anweisung bei %C kann nicht innerhalb eines STRUCTURE-Blockes auftreten"
 
-#: fortran/decl.c:7194
+#: fortran/decl.c:7213
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr "ENTRY-Anweisung bei %C kann nicht innerhalb eines DERIVED TYPE Blockes auftreten"
 
-#: fortran/decl.c:7198
+#: fortran/decl.c:7217
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr "ENTRY-Anweisung bei %C kann nicht innerhalb eines IF-THEN-Blockes auftreten"
 
-#: fortran/decl.c:7203
+#: fortran/decl.c:7222
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr "ENTRY-Anweisung bei %C kann nicht innerhalb eines DO-Blockes auftreten"
 
-#: fortran/decl.c:7207
+#: fortran/decl.c:7226
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr "ENTRY-Anweisung bei %C kann nicht innerhalb eines SELECT-Blockes auftreten"
 
-#: fortran/decl.c:7211
+#: fortran/decl.c:7230
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr "ENTRY-Anweisung bei %C kann nicht innerhalb eines FORALL-Blockes auftreten"
 
-#: fortran/decl.c:7215
+#: fortran/decl.c:7234
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr "ENTRY-Anweisung bei %C kann nicht innerhalb eines WHERE-Blockes auftreten"
 
-#: fortran/decl.c:7219
+#: fortran/decl.c:7238
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr "ENTRY-Anweisung bei %C kann nicht innerhalb eines enthaltenen Subprogrammes auftreten"
 
-#: fortran/decl.c:7223
+#: fortran/decl.c:7242
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected ENTRY statement at %C"
 msgstr "Unerwartete ENTRY-Anweisung bei %C"
 
-#: fortran/decl.c:7244
+#: fortran/decl.c:7263
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr "ENTRY-Anweisung bei %C kann nicht in einer enthaltenen Prozedur auftreten"
 
-#: fortran/decl.c:7295 fortran/decl.c:7501
+#: fortran/decl.c:7314 fortran/decl.c:7520
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr "Erforderte Klammern vor BIND(C) bei %C fehlen"
 
-#: fortran/decl.c:7563 fortran/decl.c:7570
+#: fortran/decl.c:7582 fortran/decl.c:7589
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr "Ungültiger C-Name in NAME=-Spezifizierung bei %C"
 
-#: fortran/decl.c:7610
+#: fortran/decl.c:7629
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr "Syntaxfehler in NAME=-Spezifikation für Bindungsmarke bei %C"
 
-#: fortran/decl.c:7626
+#: fortran/decl.c:7645
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr "Spezifikation NAME= bei %C sollte ein konstanter Ausdruck sein"
 
-#: fortran/decl.c:7634
+#: fortran/decl.c:7653
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr "NAME=-Angabe bei %C sollte ein Skalar der Standardzeichenart sein"
 
-#: fortran/decl.c:7653
+#: fortran/decl.c:7672
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing closing paren for binding label at %C"
 msgstr "Schließende Klammer für Bindungsmarke bei %C fehlt"
 
-#: fortran/decl.c:7659
+#: fortran/decl.c:7678
 #, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr "In BIND(C) bei %C ist kein bindender Name erlaubt"
 
-#: fortran/decl.c:7665
+#: fortran/decl.c:7684
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr "For Schein-Prozedur %s in BIND(C) bei %C ist kein bindender Name erlaubt"
 
-#: fortran/decl.c:7694
+#: fortran/decl.c:7713
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr "NAME nicht erlaubt bei BIND(C) für ABSTRACT INTERFACE bei %C"
 
-#: fortran/decl.c:7939
+#: fortran/decl.c:7958
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr "Unerwartete END-Anweisung bei %C"
 
-#: fortran/decl.c:7948
+#: fortran/decl.c:7967
 #, gcc-internal-format, gfc-internal-format
 msgid "END statement instead of %s statement at %L"
 msgstr "END-Anweisung statt %s-Anweisung bei %L"
 
 #. We would have required END [something].
-#: fortran/decl.c:7957
+#: fortran/decl.c:7976
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr "%s-Anweisung bei %L erwartet"
 
-#: fortran/decl.c:7968
+#: fortran/decl.c:7987
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s statement at %L"
 msgstr "»%s«-Anweisung bei %L erwartet"
 
-#: fortran/decl.c:7988
+#: fortran/decl.c:8007
 #, gcc-internal-format
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr "Blocknamen von %qs in »%s«-Anweisung bei %L erwartet"
 
-#: fortran/decl.c:8005
+#: fortran/decl.c:8024
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr "Beendenden Namen bei %C erwartet"
 
-#: fortran/decl.c:8019 fortran/decl.c:8027
+#: fortran/decl.c:8038 fortran/decl.c:8046
 #, gcc-internal-format
 msgid "Expected label %qs for %s statement at %C"
 msgstr "Marke %qs für »%s«-Anweisung bei %C erwartet"
 
-#: fortran/decl.c:8126
+#: fortran/decl.c:8145
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr "Fehlende Feldspezifikation bei %L in DIMENSION-Anweisung"
 
-#: fortran/decl.c:8134
+#: fortran/decl.c:8153
 #, gcc-internal-format, gfc-internal-format
 msgid "Dimensions specified for %s at %L after its initialization"
 msgstr "Für %s bei %L wurden Dimensionen nach dessen Initialisierung angegeben"
 
-#: fortran/decl.c:8142
+#: fortran/decl.c:8161
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr "Feldspezifikation bei %L in CODIMENSION-Anweisung fehlt"
 
-#: fortran/decl.c:8151
+#: fortran/decl.c:8170
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr "Feldspezifikation muss bei %L aufgeschoben werden"
 
-#: fortran/decl.c:8249
+#: fortran/decl.c:8268
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr "Unerwartetes Zeichen in Variablenliste bei %C"
 
-#: fortran/decl.c:8286
+#: fortran/decl.c:8305
 #, gcc-internal-format
 msgid "Expected %<(%> at %C"
 msgstr "%<(%> bei %C erwartet"
 
-#: fortran/decl.c:8300 fortran/decl.c:8340
+#: fortran/decl.c:8319 fortran/decl.c:8359
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr "Variablennamen bei %C erwartet"
 
-#: fortran/decl.c:8316
+#: fortran/decl.c:8335
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C must be an integer"
 msgstr "Cray-Zeiger bei %C muss eine Ganzzahl sein"
 
-#: fortran/decl.c:8320
+#: fortran/decl.c:8339
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr "Cray-Zeiger bei %C hat %d Bytes Genauigkeit; Speicheradressen benötigen %d Bytes"
 
-#: fortran/decl.c:8326
+#: fortran/decl.c:8345
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr "»,« bei %C erwartet"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/decl.c:8365
+#: fortran/decl.c:8384
 #, gcc-internal-format
 msgid "Couldn't set Cray pointee array spec."
 msgstr "Couldn't set Cray pointee array spec."
 
-#: fortran/decl.c:8389
+#: fortran/decl.c:8408
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr "»)« bei %C erwartet"
 
-#: fortran/decl.c:8401
+#: fortran/decl.c:8420
 #, gcc-internal-format
 msgid "Expected %<,%> or end of statement at %C"
 msgstr "%<,%> oder Ende der Anweisung bei %C erwartet"
 
-#: fortran/decl.c:8427
+#: fortran/decl.c:8446
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr "INTENT ist in BLOCK bei %C nicht erlaubt"
 
-#: fortran/decl.c:8459
+#: fortran/decl.c:8478
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr "OPTIONAL ist in BLOCK bei %C nicht erlaubt"
 
-#: fortran/decl.c:8478
+#: fortran/decl.c:8497
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer declaration at %C requires -fcray-pointer flag"
 msgstr "Cray-Zeiger-Deklaration bei %C benötigt den Schalter -fcray-pointer"
 
-#: fortran/decl.c:8517
+#: fortran/decl.c:8536
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS statement at %C"
 msgstr "CONTIGUOUS-Anweisung bei %C"
 
-#: fortran/decl.c:8623
+#: fortran/decl.c:8642
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr "Zugriffsspezifikation des Operators %s bei %C wurde bereits spezifiziert"
 
-#: fortran/decl.c:8640
+#: fortran/decl.c:8659
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr "Zugriffsspezifikation des Operators .%s. bei %C wurde bereits spezifiziert"
 
-#: fortran/decl.c:8679
+#: fortran/decl.c:8698
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED statement at %C"
 msgstr "PROTECTED-Anweisung bei %C"
 
-#: fortran/decl.c:8717
+#: fortran/decl.c:8736
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr "Syntaxfehler in PROTECTED-Anweisung bei %C"
 
-#: fortran/decl.c:8741
+#: fortran/decl.c:8760
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr "PRIVATE-Anweisung bei %C ist nur in Spezifikationsteil eines Moduls erlaubt"
 
-#: fortran/decl.c:8778
+#: fortran/decl.c:8797
 #, gcc-internal-format, gfc-internal-format
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr "PUBLIC-Anweisung bei %C ist nur in Spezifikationsteil eines Moduls erlaubt"
 
-#: fortran/decl.c:8806
+#: fortran/decl.c:8825
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr "Variablennamen bei %C in PARAMETER-Anweisung erwartet"
 
-#: fortran/decl.c:8813
+#: fortran/decl.c:8832
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr "Zeichen »=« in PARAMETER-Anweisung bei %C erwartet"
 
-#: fortran/decl.c:8819
+#: fortran/decl.c:8838
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr "Ausdruck bei %C in PARAMETER-Anweisung erwartet"
 
-#: fortran/decl.c:8839
+#: fortran/decl.c:8858
 #, gcc-internal-format, gfc-internal-format
 msgid "Initializing already initialized variable at %C"
 msgstr "Initialisierung einer bereits initialisierten Variablen bei %C"
 
 #. With legacy PARAMETER statements, don't expect a terminating ')'.
-#: fortran/decl.c:8864
+#: fortran/decl.c:8883
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER without '()' at %C"
 msgstr "PARAMETER ohne »()« bei %C"
 
-#: fortran/decl.c:8880
+#: fortran/decl.c:8899
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr "Unerwartete Zeichen in PARAMETER-Anweisung bei %C"
 
-#: fortran/decl.c:8899 fortran/decl.c:8955
+#: fortran/decl.c:8918 fortran/decl.c:8974
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-static%>"
 msgstr "%s bei %C ist eine DEC-Erweiterung, muss mit »-fdec-static« eingeschaltet werden"
 
-#: fortran/decl.c:8934
+#: fortran/decl.c:8953
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in AUTOMATIC statement at %C"
 msgstr "In AUTOMATIC-Anweisung bei %C wird eine »entity-list« erwartet"
 
-#: fortran/decl.c:8941
+#: fortran/decl.c:8960
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in AUTOMATIC statement at %C"
 msgstr "Syntaxfehler in AUTOMATIC-Anweisung bei %C"
 
-#: fortran/decl.c:8990
+#: fortran/decl.c:9009
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in STATIC statement at %C"
 msgstr "»entity-list« in STATIC-Anweisung bei %C erwartet"
 
-#: fortran/decl.c:8997
+#: fortran/decl.c:9016
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in STATIC statement at %C"
 msgstr "Syntaxfehler in STATIC-Anweisung bei %C"
 
-#: fortran/decl.c:9016
+#: fortran/decl.c:9035
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr "Umfassende SAVE-Anweisung bei %C folgt vorheriger SAVE-Anweisung"
 
-#: fortran/decl.c:9027
+#: fortran/decl.c:9046
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr "SAVE-Anweisung bei %C folgt umfassender SAVE-Anweisung"
 
-#: fortran/decl.c:9073
+#: fortran/decl.c:9092
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr "Syntaxfehler in SAVE-Anweisung bei %C"
 
-#: fortran/decl.c:9087
+#: fortran/decl.c:9106
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr "VALUE ist in BLOCK bei %C nicht erlaubt"
 
-#: fortran/decl.c:9091
+#: fortran/decl.c:9110
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE statement at %C"
 msgstr "VALUE-Anweisung bei %C"
 
-#: fortran/decl.c:9129
+#: fortran/decl.c:9148
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VALUE statement at %C"
 msgstr "Syntaxfehler in VALUE-Anweisung bei %C"
 
-#: fortran/decl.c:9141
+#: fortran/decl.c:9160
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE statement at %C"
 msgstr "VOLATILE-Anweisung bei %C"
 
-#: fortran/decl.c:9168
+#: fortran/decl.c:9187
 #, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr "VOLATILE für Coarray-Variable %qs bei %C angegeben, die use-/host-assoziiert ist"
 
-#: fortran/decl.c:9193
+#: fortran/decl.c:9212
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr "Syntaxfehler in VOLATILE-Anweisung bei %C"
 
-#: fortran/decl.c:9205
+#: fortran/decl.c:9224
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS statement at %C"
 msgstr "ASYNCHRONOUS-Anweisung bei %C"
 
-#: fortran/decl.c:9249
+#: fortran/decl.c:9268
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr "Syntaxfehler in ASYNCHRONOUS-Anweisung bei %C"
 
-#: fortran/decl.c:9274
+#: fortran/decl.c:9293
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE declaration at %C"
 msgstr "MODULE-PROCEDURE-Deklaration bei %C"
 
-#: fortran/decl.c:9367
+#: fortran/decl.c:9386
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr "MODULE PROCEDURE bei %C muss in einer generischen Modulschnittstelle sein"
 
-#: fortran/decl.c:9425
+#: fortran/decl.c:9444
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr "Intrinsische Prozedur bei %L kann keine MODULE PROCEDURE sein"
 
-#: fortran/decl.c:9474
+#: fortran/decl.c:9493
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr "Mehrdeutiges Symbol in TYPE-Definition bei %C"
 
-#: fortran/decl.c:9483
+#: fortran/decl.c:9502
 #, gcc-internal-format
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr "Symbol %qs bei %C wurde vorher noch nicht definiert"
 
-#: fortran/decl.c:9489
+#: fortran/decl.c:9508
 #, gcc-internal-format
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr "%qs in EXTENDS-Ausdruck bei %C ist kein abgeleiteter Typ"
 
-#: fortran/decl.c:9496
+#: fortran/decl.c:9515
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr "%qs kann bei %C nicht erweitert werden, da es BIND(C) ist"
 
-#: fortran/decl.c:9503
+#: fortran/decl.c:9522
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr "%qs kann bei %C nicht erweitert werden, da es ein SEQUENCE-Typ ist"
 
-#: fortran/decl.c:9526
+#: fortran/decl.c:9545
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr "Abgeleiteter Typ bei %C kann nur PRIVATE im Spezifikationsteil eines Moduls sein"
 
-#: fortran/decl.c:9538
+#: fortran/decl.c:9557
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr "Abgeleiteter Typ bei %C kann nur PUBLIC im Spezifikationsteil eines Moduls sein"
 
-#: fortran/decl.c:9559
+#: fortran/decl.c:9578
 #, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
 msgstr "ABSTRACT-Typ bei %C"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/decl.c:9605
+#: fortran/decl.c:9624
 #, gcc-internal-format, gfc-internal-format
 msgid "Failed to create structure type '%s' at %C"
 msgstr "Failed to create structure type '%s' at %C"
 
-#: fortran/decl.c:9611
+#: fortran/decl.c:9630
 #, gcc-internal-format
 msgid "Type definition of %qs at %C was already defined at %L"
 msgstr "Typdefinition von %qs bei %C wurde bereits bei %L definiert"
 
-#: fortran/decl.c:9658
+#: fortran/decl.c:9677
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after MAP statement at %C"
 msgstr "Ausschuss hinter MAP-Anweisung bei %C"
 
-#: fortran/decl.c:9691
+#: fortran/decl.c:9710
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after UNION statement at %C"
 msgstr "Ausschuss hinter UNION-Anweisung bei %C"
 
-#: fortran/decl.c:9726
+#: fortran/decl.c:9745
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr "%s bei %C ist eine DEC-Erweiterung, muss mit »-fdec-structure« eingeschaltet werden"
 
-#: fortran/decl.c:9740
+#: fortran/decl.c:9759
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected in non-nested structure declaration at %C"
 msgstr "Strukturname erwartet in unverschachtelter Strukturdeklaration bei %C"
 
-#: fortran/decl.c:9758
+#: fortran/decl.c:9777
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after non-nested STRUCTURE statement at %C"
 msgstr "Ausschuss hinter unverschachtelter STRUCTURE-Anweisung bei %C"
 
-#: fortran/decl.c:9765
+#: fortran/decl.c:9784
 #, gcc-internal-format
 msgid "Structure name %qs at %C cannot be the same as an intrinsic type"
 msgstr "Strukturname %qs bei %C kann nicht der gleiche wie ein intrinsischer Typ sein"
 
-#: fortran/decl.c:9926
+#: fortran/decl.c:9947
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr "»::« in TYPE-Definition bei %C erwartet"
 
-#: fortran/decl.c:9954
+#: fortran/decl.c:9975
 #, gcc-internal-format
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr "Typname %qs bei %C kann nicht der gleiche wie ein intrinsischer Typ sein"
 
-#: fortran/decl.c:9964
+#: fortran/decl.c:9986
 #, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr "Abgeleiteter Typname %qs bei %C hat bereits einen Basistypen von %s"
 
-#: fortran/decl.c:9981
+#: fortran/decl.c:9989
 #, gcc-internal-format
+msgid "Derived type name %qs at %C already has a basic type"
+msgstr "Abgeleiteter Typname %qs bei %C hat bereits einen Basistyp"
+
+#: fortran/decl.c:10006
+#, gcc-internal-format
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr "Abgeleitete Typdefinition von %qs bei %C wurde bereits definiert"
 
-#: fortran/decl.c:10042
+#: fortran/decl.c:10067
 #, gcc-internal-format, gfc-internal-format
 msgid "Garbage after PARAMETERIZED TYPE declaration at %C"
 msgstr "Syntaxfehler hinter PARAMETERIZED-TYPE-Deklaration bei %C"
 
-#: fortran/decl.c:10126
+#: fortran/decl.c:10151
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr "Cray-Zeigerende bei %C kann nicht Feld mit impliziter Form sein"
 
-#: fortran/decl.c:10146
+#: fortran/decl.c:10171
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM and ENUMERATOR at %C"
 msgstr "ENUM und ENUMERATOR bei %C"
 
-#: fortran/decl.c:10178
+#: fortran/decl.c:10203
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr "Zähler übersteigt den C-Ganzzahltyp bei %C"
 
-#: fortran/decl.c:10257
+#: fortran/decl.c:10282
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr "ENUMERATOR %L nicht mit Ganzzahlausdruck initialisiert"
 
-#: fortran/decl.c:10305
+#: fortran/decl.c:10330
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr "Anweisung zur ENUM-Definition vor %C erwartet"
 
-#: fortran/decl.c:10341
+#: fortran/decl.c:10366
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr "Syntaxfehler in ENUMERATOR-Definition bei %C"
 
-#: fortran/decl.c:10388 fortran/decl.c:10403
+#: fortran/decl.c:10413 fortran/decl.c:10428
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate access-specifier at %C"
 msgstr "Doppelte Zugriffsspezifikation bei %C"
 
-#: fortran/decl.c:10423
+#: fortran/decl.c:10448
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr "Bindeattribute legen bereits Durchleitung fest, unzulässiges NOPASS bei %C"
 
-#: fortran/decl.c:10443
+#: fortran/decl.c:10468
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr "Bindeattribute legen bereits Durchleitung fest, unzulässiges PASS bei %C"
 
-#: fortran/decl.c:10470
+#: fortran/decl.c:10495
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate POINTER attribute at %C"
 msgstr "Doppeltes POINTER-Attribut bei %C"
 
-#: fortran/decl.c:10488
+#: fortran/decl.c:10513
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr "Doppeltes NON_OVERRIDABLE bei %C"
 
-#: fortran/decl.c:10504
+#: fortran/decl.c:10529
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DEFERRED at %C"
 msgstr "Doppeltes DEFERRED bei %C"
 
-#: fortran/decl.c:10517
+#: fortran/decl.c:10542
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected access-specifier at %C"
 msgstr "Zugriffsspezifikation bei %C erwartet"
 
-#: fortran/decl.c:10519
+#: fortran/decl.c:10544
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr "Bindeattribut bei %C erwartet"
 
-#: fortran/decl.c:10527
+#: fortran/decl.c:10552
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED can't both appear at %C"
 msgstr "NON_OVERRIDABLE und DEFERRED können nicht gleichzeitig bei %C auftreten"
 
-#: fortran/decl.c:10539
+#: fortran/decl.c:10564
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr "POINTER-Attribut ist für Prozedurzeiger-Komponente bei %C erforderlich"
 
-#: fortran/decl.c:10581
+#: fortran/decl.c:10606
 #, gcc-internal-format
 msgid "Interface-name expected after %<(%> at %C"
 msgstr "Schnittstellenname nach %<(%> bei %C erforderlich"
 
-#: fortran/decl.c:10587
+#: fortran/decl.c:10612
 #, gcc-internal-format
 msgid "%<)%> expected at %C"
 msgstr "%<)%> bei %C erwartet"
 
-#: fortran/decl.c:10607
+#: fortran/decl.c:10632
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr "Schnittstelle muss für DEFERRED-Bindung bei %C angegeben werden"
 
-#: fortran/decl.c:10612
+#: fortran/decl.c:10637
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr "PROCEDURE(Schnittstelle) bei %C sollte als DEFERRED deklariert sein"
 
-#: fortran/decl.c:10635
+#: fortran/decl.c:10660
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr "Bindungsname bei %C erwartet"
 
-#: fortran/decl.c:10639
+#: fortran/decl.c:10664
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
 msgstr "PROCEDURE-Liste bei %C"
 
-#: fortran/decl.c:10651
+#: fortran/decl.c:10676
 #, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr "%<=> target%> ist ungültig für DEFERRED-Bindung bei %C"
 
-#: fortran/decl.c:10657
+#: fortran/decl.c:10682
 #, gcc-internal-format
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr "%<::%> in PROCEDURE-Bindung mit explizitem Ziel bei %C erforderlich"
 
-#: fortran/decl.c:10667
+#: fortran/decl.c:10692
 #, gcc-internal-format
 msgid "Expected binding target after %<=>%> at %C"
 msgstr "Bindungsziel hinter %<=>%> bei %C erforderlich"
 
-#: fortran/decl.c:10684
+#: fortran/decl.c:10709
 #, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr "Typ %qs mit DEFERRED-Bindung bei %C ist nicht ABSTRACT"
 
-#: fortran/decl.c:10695
+#: fortran/decl.c:10720
 #, gcc-internal-format
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr "Es gibt bereits eine Prozedur mit Bindungsname %qs für den abgeleiteten Typ %qs bei %C"
 
-#: fortran/decl.c:10746
+#: fortran/decl.c:10771
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr "GENERIC bei %C muss innerhalb eines CONTAINS eines abgeleiteten Typs sein"
 
-#: fortran/decl.c:10766
+#: fortran/decl.c:10791
 #, gcc-internal-format
 msgid "Expected %<::%> at %C"
 msgstr "%<::%> bei %C erwartet"
 
-#: fortran/decl.c:10778
+#: fortran/decl.c:10803
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected generic name or operator descriptor at %C"
 msgstr "Generischer Name oder Operatordeskriptor bei %C erwartet"
 
-#: fortran/decl.c:10799
+#: fortran/decl.c:10824
 #, gcc-internal-format, gfc-internal-format
 msgid "Malformed GENERIC statement at %C"
 msgstr "Kaputte GENERIC-Anweisung bei %C"
 
-#: fortran/decl.c:10810
+#: fortran/decl.c:10835
 #, gcc-internal-format
 msgid "Expected %<=>%> at %C"
 msgstr "%<=>%> bei %C erwartet"
 
-#: fortran/decl.c:10846
+#: fortran/decl.c:10871
 #, gcc-internal-format
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr "Es gibt bereits eine nicht-generische Prozedur mit Bindungsname %qs für den abgeleiteten Typ %qs bei %C"
 
-#: fortran/decl.c:10854
+#: fortran/decl.c:10879
 #, gcc-internal-format
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr "Bindung bei %C muss denselben Zugriff wie bereits definierte Bindung %qs haben"
 
-#: fortran/decl.c:10902
+#: fortran/decl.c:10927
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr "Spezifischer Bindungsname bei %C erwartet"
 
-#: fortran/decl.c:10912
+#: fortran/decl.c:10937
 #, gcc-internal-format
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr "%qs bereits als spezifische Bindung für das generische %qs bei %C definiert"
 
-#: fortran/decl.c:10930
+#: fortran/decl.c:10955
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr "Ausschuss hinter GENERIC-Bindung bei %C"
 
-#: fortran/decl.c:10965
+#: fortran/decl.c:10990
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr "FINAL-Deklaration bei %C muss innerhalb eines CONTAINS-Abschnitts eines abgeleiteten Typs stehen"
 
-#: fortran/decl.c:10976
+#: fortran/decl.c:11001
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr "Deklaration abgeleiteten Typs mit FINAL bei %C muss im Spezifikationsteil eines Moduls sein"
 
-#: fortran/decl.c:10998
+#: fortran/decl.c:11023
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr "Leeres FINAL bei %C"
 
-#: fortran/decl.c:11005
+#: fortran/decl.c:11030
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr "Prozedurname im Modul bei %C erwartet"
 
-#: fortran/decl.c:11015
+#: fortran/decl.c:11040
 #, gcc-internal-format
 msgid "Expected %<,%> at %C"
 msgstr "%<,%> bei %C erwartet"
 
-#: fortran/decl.c:11021
+#: fortran/decl.c:11046
 #, gcc-internal-format
 msgid "Unknown procedure name %qs at %C"
 msgstr "Unbekannter Prozedurname %qs bei %C"
 
-#: fortran/decl.c:11034
+#: fortran/decl.c:11059
 #, gcc-internal-format
 msgid "%qs at %C is already defined as FINAL procedure"
 msgstr "%qs bei %C ist bereits als FINAL-Prozedur definiert"
 
-#: fortran/decl.c:11104
+#: fortran/decl.c:11129
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr "Unbekanntes Attribut in !GCC$ ATTRIBUTES-Anweisung bei %C"
 
-#: fortran/decl.c:11150
+#: fortran/decl.c:11175
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr "Syntaxfehler in !GCC$ ATTRIBUTES-Anweisung bei %C"
 
-#: fortran/decl.c:11170
+#: fortran/decl.c:11195
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive requires a non-negative integral constant less than or equal to %u at %C"
 msgstr "Direktive %<GCC unroll%> bei %2$C verlangt eine konstante Anzahl (maximal %1$u)"
 
-#: fortran/decl.c:11184
+#: fortran/decl.c:11209
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ UNROLL directive at %C"
 msgstr "Syntaxfehler in !GCC$-UNROLL-Direktive bei %C"
@@ -53203,27 +53275,27 @@
 msgid "BOZ literal at %L used to initialize non-integer variable %qs"
 msgstr "BOZ-Literal bei %L verwendet, um Nicht-Ganzzahlvariable %qs zu initialisieren"
 
-#: fortran/expr.c:3369 fortran/resolve.c:10197
+#: fortran/expr.c:3369 fortran/resolve.c:10210
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal at %L outside a DATA statement and outside INT/REAL/DBLE/CMPLX"
 msgstr "BOZ-Literal bei %L außerhalb einer DATA-Anweisung und außerhalb von INT/REAL/DBLE/CMPLX"
 
-#: fortran/expr.c:3380 fortran/resolve.c:10208
+#: fortran/expr.c:3380 fortran/resolve.c:10221
 #, gcc-internal-format
 msgid "BOZ literal at %L is bitwise transferred non-integer symbol %qs"
 msgstr "BOZ-Literal bei %L ist bitweise übertragenes Nicht-Ganzzahlsymbol %qs"
 
-#: fortran/expr.c:3388 fortran/resolve.c:10217
+#: fortran/expr.c:3388 fortran/resolve.c:10230
 #, gcc-internal-format
 msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "Arithmetischer Unterlauf des bitweise übertragenen BOZ bei %L. Diese Überprüfung kann mit der Option %<-fno-range-check%> ausgeschaltet werden"
 
-#: fortran/expr.c:3392 fortran/resolve.c:10221
+#: fortran/expr.c:3392 fortran/resolve.c:10234
 #, gcc-internal-format
 msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "Arithmetischer Überlauf des bitweise übertragenen BOZ bei %L. Diese Überprüfung kann mit der Option %<-fno-range-check%> ausgeschaltet werden"
 
-#: fortran/expr.c:3396 fortran/resolve.c:10225
+#: fortran/expr.c:3396 fortran/resolve.c:10238
 #, gcc-internal-format
 msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "Arithmetisches NaN des bitweise übertragenen BOZ bei %L. Diese Überprüfung kann mit der Option %<-fno-range-check%> ausgeschaltet werden"
@@ -53233,147 +53305,147 @@
 msgid "The assignment to a KIND or LEN component of a parameterized type at %L is not allowed"
 msgstr "Die Zuweisung zu einer KIND- oder LEN-Komponente eines parametrisierten Typs bei %L ist nicht erlaubt"
 
-#: fortran/expr.c:3426
+#: fortran/expr.c:3429
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible types in DATA statement at %L; attempted conversion of %s to %s"
 msgstr "Unverträgliche Typen in DATA-Anweisung bei %L; versuchte Umwandlung von %s an %s"
 
-#: fortran/expr.c:3465
+#: fortran/expr.c:3468
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is not a POINTER at %L"
 msgstr "Zeiger-Zuweisungsziel ist kein POINTER bei %L"
 
-#: fortran/expr.c:3473
+#: fortran/expr.c:3476
 #, gcc-internal-format
 msgid "%qs in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgstr "%qs in Zeigerzuweisung bei %L kann kein L-Wert sein, da es eine Prozedur ist"
 
-#: fortran/expr.c:3496
+#: fortran/expr.c:3499
 #, gcc-internal-format
 msgid "Expected bounds specification for %qs at %L"
 msgstr "Grenzen für %qs bei %L erwartet"
 
-#: fortran/expr.c:3501
+#: fortran/expr.c:3504
 #, gcc-internal-format
 msgid "Bounds specification for %qs in pointer assignment at %L"
 msgstr "Grenzenangabe für %qs in Zeigerzuweisung bei %L"
 
-#: fortran/expr.c:3514
+#: fortran/expr.c:3517
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower bound has to be present at %L"
 msgstr "Bei %L muss untere Grenze vorhanden sein"
 
-#: fortran/expr.c:3520
+#: fortran/expr.c:3523
 #, gcc-internal-format, gfc-internal-format
 msgid "Stride must not be present at %L"
 msgstr "Bei %L darf kein Schritt vorhanden sein"
 
-#: fortran/expr.c:3532
+#: fortran/expr.c:3535
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the upper bounds must be specified at %L"
 msgstr "Bei %L müssen entweder alle oberen Grenzen oder keine obere Grenze angegeben werden"
 
-#: fortran/expr.c:3558
+#: fortran/expr.c:3561
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %L shall not have a coindex"
 msgstr "Zeigerobjekt bei %L darf keinen Koindex haben"
 
-#: fortran/expr.c:3579
+#: fortran/expr.c:3582
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure pointer assignment at %L"
 msgstr "Ungültige Zuweisung eines Prozedurzeigers bei %L"
 
-#: fortran/expr.c:3603
+#: fortran/expr.c:3606
 #, gcc-internal-format
 msgid "Function result %qs is invalid as proc-target in procedure pointer assignment at %L"
 msgstr "Funktionsergebnis %qs ist als Prozedurziel in Zuweisung des Prozedurzeigers bei %L ungültig"
 
-#: fortran/expr.c:3612
+#: fortran/expr.c:3615
 #, gcc-internal-format
 msgid "Abstract interface %qs is invalid in procedure pointer assignment at %L"
 msgstr "Abstrakte Schnittstelle %qs ist in Zuweisung des Prozedurzeigers bei %L ungültig"
 
-#: fortran/expr.c:3622
+#: fortran/expr.c:3625
 #, gcc-internal-format
 msgid "Statement function %qs is invalid in procedure pointer assignment at %L"
 msgstr "Anweisungsfunktion %qs ist in Zuweisung des Prozedurzeigers bei %L ungültig"
 
-#: fortran/expr.c:3628
+#: fortran/expr.c:3631
 #, gcc-internal-format
 msgid "Internal procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "Interne Prozedur %qs ist in Zuweisung des Prozedurzeigers bei %L ungültig"
 
-#: fortran/expr.c:3635
+#: fortran/expr.c:3638
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L is invalid in procedure pointer assignment"
 msgstr "Eingebautes %qs bei %L ist in Zuweisung des Prozedurzeigers ungültig"
 
-#: fortran/expr.c:3643
+#: fortran/expr.c:3646
 #, gcc-internal-format
 msgid "Nonintrinsic elemental procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "Nichtintrinsische elementare Prozedur %qs ist in Zuweisung des Prozedurzeigers bei %L ungültig"
 
-#: fortran/expr.c:3666
+#: fortran/expr.c:3669
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in the procedure pointer assignment at %L: mismatch in the calling convention"
 msgstr "Unpassende Zuweisung des Prozedurzeigers bei %L: Unpassende Aufrufkonvention"
 
-#: fortran/expr.c:3719
+#: fortran/expr.c:3722
 #, gcc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %qs is not a subroutine"
 msgstr "Unpassende Schnittstellen bei Zuweisung des Prozedurzeigers bei %L: %qs ist kein Unterprogramm"
 
-#: fortran/expr.c:3729 fortran/expr.c:3744
+#: fortran/expr.c:3732 fortran/expr.c:3747
 #, gcc-internal-format
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr "Explizite Schnittstelle für Komponente %qs bei %L erforderlich: %s"
 
-#: fortran/expr.c:3735 fortran/expr.c:3750 fortran/resolve.c:2566
+#: fortran/expr.c:3738 fortran/expr.c:3753 fortran/resolve.c:2566
 #, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr "Explizite Schnittstelle für %qs bei %L erforderlich: %s"
 
-#: fortran/expr.c:3762
+#: fortran/expr.c:3765
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %s"
 msgstr "Unpassende Schnittstellen bei Zuweisung des Prozedurzeigers bei %L: %s"
 
-#: fortran/expr.c:3771
+#: fortran/expr.c:3774
 #, gcc-internal-format
 msgid "Procedure pointer target %qs at %L must be either an intrinsic, host or use associated, referenced or have the EXTERNAL attribute"
 msgstr "Prozedurzeigerziel %qs bei %L muss entweder eine intrinsische Funktion, host- oder use-assoziiert oder referenziert sein, oder aber das EXTERNAL-Attribut haben"
 
-#: fortran/expr.c:3788
+#: fortran/expr.c:3791
 #, gcc-internal-format, gfc-internal-format
 msgid "Data-pointer-object at %L must be unlimited polymorphic, or of a type with the BIND or SEQUENCE attribute, to be compatible with an unlimited polymorphic target"
 msgstr "Datenzeigerobjekt bei %L muss unbegrenzt polymorph oder von einem Typ mit BIND- oder SEQUENCE-Attribut sein, um zum unbegrenzt polymorphen Ziel zu passen"
 
-#: fortran/expr.c:3793
+#: fortran/expr.c:3796
 #, gcc-internal-format, gfc-internal-format
 msgid "Different types in pointer assignment at %L; attempted assignment of %s to %s"
 msgstr "Verschiedene Typen in Zeigerzuweisung bei %L; Versuch der Zuweisung von %s an %s"
 
-#: fortran/expr.c:3802
+#: fortran/expr.c:3805
 #, gcc-internal-format, gfc-internal-format
 msgid "Different kind type parameters in pointer assignment at %L"
 msgstr "Parameter verschiedener Typen in Zeigerzuweisung bei %L"
 
-#: fortran/expr.c:3809
+#: fortran/expr.c:3812
 #, gcc-internal-format, gfc-internal-format
 msgid "Different ranks in pointer assignment at %L"
 msgstr "Verschiedene Ränge in Zeigerzuweisung bei %L"
 
-#: fortran/expr.c:3828
+#: fortran/expr.c:3831
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is smaller than size of the pointer (%ld < %ld) at %L"
 msgstr "Ziel der Rang-Neuzuordnung ist kleiner als die Größe des Zeigers (%ld < %ld) bei %L"
 
-#: fortran/expr.c:3841
+#: fortran/expr.c:3844
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target must be rank 1 or simply contiguous at %L"
 msgstr "Ziel der Rang-Neuzuordnung muss Rang 1 oder einfach fortlaufend bei %L sein"
 
-#: fortran/expr.c:3845
+#: fortran/expr.c:3848
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is not rank 1 at %L"
 msgstr "Ziel der Rang-Neuzuordnung ist nicht Rang 1 bei %L"
@@ -53381,147 +53453,152 @@
 #. The test above might need to be extend when F08, Note 5.4 has to be
 #. interpreted in the way that target and pointer with the same coindex
 #. are allowed.
-#: fortran/expr.c:3877 fortran/expr.c:3925
+#: fortran/expr.c:3880 fortran/expr.c:3928
 #, gcc-internal-format, gfc-internal-format
 msgid "Data target at %L shall not have a coindex"
 msgstr "Datenziel bei %L darf keinen Koindex haben"
 
-#: fortran/expr.c:3880
+#: fortran/expr.c:3883
 #, gcc-internal-format, gfc-internal-format
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr "Zielausdruck in Zeigerzuweisung bei %L muss ein Zeigerergebnis liefern"
 
-#: fortran/expr.c:3888
+#: fortran/expr.c:3891
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr "Zeiger-Zuweisungsziel bei %L ist weder TARGET noch POINTER"
 
-#: fortran/expr.c:3895
+#: fortran/expr.c:3898
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr "Falsches Ziel in Zeigerzuweisung in PURE-Prozedur bei %L"
 
-#: fortran/expr.c:3904
+#: fortran/expr.c:3907
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr "Zeigerzuweisung mit Vektorindex für rhs bei %L"
 
-#: fortran/expr.c:3912
+#: fortran/expr.c:3915
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr "Zeiger-Zuweisungsziel hat PROTECTED-Attribut bei %L"
 
-#: fortran/expr.c:3936
+#: fortran/expr.c:3939
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to contiguous pointer from non-contiguous target at %L"
 msgstr "Zuweisung an zusammenhängenden Zeiger von nichtzusammenhängendem Ziel bei %L"
 
-#: fortran/expr.c:3975
+#: fortran/expr.c:3978
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr "Zeiger bei %L in Zeigerzuweisung könnte Zeigerziel überdauern"
 
-#: fortran/expr.c:4051 fortran/resolve.c:1452
+#: fortran/expr.c:4054 fortran/resolve.c:1452
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr "Ziel der Zeigerinitialisierung bei %L darf nicht ALLOCATABLE sein"
 
-#: fortran/expr.c:4057
+#: fortran/expr.c:4060
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr "Ziel der Zeigerinitialisierung bei %L muss das TARGET-Attribut haben"
 
-#: fortran/expr.c:4072 fortran/resolve.c:1458
+#: fortran/expr.c:4075 fortran/resolve.c:1458
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr "Ziel der Zeigerinitialisierung bei %L muss das SAVE-Attribut haben"
 
-#: fortran/expr.c:4084
+#: fortran/expr.c:4087
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr "Ziel der Zeigerinitialisierung für Prozedur bei %L darf kein Prozedurzeiger sein"
 
-#: fortran/expr.c:5512
+#: fortran/expr.c:4557
+#, gcc-internal-format
+msgid "generate_isocbinding_initializer(): bad iso_c_binding type, expected %<c_ptr%> or %<c_funptr%>"
+msgstr "Interner Fehler: generate_isocbinding_initializer(): bad iso_c_binding type, expected %<c_ptr%> or %<c_funptr%>"
+
+#: fortran/expr.c:5568
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr "Fortran 2008: Zeigerfunktionen in Variablen-Definitionskontext (%s) bei %L"
 
-#: fortran/expr.c:5520
+#: fortran/expr.c:5576
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr "Nicht-variabler Ausdruck in Variablen-Definitionskontext (%s) bei %L"
 
-#: fortran/expr.c:5528
+#: fortran/expr.c:5584
 #, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr "Benannte Konstante %qs in Variablen-Definitionskontext (%s) bei %L"
 
-#: fortran/expr.c:5537
+#: fortran/expr.c:5593
 #, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr "%qs in Variablen-Definitionskontext (%s) bei %L ist keine Variable"
 
-#: fortran/expr.c:5548
+#: fortran/expr.c:5604
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr "Nicht-POINTER in Zeiger-Verbindungskontext (%s) bei %L"
 
-#: fortran/expr.c:5557
+#: fortran/expr.c:5613
 #, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr "Typ nicht zugreifbar in Variablen-Definitionskontext (%s) bei %L"
 
-#: fortran/expr.c:5570
+#: fortran/expr.c:5626
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr "LOCK_TYPE in Variablen-Definitionskontext (%s) bei %L"
 
-#: fortran/expr.c:5583
+#: fortran/expr.c:5639
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr "LOCK_EVENT in Variablen-Definitionskontext (%s) bei %L"
 
-#: fortran/expr.c:5613
+#: fortran/expr.c:5669
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr "Scheinargument %qs mit INTENT(IN) in Zeiger-Verbindungskontext (%s) bei %L"
 
-#: fortran/expr.c:5621
+#: fortran/expr.c:5677
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr "Scheinargument %qs mit INTENT(IN) in Variablen-Definitionskontext (%s) bei %L"
 
-#: fortran/expr.c:5634
+#: fortran/expr.c:5690
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a pointer association context (%s) at %L"
 msgstr "Variable %qs ist PROTECTED und kann nicht in Zeiger-Verbindungskontext (%s) bei %L auftreten"
 
-#: fortran/expr.c:5642
+#: fortran/expr.c:5698
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a variable definition context (%s) at %L"
 msgstr "Variable %qs ist PROTECTED und kann nicht in Variablen-Definitionskontext (%s) bei %L auftreten"
 
-#: fortran/expr.c:5654
+#: fortran/expr.c:5710
 #, gcc-internal-format
 msgid "Variable %qs can not appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr "Variable %qs kann nicht in Variablen-Definitionskontext (%s) bei %L in PURE-Prozedur auftreten"
 
-#: fortran/expr.c:5713
+#: fortran/expr.c:5769
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
 msgstr "%qs ist bei %L mit vektorindiziertem Ziel verbunden und kann nicht in Variablen-Definitionskontext (%s) verwendet werden"
 
-#: fortran/expr.c:5717
+#: fortran/expr.c:5773
 #, gcc-internal-format
 msgid "%qs at %L associated to expression can not be used in a variable definition context (%s)"
 msgstr "%qs ist bei %L mit Ausdruck verbunden und kann nicht in Variablen-Definitionskontext (%s) verwendet werden"
 
-#: fortran/expr.c:5728
+#: fortran/expr.c:5784
 #, gcc-internal-format
 msgid "Associate-name %qs can not appear in a variable definition context (%s) at %L because its target at %L can not, either"
 msgstr "Verbundener Name %qs kann nicht in Variablen-Definitionskontext (%s) bei %L auftreten, da sein Ziel bei %L es auch nicht kann"
 
-#: fortran/expr.c:5770
+#: fortran/expr.c:5826
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr "Elemente mit demselben Wert bei %L und %L in Vektorindex in einem Variablen-Definitionskontext (%s)"
@@ -53531,22 +53608,22 @@
 msgid "can't open input file: %s"
 msgstr "Eingabedatei »%s« kann nicht geöffnet werden"
 
-#: fortran/frontend-passes.c:190
+#: fortran/frontend-passes.c:192
 #, gcc-internal-format
 msgid "No location in statement"
 msgstr "Keine Quellcodeposition in Anweisung"
 
-#: fortran/frontend-passes.c:205
+#: fortran/frontend-passes.c:207
 #, gcc-internal-format, gfc-internal-format
 msgid "No location in expression near %L"
 msgstr "Keine Quellcodeposition in Ausdruck nahe %L"
 
-#: fortran/frontend-passes.c:409
+#: fortran/frontend-passes.c:414
 #, gcc-internal-format
 msgid "Illegal id in copy_walk_reduction_arg"
 msgstr "Illegal id in copy_walk_reduction_arg"
 
-#: fortran/frontend-passes.c:817 fortran/trans-array.c:1182
+#: fortran/frontend-passes.c:822 fortran/trans-array.c:1182
 #: fortran/trans-array.c:6440 fortran/trans-array.c:7864
 #: fortran/trans-intrinsic.c:7307
 #, gcc-internal-format, gfc-internal-format
@@ -53553,67 +53630,67 @@
 msgid "Creating array temporary at %L"
 msgstr "Zwischenergebnis-Feld bei %L wird erzeugt"
 
-#: fortran/frontend-passes.c:842 fortran/frontend-passes.c:846
+#: fortran/frontend-passes.c:847 fortran/frontend-passes.c:851
 #, gcc-internal-format
 msgid "Removing call to function %qs at %L"
 msgstr "Aufruf von Funktion %qs bei %L wird entfernt"
 
-#: fortran/frontend-passes.c:1273 fortran/frontend-passes.c:1312
+#: fortran/frontend-passes.c:1278 fortran/frontend-passes.c:1317
 #, gcc-internal-format
 msgid "bad expression"
 msgstr "falscher Ausdruck"
 
-#: fortran/frontend-passes.c:1308
+#: fortran/frontend-passes.c:1313
 #, gcc-internal-format
 msgid "bad op"
 msgstr "falscher Operator"
 
-#: fortran/frontend-passes.c:2161
+#: fortran/frontend-passes.c:2166
 #, gcc-internal-format
 msgid "illegal OP in optimize_comparison"
 msgstr "illegal OP in optimize_comparison"
 
-#: fortran/frontend-passes.c:2407
+#: fortran/frontend-passes.c:2412
 #, gcc-internal-format
 msgid "Variable %qs at %L set to undefined value inside loop  beginning at %L as INTENT(OUT) argument to subroutine %qs"
 msgstr "Variable %qs bei %L auf undefinierten Wert innerhalb der bei %L beginnenden Schleife gesetzt, als INTENT(OUT)-Argument für Unterprogramm %qs"
 
-#: fortran/frontend-passes.c:2414
+#: fortran/frontend-passes.c:2419
 #, gcc-internal-format
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to subroutine %qs"
 msgstr "Variable %qs bei %L kann nicht innerhalb der bei %L beginnenden Schleife als INTENT(INOUT)-Argument für Unterprogramm %qs definiert werden"
 
-#: fortran/frontend-passes.c:2637 fortran/frontend-passes.c:2661
+#: fortran/frontend-passes.c:2642 fortran/frontend-passes.c:2666
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L out of bounds (%ld < %ld) in loop beginning at %L"
 msgstr "Feldreferenz bei %L ist außerhalb der Grenzen (%ld < %ld) in Schleife, die bei %L beginnt"
 
-#: fortran/frontend-passes.c:2646 fortran/frontend-passes.c:2670
+#: fortran/frontend-passes.c:2651 fortran/frontend-passes.c:2675
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L out of bounds (%ld > %ld) in loop beginning at %L"
 msgstr "Feldreferenz bei %L ist außerhalb der Grenzen (%ld > %ld) in Schleife, die bei %L beginnt"
 
-#: fortran/frontend-passes.c:2730
+#: fortran/frontend-passes.c:2735
 #, gcc-internal-format
 msgid "Variable %qs at %L set to undefined value inside loop beginning at %L as INTENT(OUT) argument to function %qs"
 msgstr "Variable %qs bei %L auf undefinierten Wert innerhalb der bei %L beginnenden Schleife gesetzt, als INTENT(OUT)-Argument für Funktion %qs"
 
-#: fortran/frontend-passes.c:2736
+#: fortran/frontend-passes.c:2741
 #, gcc-internal-format
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr "Variable %qs bei %L kann nicht innerhalb der bei %L beginnenden Schleife als INTENT(INOUT)-Argument für Funktion %qs definiert werden"
 
-#: fortran/frontend-passes.c:3128 fortran/trans-expr.c:1581
+#: fortran/frontend-passes.c:3133 fortran/trans-expr.c:1581
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr "Code zur Neu-Reservierung des reservierbaren Feldes bei %L wird hinzugefügt"
 
-#: fortran/frontend-passes.c:3637
+#: fortran/frontend-passes.c:3642
 #, gcc-internal-format
 msgid "Scalarization using DIMEN_RANGE unimplemented"
 msgstr "Scalarization using DIMEN_RANGE unimplemented"
 
-#: fortran/frontend-passes.c:4429
+#: fortran/frontend-passes.c:4434
 #, gcc-internal-format, gfc-internal-format
 msgid "Interchanging loops at %L"
 msgstr "Schleifen bei %L werden getauscht"
@@ -53733,12 +53810,12 @@
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "Zweites Argument der definierten Zuweisung bei %L muss INTENT(IN)"
 
-#: fortran/interface.c:970 fortran/resolve.c:16351
+#: fortran/interface.c:970 fortran/resolve.c:16378
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "Erstes Argument der Operatorschnittstelle bei %L muss INTENT(IN) sein"
 
-#: fortran/interface.c:977 fortran/resolve.c:16369
+#: fortran/interface.c:977 fortran/resolve.c:16396
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "Zweites Argument der Operatorschnittstelle bei %L muss INTENT(IN) sein"
@@ -54939,7 +55016,7 @@
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr "NAMELIST-Objekt %qs in Namensliste %qs bei %L ist polymorph und erfordert eine definierte Ein-/Ausgabeprozedur"
 
-#: fortran/io.c:3369 fortran/resolve.c:14263
+#: fortran/io.c:3369 fortran/resolve.c:14283
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr "NAMELIST-Objekt %qs in Namensliste %qs bei %L mit ALLOCATABLE- oder POINTER-Komponenten"
@@ -55107,7 +55184,7 @@
 msgid "Integer too large at %C"
 msgstr "Ganzzahl bei %C zu groß"
 
-#: fortran/match.c:580 fortran/parse.c:1132
+#: fortran/match.c:580 fortran/parse.c:1136
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many digits in statement label at %C"
 msgstr "Zu viele Ziffern in Anweisungsmarke bei %C"
@@ -55869,57 +55946,57 @@
 msgid "Expected block name %qs of SELECT construct at %C"
 msgstr "Blockname %qs des SELECT-Konstrukts bei %C erwartet"
 
-#: fortran/match.c:6186
+#: fortran/match.c:6201
 #, gcc-internal-format, gfc-internal-format
 msgid "parse error in SELECT TYPE statement at %C"
 msgstr "Syntaxfehler in »SELECT TYPE«-Anweisung bei %C"
 
-#: fortran/match.c:6211
+#: fortran/match.c:6226
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr "Selektor in SELECT TYPE bei %C ist keine benannte Variable; associate-name=> verwendet"
 
-#: fortran/match.c:6249
+#: fortran/match.c:6264
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr "Unerwartete CASE-Anweisung bei %C"
 
-#: fortran/match.c:6301
+#: fortran/match.c:6316
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CASE specification at %C"
 msgstr "Syntaxfehler in CASE-Spezifikation bei %C"
 
-#: fortran/match.c:6319
+#: fortran/match.c:6334
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected TYPE IS statement at %C"
 msgstr "Unerwartete TYPE IS-Anweisung bei %C"
 
-#: fortran/match.c:6351
+#: fortran/match.c:6366
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr "Typspezifikation darf keinen Sequenz-abgeleiteten Typ oder Typ mit BIND-Attribut in SELECT TYPE bei %C beschreiben [F2003:C815]"
 
-#: fortran/match.c:6362
+#: fortran/match.c:6377
 #, gcc-internal-format, gfc-internal-format
 msgid "All the LEN type parameters in the TYPE IS statement at %C must be ASSUMED"
 msgstr "Alle LEN-Typparameter in der TYPE-IS-Anweisung bei %C müssen ASSUMED sein"
 
-#: fortran/match.c:6373
+#: fortran/match.c:6388
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr "Syntaxfehler in TYPE IS-Spezifikation bei %C"
 
-#: fortran/match.c:6449
+#: fortran/match.c:6464
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr "Syntaxfehler in CLASS IS-Spezifikation bei %C"
 
-#: fortran/match.c:6572
+#: fortran/match.c:6587
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr "ELSEWHERE-Anweisung bei %C nicht eingeschlossen in WHERE-Block"
 
-#: fortran/match.c:6610
+#: fortran/match.c:6625
 #, gcc-internal-format
 msgid "Label %qs at %C doesn't match WHERE label %qs"
 msgstr "Marke %qs bei %C passt nicht zur WHERE-Marke %qs"
@@ -56080,192 +56157,192 @@
 msgid "mio_array_ref(): Unknown array ref"
 msgstr "mio_array_ref(): Unknown array ref"
 
-#: fortran/module.c:3716
+#: fortran/module.c:3718
 #, gcc-internal-format, gfc-internal-format
 msgid "Namelist %s cannot be renamed by USE association to %s"
 msgstr "Namensliste %s kann nicht mit USE-Verbindung in %s umbenannt werden"
 
-#: fortran/module.c:4832
+#: fortran/module.c:4834
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr "Mehrdeutiges !$OMP DECLARE REDUCTION von Modul %s bei %L"
 
-#: fortran/module.c:4835
+#: fortran/module.c:4837
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr "Vorherige !$OMP DECLARE REDUCTION von Modul %s bei %L"
 
-#: fortran/module.c:5029
+#: fortran/module.c:5031
 #, gcc-internal-format
 msgid "%qs of module %qs, imported at %C, is also the name of the current program unit"
 msgstr "Bei %3$C importiertes %1$qs von Modul %2$qs ist auch der Name der aktuellen Programmeinheit"
 
-#: fortran/module.c:5381
+#: fortran/module.c:5383
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in module %qs"
 msgstr "Bei %2$L referenziertes Symbol %1$qs nicht im Modul %3$qs gefunden"
 
-#: fortran/module.c:5388
+#: fortran/module.c:5390
 #, gcc-internal-format
 msgid "User operator %qs referenced at %L not found in module %qs"
 msgstr "Bei %2$L referenzierter Benutzeroperator %1$qs nicht im Modul %3$qs gefunden"
 
-#: fortran/module.c:5393
+#: fortran/module.c:5395
 #, gcc-internal-format
 msgid "Intrinsic operator %qs referenced at %L not found in module %qs"
 msgstr "Bei %2$L referenzierter intrinsischer Operator %1$qs nicht im Modul %3$qs gefunden"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/module.c:5628
+#: fortran/module.c:5630
 #, gcc-internal-format
 msgid "write_symbol(): bad module symbol %qs"
 msgstr "write_symbol(): bad module symbol %qs"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/module.c:5961
+#: fortran/module.c:5963
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr "write_symtree(): Symbol not written"
 
-#: fortran/module.c:6148
+#: fortran/module.c:6150
 #, gcc-internal-format
 msgid "Can't open module file %qs for writing at %C: %s"
 msgstr "Moduldatei %qs kann bei %C nicht zum Schreiben geöffnet werden: %s"
 
-#: fortran/module.c:6169
+#: fortran/module.c:6171
 #, gcc-internal-format
 msgid "Error writing module file %qs for writing: %s"
 msgstr "Fehler beim Schreiben der Moduldatei %qs: %s"
 
-#: fortran/module.c:6180
+#: fortran/module.c:6182
 #, gcc-internal-format
 msgid "Can't delete module file %qs: %s"
 msgstr "Moduldatei %qs kann nicht gelöscht werden: %s"
 
-#: fortran/module.c:6183
+#: fortran/module.c:6185
 #, gcc-internal-format
 msgid "Can't rename module file %qs to %qs: %s"
 msgstr "Moduldatei %qs kann nicht in %qs umbenannt werden: %s"
 
-#: fortran/module.c:6189
+#: fortran/module.c:6191
 #, gcc-internal-format
 msgid "Can't delete temporary module file %qs: %s"
 msgstr "Temporäre Moduldatei %qs kann nicht gelöscht werden: %s"
 
-#: fortran/module.c:6246
+#: fortran/module.c:6248
 #, gcc-internal-format
 msgid "Symbol %qs at %C already declared"
 msgstr "Symbol %qs bei %C bereits deklariert"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/module.c:6317
+#: fortran/module.c:6319
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr "import_iso_c_binding_module(): Unable to create symbol for %s"
 
-#: fortran/module.c:6425 fortran/module.c:6769
+#: fortran/module.c:6427 fortran/module.c:6771
 #, gcc-internal-format
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr "Das bei %2$L referenzierte Symbol %1$qs ist nicht im gewählten Standard vorhanden"
 
-#: fortran/module.c:6553
+#: fortran/module.c:6555
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr "Bei %2$L referenziertes Symbol %1$qs nicht im Modul ISO_C_BINDING gefunden"
 
-#: fortran/module.c:6574 fortran/module.c:6607 fortran/module.c:6649
+#: fortran/module.c:6576 fortran/module.c:6609 fortran/module.c:6651
 #, gcc-internal-format
 msgid "Symbol %qs already declared"
 msgstr "Symbol %qs bereits deklariert"
 
 # https://german.stackexchange.com/questions/35158/deklination-mehrerer-attributiver-adjektive
-#: fortran/module.c:6754
+#: fortran/module.c:6756
 #, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr "Verwendung des intrinsischen Moduls %qs bei %C steht mit nicht-intrinsischem vorher verwendeten Modulnamen in Konflikt"
 
-#: fortran/module.c:6776
+#: fortran/module.c:6778
 #, gcc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr "Verwendung der Konstante NUMERIC_STORAGE_SIZE aus intrinsischem Modul ISO_FORTRAN_ENV bei %L ist mit Option %qs unverträglich"
 
-#: fortran/module.c:6844
+#: fortran/module.c:6846
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr "Verwendung der Konstante NUMERIC_STORAGE_SIZE aus intrinsischem Modul ISO_FORTRAN_ENV bei %C ist mit Option %s unverträglich"
 
-#: fortran/module.c:6898
+#: fortran/module.c:6900
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr "Bei %2$L referenziertes Symbol %1$qs nicht im intrinsischen Modul ISO_FORTRAN_ENV gefunden"
 
-#: fortran/module.c:6924
+#: fortran/module.c:6926
 #, gcc-internal-format, gfc-internal-format
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr "USE-Anweisung bei %C hat keinen ONLY-Qualifizierer"
 
-#: fortran/module.c:6953
+#: fortran/module.c:6955
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr "Intrinsisches Modul ISO_FORTRAN_ENV bei %C"
 
-#: fortran/module.c:6965
+#: fortran/module.c:6967
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
 msgstr "Modul ISO_C_BINDING bei %C"
 
-#: fortran/module.c:6978
+#: fortran/module.c:6980
 #, gcc-internal-format
 msgid "Can't find an intrinsic module named %qs at %C"
 msgstr "Intrinsisches Modul %qs bei %C nicht gefunden"
 
-#: fortran/module.c:6984
+#: fortran/module.c:6986
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr "IEEE_FEATURES-Modul bei %C"
 
-#: fortran/module.c:6990
+#: fortran/module.c:6992
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr "IEEE_EXCEPTIONS-Modul bei %C"
 
-#: fortran/module.c:6996
+#: fortran/module.c:6998
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr "IEEE_ARITHMETIC-Modul bei %C"
 
-#: fortran/module.c:7006
+#: fortran/module.c:7008
 #, gcc-internal-format
 msgid "Can't open module file %qs for reading at %C: %s"
 msgstr "Moduldatei %qs kann bei %C nicht zum Lesen geöffnet werden: %s"
 
-#: fortran/module.c:7009
+#: fortran/module.c:7011
 #, gcc-internal-format
 msgid "Module file %qs has not been generated, either because the module does not contain a MODULE PROCEDURE or there is an error in the module."
 msgstr "Moduldatei %qs wurde nicht generiert, entweder weil das Modul keine MODULE PROCEDURE enthält oder weil es einen Fehler in dem Modul gibt."
 
-#: fortran/module.c:7020
+#: fortran/module.c:7022
 #, gcc-internal-format
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr "Verwendung des nicht-intrinsischen Moduls %qs bei %C steht mit vorher verwendetem intrinsischen Modulnamen in Konflikt"
 
-#: fortran/module.c:7043
+#: fortran/module.c:7045
 #, gcc-internal-format
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr "Bei %2$C geöffnete Datei %1$qs ist keine GNU-Fortran-Moduldatei"
 
-#: fortran/module.c:7051
+#: fortran/module.c:7053
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr "Bei %2$C geöffnete Moduldatei %1$qs kann nicht gelesen werden, da sie von einer anderen Version von GNU Fortran erstellt wurde"
 
-#: fortran/module.c:7066
+#: fortran/module.c:7068
 #, gcc-internal-format, gfc-internal-format
 msgid "Can't USE the same %smodule we're building"
 msgstr "Das %sModul, das gerade gebaut wird, kann nicht gleichzeitig mit USE verwendet werden"
 
 #: fortran/openmp.c:296 fortran/openmp.c:397 fortran/openmp.c:692
-#: fortran/openmp.c:3167
+#: fortran/openmp.c:3166
 #, gcc-internal-format, gfc-internal-format
 msgid "COMMON block /%s/ not found at %C"
 msgstr "COMMON-Block /%s/ bei %C nicht gefunden"
@@ -56342,862 +56419,862 @@
 
 #: fortran/openmp.c:2180
 #, gcc-internal-format, gfc-internal-format
-msgid "Invalid argument to !$ACC WAIT at %L"
-msgstr "Ungültiges Argument von »!$ACC WAIT« bei %L"
+msgid "Invalid argument to !$ACC WAIT at %C"
+msgstr "Ungültiges Argument für »!$ACC WAIT« bei %C"
 
-#: fortran/openmp.c:2188
+#: fortran/openmp.c:2187
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT clause at %L requires a scalar INTEGER expression"
 msgstr "WAIT-Klausel bei %L erfordert einen skalaren INTEGER-Ausdruck"
 
-#: fortran/openmp.c:2221
+#: fortran/openmp.c:2220
 #, gcc-internal-format, gfc-internal-format
 msgid "ACC CACHE directive must be inside of loop %C"
 msgstr "ACC-CACHE-Direktive bei %C muss innerhalb einer Schleife sein"
 
-#: fortran/openmp.c:2252
+#: fortran/openmp.c:2251
 #, gcc-internal-format
 msgid "Multiple loop axes specified for routine"
 msgstr "Mehrere Schleifenachsen für Routine angegeben"
 
-#: fortran/openmp.c:2278
+#: fortran/openmp.c:2277
 #, gcc-internal-format, gfc-internal-format
 msgid "Only the !$ACC ROUTINE form without list is allowed in interface block at %C"
 msgstr "Nur die Form !$ACC ROUTINE ohne Liste ist im Schnittstellenblock bei %C erlaubt"
 
-#: fortran/openmp.c:2306
+#: fortran/openmp.c:2305
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$ACC ROUTINE ( NAME ) at %C, invalid function name %s"
 msgstr "Syntaxfehler in »!$ACC ROUTINE ( NAME )« bei %C, ungültiger Funktionsname %s"
 
-#: fortran/openmp.c:2315
+#: fortran/openmp.c:2314
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$ACC ROUTINE ( NAME ) at %C"
 msgstr "Syntaxfehler in »!$ACC ROUTINE ( NAME )« bei %C"
 
-#: fortran/openmp.c:2322
+#: fortran/openmp.c:2321
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$ACC ROUTINE ( NAME ) at %C, expecting ')' after NAME"
 msgstr "Syntaxfehler in !$ACC ROUTINE ( NAME ) bei %C, hinter NAME wird »)« erwartet"
 
-#: fortran/openmp.c:2457 fortran/openmp.c:2481
+#: fortran/openmp.c:2456 fortran/openmp.c:2480
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP CRITICAL statement at %C"
 msgstr "Unerwarteter Ausschuss hinter $OMP CRITICAL-Anweisung bei %C"
 
-#: fortran/openmp.c:2548
+#: fortran/openmp.c:2547
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP FLUSH statement at %C"
 msgstr "Unerwarteter Ausschuss inter $OMP FLUSH-Anweisung bei %C"
 
-#: fortran/openmp.c:2942 fortran/openmp.c:6225
+#: fortran/openmp.c:2941 fortran/openmp.c:6230
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined %s !$OMP DECLARE REDUCTION at %L"
 msgstr "Redefinition der vordefinierten !$OMP DECLARE REDUCTION »%s« bei %L"
 
-#: fortran/openmp.c:2946 fortran/openmp.c:6229
+#: fortran/openmp.c:2945 fortran/openmp.c:6234
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined !$OMP DECLARE REDUCTION at %L"
 msgstr "Redefinition der vordefinierten !$OMP DECLARE REDUCTION bei %L"
 
-#: fortran/openmp.c:2951
+#: fortran/openmp.c:2950
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of !$OMP DECLARE REDUCTION at %L"
 msgstr "Redefinition von !$OMP DECLARE REDUCTION bei %L"
 
-#: fortran/openmp.c:2953
+#: fortran/openmp.c:2952
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION at %L"
 msgstr "Vorherige !$OMP DECLARE REDUCTION bei %L"
 
-#: fortran/openmp.c:2973
+#: fortran/openmp.c:2972
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after !$OMP DECLARE REDUCTION at %C"
 msgstr "Unerwarteter Ausschuss hinter »!$OMP DECLARE REDUCTION« bei %C"
 
-#: fortran/openmp.c:3010
+#: fortran/openmp.c:3009
 #, gcc-internal-format, gfc-internal-format
 msgid "Only the !$OMP DECLARE TARGET form without clauses is allowed in interface block at %C"
 msgstr "Nur die Form !$OMP DECLARE TARGET ohne Klauseln ist im Schnittstellenblock bei %C erlaubt"
 
-#: fortran/openmp.c:3025
+#: fortran/openmp.c:3024
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after !$OMP DECLARE TARGET at %C"
 msgstr "Unerwarteter Ausschuss hinter »!$OMP DECLARE TARGET« bei %C"
 
-#: fortran/openmp.c:3048
+#: fortran/openmp.c:3047
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET variable at %L is an element of a COMMON block"
 msgstr "»OMP DECLARE TARGET«-Variable bei %L ist ein Element eines COMMON-Blocks"
 
-#: fortran/openmp.c:3053
+#: fortran/openmp.c:3052
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET variable at %L previously mentioned in LINK clause and later in TO clause"
 msgstr "OMP-DECLARE-TARGET-Variable bei %L wurde vorher in LINK-Klausel und später in TO-Klausel erwähnt"
 
-#: fortran/openmp.c:3059
+#: fortran/openmp.c:3058
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET variable at %L previously mentioned in TO clause and later in LINK clause"
 msgstr "OMP-DECLARE-TARGET-Variable bei %L wurde vorher in TO-Klausel und später in LINK-Klausel erwähnt"
 
-#: fortran/openmp.c:3063
+#: fortran/openmp.c:3062
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable at %L mentioned multiple times in clauses of the same OMP DECLARE TARGET directive"
 msgstr "Variable bei %L wird mehrfach in Klauseln derselben OMP-DECLARE-TARGET-Direktive erwähnt"
 
-#: fortran/openmp.c:3078
+#: fortran/openmp.c:3077
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET COMMON at %L previously mentioned in LINK clause and later in TO clause"
 msgstr "OMP DECLARE TARGET COMMON bei %L wurde vorher in LINK-Klausel und später in TO-Klausel erwähnt"
 
-#: fortran/openmp.c:3084
+#: fortran/openmp.c:3083
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET COMMON at %L previously mentioned in TO clause and later in LINK clause"
 msgstr "OMP DECLARE TARGET COMMON bei %L wurde vorher in TO-Klausel und später in LINK-Klausel erwähnt"
 
-#: fortran/openmp.c:3088
+#: fortran/openmp.c:3087
 #, gcc-internal-format, gfc-internal-format
 msgid "COMMON at %L mentioned multiple times in clauses of the same OMP DECLARE TARGET directive"
 msgstr "COMMON bei %L wird mehrfach in Klauseln derselben OMP-DECLARE-TARGET-Direktive erwähnt"
 
-#: fortran/openmp.c:3115
+#: fortran/openmp.c:3114
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$OMP DECLARE TARGET list at %C"
 msgstr "Syntaxfehler in »!$OMP DECLARE TARGET«-Liste bei %C"
 
-#: fortran/openmp.c:3147
+#: fortran/openmp.c:3146
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate variable at %C is an element of a COMMON block"
 msgstr "Threadprivate Variable bei %C ist ein Element eines COMMON-Blocks"
 
-#: fortran/openmp.c:3184
+#: fortran/openmp.c:3183
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after OMP THREADPRIVATE at %C"
 msgstr "Unerwarteter Ausschuss hinter »OMP THREADPRIVATE« bei %C"
 
-#: fortran/openmp.c:3191
+#: fortran/openmp.c:3190
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$OMP THREADPRIVATE list at %C"
 msgstr "Syntaxfehler in !$OMP THREADPRIVATE Liste bei %C"
 
-#: fortran/openmp.c:3405
+#: fortran/openmp.c:3404
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after TASKWAIT clause at %C"
 msgstr "Unerwarteter Ausschuss hinter TASKWAIT-Klausel bei %C"
 
-#: fortran/openmp.c:3419
+#: fortran/openmp.c:3418
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after TASKYIELD clause at %C"
 msgstr "Unerwarteter Ausschuss hinter TASKYIELD-Klausel bei %C"
 
-#: fortran/openmp.c:3478
+#: fortran/openmp.c:3477
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP WORKSHARE statement at %C"
 msgstr "Unerwarteter Ausschuss hinter $OMP WORKSHARE-Anweisung bei %C"
 
-#: fortran/openmp.c:3492
+#: fortran/openmp.c:3491
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP MASTER statement at %C"
 msgstr "Unerwarteter Ausschuss hinter $OMP MASTER-Anweisung bei %C"
 
-#: fortran/openmp.c:3551
+#: fortran/openmp.c:3550
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP ATOMIC statement at %C"
 msgstr "Unerwarteter Ausschuss hinter $OMP ATOMIC-Anweisung bei %C"
 
-#: fortran/openmp.c:3578
+#: fortran/openmp.c:3577
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP BARRIER statement at %C"
 msgstr "Unerwarteter Ausschuss hinter $OMP BARRIER-Anweisung bei %C"
 
-#: fortran/openmp.c:3592
+#: fortran/openmp.c:3591
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP TASKGROUP statement at %C"
 msgstr "Unerwarteter Ausschuss hinter »$OMP TASKGROUP«-Anweisung bei %C"
 
-#: fortran/openmp.c:3642
+#: fortran/openmp.c:3641
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP CANCELLATION POINT statement at %C"
 msgstr "Unerwarteter Ausschuss hinter »$OMP CANCELLATION POINT«-Anweisung bei %C"
 
-#: fortran/openmp.c:3662
+#: fortran/openmp.c:3661
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after NOWAIT clause at %C"
 msgstr "Unerwarteter Ausschuss hinter NOWAIT-Klausel bei %C"
 
-#: fortran/openmp.c:3704
+#: fortran/openmp.c:3703
 #, gcc-internal-format, gfc-internal-format
 msgid "%s clause at %L requires a scalar INTEGER expression"
 msgstr "Klausel %s bei %L erfordert einen skalaren INTEGER-Ausdruck"
 
-#: fortran/openmp.c:3715
+#: fortran/openmp.c:3714
 #, gcc-internal-format, gfc-internal-format
 msgid "INTEGER expression of %s clause at %L must be positive"
 msgstr "INTEGER-Ausdruck von %s-Klausel bei %L muss positiv sein"
 
-#: fortran/openmp.c:3726
+#: fortran/openmp.c:3725
 #, gcc-internal-format, gfc-internal-format
 msgid "INTEGER expression of %s clause at %L must be non-negative"
 msgstr "INTEGER-Ausdruck von %s-Klausel bei %L darf nicht negativ sein"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79841
-#: fortran/openmp.c:3737
+#: fortran/openmp.c:3736
 #, gcc-internal-format
 msgid "POINTER object %qs of derived type in %s clause at %L"
 msgstr "POINTER-Objekt %qs von abgeleitetem Typ in Klausel %s bei %L"
 
-#: fortran/openmp.c:3740
+#: fortran/openmp.c:3739
 #, gcc-internal-format
 msgid "Cray pointer object %qs of derived type in %s clause at %L"
 msgstr "Cray-Zeiger-Objekt von abgeleitetem Typ %qs in »%s«-Klausel bei %L"
 
-#: fortran/openmp.c:3743
+#: fortran/openmp.c:3742
 #, gcc-internal-format
 msgid "Cray pointee object %qs of derived type in %s clause at %L"
 msgstr "Cray-Zeigerziel-Objekt %qs von abgeleitetem Typ in »%s«-Klausel bei %L"
 
-#: fortran/openmp.c:3749 fortran/openmp.c:4687
+#: fortran/openmp.c:3748 fortran/openmp.c:4686
 #, gcc-internal-format
 msgid "POINTER object %qs of polymorphic type in %s clause at %L"
 msgstr "POINTER-Objekt %qs von polymorphem Typ in Klausel %s bei %L"
 
-#: fortran/openmp.c:3754
+#: fortran/openmp.c:3753
 #, gcc-internal-format
 msgid "Cray pointer object %qs of polymorphic type in %s clause at %L"
 msgstr "Cray-Zeiger-Objekt %qs von polymorphem Typ in %qs-Klausel bei %L"
 
-#: fortran/openmp.c:3759
+#: fortran/openmp.c:3758
 #, gcc-internal-format
 msgid "Cray pointee object %qs of polymorphic type in %s clause at %L"
 msgstr "Cray-Zeigerziel-Objekt %qs von polymorphem Typ in %qs-Klausel bei %L"
 
-#: fortran/openmp.c:3769 fortran/openmp.c:4385 fortran/openmp.c:4490
+#: fortran/openmp.c:3768 fortran/openmp.c:4384 fortran/openmp.c:4489
 #, gcc-internal-format
 msgid "Assumed size array %qs in %s clause at %L"
 msgstr "Feld %qs mit vermuteter Größe in Klausel %s bei %L"
 
-#: fortran/openmp.c:3772
+#: fortran/openmp.c:3771
 #, gcc-internal-format
 msgid "Assumed rank array %qs in %s clause at %L"
 msgstr "Feld %qs mit vermutetem Rang in Klausel %s bei %L"
 
-#: fortran/openmp.c:3776
+#: fortran/openmp.c:3775
 #, gcc-internal-format
 msgid "Noncontiguous deferred shape array %qs in %s clause at %L"
 msgstr "Unzusammenhängendes Feld %qs mit verzögerter Form in Klausel %s bei %L"
 
-#: fortran/openmp.c:3784
+#: fortran/openmp.c:3783
 #, gcc-internal-format
 msgid "ALLOCATABLE object %qs of derived type in %s clause at %L"
 msgstr "ALLOCATABLE-Objekt %qs von abgeleitetem Typ in Klausel %s bei %L"
 
-#: fortran/openmp.c:3789
+#: fortran/openmp.c:3788
 #, gcc-internal-format
 msgid "ALLOCATABLE object %qs of polymorphic type in %s clause at %L"
 msgstr "ALLOCATABLE-Objekt %qs von polymorphem Typ in Klausel %s bei %L"
 
-#: fortran/openmp.c:3801 fortran/openmp.c:4480
+#: fortran/openmp.c:3800 fortran/openmp.c:4479
 #, gcc-internal-format
 msgid "POINTER object %qs in %s clause at %L"
 msgstr "POINTER-Objekt %qs in Klausel %s bei %L"
 
-#: fortran/openmp.c:3806 fortran/openmp.c:4691
+#: fortran/openmp.c:3805 fortran/openmp.c:4690
 #, gcc-internal-format
 msgid "Cray pointer object %qs in %s clause at %L"
 msgstr "Cray-Zeiger-Objekt %qs in Klausel %s bei %L"
 
-#: fortran/openmp.c:3811 fortran/openmp.c:4694
+#: fortran/openmp.c:3810 fortran/openmp.c:4693
 #, gcc-internal-format
 msgid "Cray pointee object %qs in %s clause at %L"
 msgstr "Cray-Zeigerziel-Objekt %qs in Klausel %s bei %L"
 
-#: fortran/openmp.c:3816 fortran/openmp.c:4682
+#: fortran/openmp.c:3815 fortran/openmp.c:4681
 #, gcc-internal-format
 msgid "ALLOCATABLE object %qs in %s clause at %L"
 msgstr "ALLOCATABLE-Objekt %qs in Klausel %s bei %L"
 
-#: fortran/openmp.c:3819
+#: fortran/openmp.c:3818
 #, gcc-internal-format
 msgid "VALUE object %qs in %s clause at %L"
 msgstr "VALUE-Objekt %qs in Klausel %s bei %L"
 
-#: fortran/openmp.c:3862
+#: fortran/openmp.c:3861
 #, gcc-internal-format, gfc-internal-format
 msgid "Implicitly declared function %s used in !$OMP DECLARE REDUCTION at %L"
 msgstr "Implizit deklarierte Funktion %s wird in !$OMP DECLARE REDUCTION bei %L verwendet"
 
-#: fortran/openmp.c:3911
+#: fortran/openmp.c:3910
 #, gcc-internal-format, gfc-internal-format
 msgid "Implicitly declared subroutine %s used in !$OMP DECLARE REDUCTION at %L"
 msgstr "Implizit deklariertes Unterprogramm %s wird in !$OMP DECLARE REDUCTION bei %L verwendet"
 
-#: fortran/openmp.c:3944
+#: fortran/openmp.c:3943
 #, gcc-internal-format, gfc-internal-format
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr "ORDERED-Parameter der Klausel bei %L ist weniger als COLLAPSE"
 
-#: fortran/openmp.c:3952 fortran/openmp.c:3963 fortran/resolve.c:10028
-#: fortran/resolve.c:11295
+#: fortran/openmp.c:3951 fortran/openmp.c:3962 fortran/resolve.c:10041
+#: fortran/resolve.c:11315
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "IF-Klausel bei %L erfordert einen skalaren LOGICAL-Ausdruck"
 
-#: fortran/openmp.c:3967
+#: fortran/openmp.c:3966
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause without modifier at %L used together with IF clauses with modifiers"
 msgstr "IF-Klausel ohne Modifizierer bei %L wird zusammen mit IF-Klauseln mit Modifizierert verwendet"
 
-#: fortran/openmp.c:4044
+#: fortran/openmp.c:4043
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause modifier %s at %L not appropriate for the current OpenMP construct"
 msgstr "IF-Klausel-Modifizierer »%s« bei %L ist dem aktuellen OpenMP-Konstrukt nicht angemessen"
 
-#: fortran/openmp.c:4054
+#: fortran/openmp.c:4053
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL clause at %L requires a scalar LOGICAL expression"
 msgstr "FINAL-Klausel bei %L erfordert einen skalaren LOGICAL-Ausdruck"
 
-#: fortran/openmp.c:4064
+#: fortran/openmp.c:4063
 #, gcc-internal-format, gfc-internal-format
 msgid "SCHEDULE clause's chunk_size at %L requires a scalar INTEGER expression"
 msgstr "chunk_size der SCHEDULE-Klausel bei %L erfordert einen skalaren INTEGER-Ausdruck"
 
-#: fortran/openmp.c:4069
+#: fortran/openmp.c:4068
 #, gcc-internal-format, gfc-internal-format
 msgid "INTEGER expression of SCHEDULE clause's chunk_size at %L must be positive"
 msgstr "INTEGER-Ausdruck der »chunk_size« der SCHEDULE-Klausel bei %L muss positiv sein"
 
-#: fortran/openmp.c:4084
+#: fortran/openmp.c:4083
 #, gcc-internal-format
 msgid "Variable %qs is not a dummy argument at %L"
 msgstr "Variable %qs bei %L ist kein Dummyargument"
 
-#: fortran/openmp.c:4116
+#: fortran/openmp.c:4115 fortran/openmp.c:5998
 #, gcc-internal-format
 msgid "Object %qs is not a variable at %L"
 msgstr "Objekt %qs bei %L ist keine Variable"
 
-#: fortran/openmp.c:4132 fortran/openmp.c:4143 fortran/openmp.c:4151
-#: fortran/openmp.c:4162 fortran/openmp.c:4174 fortran/openmp.c:4189
-#: fortran/openmp.c:6023
+#: fortran/openmp.c:4131 fortran/openmp.c:4142 fortran/openmp.c:4150
+#: fortran/openmp.c:4161 fortran/openmp.c:4173 fortran/openmp.c:4188
+#: fortran/openmp.c:6028
 #, gcc-internal-format
 msgid "Symbol %qs present on multiple clauses at %L"
 msgstr "Symbol %qs bei %L in mehreren Klauseln vorhanden"
 
-#: fortran/openmp.c:4196
+#: fortran/openmp.c:4195
 #, gcc-internal-format
 msgid "Array %qs is not permitted in reduction at %L"
 msgstr "Feld %qs ist nicht in Reduzierung bei %L erlaubt"
 
-#: fortran/openmp.c:4209
+#: fortran/openmp.c:4208
 #, gcc-internal-format
 msgid "Symbol %qs present on both FROM and TO clauses at %L"
 msgstr "Symbol %qs tritt bei %L sowohl in der FROM- als auch in der TO-Klausel auf"
 
-#: fortran/openmp.c:4231
+#: fortran/openmp.c:4230
 #, gcc-internal-format
 msgid "Non-THREADPRIVATE object %qs in COPYIN clause at %L"
 msgstr "Nicht-THREADPRIVATE-Objekt %qs in Klausel COPYIN bei %L"
 
-#: fortran/openmp.c:4239
+#: fortran/openmp.c:4238
 #, gcc-internal-format
 msgid "Assumed size array %qs in COPYPRIVATE clause at %L"
 msgstr "Feld %qs mit vermuteter Größe in Klausel COPYPRIVATE bei %L"
 
-#: fortran/openmp.c:4242
+#: fortran/openmp.c:4241
 #, gcc-internal-format
 msgid "INTENT(IN) POINTER %qs in COPYPRIVATE clause at %L"
 msgstr "INTENT(IN)-Zeiger %qs in COPYPRIVATE-Klausel bei %L"
 
-#: fortran/openmp.c:4250
+#: fortran/openmp.c:4249
 #, gcc-internal-format
 msgid "THREADPRIVATE object %qs in SHARED clause at %L"
 msgstr "THREADPRIVATE-Objekt %qs in SHARED-Klausel bei %L"
 
-#: fortran/openmp.c:4253
+#: fortran/openmp.c:4252
 #, gcc-internal-format
 msgid "Cray pointee %qs in SHARED clause at %L"
 msgstr "Cray-Zeigerziel %qs in Klausel SHARED bei %L"
 
-#: fortran/openmp.c:4256
+#: fortran/openmp.c:4255
 #, gcc-internal-format
 msgid "ASSOCIATE name %qs in SHARED clause at %L"
 msgstr "ASSOCIATE-Name %qs in SHARED-Klausel bei %L"
 
-#: fortran/openmp.c:4271
+#: fortran/openmp.c:4270
 #, gcc-internal-format
 msgid "%qs in ALIGNED clause must be POINTER, ALLOCATABLE, Cray pointer or C_PTR at %L"
 msgstr "%qs in ALIGNED-Klausel bei %L muss POINTER, ALLOCATABLE, Cray-Zeiger oder C_PTR sein"
 
-#: fortran/openmp.c:4283
+#: fortran/openmp.c:4282
 #, gcc-internal-format
 msgid "%qs in ALIGNED clause at %L requires a scalar positive constant integer alignment expression"
 msgstr "%qs in ALIGNED-Klausel bei %L erfordert einen skalaren, positiven, konstanten Ganzzahlausdruck für die Ausrichtung"
 
-#: fortran/openmp.c:4302
+#: fortran/openmp.c:4301
 #, gcc-internal-format, gfc-internal-format
 msgid "SINK dependence type only allowed on ORDERED directive at %L"
 msgstr "SINK-Abhängigkeitstyp bei %L ist nur in ORDERED-Direktive erlaubt"
 
-#: fortran/openmp.c:4306
+#: fortran/openmp.c:4305
 #, gcc-internal-format, gfc-internal-format
 msgid "DEPEND SINK used together with DEPEND SOURCE on the same construct at %L"
 msgstr "DEPEND SINK wird zusammen mit DEPEND SOURCE an demselben Konstrukt bei %L verwendet"
 
-#: fortran/openmp.c:4316
+#: fortran/openmp.c:4315
 #, gcc-internal-format, gfc-internal-format
 msgid "SINK addend not a constant integer at %L"
 msgstr "SINK-Summand bei %L ist keine konstante Ganzzahl"
 
-#: fortran/openmp.c:4322
+#: fortran/openmp.c:4321
 #, gcc-internal-format, gfc-internal-format
 msgid "Only SOURCE or SINK dependence types are allowed on ORDERED directive at %L"
 msgstr "Nur SOURCE- oder SINK-Abhängigkeitstypen sind an ORDERED-Direktive bei %L erlaubt"
 
-#: fortran/openmp.c:4333 fortran/openmp.c:4354
+#: fortran/openmp.c:4332 fortran/openmp.c:4353
 #, gcc-internal-format
 msgid "%qs in %s clause at %L is not a proper array section"
 msgstr "%qs in %s-Klausel bei %L ist kein korrekter Feldabschnitt"
 
-#: fortran/openmp.c:4337
+#: fortran/openmp.c:4336
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarrays not supported in %s clause at %L"
 msgstr "Coarrays werden nicht unterstützt in %s-Klausel bei %L"
 
-#: fortran/openmp.c:4346
+#: fortran/openmp.c:4345
 #, gcc-internal-format, gfc-internal-format
 msgid "Stride should not be specified for array section in %s clause at %L"
 msgstr "Schrittweite sollte für Feldabschnitt in %s-Klausel bei %L nicht angegeben werden"
 
-#: fortran/openmp.c:4367
+#: fortran/openmp.c:4366
 #, gcc-internal-format
 msgid "%qs in DEPEND clause at %L is a zero size array section"
 msgstr "%qs in DEPEND-Klausel bei %L ist ein Feldabschnitt der Größe 0"
 
-#: fortran/openmp.c:4403
+#: fortran/openmp.c:4402
 #, gcc-internal-format, gfc-internal-format
 msgid "TARGET%s with map-type other than TO, FROM, TOFROM, or ALLOC on MAP clause at %L"
 msgstr "TARGET%s mit Zuordnungstyp außer TO, FROM, TOFROM oder ALLOC an MAP-Klausel bei %L"
 
-#: fortran/openmp.c:4419
+#: fortran/openmp.c:4418
 #, gcc-internal-format, gfc-internal-format
 msgid "TARGET ENTER DATA with map-type other than TO, or ALLOC on MAP clause at %L"
 msgstr "TARGET ENTER DATA mit Zuordnungstyp außer TO oder ALLOC an MAP-Klausel bei %L"
 
-#: fortran/openmp.c:4434
+#: fortran/openmp.c:4433
 #, gcc-internal-format, gfc-internal-format
 msgid "TARGET EXIT DATA with map-type other than FROM, RELEASE, or DELETE on MAP clause at %L"
 msgstr "TARGET EXIT DATA mit Zuordnungstyp außer FROM, RELEASE oder DELETE MAP-Klausel bei %L"
 
-#: fortran/openmp.c:4450 fortran/openmp.c:4466
+#: fortran/openmp.c:4449 fortran/openmp.c:4465
 #, gcc-internal-format
 msgid "THREADPRIVATE object %qs in %s clause at %L"
 msgstr "THREADPRIVATE-Objekt %qs in %s-Klausel bei %L"
 
-#: fortran/openmp.c:4453 fortran/openmp.c:4469
+#: fortran/openmp.c:4452 fortran/openmp.c:4468
 #, gcc-internal-format
 msgid "Cray pointee %qs in %s clause at %L"
 msgstr "Cray-Zeigerziel %qs in %s-Klausel bei %L"
 
-#: fortran/openmp.c:4472
+#: fortran/openmp.c:4471
 #, gcc-internal-format
 msgid "ASSOCIATE name %qs in %s clause at %L"
 msgstr "ASSOCIATE-Name %qs in %s-Klausel bei %L"
 
-#: fortran/openmp.c:4477
+#: fortran/openmp.c:4476
 #, gcc-internal-format
 msgid "Procedure pointer %qs in %s clause at %L"
 msgstr "Prozedurzeiger %qs in %s-Klausel bei %L"
 
-#: fortran/openmp.c:4483
+#: fortran/openmp.c:4482
 #, gcc-internal-format
 msgid "Cray pointer %qs in %s clause at %L"
 msgstr "Cray-Zeiger %qs in %s-Klausel bei %L"
 
-#: fortran/openmp.c:4493
+#: fortran/openmp.c:4492
 #, gcc-internal-format
 msgid "Variable %qs in %s clause is used in NAMELIST statement at %L"
 msgstr "Variable %qs in %s-Klausel wird in NAMELIST-Anweisung bei %L verwendet"
 
 #. case OMP_LIST_REDUCTION:
-#: fortran/openmp.c:4503
+#: fortran/openmp.c:4502
 #, gcc-internal-format
 msgid "INTENT(IN) POINTER %qs in %s clause at %L"
 msgstr "INTENT(IN) POINTER %qs in Klausel %s bei %L"
 
-#: fortran/openmp.c:4596
+#: fortran/openmp.c:4595
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP DECLARE REDUCTION %s not found for type %s at %L"
 msgstr "!$OMP DECLARE REDUCTION »%s« für Typ %s bei %L nicht gefunden"
 
-#: fortran/openmp.c:4622
+#: fortran/openmp.c:4621
 #, gcc-internal-format, gfc-internal-format
 msgid "LINEAR clause modifier used on DO or SIMD construct at %L"
 msgstr "LINEAR-Klauselmodifizierer wird bei %L an DO- oder SIMD-Konstrukt verwendet"
 
-#: fortran/openmp.c:4627
+#: fortran/openmp.c:4626
 #, gcc-internal-format, gfc-internal-format
 msgid "LINEAR clause specified together with ORDERED clause with argument at %L"
 msgstr "Für Argument bei %L ist die LINEAR-Klausel zusammen mit ORDERED-Klausel angegeben"
 
-#: fortran/openmp.c:4632
+#: fortran/openmp.c:4631
 #, gcc-internal-format
 msgid "LINEAR variable %qs must be INTEGER at %L"
 msgstr "LINEAR-Variable %qs bei %L muss INTEGER sein"
 
-#: fortran/openmp.c:4637
+#: fortran/openmp.c:4636
 #, gcc-internal-format
 msgid "LINEAR dummy argument %qs with VALUE attribute with %s modifier at %L"
 msgstr "LINEAR-Dummy-Argument %qs mit VALUE-Attribut mit %s-Modifizierer bei %L"
 
-#: fortran/openmp.c:4648
+#: fortran/openmp.c:4647
 #, gcc-internal-format
 msgid "%qs in LINEAR clause at %L requires a scalar integer linear-step expression"
 msgstr "%qs in LINEAR-Klausel bei %L benötigt einen skalaren, ganzzahligen linear-step-Ausdruck"
 
-#: fortran/openmp.c:4665
+#: fortran/openmp.c:4664
 #, gcc-internal-format
 msgid "%qs in LINEAR clause at %L requires a constant integer linear-step expression or dummy argument specified in UNIFORM clause"
 msgstr "%qs in LINEAR-Klausel bei %L benötigt einen konstanten, ganzzahligen linear-step-Ausdruck oder ein Dummy-Argument, das in der UNIFORM-Klausel angegeben ist"
 
-#: fortran/openmp.c:4699
+#: fortran/openmp.c:4698
 #, gcc-internal-format
 msgid "%s clause variable %qs at %L is neither a POINTER nor an array"
 msgstr "%s-Klausel-Variable %qs bei %L ist weder Zeiger- noch Feldtyp"
 
-#: fortran/openmp.c:4731
+#: fortran/openmp.c:4730
 #, gcc-internal-format, gfc-internal-format
 msgid "DIST_SCHEDULE clause's chunk_size at %L requires a scalar INTEGER expression"
 msgstr "Die chunk_size der DIST_SCHEDULE-Klausel bei %L erfordert einen skalaren INTEGER-Ausdruck"
 
-#: fortran/openmp.c:4763
+#: fortran/openmp.c:4762
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible use of TILE and COLLAPSE at %L"
 msgstr "Unverträgliche Verwendung von TILE und COLLAPSE bei %L"
 
-#: fortran/openmp.c:4765
+#: fortran/openmp.c:4764
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE dependence type only allowed on ORDERED directive at %L"
 msgstr "SOURCE Abhängigkeitstyp ist nur an ORDERED-Direktive erlaubt bei %L"
 
-#: fortran/openmp.c:4778
+#: fortran/openmp.c:4777
 #, gcc-internal-format, gfc-internal-format
 msgid "%s must contain at least one MAP clause at %L"
 msgstr "%s bei %L muss mindestens eine MAP-Klausel enthalten"
 
-#: fortran/openmp.c:4875
+#: fortran/openmp.c:4874
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected !$OMP ATOMIC expression at %L"
 msgstr "Unerwarteter »!$OMP ATOMIC«Ausdruck bei %L"
 
-#: fortran/openmp.c:4904
+#: fortran/openmp.c:4903
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC statement must set a scalar variable of intrinsic type at %L"
 msgstr "Anweisung !$OMP ATOMIC muss eine skalare Variable intrinsischen Typs bei %L setzen"
 
-#: fortran/openmp.c:4929
+#: fortran/openmp.c:4928
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC READ statement must read from a scalar variable of intrinsic type at %L"
 msgstr "Anweisung !$OMP ATOMIC READ muss bei %L von skalarer Variable intrinsischen Typs lesen"
 
-#: fortran/openmp.c:4934
+#: fortran/openmp.c:4933
 #, gcc-internal-format, gfc-internal-format
 msgid "expr in !$OMP ATOMIC WRITE assignment var = expr must be scalar and cannot reference var at %L"
 msgstr "Ausdruck in !$OMP ATOMIC WRITE-Zuweisung »var = expr« muss skalar sein und kann keine Variable bei %L referenzieren"
 
-#: fortran/openmp.c:4956 fortran/openmp.c:5247
+#: fortran/openmp.c:4955 fortran/openmp.c:5246
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE capture statement must read from a scalar variable of intrinsic type at %L"
 msgstr "!$OMP ATOMIC CAPTURE-Erfassungsanweisung muss bei %L von skalarer Variable intrinsischen Typs lesen"
 
-#: fortran/openmp.c:4971
+#: fortran/openmp.c:4970
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE update statement must set a scalar variable of intrinsic type at %L"
 msgstr "!$OMP ATOMIC CAPTURE-Updateanweisung muss bei %L skalare Variable intrinsischen Typs setzen"
 
-#: fortran/openmp.c:4978 fortran/openmp.c:5254
+#: fortran/openmp.c:4977 fortran/openmp.c:5253
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE capture statement reads from different variable than update statement writes into at %L"
 msgstr "!$OMP ATOMIC CAPTURE-Erfassungsanweisung liest bei %L von anderer Variable als die Update-Anweisung schreibt"
 
-#: fortran/openmp.c:4994
+#: fortran/openmp.c:4993
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC with ALLOCATABLE variable at %L"
 msgstr "!$OMP ATOMIC mit ALLOCATABLE-Variable bei %L"
 
-#: fortran/openmp.c:5036
+#: fortran/openmp.c:5035
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment operator must be binary +, *, -, /, .AND., .OR., .EQV. or .NEQV. at %L"
 msgstr "Zuweisungsoperator »!$OMP ATOMIC« muss bei %L ein binäres +, *, -, /, .AND., .OR., .EQV. oder .NEQV. sein"
 
-#: fortran/openmp.c:5084
+#: fortran/openmp.c:5083
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment must be var = var op expr or var = expr op var at %L"
 msgstr "Zuweisung !$OMP ATOMIC muss bei %L »var = var op expr« oder »var = expr op var« sein"
 
-#: fortran/openmp.c:5098
+#: fortran/openmp.c:5097
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC var = var op expr not mathematically equivalent to var = var op (expr) at %L"
 msgstr "!$OMP ATOMIC »var op expr« bei %L ist nicht mathematisch äquivalent zu »var = var op (expr)«"
 
-#: fortran/openmp.c:5130
+#: fortran/openmp.c:5129
 #, gcc-internal-format, gfc-internal-format
 msgid "expr in !$OMP ATOMIC assignment var = var op expr must be scalar and cannot reference var at %L"
 msgstr "Ausdruck in Zuweisung !$OMP ATOMIC »var = var op expr« muss skalar sein und kann keine Variable bei %L referenzieren"
 
-#: fortran/openmp.c:5154
+#: fortran/openmp.c:5153
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment intrinsic IAND, IOR or IEOR must have two arguments at %L"
 msgstr "Eingebaute Zuweisung !$OMP ATOMIC IAND, IOR oder IEOR muss bei %L zwei Argumente haben"
 
-#: fortran/openmp.c:5161
+#: fortran/openmp.c:5160
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment intrinsic must be MIN, MAX, IAND, IOR or IEOR at %L"
 msgstr "Eingebaute Zuweisung !$OMP ATOMIC muss bei %L MIN, MAX, IAND, IOR oder IEOR sein"
 
-#: fortran/openmp.c:5178
+#: fortran/openmp.c:5177
 #, gcc-internal-format
 msgid "!$OMP ATOMIC intrinsic arguments except one must not reference %qs at %L"
 msgstr "Von den intrinsischen Argumenten für %<!$OMP ATOMIC%> bei %2$L darf höchstens eins auf %1$qs verweisen"
 
-#: fortran/openmp.c:5185
+#: fortran/openmp.c:5184
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC intrinsic arguments must be scalar at %L"
 msgstr "!$OMP ATOMIC intrinsische Argumente müssen bei %L skalar sein"
 
-#: fortran/openmp.c:5193
+#: fortran/openmp.c:5192
 #, gcc-internal-format
 msgid "First or last !$OMP ATOMIC intrinsic argument must be %qs at %L"
 msgstr "Erstes oder letztes intrinsisches Argument zu !$OMP ATOMIC muss bei %2$L %1$qs sein"
 
-#: fortran/openmp.c:5211
+#: fortran/openmp.c:5210
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment must have an operator or intrinsic on right hand side at %L"
 msgstr "!$OMP ATOMIC Zuweisung muss auf der rechten Seite bei %L Operator oder Intrinsic haben"
 
-#: fortran/openmp.c:5225
+#: fortran/openmp.c:5224
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE capture statement must set a scalar variable of intrinsic type at %L"
 msgstr "!$OMP ATOMIC CAPTURE-Erfassungsanweisung muss eine skalare Variable intrinsischen Typs bei %L setzen"
 
-#: fortran/openmp.c:5544
+#: fortran/openmp.c:5543
 #, gcc-internal-format, gfc-internal-format
 msgid "%s cannot be a DO WHILE or DO without loop control at %L"
 msgstr "%s kann weder DO WHILE noch DO sein, ohne Schleifensteuerung bei %L"
 
-#: fortran/openmp.c:5550
+#: fortran/openmp.c:5549
 #, gcc-internal-format, gfc-internal-format
 msgid "%s cannot be a DO CONCURRENT loop at %L"
 msgstr "%s kann bei %L keine DO-CONCURRENT-Schleife sein"
 
-#: fortran/openmp.c:5556
+#: fortran/openmp.c:5555
 #, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable must be of type integer at %L"
 msgstr "%s-Iterationsvariable bei %L muss vom Typ integer sein"
 
-#: fortran/openmp.c:5560
+#: fortran/openmp.c:5559
 #, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable must not be THREADPRIVATE at %L"
 msgstr "%s-Iterationsvariable bei %L darf nicht THREADPRIVATE sein"
 
-#: fortran/openmp.c:5573
+#: fortran/openmp.c:5572
 #, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable present on clause other than PRIVATE or LASTPRIVATE at %L"
 msgstr "%s-Iterationsvariable bei %L an anderer Klausel als PRIVATE oder LASTPRIVATE gefunden"
 
-#: fortran/openmp.c:5577
+#: fortran/openmp.c:5576
 #, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable present on clause other than LASTPRIVATE at %L"
 msgstr "%s-Iterationsvariable bei %L an anderer Klausel als LASTPRIVATE gefunden"
 
-#: fortran/openmp.c:5581
+#: fortran/openmp.c:5580
 #, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable present on clause other than LINEAR at %L"
 msgstr "%s-Iterationsvariable bei %L an anderer Klausel als LINEAR gefunden"
 
-#: fortran/openmp.c:5599
+#: fortran/openmp.c:5598
 #, gcc-internal-format, gfc-internal-format
 msgid "%s collapsed loops don't form rectangular iteration space at %L"
 msgstr "Zusammengefallene »%s«-Schleifen formen bei %L keinen rechteckigen Wiederholungsraum"
 
-#: fortran/openmp.c:5611
+#: fortran/openmp.c:5610
 #, gcc-internal-format, gfc-internal-format
 msgid "collapsed %s loops not perfectly nested at %L"
 msgstr "Zusammengefallene »%s«-Schleifen bei %L nicht perfekt geschachtelt"
 
-#: fortran/openmp.c:5620 fortran/openmp.c:5628
+#: fortran/openmp.c:5619 fortran/openmp.c:5627
 #, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for collapsed %s at %L"
 msgstr "zu wenige DO-Schleifen für zusammengefallenes %s bei %L"
 
-#: fortran/openmp.c:5712 fortran/openmp.c:5725
+#: fortran/openmp.c:5711 fortran/openmp.c:5724
 #, gcc-internal-format, gfc-internal-format
 msgid "The %s directive cannot be specified within a %s region at %L"
 msgstr "Die %1$s-Direktive bei %3$L darf nicht innerhalb einer %2$s-Region angegeben werden"
 
-#: fortran/openmp.c:5744
+#: fortran/openmp.c:5743
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP cannot be a DO WHILE or DO without loop control at %L"
 msgstr "!$ACC LOOP darf ohne Schleifensteuerung bei %L kein DO WHILE oder DO sein"
 
-#: fortran/openmp.c:5750
+#: fortran/openmp.c:5749
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP iteration variable must be of type integer at %L"
 msgstr "!$ACC-LOOP-Iterationsvariable bei %L muss vom Typ integer sein"
 
-#: fortran/openmp.c:5766
+#: fortran/openmp.c:5765
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s loops don't form rectangular iteration space at %L"
 msgstr "»%s !$ACC LOOP«-Schleifen bei %L formen keinen rechteckigen Wiederholungsraum"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79861
-#: fortran/openmp.c:5778
+#: fortran/openmp.c:5777
 #, gcc-internal-format, gfc-internal-format
 msgid "%s !$ACC LOOP loops not perfectly nested at %L"
 msgstr "»%s !$ACC LOOP«-Schleifen bei %L nicht perfekt geschachtelt"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79861
-#: fortran/openmp.c:5788 fortran/openmp.c:5797
+#: fortran/openmp.c:5787 fortran/openmp.c:5796
 #, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for %s !$ACC LOOP at %L"
 msgstr "zu wenige DO-Schleifen für »%s !$ACC LOOP« bei %L"
 
-#: fortran/openmp.c:5812 fortran/openmp.c:5819
+#: fortran/openmp.c:5811 fortran/openmp.c:5818
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s in PARALLEL region doesn't allow %s arguments at %L"
 msgstr "!$ACC LOOP %s in PARALLEL-Region erlaubt keine »%s«-Argumente bei %L"
 
-#: fortran/openmp.c:5841
+#: fortran/openmp.c:5840
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside another loop parallelized across gangs at %L"
 msgstr "Gangübergreifende Schleife bei %L ist innerhalb einer anderen gangübergreifenden Schleife nicht erlaubt"
 
-#: fortran/openmp.c:5845 fortran/openmp.c:5849
+#: fortran/openmp.c:5844 fortran/openmp.c:5848
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside loop parallelized across workers at %L"
 msgstr "Gangübergreifende Schleife bei %L ist innerhalb einer workerübergreifenden Schleife nicht erlaubt"
 
-#: fortran/openmp.c:5856
+#: fortran/openmp.c:5855
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across workers at %L"
 msgstr "Workerübergreifende Schleife bei %L ist innerhalb einer anderen workerübergreifenden Schleife nicht erlaubt"
 
-#: fortran/openmp.c:5860
+#: fortran/openmp.c:5859
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across vectors at %L"
 msgstr "Workerübergreifende Schleife bei %L ist innerhalb einer anderen vektorübergreifenden Schleife nicht erlaubt"
 
-#: fortran/openmp.c:5866
+#: fortran/openmp.c:5865
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across vectors is not allowed inside another loop parallelized across vectors at %L"
 msgstr "Vektorübergreifende Schleife bei %L ist innerhalb einer anderen vektorübergreifenden Schleife nicht erlaubt"
 
-#: fortran/openmp.c:5878
+#: fortran/openmp.c:5877
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with INDEPENDENT at %L"
 msgstr "Klausel SEQ steht in Konflikt mit INDEPENDENT bei %L"
 
-#: fortran/openmp.c:5880
+#: fortran/openmp.c:5879
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with GANG at %L"
 msgstr "Klausel SEQ steht in Konflikt mit GANG bei %L"
 
-#: fortran/openmp.c:5882
+#: fortran/openmp.c:5881
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with WORKER at %L"
 msgstr "Klausel SEQ steht in Konflikt mit WORKER bei %L"
 
-#: fortran/openmp.c:5884
+#: fortran/openmp.c:5883
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with VECTOR at %L"
 msgstr "Klausel SEQ steht in Konflikt mit VECTOR bei %L"
 
-#: fortran/openmp.c:5886
+#: fortran/openmp.c:5885
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with AUTO at %L"
 msgstr "Klausel SEQ steht in Konflikt mit AUTO bei %L"
 
-#: fortran/openmp.c:5891
+#: fortran/openmp.c:5890
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with GANG at %L"
 msgstr "Klausel AUTO steht in Konflikt mit GANG bei %L"
 
-#: fortran/openmp.c:5893
+#: fortran/openmp.c:5892
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with WORKER at %L"
 msgstr "Klausel AUTO steht in Konflikt mit WORKER bei %L"
 
-#: fortran/openmp.c:5895
+#: fortran/openmp.c:5894
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with VECTOR at %L"
 msgstr "Klausel AUTO steht in Konflikt mit VECTOR bei %L"
 
-#: fortran/openmp.c:5899
+#: fortran/openmp.c:5898
 #, gcc-internal-format, gfc-internal-format
 msgid "Tiled loop cannot be parallelized across gangs, workers and vectors at the same time at %L"
 msgstr "Gekachelte Schleife bei %L kann nicht über Gangs, Worker oder Vektoren übergreifend parallelisiert werden"
 
-#: fortran/openmp.c:5934
+#: fortran/openmp.c:5933
 #, gcc-internal-format, gfc-internal-format
 msgid "TILE requires constant expression at %L"
 msgstr "TILE bei %L erfordert konstanten Ausdruck"
 
-#: fortran/openmp.c:5999
+#: fortran/openmp.c:6004
 #, gcc-internal-format
 msgid "PARAMETER object %qs is not allowed at %L"
 msgstr "PARAMETER-Objekt %qs ist bei %L nicht erlaubt"
 
-#: fortran/openmp.c:6006
+#: fortran/openmp.c:6011
 #, gcc-internal-format
 msgid "Array sections: %qs not allowed in !$ACC DECLARE at %L"
 msgstr "Feldabschnitte: %qs ist in !$ACC DECLARE bei %L nicht erlaubt"
 
-#: fortran/openmp.c:6133
+#: fortran/openmp.c:6138
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP TARGET UPDATE at %L requires at least one TO or FROM clause"
 msgstr "OMP TARGET UPDATE bei %L erfordert mindestens eine TO- oder FROM-Klausel"
 
-#: fortran/openmp.c:6155
+#: fortran/openmp.c:6160
 #, gcc-internal-format
 msgid "!$OMP DECLARE SIMD should refer to containing procedure %qs at %L"
 msgstr "!$OMP DECLARE SIMD bei %2$L sollte auf die enthaltende Prozedur %1$qs verweisen"
 
-#: fortran/openmp.c:6179
+#: fortran/openmp.c:6184
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_PRIV or OMP_ORIG used in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr "Variable außer OMP_PRIV oder OMP_ORIG wird bei %L in INITIALIZER-Klausel von !$OMP DECLARE REDUCTION verwendet"
 
-#: fortran/openmp.c:6187
+#: fortran/openmp.c:6192
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_OUT or OMP_IN used in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr "Variable außer OMP_OUT oder OMP_IN wird bei %L in Kombinierer von !$OMP DECLARE REDUCTION verwendet"
 
-#: fortran/openmp.c:6216
+#: fortran/openmp.c:6221
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid operator for !$OMP DECLARE REDUCTION %s at %L"
 msgstr "Ungültiger Operator für !$OMP DECLARE REDUCTION %s bei %L"
 
-#: fortran/openmp.c:6238
+#: fortran/openmp.c:6243
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER length in !$OMP DECLARE REDUCTION %s not constant at %L"
 msgstr "CHARACTER-Länge in !$OMP DECLARE REDUCTION %s ist bei %L nicht konstant"
 
-#: fortran/openmp.c:6254
+#: fortran/openmp.c:6259
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr "Unterprogrammaufruf mit alternativen Rückgaben in Kombinierer von !$OMP DECLARE REDUCTION bei %L"
 
-#: fortran/openmp.c:6269
+#: fortran/openmp.c:6274
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr "Unterprogrammaufruf mit alternativen Rückgaben in INITIALIZER-Klausel von !$OMP DECLARE REDUCTION bei %L"
 
-#: fortran/openmp.c:6279
+#: fortran/openmp.c:6284
 #, gcc-internal-format, gfc-internal-format
 msgid "One of actual subroutine arguments in INITIALIZER clause of !$OMP DECLARE REDUCTION must be OMP_PRIV at %L"
 msgstr "Eins der tatsächlichen Argumente in INITIALIZER-Klausel von !$OMP DECLARE REDUCTION bei %L muss OMP_PRIV sein"
 
-#: fortran/openmp.c:6287
+#: fortran/openmp.c:6292
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing INITIALIZER clause for !$OMP DECLARE REDUCTION of derived type without default initializer at %L"
 msgstr "Fehlende INITIALIZER-Klausel für !$OMP DECLARE REDUCTION von abgeleitetem Typ ohne Defaultinitialisierer bei %L"
@@ -57307,493 +57384,493 @@
 msgid "Unclassifiable statement at %C"
 msgstr "Nicht klassifizierbare Anweisung bei %C"
 
-#: fortran/parse.c:629
+#: fortran/parse.c:631
 #, gcc-internal-format, gfc-internal-format
 msgid "OpenACC directives at %C may not appear in PURE procedures"
 msgstr "OpenACC-Anweisungen bei %C dürfen in PURE-Prozeduren nicht auftreten"
 
-#: fortran/parse.c:705
+#: fortran/parse.c:707
 #, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable OpenACC directive at %C"
 msgstr "Nicht klassifizierbare OpenACC-Anweisung bei %C"
 
-#: fortran/parse.c:831 fortran/parse.c:1040
+#: fortran/parse.c:835 fortran/parse.c:1044
 #, gcc-internal-format, gfc-internal-format
 msgid "OpenMP directives other than SIMD or DECLARE TARGET at %C may not appear in PURE or ELEMENTAL procedures"
 msgstr "OpenMP-Direktiven außer SIMD und DECLARE TARGET bei %C dürfen in PURE- oder ELEMENTAL-Prozeduren nicht auftreten"
 
-#: fortran/parse.c:1024
+#: fortran/parse.c:1028
 #, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable OpenMP directive at %C"
 msgstr "Nicht klassifizierbare OpenMP-Anweisung bei %C"
 
-#: fortran/parse.c:1076
+#: fortran/parse.c:1080
 #, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable GCC directive at %C"
 msgstr "Nicht klassifizierbare GCC-Anweisung bei %C"
 
-#: fortran/parse.c:1135 fortran/parse.c:1362
+#: fortran/parse.c:1139 fortran/parse.c:1366
 #, gcc-internal-format, gfc-internal-format
 msgid "Zero is not a valid statement label at %C"
 msgstr "Null ist keine gültige Anweisungsmarke bei %C"
 
-#: fortran/parse.c:1142 fortran/parse.c:1354
+#: fortran/parse.c:1146 fortran/parse.c:1358
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-numeric character in statement label at %C"
 msgstr "Nicht-numerisches Zeichen in Anweisungsmarke bei %C"
 
-#: fortran/parse.c:1154 fortran/parse.c:1403
+#: fortran/parse.c:1158 fortran/parse.c:1407
 #, gcc-internal-format, gfc-internal-format
 msgid "Semicolon at %C needs to be preceded by statement"
 msgstr "Semikolon bei %C muss Anweisung vorausgehen"
 
-#: fortran/parse.c:1161 fortran/parse.c:1418
+#: fortran/parse.c:1165 fortran/parse.c:1422
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label without statement at %L"
 msgstr "Anweisungsmarke in leerer Anweisung bei %L"
 
-#: fortran/parse.c:1224 fortran/parse.c:1405
+#: fortran/parse.c:1228 fortran/parse.c:1409
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Semicolon at %C without preceding statement"
 msgstr "Fortran 2008: Semikolon bei %C ohne vorausgehende Anweisung"
 
-#: fortran/parse.c:1247 fortran/parse.c:1381
+#: fortran/parse.c:1251 fortran/parse.c:1385
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad continuation line at %C"
 msgstr "Falsche Fortsetzungszeile bei %C"
 
-#: fortran/parse.c:1679
+#: fortran/parse.c:1683
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT statement at %L does not have a statement label"
 msgstr "FORMAT-Anweisung bei %L hat keine Anweisungsmarke"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/parse.c:2435
+#: fortran/parse.c:2439
 #, gcc-internal-format
 msgid "gfc_ascii_statement(): Bad statement code"
 msgstr "gfc_ascii_statement(): Bad statement code"
 
-#: fortran/parse.c:2577
+#: fortran/parse.c:2581
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement at %C"
 msgstr "Unerwartete Anweisung %s bei %C"
 
-#: fortran/parse.c:2732
+#: fortran/parse.c:2736
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot follow %s statement at %L"
 msgstr "Anweisung %s bei %C kann nicht auf Anweisung %s bei %L folgen"
 
-#: fortran/parse.c:2749
+#: fortran/parse.c:2753
 #, gcc-internal-format
 msgid "Unexpected end of file in %qs"
 msgstr "Unerwartetes Dateiende in %qs"
 
-#: fortran/parse.c:2784
+#: fortran/parse.c:2788
 #, gcc-internal-format
 msgid "Derived-type %qs with SEQUENCE must not have a CONTAINS section at %C"
 msgstr "Abgeleiteter Typ %qs bei %C mit SEQUENCE darf keinen CONTAINS-Abschnitt haben"
 
-#: fortran/parse.c:2787
+#: fortran/parse.c:2791
 #, gcc-internal-format
 msgid "Derived-type %qs with BIND(C) must not have a CONTAINS section at %C"
 msgstr "Abgeleiteter Typ %qs bei %C mit BIND(C) darf keinen CONTAINS-Abschnitt haben"
 
-#: fortran/parse.c:2807
+#: fortran/parse.c:2811
 #, gcc-internal-format, gfc-internal-format
 msgid "Components in TYPE at %C must precede CONTAINS"
 msgstr "Komponenten in TYPE bei %C müssen CONTAINS vorausgehen"
 
-#: fortran/parse.c:2811
+#: fortran/parse.c:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound procedure at %C"
 msgstr "Typgebundene Prozedur bei %C"
 
-#: fortran/parse.c:2819
+#: fortran/parse.c:2823
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC binding at %C"
 msgstr "GENERIC-Bindung bei %C"
 
-#: fortran/parse.c:2827
+#: fortran/parse.c:2831
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure declaration at %C"
 msgstr "FINAL-Prozedurdeklaration bei %C"
 
-#: fortran/parse.c:2839
+#: fortran/parse.c:2843
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type definition at %C with empty CONTAINS section"
 msgstr "Definition eines abgeleiteten Typs bei %C mit leerem CONTAINS-Abschnitt"
 
-#: fortran/parse.c:2849 fortran/parse.c:3304
+#: fortran/parse.c:2853 fortran/parse.c:3308
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement in TYPE at %C must be inside a MODULE"
 msgstr "PRIVATE-Anweisung in TYPE bei %C muss innerhalb eines MODULEs sein"
 
-#: fortran/parse.c:2856
+#: fortran/parse.c:2860
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede procedure bindings"
 msgstr "PRIVATE-Anweisung bei %C muss Prozedurbindungen vorausgehen"
 
-#: fortran/parse.c:2863 fortran/parse.c:3317
+#: fortran/parse.c:2867 fortran/parse.c:3321
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PRIVATE statement at %C"
 msgstr "Doppelte PRIVATE-Anweisung bei %C"
 
-#: fortran/parse.c:2873
+#: fortran/parse.c:2877
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede CONTAINS"
 msgstr "SEQUENCE-Anweisung bei %C muss CONTAINS vorausgehen"
 
-#: fortran/parse.c:2877
+#: fortran/parse.c:2881
 #, gcc-internal-format, gfc-internal-format
 msgid "Already inside a CONTAINS block at %C"
 msgstr "Bereits in CONTAINS-Block bei %C"
 
-#: fortran/parse.c:2996
+#: fortran/parse.c:3000
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s at %L of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray, which is not possible as the component has the pointer attribute"
 msgstr "Komponente %s bei %L des Typs LOCK_TYPE muss eine Kodimension haben oder eine Subkomponente eines Koarrays sein, was wegen des Zeigerattributs der Komponente nicht möglich ist"
 
-#: fortran/parse.c:3002
+#: fortran/parse.c:3006
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer component %s at %L has a noncoarray subcomponent of type LOCK_TYPE, which must have a codimension or be a subcomponent of a coarray"
 msgstr "Zeigerkomponente %s bei %L hat eine Subkomponente als Nicht-Koarray des Type LOCK_TYPE, die eine Kodimension haben muss oder eine Subkomponente eines Koarrays sein muss"
 
-#: fortran/parse.c:3007
+#: fortran/parse.c:3011
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L of type LOCK_TYPE must have a codimension"
 msgstr "Allozierbare Komponente %s bei %L des Typs LOCK_TYPE muss eine Kodimension haben"
 
-#: fortran/parse.c:3011
+#: fortran/parse.c:3015
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L must have a codimension as it has a noncoarray subcomponent of type LOCK_TYPE"
 msgstr "Allozierbare Komponente %s bei %L muss eine Kodimension haben, da es eine Subkomponente als Nicht-Koarray des Typs LOCK_TYPE hat"
 
-#: fortran/parse.c:3016
+#: fortran/parse.c:3020
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as already a coarray subcomponent exists)"
 msgstr "Nicht-Koarray-Komponente %s bei %L des Typs LOCK_TYPE oder mit Subkomponente des Typs LOCK_TYPE muss eine Kodimension haben oder die Subkomponente eines Koarrays sein. (Variablen des Typs %s dürfen keine Kodimension haben, da es bereits eine Koarray-Subkomponente gibt.)"
 
-#: fortran/parse.c:3023
+#: fortran/parse.c:3027
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as %s at %L has a codimension or a coarray subcomponent)"
 msgstr "Nicht-Koarray-Komponente %s bei %L des Typs LOCK_TYPE oder mit Subkomponente des Typs LOCK_TYPE muss eine Kodimension haben oder die Subkomponente eines Koarrays sein. (Variablen des Typs %s dürfen keine Kodimension haben, da %s bei %L eine Kodimension oder Koarray-Subkomponente hat.)"
 
-#: fortran/parse.c:3033
+#: fortran/parse.c:3037
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s at %L of type EVENT_TYPE must have a codimension or be a subcomponent of a coarray, which is not possible as the component has the pointer attribute"
 msgstr "Komponente %s bei %L des Typs EVENT_TYPE muss eine Kodimension haben oder eine Subkomponente eines Koarrays sein, was wegen des Zeigerattributs der Komponente nicht möglich ist"
 
-#: fortran/parse.c:3039
+#: fortran/parse.c:3043
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer component %s at %L has a noncoarray subcomponent of type EVENT_TYPE, which must have a codimension or be a subcomponent of a coarray"
 msgstr "Zeigerkomponente %s bei %L hat eine Subkomponente als Nicht-Koarray des Type EVENT_TYPE, die eine Kodimension haben muss oder eine Subkomponente eines Koarrays sein muss"
 
-#: fortran/parse.c:3044
+#: fortran/parse.c:3048
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L of type EVENT_TYPE must have a codimension"
 msgstr "Allozierbare Komponente %s bei %L des Typs EVENT_TYPE muss eine Kodimension haben"
 
-#: fortran/parse.c:3048
+#: fortran/parse.c:3052
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L must have a codimension as it has a noncoarray subcomponent of type EVENT_TYPE"
 msgstr "Allozierbare Komponente %s bei %L muss eine Kodimension haben, da sie eine Subkomponente als Nicht-Koarray des Typs EVENT_TYPE hat"
 
-#: fortran/parse.c:3053
+#: fortran/parse.c:3057
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as already a coarray subcomponent exists)"
 msgstr "Nicht-Koarray-Komponente %s bei %L des Typs EVENT_TYPE oder mit Subkomponente des Typs EVENT_TYPE muss eine Kodimension haben oder die Subkomponente eines Koarrays sein. (Variablen des Typs %s dürfen keine Kodimension haben, da es bereits eine Koarray-Subkomponente gibt.)"
 
-#: fortran/parse.c:3060
+#: fortran/parse.c:3064
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as %s at %L has a codimension or a coarray subcomponent)"
 msgstr "Nicht-Koarray-Komponente %s bei %L des Typs EVENT_TYPE oder mit Subkomponente des Typs EVENT_TYPE muss eine Kodimension haben oder die Subkomponente eines Koarrays sein. (Variablen des Typs %s dürfen keine Kodimension haben, da %s bei %L eine Kodimension oder Koarray-Subkomponente hat.)"
 
-#: fortran/parse.c:3112
+#: fortran/parse.c:3116
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to create map component '%s'"
 msgstr "failed to create map component '%s'"
 
-#: fortran/parse.c:3145
+#: fortran/parse.c:3149
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to create union component '%s'"
 msgstr "failed to create union component '%s'"
 
-#: fortran/parse.c:3200
+#: fortran/parse.c:3204
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in nested structure declaration at %C"
 msgstr "Syntaxfehler in geschachtelter Struktur-Deklaration bei %C"
 
-#: fortran/parse.c:3287
+#: fortran/parse.c:3291
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside CONTAINS"
 msgstr "FINAL-Deklaration bei %C muss innerhalb von CONTAINS sein"
 
-#: fortran/parse.c:3295
+#: fortran/parse.c:3299
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type definition at %C without components"
 msgstr "Definition des abgeleiteten Typs bei %C ohne Komponenten"
 
-#: fortran/parse.c:3311
+#: fortran/parse.c:3315
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede structure components"
 msgstr "PRIVATE-Anweisung bei %C muss Strukturkomponenten vorausgehen"
 
-#: fortran/parse.c:3328
+#: fortran/parse.c:3332
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede structure components"
 msgstr "SEQUENCE-Anweisung bei %C muss Strukturkomponenten vorausgehen"
 
-#: fortran/parse.c:3334
+#: fortran/parse.c:3338
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE attribute at %C already specified in TYPE statement"
 msgstr "SEQUENCE-Attribut bei %C bereits in TYPE-Anweisung angegeben"
 
-#: fortran/parse.c:3339
+#: fortran/parse.c:3343
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SEQUENCE statement at %C"
 msgstr "Doppelte SEQUENCE-Anweisung bei %C"
 
-#: fortran/parse.c:3349
+#: fortran/parse.c:3353
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS block in derived type definition at %C"
 msgstr "CONTAINS-Block in Definition des abgeleiteten Typs bei %C"
 
-#: fortran/parse.c:3407
+#: fortran/parse.c:3411
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM declaration at %C has no ENUMERATORS"
 msgstr "ENUM-Deklaration bei %C hat keine ENUMERATORen"
 
-#: fortran/parse.c:3494
+#: fortran/parse.c:3498
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in INTERFACE block at %C"
 msgstr "Unerwartete Anweisung %s in INTERFACE-Block bei %C"
 
-#: fortran/parse.c:3518
+#: fortran/parse.c:3522
 #, gcc-internal-format
 msgid "Name %qs of ABSTRACT INTERFACE at %C cannot be the same as an intrinsic type"
 msgstr "Name %qs des ABSTRACT INTERFACE bei %C kann nicht der gleiche wie ein intrinsischer Typ sein"
 
-#: fortran/parse.c:3552
+#: fortran/parse.c:3556
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement at %C in INTERFACE body"
 msgstr "Unerwartete Anweisung %s bei %C in INTERFACE-Körper"
 
-#: fortran/parse.c:3570
+#: fortran/parse.c:3574
 #, gcc-internal-format
 msgid "INTERFACE procedure %qs at %L has the same name as the enclosing procedure"
 msgstr "INTERFACE-Prozedur %qs bei %L hat denselben Namen wie die umgebende Prozedur"
 
-#: fortran/parse.c:3700
+#: fortran/parse.c:3704
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement is not allowed inside of BLOCK at %C"
 msgstr "%s-Anweisung ist innerhalb eines BLOCKs bei %C nicht erlaubt"
 
-#: fortran/parse.c:3732
+#: fortran/parse.c:3736
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement is not allowed inside of BLOCK DATA at %C"
 msgstr "%s-Anweisung ist innerhalb von BLOCK DATA bei %C nicht erlaubt"
 
-#: fortran/parse.c:3822
+#: fortran/parse.c:3826
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement must appear in a MODULE"
 msgstr "Anweisung %s muss in einem MODULE auftreten"
 
-#: fortran/parse.c:3830
+#: fortran/parse.c:3834
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C follows another accessibility specification"
 msgstr "Anweisung %s bei %C folgt einer anderen Zugriffsspezifikation"
 
-#: fortran/parse.c:3882
+#: fortran/parse.c:3886
 #, gcc-internal-format
 msgid "Bad kind expression for function %qs at %L"
 msgstr "Falscher Art-Ausdruck für Funktion %qs bei %L"
 
-#: fortran/parse.c:3886
+#: fortran/parse.c:3890
 #, gcc-internal-format
 msgid "The type for function %qs at %L is not accessible"
 msgstr "Der Typ für Funktion %qs bei %L ist nicht zugreifbar"
 
-#: fortran/parse.c:3946
+#: fortran/parse.c:3950
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C follows previous unmasked ELSEWHERE"
 msgstr "Anweisung ELSEWHERE bei %C folgt zuvor unmaskiertem ELSEWHERE"
 
-#: fortran/parse.c:3968
+#: fortran/parse.c:3972
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in WHERE block at %C"
 msgstr "Unerwartete Anweisung %s in WHERE-Block bei %C"
 
-#: fortran/parse.c:4027
+#: fortran/parse.c:4031
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in FORALL block at %C"
 msgstr "Unerwartete Anweisung %s in FORALL-Block bei %C"
 
-#: fortran/parse.c:4078
+#: fortran/parse.c:4082
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSE IF statement at %C cannot follow ELSE statement at %L"
 msgstr "ELSE-IF-Anweisung bei %C kann nicht auf eine ELSE-Anweisung bei %L folgen"
 
-#: fortran/parse.c:4096
+#: fortran/parse.c:4100
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ELSE statements at %L and %C"
 msgstr "Doppelte ELSE-Anweisungen bei %L und %C"
 
-#: fortran/parse.c:4157
+#: fortran/parse.c:4161
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected a CASE or END SELECT statement following SELECT CASE at %C"
 msgstr "CASE- oder END-SELECT-Anweisung hinter SELECT CASE bei %C erwartet"
 
-#: fortran/parse.c:4241
+#: fortran/parse.c:4245
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected TYPE IS, CLASS IS or END SELECT statement following SELECT TYPE at %C"
 msgstr "TYPE IS-, CLASS IS- oder END SELECT-Anweisung hinter SELECT TYPE bei %C erwartet"
 
-#: fortran/parse.c:4303
+#: fortran/parse.c:4307
 #, gcc-internal-format
 msgid "Variable %qs at %C cannot be redefined inside loop beginning at %L"
 msgstr "Variable %qs bei %C kann nicht innerhalb der bei %L beginnenden Schleife redefiniert werden"
 
-#: fortran/parse.c:4336
+#: fortran/parse.c:4340
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is within another block"
 msgstr "Ende der DO-Anweisung ohne Block bei %C ist innerhalb eines anderen Blockes"
 
-#: fortran/parse.c:4346
+#: fortran/parse.c:4350
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is interwoven with another DO loop"
 msgstr "Ende der DO-Anweisung bei %C ist mit anderer DO-Schleife verwoben"
 
-#: fortran/parse.c:4372
+#: fortran/parse.c:4376
 #, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL block inside of OpenACC region at %C"
 msgstr "CRITICAL-Block innerhalb von OpenACC-Region bei %C"
 
-#: fortran/parse.c:4373
+#: fortran/parse.c:4377
 #, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL block inside of OpenMP region at %C"
 msgstr "CRITICAL-Block innerhalb von OpenMP-Region bei %C"
 
-#: fortran/parse.c:4399
+#: fortran/parse.c:4403
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label in END CRITICAL at %C does not match CRITICAL label"
 msgstr "Anweisungsmarke in END CRITICAL bei %C passt nicht zur CRITICAL-Marke"
 
-#: fortran/parse.c:4468
+#: fortran/parse.c:4472
 #, gcc-internal-format, gfc-internal-format
 msgid "BLOCK construct at %C"
 msgstr "BLOCK-Konstrukt bei %C"
 
-#: fortran/parse.c:4502
+#: fortran/parse.c:4506
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSOCIATE construct at %C"
 msgstr "ASSOCIATE-Konstrukt bei %C"
 
-#: fortran/parse.c:4690
+#: fortran/parse.c:4694
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label in ENDDO at %C doesn't match DO label"
 msgstr "Anweisungsmarke in ENDDO bei %C passt nicht zum DO-Label"
 
-#: fortran/parse.c:4706
+#: fortran/parse.c:4710
 #, gcc-internal-format, gfc-internal-format
 msgid "Named block DO at %L requires matching ENDDO name"
 msgstr "Benanntes Block-DO bei %L erfordert passenden ENDDO-Namen"
 
-#: fortran/parse.c:4897
+#: fortran/parse.c:4901
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing !$OMP END ATOMIC after !$OMP ATOMIC CAPTURE at %C"
 msgstr "!$OMP END ATOMIC fehlt hinter !$OMP ATOMIC CAPTURE bei %C"
 
-#: fortran/parse.c:4913 fortran/parse.c:4972
+#: fortran/parse.c:4917 fortran/parse.c:4976
 #, gcc-internal-format, gfc-internal-format
 msgid "OpenACC directive inside of CRITICAL block at %C"
 msgstr "OpenACC-Direktive innerhalb von CRITICAL-Block bei %C"
 
-#: fortran/parse.c:4947
+#: fortran/parse.c:4951
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s at %C"
 msgstr "%s bei %C erwartet"
 
-#: fortran/parse.c:4991
+#: fortran/parse.c:4995
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected DO loop at %C"
 msgstr "DO-Schleife bei %C erwartet"
 
-#: fortran/parse.c:5011
+#: fortran/parse.c:5015
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant !$ACC END LOOP at %C"
 msgstr "Redundantes !$ACC END LOOP bei %C"
 
-#: fortran/parse.c:5225
+#: fortran/parse.c:5229
 #, gcc-internal-format, gfc-internal-format
 msgid "Name after !$omp critical and !$omp end critical does not match at %C"
 msgstr "Name hinter »!$omp critical« und »!$omp end critical« passt nicht bei %C"
 
-#: fortran/parse.c:5283
+#: fortran/parse.c:5287
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot terminate a non-block DO loop"
 msgstr "Anweisung %s bei %C kann keine DO-Schleife ohne Block beenden"
 
-#: fortran/parse.c:5297
+#: fortran/parse.c:5301
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %C after the first executable statement"
 msgstr "DATA-Anweisung bei %C hinter der ersten ausführbaren Anweisung"
 
-#: fortran/parse.c:5423
+#: fortran/parse.c:5427
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive does not commence a loop at %C"
 msgstr "Die Direktive %<GCC unroll%> bei %C darf nur direkt vor einem Schleifenbeginn stehen"
 
-#: fortran/parse.c:5538
+#: fortran/parse.c:5542
 #, gcc-internal-format
 msgid "Contained procedure %qs at %C is already ambiguous"
 msgstr "Enthaltene Prozedur %qs bei %C ist bereits mehrdeutig"
 
-#: fortran/parse.c:5595
+#: fortran/parse.c:5599
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in CONTAINS section at %C"
 msgstr "Unerwartete Anweisung %s in CONTAINS-Abschnitt bei %C"
 
-#: fortran/parse.c:5620
+#: fortran/parse.c:5624
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS statement without FUNCTION or SUBROUTINE statement at %L"
 msgstr "CONTAINS-Anweisung ohne FUNCTION- oder SUBROUTINE-Anweisung bei %L"
 
-#: fortran/parse.c:5732
+#: fortran/parse.c:5736
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS statement at %C is already in a contained program unit"
 msgstr "CONTAINS-Anweisung bei %C ist bereits in einer enthaltenen Programmeinheit"
 
-#: fortran/parse.c:5784
+#: fortran/parse.c:5788
 #, gcc-internal-format
 msgid "Global binding name %qs at %L is already being used as a %s at %L"
 msgstr "Globaler Bindungs-Name %qs bei %L wird bereits als ein %s bei %L verwendet"
 
-#: fortran/parse.c:5788
+#: fortran/parse.c:5792
 #, gcc-internal-format
 msgid "Global name %qs at %L is already being used as a %s at %L"
 msgstr "Globaler Name %qs bei %L wird bereits als ein %s bei %L verwendet"
 
-#: fortran/parse.c:5794
+#: fortran/parse.c:5798
 #, gcc-internal-format
 msgid "Global binding name %qs at %L is already being used at %L"
 msgstr "Globaler Bindungs-Name %qs bei %L wird bereits bei %L verwendet"
 
-#: fortran/parse.c:5797
+#: fortran/parse.c:5801
 #, gcc-internal-format
 msgid "Global name %qs at %L is already being used at %L"
 msgstr "Globaler Name %qs bei %L wird bereits bei %L verwendet"
 
-#: fortran/parse.c:5819
+#: fortran/parse.c:5823
 #, gcc-internal-format, gfc-internal-format
 msgid "Blank BLOCK DATA at %C conflicts with prior BLOCK DATA at %L"
 msgstr "Leeres BLOCK DATA bei %C steht in Konflikt mit vorherigem BLOCK DATA bei %L"
 
-#: fortran/parse.c:5845
+#: fortran/parse.c:5849
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in BLOCK DATA at %C"
 msgstr "Unerwartete Anweisung %s in BLOCK DATA bei %C"
 
-#: fortran/parse.c:5949
+#: fortran/parse.c:5953
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in MODULE at %C"
 msgstr "Unerwartete Anweisung %s in MODULE bei %C"
@@ -57801,7 +57878,7 @@
 #. If we see a duplicate main program, shut down.  If the second
 #. instance is an implied main program, i.e. data decls or executable
 #. statements, we're in for lots of errors.
-#: fortran/parse.c:6333
+#: fortran/parse.c:6337
 #, gcc-internal-format, gfc-internal-format
 msgid "Two main PROGRAMs at %L and %C"
 msgstr "Zwei Haupt-PROGRAMme bei %L und %C"
@@ -58557,7 +58634,7 @@
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr "Nicht-RECURSIVE Prozedur %qs bei %L ruft sich möglicherweise rekursiv selbst auf. Sollte als RECURSIVE oder mit »-frecursive« verwendet werden"
 
-#: fortran/resolve.c:1893 fortran/resolve.c:9560 fortran/resolve.c:11225
+#: fortran/resolve.c:1893 fortran/resolve.c:9573 fortran/resolve.c:11245
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "Marke %d wird bei %L referenziert, aber nirgendwo definiert"
@@ -58667,7 +58744,7 @@
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "Funktion %qs bei %L hat keinen IMPLICIT-Typ; meinen Sie %qs?"
 
-#: fortran/resolve.c:2905 fortran/resolve.c:16283
+#: fortran/resolve.c:2905 fortran/resolve.c:16310
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr "Funktion %qs bei %L hat keinen IMPLICIT-Typ"
@@ -58792,204 +58869,204 @@
 msgstr "logical_to_bitwise(): Bad intrinsic"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/resolve.c:4059
+#: fortran/resolve.c:4065
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr "resolve_operator(): Bad intrinsic"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/resolve.c:4229 fortran/resolve.c:4252
+#: fortran/resolve.c:4235 fortran/resolve.c:4258
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr "compare_bound_int(): Bad expression"
 
-#: fortran/resolve.c:4347
+#: fortran/resolve.c:4353
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Feldreferenz bei %L ist außerhalb der Schranken (%ld < %ld) in Dimension %d"
 
-#: fortran/resolve.c:4352
+#: fortran/resolve.c:4358
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr "Feldreferenz bei %L ist außerhalb der Grenzen (%ld < %ld) in Kodimension %d"
 
-#: fortran/resolve.c:4362
+#: fortran/resolve.c:4368
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Feldreferenz bei %L ist außerhalb der Schranken (%ld > %ld) in Dimension %d"
 
-#: fortran/resolve.c:4367
+#: fortran/resolve.c:4373
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr "Feldreferenz bei %L ist außerhalb der Grenzen (%ld > %ld) in Kodimension %d"
 
-#: fortran/resolve.c:4387
+#: fortran/resolve.c:4393
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr "Unzulässiger Schritt von Null bei %L"
 
-#: fortran/resolve.c:4404
+#: fortran/resolve.c:4410
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Untere Feldreferenz bei %L ist außerhalb der Schranken (%ld < %ld) in Dimension %d"
 
-#: fortran/resolve.c:4412
+#: fortran/resolve.c:4418
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Untere Feldreferenz bei %L ist außerhalb der Schranken (%ld > %ld) in Dimension %d"
 
-#: fortran/resolve.c:4428
+#: fortran/resolve.c:4434
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Obere Feldreferenz bei %L ist außerhalb der Schranken (%ld < %ld) in Dimension %d"
 
-#: fortran/resolve.c:4437
+#: fortran/resolve.c:4443
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Obere Feldreferenz bei %L ist außerhalb der Schranken (%ld > %ld) in Dimension %d"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/resolve.c:4453
+#: fortran/resolve.c:4459
 #, gcc-internal-format
 msgid "check_dimension(): Bad array reference"
 msgstr "check_dimension(): Bad array reference"
 
-#: fortran/resolve.c:4476
+#: fortran/resolve.c:4482
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr "Rechte obere Schranke des Feldabschnitts angenommener Größe nicht angegeben bei %L"
 
-#: fortran/resolve.c:4486
+#: fortran/resolve.c:4492
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr "Unpassende Ränge in Feldreferenz bei %L (%d/%d)"
 
-#: fortran/resolve.c:4494
+#: fortran/resolve.c:4500
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr "Unpassende Ränge des Koindex in Feldreferenz bei %L (%d/%d)"
 
-#: fortran/resolve.c:4510
+#: fortran/resolve.c:4516
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr "Koindex der Kodimension %d muss bei %L ein Skalar sein"
 
-#: fortran/resolve.c:4538
+#: fortran/resolve.c:4544
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr "Feldindex bei %L muss skalar sein"
 
-#: fortran/resolve.c:4544
+#: fortran/resolve.c:4550
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr "Feldindex bei %L muss INTEGER-Typ haben, %s gefunden"
 
-#: fortran/resolve.c:4550
+#: fortran/resolve.c:4556
 #, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr "REAL-Feld-Index bei %L"
 
-#: fortran/resolve.c:4589
+#: fortran/resolve.c:4595
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr "Argument dim bei %L muss skalar sein"
 
-#: fortran/resolve.c:4596
+#: fortran/resolve.c:4602
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr "Argument dim bei %L muss INTEGER-Typ haben"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/resolve.c:4641
+#: fortran/resolve.c:4647
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr "find_array_spec(): Missing spec"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/resolve.c:4652
+#: fortran/resolve.c:4658
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr "find_array_spec(): unused as(1)"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/resolve.c:4663
+#: fortran/resolve.c:4669
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr "find_array_spec(): unused as(2)"
 
-#: fortran/resolve.c:4706
+#: fortran/resolve.c:4712
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr "Feldindex bei %L ist ein Feld mit Rang %d"
 
-#: fortran/resolve.c:4804
+#: fortran/resolve.c:4810
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr "Anfangs-Index der Teilzeichenkette bei %L muss INTEGER-Typ haben"
 
-#: fortran/resolve.c:4811
+#: fortran/resolve.c:4817
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr "Anfangs-Index der Teilzeichenkette bei %L muss skalar sein"
 
-#: fortran/resolve.c:4820
+#: fortran/resolve.c:4826
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr "Anfangs-Index der Teilzeichenkette bei %L ist kleiner als Eins"
 
-#: fortran/resolve.c:4833
+#: fortran/resolve.c:4839
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr "End-Index der Teilzeichenkette bei %L muss INTEGER-Typ haben"
 
-#: fortran/resolve.c:4840
+#: fortran/resolve.c:4846
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr "End-Index der Teilzeichenkette bei %L muss skalar sein"
 
-#: fortran/resolve.c:4850
+#: fortran/resolve.c:4856
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr "End-Index der Teilzeichenkette bei %L überschreitet Zeichenkettenlänge"
 
-#: fortran/resolve.c:4860
+#: fortran/resolve.c:4866
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr "End-Index der Teilzeichenkette bei %L ist zu groß"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/resolve.c:5013
+#: fortran/resolve.c:5019
 #, gcc-internal-format
 msgid "resolve_ref(): Bad array reference"
 msgstr "resolve_ref(): Bad array reference"
 
-#: fortran/resolve.c:5027
+#: fortran/resolve.c:5033
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr "Komponente rechts einer Teilreferenz mit Rang größer Null darf kein POINTER-Attribut bei %L haben"
 
-#: fortran/resolve.c:5037
+#: fortran/resolve.c:5043
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr "Komponente rechts einer Teilreferenz mit Rang ungleich Null darf bei %L kein Attribut ALLOCATABLE haben"
 
-#: fortran/resolve.c:5056
+#: fortran/resolve.c:5062
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr "Zwei oder mehr Teilreferenzen mit Rang größer Null dürfen nicht bei %L angegeben werden"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/resolve.c:5154
+#: fortran/resolve.c:5160
 #, gcc-internal-format
 msgid "expression_rank(): Two array specs"
 msgstr "expression_rank(): Two array specs"
 
-#: fortran/resolve.c:5236
+#: fortran/resolve.c:5242
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr "Variable %s bei %L mit NO_ARG_CHECK-Attribut kann nur als effektives Argument verwendet werden"
 
-#: fortran/resolve.c:5246
+#: fortran/resolve.c:5252
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr "Variable %s vermuteten Typs bei %L kann nur als effektives Argument verwendet werden"
@@ -58998,12 +59075,12 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5256
+#: fortran/resolve.c:5262
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr "Variable %s vermuteten Typs bei %L als effektives Argument für Abfragefunktion muss das erste Argument sein"
 
-#: fortran/resolve.c:5271
+#: fortran/resolve.c:5277
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr "Variable %s vermuteten Ranges bei %L kann nur als effektives Argument verwendet werden"
@@ -59012,269 +59089,269 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5281
+#: fortran/resolve.c:5287
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr "Variable %s vermuteten Ranges bei %L als effektives Argument für Abfragefunktion muss das erste Argument sein"
 
-#: fortran/resolve.c:5292
+#: fortran/resolve.c:5298
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr "Variable %s bei %L mit NO_ARG_CHECK-Attribut darf keine Referenz auf Subobjekt haben"
 
-#: fortran/resolve.c:5301
+#: fortran/resolve.c:5307
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr "Variable %s vermuteten Typs bei %L darf keine Referenz auf Subobjekt haben"
 
-#: fortran/resolve.c:5316
+#: fortran/resolve.c:5322
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr "Variable »%s« vermuteten Ranges bei %L darf keine Referenz auf Subobjekt haben"
 
-#: fortran/resolve.c:5478
+#: fortran/resolve.c:5484
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr "In Spezifikationsausdruck verwendete Variable %qs wird bei %L vor Anweisung ENTRY referenziert, in der sie ein Parameter ist"
 
-#: fortran/resolve.c:5483
+#: fortran/resolve.c:5489
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr "Variable %qs wird bei %L vor Anweisung ENTRY verwendet, in der sie ein Parameter ist"
 
-#: fortran/resolve.c:5553
+#: fortran/resolve.c:5559
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr "Polymorphes Subobjekt des koindizierten Objektes bei %L"
 
-#: fortran/resolve.c:5566
+#: fortran/resolve.c:5572
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr "Koindiziertes Objekt mit polymorpher reservierbarer Subkomponente bei %L"
 
-#: fortran/resolve.c:5919
+#: fortran/resolve.c:5925
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "Weitergegebenes Objekt bei %L muss Skalar sein"
 
-#: fortran/resolve.c:5926
+#: fortran/resolve.c:5932
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr "Basisobjekt für Aufruf der Prozedurzeigerkomponente bei %L hat ABSTRACT-Typ %qs"
 
-#: fortran/resolve.c:5961
+#: fortran/resolve.c:5967
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr "Basisobjekt für Aufruf der typgebundenen Prozedur bei %L hat ABSTRACT-Typ %qs"
 
-#: fortran/resolve.c:5970
+#: fortran/resolve.c:5976
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr "Basisobjekt für Aufruf der typgebundenen NOPASS-Prozedur bei %L muss skalar sein"
 
 #. Nothing matching found!
-#: fortran/resolve.c:6158
+#: fortran/resolve.c:6164
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr "Keine passende spezifische Bindung für Aufruf des GENERIC %qs bei %L gefunden"
 
-#: fortran/resolve.c:6185
+#: fortran/resolve.c:6191
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "%qs bei %L sollte eine SUBROUTINE sein"
 
-#: fortran/resolve.c:6236
+#: fortran/resolve.c:6242
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr "%qs bei %L sollte eine FUNCTION sein"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/resolve.c:6786
+#: fortran/resolve.c:6792
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "gfc_resolve_expr(): Bad expression type"
 
-#: fortran/resolve.c:6812
+#: fortran/resolve.c:6818
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s bei %L muss skalar sein"
 
-#: fortran/resolve.c:6822
+#: fortran/resolve.c:6828
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "%s bei %L muss ganzzahlig sein"
 
-#: fortran/resolve.c:6826 fortran/resolve.c:6833
+#: fortran/resolve.c:6832 fortran/resolve.c:6839
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s bei %L muss INTEGER sein"
 
-#: fortran/resolve.c:6875
+#: fortran/resolve.c:6881
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "Schrittausdruck in DO-Schleife bei %L kann nicht Null sein"
 
-#: fortran/resolve.c:6911
+#: fortran/resolve.c:6917
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr "DO-Schleife bei %L wird null mal ausgeführt"
 
-#: fortran/resolve.c:6928
+#: fortran/resolve.c:6934
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr "DO-Schleife bei %L ist undefiniert, da sie überläuft"
 
-#: fortran/resolve.c:6934
+#: fortran/resolve.c:6940
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr "DO-Schleife bei %L ist undefiniert, da sie unterläuft"
 
-#: fortran/resolve.c:6995
+#: fortran/resolve.c:7001
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "FORALL-Indexname bei %L muss skalarer INTEGER sein"
 
-#: fortran/resolve.c:7000
+#: fortran/resolve.c:7006
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "FORALL-Anfangsausdruck bei %L muss skalarer INTEGER sein"
 
-#: fortran/resolve.c:7007
+#: fortran/resolve.c:7013
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "FORALL-Endausdruck bei %L muss skalarer INTEGER sein"
 
-#: fortran/resolve.c:7015
+#: fortran/resolve.c:7021
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "FORALL-Schrittausdruck bei %L muss skalares %s sein"
 
-#: fortran/resolve.c:7020
+#: fortran/resolve.c:7026
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "FORALL-Schrittausdruck bei %L kann nicht Null sein"
 
-#: fortran/resolve.c:7033
+#: fortran/resolve.c:7039
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "FORALL-Index %qs kann nicht in Tripel-Spezifikation bei %L auftreten"
 
-#: fortran/resolve.c:7136 fortran/resolve.c:7428
+#: fortran/resolve.c:7142 fortran/resolve.c:7434
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "ALLOCATE-Objekt bei %L muss ALLOCATABLE oder ein POINTER sein"
 
-#: fortran/resolve.c:7144 fortran/resolve.c:7393
+#: fortran/resolve.c:7150 fortran/resolve.c:7399
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr "Koindiziertes reservierbares Objekt bei %L"
 
-#: fortran/resolve.c:7250
+#: fortran/resolve.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr "Quell-Ausdruck bei %L muss skalar sein oder den selben Rang wie das ALLOCATE-Objekt bei %L haben"
 
-#: fortran/resolve.c:7281
+#: fortran/resolve.c:7287
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr "Quell-Ausdruck bei %L und ALLOCATE-Objekt bei %L müssen dieselbe Form haben"
 
-#: fortran/resolve.c:7439
+#: fortran/resolve.c:7445
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr "Typ der Entität bei %L ist mit Quellausdruck bei %L typunverträglich"
 
-#: fortran/resolve.c:7451
+#: fortran/resolve.c:7457
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr "Das ALLOCATE-Objekt bei %L und der Quellausdruck bei %L müssen Typparameter der gleichen Art haben"
 
-#: fortran/resolve.c:7465
+#: fortran/resolve.c:7471
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr "Der Quellausdruck bei %L darf weder vom Typ LOCK_TYPE sein noch eine LOCK_TYPE-Komponente haben, wenn ALLOCATE-Objekt bei %L ein Koarray ist"
 
-#: fortran/resolve.c:7480
+#: fortran/resolve.c:7486
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr "Der Quellausdruck bei %L darf weder vom Typ EVENT_TYPE sein noch eine EVENT_TYPE-Komponente haben, wenn ALLOCATE-Objekt bei %L ein Koarray ist"
 
-#: fortran/resolve.c:7493
+#: fortran/resolve.c:7499
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr "Reservierung von %s mit ABSTRACT-Basistyp bei %L erfordert Typspezifikation oder Quellausdruck"
 
-#: fortran/resolve.c:7511
+#: fortran/resolve.c:7517
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr "Reservierung von %s bei %L mit Typspezifikation erfordert den selben Zeichenkettenlängenparameter wie in der Deklaration"
 
-#: fortran/resolve.c:7592 fortran/resolve.c:7607
+#: fortran/resolve.c:7598 fortran/resolve.c:7613
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "In ALLOCATE-Anweisung bei %L ist Feld-Spezifikation erforderlich"
 
-#: fortran/resolve.c:7599
+#: fortran/resolve.c:7605
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "Feldspezifikation oder feldwertiger SOURCE=-Ausdruck erforderlich in ALLOCATE-Anweisung bei %L"
 
-#: fortran/resolve.c:7622
+#: fortran/resolve.c:7628
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "Koarray-Spezifikation in ALLOCATE-Anweisung bei %L erforderlich"
 
-#: fortran/resolve.c:7649
+#: fortran/resolve.c:7655
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "Falsche Feldspezifikation in ALLOCATE-Anweisung bei %L"
 
-#: fortran/resolve.c:7668
+#: fortran/resolve.c:7674
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr "%qs darf nicht bei %L in einer Feldspezifikation in der gleichen ALLOCATE-Anweisung auftreten, wo es selbst alloziert wird"
 
-#: fortran/resolve.c:7683
+#: fortran/resolve.c:7689
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr "In Koindex-Spezifikation in ALLOCATE-Anweisung bei %L wird »*« erwartet"
 
-#: fortran/resolve.c:7694
+#: fortran/resolve.c:7700
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "Falsche Koarray-Spezifikation in ALLOCATE-Anweisung bei %L"
 
-#: fortran/resolve.c:7726
+#: fortran/resolve.c:7732
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "Stat-Variable bei %L muss skalare INTEGER-Variable sein"
 
-#: fortran/resolve.c:7749
+#: fortran/resolve.c:7755
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "Stat-Variable bei %L darf nicht %s innerhalb der gleichen %s-Anweisung sein"
 
-#: fortran/resolve.c:7760
+#: fortran/resolve.c:7766
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr "ERRMSG bei %L ist ohne STAT-Marke nutzlos"
 
-#: fortran/resolve.c:7771
+#: fortran/resolve.c:7782
 #, gcc-internal-format, gfc-internal-format
-msgid "Errmsg-variable at %L must be a scalar CHARACTER variable"
-msgstr "ERRMSG-Variable bei %L muss skalare CHARACTER-Variable sein"
+msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
+msgstr "»ERRMSG=«-Variable bei %L muss skalare Default-CHARACTER-Variable sein"
 
-#: fortran/resolve.c:7794
+#: fortran/resolve.c:7805
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr "ERRMSG-Variable bei %L darf nicht »%s« innerhalb der selben »%s«-Anweisung sein"
 
-#: fortran/resolve.c:7824
+#: fortran/resolve.c:7835
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr "ALLOCATE-Objekt bei %L tritt auch bei %L auf"
 
-#: fortran/resolve.c:7830 fortran/resolve.c:7836
+#: fortran/resolve.c:7841 fortran/resolve.c:7847
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr "ALLOCATE-Objekt bei %L ist Subobjekt des Objekts bei %L"
@@ -59283,232 +59360,232 @@
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8064
+#: fortran/resolve.c:8075
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "CASE-Marke bei %L überschneidet sich mit CASE-Marke bei %L"
 
-#: fortran/resolve.c:8115
+#: fortran/resolve.c:8126
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "Ausdruck in CASE-Anweisung bei %L muss Typ %s haben"
 
-#: fortran/resolve.c:8126
+#: fortran/resolve.c:8137
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "Ausdruck in CASE-Anweisung bei %L muss von der Art %d sein"
 
-#: fortran/resolve.c:8139
+#: fortran/resolve.c:8150
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "Ausdruck in CASE-Anweisung bei %L muss skalar sein"
 
-#: fortran/resolve.c:8185
+#: fortran/resolve.c:8196
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "Auswahlausdruck in berechneter GOTO-Anweisung bei %L muss ein skalarer Ganzzahlausdruck sein"
 
-#: fortran/resolve.c:8204
+#: fortran/resolve.c:8215
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "Argument der SELECT-Anweisung bei %L kann nicht %s sein"
 
-#: fortran/resolve.c:8214
+#: fortran/resolve.c:8225
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "Argument der SELECT-Anweisung bei %L muss ein skalarer Ausdruck sein"
 
-#: fortran/resolve.c:8232 fortran/resolve.c:8240
+#: fortran/resolve.c:8243 fortran/resolve.c:8251
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "Ausdruck in CASE-Anweisung bei %L ist nicht im Bereich von %s"
 
-#: fortran/resolve.c:8302 fortran/resolve.c:8873
+#: fortran/resolve.c:8313 fortran/resolve.c:8884
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "Der DEFAULT CASE bei %L kann nicht von zweitem DEFAULT CASE bei %L gefolgt werden"
 
-#: fortran/resolve.c:8328
+#: fortran/resolve.c:8339
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "Logischer Bereich in CASE-Anweisung bei %L ist nicht erlaubt"
 
-#: fortran/resolve.c:8340
+#: fortran/resolve.c:8351
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "Konstanter logischer Wert in CASE-Anweisung wird bei %L wiederholt"
 
-#: fortran/resolve.c:8355
+#: fortran/resolve.c:8366
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "Bereichsspezifikation bei %L kann nie passen"
 
-#: fortran/resolve.c:8458
+#: fortran/resolve.c:8469
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "Logischer SELECT CASE Block bei %L hat mehr als zwei Fälle"
 
-#: fortran/resolve.c:8518
+#: fortran/resolve.c:8529
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr "Selektor bei %L darf nicht NULL() sein"
 
-#: fortran/resolve.c:8523
+#: fortran/resolve.c:8534
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr "Selektor bei %L hat keinen Typ"
 
-#: fortran/resolve.c:8545
+#: fortran/resolve.c:8556
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr "Zugeordneter Name %qs bei %L wird als Feld verwendet"
 
-#: fortran/resolve.c:8556
+#: fortran/resolve.c:8567
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr "CLASS-Selektor bei %L erfordert Zwischenspeicher, was noch nicht implementiert ist"
 
-#: fortran/resolve.c:8763
+#: fortran/resolve.c:8774
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "Selektor muss in SELECT TYPE-Anweisung bei %L polymorph sein"
 
-#: fortran/resolve.c:8783 fortran/resolve.c:8795
+#: fortran/resolve.c:8794 fortran/resolve.c:8806
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr "Selektor bei %L darf nicht koindiziert sein"
 
-#: fortran/resolve.c:8824
+#: fortran/resolve.c:8835
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "TYPE IS bei %L überlappt sich mit TYPE IS bei %L"
 
-#: fortran/resolve.c:8836
+#: fortran/resolve.c:8847
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr "Abgeleiteter Typ %qs bei %L muss erweiterbar sein"
 
-#: fortran/resolve.c:8848
+#: fortran/resolve.c:8859
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "Abgeleiteter Typ %qs bei %L muss eine Erweiterung von %qs sein"
 
-#: fortran/resolve.c:8851
+#: fortran/resolve.c:8862
 #, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "Unerwarteter intrinsischer Typ %qs bei %L"
 
-#: fortran/resolve.c:8861
+#: fortran/resolve.c:8872
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr "Die Typspezifikation bei %L muss angeben, dass jeder Parameter mit Längentyp vermutet ist"
 
-#: fortran/resolve.c:9108
+#: fortran/resolve.c:9119
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr "Doppelter CLASS IS-Block in SELECT TYPE-Anweisung bei %L"
 
-#: fortran/resolve.c:9204
+#: fortran/resolve.c:9215
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "Ungültiger Kontext für NULL()-Zeiger bei %L"
 
-#: fortran/resolve.c:9257
+#: fortran/resolve.c:9268
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "DTIO-%s-Prozedur bei %L muss rekursiv sein"
 
-#: fortran/resolve.c:9267
+#: fortran/resolve.c:9278
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr "Element zum Datenaustausch bei %L kann nicht polymorph sein, außer es wird von einer definierten E/A-Prozedur verarbeitet"
 
-#: fortran/resolve.c:9280
+#: fortran/resolve.c:9291
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "Datenübertragungselement bei %L kann keine POINTER-Komponenten haben, außer es wird von einer definierten E/A-Prozedur verarbeitet"
 
-#: fortran/resolve.c:9289
+#: fortran/resolve.c:9300
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "Datenübertragungselement bei %L kann keine Prozedurzeiger-Komponenten haben"
 
-#: fortran/resolve.c:9296
+#: fortran/resolve.c:9307
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "Datenübertragungselement bei %L kann keine ALLOCATABLE-Komponenten haben, außer es wird von einer definierten E/A-Prozedur verarbeitet"
 
-#: fortran/resolve.c:9307
+#: fortran/resolve.c:9318
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "Datenübertragungselement bei %L kann keine PRIVATE-Komponenten haben"
 
-#: fortran/resolve.c:9313
+#: fortran/resolve.c:9324
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr "Datenübertragungselement bei %L kann keine PRIVATE-Komponenten haben, außer es wird von einer definierten E/A-Prozedur verarbeitet"
 
-#: fortran/resolve.c:9328
+#: fortran/resolve.c:9339
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "Datenübertragungselement bei %L kann keine vollständige Referenz auf Feld vermuteter Größe sein"
 
-#: fortran/resolve.c:9388
+#: fortran/resolve.c:9399
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "Lock-Variable bei %L muss Skalar mit LOCK_TYPE sein"
 
-#: fortran/resolve.c:9398
+#: fortran/resolve.c:9409
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr "Ereignis-Variable bei %L muss Skalar mit EVENT_TYPE sein"
 
-#: fortran/resolve.c:9402
+#: fortran/resolve.c:9413
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "Argument für Ereignisvariable bei %L muss ein Koarray oder koindiziert sein"
 
-#: fortran/resolve.c:9405
+#: fortran/resolve.c:9416
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "Argument für Ereignisvariable bei %L muss ein Koarray, aber nicht koindiziert sein"
 
-#: fortran/resolve.c:9412 fortran/resolve.c:9533
+#: fortran/resolve.c:9423 fortran/resolve.c:9545
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "»STAT=«-Argument bei %L muss skalare INTEGER-Variable sein"
 
-#: fortran/resolve.c:9424 fortran/resolve.c:9540
+#: fortran/resolve.c:9435 fortran/resolve.c:9553
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "»ERRMSG=«-Argument bei %L muss skalare CHARACTER-Variable sein"
 
-#: fortran/resolve.c:9436
+#: fortran/resolve.c:9447
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "»ACQUIRED_LOCK=«-Argument bei %L muss skalare LOGICAL-Variable sein"
 
-#: fortran/resolve.c:9449
+#: fortran/resolve.c:9460
 #, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "Argument UNTIL_COUNT= bei %L muss ein skalarer INTEGER-Ausdruck sein"
 
-#: fortran/resolve.c:9510
+#: fortran/resolve.c:9521
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "Argument für Imageset bei %L muss Skalar oder Rang-1-INTEGER-Ausdruck sein"
 
-#: fortran/resolve.c:9514 fortran/resolve.c:9524
+#: fortran/resolve.c:9525 fortran/resolve.c:9535
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "Argument für Imageset bei %L muss zwischen 1 und num_images() liegen"
 
-#: fortran/resolve.c:9567
+#: fortran/resolve.c:9580
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "Anweisung bei %L ist keine gültige Sprungzielanweisung für Sprungziel bei %L"
 
-#: fortran/resolve.c:9577
+#: fortran/resolve.c:9590
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr "Sprung bei %L könnte Endlosschleife bewirken"
@@ -59515,12 +59592,12 @@
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:9594 fortran/resolve.c:9617
+#: fortran/resolve.c:9607 fortran/resolve.c:9630
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr "GOTO-Anweisung bei %L hinterlässt CRITICAL-Konstrukt für Marke bei %L"
 
-#: fortran/resolve.c:9598 fortran/resolve.c:9623
+#: fortran/resolve.c:9611 fortran/resolve.c:9636
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr "GOTO-Anweisung bei %L hinterlässt DO CONCURRENT-Konstrukt für Marke bei %L"
@@ -59528,108 +59605,108 @@
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:9638
+#: fortran/resolve.c:9651
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "Marke bei %L ist nicht im gleichen Block wie GOTO-Anweisung bei %L"
 
-#: fortran/resolve.c:9710
+#: fortran/resolve.c:9723
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "WHERE-Maske bei %L hat ungültige Form"
 
-#: fortran/resolve.c:9726
+#: fortran/resolve.c:9739
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "WHERE-Zuweisungsziel bei %L hat ungültige Form"
 
-#: fortran/resolve.c:9734 fortran/resolve.c:9821
+#: fortran/resolve.c:9747 fortran/resolve.c:9834
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr "Benutzerdefinierte Nicht-ELEMENTAL-Zuweisung in WHERE bei %L"
 
-#: fortran/resolve.c:9744 fortran/resolve.c:9831
+#: fortran/resolve.c:9757 fortran/resolve.c:9844
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "Nicht unterstützte Anweisung in WHERE bei %L"
 
-#: fortran/resolve.c:9775
+#: fortran/resolve.c:9788
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "Zuweisung an FORALL-Indexvariable bei %L"
 
-#: fortran/resolve.c:9784
+#: fortran/resolve.c:9797
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "Das FORALL mit Index %qs wird nicht auf der linken Seite der Zuweisung bei %L verwendet und könnte somit mehrere Zuweisungen an dieses Objekt auslösen"
 
-#: fortran/resolve.c:9949
+#: fortran/resolve.c:9962
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "FORALL-Indexname bei %L muss skalarer INTEGER sein"
 
-#: fortran/resolve.c:9959
+#: fortran/resolve.c:9972
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "Ein äußeres FORALL-Konstrukt hat bereits einen Index mit Namen %L"
 
-#: fortran/resolve.c:10036
+#: fortran/resolve.c:10049
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "Klausel WHERE/ELSEWHERE bei %L erfordert ein LOGICAL-Feld"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/resolve.c:10138
+#: fortran/resolve.c:10151
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr "gfc_resolve_blocks(): Bad block type"
 
-#: fortran/resolve.c:10251
+#: fortran/resolve.c:10264
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr "CHARACTER-Ausdruck wird in Zuweisung (%ld/%ld) bei %L abgeschnitten"
 
-#: fortran/resolve.c:10283
+#: fortran/resolve.c:10296
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "Koindizierter Ausdruck bei %L wird einer Variable abgeleiteten Typs mit einer POINTER-Komponente in einer PURE-Prozedur zugewiesen"
 
-#: fortran/resolve.c:10288
+#: fortran/resolve.c:10301
 #, gcc-internal-format, gfc-internal-format
 msgid "The impure variable at %L is assigned to a derived type variable with a POINTER component in a PURE procedure (12.6)"
 msgstr "Die unreine Variable bei %L wird einer Variable abgeleiteten Typs mit einer POINTER-Komponente in einer PURE-Prozedur zugewiesen (12.6)"
 
-#: fortran/resolve.c:10298
+#: fortran/resolve.c:10311
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "Zuweisung an koindizierte Variable bei %L in einer PURE-Prozedur"
 
-#: fortran/resolve.c:10330
+#: fortran/resolve.c:10343
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr "Zuweisung an polymorphes Koarray bei %L ist nicht erlaubt"
 
-#: fortran/resolve.c:10334
+#: fortran/resolve.c:10347
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "Zuweisung an allozierbare polymorphe Variable bei %L"
 
-#: fortran/resolve.c:10339
+#: fortran/resolve.c:10352
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr "Zuweisung an allozierbare polymorphe Variable bei %L erfordert %<-frealloc-lhs%>"
 
-#: fortran/resolve.c:10346
+#: fortran/resolve.c:10359
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr "Variable darf in intrinsischer Zuweisung bei %L nicht polymorph sein - bitte prüfen, ob es ein passendes spezifisches Unterprogramm für den »=«-Operator gibt"
 
-#: fortran/resolve.c:10357
+#: fortran/resolve.c:10370
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr "Koindizierte Variable darf keine reservierbare endgültige Komponente in Zuweisung bei %L haben"
 
-#: fortran/resolve.c:10663
+#: fortran/resolve.c:10683
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr "TODO: als typgebunden definierte Zuweisung(en) bei %L nicht durchgeführt, da Feldreferenzen mit mehreren Teilen in Ausdrücken als Zwischenergebnisse auftreten würden."
@@ -59636,69 +59713,69 @@
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:10905
+#: fortran/resolve.c:10925
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr "Zuweisung eines Prozedurzeigers bei %L"
 
-#: fortran/resolve.c:10917
+#: fortran/resolve.c:10937
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr "Funktionsergebnis auf der linken Seite der Zuweisung bei %L muss Zeiger-Attribut haben."
 
-#: fortran/resolve.c:11157
+#: fortran/resolve.c:11177
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgstr "Anweisung ASSIGNED GOTO bei %L erfordert eine INTEGER-Variable"
 
-#: fortran/resolve.c:11160
+#: fortran/resolve.c:11180
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "Variable %qs bei %L wurde keine Zielmarke zugewiesen"
 
-#: fortran/resolve.c:11171
+#: fortran/resolve.c:11191
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "Alternative RETURN-Anweisung bei %L erfordert einen SCALAR-INTEGER-Spezifizierer als Rückgabe"
 
-#: fortran/resolve.c:11233
+#: fortran/resolve.c:11253
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "ASSIGN-Anweisung bei %L erfordert eine skalare Standard-INTEGER-Variable"
 
-#: fortran/resolve.c:11278
+#: fortran/resolve.c:11298
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid NULL at %L"
 msgstr "Ungültiges NULL bei %L"
 
-#: fortran/resolve.c:11282
+#: fortran/resolve.c:11302
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr "Arithmetische IF-Anweisung bei %L erfordert einen skalaren REAL- oder INTEGER-Ausdruck"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/resolve.c:11339
+#: fortran/resolve.c:11359
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr "gfc_resolve_code(): No expression on DO WHILE"
 
-#: fortran/resolve.c:11344
+#: fortran/resolve.c:11364
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "Abbruchbedingung der DO WHILE-Schleife bei %L muss ein skalarer LOGICAL-Ausdruck sein"
 
-#: fortran/resolve.c:11428
+#: fortran/resolve.c:11448
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "FORALL-Maskenklausel bei %L erfordert einen skalaren LOGICAL-Ausdruck"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/resolve.c:11507
+#: fortran/resolve.c:11527
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_resolve_code(): Bad statement code"
 
-#: fortran/resolve.c:11617
+#: fortran/resolve.c:11637
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "Variable %1$qs bei %3$L mit Binde-Marke %2$qs verwenden denselben globalen Bezeichner wie die Entität bei %4$L"
@@ -59705,7 +59782,7 @@
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:11630
+#: fortran/resolve.c:11650
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr "Variable %qs aus Modul %qs mit Bindungsmarke %qs bei %L verwendet denselben globalen Bezeichner wie Entität bei %L aus Modul %qs"
@@ -59713,57 +59790,57 @@
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:11647
+#: fortran/resolve.c:11667
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "Prozedur %1$qs bei %3$L mit Binde-Marke %2$qs verwenden denselben globalen Bezeichner wie die Entität bei %4$L"
 
-#: fortran/resolve.c:11732
+#: fortran/resolve.c:11752
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "Zeichenkettenlänge bei %L ist zu groß"
 
-#: fortran/resolve.c:11961
+#: fortran/resolve.c:11981
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "Reservierbares Feld %qs bei %L muss aufgeschobene Form oder vermuteten Rang haben"
 
-#: fortran/resolve.c:11965
+#: fortran/resolve.c:11985
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "Skalares Objekt %qs bei %L kann nicht ALLOCATABLE sein"
 
-#: fortran/resolve.c:11973
+#: fortran/resolve.c:11993
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "Feldzeiger %qs bei %L muss aufgeschobene Form oder vermuteten Rang haben"
 
-#: fortran/resolve.c:11983
+#: fortran/resolve.c:12003
 #, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "Feld %qs bei %L kann keine aufgeschobene Form haben"
 
-#: fortran/resolve.c:11998
+#: fortran/resolve.c:12018
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr "Typ %qs der CLASS-Variable %qs bei %L ist nicht erweiterbar"
 
-#: fortran/resolve.c:12010
+#: fortran/resolve.c:12030
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr "CLASS-Variable %qs bei %L muss Attrappe, reservierbar oder Zeiger sein"
 
-#: fortran/resolve.c:12041
+#: fortran/resolve.c:12061
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr "Der Typ %qs bei %L darf nicht mit Wirt verbunden sein, da er von unverträglichem bei %L definierten Objekt mit gleichem Namen blockiert wird"
 
-#: fortran/resolve.c:12063
+#: fortran/resolve.c:12083
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr "Einbezogenes SAVE für Modulvariable %qs bei %L, benötigt wegen Standardinitialisierung"
 
-#: fortran/resolve.c:12090
+#: fortran/resolve.c:12110
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr "Entität %qs bei %L hat Parameter mit aufgeschobenem Typ und benötigt entweder das POINTER- oder ALLOCATABLE-Attribut"
@@ -59770,889 +59847,894 @@
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12131
+#: fortran/resolve.c:12151
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "Das Feld %qs im Modul oder Hauptprogramm bei %L muss konstante Form haben"
 
-#: fortran/resolve.c:12150
+#: fortran/resolve.c:12170
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "Entität mit vermuteter Zeichenlänge bei %L muss ein Scheinargument oder ein PARAMETER sein"
 
-#: fortran/resolve.c:12171
+#: fortran/resolve.c:12191
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr "%qs bei %L muss in diesem Zusammenhang konstante Zeichenlänge haben"
 
-#: fortran/resolve.c:12178
+#: fortran/resolve.c:12198
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "COMMON-Variable %qs bei %L muss konstante Zeichenlänge haben"
 
-#: fortran/resolve.c:12225
+#: fortran/resolve.c:12245
 #, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "Zuordnungsfähiges %qs bei %L kann keine Initialisierung haben"
 
-#: fortran/resolve.c:12228
+#: fortran/resolve.c:12248
 #, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr "Externes %qs bei %L kann keine Initialisierung haben"
 
-#: fortran/resolve.c:12232
+#: fortran/resolve.c:12252
 #, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "Schein-%qs bei %L kann keine Initialisierung haben"
 
-#: fortran/resolve.c:12235
+#: fortran/resolve.c:12255
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "Intrinsisches %qs bei %L kann keine Initialisierung haben"
 
-#: fortran/resolve.c:12238
+#: fortran/resolve.c:12258
 #, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "Funktionsergebnis %qs bei %L kann keine Initialisierung haben"
 
-#: fortran/resolve.c:12241
+#: fortran/resolve.c:12261
 #, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "Automatisches Feld %qs bei %L kann keine Initialisierung haben"
 
-#: fortran/resolve.c:12283
+#: fortran/resolve.c:12303
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L"
 msgstr "%s bei %L"
 
-#: fortran/resolve.c:12310
+#: fortran/resolve.c:12330
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "Zeichenwertige Anweisungsfunktion %qs bei %L muss konstante Länge haben"
 
-#: fortran/resolve.c:12332
+#: fortran/resolve.c:12352
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "%qs hat PRIVATE-Typ und kann kein Scheinargument von %qs bei %L sein, das PUBLIC ist"
 
-#: fortran/resolve.c:12354
+#: fortran/resolve.c:12374
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr "Prozedur %qs in PUBLIC-Schnittstelle %qs bei %L nimmt Scheinargumente von %qs, das PRIVATE ist"
 
-#: fortran/resolve.c:12372
+#: fortran/resolve.c:12392
 #, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "Funktion %qs bei %L darf keinen Initialisierer haben"
 
-#: fortran/resolve.c:12381
+#: fortran/resolve.c:12401
 #, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr "Externes Objekt %qs bei %L darf keinen Initialisierer haben"
 
-#: fortran/resolve.c:12389
+#: fortran/resolve.c:12409
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "ELEMENTAL-Funktion %qs bei %L muss ein skalares Ergebnis haben"
 
-#: fortran/resolve.c:12399
+#: fortran/resolve.c:12419
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "Anweisungsfunktion %qs bei %L darf weder POINTER- oder ALLOCATABLE-Attribut haben"
 
-#: fortran/resolve.c:12418
+#: fortran/resolve.c:12438
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "CHARACTER(*)-Funktion %qs bei %L darf nicht feld-wertig sein"
 
-#: fortran/resolve.c:12422
+#: fortran/resolve.c:12442
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "CHARACTER(*)-Funktion %qs bei %L darf nicht zeiger-wertig sein"
 
-#: fortran/resolve.c:12426
+#: fortran/resolve.c:12446
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "CHARACTER(*)-Funktion %qs bei %L darf nicht rein sein"
 
-#: fortran/resolve.c:12430
+#: fortran/resolve.c:12450
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "CHARACTER(*)-Funktion %qs bei %L darf nicht rekursiv sein"
 
-#: fortran/resolve.c:12443
+#: fortran/resolve.c:12463
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "CHARACTER(*)-Funktion %qs bei %L"
 
-#: fortran/resolve.c:12452
+#: fortran/resolve.c:12472
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "Prozedurzeiger %qs bei %L darf nicht ELEMENTAL sein"
 
-#: fortran/resolve.c:12458
+#: fortran/resolve.c:12478
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "Scheinprozedur %qs bei %L darf nicht ELEMENTAL sein"
 
-#: fortran/resolve.c:12470
+#: fortran/resolve.c:12490
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr "Funktionsergebnisvariable %qs bei %L von elementarer Funktion %qs darf nicht die Attribute ALLOCATABLE oder POINTER haben"
 
-#: fortran/resolve.c:12527
+#: fortran/resolve.c:12547
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "Attribut PROCEDURE steht mit Attribut SAVE in %qs bei %L in Konflikt"
 
-#: fortran/resolve.c:12533
+#: fortran/resolve.c:12553
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "Attribut PROCEDURE steht mit Attribut INTENT in %qs bei %L in Konflikt"
 
-#: fortran/resolve.c:12539
+#: fortran/resolve.c:12559
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "Attribut PROCEDURE steht mit Attribut RESULT in %qs bei %L in Konflikt"
 
-#: fortran/resolve.c:12547
+#: fortran/resolve.c:12567
 #, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "Attribut EXTERNAL steht mit Attribut FUNCTION in %qs bei %L in Konflikt"
 
-#: fortran/resolve.c:12553
+#: fortran/resolve.c:12573
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr "Dem Ergebnis %qs als Prozedurzeiger bei %L fehlt das POINTER-Attribut"
 
-#: fortran/resolve.c:12596
+#: fortran/resolve.c:12616
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "Konflikt in ELEMENTAL-Attribut zwischen MODULE-PROCEDURE bei %L und seiner Schnittstelle in %s"
 
-#: fortran/resolve.c:12604
+#: fortran/resolve.c:12624
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "Konflikt in PURE-Attribut zwischen MODULE-PROCEDURE bei %L und seiner Schnittstelle in %s"
 
-#: fortran/resolve.c:12612
+#: fortran/resolve.c:12632
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr "Konflikt in RECURSIVE-Attribut zwischen MODULE-PROCEDURE bei %L und seiner Schnittstelle in %s"
 
-#: fortran/resolve.c:12621
+#: fortran/resolve.c:12641
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr "%s zwischen der MODULE-PROCEDURE-Deklaration in Modul %qs und der Deklaration bei %L in (SUB)MODULE %qs"
 
-#: fortran/resolve.c:12705
+#: fortran/resolve.c:12725
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "FINAL-Prozedur %qs bei %L ist keine SUBROUTINE"
 
-#: fortran/resolve.c:12714
+#: fortran/resolve.c:12734
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "FINAL-Prozedur bei %L muss genau ein Argument haben"
 
-#: fortran/resolve.c:12723
+#: fortran/resolve.c:12743
 #, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "Argument der FINAL-Prozedur bei %L muss Typ %qs haben"
 
-#: fortran/resolve.c:12731
+#: fortran/resolve.c:12751
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "Argument der FINAL-Prozedur bei %L darf kein POINTER sein"
 
-#: fortran/resolve.c:12737
+#: fortran/resolve.c:12757
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "Argument der FINAL-Prozedur bei %L darf nicht ALLOCATABLE sein"
 
-#: fortran/resolve.c:12743
+#: fortran/resolve.c:12763
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "Argument der FINAL-Prozedur bei %L darf nicht OPTIONAL sein"
 
-#: fortran/resolve.c:12751
+#: fortran/resolve.c:12771
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "Argument der FINAL-Prozedur bei %L darf nicht INTENT(OUT) sein"
 
-#: fortran/resolve.c:12760
+#: fortran/resolve.c:12780
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "Nicht-skalare FINAL-Prozedur bei %L sollte Argument mit vermuteter Form haben"
 
-#: fortran/resolve.c:12782
+#: fortran/resolve.c:12802
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "Bei %2$L deklarierte FINAL-Prozedur %1$qs hat denselben Rang (%3$d) wie %4$qs"
 
-#: fortran/resolve.c:12819
+#: fortran/resolve.c:12839
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr "Bei %2$L wurde nur FINAL-Feldprozedur für abgeleiteten Typ %1$qs definiert, skalare wird ebenfalls empfohlen"
 
-#: fortran/resolve.c:12859
+#: fortran/resolve.c:12879
 #, gcc-internal-format
 msgid "%qs and %qs can't be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr "%qs und %qs können nicht gemischte FUNCTION/SUBROUTINE für GENERIC %qs bei %L sein"
 
-#: fortran/resolve.c:12895
+#: fortran/resolve.c:12915
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr "%qs und %qs für GENERIC %qs bei %L sind mehrdeutig"
 
-#: fortran/resolve.c:12954
+#: fortran/resolve.c:12974
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr "Undefinierte spezifische Bindung %qs als Ziel des GENERIC %qs bei %L"
 
-#: fortran/resolve.c:12966
+#: fortran/resolve.c:12986
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr "GENERIC %qs bei %L muss auf spezifische Bindung abzielen, %qs ist ebenfalls GENERIC"
 
-#: fortran/resolve.c:12994
+#: fortran/resolve.c:13014
 #, gcc-internal-format
 msgid "GENERIC %qs at %L can't overwrite specific binding with the same name"
 msgstr "GENERIC %qs bei %L kann nicht spezifische Bindung mit gleichem Namen überschreiben"
 
-#: fortran/resolve.c:13050
+#: fortran/resolve.c:13070
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L can't be NOPASS"
 msgstr "Typgebundener Operator bei %L kann nicht NOPASS sein"
 
-#: fortran/resolve.c:13242
+#: fortran/resolve.c:13262
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "%qs bei %L muss eine Modulprozedur oder eine externe Prozedur mit expliziter Schnittstelle sein"
 
-#: fortran/resolve.c:13284
+#: fortran/resolve.c:13304
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "Prozedur %qs mit PASS(%s) bei %L hat kein Argument %qs"
 
-#: fortran/resolve.c:13298
+#: fortran/resolve.c:13318
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "Prozedur %qs mit PASS bei %L muss mindestens ein Argument haben"
 
-#: fortran/resolve.c:13312 fortran/resolve.c:13778
+#: fortran/resolve.c:13332 fortran/resolve.c:13798
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "Nicht-polymorphes Scheinargument von %qs für weitergegebenes Objekt bei %L"
 
-#: fortran/resolve.c:13320
+#: fortran/resolve.c:13340
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "Argument %qs von %qs mit PASS(%s) bei %L muss abgeleiteten Typ %qs haben"
 
-#: fortran/resolve.c:13329
+#: fortran/resolve.c:13349
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "Scheinargument von %qs für weitergegebenes Objekt bei %L muss ein Skalar sein"
 
-#: fortran/resolve.c:13335
+#: fortran/resolve.c:13355
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "Scheinargument von %qs für weitergegebenes Objekt bei %L darf nicht ALLOCATABLE sein"
 
-#: fortran/resolve.c:13341
+#: fortran/resolve.c:13361
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "Scheinargument von %qs für weitergegebenes Objekt bei %L darf nicht POINTER sein"
 
-#: fortran/resolve.c:13370
+#: fortran/resolve.c:13390
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "Prozedur %qs bei %L hat den gleichen Namen wie eine Komponente von %qs"
 
-#: fortran/resolve.c:13380
+#: fortran/resolve.c:13400
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "Prozedur %qs bei %L hat den selben Namen wie eine vererbte Komponente von %qs"
 
-#: fortran/resolve.c:13472
+#: fortran/resolve.c:13492
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr "Bei %2$L deklarierter abgeleiteter Typ %1$qs muss ABSTRACT sein, da %3$qs DEFERRED und nicht überschrieben ist"
 
-#: fortran/resolve.c:13574
+#: fortran/resolve.c:13594
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "Koarray-Komponente %qs bei %L muss reservierbar mit aufgeschobener Form sein"
 
-#: fortran/resolve.c:13583
+#: fortran/resolve.c:13603
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "Komponente %qs bei %L mit TYPE(C_PTR) oder TYPE(C_FUNPTR) darf kein Koarray sein"
 
-#: fortran/resolve.c:13593
+#: fortran/resolve.c:13613
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr "Komponente %qs bei %L mit Koarray-Komponente darf ein Nicht-Zeiger und nicht-reservierbares Skalar sein"
 
-#: fortran/resolve.c:13602
+#: fortran/resolve.c:13622
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr "Komponente %qs bei %L hat das CONTIGUOUS-Attribut, aber ist kein Feldzeiger"
 
-#: fortran/resolve.c:13613
+#: fortran/resolve.c:13633
 #, gcc-internal-format
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "Komponente %qs von BIND(C)-Typ bei %L muss Länge eins haben"
 
-#: fortran/resolve.c:13711
+#: fortran/resolve.c:13731
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "Prozedurzeiger-Komponente %qs mit PASS(%s) bei %L hat kein Argument %qs"
 
-#: fortran/resolve.c:13725
+#: fortran/resolve.c:13745
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "Prozedurzeiger-Komponente %qs mit PASS bei %L muss mindestens ein Argument haben"
 
-#: fortran/resolve.c:13741
+#: fortran/resolve.c:13761
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "Argument %qs von %qs mit PASS(%s) bei %L muss abgeleiteten Typ %qs haben"
 
-#: fortran/resolve.c:13751
+#: fortran/resolve.c:13771
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "Parameter %qs von %qs mit PASS(%s) bei %L muss skalar sein"
 
-#: fortran/resolve.c:13760
+#: fortran/resolve.c:13780
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "Argument %qs von %qs mit PASS(%s) bei %L darf kein POINTER-Attribut haben"
 
-#: fortran/resolve.c:13769
+#: fortran/resolve.c:13789
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "Argument %qs von %qs mit PASS(%s) bei %L darf nicht ALLOCATABLE sein"
 
-#: fortran/resolve.c:13811
+#: fortran/resolve.c:13831
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "Komponente %qs von %qs bei %L hat den gleichen Namen wie eine geerbte typgebundene Prozedur"
 
-#: fortran/resolve.c:13824
+#: fortran/resolve.c:13844
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "Zeichenlänge der Komponente %qs muss ein konstanter Spezifikationsausdruck bei %L sein"
 
-#: fortran/resolve.c:13835
+#: fortran/resolve.c:13855
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr "Zeichenkomponente %qs von %qs bei %L mit aufgeschobener Länge muss POINTER oder ALLOCATABLE sein"
 
-#: fortran/resolve.c:13868
+#: fortran/resolve.c:13888
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "Die Komponente %qs ist ein PRIVATE-Typ und kann nicht Komponente von %qs sein, die PUBLIC bei %L ist"
 
-#: fortran/resolve.c:13876
+#: fortran/resolve.c:13896
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr "Polymorphe Komponente %s bei %L in SEQUENCE oder BIND(C)-Typ %s"
 
-#: fortran/resolve.c:13885
+#: fortran/resolve.c:13905
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "Komponente %s des bei %L deklarierten SEQUENCE-Typen hat kein SEQUENCE-Attribut"
 
-#: fortran/resolve.c:13903 fortran/resolve.c:13915
+#: fortran/resolve.c:13923 fortran/resolve.c:13935
 #, gcc-internal-format
 msgid "The pointer component %qs of %qs at %L is a type that has not been declared"
 msgstr "Die Zeigerkomponente %qs bei %qs bei %L hat nicht deklarierten Typ"
 
-#: fortran/resolve.c:13989
+#: fortran/resolve.c:14009
 #, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "In Konflikt stehende Initialisierungen in Union bei %L und %L"
 
-#: fortran/resolve.c:14034
+#: fortran/resolve.c:14054
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr "Da der erweiterte Typ %qs bei %L eine Koarray-Komponente hat, muss der Elterntyp %qs auch eine haben"
 
-#: fortran/resolve.c:14047
+#: fortran/resolve.c:14067
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "Nicht-erweiterbarer abgeleiteter Typ %qs bei %L darf nicht ABSTRACT sein"
 
-#: fortran/resolve.c:14111
+#: fortran/resolve.c:14131
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr "Parametrisierter Typ %1$qs hat bei %3$L keine Komponente, die zu Parameter %2$qs gehört"
 
-#: fortran/resolve.c:14144
+#: fortran/resolve.c:14164
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr "Allgemeiner Name %qs der Funktion %qs bei %L ist der gleiche wie der des abgeleiteten Typs bei %L"
 
-#: fortran/resolve.c:14216
+#: fortran/resolve.c:14236
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "Feld %qs mit vermuteter Größe in Namensliste %qs bei %L ist nicht erlaubt"
 
-#: fortran/resolve.c:14222
+#: fortran/resolve.c:14242
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "NAMELIST-Feldobjekt %qs mit vermuteter Form in Namensliste %qs bei %L"
 
-#: fortran/resolve.c:14228
+#: fortran/resolve.c:14248
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "NAMELIST-Feldobjekt %qs ohne konstante Form in Namensliste %qs bei %L"
 
-#: fortran/resolve.c:14236
+#: fortran/resolve.c:14256
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "NAMELIST-Objekt %qs ohne konstante Zeichenlänge in Namensliste %qs bei %L"
 
-#: fortran/resolve.c:14253
+#: fortran/resolve.c:14273
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "NAMELIST-Objekt %qs wurde als PRIVATE deklariert und kann kein Element der PUBLIC-Namensliste %qs bei %L sein"
 
-#: fortran/resolve.c:14275
+#: fortran/resolve.c:14295
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "NAMELIST-Objekt %qs hat Verwendungs-verbundene PRIVATE-Komponenten und kann kein Element der Namensliste %qs bei %L sein"
 
-#: fortran/resolve.c:14286
+#: fortran/resolve.c:14306
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "NAMELIST-Objekt %qs hat PRIVATE-Komponenten und kann kein Element der PUBLIC-Namensliste %qs bei %L sein"
 
-#: fortran/resolve.c:14313
+#: fortran/resolve.c:14333
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "Attribut PROCEDURE steht mit Attribut NAMELIST in %qs bei %L in Konflikt"
 
-#: fortran/resolve.c:14337
+#: fortran/resolve.c:14357
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "Parameterfeld %qs bei %L kann nicht automatische oder vermutete Form haben"
 
-#: fortran/resolve.c:14353
+#: fortran/resolve.c:14373
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "Implizit angegebener PARAMETER %qs bei %L passt nicht zu früherem IMPLICIT-Typ"
 
-#: fortran/resolve.c:14364
+#: fortran/resolve.c:14384
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "Unverträglicher abgeleiteter Typ in PARAMETER bei %L"
 
-#: fortran/resolve.c:14372
+#: fortran/resolve.c:14392
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "COMMON-Block %qs bei %L kann nicht das EXTERNAL-Attribut haben"
 
-#: fortran/resolve.c:14423
+#: fortran/resolve.c:14443
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr "Das Objekt %qs bei %L hat aufgeschobenen LEN-Parameter %qs und ist weder allozierbar noch ein Zeiger"
 
-#: fortran/resolve.c:14434
+#: fortran/resolve.c:14454
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr "Das AUTOMATIC-Objekt %qs bei %L darf kein SAVE-Attribut haben und dard auch keine Variable im main-Programm, einem Modul oder einem Teilmodus sein (F08/C513)"
 
-#: fortran/resolve.c:14441
+#: fortran/resolve.c:14461
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr "Das Objekt %qs bei %L mit ASSUMED-Typparametern muss ein Dummy oder ein SELECT-TYPE-Selektor sein (F08/4.2)"
 
-#: fortran/resolve.c:14480
+#: fortran/resolve.c:14500
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr "Sorry, allozierbare/Zeiger-Komponenten in polymorphen (CLASS-)getypten Koarrays bei %L werden nicht unterstützt"
 
-#: fortran/resolve.c:14544
+#: fortran/resolve.c:14564
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "Attribut PROTECTED steht mit Attribut EXTERNAL bei %L in Konflikt"
 
-#: fortran/resolve.c:14547
+#: fortran/resolve.c:14567
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "Attribut PROCEDURE steht mit Attribut PROTECTED bei %L in Konflikt"
 
-#: fortran/resolve.c:14643
+#: fortran/resolve.c:14663
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr "%qs bei %L hat Attribut CONTIGUOUS, aber ist kein Feldzeiger oder Feld vermuteter Größe oder Rang"
 
-#: fortran/resolve.c:14664
+#: fortran/resolve.c:14684
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr "Falsche Spezifikation für Feld bei %L mit angenommener Größe"
 
-#: fortran/resolve.c:14677
+#: fortran/resolve.c:14697
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "Feld mit vermuteter Größe bei %L muss ein Schein-Argument sein"
 
-#: fortran/resolve.c:14680
+#: fortran/resolve.c:14700
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "Feld mit vermuteter Form bei %L muss ein Scheinargument sein"
 
-#: fortran/resolve.c:14688
+#: fortran/resolve.c:14708
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "Feld mit vermutetem Rang bei %L muss ein Scheinargument sein"
 
-#: fortran/resolve.c:14695
+#: fortran/resolve.c:14715
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr "Feld mit vermutetem Rang bei %L darf kein Attribut VALUE oder CODIMENSION haben"
 
-#: fortran/resolve.c:14708
+#: fortran/resolve.c:14728
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "Symbol bei %L ist keine Scheinvariable"
 
-#: fortran/resolve.c:14714
+#: fortran/resolve.c:14734
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "%qs bei %L kann nicht das VALUE-Attribut haben, da es kein Scheinargument ist"
 
-#: fortran/resolve.c:14724
+#: fortran/resolve.c:14744
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "Zeichenwertige Scheinvariable %qs bei %L mit VALUE-Attribut muss konstante Länge haben"
 
-#: fortran/resolve.c:14733
+#: fortran/resolve.c:14753
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "C-kompatible zeichenwertige Scheinvariable %qs bei %L mit VALUE-Attribut muss Länge eins haben"
 
-#: fortran/resolve.c:14746 fortran/resolve.c:14923
+#: fortran/resolve.c:14766 fortran/resolve.c:14943
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "Der abgeleitete Typ %qs bei %L hat Typ %qs, der nicht definiert wurde"
 
-#: fortran/resolve.c:14760
+#: fortran/resolve.c:14780
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr "Variable %s bei %L mit NO_ARG_CHECK-Attribut muss ein Scheinargument sein"
 
-#: fortran/resolve.c:14769
+#: fortran/resolve.c:14789
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr "Variable %s bei %L mit NO_ARG_CHECK-Attribut muss vom Typ TYPE(*) oder von einem numerischen intrinsischen Typ sein"
 
-#: fortran/resolve.c:14778
+#: fortran/resolve.c:14798
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Variable %s bei %L mit NO_ARG_CHECK-Attribut darf nicht die Attribute ALLOCATABLE, CODIMENSION, POINTER oder VALUE haben"
 
-#: fortran/resolve.c:14786
+#: fortran/resolve.c:14806
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "Variable %s bei %L mit NO_ARG_CHECK-Attribut darf nicht das Attribut INTENT(OUT) haben"
 
-#: fortran/resolve.c:14793
+#: fortran/resolve.c:14813
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr "Variable %s bei %L mit NO_ARG_CHECK-Attribut muss entweder skalar sein oder ein Feld vermuteter Größe"
 
-#: fortran/resolve.c:14813
+#: fortran/resolve.c:14833
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "Vermuteter Typ der Variable %s bei %L ist nur für Scheinvariablen erlaubt"
 
-#: fortran/resolve.c:14820
+#: fortran/resolve.c:14840
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Variable %s vermuteten Typs bei %L darf nicht die Attribute ALLOCATABLE, CODIMENSION, POINTER oder VALUE haben"
 
-#: fortran/resolve.c:14827
+#: fortran/resolve.c:14847
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "Variable %s vermuteten Typs bei %L darf nicht das Attribut INTENT(OUT) haben"
 
-#: fortran/resolve.c:14834
+#: fortran/resolve.c:14854
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr "Variable %s vermuteten Typs bei %L darf kein Feld mit ausdrücklicher Form sein"
 
-#: fortran/resolve.c:14860
+#: fortran/resolve.c:14880
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr "Variable %qs bei %L kann nicht BIND(C) sein, weil es weder ein COMMON-Block noch mit Sichtbarkeit auf Modulebene deklariert ist"
 
-#: fortran/resolve.c:14870
+#: fortran/resolve.c:14890
 #, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "BIND(C)-Variable %qs bei %L muss Länge eins haben"
 
-#: fortran/resolve.c:14949
+#: fortran/resolve.c:14969
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "PUBLIC %s %qs bei %L mit abgeleitetem PRIVATE-Typen %qs"
 
-#: fortran/resolve.c:14964
+#: fortran/resolve.c:14984
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr "Variable %s bei %L mit LOCK_TYPE oder mit Subkomponente mit LOCK_TYPE muss ein Koarray sein"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79866
-#: fortran/resolve.c:14977
+#: fortran/resolve.c:14997
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr "Variable %s bei %L des Typs EVENT_TYPE oder mit Subkomponente des Typs EVENT_TYPE muss ein Koarray sein"
 
-#: fortran/resolve.c:14995
+#: fortran/resolve.c:15015
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "Das INTENT(OUT)-Scheinargument %qs bei %L hat ASSUMED SIZE und kann damit keine Standardinitialisierung haben"
 
-#: fortran/resolve.c:15007
+#: fortran/resolve.c:15027
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "Scheinargument %qs bei %L mit LOCK_TYPE darf nicht INTENT(OUT) sein"
 
-#: fortran/resolve.c:15016
+#: fortran/resolve.c:15036
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "Scheinargument %qs bei %L mit EVENT_TYPE darf nicht INTENT(OUT) sein"
 
-#: fortran/resolve.c:15028
+#: fortran/resolve.c:15048
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "Funktionsergebnis %qs bei %L darf weder Koarray sein noch eine Koarray-Komponente haben"
 
-#: fortran/resolve.c:15037
+#: fortran/resolve.c:15057
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "Variable %qs bei %L mit TYPE(C_PTR) oder TYPE(C_FUNPTR) darf kein Koarray sein"
 
-#: fortran/resolve.c:15049
+#: fortran/resolve.c:15069
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr "Variable %qs bei %L mit Koarraykomponente muss ein Nichtzeiger, nichtallozierbares Skalar und damit kein Koarray sein"
 
-#: fortran/resolve.c:15065
+#: fortran/resolve.c:15085
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr "Variable %qs bei %L ist ein Koarray und ist weder ALLOCATABLE, SAVE, noch ein Scheinargument"
 
-#: fortran/resolve.c:15073
+#: fortran/resolve.c:15093
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "Koarray-Variable %qs bei %L darf keine Kodimensionen mit aufgeschobener Form haben"
 
-#: fortran/resolve.c:15080
+#: fortran/resolve.c:15100
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "Zuordnungsfähige Koarray-Variable %qs bei %L muss aufgeschobene Form haben"
 
-#: fortran/resolve.c:15092
+#: fortran/resolve.c:15112
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "Variable %qs bei %L ist INTENT(OUT) und kann daher kein reservierbares Coarray sein oder Coarray-Komponenten haben"
 
-#: fortran/resolve.c:15101
+#: fortran/resolve.c:15121
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "Coarray-Scheinvariable %qs bei %L in BIND(C)-Prozedur %qs nicht erlaubt"
 
-#: fortran/resolve.c:15117
+#: fortran/resolve.c:15137
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "LOGICAL-Scheinargument %qs bei %L mit Nicht-C_Bool-Art in BIND(C)-Prozedur %qs"
 
-#: fortran/resolve.c:15123
+#: fortran/resolve.c:15143
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "LOGICAL-Rückgabevariable %qs bei %L mit Nicht-C_Bool-Art in BIND(C)-Prozedur %qs"
 
-#: fortran/resolve.c:15148
+#: fortran/resolve.c:15168
 #, gcc-internal-format
 msgid "Namelist %qs can not be an argument to subroutine or function at %L"
 msgstr "Namensliste %qs kann bei %L nicht als Argument für Unterprogramm oder Funktion verwendet werden"
 
-#: fortran/resolve.c:15218
+#: fortran/resolve.c:15238
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "Threadprivate bei %L ist nicht SAVEd"
 
-#: fortran/resolve.c:15229
+#: fortran/resolve.c:15249
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr "»!$OMP DECLARE TARGET«-Variable %qs bei %L ist nicht gespeichert (SAVE)"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/resolve.c:15333
+#: fortran/resolve.c:15353
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr "check_data_variable(): Bad expression"
 
-#: fortran/resolve.c:15339
+#: fortran/resolve.c:15359
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "BLOCK DATA Element %qs bei %L muss in COMMON sein"
 
-#: fortran/resolve.c:15345
+#: fortran/resolve.c:15365
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "DATA-Feld %qs bei %L muss in vorheriger Deklaration angegeben werden"
 
-#: fortran/resolve.c:15354
+#: fortran/resolve.c:15374
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "DATA-Element %qs bei %L kann keinen Coindex haben"
 
-#: fortran/resolve.c:15368
+#: fortran/resolve.c:15388
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr "DATA-Element %qs bei %L ist ein Zeiger und muss daher ein vollständiges Feld sein"
 
-#: fortran/resolve.c:15414
+#: fortran/resolve.c:15434
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "Abschnitt eines nicht konstanten Feldes bei %L in DATA-Anweisung"
 
-#: fortran/resolve.c:15427
+#: fortran/resolve.c:15447
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "DATA-Anweisung bei %L hat mehr Variablen als Werte"
 
-#: fortran/resolve.c:15526
+#: fortran/resolve.c:15546
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr "Anfang der Implied-do-Schleife bei %L konnte nicht zu einem konstanten Wert vereinfacht werden"
 
-#: fortran/resolve.c:15534
+#: fortran/resolve.c:15554
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr "Ende der Implied-do-Schleife bei %L konnte nicht zu einem konstanten Wert vereinfacht werden"
 
-#: fortran/resolve.c:15542
+#: fortran/resolve.c:15562
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr "Schritt der Implied-do-Schleife bei %L konnte nicht zu einem konstanten Wert vereinfacht werden"
 
-#: fortran/resolve.c:15667
+#: fortran/resolve.c:15687
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "DATA-Anweisung bei %L hat mehr Werte als Variablen"
 
-#: fortran/resolve.c:15832
+#: fortran/resolve.c:15852
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "Marke %d bei %L definiert, aber nicht verwendet"
 
-#: fortran/resolve.c:15838
+#: fortran/resolve.c:15858
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "Marke %d bei %L definiert, kann aber nicht verwendet werden"
 
-#: fortran/resolve.c:15922
+#: fortran/resolve.c:15942
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "Variable %qs abgeleiteten Typs bei %L muss SEQUENCE-Attribut haben, um EQUIVALENCE-Objekt zu sein"
 
-#: fortran/resolve.c:15931
+#: fortran/resolve.c:15951
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "Variable %qs abgeleiteten Typs bei %L kann keine ALLOCATABLE-Komponenten haben, um EQUIVALENCE-Objekt zu sein"
 
-#: fortran/resolve.c:15939
+#: fortran/resolve.c:15959
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "Variable %qs abgeleiteten Typs bei %L mit Standardinitialisierung kann nicht in EQUIVALENCE mit einer Variablen in COMMON sein"
 
-#: fortran/resolve.c:15955
+#: fortran/resolve.c:15975
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "Variable %qs abgeleiteten Typs bei %L mit Zeigerkomponenten kann kein EQUIVALENCE-Objekt sein"
 
-#: fortran/resolve.c:16058
+#: fortran/resolve.c:16078
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "Syntaxfehler in EQUIVALENCE-Anweisung bei %L"
 
-#: fortran/resolve.c:16073
+#: fortran/resolve.c:16093
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr "Entweder alle oder keines der Objekte in bei %L gesetztem EQUIVALENCE muss das Attribut PROTECTED haben"
 
-#: fortran/resolve.c:16098
+#: fortran/resolve.c:16118
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "COMMON-Blockelement %qs bei %L darf in der PURE-Prozedur %qs kein EQUIVALENCE-Objekt sein"
 
-#: fortran/resolve.c:16107
+#: fortran/resolve.c:16127
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Benannte Konstante %qs bei %L kann kein EQUIVALENCE-Objekt sein"
 
-#: fortran/resolve.c:16180
+#: fortran/resolve.c:16200
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "Feld %qs bei %L mit nicht-konstanten Grenzen kann kein EQUIVALENCE-Objekt sein"
 
-#: fortran/resolve.c:16191
+#: fortran/resolve.c:16211
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Strukturkomponente %qs bei %L kann kein EQUIVALENCE-Objekt sein"
 
-#: fortran/resolve.c:16202
+#: fortran/resolve.c:16222
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "Teilzeichenkette bei %L hat Länge Null"
 
-#: fortran/resolve.c:16293
+#: fortran/resolve.c:16253
 #, gcc-internal-format
+msgid "Self reference in character length expression for %qs at %L"
+msgstr "Selbstreferenz im Zeichenlängenausdruck für %qs bei %L"
+
+#: fortran/resolve.c:16320
+#, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "PUBLIC-Funktion %qs bei %L mit PRIVATE-Typ %qs"
 
-#: fortran/resolve.c:16306
+#: fortran/resolve.c:16333
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "ENTRY %qs bei %L hat keinen IMPLICIT-Typ"
 
-#: fortran/resolve.c:16326
+#: fortran/resolve.c:16353
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "Prozedur für Benutzeroperator %qs bei %L muss eine FUNCTION sein"
 
-#: fortran/resolve.c:16336
+#: fortran/resolve.c:16363
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "Prozedur für Benutzeroperator %qs bei %L kann nicht vermutete Zeichenlänge haben"
 
-#: fortran/resolve.c:16344
+#: fortran/resolve.c:16371
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "Prozedur für Benutzeroperator %qs bei %L muss mindestens ein Argument haben"
 
-#: fortran/resolve.c:16358
+#: fortran/resolve.c:16385
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "Erstes Argument der Operatorschnittstelle bei %L kann nicht optional sein"
 
-#: fortran/resolve.c:16376
+#: fortran/resolve.c:16403
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "Zweites Argument der Operatorschnittstelle bei %L kann nicht optional sein"
 
-#: fortran/resolve.c:16383
+#: fortran/resolve.c:16410
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "Operatorschnittstelle bei %L darf höchstens zwei Argumente haben"
 
-#: fortran/resolve.c:16461
+#: fortran/resolve.c:16488
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr "Enthaltene Prozedur %qs bei %L einer PURE-Prozedur muss auch PURE sein"
@@ -60996,20 +61078,13 @@
 msgid "simplify_min_max(): Bad type in arglist"
 msgstr "simplify_min_max(): Bad type in arglist"
 
-#. Result is processor-dependent.
-#: fortran/simplify.c:5472
-#, gcc-internal-format, gfc-internal-format
-msgid "Second argument MOD at %L is zero"
-msgstr "Zweites Argument von MOD bei %L ist Null"
+#: fortran/simplify.c:5470 fortran/simplify.c:5478
+#, gcc-internal-format
+msgid "Argument %qs of MOD at %L shall not be zero"
+msgstr "Argument %qs von MOD bei %L darf nicht Null sein"
 
-#. Result is processor-dependent.
-#: fortran/simplify.c:5483
-#, gcc-internal-format, gfc-internal-format
-msgid "Second argument of MOD at %L is zero"
-msgstr "Zweites Argument von MOD bei %L ist Null"
-
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/simplify.c:5494
+#: fortran/simplify.c:5484
 #, gcc-internal-format
 msgid "gfc_simplify_mod(): Bad arguments"
 msgstr "gfc_simplify_mod(): Bad arguments"
@@ -61017,100 +61092,100 @@
 #. Result is processor-dependent. This processor just opts
 #. to not handle it at all.
 #. Result is processor-dependent.
-#: fortran/simplify.c:5520 fortran/simplify.c:5532
+#: fortran/simplify.c:5525 fortran/simplify.c:5537
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of MODULO at %L is zero"
 msgstr "Zweites Argument von MODULO bei %L ist Null"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/simplify.c:5552
+#: fortran/simplify.c:5557
 #, gcc-internal-format
 msgid "gfc_simplify_modulo(): Bad arguments"
 msgstr "gfc_simplify_modulo(): Bad arguments"
 
-#: fortran/simplify.c:5600
+#: fortran/simplify.c:5605
 #, gcc-internal-format, gfc-internal-format
 msgid "Result of NEAREST is NaN at %L"
 msgstr "Ergebnis von NEAREST ist NaN bei %L"
 
-#: fortran/simplify.c:6081
+#: fortran/simplify.c:6086
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative at %L"
 msgstr "Argument NCOPIES des intrinsischen REPEAT ist bei %L negativ"
 
-#: fortran/simplify.c:6137
+#: fortran/simplify.c:6142
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument NCOPIES of REPEAT intrinsic is too large at %L"
 msgstr "Argument NCOPIES des intrinsischen REPEAT ist bei %L zu groß"
 
-#: fortran/simplify.c:6174
+#: fortran/simplify.c:6179
 #, gcc-internal-format, gfc-internal-format
 msgid "Evaluation of string longer than 2**28 at %L deferred to runtime, expect bugs"
 msgstr "Zeichenkette mit mehr als 2 hoch 28 Zeichen bei %L wird erst bei Ausführung des Programms ausgewertet werden, rechnen Sie mit Fehlern"
 
-#: fortran/simplify.c:6302
+#: fortran/simplify.c:6307
 #, gcc-internal-format, gfc-internal-format
 msgid "Reshaped array too large at %C"
 msgstr "Umgeformtes Feld bei %C zu groß"
 
-#: fortran/simplify.c:6416
+#: fortran/simplify.c:6421
 #, gcc-internal-format, gfc-internal-format
 msgid "Result of SCALE overflows its kind at %L"
 msgstr "Ergebnis von SCALE überschreitet seine Art bei %L"
 
-#: fortran/simplify.c:6995
+#: fortran/simplify.c:7000
 #, gcc-internal-format
 msgid "Bad type in gfc_simplify_sign"
 msgstr "Bad type in gfc_simplify_sign"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/simplify.c:7024
+#: fortran/simplify.c:7029
 #, gcc-internal-format
 msgid "in gfc_simplify_sin(): Bad type"
 msgstr "in gfc_simplify_sin(): Bad type"
 
-#: fortran/simplify.c:7151 fortran/simplify.c:7431
+#: fortran/simplify.c:7156 fortran/simplify.c:7436
 #, gcc-internal-format
 msgid "Failure getting length of a constant array."
 msgstr "Failure getting length of a constant array."
 
-#: fortran/simplify.c:7161
+#: fortran/simplify.c:7166
 #, gcc-internal-format
 msgid "The number of elements (%d) in the array constructor at %L requires an increase of the allowed %d upper limit.  See %<-fmax-array-constructor%> option."
 msgstr "Die Anzahl der Elemente (%d) im Feldkonstruktor bei %L erfordert Erhöhung der erlaubten oberen Grenze %d. Siehe Option %<-fmax-array-constructor%>."
 
-#: fortran/simplify.c:7227
+#: fortran/simplify.c:7232
 #, gcc-internal-format, gfc-internal-format
 msgid "Simplification of SPREAD at %C not yet implemented"
 msgstr "Vereinfachung von SPREAD bei %C ist noch nicht implementiert"
 
-#: fortran/simplify.c:7251
+#: fortran/simplify.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SQRT at %L has a negative value"
 msgstr "Argument von SQRT bei %L hat negativen Wert"
 
-#: fortran/simplify.c:7267
+#: fortran/simplify.c:7272
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid argument of SQRT at %L"
 msgstr "Ungültiges Argument von SQRT bei %L"
 
-#: fortran/simplify.c:7598
+#: fortran/simplify.c:7603
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY lower bound is %ld)"
 msgstr "Außerhalb des Wertebereichs in IMAGE_INDEX bei %L für Dimension %d, SUB hat %ld und untere Grenze für COARRAY ist %ld"
 
-#: fortran/simplify.c:7621
+#: fortran/simplify.c:7626
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY upper bound is %ld)"
 msgstr "Außerhalb des Wertebereichs in IMAGE_INDEX bei %L für Dimension %d, SUB hat %ld und obere Grenze für COARRAY ist %ld"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/simplify.c:7993
+#: fortran/simplify.c:7998
 #, gcc-internal-format
 msgid "gfc_convert_constant(): Unexpected type"
 msgstr "gfc_convert_constant(): Unexpected type"
 
-#: fortran/simplify.c:8078
+#: fortran/simplify.c:8083
 #, gcc-internal-format
 msgid "Character %qs in string at %L cannot be converted into character kind %d"
 msgstr "Zeichen %qs in Zeichenkette bei %L kann nicht in Zeichenart %d umgewandelt werden"
@@ -61216,7 +61291,7 @@
 msgid "BIND(C) applied to %s %s at %L"
 msgstr "BIND(C) auf %s %s bei %L angewendet"
 
-#: fortran/symbol.c:901 fortran/symbol.c:912 fortran/symbol.c:1762
+#: fortran/symbol.c:901 fortran/symbol.c:912 fortran/symbol.c:1776
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute conflicts with %s attribute at %L"
 msgstr "Attribut %s steht mit Attribut %s bei %L in Konflikt"
@@ -61291,18 +61366,23 @@
 msgid "Duplicate VOLATILE attribute specified at %L"
 msgstr "Doppeltes VOLATILE-Attribut bei %L angegeben"
 
-#: fortran/symbol.c:1367
+#: fortran/symbol.c:1360
 #, gcc-internal-format, gfc-internal-format
+msgid "VOLATILE attribute at %L cannot be specified in a PURE procedure"
+msgstr "VOLATILE-Attribut bei %L darf nicht in einer PURE-Prozedur angegeben werden"
+
+#: fortran/symbol.c:1381
+#, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ASYNCHRONOUS attribute specified at %L"
 msgstr "Doppeltes ASYNCHRONOUS-Attribut bei %L angegeben"
 
-#: fortran/symbol.c:1758
+#: fortran/symbol.c:1772
 #, gcc-internal-format
 msgid "%s attribute of %qs conflicts with %s attribute at %L"
 msgstr "Attribut %s von %qs steht mit Attribut %s bei %L in Konflikt"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=80012
-#: fortran/symbol.c:1794
+#: fortran/symbol.c:1808
 #, gcc-internal-format, gfc-internal-format
 msgid ""
 "%s procedure at %L is already declared as %s procedure. \n"
@@ -61311,210 +61391,210 @@
 "%s-Prozedur bei %L ist bereits als %s-Prozedur deklariert.\n"
 "F2008: Eine Zuweisung an eine Zeigerfunktion ist mehrdeutig, wenn dies die erste Anweisung nach dem Spezifikationsblock ist. Bitte fügen Sie davor irgend eine andere ausführbare Anweisung ein. FIXME (steht so im englischen Original.)"
 
-#: fortran/symbol.c:1802
+#: fortran/symbol.c:1816
 #, gcc-internal-format, gfc-internal-format
 msgid "%s procedure at %L is already declared as %s procedure"
 msgstr "Prozedur %s bei %L ist bereits als Prozedur %s deklariert"
 
-#: fortran/symbol.c:1837
+#: fortran/symbol.c:1851
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgstr "INTENT(%s) steht mit INTENT(%s) bei %L in Konflikt"
 
-#: fortran/symbol.c:1861
+#: fortran/symbol.c:1875
 #, gcc-internal-format, gfc-internal-format
 msgid "ACCESS specification at %L was already specified"
 msgstr "ACCESS-Spezifikation bei %L wurde bereits spezifiziert"
 
-#: fortran/symbol.c:1878
+#: fortran/symbol.c:1892
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate BIND attribute specified at %L"
 msgstr "Doppeltes BIND-Attribut bei %L angegeben"
 
-#: fortran/symbol.c:1885
+#: fortran/symbol.c:1899
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) at %L"
 msgstr "BIND(C) bei %L"
 
-#: fortran/symbol.c:1901
+#: fortran/symbol.c:1915
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate EXTENDS attribute specified at %L"
 msgstr "Doppeltes EXTENDS-Attribut bei %L angegeben"
 
-#: fortran/symbol.c:1905
+#: fortran/symbol.c:1919
 #, gcc-internal-format, gfc-internal-format
 msgid "EXTENDS at %L"
 msgstr "EXTENDS bei %L"
 
-#: fortran/symbol.c:1931
+#: fortran/symbol.c:1945
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has an explicit interface"
 msgstr "Symbol %qs bei %L hat bereits eine explizite Schnittstelle"
 
-#: fortran/symbol.c:1938
+#: fortran/symbol.c:1952
 #, gcc-internal-format
 msgid "%qs at %L has attributes specified outside its INTERFACE body"
 msgstr "%qs bei %L hat außerhalb seines INTERFACE-Körpers spezifizierte Attribute"
 
-#: fortran/symbol.c:1976
+#: fortran/symbol.c:1990
 #, gcc-internal-format
 msgid "Symbol %qs at %L conflicts with symbol from module %qs, use-associated at %L"
 msgstr "Symbol %qs bei %L steht mit Symbol aus Modul %qs in Konflikt, verbunden durch Verwendung bei %L"
 
-#: fortran/symbol.c:1980
+#: fortran/symbol.c:1994
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr "Symbol %qs bei %L hat bereits grundlegenden Typen %s"
 
-#: fortran/symbol.c:1987
+#: fortran/symbol.c:2001
 #, gcc-internal-format
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr "Prozedur %qs bei %L kann nicht grundlegenden Typen %s haben"
 
-#: fortran/symbol.c:1999
+#: fortran/symbol.c:2013
 #, gcc-internal-format
 msgid "Symbol %qs at %L cannot have a type"
 msgstr "Symbol %qs bei %L kann keinen Typen haben"
 
-#: fortran/symbol.c:2242
+#: fortran/symbol.c:2256
 #, gcc-internal-format
 msgid "Component %qs at %C already in the parent type at %L"
 msgstr "Komponente %qs bei %C bereits im Elterntypen bei %L deklariert"
 
-#: fortran/symbol.c:2327
+#: fortran/symbol.c:2341
 #, gcc-internal-format
 msgid "Symbol %qs at %C is ambiguous"
 msgstr "Symbol %qs bei %C ist mehrdeutig"
 
-#: fortran/symbol.c:2359
+#: fortran/symbol.c:2373
 #, gcc-internal-format
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr "Abgeleiteter Typ %qs bei %C wird verwendet, bevor er definiert wird"
 
-#: fortran/symbol.c:2508
+#: fortran/symbol.c:2522
 #, gcc-internal-format
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr "Komponente %qs bei %C ist eine PRIVATE-Komponente von %qs"
 
-#: fortran/symbol.c:2529
+#: fortran/symbol.c:2543
 #, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure; did you mean %qs?"
 msgstr "%qs bei %C ist kein Element der Struktur %qs; meinen Sie %qs?"
 
-#: fortran/symbol.c:2533
+#: fortran/symbol.c:2547
 #, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr "%qs bei %C ist kein Element der Struktur %qs"
 
-#: fortran/symbol.c:2697
+#: fortran/symbol.c:2711
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr "Doppelte Anweisungsmarke %d bei %L und %L"
 
-#: fortran/symbol.c:2708
+#: fortran/symbol.c:2722
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr "Marke %d bei %C bereits als Sprungziel referenziert"
 
-#: fortran/symbol.c:2718
+#: fortran/symbol.c:2732
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr "Marke %d bei %C bereits als eine Formatmarke referenziert"
 
-#: fortran/symbol.c:2724
+#: fortran/symbol.c:2738
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr "DO-Abbruchanweisung ist nicht »END DO« oder »CONTINUE« mit Marke %d bei %C"
 
-#: fortran/symbol.c:2766
+#: fortran/symbol.c:2780
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr "Marke %d bei %C vorher als FORMAT-Marke verwendet"
 
-#: fortran/symbol.c:2775
+#: fortran/symbol.c:2789
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr "Marke %d bei %C vorher als Sprungziel verwendet"
 
-#: fortran/symbol.c:2781
+#: fortran/symbol.c:2795
 #, gcc-internal-format, gfc-internal-format
 msgid "Shared DO termination label %d at %C"
 msgstr "Gemeinsam genutzte DO-Abbruchmarke %d bei %C"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/symbol.c:3110
+#: fortran/symbol.c:3124
 #, gcc-internal-format
 msgid "new_symbol(): Symbol name too long"
 msgstr "new_symbol(): Symbol name too long"
 
-#: fortran/symbol.c:3135
+#: fortran/symbol.c:3149
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr "Name %qs bei %C ist eine mehrdeutige Referenz auf %qs vom Modul %qs"
 
-#: fortran/symbol.c:3138
+#: fortran/symbol.c:3152
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
 msgstr "Name %qs bei %C ist eine mehrdeutige Referenz auf %qs von aktueller Programmeinheit"
 
 #. Symbol is from another namespace.
-#: fortran/symbol.c:3381
+#: fortran/symbol.c:3395
 #, gcc-internal-format
 msgid "Symbol %qs at %C has already been host associated"
 msgstr "Symbol %qs bei %C wurde bereits mit Host verbunden"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/symbol.c:4397
+#: fortran/symbol.c:4411
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 
-#: fortran/symbol.c:4410
+#: fortran/symbol.c:4424
 #, gcc-internal-format
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr "Abgeleiteter Typ %qs, bei %L deklariert, muss BIND-Attribut haben, um C-kompatibel zu sein"
 
-#: fortran/symbol.c:4428
+#: fortran/symbol.c:4442
 #, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr "Abgeleiteter Typ %qs mit Attribut BIND(C) bei %L ist leer und könnte für entsprechenden C-Prozessor unzugreifbar sein"
 
-#: fortran/symbol.c:4449
+#: fortran/symbol.c:4463
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr "Komponente %qs bei %L kann nicht POINTER-Attribut haben, da es Element des BIND(C)-abgeleiteten Typs %qs bei %L ist"
 
-#: fortran/symbol.c:4459
+#: fortran/symbol.c:4473
 #, gcc-internal-format
 msgid "Procedure pointer component %qs at %L cannot be a member of the BIND(C) derived type %qs at %L"
 msgstr "Komponente %qs des Prozedurzeigers bei %L kann kein Element des BIND(C)-abgeleiteten Typs %qs bei %L sein"
 
-#: fortran/symbol.c:4470
+#: fortran/symbol.c:4484
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr "Komponente %qs bei %L kann nicht ALLOCATABLE-Attribut haben, da es Element des BIND(C)-abgeleiteten Typs %qs bei %L ist"
 
-#: fortran/symbol.c:4509
+#: fortran/symbol.c:4523
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr "Komponente %qs in abgeleitetem Typ %qs bei %L könnte nicht C-kompatibel sein, obwohl abgeleiteter Typ %qs BIND(C) ist"
 
-#: fortran/symbol.c:4519
+#: fortran/symbol.c:4533
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr "Komponente %qs in abgeleitetem Typ %qs bei %L könnte nicht C-kompatibel sein"
 
-#: fortran/symbol.c:4533
+#: fortran/symbol.c:4547
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot be declared with both PRIVATE and BIND(C) attributes"
 msgstr "Abgeleiteter Typ %qs bei %L kann nicht gleichzeitig mit beiden Attributen PRIVATE und BIND(C) deklariert werden"
 
-#: fortran/symbol.c:4541
+#: fortran/symbol.c:4555
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr "Abgeleiteter Typ %qs bei %L kann nicht das SEQUENCE-Attribut haben, da er BIND(C) ist"
 
-#: fortran/symbol.c:5018 fortran/symbol.c:5023
+#: fortran/symbol.c:5032 fortran/symbol.c:5037
 #, gcc-internal-format
 msgid "Symbol %qs is used before it is typed at %L"
 msgstr "Symbol %qs wird bei %L verwendet, bevor es typisiert wird"
@@ -61561,7 +61641,7 @@
 msgid "Creating array temporary at %L for argument %qs"
 msgstr "Bei %L wird ein vorübergehendes Feld für Argument %qs erzeugt"
 
-#: fortran/trans-array.c:10693
+#: fortran/trans-array.c:10724
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr "Falscher Ausdruckstyp beim Durchlaufen (%d)"
@@ -61766,12 +61846,12 @@
 msgid "%<dim%> argument of %s intrinsic at %L is not a valid dimension index"
 msgstr "Argument %<dim%> des intrinsischen »%s« bei %L ist kein gültiger Dimensionsindex"
 
-#: fortran/trans-intrinsic.c:10572 fortran/trans-stmt.c:1050
+#: fortran/trans-intrinsic.c:10574 fortran/trans-stmt.c:1050
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, the event component of derived type at %L is not yet supported"
 msgstr "Sorry, die Event-Komponente des abgeleiteten Typs bei %L wird noch nicht unterstützt"
 
-#: fortran/trans-intrinsic.c:10579
+#: fortran/trans-intrinsic.c:10581
 #, gcc-internal-format, gfc-internal-format
 msgid "The event variable at %L shall not be coindexed"
 msgstr "Event-Variable bei %L darf nicht koindiziert sein"
@@ -61813,7 +61893,7 @@
 msgstr "Entschuldigung; für Image-Set bei %2$L ist nur Unterstützung für Ganzzahl-Art %1$d implementiert"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/trans-stmt.c:3346
+#: fortran/trans-stmt.c:3343
 #, gcc-internal-format
 msgid "gfc_trans_select(): Bad type for case expr."
 msgstr "gfc_trans_select(): Bad type for case expr."
@@ -61942,7 +62022,7 @@
 msgid "two or more sections for %s"
 msgstr "zwei oder mehr Abschnitte für %s"
 
-#: lto/lto-partition.c:516
+#: lto/lto-partition.c:570
 #, gcc-internal-format
 msgid "min partition size cannot be greater than max partition size"
 msgstr "Mindestgröße der Partition darf nicht größer als Höchstgröße der Partition sein"
@@ -62077,57 +62157,57 @@
 msgid "Cannot read %s"
 msgstr "»%s« kann nicht gelesen werden"
 
-#: lto/lto.c:2369
+#: lto/lto.c:2337
 #, gcc-internal-format
 msgid "lto_obj_file_open() failed"
 msgstr "lto_obj_file_open() gescheitert"
 
-#: lto/lto.c:2394
+#: lto/lto.c:2362
 #, gcc-internal-format
 msgid "waitpid failed"
 msgstr "waitpid gescheitert"
 
-#: lto/lto.c:2397
+#: lto/lto.c:2365
 #, gcc-internal-format
 msgid "streaming subprocess failed"
 msgstr "Streaming-Kindprozess fehlgeschlagen"
 
-#: lto/lto.c:2400
+#: lto/lto.c:2368
 #, gcc-internal-format
 msgid "streaming subprocess was killed by signal"
 msgstr "Der Streaming-Kindprozess wurde durch ein Signal beendet"
 
-#: lto/lto.c:2476
+#: lto/lto.c:2445
 #, gcc-internal-format
 msgid "no LTRANS output list filename provided"
 msgstr "kein Dateiname für LTRANS-Ausgabeliste angegeben"
 
-#: lto/lto.c:2564
+#: lto/lto.c:2525
 #, gcc-internal-format
 msgid "opening LTRANS output list %s: %m"
 msgstr "LTRANS-Ausgabeliste »%s« kann nicht geöffnet werden: %m"
 
-#: lto/lto.c:2570
+#: lto/lto.c:2532
 #, gcc-internal-format
 msgid "writing to LTRANS output list %s: %m"
 msgstr "beim Schreiben in LTRANS-Ausgabeliste %s: %m"
 
-#: lto/lto.c:2581
+#: lto/lto.c:2542
 #, gcc-internal-format
 msgid "closing LTRANS output list %s: %m"
 msgstr "LTRANS-Ausgabeliste »%s« kann nicht geschlossen werden: %m"
 
-#: lto/lto.c:2833
+#: lto/lto.c:2794
 #, gcc-internal-format
 msgid "could not open symbol resolution file: %m"
 msgstr "Datei zur Symbolauflösung konnte nicht geöffnet werden: %m"
 
-#: lto/lto.c:2954
+#: lto/lto.c:2915
 #, gcc-internal-format, gfc-internal-format
 msgid "missing resolution data for %s"
 msgstr "fehlende Auflösungsdaten für %s"
 
-#: lto/lto.c:2986
+#: lto/lto.c:2947
 #, gcc-internal-format
 msgid "errors during merging of translation units"
 msgstr "Fehler beim Einfügen von Übersetzungseinheiten"
@@ -63070,6 +63150,21 @@
 msgid "creating selector for nonexistent method %qE"
 msgstr "für nicht existierende Methode %qE wird Selektor erzeugt"
 
+#~ msgid "Warn if the loop cannot be optimized due to nontrivial assumptions."
+#~ msgstr "Warnen, wenn Schleife wegen nichttrivialer Annahmen nicht optimiert werden kann."
+
+#~ msgid "Expected constant array-spec in initializer list at %L"
+#~ msgstr "Konstante Feldangabe erwartet in Initialisierungsliste bei %L"
+
+#~ msgid "Errmsg-variable at %L must be a scalar CHARACTER variable"
+#~ msgstr "ERRMSG-Variable bei %L muss skalare CHARACTER-Variable sein"
+
+#~ msgid "Second argument MOD at %L is zero"
+#~ msgstr "Zweites Argument von MOD bei %L ist Null"
+
+#~ msgid "Second argument of MOD at %L is zero"
+#~ msgstr "Zweites Argument von MOD bei %L ist Null"
+
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=84807
 #~ msgid "Support Control-flow Enforcement Technology (CET) built-in functions and code generation."
 #~ msgstr "Eingebaute Funktionen und Codeerzeugung für Control-flow Enforcement Technology (CET) unterstützen."
Index: gcc/po/ja.po
===================================================================
--- gcc/po/ja.po	(.../tags/gcc_8_2_0_release)
+++ gcc/po/ja.po	(.../branches/gcc-8-branch)
@@ -20,7 +20,7 @@
 msgstr ""
 "Project-Id-Version: gcc 8.1.0\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2018-05-01 20:30+0000\n"
+"POT-Creation-Date: 2018-07-25 14:25+0000\n"
 "PO-Revision-Date: 2018-07-17 22:26+0900\n"
 "Last-Translator: Takeshi Hamasaki <hmatrjp@users.sourceforge.jp>\n"
 "Language-Team: Japanese <translation-team-ja@lists.sourceforge.net>\n"
@@ -53,36 +53,36 @@
 msgid "[cannot find %s]"
 msgstr "[%s が見つかりません]"
 
-#: collect2.c:1557
+#: collect2.c:1585
 #, fuzzy, c-format
 #| msgid "collect2 version %s"
 msgid "collect2 version %s\n"
 msgstr "collect2 バージョン %s"
 
-#: collect2.c:1664
+#: collect2.c:1692
 #, c-format
 msgid "%d constructor found\n"
 msgid_plural "%d constructors found\n"
 msgstr[0] "%d 個のコンストラクタが見つかりました\n"
 
-#: collect2.c:1668
+#: collect2.c:1696
 #, c-format
 msgid "%d destructor found\n"
 msgid_plural "%d destructors found\n"
 msgstr[0] "%d 個のデストラクタが見つかりました\n"
 
-#: collect2.c:1672
+#: collect2.c:1700
 #, c-format
 msgid "%d frame table found\n"
 msgid_plural "%d frame tables found\n"
 msgstr[0] "%d 個のフレーム表が見つかりました\n"
 
-#: collect2.c:1836
+#: collect2.c:1864
 #, c-format
 msgid "[Leaving %s]\n"
 msgstr "[%s を離れます]\n"
 
-#: collect2.c:2068
+#: collect2.c:2094
 #, c-format
 msgid ""
 "\n"
@@ -91,7 +91,7 @@
 "\n"
 "write_c_file - 出力名は %s、接頭辞は %s\n"
 
-#: collect2.c:2584
+#: collect2.c:2610
 #, c-format
 msgid ""
 "\n"
@@ -116,7 +116,7 @@
 msgid "%s: some warnings being treated as errors"
 msgstr "%s: いくつかの警告はエラーとして取り扱われます\n"
 
-#: diagnostic.c:324 input.c:222 input.c:1834 c-family/c-opts.c:1377
+#: diagnostic.c:324 input.c:222 input.c:1834 c-family/c-opts.c:1392
 #: fortran/cpp.c:576 fortran/error.c:1008 fortran/error.c:1028
 msgid "<built-in>"
 msgstr "<組み込み>"
@@ -214,13 +214,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:4164 config/arc/arc.c:5784 config/i386/i386.c:17302
+#: final.c:4164 config/arc/arc.c:5775 config/i386/i386.c:17305
 #: config/pdp11/pdp11.c:1715
 #, c-format
 msgid "floating constant misused"
 msgstr "浮動小数定数を使い損ねました"
 
-#: final.c:4222 config/arc/arc.c:5881 config/i386/i386.c:17393
+#: final.c:4222 config/arc/arc.c:5872 config/i386/i386.c:17396
 #: config/pdp11/pdp11.c:1756
 #, c-format
 msgid "invalid expression as operand"
@@ -1235,7 +1235,7 @@
 msgid "GCSE disabled"
 msgstr "GCSE が無効です"
 
-#: gimple-ssa-isolate-paths.c:542 c/c-typeck.c:10240
+#: gimple-ssa-isolate-paths.c:542 c/c-typeck.c:10245
 #, gcc-internal-format
 msgid "function returns address of local variable"
 msgstr "関数が局所変数のアドレスを返します"
@@ -1542,7 +1542,7 @@
 msgid "options enabled: "
 msgstr "有効オプション: "
 
-#: tree-diagnostic.c:299 c/c-decl.c:5419 c/c-typeck.c:7259 cp/error.c:1042
+#: tree-diagnostic.c:299 c/c-decl.c:5439 c/c-typeck.c:7264 cp/error.c:1042
 #: c-family/c-pretty-print.c:413
 #, gcc-internal-format
 msgid "<anonymous>"
@@ -3061,71 +3061,71 @@
 msgstr "strfmon 書式の長さ修飾子"
 
 #. Handle deferred options from command-line.
-#: c-family/c-opts.c:1402 fortran/cpp.c:590
+#: c-family/c-opts.c:1417 fortran/cpp.c:590
 msgid "<command-line>"
 msgstr "<コマンドライン>"
 
-#: config/aarch64/aarch64.c:6613
+#: config/aarch64/aarch64.c:6629
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "unsupported operand for code '%c'"
 msgstr "コード '%c' に対する無効な被演算子です"
 
-#: config/aarch64/aarch64.c:6624 config/aarch64/aarch64.c:6640
-#: config/aarch64/aarch64.c:6652 config/aarch64/aarch64.c:6663
-#: config/aarch64/aarch64.c:6673 config/aarch64/aarch64.c:6694
-#: config/aarch64/aarch64.c:6764 config/aarch64/aarch64.c:6775
-#: config/aarch64/aarch64.c:6789 config/aarch64/aarch64.c:7011
-#: config/aarch64/aarch64.c:7029
+#: config/aarch64/aarch64.c:6640 config/aarch64/aarch64.c:6656
+#: config/aarch64/aarch64.c:6668 config/aarch64/aarch64.c:6679
+#: config/aarch64/aarch64.c:6689 config/aarch64/aarch64.c:6710
+#: config/aarch64/aarch64.c:6780 config/aarch64/aarch64.c:6791
+#: config/aarch64/aarch64.c:6805 config/aarch64/aarch64.c:7027
+#: config/aarch64/aarch64.c:7045
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "invalid operand for '%%%c'"
 msgstr "コード '%c' に対する無効な被演算子です"
 
-#: config/aarch64/aarch64.c:6709 config/aarch64/aarch64.c:6720
-#: config/aarch64/aarch64.c:6871 config/aarch64/aarch64.c:6882
+#: config/aarch64/aarch64.c:6725 config/aarch64/aarch64.c:6736
+#: config/aarch64/aarch64.c:6887 config/aarch64/aarch64.c:6898
 #, fuzzy, c-format
 #| msgid "invalid vector permutation constant"
 msgid "invalid vector constant"
 msgstr "無効なベクトル順列定数です"
 
-#: config/aarch64/aarch64.c:6732 config/aarch64/aarch64.c:6744
-#: config/aarch64/aarch64.c:6755
+#: config/aarch64/aarch64.c:6748 config/aarch64/aarch64.c:6760
+#: config/aarch64/aarch64.c:6771
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6823 config/arm/arm.c:22704
+#: config/aarch64/aarch64.c:6839 config/arm/arm.c:22704
 #, c-format
 msgid "missing operand"
 msgstr "被演算子がありません"
 
-#: config/aarch64/aarch64.c:6908
+#: config/aarch64/aarch64.c:6924
 #, fuzzy, c-format
 #| msgid "invalid insn:"
 msgid "invalid constant"
 msgstr "無効な命令:"
 
-#: config/aarch64/aarch64.c:6911
+#: config/aarch64/aarch64.c:6927
 #, fuzzy, c-format
 #| msgid "invalid %%d operand"
 msgid "invalid operand"
 msgstr "無効な %%d 被演算子です"
 
-#: config/aarch64/aarch64.c:7040 config/aarch64/aarch64.c:7045
+#: config/aarch64/aarch64.c:7056 config/aarch64/aarch64.c:7061
 #, fuzzy, c-format
 #| msgid "invalid operand code '%c'"
 msgid "invalid operand prefix '%%%c'"
 msgstr "無効な被演算子コード '%c' です"
 
-#: config/aarch64/aarch64.c:7062
+#: config/aarch64/aarch64.c:7078
 #, fuzzy, c-format
 #| msgid "invalid addressing mode"
 msgid "invalid address mode"
 msgstr "無効なアドレスモードです"
 
-#: config/alpha/alpha.c:5125 config/i386/i386.c:18558
-#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21798
+#: config/alpha/alpha.c:5125 config/i386/i386.c:18561
+#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21875
 #: config/sparc/sparc.c:9290
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
@@ -3142,7 +3142,7 @@
 msgstr "無効な %%r 値"
 
 #: config/alpha/alpha.c:5223 config/ia64/ia64.c:5534
-#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21506
+#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21583
 #: config/xtensa/xtensa.c:2429
 #, c-format
 msgid "invalid %%R value"
@@ -3149,13 +3149,13 @@
 msgstr "無効な %%R 値"
 
 #: config/alpha/alpha.c:5229 config/powerpcspe/powerpcspe.c:23933
-#: config/rs6000/rs6000.c:21426 config/xtensa/xtensa.c:2396
+#: config/rs6000/rs6000.c:21503 config/xtensa/xtensa.c:2396
 #, c-format
 msgid "invalid %%N value"
 msgstr "無効な %%N 値"
 
 #: config/alpha/alpha.c:5237 config/powerpcspe/powerpcspe.c:23961
-#: config/rs6000/rs6000.c:21454
+#: config/rs6000/rs6000.c:21531
 #, c-format
 msgid "invalid %%P value"
 msgstr "無効な %%P 値"
@@ -3186,7 +3186,7 @@
 msgstr "無効な %%U 値"
 
 #: config/alpha/alpha.c:5323 config/powerpcspe/powerpcspe.c:24021
-#: config/rs6000/rs6000.c:21514
+#: config/rs6000/rs6000.c:21591
 #, c-format
 msgid "invalid %%s value"
 msgstr "無効な %%s 値"
@@ -3197,7 +3197,7 @@
 msgstr "無効な %%C 値"
 
 #: config/alpha/alpha.c:5371 config/powerpcspe/powerpcspe.c:23797
-#: config/rs6000/rs6000.c:21290
+#: config/rs6000/rs6000.c:21367
 #, c-format
 msgid "invalid %%E value"
 msgstr "無効な %%E 値"
@@ -3208,7 +3208,7 @@
 msgstr ""
 
 #: config/alpha/alpha.c:5405 config/cr16/cr16.c:1569
-#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21803
+#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21880
 #: config/spu/spu.c:1458
 #, c-format
 msgid "invalid %%xn code"
@@ -3220,61 +3220,61 @@
 msgid "invalid operand address"
 msgstr "無効なアドレスです"
 
-#: config/arc/arc.c:3810
+#: config/arc/arc.c:3808
 #, fuzzy, c-format
 #| msgid "invalid operand to %%R code"
 msgid "invalid operand to %%Z code"
 msgstr "%%R コードに対する無効な被演算子"
 
-#: config/arc/arc.c:3818
+#: config/arc/arc.c:3816
 #, fuzzy, c-format
 #| msgid "invalid operand to %%R code"
 msgid "invalid operand to %%z code"
 msgstr "%%R コードに対する無効な被演算子"
 
-#: config/arc/arc.c:3826
+#: config/arc/arc.c:3824
 #, fuzzy, c-format
 #| msgid "invalid operand to %%R code"
 msgid "invalid operands to %%c code"
 msgstr "%%R コードに対する無効な被演算子"
 
-#: config/arc/arc.c:3834
+#: config/arc/arc.c:3832
 #, fuzzy, c-format
 #| msgid "invalid operand to %%R code"
 msgid "invalid operand to %%M code"
 msgstr "%%R コードに対する無効な被演算子"
 
-#: config/arc/arc.c:3842 config/m32r/m32r.c:2100
+#: config/arc/arc.c:3840 config/m32r/m32r.c:2100
 #, c-format
 msgid "invalid operand to %%p code"
 msgstr "%%p コードへの無効な被演算子です"
 
-#: config/arc/arc.c:3853 config/m32r/m32r.c:2093
+#: config/arc/arc.c:3851 config/m32r/m32r.c:2093
 #, c-format
 msgid "invalid operand to %%s code"
 msgstr "%%s コードへの無効な被演算子です"
 
-#: config/arc/arc.c:4001 config/m32r/m32r.c:2126
+#: config/arc/arc.c:3999 config/m32r/m32r.c:2126
 #, c-format
 msgid "invalid operand to %%R code"
 msgstr "%%R コードに対する無効な被演算子"
 
-#: config/arc/arc.c:4077 config/m32r/m32r.c:2149
+#: config/arc/arc.c:4075 config/m32r/m32r.c:2149
 #, c-format
 msgid "invalid operand to %%H/%%L code"
 msgstr "%%H/%%L コードに対する無効な被演算子"
 
-#: config/arc/arc.c:4145 config/m32r/m32r.c:2220
+#: config/arc/arc.c:4143 config/m32r/m32r.c:2220
 #, c-format
 msgid "invalid operand to %%U code"
 msgstr "%%U コードに対する無効な被演算子"
 
-#: config/arc/arc.c:4157
+#: config/arc/arc.c:4155
 #, c-format
 msgid "invalid operand to %%V code"
 msgstr "%%V コードに対する無効な被演算子"
 
-#: config/arc/arc.c:4214
+#: config/arc/arc.c:4212
 #, fuzzy, c-format
 #| msgid "invalid operand to %%R code"
 msgid "invalid operand to %%O code"
@@ -3282,19 +3282,19 @@
 
 #. Unknown flag.
 #. Undocumented flag.
-#: config/arc/arc.c:4240 config/epiphany/epiphany.c:1305
-#: config/m32r/m32r.c:2247 config/nds32/nds32.c:3079 config/sparc/sparc.c:9569
+#: config/arc/arc.c:4238 config/epiphany/epiphany.c:1305
+#: config/m32r/m32r.c:2247 config/nds32/nds32.c:3080 config/sparc/sparc.c:9569
 #, c-format
 msgid "invalid operand output code"
 msgstr "無効な被演算子出力コード"
 
-#: config/arc/arc.c:5869
+#: config/arc/arc.c:5860
 #, fuzzy, c-format
 #| msgid "invalid UNSPEC as operand"
 msgid "invalid UNSPEC as operand: %d"
 msgstr "被演算子として無効な UNSPEC です"
 
-#: config/arc/arc.c:6158 config/cris/cris.c:2568
+#: config/arc/arc.c:6149 config/cris/cris.c:2568
 msgid "unrecognized supposed constant"
 msgstr "認識できない定数のようなもの"
 
@@ -3330,7 +3330,7 @@
 #: config/arm/arm.c:22685 config/arm/arm.c:22692 config/bfin/bfin.c:1441
 #: config/bfin/bfin.c:1448 config/bfin/bfin.c:1455 config/bfin/bfin.c:1462
 #: config/bfin/bfin.c:1471 config/bfin/bfin.c:1478 config/bfin/bfin.c:1485
-#: config/bfin/bfin.c:1492 config/nds32/nds32.c:3098
+#: config/bfin/bfin.c:1492 config/nds32/nds32.c:3099
 #, c-format
 msgid "invalid operand for code '%c'"
 msgstr "コード '%c' に対する無効な被演算子です"
@@ -3687,110 +3687,110 @@
 msgid "bad output_condmove_single operand"
 msgstr "誤った output_condmove_single 被演算子"
 
-#: config/i386/i386.c:17387
+#: config/i386/i386.c:17390
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "被演算子として無効な UNSPEC です"
 
-#: config/i386/i386.c:17925
+#: config/i386/i386.c:17928
 #, fuzzy, c-format
 #| msgid "invalid use of %<restrict%>"
 msgid "invalid use of register '%s'"
 msgstr "%<restrict%> の誤った使用法です"
 
-#: config/i386/i386.c:17930
+#: config/i386/i386.c:17933
 #, fuzzy, c-format
 #| msgid "invalid use of type"
 msgid "invalid use of asm flag output"
 msgstr "無効な型の使用法です"
 
-#: config/i386/i386.c:18160
+#: config/i386/i386.c:18163
 #, fuzzy, c-format
 #| msgid "invalid operand size for operand code '%c'"
 msgid "invalid operand size for operand code 'O'"
 msgstr "演算子コード '%c' に対する無効な被演算子サイズです"
 
-#: config/i386/i386.c:18195
+#: config/i386/i386.c:18198
 #, fuzzy, c-format
 #| msgid "invalid operand size for operand code '%c'"
 msgid "invalid operand size for operand code 'z'"
 msgstr "演算子コード '%c' に対する無効な被演算子サイズです"
 
-#: config/i386/i386.c:18264
+#: config/i386/i386.c:18267
 #, fuzzy, c-format
 #| msgid "invalid operand type used with operand code '%c'"
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "被演算子コード '%c' に無効な被演算子型が使用されました"
 
-#: config/i386/i386.c:18269
+#: config/i386/i386.c:18272
 #, fuzzy, c-format
 #| msgid "invalid operand size for operand code '%c'"
 msgid "invalid operand size for operand code 'Z'"
 msgstr "演算子コード '%c' に対する無効な被演算子サイズです"
 
-#: config/i386/i386.c:18346
+#: config/i386/i386.c:18349
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "被演算子は条件コードではありません。無効な被演算子コード 'Y' です"
 
-#: config/i386/i386.c:18425
+#: config/i386/i386.c:18428
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "被演算子は条件コードではありません。無効な被演算子コード 'D' です"
 
-#: config/i386/i386.c:18443
+#: config/i386/i386.c:18446
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'D'"
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "被演算子は条件コードではありません。無効な被演算子コード 'D' です"
 
-#: config/i386/i386.c:18456
+#: config/i386/i386.c:18459
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'D'"
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "被演算子は条件コードではありません。無効な被演算子コード 'D' です"
 
-#: config/i386/i386.c:18471
+#: config/i386/i386.c:18474
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'D'"
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr "被演算子は条件コードではありません。無効な被演算子コード 'D' です"
 
-#: config/i386/i386.c:18499
+#: config/i386/i386.c:18502
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'D'"
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr "被演算子は条件コードではありません。無効な被演算子コード 'D' です"
 
-#: config/i386/i386.c:18517
+#: config/i386/i386.c:18520
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'D'"
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr "被演算子は条件コードではありません。無効な被演算子コード 'D' です"
 
-#: config/i386/i386.c:18540
+#: config/i386/i386.c:18543
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'D'"
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "被演算子は条件コードではありません。無効な被演算子コード 'D' です"
 
-#: config/i386/i386.c:18626
+#: config/i386/i386.c:18629
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "無効な被演算子コード '%c' です"
 
-#: config/i386/i386.c:18688
+#: config/i386/i386.c:18691
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "演算子に対する無効な制約です"
 
-#: config/i386/i386.c:18738
+#: config/i386/i386.c:18741
 #, fuzzy, c-format
 #| msgid "invalid vector permutation constant"
 msgid "invalid vector immediate"
 msgstr "無効なベクトル順列定数です"
 
-#: config/i386/i386.c:29572
+#: config/i386/i386.c:29575
 msgid "unknown insn mode"
 msgstr "不明な命令モード"
 
@@ -3829,7 +3829,7 @@
 msgstr "無効な %%P 被演算子です"
 
 #: config/iq2000/iq2000.c:3185 config/powerpcspe/powerpcspe.c:23951
-#: config/rs6000/rs6000.c:21444
+#: config/rs6000/rs6000.c:21521
 #, c-format
 msgid "invalid %%p value"
 msgstr "無効な %%p 値です"
@@ -3883,7 +3883,7 @@
 msgstr "後置増分アドレスがレジスタではありません"
 
 #: config/m32r/m32r.c:2350 config/m32r/m32r.c:2365
-#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33292
+#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33348
 msgid "bad address"
 msgstr "誤ったアドレスです"
 
@@ -4004,192 +4004,192 @@
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr "'%s' をシェル内で実行して制限値を上げてください\n"
 
-#: config/powerpcspe/powerpcspe.c:4411 config/rs6000/rs6000.c:4258
+#: config/powerpcspe/powerpcspe.c:4411 config/rs6000/rs6000.c:4278
 msgid "-maltivec=le not allowed for big-endian targets"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4423 config/rs6000/rs6000.c:4273
+#: config/powerpcspe/powerpcspe.c:4423 config/rs6000/rs6000.c:4293
 msgid "-mvsx requires hardware floating point"
 msgstr "-mvsx はハードウェア浮動小数を要求します"
 
-#: config/powerpcspe/powerpcspe.c:4431 config/rs6000/rs6000.c:4281
+#: config/powerpcspe/powerpcspe.c:4431 config/rs6000/rs6000.c:4301
 msgid "-mvsx and -mpaired are incompatible"
 msgstr "-mvsx と -mpaired は併用できません"
 
-#: config/powerpcspe/powerpcspe.c:4433 config/rs6000/rs6000.c:4283
+#: config/powerpcspe/powerpcspe.c:4433 config/rs6000/rs6000.c:4303
 msgid "-mvsx needs indexed addressing"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4438 config/rs6000/rs6000.c:4288
+#: config/powerpcspe/powerpcspe.c:4438 config/rs6000/rs6000.c:4308
 msgid "-mvsx and -mno-altivec are incompatible"
 msgstr "-mvsx と -mno-altivec は併用できません"
 
-#: config/powerpcspe/powerpcspe.c:4440 config/rs6000/rs6000.c:4290
+#: config/powerpcspe/powerpcspe.c:4440 config/rs6000/rs6000.c:4310
 msgid "-mno-altivec disables vsx"
 msgstr "-mno-altivec は vsx を無効にします"
 
-#: config/powerpcspe/powerpcspe.c:4648 config/rs6000/rs6000.c:4416
+#: config/powerpcspe/powerpcspe.c:4648 config/rs6000/rs6000.c:4436
 msgid "-mquad-memory requires 64-bit mode"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4651 config/rs6000/rs6000.c:4419
+#: config/powerpcspe/powerpcspe.c:4651 config/rs6000/rs6000.c:4439
 msgid "-mquad-memory-atomic requires 64-bit mode"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4663 config/rs6000/rs6000.c:4431
+#: config/powerpcspe/powerpcspe.c:4663 config/rs6000/rs6000.c:4451
 #, fuzzy
 #| msgid "Generate code in little endian mode"
 msgid "-mquad-memory is not available in little endian mode"
 msgstr "リトルエンディアンモードでコードを生成する"
 
-#: config/powerpcspe/powerpcspe.c:4735 config/rs6000/rs6000.c:4512
+#: config/powerpcspe/powerpcspe.c:4735 config/rs6000/rs6000.c:4532
 msgid "-mtoc-fusion requires 64-bit"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4742 config/rs6000/rs6000.c:4519
+#: config/powerpcspe/powerpcspe.c:4742 config/rs6000/rs6000.c:4539
 msgid "-mtoc-fusion requires medium/large code model"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10915
+#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10947
 msgid "bad move"
 msgstr "誤った move です"
 
-#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21087
+#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21164
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21278
+#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21355
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%e value"
 msgstr "無効な %%H 値"
 
-#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21299
+#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21376
 #, c-format
 msgid "invalid %%f value"
 msgstr "無効な %%f 値です"
 
-#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21308
+#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21385
 #, c-format
 msgid "invalid %%F value"
 msgstr "無効な %%F 値です"
 
-#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21317
+#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21394
 #, c-format
 msgid "invalid %%G value"
 msgstr "無効な %%G 値です"
 
-#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21352
+#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21429
 #, c-format
 msgid "invalid %%j code"
 msgstr "無効な %%j コードです"
 
-#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21362
+#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21439
 #, c-format
 msgid "invalid %%J code"
 msgstr "無効な %%J コードです"
 
-#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21372
+#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21449
 #, c-format
 msgid "invalid %%k value"
 msgstr "無効な %%k 値です"
 
-#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21387
+#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21464
 #: config/xtensa/xtensa.c:2415
 #, c-format
 msgid "invalid %%K value"
 msgstr "無効な %%K 値です"
 
-#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21434
+#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21511
 #, c-format
 msgid "invalid %%O value"
 msgstr "無効な %%O 値です"
 
-#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21481
+#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21558
 #, c-format
 msgid "invalid %%q value"
 msgstr "無効な %%q 値です"
 
-#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21534
+#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21611
 #, c-format
 msgid "invalid %%T value"
 msgstr "無効な %%T 値です"
 
-#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21546
+#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21623
 #, c-format
 msgid "invalid %%u value"
 msgstr "無効な %%u 値です"
 
-#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21560
+#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21637
 #: config/xtensa/xtensa.c:2384
 #, c-format
 msgid "invalid %%v value"
 msgstr "無効な %%v 値です"
 
-#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21627
+#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21704
 #: config/xtensa/xtensa.c:2436
 #, c-format
 msgid "invalid %%x value"
 msgstr "無効な %%x 値です"
 
-#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21747
+#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21824
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "無効な %%y 値です。'Z' 制約を使用してみてください"
 
-#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22282
+#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22359
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22288
+#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22365
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22294
+#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22371
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36572
+#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36628
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "プロトタイプが無い関数に AltiVec 引数が渡されました"
 
-#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38739
+#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38795
 #, fuzzy
 #| msgid "Do not generate a single exit point for each function"
 msgid "Could not generate addis value for fusion"
 msgstr "各関数で単一の終了点を生成しない"
 
-#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38809
+#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38865
 #, fuzzy
 #| msgid "Enable unaligned load/store instruction"
 msgid "Unable to generate load/store offset for fusion"
 msgstr "整列されていない load/store 命令を有効にする"
 
-#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38908
+#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38964
 msgid "Bad GPR fusion"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39126
+#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39182
 msgid "emit_fusion_p9_load, bad reg #1"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39172
+#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39228
 msgid "emit_fusion_p9_load, bad reg #2"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39175
+#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39231
 msgid "emit_fusion_p9_load not MEM"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39213
+#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39269
 msgid "emit_fusion_p9_store, bad reg #1"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39259
+#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39315
 msgid "emit_fusion_p9_store, bad reg #2"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39262
+#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39318
 msgid "emit_fusion_p9_store not MEM"
 msgstr ""
 
@@ -4598,14 +4598,14 @@
 #: c/gimple-parser.c:188 c/gimple-parser.c:197 c/gimple-parser.c:226
 #: c/gimple-parser.c:1375 c/gimple-parser.c:1404 c/gimple-parser.c:1484
 #: c/gimple-parser.c:1511 c/c-parser.c:3204 c/c-parser.c:9967
-#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27841
-#: cp/parser.c:28430
+#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27838
+#: cp/parser.c:28427
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "%<;%> が予期されます"
 
 #: c/c-parser.c:2431 c/c-parser.c:7573 c/c-parser.c:8015 c/c-parser.c:8058
-#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27839 cp/parser.c:28448
+#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27836 cp/parser.c:28445
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "%<,%> が予期されます"
@@ -4620,7 +4620,7 @@
 #: c/gimple-parser.c:821 c/gimple-parser.c:837 c/gimple-parser.c:853
 #: c/gimple-parser.c:880 c/gimple-parser.c:915 c/gimple-parser.c:1038
 #: c/gimple-parser.c:1209 c/gimple-parser.c:1220 c/gimple-parser.c:1342
-#: c/gimple-parser.c:1441 cp/parser.c:28478
+#: c/gimple-parser.c:1441 cp/parser.c:28475
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "%<)%> が予期されます"
@@ -4628,7 +4628,7 @@
 #: c/c-parser.c:3824 c/c-parser.c:4733 c/c-parser.c:4769 c/c-parser.c:6441
 #: c/c-parser.c:8125 c/c-parser.c:8983 c/c-parser.c:9127 c/c-parser.c:11588
 #: c/c-parser.c:18220 c/c-parser.c:18222 c/gimple-parser.c:1015
-#: cp/parser.c:28442
+#: cp/parser.c:28439
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "%<]%> が予期されます"
@@ -4642,7 +4642,7 @@
 #: c/c-parser.c:17792 c/gimple-parser.c:363 c/gimple-parser.c:811
 #: c/gimple-parser.c:873 c/gimple-parser.c:911 c/gimple-parser.c:1198
 #: c/gimple-parser.c:1339 c/gimple-parser.c:1438 c/c-parser.c:11911
-#: cp/parser.c:28433
+#: cp/parser.c:28430
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "%<(%> が予期されます"
@@ -4649,7 +4649,7 @@
 
 #: c/c-parser.c:4903 c/c-parser.c:10310 c/c-parser.c:16212 c/c-parser.c:18449
 #: c/gimple-parser.c:141 c/gimple-parser.c:1444 c/c-parser.c:3018
-#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18155 cp/parser.c:28439
+#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18152 cp/parser.c:28436
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "%<{%> が予期されます"
@@ -4659,13 +4659,13 @@
 #: c/c-parser.c:12351 c/c-parser.c:12493 c/c-parser.c:12864 c/c-parser.c:12957
 #: c/c-parser.c:13566 c/c-parser.c:17636 c/c-parser.c:17695
 #: c/gimple-parser.c:431 c/gimple-parser.c:1492 c/gimple-parser.c:1519
-#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28472 cp/parser.c:29597
-#: cp/parser.c:32279
+#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28469 cp/parser.c:29594
+#: cp/parser.c:32276
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "%<:%> が予期されます"
 
-#: c/c-parser.c:5974 cp/parser.c:28365
+#: c/c-parser.c:5974 cp/parser.c:28362
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "%<while%> が予期されます"
@@ -4674,18 +4674,18 @@
 msgid "expected %<.%>"
 msgstr "%<.%> が予期されます"
 
-#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30172
-#: cp/parser.c:30246
+#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30169
+#: cp/parser.c:30243
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "%<@end%> が予期されます"
 
-#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28457
+#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28454
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "%<>%> が予期されます"
 
-#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28481
+#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28478
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "%<,%> または %<)%> が予期されます"
@@ -4693,32 +4693,32 @@
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15190 c/c-parser.c:15234 c/c-parser.c:15466 c/c-parser.c:15701
 #: c/c-parser.c:17833 c/gimple-parser.c:286 c/c-parser.c:4792
-#: cp/parser.c:28460
+#: cp/parser.c:28457
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "%<=%> が予期されます"
 
-#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28436
-#: cp/parser.c:30389
+#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28433
+#: cp/parser.c:30386
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "%<}%> が予期されます"
 
-#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35674
+#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35671
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "%<#pragma omp section%> または %<}%> が予期されます"
 
-#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28445 cp/parser.c:31535
+#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28442 cp/parser.c:31532
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "%<[%> が予期されます"
 
-#: c/c-typeck.c:7847
+#: c/c-typeck.c:7852
 msgid "(anonymous)"
 msgstr "(無名)"
 
-#: c/gimple-parser.c:795 cp/parser.c:15791 cp/parser.c:28454
+#: c/gimple-parser.c:795 cp/parser.c:15788 cp/parser.c:28451
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "%<<%> が予期されます"
@@ -5000,11 +5000,11 @@
 msgid "%r%s:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr ""
 
-#: cp/pt.c:1949 cp/semantics.c:5268
+#: cp/pt.c:1949 cp/semantics.c:5271
 msgid "candidates are:"
 msgstr "候補:"
 
-#: cp/pt.c:1951 cp/pt.c:22975
+#: cp/pt.c:1951 cp/pt.c:23053
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "候補:"
@@ -5049,27 +5049,27 @@
 msgid "source type is not polymorphic"
 msgstr ""
 
-#: cp/typeck.c:6083 c/c-typeck.c:4261
+#: cp/typeck.c:6083 c/c-typeck.c:4266
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "単項マイナスへの引数の型が間違っています"
 
-#: cp/typeck.c:6084 c/c-typeck.c:4248
+#: cp/typeck.c:6084 c/c-typeck.c:4253
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "単項プラスへの引数の型が間違っています"
 
-#: cp/typeck.c:6111 c/c-typeck.c:4302
+#: cp/typeck.c:6111 c/c-typeck.c:4307
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "ビット反転への引数の型が間違っています"
 
-#: cp/typeck.c:6128 c/c-typeck.c:4310
+#: cp/typeck.c:6128 c/c-typeck.c:4315
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "abs への引数の型が間違っています"
 
-#: cp/typeck.c:6140 c/c-typeck.c:4322
+#: cp/typeck.c:6140 c/c-typeck.c:4327
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "複素共役(~)への引数の型が間違っています"
@@ -5318,73 +5318,73 @@
 msgid "Expected attribute bit name"
 msgstr "packed 属性は必要ありません"
 
-#: fortran/module.c:3223
+#: fortran/module.c:3225
 #, fuzzy
 msgid "Expected integer string"
 msgstr "セクションポインタを欠いています"
 
-#: fortran/module.c:3227
+#: fortran/module.c:3229
 msgid "Error converting integer"
 msgstr ""
 
-#: fortran/module.c:3249
+#: fortran/module.c:3251
 #, fuzzy
 msgid "Expected real string"
 msgstr "終端されていないフォーマット文字列"
 
-#: fortran/module.c:3474
+#: fortran/module.c:3476
 msgid "Expected expression type"
 msgstr ""
 
-#: fortran/module.c:3554
+#: fortran/module.c:3556
 msgid "Bad operator"
 msgstr ""
 
-#: fortran/module.c:3671
+#: fortran/module.c:3673
 #, fuzzy
 msgid "Bad type in constant expression"
 msgstr "定数式がオーバーフローしました"
 
-#: fortran/module.c:7038
+#: fortran/module.c:7040
 #, fuzzy
 msgid "Unexpected end of module"
 msgstr "予期しない型が `id' (%s) に指定されました"
 
-#: fortran/parse.c:1757
+#: fortran/parse.c:1761
 msgid "arithmetic IF"
 msgstr ""
 
-#: fortran/parse.c:1766
+#: fortran/parse.c:1770
 msgid "attribute declaration"
 msgstr "属性宣言です"
 
-#: fortran/parse.c:1802
+#: fortran/parse.c:1806
 msgid "data declaration"
 msgstr "データ宣言です"
 
-#: fortran/parse.c:1820
+#: fortran/parse.c:1824
 #, fuzzy
 msgid "derived type declaration"
 msgstr "空の宣言です"
 
-#: fortran/parse.c:1947
+#: fortran/parse.c:1951
 msgid "block IF"
 msgstr ""
 
-#: fortran/parse.c:1956
+#: fortran/parse.c:1960
 msgid "implied END DO"
 msgstr ""
 
-#: fortran/parse.c:2050 fortran/resolve.c:11199
+#: fortran/parse.c:2054 fortran/resolve.c:11219
 msgid "assignment"
 msgstr "代入"
 
-#: fortran/parse.c:2053 fortran/resolve.c:11250 fortran/resolve.c:11253
+#: fortran/parse.c:2057 fortran/resolve.c:11270 fortran/resolve.c:11273
 #, fuzzy
 msgid "pointer assignment"
 msgstr "代入"
 
-#: fortran/parse.c:2071
+#: fortran/parse.c:2075
 msgid "simple IF"
 msgstr ""
 
@@ -5499,107 +5499,112 @@
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:3878
+#: fortran/resolve.c:3879
 #, c-format
+msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
+msgstr ""
+
+#: fortran/resolve.c:3884
+#, c-format
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3893
+#: fortran/resolve.c:3899
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3926
+#: fortran/resolve.c:3932
 #, c-format
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3949
+#: fortran/resolve.c:3955
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:3963
+#: fortran/resolve.c:3969
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr ""
 
-#: fortran/resolve.c:4015
+#: fortran/resolve.c:4021
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr ""
 
-#: fortran/resolve.c:4021
+#: fortran/resolve.c:4027
 #, c-format
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4034
+#: fortran/resolve.c:4040
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L; did you mean '%s'?"
 msgstr ""
 
-#: fortran/resolve.c:4037
+#: fortran/resolve.c:4043
 #, fuzzy, c-format
 #| msgid "<unknown operator>"
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr "<不明な演算子>"
 
-#: fortran/resolve.c:4040
+#: fortran/resolve.c:4046
 #, c-format
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:4044
+#: fortran/resolve.c:4050
 #, c-format
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4132
+#: fortran/resolve.c:4138
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr ""
 
-#: fortran/resolve.c:6849
+#: fortran/resolve.c:6855
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.c:6853
+#: fortran/resolve.c:6859
 msgid "iterator variable"
 msgstr ""
 
-#: fortran/resolve.c:6857
+#: fortran/resolve.c:6863
 msgid "Start expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:6861
+#: fortran/resolve.c:6867
 msgid "End expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:6865
+#: fortran/resolve.c:6871
 msgid "Step expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:7150 fortran/resolve.c:7153
+#: fortran/resolve.c:7156 fortran/resolve.c:7159
 msgid "DEALLOCATE object"
 msgstr "DEALLOCATE オブジェクト"
 
-#: fortran/resolve.c:7525 fortran/resolve.c:7528
+#: fortran/resolve.c:7531 fortran/resolve.c:7534
 msgid "ALLOCATE object"
 msgstr "ALLOCATE オブジェクト"
 
-#: fortran/resolve.c:7720 fortran/resolve.c:9417
+#: fortran/resolve.c:7726 fortran/resolve.c:9428
 msgid "STAT variable"
 msgstr "STAT 変数"
 
-#: fortran/resolve.c:7764 fortran/resolve.c:9429
+#: fortran/resolve.c:7770 fortran/resolve.c:9440
 msgid "ERRMSG variable"
 msgstr "ERRMSG 変数"
 
-#: fortran/resolve.c:9219
+#: fortran/resolve.c:9230
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.c:9441
+#: fortran/resolve.c:9452
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
@@ -5632,7 +5637,7 @@
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:10154
+#: fortran/trans-expr.c:10157
 msgid "Assignment of scalar to unallocated array"
 msgstr ""
 
@@ -5641,12 +5646,12 @@
 msgid "Unequal character lengths (%ld/%ld) in %s"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:8088
+#: fortran/trans-intrinsic.c:8090
 #, fuzzy, c-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative (its value is %ld)"
 msgstr "関数呼び出しが集合体の値を持っています"
 
-#: fortran/trans-intrinsic.c:8120
+#: fortran/trans-intrinsic.c:8122
 msgid "Argument NCOPIES of REPEAT intrinsic is too large"
 msgstr ""
 
@@ -5667,15 +5672,15 @@
 msgid "Invalid image number %d in SYNC IMAGES"
 msgstr ""
 
-#: fortran/trans-stmt.c:2180
+#: fortran/trans-stmt.c:2177
 msgid "Loop iterates infinitely"
 msgstr ""
 
-#: fortran/trans-stmt.c:2200 fortran/trans-stmt.c:2456
+#: fortran/trans-stmt.c:2197 fortran/trans-stmt.c:2453
 msgid "Loop variable has been modified"
 msgstr ""
 
-#: fortran/trans-stmt.c:2309
+#: fortran/trans-stmt.c:2306
 msgid "DO step value is zero"
 msgstr ""
 
@@ -6337,10 +6342,10 @@
 msgid "Allow dollar signs in entity names."
 msgstr ""
 
-#: fortran/lang.opt:485 config/alpha/alpha.opt:31 common.opt:783
-#: common.opt:985 common.opt:989 common.opt:993 common.opt:997 common.opt:1532
-#: common.opt:1588 common.opt:1712 common.opt:1716 common.opt:1946
-#: common.opt:2116 common.opt:2792
+#: fortran/lang.opt:485 config/alpha/alpha.opt:31 common.opt:649
+#: common.opt:783 common.opt:989 common.opt:993 common.opt:997 common.opt:1001
+#: common.opt:1536 common.opt:1592 common.opt:1716 common.opt:1720
+#: common.opt:1950 common.opt:2120 common.opt:2796
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr "何もしない。後方互換性のために残されている。"
 
@@ -6577,12 +6582,12 @@
 msgstr ""
 
 #: fortran/lang.opt:751 c-family/c.opt:1356 c-family/c.opt:1384
-#: c-family/c.opt:1634 config/pa/pa.opt:42 config/pa/pa.opt:70 common.opt:1154
-#: common.opt:1333 common.opt:1408 common.opt:1676 common.opt:1799
-#: common.opt:2169 common.opt:2205 common.opt:2298 common.opt:2302
-#: common.opt:2407 common.opt:2498 common.opt:2506 common.opt:2514
-#: common.opt:2522 common.opt:2623 common.opt:2675 common.opt:2755
-#: common.opt:2893 common.opt:2897 common.opt:2901 common.opt:2905
+#: c-family/c.opt:1634 config/pa/pa.opt:42 config/pa/pa.opt:70 common.opt:1158
+#: common.opt:1337 common.opt:1412 common.opt:1680 common.opt:1803
+#: common.opt:2173 common.opt:2209 common.opt:2302 common.opt:2306
+#: common.opt:2411 common.opt:2502 common.opt:2510 common.opt:2518
+#: common.opt:2526 common.opt:2627 common.opt:2679 common.opt:2759
+#: common.opt:2897 common.opt:2901 common.opt:2905 common.opt:2909
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr "何もしない。後方互換性のために残されている。"
 
@@ -6646,7 +6651,7 @@
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:220 c-family/c.opt:224
 #: c-family/c.opt:236 c-family/c.opt:1855 c-family/c.opt:1863 brig/lang.opt:39
-#: config/darwin.opt:56 common.opt:338 common.opt:341 common.opt:3046
+#: config/darwin.opt:56 common.opt:338 common.opt:341 common.opt:3050
 #, c-format
 msgid "missing filename after %qs"
 msgstr "%qs の後にファイル名がありません"
@@ -7415,7 +7420,7 @@
 #: c-family/c.opt:1525 c-family/c.opt:1528 c-family/c.opt:1569
 #: c-family/c.opt:1704 c-family/c.opt:1731 c-family/c.opt:1771
 #: c-family/c.opt:1802 c-family/c.opt:1806 c-family/c.opt:1822
-#: config/ia64/ia64.opt:167 config/ia64/ia64.opt:170 c-family/c-opts.c:434
+#: config/ia64/ia64.opt:167 config/ia64/ia64.opt:170 c-family/c-opts.c:432
 #, gcc-internal-format
 msgid "switch %qs is no longer supported"
 msgstr "%qs スイッチは既にサポートされていません"
@@ -16739,10 +16744,6 @@
 msgid "Warn if dereferencing a NULL pointer may lead to erroneous or undefined behavior."
 msgstr ""
 
-#: common.opt:649
-msgid "Warn if the loop cannot be optimized due to nontrivial assumptions."
-msgstr ""
-
 #: common.opt:656
 msgid "Warn about some C++ One Definition Rule violations during link time optimization."
 msgstr ""
@@ -16979,286 +16980,286 @@
 msgid "-dumpdir <dir>\tSet the directory name to be used for dumps."
 msgstr "-dumpdir <dir>\tダンプ用に使用されるディレクトリ名を設定する"
 
-#: common.opt:946
+#: common.opt:950
 msgid "The version of the C++ ABI in use."
 msgstr ""
 
-#: common.opt:950
+#: common.opt:954
 msgid "Aggressively optimize loops using language constraints."
 msgstr ""
 
-#: common.opt:954
+#: common.opt:958
 #, fuzzy
 #| msgid "Align the start of functions"
 msgid "Align the start of functions."
 msgstr "関数に開始を整列する"
 
-#: common.opt:964
+#: common.opt:968
 #, fuzzy
 #| msgid "Align labels which are only reached by jumping"
 msgid "Align labels which are only reached by jumping."
 msgstr "ジャンプの到達先となるラベルのみ整列する"
 
-#: common.opt:971
+#: common.opt:975
 #, fuzzy
 #| msgid "Align all labels"
 msgid "Align all labels."
 msgstr "全てのラベルを整列する"
 
-#: common.opt:978
+#: common.opt:982
 #, fuzzy
 #| msgid "Align the start of loops"
 msgid "Align the start of loops."
 msgstr "ループの開始を整列する"
 
-#: common.opt:1001
+#: common.opt:1005
 msgid "Select what to sanitize."
 msgstr ""
 
-#: common.opt:1005
+#: common.opt:1009
 msgid "Select type of coverage sanitization."
 msgstr ""
 
-#: common.opt:1009
+#: common.opt:1013
 msgid "-fasan-shadow-offset=<number>\tUse custom shadow memory offset."
 msgstr ""
 
-#: common.opt:1013
+#: common.opt:1017
 msgid "-fsanitize-sections=<sec1,sec2,...>\tSanitize global variables in user-defined sections."
 msgstr ""
 
-#: common.opt:1018
+#: common.opt:1022
 msgid "After diagnosing undefined behavior attempt to continue execution."
 msgstr ""
 
-#: common.opt:1022
+#: common.opt:1026
 #, fuzzy
 #| msgid "This switch is deprecated; use -Wextra instead"
 msgid "This switch is deprecated; use -fsanitize-recover= instead."
 msgstr "このスイッチは廃止されました。代わりに -Wextra を使用してください"
 
-#: common.opt:1029
+#: common.opt:1033
 msgid "Use trap instead of a library function for undefined behavior sanitization."
 msgstr ""
 
-#: common.opt:1033
+#: common.opt:1037
 msgid "Generate unwind tables that are exact at each instruction boundary."
 msgstr ""
 
-#: common.opt:1037
+#: common.opt:1041
 #, fuzzy
 #| msgid "Generate auto-inc/dec instructions"
 msgid "Generate auto-inc/dec instructions."
 msgstr "自動増加/減少命令を生成する"
 
-#: common.opt:1041
+#: common.opt:1045
 msgid "Use sample profile information for call graph node weights. The default profile file is fbdata.afdo in 'pwd'."
 msgstr ""
 
-#: common.opt:1046
+#: common.opt:1050
 msgid "Use sample profile information for call graph node weights. The profile file is specified in the argument."
 msgstr ""
 
-#: common.opt:1055
+#: common.opt:1059
 #, fuzzy
 #| msgid "Generate code to check bounds before indexing arrays"
 msgid "Generate code to check bounds before indexing arrays."
 msgstr "配列の添え字を使用する前に境界検査を行うコードを生成する"
 
-#: common.opt:1059
+#: common.opt:1063
 #, fuzzy
 msgid "Replace add, compare, branch with branch on count register."
 msgstr "加算、比較ブランチの代わりにカウントレジスタのブランチを使う"
 
-#: common.opt:1063
+#: common.opt:1067
 #, fuzzy
 #| msgid "Use profiling information for branch probabilities"
 msgid "Use profiling information for branch probabilities."
 msgstr "分岐経路推測用のプロファイル情報を利用する"
 
-#: common.opt:1067
+#: common.opt:1071
 msgid "Perform branch target load optimization before prologue / epilogue threading."
 msgstr ""
 
-#: common.opt:1071
+#: common.opt:1075
 msgid "Perform branch target load optimization after prologue / epilogue threading."
 msgstr ""
 
-#: common.opt:1075
+#: common.opt:1079
 msgid "Restrict target load migration not to re-use registers in any basic block."
 msgstr ""
 
-#: common.opt:1079
+#: common.opt:1083
 #, fuzzy
 #| msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions"
 msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions."
 msgstr "-fcall-saved-<register>  <register> が関数を通じて保全されるとマークする"
 
-#: common.opt:1083
+#: common.opt:1087
 #, fuzzy
 #| msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls"
 msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls."
 msgstr "-fcall-used-<register>\t<register> が関数呼び出しによって変更されるとマークする"
 
-#: common.opt:1090
+#: common.opt:1094
 #, fuzzy
 #| msgid "Save registers around function calls"
 msgid "Save registers around function calls."
 msgstr "関数呼び出しの前後でレジスタを保存する"
 
-#: common.opt:1094
+#: common.opt:1098
 #, fuzzy
 #| msgid "This switch is deprecated; use -Wextra instead"
 msgid "This switch is deprecated; do not use."
 msgstr "このスイッチは廃止されました。代わりに -Wextra を使用してください"
 
-#: common.opt:1098
+#: common.opt:1102
 #, fuzzy
 #| msgid "Check the return value of new"
 msgid "Check the return value of new in C++."
 msgstr "new の戻り値を検査する"
 
-#: common.opt:1102 common.opt:1106
+#: common.opt:1106 common.opt:1110
 #, fuzzy
 #| msgid "internal consistency failure"
 msgid "Perform internal consistency checkings."
 msgstr "内部一貫性がありません"
 
-#: common.opt:1110
+#: common.opt:1114
 #, fuzzy
 #| msgid "Enable function profiling"
 msgid "Enable code hoisting."
 msgstr "関数プロファイルを有効にする"
 
-#: common.opt:1114
+#: common.opt:1118
 msgid "Looks for opportunities to reduce stack adjustments and stack references."
 msgstr "スタック調整およびスタック参照を削減する機会を探す"
 
-#: common.opt:1118
+#: common.opt:1122
 #, fuzzy
 #| msgid "Do not put uninitialized globals in the common section"
 msgid "Do not put uninitialized globals in the common section."
 msgstr "初期化されない大域変数類を共通セクションに配置しない"
 
-#: common.opt:1126
+#: common.opt:1130
 msgid "-fcompare-debug[=<opts>]\tCompile with and without e.g. -gtoggle, and compare the final-insns dump."
 msgstr ""
 
-#: common.opt:1130
+#: common.opt:1134
 #, fuzzy
 #| msgid "recompiling with -fcompare-debug"
 msgid "Run only the second compilation of -fcompare-debug."
 msgstr "-fcompare-debug 付きで再コンパイルしています"
 
-#: common.opt:1134
+#: common.opt:1138
 #, fuzzy
 #| msgid "Perform comparison elimination after register allocation has finished"
 msgid "Perform comparison elimination after register allocation has finished."
 msgstr "レジスタは位置が完了した後に比較の除去を行う"
 
-#: common.opt:1138
+#: common.opt:1142
 #, fuzzy
 #| msgid "Do not perform optimizations increasing noticeably stack usage"
 msgid "Do not perform optimizations increasing noticeably stack usage."
 msgstr "スタック使用量を著しく増加させる最適化を行わない"
 
-#: common.opt:1142
+#: common.opt:1146
 #, fuzzy
 #| msgid "Perform whole program optimizations"
 msgid "Perform a register copy-propagation optimization pass."
 msgstr "プログラム全体の最適化を実行する"
 
-#: common.opt:1146
+#: common.opt:1150
 #, fuzzy
 #| msgid "Perform cross-jumping optimization"
 msgid "Perform cross-jumping optimization."
 msgstr "ジャンプをまたがった最適化を行う"
 
-#: common.opt:1150
+#: common.opt:1154
 #, fuzzy
 #| msgid "When running CSE, follow jumps to their targets"
 msgid "When running CSE, follow jumps to their targets."
 msgstr "CSE で動作するとき、それらのターゲットへのジャンプに追随する"
 
-#: common.opt:1158
+#: common.opt:1162
 msgid "Omit range reduction step when performing complex division."
 msgstr ""
 
-#: common.opt:1162
+#: common.opt:1166
 #, fuzzy
 #| msgid "Complex multiplication and division follow Fortran rules"
 msgid "Complex multiplication and division follow Fortran rules."
 msgstr "Fortran 規格に従った複素数の乗除算を行う"
 
-#: common.opt:1166
+#: common.opt:1170
 #, fuzzy
 #| msgid "Place data items into their own section"
 msgid "Place data items into their own section."
 msgstr "データ項目をそれら自身のセクションに配置する"
 
-#: common.opt:1170
+#: common.opt:1174
 msgid "List all available debugging counters with their limits and counts."
 msgstr ""
 
-#: common.opt:1174
+#: common.opt:1178
 #, fuzzy
 #| msgid "-fdbg-cnt=<counter>:<limit>[,<counter>:<limit>,...]\tSet the debug counter limit.   "
 msgid "-fdbg-cnt=<counter>:<limit>[,<counter>:<limit>,...]\tSet the debug counter limit."
 msgstr "-fdbg-cnt=<counter>:<limit>[,<counter>:<limit>,...]\tデバッグカウンタ制限を設定する。"
 
-#: common.opt:1178
+#: common.opt:1182
 #, fuzzy
 #| msgid "Map one directory name to another in debug information"
 msgid "-fdebug-prefix-map=<old>=<new> Map one directory name to another in debug information."
 msgstr "デバッグ情報内のディレクトリー名を他のものにマップする"
 
-#: common.opt:1182
+#: common.opt:1186
 #, fuzzy
 #| msgid "Map one directory name to another in debug information"
 msgid "-ffile-prefix-map=<old>=<new> Map one directory name to another in compilation result."
 msgstr "デバッグ情報内のディレクトリー名を他のものにマップする"
 
-#: common.opt:1186
+#: common.opt:1190
 msgid "Output .debug_types section when using DWARF v4 debuginfo."
 msgstr ""
 
-#: common.opt:1192
+#: common.opt:1196
 #, fuzzy
 #| msgid "Defer popping functions args from stack until later"
 msgid "Defer popping functions args from stack until later."
 msgstr "関数引数をスタックから pop するのを呼び出し後まで遅らせる"
 
-#: common.opt:1196
+#: common.opt:1200
 #, fuzzy
 #| msgid "Attempt to fill delay slots of branch instructions"
 msgid "Attempt to fill delay slots of branch instructions."
 msgstr "分岐命令の遅延スロットを使うことを試みる"
 
-#: common.opt:1200
+#: common.opt:1204
 msgid "Delete dead instructions that may throw exceptions."
 msgstr ""
 
-#: common.opt:1204
+#: common.opt:1208
 #, fuzzy
 #| msgid "Delete useless null pointer checks"
 msgid "Delete useless null pointer checks."
 msgstr "無意味な null ポインタ検査を削除する"
 
-#: common.opt:1208
+#: common.opt:1212
 msgid "Stream extra data to support more aggressive devirtualization in LTO local transformation mode."
 msgstr ""
 
-#: common.opt:1212
+#: common.opt:1216
 #, fuzzy
 #| msgid "Perform DWARF2 duplicate elimination"
 msgid "Perform speculative devirtualization."
 msgstr "DWARF2 重複削除を行う"
 
-#: common.opt:1216
+#: common.opt:1220
 msgid "Try to convert virtual calls to direct ones."
 msgstr "仮想呼び出しを直接呼び出しに変換することを試みる"
 
-#: common.opt:1220
+#: common.opt:1224
 #, fuzzy
 msgid "-fdiagnostics-show-location=[once|every-line]\tHow often to emit source location at the beginning of line-wrapped diagnostics."
 msgstr ""
@@ -17265,1832 +17266,1832 @@
 "  -fdiagnostics-show-location=[once | every-line]  診断メッセージの改行の際に,\n"
 " ソース位置情報が行の最初に表示される頻度を指定する\n"
 
-#: common.opt:1237
+#: common.opt:1241
 msgid "Show the source line with a caret indicating the column."
 msgstr ""
 
-#: common.opt:1245
+#: common.opt:1249
 msgid "-fdiagnostics-color=[never|always|auto]\tColorize diagnostics."
 msgstr ""
 
-#: common.opt:1265
+#: common.opt:1269
 msgid "Print fix-it hints in machine-readable form."
 msgstr ""
 
-#: common.opt:1269
+#: common.opt:1273
 msgid "Print fix-it hints to stderr in unified diff format."
 msgstr ""
 
-#: common.opt:1273
+#: common.opt:1277
 msgid "Amend appropriate diagnostic messages with the command line option that controls them."
 msgstr ""
 
-#: common.opt:1277
+#: common.opt:1281
 msgid "-fdisable-[tree|rtl|ipa]-<pass>=range1+range2 disables an optimization pass."
 msgstr ""
 
-#: common.opt:1281
+#: common.opt:1285
 msgid "-fenable-[tree|rtl|ipa]-<pass>=range1+range2 enables an optimization pass."
 msgstr ""
 
-#: common.opt:1285
+#: common.opt:1289
 #, fuzzy
 #| msgid "-fdump-<type>\tDump various compiler internals to a file"
 msgid "-fdump-<type>\tDump various compiler internals to a file."
 msgstr "-fdump-<type>\t様々なコンパイラ内部情報をファイルにダンプする"
 
-#: common.opt:1292
+#: common.opt:1296
 #, fuzzy
 #| msgid "-fdump-final-insns=filename\tDump to filename the insns at the end of translation"
 msgid "-fdump-final-insns=filename\tDump to filename the insns at the end of translation."
 msgstr "-fdump-final-insns=filename\t翻訳終了時に filename へ命令をダンプする"
 
-#: common.opt:1296
+#: common.opt:1300
 #, fuzzy
 #| msgid "-fdump-go-spec=filename\tWrite all declarations to file as Go code"
 msgid "-fdump-go-spec=filename\tWrite all declarations to file as Go code."
 msgstr "-fdump-go-spec=filename\t全ての宣言を Go コードとしてファイルに書き込む"
 
-#: common.opt:1300
+#: common.opt:1304
 #, fuzzy
 #| msgid "Suppress output of addresses in debugging dumps"
 msgid "Suppress output of addresses in debugging dumps."
 msgstr "デバッグダンプ内でアドレスの出力を抑止する"
 
-#: common.opt:1304
+#: common.opt:1308
 msgid "Collect and dump debug information into temporary file if ICE in C/C++ compiler occurred."
 msgstr ""
 
-#: common.opt:1309
+#: common.opt:1313
 msgid "Dump detailed information on GCC's internal representation of source code locations."
 msgstr ""
 
-#: common.opt:1313
+#: common.opt:1317
 msgid "Dump optimization passes."
 msgstr ""
 
-#: common.opt:1317
+#: common.opt:1321
 #, fuzzy
 #| msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps"
 msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps."
 msgstr "デバッグダンプ内で命令番号、行番号情報およびアドレスの出力を抑止する"
 
-#: common.opt:1321
+#: common.opt:1325
 #, fuzzy
 #| msgid "Suppress output of previous and next insn numbers in debugging dumps"
 msgid "Suppress output of previous and next insn numbers in debugging dumps."
 msgstr "デバッグダンプ内で前と次の命令番号の出力を抑止する"
 
-#: common.opt:1325
+#: common.opt:1329
 msgid "Enable CFI tables via GAS assembler directives."
 msgstr "GAS アセンブラ指示を経由して CFI 表を有効にする"
 
-#: common.opt:1329
+#: common.opt:1333
 #, fuzzy
 #| msgid "Perform partial inlining"
 msgid "Perform early inlining."
 msgstr "部分的なインライン化を行う"
 
-#: common.opt:1337
+#: common.opt:1341
 msgid "Perform interprocedural reduction of aggregates."
 msgstr ""
 
-#: common.opt:1341
+#: common.opt:1345
 #, fuzzy
 #| msgid "Perform unused type elimination in debug info"
 msgid "Perform unused symbol elimination in debug info."
 msgstr "デバッグ情報内で使用されていない型の除去を行う"
 
-#: common.opt:1345
+#: common.opt:1349
 #, fuzzy
 #| msgid "Perform unused type elimination in debug info"
 msgid "Perform unused type elimination in debug info."
 msgstr "デバッグ情報内で使用されていない型の除去を行う"
 
-#: common.opt:1349
+#: common.opt:1353
 msgid "Do not suppress C++ class debug information."
 msgstr "C++ クラスデバッグ情報を抑止しない。"
 
-#: common.opt:1353
+#: common.opt:1357
 #, fuzzy
 #| msgid "Enable exception handling"
 msgid "Enable exception handling."
 msgstr "例外処理を有効にする"
 
-#: common.opt:1357
+#: common.opt:1361
 #, fuzzy
 #| msgid "Perform a number of minor, expensive optimizations"
 msgid "Perform a number of minor, expensive optimizations."
 msgstr "多くの、目立たないがコストが高い最適化を行う"
 
-#: common.opt:1361
+#: common.opt:1365
 #, fuzzy
 #| msgid "-fexcess-precision=[fast|standard]\tSpecify handling of excess floating-point precision"
 msgid "-fexcess-precision=[fast|standard]\tSpecify handling of excess floating-point precision."
 msgstr "-fexcess-precision=[fast|standard]\t余分な浮動小数点精度の取り扱いを指定する"
 
-#: common.opt:1364
+#: common.opt:1368
 #, c-format
 msgid "unknown excess precision style %qs"
 msgstr "不明な余分な精度スタイル %qs です"
 
-#: common.opt:1376
+#: common.opt:1380
 msgid "-fpermitted-flt-eval-methods=[c11|ts-18661]\tSpecify which values of FLT_EVAL_METHOD are permitted."
 msgstr ""
 
-#: common.opt:1379
+#: common.opt:1383
 #, c-format
 msgid "unknown specification for the set of FLT_EVAL_METHOD values to permit %qs"
 msgstr ""
 
-#: common.opt:1392
+#: common.opt:1396
 msgid "Output lto objects containing both the intermediate language and binary output."
 msgstr ""
 
-#: common.opt:1396
+#: common.opt:1400
 #, fuzzy
 #| msgid "Assume no NaNs or infinities are generated"
 msgid "Assume no NaNs or infinities are generated."
 msgstr "NaN または無限大が生成されないと見なす"
 
-#: common.opt:1400
+#: common.opt:1404
 #, fuzzy
 #| msgid "-ffixed-<register>\tMark <register> as being unavailable to the compiler"
 msgid "-ffixed-<register>\tMark <register> as being unavailable to the compiler."
 msgstr "-ffixed-<register>\t<register> がコンパイラでは使用できないとマークする"
 
-#: common.opt:1404
+#: common.opt:1408
 #, fuzzy
 #| msgid "Don't allocate floats and doubles in extended-precision registers"
 msgid "Don't allocate floats and doubles in extended-precision registers."
 msgstr "拡張精度レジスタ内に float と double を配置しない"
 
-#: common.opt:1412
+#: common.opt:1416
 msgid "Perform a forward propagation pass on RTL."
 msgstr ""
 
-#: common.opt:1416
+#: common.opt:1420
 msgid "-ffp-contract=[off|on|fast]\tPerform floating-point expression contraction."
 msgstr ""
 
-#: common.opt:1419
+#: common.opt:1423
 #, c-format
 msgid "unknown floating point contraction style %qs"
 msgstr "不明な浮動小数短縮形 %qs です"
 
-#: common.opt:1433
+#: common.opt:1437
 msgid "Allow built-in functions ceil, floor, round, trunc to raise \"inexact\" exceptions."
 msgstr ""
 
-#: common.opt:1440
+#: common.opt:1444
 #, fuzzy
 #| msgid "Allow function addresses to be held in registers"
 msgid "Allow function addresses to be held in registers."
 msgstr "関数アドレスをレジスタに持たせる事を許可する"
 
-#: common.opt:1444
+#: common.opt:1448
 #, fuzzy
 #| msgid "Place each function into its own section"
 msgid "Place each function into its own section."
 msgstr "それぞれの関数をそれ自身のセクションに配置する"
 
-#: common.opt:1448
+#: common.opt:1452
 #, fuzzy
 #| msgid "Perform global common subexpression elimination"
 msgid "Perform global common subexpression elimination."
 msgstr "大域共通部分式の除去を行う"
 
-#: common.opt:1452
+#: common.opt:1456
 #, fuzzy
 #| msgid "Perform global common subexpression elimination"
 msgid "Perform enhanced load motion during global common subexpression elimination."
 msgstr "大域共通部分式の除去を行う"
 
-#: common.opt:1456
+#: common.opt:1460
 #, fuzzy
 #| msgid "Perform global common subexpression elimination"
 msgid "Perform store motion after global common subexpression elimination."
 msgstr "大域共通部分式の除去を行う"
 
-#: common.opt:1460
+#: common.opt:1464
 #, fuzzy
 #| msgid "Perform global common subexpression elimination"
 msgid "Perform redundant load after store elimination in global common subexpression elimination."
 msgstr "大域共通部分式の除去を行う"
 
-#: common.opt:1465
+#: common.opt:1469
 #, fuzzy
 #| msgid "Perform global common subexpression elimination after register allocation"
 msgid "Perform global common subexpression elimination after register allocation has finished."
 msgstr "レジスタ配置後に大域共通部分式の除去を行う"
 
-#: common.opt:1482
+#: common.opt:1486
 msgid "-fgnat-encodings=[all|gdb|minimal]\tSelect the balance between GNAT encodings and standard DWARF emitted in the debug information"
 msgstr ""
 
-#: common.opt:1487
+#: common.opt:1491
 msgid "Enable in and out of Graphite representation."
 msgstr ""
 
-#: common.opt:1491
+#: common.opt:1495
 msgid "Enable Graphite Identity transformation."
 msgstr ""
 
-#: common.opt:1495
+#: common.opt:1499
 #, fuzzy
 msgid "Enable hoisting adjacent loads to encourage generating conditional move instructions."
 msgstr "条件的 move 命令の利用を有効にする"
 
-#: common.opt:1504
+#: common.opt:1508
 #, fuzzy
 #| msgid "Mark all loops as parallel"
 msgid "Mark all loops as parallel."
 msgstr "全てのループを並列としてマークする"
 
-#: common.opt:1508 common.opt:1516 common.opt:2587
+#: common.opt:1512 common.opt:1520 common.opt:2591
 msgid "Enable loop nest transforms.  Same as -floop-nest-optimize."
 msgstr ""
 
-#: common.opt:1512
+#: common.opt:1516
 #, fuzzy
 msgid "Enable loop interchange on trees."
 msgstr "並列命令を有効にする"
 
-#: common.opt:1520
+#: common.opt:1524
 #, fuzzy
 #| msgid "Perform loop unrolling for all loops"
 msgid "Perform unroll-and-jam on loops."
 msgstr "全てのループでループ展開を行なう"
 
-#: common.opt:1524
+#: common.opt:1528
 msgid "Enable support for GNU transactional memory."
 msgstr ""
 
-#: common.opt:1528
+#: common.opt:1532
 msgid "Use STB_GNU_UNIQUE if supported by the assembler."
 msgstr ""
 
-#: common.opt:1536
+#: common.opt:1540
 #, fuzzy
 #| msgid "Enable label alignment optimizations"
 msgid "Enable the loop nest optimizer."
 msgstr "ラベル整列最適化を有効にする"
 
-#: common.opt:1540
+#: common.opt:1544
 msgid "Force bitfield accesses to match their type width."
 msgstr ""
 
-#: common.opt:1544
+#: common.opt:1548
 msgid "Merge adjacent stores."
 msgstr ""
 
-#: common.opt:1548
+#: common.opt:1552
 #, fuzzy
 #| msgid "Enable guessing of branch probabilities"
 msgid "Enable guessing of branch probabilities."
 msgstr "分岐可能性の推測を有効にする"
 
-#: common.opt:1556
+#: common.opt:1560
 #, fuzzy
 #| msgid "Process #ident directives"
 msgid "Process #ident directives."
 msgstr "#ident 指示を処理する"
 
-#: common.opt:1560
+#: common.opt:1564
 msgid "Perform conversion of conditional jumps to branchless equivalents."
 msgstr ""
 
-#: common.opt:1564
+#: common.opt:1568
 #, fuzzy
 #| msgid "Prefer branches over conditional execution"
 msgid "Perform conversion of conditional jumps to conditional execution."
 msgstr "条件付き実行より分岐の生成を優先する"
 
-#: common.opt:1568
+#: common.opt:1572
 msgid "-fstack-reuse=[all|named_vars|none]\tSet stack reuse level for local variables."
 msgstr ""
 
-#: common.opt:1571
+#: common.opt:1575
 #, fuzzy, c-format
 #| msgid "unknown architecture %qs"
 msgid "unknown Stack Reuse Level %qs"
 msgstr "不明なアーキテクチャ %qs です"
 
-#: common.opt:1584
+#: common.opt:1588
 msgid "Convert conditional jumps in innermost loops to branchless equivalents."
 msgstr ""
 
-#: common.opt:1596
+#: common.opt:1600
 #, fuzzy
 #| msgid "Do not generate .size directives"
 msgid "Do not generate .size directives."
 msgstr ".size 指示を生成しない"
 
-#: common.opt:1600
+#: common.opt:1604
 #, fuzzy
 #| msgid "Perform indirect inlining"
 msgid "Perform indirect inlining."
 msgstr "間接インライン化を実行する"
 
-#: common.opt:1606
+#: common.opt:1610
 msgid "Enable inlining of function declared \"inline\", disabling disables all inlining."
 msgstr ""
 
-#: common.opt:1610
+#: common.opt:1614
 #, fuzzy
 #| msgid "Integrate simple functions into their callers when code size is known to not growth"
 msgid "Integrate functions into their callers when code size is known not to grow."
 msgstr "コードサイズが増加しないと分かってる場合は単純な関数を呼び出し側に統合する"
 
-#: common.opt:1614
+#: common.opt:1618
 #, fuzzy
 #| msgid "Integrate functions called once into their callers"
 msgid "Integrate functions not declared \"inline\" into their callers when profitable."
 msgstr "一回だけ呼び出される関数を呼び出し側に統合する"
 
-#: common.opt:1618
+#: common.opt:1622
 #, fuzzy
 #| msgid "Integrate functions called once into their callers"
 msgid "Integrate functions only required by their single caller."
 msgstr "一回だけ呼び出される関数を呼び出し側に統合する"
 
-#: common.opt:1625
+#: common.opt:1629
 #, fuzzy
 #| msgid "-finline-limit=<number>\tLimit the size of inlined functions to <number>"
 msgid "-finline-limit=<number>\tLimit the size of inlined functions to <number>."
 msgstr "  -finline-limit=<number> インライン関数のサイズを <number> に制限する"
 
-#: common.opt:1629
+#: common.opt:1633
 msgid "Inline __atomic operations when a lock free instruction sequence is available."
 msgstr ""
 
-#: common.opt:1636
+#: common.opt:1640
 msgid "-fcf-protection=[full|branch|return|none]\tInstrument functions with checks to verify jump/call/return control-flow transfer instructions have valid targets."
 msgstr ""
 
-#: common.opt:1640
+#: common.opt:1644
 #, c-format
 msgid "unknown Control-Flow Protection Level %qs"
 msgstr ""
 
-#: common.opt:1656
+#: common.opt:1660
 #, fuzzy
 msgid "Instrument function entry and exit with profiling calls."
 msgstr "関数の入り口/出口でプロファイル呼び出しを生成する"
 
-#: common.opt:1660
+#: common.opt:1664
 msgid "-finstrument-functions-exclude-function-list=name,...  Do not instrument listed functions."
 msgstr ""
 
-#: common.opt:1664
+#: common.opt:1668
 msgid "-finstrument-functions-exclude-file-list=filename,...  Do not instrument functions listed in files."
 msgstr ""
 
-#: common.opt:1668
+#: common.opt:1672
 msgid "Perform interprocedural constant propagation."
 msgstr ""
 
-#: common.opt:1672
+#: common.opt:1676
 msgid "Perform cloning to make Interprocedural constant propagation stronger."
 msgstr ""
 
-#: common.opt:1680
+#: common.opt:1684
 msgid "Perform interprocedural bitwise constant propagation."
 msgstr ""
 
-#: common.opt:1684
+#: common.opt:1688
 msgid "Perform interprocedural profile propagation."
 msgstr ""
 
-#: common.opt:1688
+#: common.opt:1692
 msgid "Perform interprocedural points-to analysis."
 msgstr ""
 
-#: common.opt:1692
+#: common.opt:1696
 #, fuzzy
 #| msgid "Discover pure and const functions"
 msgid "Discover pure and const functions."
 msgstr "純粋および定数関数を見つける"
 
-#: common.opt:1696
+#: common.opt:1700
 msgid "Perform Identical Code Folding for functions and read-only variables."
 msgstr ""
 
-#: common.opt:1700
+#: common.opt:1704
 msgid "Perform Identical Code Folding for functions."
 msgstr ""
 
-#: common.opt:1704
+#: common.opt:1708
 msgid "Perform Identical Code Folding for variables."
 msgstr ""
 
-#: common.opt:1708
+#: common.opt:1712
 #, fuzzy
 #| msgid "Discover readonly and non addressable static variables"
 msgid "Discover readonly and non addressable static variables."
 msgstr "読み取り専用およびアドレス付けできない静的変数を見つける"
 
-#: common.opt:1720
+#: common.opt:1724
 msgid "Perform IPA Value Range Propagation."
 msgstr ""
 
-#: common.opt:1724
+#: common.opt:1728
 #, fuzzy
 #| msgid "-fira-algorithm=[CB|priority] Set the used IRA algorithm"
 msgid "-fira-algorithm=[CB|priority]\tSet the used IRA algorithm."
 msgstr "-fira-algorithm=[CB|priority] 使用する IRA アルゴリズムを設定する"
 
-#: common.opt:1727
+#: common.opt:1731
 #, c-format
 msgid "unknown IRA algorithm %qs"
 msgstr "不明な IRA アルゴリズム %qs です"
 
-#: common.opt:1737
+#: common.opt:1741
 #, fuzzy
 #| msgid "-fira-region=[one|all|mixed] Set regions for IRA"
 msgid "-fira-region=[one|all|mixed]\tSet regions for IRA."
 msgstr "-fira-region=[one|all|mixed] IRA 用の範囲を設定する"
 
-#: common.opt:1740
+#: common.opt:1744
 #, c-format
 msgid "unknown IRA region %qs"
 msgstr "不明な IRA 範囲 %qs です"
 
-#: common.opt:1753
+#: common.opt:1757
 msgid "Use IRA based register pressure calculation in RTL hoist optimizations."
 msgstr ""
 
-#: common.opt:1758
+#: common.opt:1762
 msgid "Use IRA based register pressure calculation in RTL loop optimizations."
 msgstr ""
 
-#: common.opt:1763
+#: common.opt:1767
 msgid "Share slots for saving different hard registers."
 msgstr ""
 
-#: common.opt:1767
+#: common.opt:1771
 msgid "Share stack slots for spilled pseudo-registers."
 msgstr ""
 
-#: common.opt:1771
+#: common.opt:1775
 msgid "-fira-verbose=<number>\tControl IRA's level of diagnostic messages."
 msgstr ""
 
-#: common.opt:1775
+#: common.opt:1779
 #, fuzzy
 msgid "Optimize induction variables on trees."
 msgstr "ループの中の全ての一般誘導変数を強度削減する"
 
-#: common.opt:1779
+#: common.opt:1783
 #, fuzzy
 #| msgid "Use jump tables for sufficiently large switch statements"
 msgid "Use jump tables for sufficiently large switch statements."
 msgstr "十分に大きな switch 文ではジャンプ表を使用する"
 
-#: common.opt:1783
+#: common.opt:1787
 #, fuzzy
 #| msgid "Generate code for functions even if they are fully inlined"
 msgid "Generate code for functions even if they are fully inlined."
 msgstr "完全にインライン化される場合でも関数用のコードを生成する"
 
-#: common.opt:1787
+#: common.opt:1791
 #, fuzzy
 #| msgid "Generate code for functions even if they are fully inlined"
 msgid "Generate code for static functions even if they are never called."
 msgstr "完全にインライン化される場合でも関数用のコードを生成する"
 
-#: common.opt:1791
+#: common.opt:1795
 #, fuzzy
 #| msgid "Emit static const variables even if they are not used"
 msgid "Emit static const variables even if they are not used."
 msgstr "使用されない静的定数変数であっても出力する"
 
-#: common.opt:1795
+#: common.opt:1799
 #, fuzzy
 #| msgid "Give external symbols a leading underscore"
 msgid "Give external symbols a leading underscore."
 msgstr "外部シンボルの先頭に下線 (_) を付ける"
 
-#: common.opt:1803
+#: common.opt:1807
 msgid "Do CFG-sensitive rematerialization in LRA."
 msgstr ""
 
-#: common.opt:1807
+#: common.opt:1811
 msgid "Enable link-time optimization."
 msgstr "リンク時最適化を有効にする"
 
-#: common.opt:1811
+#: common.opt:1815
 msgid "Link-time optimization with number of parallel jobs or jobserver."
 msgstr ""
 
-#: common.opt:1814
+#: common.opt:1818
 #, fuzzy, c-format
 #| msgid "unknown TLS model %qs"
 msgid "unknown LTO partitioning model %qs"
 msgstr "不明な TLS モデル %qs です"
 
-#: common.opt:1833
+#: common.opt:1837
 msgid "Specify the algorithm to partition symbols and vars at linktime."
 msgstr ""
 
-#: common.opt:1838
+#: common.opt:1842
 msgid "-flto-compression-level=<number>\tUse zlib compression level <number> for IL."
 msgstr ""
 
-#: common.opt:1842
+#: common.opt:1846
 msgid "Merge C++ types using One Definition Rule."
 msgstr ""
 
-#: common.opt:1846
+#: common.opt:1850
 #, fuzzy
 #| msgid "Report various link-time optimization statistics"
 msgid "Report various link-time optimization statistics."
 msgstr "様々なリンク時最適化統計情報に関して報告する"
 
-#: common.opt:1850
+#: common.opt:1854
 #, fuzzy
 #| msgid "Report various link-time optimization statistics"
 msgid "Report various link-time optimization statistics for WPA only."
 msgstr "様々なリンク時最適化統計情報に関して報告する"
 
-#: common.opt:1854
+#: common.opt:1858
 #, fuzzy
 #| msgid "Set errno after built-in math functions"
 msgid "Set errno after built-in math functions."
 msgstr "組み込み数学関数の後に errno をセットする"
 
-#: common.opt:1858
+#: common.opt:1862
 #, fuzzy
 #| msgid "-fmax-errors=<number>\tMaximum number of errors to report"
 msgid "-fmax-errors=<number>\tMaximum number of errors to report."
 msgstr "-fmax-errors=<number>\tエラー報告する最大数を <number> にする"
 
-#: common.opt:1862
+#: common.opt:1866
 #, fuzzy
 #| msgid "Report on permanent memory allocation"
 msgid "Report on permanent memory allocation."
 msgstr "永続的なメモリ確保に関して報告する"
 
-#: common.opt:1866
+#: common.opt:1870
 #, fuzzy
 #| msgid "Report on permanent memory allocation"
 msgid "Report on permanent memory allocation in WPA only."
 msgstr "永続的なメモリ確保に関して報告する"
 
-#: common.opt:1873
+#: common.opt:1877
 #, fuzzy
 #| msgid "Attempt to merge identical constants and constant variables"
 msgid "Attempt to merge identical constants and constant variables."
 msgstr "定数と定数変数の併合を試みる"
 
-#: common.opt:1877
+#: common.opt:1881
 #, fuzzy
 #| msgid "Attempt to merge identical constants across compilation units"
 msgid "Attempt to merge identical constants across compilation units."
 msgstr "コンパイル単位をまたがった同一の定数の併合を試みる"
 
-#: common.opt:1881
+#: common.opt:1885
 #, fuzzy
 #| msgid "Attempt to merge identical debug strings across compilation units"
 msgid "Attempt to merge identical debug strings across compilation units."
 msgstr "コンパイル単位をまたがった同一のデバッグ文字列の併合を試みる"
 
-#: common.opt:1885
+#: common.opt:1889
 #, fuzzy
 #| msgid "-fmessage-length=<number>\tLimit diagnostics to <number> characters per line.  0 suppresses line-wrapping"
 msgid "-fmessage-length=<number>\tLimit diagnostics to <number> characters per line.  0 suppresses line-wrapping."
 msgstr "-fmessage-length=<number>\t一行あたりの診断メッセージ文字数を <number> に制限する。0 の場合は改行しない"
 
-#: common.opt:1889
+#: common.opt:1893
 msgid "Perform SMS based modulo scheduling before the first scheduling pass."
 msgstr ""
 
-#: common.opt:1893
+#: common.opt:1897
 msgid "Perform SMS based modulo scheduling with register moves allowed."
 msgstr ""
 
-#: common.opt:1897
+#: common.opt:1901
 #, fuzzy
 #| msgid "Move loop invariant computations out of loops"
 msgid "Move loop invariant computations out of loops."
 msgstr "ループの中で変更がない計算をループの外に移動する"
 
-#: common.opt:1901
+#: common.opt:1905
 #, fuzzy
 #| msgid "Use the RTL dead code elimination pass"
 msgid "Use the RTL dead code elimination pass."
 msgstr "RTL 不要なコード (dead code) の除去過程を使用する"
 
-#: common.opt:1905
+#: common.opt:1909
 #, fuzzy
 #| msgid "Use the RTL dead store elimination pass"
 msgid "Use the RTL dead store elimination pass."
 msgstr "RTL 不要な記憶域 (dead store) 除去過程を使用する"
 
-#: common.opt:1909
+#: common.opt:1913
 msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling."
 msgstr ""
 
-#: common.opt:1913
+#: common.opt:1917
 #, fuzzy
 #| msgid "Support synchronous non-call exceptions"
 msgid "Support synchronous non-call exceptions."
 msgstr "同期非呼び出し例外をサポートする"
 
-#: common.opt:1916
+#: common.opt:1920
 #, fuzzy, c-format
 #| msgid "assertion missing after %qs"
 msgid "options or targets missing after %qs"
 msgstr "%qs の後にアサーションがありません"
 
-#: common.opt:1917
+#: common.opt:1921
 msgid "-foffload=<targets>=<options>  Specify offloading targets and options for them."
 msgstr ""
 
-#: common.opt:1921
+#: common.opt:1925
 msgid "-foffload-abi=[lp64|ilp32]     Set the ABI to use in an offload compiler."
 msgstr ""
 
-#: common.opt:1924
+#: common.opt:1928
 #, fuzzy, c-format
 #| msgid "unknown TLS model %qs"
 msgid "unknown offload ABI %qs"
 msgstr "不明な TLS モデル %qs です"
 
-#: common.opt:1934
+#: common.opt:1938
 #, fuzzy
 #| msgid "When possible do not generate stack frames"
 msgid "When possible do not generate stack frames."
 msgstr "可能な場合、スタックフレームを生成しない"
 
-#: common.opt:1938
+#: common.opt:1942
 #, fuzzy
 msgid "Enable all optimization info dumps on stderr."
 msgstr "SSA 最適化を有効にする"
 
-#: common.opt:1942
+#: common.opt:1946
 msgid "-fopt-info[-<type>=filename]\tDump compiler optimization details."
 msgstr ""
 
-#: common.opt:1950
+#: common.opt:1954
 #, fuzzy
 #| msgid "Optimize sibling and tail recursive calls"
 msgid "Optimize sibling and tail recursive calls."
 msgstr "sibling 呼び出しや末尾再帰呼び出しを最適化する"
 
-#: common.opt:1954
+#: common.opt:1958
 #, fuzzy
 #| msgid "Perform partial inlining"
 msgid "Perform partial inlining."
 msgstr "部分的なインライン化を行う"
 
-#: common.opt:1958 common.opt:1962
+#: common.opt:1962 common.opt:1966
 msgid "Report on memory allocation before interprocedural optimization."
 msgstr ""
 
-#: common.opt:1966
+#: common.opt:1970
 #, fuzzy
 #| msgid "Pack structure members together without holes"
 msgid "Pack structure members together without holes."
 msgstr "構造体メンバを穴が開かないようにパックする"
 
-#: common.opt:1970
+#: common.opt:1974
 msgid "-fpack-struct=<number>\tSet initial maximum structure member alignment."
 msgstr ""
 
-#: common.opt:1974
+#: common.opt:1978
 #, fuzzy
 #| msgid "Return small aggregates in memory, not registers"
 msgid "Return small aggregates in memory, not registers."
 msgstr "小さな集合体を (レジスタではなく) メモリで返す"
 
-#: common.opt:1978
+#: common.opt:1982
 #, fuzzy
 #| msgid "Perform loop peeling"
 msgid "Perform loop peeling."
 msgstr "ループの展開を行う"
 
-#: common.opt:1982
+#: common.opt:1986
 #, fuzzy
 #| msgid "Enable nested conditional execution optimizations"
 msgid "Enable machine specific peephole optimizations."
 msgstr "入れ子にされた条件付き実行の最適化を有効にする"
 
-#: common.opt:1986
+#: common.opt:1990
 msgid "Enable an RTL peephole pass before sched2."
 msgstr ""
 
-#: common.opt:1990
+#: common.opt:1994
 #, fuzzy
 #| msgid "Generate position-independent code if possible (large mode)"
 msgid "Generate position-independent code if possible (large mode)."
 msgstr "可能であれば位置非依存コードを生成する (large モード)"
 
-#: common.opt:1994
+#: common.opt:1998
 #, fuzzy
 #| msgid "Generate position-independent code for executables if possible (large mode)"
 msgid "Generate position-independent code for executables if possible (large mode)."
 msgstr "可能であれば実行可能な位置非依存コードを生成する (large モード)"
 
-#: common.opt:1998
+#: common.opt:2002
 #, fuzzy
 #| msgid "Generate position-independent code if possible (small mode)"
 msgid "Generate position-independent code if possible (small mode)."
 msgstr "可能であれば胃非値非損コードを生成する (small モード)"
 
-#: common.opt:2002
+#: common.opt:2006
 #, fuzzy
 #| msgid "Generate position-independent code for executables if possible (small mode)"
 msgid "Generate position-independent code for executables if possible (small mode)."
 msgstr "可能であれば実行可能な非値非依存コードを生成する (small モード)"
 
-#: common.opt:2006
+#: common.opt:2010
 msgid "Use PLT for PIC calls (-fno-plt: load the address from GOT at call site)."
 msgstr ""
 
-#: common.opt:2010
+#: common.opt:2014
 #, fuzzy
 #| msgid "Specify a plugin to load"
 msgid "Specify a plugin to load."
 msgstr "ロードするプラグインを指定する"
 
-#: common.opt:2014
+#: common.opt:2018
 #, fuzzy
 #| msgid "-fplugin-arg-<name>-<key>[=<value>]\tSpecify argument <key>=<value> for plugin <name>"
 msgid "-fplugin-arg-<name>-<key>[=<value>]\tSpecify argument <key>=<value> for plugin <name>."
 msgstr "-fplugin-arg-<name>-<key>[=<value>]\tプラグイン <name> 用に引数 <key>=<value> を指定する"
 
-#: common.opt:2018
+#: common.opt:2022
 msgid "Run predictive commoning optimization."
 msgstr ""
 
-#: common.opt:2022
+#: common.opt:2026
 #, fuzzy
 #| msgid "Generate prefetch instructions, if available, for arrays in loops"
 msgid "Generate prefetch instructions, if available, for arrays in loops."
 msgstr "ループ内の配列で、可能であればプリフェッチ命令を生成する"
 
-#: common.opt:2026
+#: common.opt:2030
 #, fuzzy
 #| msgid "Enable basic program profiling code"
 msgid "Enable basic program profiling code."
 msgstr "基本プログラムプロファイリングコードを有効にする"
 
-#: common.opt:2030
+#: common.opt:2034
 msgid "Generate absolute source path names for gcov."
 msgstr ""
 
-#: common.opt:2034
+#: common.opt:2038
 #, fuzzy
 #| msgid "Insert arc-based program profiling code"
 msgid "Insert arc-based program profiling code."
 msgstr "円弧ベースプログラムプロファイリングコードを挿入する"
 
-#: common.opt:2038
+#: common.opt:2042
 #, fuzzy
 #| msgid "Set the top-level directory for storing the profile data."
 msgid "Set the top-level directory for storing the profile data. The default is 'pwd'."
 msgstr "プロファイルデータ保存用の最上位ディレクリーを設定する"
 
-#: common.opt:2043
+#: common.opt:2047
 #, fuzzy
 #| msgid "Enable correction of flow inconsistent profile data input"
 msgid "Enable correction of flow inconsistent profile data input."
 msgstr "フロー一貫性が無いデータ入力の訂正を有効にする"
 
-#: common.opt:2047
+#: common.opt:2051
 msgid "-fprofile-update=[single|atomic|prefer-atomic]\tSet the profile update method."
 msgstr ""
 
-#: common.opt:2050
+#: common.opt:2054
 #, fuzzy, c-format
 #| msgid "unknown type name %qE"
 msgid "unknown profile update method %qs"
 msgstr "不明な型名 %qE です"
 
-#: common.opt:2063
+#: common.opt:2067
 msgid "Enable common options for generating profile info for profile feedback directed optimizations."
 msgstr ""
 
-#: common.opt:2067
+#: common.opt:2071
 msgid "Enable common options for generating profile info for profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr ""
 
-#: common.opt:2071
+#: common.opt:2075
 msgid "Enable common options for performing profile feedback directed optimizations."
 msgstr ""
 
-#: common.opt:2075
+#: common.opt:2079
 msgid "Enable common options for performing profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr ""
 
-#: common.opt:2079
+#: common.opt:2083
 #, fuzzy
 #| msgid "Insert code to profile values of expressions"
 msgid "Insert code to profile values of expressions."
 msgstr "式の値をプロファイルするためのコードを挿入する"
 
-#: common.opt:2083
+#: common.opt:2087
 #, fuzzy
 #| msgid "internal consistency failure"
 msgid "Report on consistency of profile."
 msgstr "内部一貫性がありません"
 
-#: common.opt:2087
+#: common.opt:2091
 #, fuzzy
 #| msgid "Reorder functions to improve code placement"
 msgid "Enable function reordering that improves code placement."
 msgstr "コード配置を改善するために関数を並べ替える"
 
-#: common.opt:2091
+#: common.opt:2095
 #, fuzzy
 #| msgid "Generate cld instruction in the function prologue."
 msgid "Insert NOP instructions at each function entry."
 msgstr "関数プロローグ内で cld 命令を生成する"
 
-#: common.opt:2098
+#: common.opt:2102
 #, fuzzy
 #| msgid "-frandom-seed=<string>\tMake compile reproducible using <string>"
 msgid "-frandom-seed=<string>\tMake compile reproducible using <string>."
 msgstr "-frandom-seed=<string>\t<string> を使用してコンパイルを再現可能にする"
 
-#: common.opt:2108
+#: common.opt:2112
 msgid "Record gcc command line switches in the object file."
 msgstr "オブジェクトファイル内に gcc のコマンドラインスイッチを記録する。"
 
-#: common.opt:2112
+#: common.opt:2116
 #, fuzzy
 #| msgid "Return small aggregates in registers"
 msgid "Return small aggregates in registers."
 msgstr "小さな集合体をレジスタで返す"
 
-#: common.opt:2120
+#: common.opt:2124
 msgid "Tell DSE that the storage for a C++ object is dead when the constructor starts and when the destructor finishes."
 msgstr ""
 
-#: common.opt:2128
+#: common.opt:2132
 msgid "Relief of register pressure through live range shrinkage."
 msgstr ""
 
-#: common.opt:2132
+#: common.opt:2136
 #, fuzzy
 #| msgid "Perform whole program optimizations"
 msgid "Perform a register renaming optimization pass."
 msgstr "プログラム全体の最適化を実行する"
 
-#: common.opt:2136
+#: common.opt:2140
 msgid "Perform a target dependent instruction fusion optimization pass."
 msgstr ""
 
-#: common.opt:2140
+#: common.opt:2144
 #, fuzzy
 #| msgid "Reorder basic blocks to improve code placement"
 msgid "Reorder basic blocks to improve code placement."
 msgstr "コード配置を改善するために基本ブロックを並べ替える"
 
-#: common.opt:2144
+#: common.opt:2148
 msgid "-freorder-blocks-algorithm=[simple|stc]\tSet the used basic block reordering algorithm."
 msgstr ""
 
-#: common.opt:2147
+#: common.opt:2151
 #, fuzzy, c-format
 #| msgid "unknown IRA algorithm %qs"
 msgid "unknown basic block reordering algorithm %qs"
 msgstr "不明な IRA アルゴリズム %qs です"
 
-#: common.opt:2157
+#: common.opt:2161
 #, fuzzy
 #| msgid "Reorder basic blocks to improve code placement"
 msgid "Reorder basic blocks and partition into hot and cold sections."
 msgstr "コード配置を改善するために基本ブロックを並べ替える"
 
-#: common.opt:2161
+#: common.opt:2165
 #, fuzzy
 #| msgid "Reorder functions to improve code placement"
 msgid "Reorder functions to improve code placement."
 msgstr "コード配置を改善するために関数を並べ替える"
 
-#: common.opt:2165
+#: common.opt:2169
 #, fuzzy
 #| msgid "Add a common subexpression elimination pass after loop optimizations"
 msgid "Add a common subexpression elimination pass after loop optimizations."
 msgstr "ループ最適化後に共通部分式を除去する過程を追加する"
 
-#: common.opt:2173
+#: common.opt:2177
 #, fuzzy
 #| msgid "Disable optimizations that assume default FP rounding behavior"
 msgid "Disable optimizations that assume default FP rounding behavior."
 msgstr "デフォルトの浮動小数点丸め動作と見なせる最適化を無効にする"
 
-#: common.opt:2177
+#: common.opt:2181
 #, fuzzy
 #| msgid "Enable scheduling across basic blocks"
 msgid "Enable scheduling across basic blocks."
 msgstr "基本ブロックをまたがるスケジューリングを有効にする"
 
-#: common.opt:2181
+#: common.opt:2185
 msgid "Enable register pressure sensitive insn scheduling."
 msgstr ""
 
-#: common.opt:2185
+#: common.opt:2189
 #, fuzzy
 #| msgid "Allow speculative motion of non-loads"
 msgid "Allow speculative motion of non-loads."
 msgstr "非ロードでの不確実な動作を許可する"
 
-#: common.opt:2189
+#: common.opt:2193
 #, fuzzy
 #| msgid "Allow speculative motion of some loads"
 msgid "Allow speculative motion of some loads."
 msgstr "いくつかのロードでの不確実な動作を許可する"
 
-#: common.opt:2193
+#: common.opt:2197
 #, fuzzy
 #| msgid "Allow speculative motion of more loads"
 msgid "Allow speculative motion of more loads."
 msgstr "より多くのロードでの不確実な動作を許可する"
 
-#: common.opt:2197
+#: common.opt:2201
 #, fuzzy
 #| msgid "-fsched-verbose=<number>\tSet the verbosity level of the scheduler"
 msgid "-fsched-verbose=<number>\tSet the verbosity level of the scheduler."
 msgstr "-fsched-verbose=<number>\tスケジューラの冗長レベルを設定する"
 
-#: common.opt:2201
+#: common.opt:2205
 msgid "If scheduling post reload, do superblock scheduling."
 msgstr ""
 
-#: common.opt:2209
+#: common.opt:2213
 #, fuzzy
 #| msgid "Reschedule instructions before register allocation"
 msgid "Reschedule instructions before register allocation."
 msgstr "レジスタ確保の前に命令を並べ直す"
 
-#: common.opt:2213
+#: common.opt:2217
 #, fuzzy
 #| msgid "Reschedule instructions after register allocation"
 msgid "Reschedule instructions after register allocation."
 msgstr "レジスタ確保の後で命令を並べ直す"
 
-#: common.opt:2220
+#: common.opt:2224
 msgid "Schedule instructions using selective scheduling algorithm."
 msgstr ""
 
-#: common.opt:2224
+#: common.opt:2228
 #, fuzzy
 #| msgid "Run selective scheduling after reload"
 msgid "Run selective scheduling after reload."
 msgstr "再ロード後に選択的スケジューリングを実行する"
 
-#: common.opt:2228
+#: common.opt:2232
 msgid "Run self-tests, using the given path to locate test files."
 msgstr ""
 
-#: common.opt:2232
+#: common.opt:2236
 msgid "Perform software pipelining of inner loops during selective scheduling."
 msgstr ""
 
-#: common.opt:2236
+#: common.opt:2240
 msgid "Perform software pipelining of outer loops during selective scheduling."
 msgstr ""
 
-#: common.opt:2240
+#: common.opt:2244
 msgid "Reschedule pipelined regions without pipelining."
 msgstr ""
 
-#: common.opt:2244
+#: common.opt:2248
 msgid "Allow interposing function (or variables) by ones with different semantics (or initializer) respectively by dynamic linker."
 msgstr ""
 
-#: common.opt:2250
+#: common.opt:2254
 msgid "Allow premature scheduling of queued insns."
 msgstr ""
 
-#: common.opt:2254
+#: common.opt:2258
 msgid "-fsched-stalled-insns=<number>\tSet number of queued insns that can be prematurely scheduled."
 msgstr ""
 
-#: common.opt:2262
+#: common.opt:2266
 msgid "Set dependence distance checking in premature scheduling of queued insns."
 msgstr ""
 
-#: common.opt:2266
+#: common.opt:2270
 msgid "-fsched-stalled-insns-dep=<number>\tSet dependence distance checking in premature scheduling of queued insns."
 msgstr ""
 
-#: common.opt:2270
+#: common.opt:2274
 msgid "Enable the group heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2274
+#: common.opt:2278
 msgid "Enable the critical path heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2278
+#: common.opt:2282
 #, fuzzy
 #| msgid "Enable the use of RX FPU instructions.  This is the default."
 msgid "Enable the speculative instruction heuristic in the scheduler."
 msgstr "RX FPU 命令の使用を有効にする (デフォルト)。"
 
-#: common.opt:2282
+#: common.opt:2286
 msgid "Enable the rank heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2286
+#: common.opt:2290
 #, fuzzy
 #| msgid "Enable the use of RX FPU instructions.  This is the default."
 msgid "Enable the last instruction heuristic in the scheduler."
 msgstr "RX FPU 命令の使用を有効にする (デフォルト)。"
 
-#: common.opt:2290
+#: common.opt:2294
 msgid "Enable the dependent count heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2294
+#: common.opt:2298
 msgid "Access data in the same section from shared anchor points."
 msgstr ""
 
-#: common.opt:2306
+#: common.opt:2310
 msgid "Turn on Redundant Extensions Elimination pass."
 msgstr ""
 
-#: common.opt:2310
+#: common.opt:2314
 #, fuzzy
 #| msgid "Show column numbers in diagnostics, when available.  Default on"
 msgid "Show column numbers in diagnostics, when available.  Default on."
 msgstr "診断内で利用可能な場合に列番号を表示する。デフォルトで有効"
 
-#: common.opt:2314
+#: common.opt:2318
 msgid "Emit function prologues only before parts of the function that need it, rather than at the top of the function."
 msgstr ""
 
-#: common.opt:2319
+#: common.opt:2323
 msgid "Shrink-wrap parts of the prologue and epilogue separately."
 msgstr ""
 
-#: common.opt:2323
+#: common.opt:2327
 msgid "Disable optimizations observable by IEEE signaling NaNs."
 msgstr ""
 
-#: common.opt:2327
+#: common.opt:2331
 msgid "Disable floating point optimizations that ignore the IEEE signedness of zero."
 msgstr ""
 
-#: common.opt:2331
+#: common.opt:2335
 #, fuzzy
 #| msgid "Convert floating point constants to single precision constants"
 msgid "Convert floating point constants to single precision constants."
 msgstr "浮動小数点定数を単精度定数に変換する"
 
-#: common.opt:2335
+#: common.opt:2339
 #, fuzzy
 #| msgid "Apply variable expansion when loops are unrolled"
 msgid "Split lifetimes of induction variables when loops are unrolled."
 msgstr "ループを展開したときに変数の展開を行う"
 
-#: common.opt:2339
+#: common.opt:2343
 #, fuzzy
 #| msgid "Generate discontiguous stack frames"
 msgid "Generate discontiguous stack frames."
 msgstr "不連続なスタックフレームを生成する"
 
-#: common.opt:2343
+#: common.opt:2347
 #, fuzzy
 #| msgid "Split wide types into independent registers"
 msgid "Split wide types into independent registers."
 msgstr "ワイド型を独立したレジスタに分割する"
 
-#: common.opt:2347
+#: common.opt:2351
 msgid "Enable backward propagation of use properties at the SSA level."
 msgstr ""
 
-#: common.opt:2351
+#: common.opt:2355
 msgid "Optimize conditional patterns using SSA PHI nodes."
 msgstr ""
 
-#: common.opt:2355
+#: common.opt:2359
 msgid "Optimize amount of stdarg registers saved to stack at start of function."
 msgstr ""
 
-#: common.opt:2359
+#: common.opt:2363
 #, fuzzy
 #| msgid "Apply variable expansion when loops are unrolled"
 msgid "Apply variable expansion when loops are unrolled."
 msgstr "ループを展開したときに変数の展開を行う"
 
-#: common.opt:2363
+#: common.opt:2367
 #, fuzzy
 #| msgid "-fstack-check=[no|generic|specific]\tInsert stack checking code into the program"
 msgid "-fstack-check=[no|generic|specific]\tInsert stack checking code into the program."
 msgstr "-fstack-check=[no|generic|specific]\tプログラム内にスタック検査コードを挿入する"
 
-#: common.opt:2367
+#: common.opt:2371
 #, fuzzy
 #| msgid "Insert stack checking code into the program.  Same as -fstack-check=specific"
 msgid "Insert stack checking code into the program.  Same as -fstack-check=specific."
 msgstr "プログラム内にスタック検査コードを挿入する。 -fstack-check=specific と同様"
 
-#: common.opt:2371
+#: common.opt:2375
 msgid "Insert code to probe each page of stack space as it is allocated to protect from stack-clash style attacks."
 msgstr ""
 
-#: common.opt:2379
+#: common.opt:2383
 #, fuzzy
 #| msgid "-fstack-limit-register=<register>\tTrap if the stack goes past <register>"
 msgid "-fstack-limit-register=<register>\tTrap if the stack goes past <register>."
 msgstr "-fstack-limit-register=<register>\tスタックがレジスタ <register> より後に行った場合にトラップする"
 
-#: common.opt:2383
+#: common.opt:2387
 #, fuzzy
 #| msgid "-fstack-limit-symbol=<name>\tTrap if the stack goes past symbol <name>"
 msgid "-fstack-limit-symbol=<name>\tTrap if the stack goes past symbol <name>."
 msgstr "-fstack-limit-symbol=<name>\tスタックがシンボル <name> より後に行った場合にトラップする"
 
-#: common.opt:2387
+#: common.opt:2391
 #, fuzzy
 #| msgid "Use propolice as a stack protection method"
 msgid "Use propolice as a stack protection method."
 msgstr "スタック保護方法としてプロポリス (propolice) を使用する"
 
-#: common.opt:2391
+#: common.opt:2395
 #, fuzzy
 #| msgid "Use a stack protection method for every function"
 msgid "Use a stack protection method for every function."
 msgstr "それぞれの関数に関してスタック保護方法を使用する"
 
-#: common.opt:2395
+#: common.opt:2399
 #, fuzzy
 #| msgid "Use a stack protection method for every function"
 msgid "Use a smart stack protection method for certain functions."
 msgstr "それぞれの関数に関してスタック保護方法を使用する"
 
-#: common.opt:2399
+#: common.opt:2403
 #, fuzzy
 #| msgid "Use a stack protection method for every function"
 msgid "Use stack protection method only for functions with the stack_protect attribute."
 msgstr "それぞれの関数に関してスタック保護方法を使用する"
 
-#: common.opt:2403
+#: common.opt:2407
 #, fuzzy
 #| msgid "Output stack usage information on a per-function basis"
 msgid "Output stack usage information on a per-function basis."
 msgstr "関数単位でスタック使用情報を出力する"
 
-#: common.opt:2415
+#: common.opt:2419
 #, fuzzy
 #| msgid "Assume strict aliasing rules apply"
 msgid "Assume strict aliasing rules apply."
 msgstr "厳密な別名規則を適用するとみなす"
 
-#: common.opt:2419
+#: common.opt:2423
 #, fuzzy
 #| msgid "Treat signed overflow as undefined"
 msgid "Treat signed overflow as undefined.  Negated as -fwrapv -fwrapv-pointer."
 msgstr "符号のオーバーフローを未定義として取り扱う"
 
-#: common.opt:2423
+#: common.opt:2427
 msgid "Implement __atomic operations via libcalls to legacy __sync functions."
 msgstr ""
 
-#: common.opt:2427
+#: common.opt:2431
 #, fuzzy
 #| msgid "Check for syntax errors, then stop"
 msgid "Check for syntax errors, then stop."
 msgstr "構文エラーを検査して、そこで停止する"
 
-#: common.opt:2431
+#: common.opt:2435
 #, fuzzy
 #| msgid "Create data files needed by \"gcov\""
 msgid "Create data files needed by \"gcov\"."
 msgstr "\"gcov\" で必要となるデータファイルを作成する"
 
-#: common.opt:2435
+#: common.opt:2439
 #, fuzzy
 #| msgid "Perform cross-jumping optimization"
 msgid "Perform jump threading optimizations."
 msgstr "ジャンプをまたがった最適化を行う"
 
-#: common.opt:2439
+#: common.opt:2443
 #, fuzzy
 #| msgid "Report the time taken by each compiler pass"
 msgid "Report the time taken by each compiler pass."
 msgstr "各コンパイル過程で費やした時間を報告する"
 
-#: common.opt:2443
+#: common.opt:2447
 msgid "Record times taken by sub-phases separately."
 msgstr ""
 
-#: common.opt:2447
+#: common.opt:2451
 #, fuzzy
 #| msgid "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tSet the default thread-local storage code generation model"
 msgid "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tSet the default thread-local storage code generation model."
 msgstr "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tデフォルトのスレッド局所記憶域 (TLS) コード生成モデルを設定する"
 
-#: common.opt:2450
+#: common.opt:2454
 #, c-format
 msgid "unknown TLS model %qs"
 msgstr "不明な TLS モデル %qs です"
 
-#: common.opt:2466
+#: common.opt:2470
 #, fuzzy
 #| msgid "Reorder top level functions, variables, and asms"
 msgid "Reorder top level functions, variables, and asms."
 msgstr "トップレベルの関数、変数、アセンブラを並べ替える"
 
-#: common.opt:2470
+#: common.opt:2474
 msgid "Perform superblock formation via tail duplication."
 msgstr ""
 
-#: common.opt:2474
+#: common.opt:2478
 msgid "For targets that normally need trampolines for nested functions, always generate them instead of using descriptors."
 msgstr ""
 
-#: common.opt:2482
+#: common.opt:2486
 #, fuzzy
 #| msgid "Assume floating-point operations can trap"
 msgid "Assume floating-point operations can trap."
 msgstr "浮動小数点操作をトラップできると見なす"
 
-#: common.opt:2486
+#: common.opt:2490
 #, fuzzy
 #| msgid "Trap for signed overflow in addition, subtraction and multiplication"
 msgid "Trap for signed overflow in addition, subtraction and multiplication."
 msgstr "加算、減算、乗算内での符号付きのオーバーフローをトラップする"
 
-#: common.opt:2490
+#: common.opt:2494
 #, fuzzy
 msgid "Enable SSA-CCP optimization on trees."
 msgstr "SSA 最適化を有効にする"
 
-#: common.opt:2494
+#: common.opt:2498
 #, fuzzy
 msgid "Enable SSA-BIT-CCP optimization on trees."
 msgstr "SSA 最適化を有効にする"
 
-#: common.opt:2502
+#: common.opt:2506
 #, fuzzy
 msgid "Enable loop header copying on trees."
 msgstr "SSA 最適化を有効にする"
 
-#: common.opt:2510
+#: common.opt:2514
 #, fuzzy
 msgid "Enable SSA coalescing of user variables."
 msgstr "SSA 最適化を有効にする"
 
-#: common.opt:2518
+#: common.opt:2522
 #, fuzzy
 msgid "Enable copy propagation on trees."
 msgstr "SSA 最適化を有効にする"
 
-#: common.opt:2526
+#: common.opt:2530
 #, fuzzy
 msgid "Transform condition stores into unconditional ones."
 msgstr "条件的 move 命令の利用を有効にする"
 
-#: common.opt:2530
+#: common.opt:2534
 msgid "Perform conversions of switch initializations."
 msgstr ""
 
-#: common.opt:2534
+#: common.opt:2538
 #, fuzzy
 msgid "Enable SSA dead code elimination optimization on trees."
 msgstr "SSA 最適化を有効にする"
 
-#: common.opt:2538
+#: common.opt:2542
 #, fuzzy
 #| msgid "Enable linker optimizations"
 msgid "Enable dominator optimizations."
 msgstr "リンカ最適化を有効にする"
 
-#: common.opt:2542
+#: common.opt:2546
 #, fuzzy
 msgid "Enable tail merging on trees."
 msgstr "SSA 最適化を有効にする"
 
-#: common.opt:2546
+#: common.opt:2550
 #, fuzzy
 #| msgid "Enable dead store elimination"
 msgid "Enable dead store elimination."
 msgstr "不要な記憶域 (dead store) の除去を行う"
 
-#: common.opt:2550
+#: common.opt:2554
 #, fuzzy
 msgid "Enable forward propagation on trees."
 msgstr "SSA 最適化を有効にする"
 
-#: common.opt:2554
+#: common.opt:2558
 #, fuzzy
 msgid "Enable Full Redundancy Elimination (FRE) on trees."
 msgstr "ループ中に不変な計算をループの外に移動する"
 
-#: common.opt:2558
+#: common.opt:2562
 #, fuzzy
 msgid "Enable string length optimizations on trees."
 msgstr "SSA 最適化を有効にする"
 
-#: common.opt:2562
+#: common.opt:2566
 msgid "Detect paths that trigger erroneous or undefined behavior due to dereferencing a null pointer.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
-#: common.opt:2568
+#: common.opt:2572
 msgid "Detect paths that trigger erroneous or undefined behavior due to a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
-#: common.opt:2575
+#: common.opt:2579
 #, fuzzy
 msgid "Enable loop distribution on trees."
 msgstr "並列命令を有効にする"
 
-#: common.opt:2579
+#: common.opt:2583
 #, fuzzy
 msgid "Enable loop distribution for patterns transformed into a library call."
 msgstr "並列命令を有効にする"
 
-#: common.opt:2583
+#: common.opt:2587
 #, fuzzy
 msgid "Enable loop invariant motion on trees."
 msgstr "ループ中に不変な計算をループの外に移動する"
 
-#: common.opt:2591
+#: common.opt:2595
 #, fuzzy
 msgid "Create canonical induction variables in loops."
 msgstr "ループの中の全ての一般誘導変数を強度削減する"
 
-#: common.opt:2595
+#: common.opt:2599
 #, fuzzy
 msgid "Enable loop optimizations on tree level."
 msgstr "SSA 最適化を有効にする"
 
-#: common.opt:2599
+#: common.opt:2603
 #, fuzzy
 #| msgid "Enable automatic parallelization of loops"
 msgid "-ftree-parallelize-loops=<number>\tEnable automatic parallelization of loops."
 msgstr "ループの自動並列化を有効にする"
 
-#: common.opt:2603
+#: common.opt:2607
 #, fuzzy
 msgid "Enable hoisting loads from conditional pointers."
 msgstr "条件的 move 命令の利用を有効にする"
 
-#: common.opt:2607
+#: common.opt:2611
 #, fuzzy
 msgid "Enable SSA-PRE optimization on trees."
 msgstr "SSA 最適化を有効にする"
 
-#: common.opt:2611
+#: common.opt:2615
 msgid "In SSA-PRE optimization on trees, enable partial-partial redundancy elimination."
 msgstr ""
 
-#: common.opt:2615
+#: common.opt:2619
 msgid "Perform function-local points-to analysis on trees."
 msgstr ""
 
-#: common.opt:2619
+#: common.opt:2623
 #, fuzzy
 msgid "Enable reassociation on tree level."
 msgstr "SSA 最適化を有効にする"
 
-#: common.opt:2627
+#: common.opt:2631
 #, fuzzy
 msgid "Enable SSA code sinking on trees."
 msgstr "SSA 最適化を有効にする"
 
-#: common.opt:2631
+#: common.opt:2635
 msgid "Perform straight-line strength reduction."
 msgstr ""
 
-#: common.opt:2635
+#: common.opt:2639
 msgid "Perform scalar replacement of aggregates."
 msgstr ""
 
-#: common.opt:2639
+#: common.opt:2643
 msgid "Replace temporary expressions in the SSA->normal pass."
 msgstr ""
 
-#: common.opt:2643
+#: common.opt:2647
 msgid "Perform live range splitting during the SSA->normal pass."
 msgstr ""
 
-#: common.opt:2647
+#: common.opt:2651
 msgid "Perform Value Range Propagation on trees."
 msgstr ""
 
-#: common.opt:2651
+#: common.opt:2655
 msgid "Split paths leading to loop backedges."
 msgstr ""
 
-#: common.opt:2655
+#: common.opt:2659
 msgid "Assume common declarations may be overridden with ones with a larger trailing array."
 msgstr ""
 
-#: common.opt:2660
+#: common.opt:2664
 #, fuzzy
 #| msgid "Compile whole compilation unit at a time"
 msgid "Compile whole compilation unit at a time."
 msgstr "コンパイル単位全体を一回でコンパイルする"
 
-#: common.opt:2664
+#: common.opt:2668
 #, fuzzy
 #| msgid "Perform loop unrolling when iteration count is known"
 msgid "Perform loop unrolling when iteration count is known."
 msgstr "反復回数が既知のとき、ループ展開を行なう"
 
-#: common.opt:2668
+#: common.opt:2672
 #, fuzzy
 #| msgid "Perform loop unrolling for all loops"
 msgid "Perform loop unrolling for all loops."
 msgstr "全てのループでループ展開を行なう"
 
-#: common.opt:2679
+#: common.opt:2683
 msgid "Allow optimization for floating-point arithmetic which may change the result of the operation due to rounding."
 msgstr ""
 
-#: common.opt:2684
+#: common.opt:2688
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr ""
 
-#: common.opt:2692
+#: common.opt:2696
 msgid "Allow math optimizations that may violate IEEE or ISO standards."
 msgstr ""
 
-#: common.opt:2696
+#: common.opt:2700
 #, fuzzy
 msgid "Perform loop unswitching."
 msgstr "全てのループでループ展開を行なう"
 
-#: common.opt:2700
+#: common.opt:2704
 #, fuzzy
 #| msgid "Perform loop peeling"
 msgid "Perform loop splitting."
 msgstr "ループの展開を行う"
 
-#: common.opt:2704
+#: common.opt:2708
 #, fuzzy
 #| msgid "Just generate unwind tables for exception handling"
 msgid "Just generate unwind tables for exception handling."
 msgstr "巻き戻しを行なう例外補足用テーブルを生成する"
 
-#: common.opt:2708
+#: common.opt:2712
 msgid "Use the bfd linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2712
+#: common.opt:2716
 msgid "Use the gold linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2724
+#: common.opt:2728
 #, fuzzy
 #| msgid "Perform variable tracking"
 msgid "Perform variable tracking."
 msgstr "変数追跡を実施する"
 
-#: common.opt:2732
+#: common.opt:2736
 #, fuzzy
 #| msgid "Perform variable tracking"
 msgid "Perform variable tracking by annotating assignments."
 msgstr "変数追跡を実施する"
 
-#: common.opt:2738
+#: common.opt:2742
 msgid "Toggle -fvar-tracking-assignments."
 msgstr ""
 
-#: common.opt:2746
+#: common.opt:2750
 msgid "Perform variable tracking and also tag variables that are uninitialized."
 msgstr ""
 
-#: common.opt:2751
+#: common.opt:2755
 #, fuzzy
 msgid "Enable vectorization on trees."
 msgstr "SSA 最適化を有効にする"
 
-#: common.opt:2759
+#: common.opt:2763
 #, fuzzy
 msgid "Enable loop vectorization on trees."
 msgstr "SSA 最適化を有効にする"
 
-#: common.opt:2763
+#: common.opt:2767
 #, fuzzy
 msgid "Enable basic block vectorization (SLP) on trees."
 msgstr "SSA 最適化を有効にする"
 
-#: common.opt:2767
+#: common.opt:2771
 msgid "Specifies the cost model for vectorization. -fvect-cost-model=[unlimited|dynamic|cheap]\tSpecifies the cost model for vectorization."
 msgstr ""
 
-#: common.opt:2772
+#: common.opt:2776
 msgid "-fsimd-cost-model=[unlimited|dynamic|cheap]\tSpecifies the vectorization cost model for code marked with a simd directive."
 msgstr ""
 
-#: common.opt:2775
+#: common.opt:2779
 #, fuzzy, c-format
 #| msgid "unknown TLS model %qs"
 msgid "unknown vectorizer cost model %qs"
 msgstr "不明な TLS モデル %qs です"
 
-#: common.opt:2788
+#: common.opt:2792
 #, fuzzy
 #| msgid "Does nothing.  Preserved for backward compatibility."
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr "何もしない。後方互換性のために残されている。"
 
-#: common.opt:2796
+#: common.opt:2800
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr ""
 
-#: common.opt:2806
+#: common.opt:2810
 #, fuzzy
 #| msgid "Add extra commentary to assembler output"
 msgid "Add extra commentary to assembler output."
 msgstr "余分なコメントをアセンブラ出力に追加する"
 
-#: common.opt:2810
+#: common.opt:2814
 #, fuzzy
 #| msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility"
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility."
 msgstr "-fvisibility=[default|internal|hidden|protected]\tシンボル可視性のデフォルトを設定する"
 
-#: common.opt:2813
+#: common.opt:2817
 #, c-format
 msgid "unrecognized visibility value %qs"
 msgstr "認識できない可視性の値 %qs です"
 
-#: common.opt:2829
+#: common.opt:2833
 msgid "Validate vtable pointers before using them."
 msgstr ""
 
-#: common.opt:2832
+#: common.opt:2836
 #, fuzzy, c-format
 #| msgid "(near initialization for %qs)"
 msgid "unknown vtable verify initialization priority %qs"
 msgstr "(%qs 用の初期化付近)"
 
-#: common.opt:2845
+#: common.opt:2849
 msgid "Output vtable verification counters."
 msgstr ""
 
-#: common.opt:2849
+#: common.opt:2853
 msgid "Output vtable verification pointer sets information."
 msgstr ""
 
-#: common.opt:2853
+#: common.opt:2857
 msgid "Use expression value profiles in optimizations."
 msgstr ""
 
-#: common.opt:2857
+#: common.opt:2861
 msgid "Construct webs and split unrelated uses of single variable."
 msgstr ""
 
-#: common.opt:2861
+#: common.opt:2865
 #, fuzzy
 #| msgid "Enable conditional execution other than moves/scc"
 msgid "Enable conditional dead code elimination for builtin calls."
 msgstr "moves/scc 以外で条件付き実行を有効にする"
 
-#: common.opt:2865
+#: common.opt:2869
 #, fuzzy
 #| msgid "Perform whole program optimizations"
 msgid "Perform whole program optimizations."
 msgstr "プログラム全体の最適化を実行する"
 
-#: common.opt:2869
+#: common.opt:2873
 #, fuzzy
 #| msgid "Assume signed arithmetic overflow wraps around"
 msgid "Assume pointer overflow wraps around."
 msgstr "符号付き計算オーバーフローが丸められると見なす"
 
-#: common.opt:2873
+#: common.opt:2877
 #, fuzzy
 #| msgid "Assume signed arithmetic overflow wraps around"
 msgid "Assume signed arithmetic overflow wraps around."
 msgstr "符号付き計算オーバーフローが丸められると見なす"
 
-#: common.opt:2877
+#: common.opt:2881
 #, fuzzy
 #| msgid "Put zero initialized data in the bss section"
 msgid "Put zero initialized data in the bss section."
 msgstr "0 で初期化されるデータを bss セクション内に配置する"
 
-#: common.opt:2881
+#: common.opt:2885
 #, fuzzy
 #| msgid "Generate debug information in default format"
 msgid "Generate debug information in default format."
 msgstr "デフォルト形式でデバッグ情報を生成する"
 
-#: common.opt:2885
+#: common.opt:2889
 #, fuzzy
 #| msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgid "Assume assembler support for (DWARF2+) .loc directives"
 msgstr "%<-fsplit-stack%> はアセンブラが CFI 指示をサポートしている必要があります"
 
-#: common.opt:2889
+#: common.opt:2893
 #, fuzzy
 #| msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgid "Assume assembler support for view in (DWARF2+) .loc directives"
 msgstr "%<-fsplit-stack%> はアセンブラが CFI 指示をサポートしている必要があります"
 
-#: common.opt:2892 common.opt:2896 common.opt:2900 common.opt:2904
+#: common.opt:2896 common.opt:2900 common.opt:2904 common.opt:2908
 #, fuzzy, c-format
 #| msgid "switch %qs is no longer supported"
 msgid "switch %qs no longer supported"
 msgstr "%qs スイッチは既にサポートされていません"
 
-#: common.opt:2909
+#: common.opt:2913
 msgid "Record DW_AT_decl_column and DW_AT_call_column in DWARF."
 msgstr ""
 
-#: common.opt:2913
+#: common.opt:2917
 #, fuzzy
 #| msgid "Generate debug information in default format"
 msgid "Generate debug information in default version of DWARF format."
 msgstr "デフォルト形式でデバッグ情報を生成する"
 
-#: common.opt:2917
+#: common.opt:2921
 #, fuzzy
 #| msgid "Generate debug information in DWARF v2 (or later) format"
 msgid "Generate debug information in DWARF v2 (or later) format."
 msgstr "DWARF v2 (またはそれ以降) 形式でデバッグ情報を生成する"
 
-#: common.opt:2921
+#: common.opt:2925
 #, fuzzy
 #| msgid "Generate debug information in default extended format"
 msgid "Generate debug information in default extended format."
 msgstr "デフォルト拡張形式でデバッグ情報を生成する"
 
-#: common.opt:2925
+#: common.opt:2929
 #, fuzzy
 #| msgid "Generate a single exit point for each function"
 msgid "Generate extended entry point information for inlined functions"
 msgstr "各関数で単一の終了点を生成する"
 
-#: common.opt:2929
+#: common.opt:2933
 msgid "Compute locview reset points based on insn length estimates"
 msgstr ""
 
-#: common.opt:2937
+#: common.opt:2941
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:2941
+#: common.opt:2945
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:2945
+#: common.opt:2949
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr ""
 
-#: common.opt:2949
+#: common.opt:2953
 #, fuzzy
 #| msgid "Record gcc command line switches in the object file."
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr "オブジェクトファイル内に gcc のコマンドラインスイッチを記録する。"
 
-#: common.opt:2953
+#: common.opt:2957
 #, fuzzy
 #| msgid "Generate debug information in default format"
 msgid "Generate debug information in separate .dwo files."
 msgstr "デフォルト形式でデバッグ情報を生成する"
 
-#: common.opt:2957
+#: common.opt:2961
 #, fuzzy
 #| msgid "Generate debug information in STABS format"
 msgid "Generate debug information in STABS format."
 msgstr "STABS 形式でデバッグ情報を生成する"
 
-#: common.opt:2961
+#: common.opt:2965
 #, fuzzy
 #| msgid "Generate debug information in extended STABS format"
 msgid "Generate debug information in extended STABS format."
 msgstr "拡張 STABS 形式でデバッグ情報を生成する"
 
-#: common.opt:2965
+#: common.opt:2969
 msgid "Emit progressive recommended breakpoint locations."
 msgstr ""
 
-#: common.opt:2969
+#: common.opt:2973
 msgid "Don't emit DWARF additions beyond selected version."
 msgstr ""
 
-#: common.opt:2973
+#: common.opt:2977
 #, fuzzy
 #| msgid "Toggle debug information generation"
 msgid "Toggle debug information generation."
 msgstr "デバッグ情報生成の有効・無効を切り替える"
 
-#: common.opt:2977
+#: common.opt:2981
 msgid "Augment variable location lists with progressive views."
 msgstr ""
 
-#: common.opt:2984
+#: common.opt:2988
 #, fuzzy
 #| msgid "Generate debug information in VMS format"
 msgid "Generate debug information in VMS format."
 msgstr "VMS 形式でデバッグ情報を生成する"
 
-#: common.opt:2988
+#: common.opt:2992
 #, fuzzy
 #| msgid "Generate debug information in XCOFF format"
 msgid "Generate debug information in XCOFF format."
 msgstr "XCOFF 形式でデバッグ情報を生成する"
 
-#: common.opt:2992
+#: common.opt:2996
 #, fuzzy
 #| msgid "Generate debug information in extended XCOFF format"
 msgid "Generate debug information in extended XCOFF format."
 msgstr "拡張 XCOFF 形式でデバッグ情報を生成する"
 
-#: common.opt:3010
+#: common.opt:3014
 #, fuzzy
 #| msgid "Generate isel instructions"
 msgid "Generate compressed debug sections."
 msgstr "isel 命令を生成する"
 
-#: common.opt:3014
+#: common.opt:3018
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>."
 msgstr ""
 
-#: common.opt:3021
+#: common.opt:3025
 #, fuzzy
 #| msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory"
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory."
 msgstr "-iplugindir=<dir>\tデフォルトのプラグインディレクトリを <dir> に設定する"
 
-#: common.opt:3025
+#: common.opt:3029
 #, fuzzy
 #| msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory"
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory."
 msgstr "-iplugindir=<dir>\tデフォルトのプラグインディレクトリを <dir> に設定する"
 
-#: common.opt:3047
+#: common.opt:3051
 #, fuzzy
 #| msgid "-o <file>\tPlace output into <file>"
 msgid "-o <file>\tPlace output into <file>."
 msgstr "-o <file>\t出力を <file> に配置する"
 
-#: common.opt:3051
+#: common.opt:3055
 #, fuzzy
 #| msgid "Enable function profiling"
 msgid "Enable function profiling."
 msgstr "関数プロファイルを有効にする"
 
-#: common.opt:3061
+#: common.opt:3065
 #, fuzzy
 #| msgid "Like -pedantic but issue them as errors"
 msgid "Like -pedantic but issue them as errors."
 msgstr "-pedantic と同様だが、エラーとして出力する"
 
-#: common.opt:3101
+#: common.opt:3105
 #, fuzzy
 #| msgid "Do not display functions compiled or elapsed time"
 msgid "Do not display functions compiled or elapsed time."
 msgstr "コンパイルされた関数または費やした時間に関して出力しない"
 
-#: common.opt:3133
+#: common.opt:3137
 #, fuzzy
 #| msgid "Enable verbose output"
 msgid "Enable verbose output."
 msgstr "冗長な出力を有効にする"
 
-#: common.opt:3137
+#: common.opt:3141
 #, fuzzy
 #| msgid "Display the compiler's version"
 msgid "Display the compiler's version."
 msgstr "`コンパイラのバージョンを表示する"
 
-#: common.opt:3141
+#: common.opt:3145
 #, fuzzy
 #| msgid "Suppress warnings"
 msgid "Suppress warnings."
 msgstr "警告を抑止する"
 
-#: common.opt:3151
+#: common.opt:3155
 #, fuzzy
 #| msgid "Create a shared library"
 msgid "Create a shared library."
 msgstr "共有ライブラリを作成する"
 
-#: common.opt:3196
+#: common.opt:3200
 #, fuzzy
 #| msgid "Create a position independent executable"
 msgid "Don't create a dynamically linked position independent executable."
 msgstr "位置非依存実行可能ファイルを生成する"
 
-#: common.opt:3200
+#: common.opt:3204
 #, fuzzy
 #| msgid "Create a position independent executable"
 msgid "Create a dynamically linked position independent executable."
 msgstr "位置非依存実行可能ファイルを生成する"
 
-#: common.opt:3204
+#: common.opt:3208
 #, fuzzy
 #| msgid "Create a position independent executable"
 msgid "Create a static position independent executable."
 msgstr "位置非依存実行可能ファイルを生成する"
 
-#: common.opt:3211
+#: common.opt:3215
 msgid "Use caller save register across calls if possible."
 msgstr ""
 
-#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:598 cp/cvt.c:1308
+#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:599 cp/cvt.c:1308
 #: cp/cvt.c:1561
 #, gcc-internal-format
 msgid "value computed is not used"
@@ -19119,7 +19120,7 @@
 msgstr "整数または真偽型が予期されます"
 
 #: go/gofrontend/expressions.cc:4331 c/c-parser.c:13477 c/c-parser.c:13484
-#: cp/parser.c:33264 cp/parser.c:33271
+#: cp/parser.c:33261 cp/parser.c:33268
 #, fuzzy, gcc-internal-format
 #| msgid "expected pointer"
 msgid "expected integer"
@@ -19580,14 +19581,14 @@
 msgid "ignoring attribute %qE because it conflicts with attribute %qs"
 msgstr "%qE 属性は %s 属性と競合します"
 
-#: attribs.c:449 c-family/c-attribs.c:1894 cp/decl.c:13690 cp/friend.c:302
-#: cp/tree.c:4559
+#: attribs.c:449 c-family/c-attribs.c:1905 cp/decl.c:13714 cp/friend.c:302
+#: cp/tree.c:4607
 #, fuzzy, gcc-internal-format
 msgid "previous declaration here"
 msgstr "前方での `%s' の宣言"
 
 #. Warn about and ignore all others for now, but store them.
-#: attribs.c:564 c-family/c-attribs.c:2717 objc/objc-act.c:4963
+#: attribs.c:564 c-family/c-attribs.c:2728 objc/objc-act.c:4963
 #: objc/objc-act.c:6932 objc/objc-act.c:8119 objc/objc-act.c:8170
 #, gcc-internal-format
 msgid "%qE attribute directive ignored"
@@ -19607,18 +19608,18 @@
 #. This is a c++11 attribute that appertains to a
 #. type-specifier, outside of the definition of, a class
 #. type.  Ignore it.
-#: attribs.c:590 cp/decl.c:10999
+#: attribs.c:590 cp/decl.c:11023
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored"
 msgid "attribute ignored"
 msgstr "%qE 属性は無視されました"
 
-#: attribs.c:592 cp/decl.c:11000
+#: attribs.c:592 cp/decl.c:11024
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
 
-#: attribs.c:610 c-family/c-attribs.c:3219
+#: attribs.c:610 c-family/c-attribs.c:3230
 #, gcc-internal-format
 msgid "%qE attribute does not apply to types"
 msgstr "%qE 属性は型に適用できません"
@@ -19634,40 +19635,40 @@
 msgstr "型が既に定義されているため型属性が無視されました"
 
 #: attribs.c:691 attribs.c:1622 attribs.c:1632 attribs.c:1642
-#: c-family/c-attribs.c:540 c-family/c-attribs.c:559 c-family/c-attribs.c:577
-#: c-family/c-attribs.c:607 c-family/c-attribs.c:628 c-family/c-attribs.c:649
-#: c-family/c-attribs.c:690 c-family/c-attribs.c:717 c-family/c-attribs.c:733
-#: c-family/c-attribs.c:750 c-family/c-attribs.c:766 c-family/c-attribs.c:792
-#: c-family/c-attribs.c:807 c-family/c-attribs.c:835 c-family/c-attribs.c:852
-#: c-family/c-attribs.c:870 c-family/c-attribs.c:893 c-family/c-attribs.c:931
-#: c-family/c-attribs.c:954 c-family/c-attribs.c:971 c-family/c-attribs.c:1000
-#: c-family/c-attribs.c:1021 c-family/c-attribs.c:1042
-#: c-family/c-attribs.c:1069 c-family/c-attribs.c:1099
-#: c-family/c-attribs.c:1136 c-family/c-attribs.c:1189
-#: c-family/c-attribs.c:1255 c-family/c-attribs.c:1313
-#: c-family/c-attribs.c:1402 c-family/c-attribs.c:1432
-#: c-family/c-attribs.c:1483 c-family/c-attribs.c:1998
-#: c-family/c-attribs.c:2035 c-family/c-attribs.c:2096
-#: c-family/c-attribs.c:2152 c-family/c-attribs.c:2230
-#: c-family/c-attribs.c:2312 c-family/c-attribs.c:2371
-#: c-family/c-attribs.c:2390 c-family/c-attribs.c:2498
-#: c-family/c-attribs.c:2514 c-family/c-attribs.c:2530
-#: c-family/c-attribs.c:2551 c-family/c-attribs.c:2608
-#: c-family/c-attribs.c:2635 c-family/c-attribs.c:2690
-#: c-family/c-attribs.c:2870 c-family/c-attribs.c:2891
-#: c-family/c-attribs.c:3004 c-family/c-attribs.c:3031
-#: c-family/c-attribs.c:3221 c-family/c-attribs.c:3239
-#: c-family/c-attribs.c:3262 c-family/c-attribs.c:3301
-#: c-family/c-attribs.c:3383 c-family/c-attribs.c:3439
-#: c-family/c-attribs.c:3455 c-family/c-attribs.c:3549
-#: c-family/c-common.c:5600 config/darwin.c:2072 config/arm/arm.c:6868
+#: c-family/c-attribs.c:547 c-family/c-attribs.c:566 c-family/c-attribs.c:584
+#: c-family/c-attribs.c:614 c-family/c-attribs.c:635 c-family/c-attribs.c:656
+#: c-family/c-attribs.c:697 c-family/c-attribs.c:728 c-family/c-attribs.c:744
+#: c-family/c-attribs.c:761 c-family/c-attribs.c:777 c-family/c-attribs.c:803
+#: c-family/c-attribs.c:818 c-family/c-attribs.c:846 c-family/c-attribs.c:863
+#: c-family/c-attribs.c:881 c-family/c-attribs.c:904 c-family/c-attribs.c:942
+#: c-family/c-attribs.c:965 c-family/c-attribs.c:982 c-family/c-attribs.c:1011
+#: c-family/c-attribs.c:1032 c-family/c-attribs.c:1053
+#: c-family/c-attribs.c:1080 c-family/c-attribs.c:1110
+#: c-family/c-attribs.c:1147 c-family/c-attribs.c:1200
+#: c-family/c-attribs.c:1266 c-family/c-attribs.c:1324
+#: c-family/c-attribs.c:1413 c-family/c-attribs.c:1443
+#: c-family/c-attribs.c:1494 c-family/c-attribs.c:2009
+#: c-family/c-attribs.c:2046 c-family/c-attribs.c:2107
+#: c-family/c-attribs.c:2163 c-family/c-attribs.c:2241
+#: c-family/c-attribs.c:2323 c-family/c-attribs.c:2382
+#: c-family/c-attribs.c:2401 c-family/c-attribs.c:2509
+#: c-family/c-attribs.c:2525 c-family/c-attribs.c:2541
+#: c-family/c-attribs.c:2562 c-family/c-attribs.c:2619
+#: c-family/c-attribs.c:2646 c-family/c-attribs.c:2701
+#: c-family/c-attribs.c:2881 c-family/c-attribs.c:2902
+#: c-family/c-attribs.c:3015 c-family/c-attribs.c:3042
+#: c-family/c-attribs.c:3232 c-family/c-attribs.c:3250
+#: c-family/c-attribs.c:3273 c-family/c-attribs.c:3312
+#: c-family/c-attribs.c:3394 c-family/c-attribs.c:3450
+#: c-family/c-attribs.c:3466 c-family/c-attribs.c:3560
+#: c-family/c-common.c:5598 config/darwin.c:2072 config/arm/arm.c:6868
 #: config/arm/arm.c:6896 config/arm/arm.c:6913 config/avr/avr.c:9698
-#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6497
-#: config/i386/i386.c:41520 config/ia64/ia64.c:788
-#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33056
-#: config/spu/spu.c:3743 ada/gcc-interface/utils.c:6244
-#: ada/gcc-interface/utils.c:6261 ada/gcc-interface/utils.c:6277
-#: ada/gcc-interface/utils.c:6303 brig/brig-lang.c:476 lto/lto-lang.c:283
+#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6500
+#: config/i386/i386.c:41514 config/ia64/ia64.c:788
+#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33112
+#: config/spu/spu.c:3743 ada/gcc-interface/utils.c:6249
+#: ada/gcc-interface/utils.c:6266 ada/gcc-interface/utils.c:6282
+#: ada/gcc-interface/utils.c:6308 brig/brig-lang.c:476 lto/lto-lang.c:283
 #, gcc-internal-format
 msgid "%qE attribute ignored"
 msgstr "%qE 属性は無視されました"
@@ -20047,92 +20048,108 @@
 msgid "%Kattempt to free a non-heap object"
 msgstr "%K ヒープではないオブジェクトを free する試みです"
 
-#: calls.c:1434
+#: calls.c:1291 file-prefix-map.c:50
 #, fuzzy, gcc-internal-format
+#| msgid "valid arguments to %qs are: %s"
+msgid "invalid argument %qs to %qs"
+msgstr "%qs への有効な引数は次の通りです: %s"
+
+#: calls.c:1452
+#, fuzzy, gcc-internal-format
 msgid "%Kargument %i value %qE is negative"
 msgstr "右シフト回数が負の数です"
 
-#: calls.c:1452
+#: calls.c:1470
 #, fuzzy, gcc-internal-format
 msgid "%Kargument %i value is zero"
 msgstr "`%s' の第二引数は `char **' とすべきです"
 
-#: calls.c:1469
+#: calls.c:1487
 #, gcc-internal-format
 msgid "%Kargument %i value %qE exceeds maximum object size %E"
 msgstr ""
 
-#: calls.c:1483
+#: calls.c:1501
 #, fuzzy, gcc-internal-format
 msgid "%Kargument %i range [%E, %E] is negative"
 msgstr "右シフト回数が負の数です"
 
-#: calls.c:1490
+#: calls.c:1508
 #, gcc-internal-format
 msgid "%Kargument %i range [%E, %E] exceeds maximum object size %E"
 msgstr ""
 
-#: calls.c:1520
+#: calls.c:1538
 #, gcc-internal-format
 msgid "%Kproduct %<%E * %E%> of arguments %i and %i exceeds %<SIZE_MAX%>"
 msgstr ""
 
-#: calls.c:1526
+#: calls.c:1544
 #, gcc-internal-format
 msgid "%Kproduct %<%E * %E%> of arguments %i and %i exceeds maximum object size %E"
 msgstr ""
 
-#: calls.c:1537 calls.c:1540
+#: calls.c:1555 calls.c:1558
 #, fuzzy, gcc-internal-format
 #| msgid "argument %d of %qE must be in the range %d...%d"
 msgid "argument %i in the range [%E, %E]"
 msgstr "%d 番目の %qE の引数は %d...%d の範囲でなければいけません"
 
-#: calls.c:1551
+#: calls.c:1569
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "in a call to built-in allocation function %qD"
 msgstr "非関数 %qD の呼び出しです"
 
-#: calls.c:1554
+#: calls.c:1572
 #, fuzzy, gcc-internal-format
 msgid "in a call to allocation function %qD declared here"
 msgstr "インライン関数 %q+D を弱いとして宣言できません"
 
-#: calls.c:1711
+#: calls.c:1835
 #, gcc-internal-format
-msgid "%qD argument %i declared attribute %<nonstring%> is smaller than the specified bound %E"
+msgid "%qD argument %i declared attribute %<nonstring%> is smaller than the specified bound %wu"
 msgstr ""
 
-#: calls.c:1716
+#: calls.c:1841
 #, gcc-internal-format
+msgid "%qD argument %i declared attribute %<nonstring%> is smaller than the specified bound [%E, %E]"
+msgstr ""
+
+#: calls.c:1847
+#, gcc-internal-format
+msgid "%qD argument %i declared attribute %<nonstring%> may be smaller than the specified bound [%E, %E]"
+msgstr ""
+
+#: calls.c:1857
+#, gcc-internal-format
 msgid "%qD argument %i declared attribute %<nonstring%>"
 msgstr ""
 
-#: calls.c:1721
+#: calls.c:1862
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared here"
 msgid "argument %qD declared here"
 msgstr "%qD はここで宣言されています"
 
-#: calls.c:1735
+#: calls.c:1876
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "[cannot find %s]"
 msgid "cannot tail-call: %s"
 msgstr "[%s が見つかりません]"
 
-#: calls.c:3365
+#: calls.c:3506
 #, gcc-internal-format
 msgid "function call has aggregate value"
 msgstr "関数呼び出しが集合体の値を持っています"
 
-#: calls.c:4059
+#: calls.c:4200
 #, fuzzy, gcc-internal-format
 #| msgid "missing argument to %qs"
 msgid "passing too large argument on stack"
 msgstr "%qs への引数がありません"
 
-#: cfgexpand.c:1665 function.c:1002 varasm.c:2231
+#: cfgexpand.c:1665 function.c:1002 varasm.c:2242
 #, gcc-internal-format
 msgid "size of variable %q+D is too large"
 msgstr "変数 %q+D のサイズが大きすぎます"
@@ -20709,241 +20726,241 @@
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr "命令連鎖中の bb の数 (%d) が n_basic_blocks (%d) と違います"
 
-#: cgraph.c:3051
+#: cgraph.c:3056
 #, fuzzy, gcc-internal-format
 msgid "caller edge count invalid"
 msgstr "左シフト回数が負の数です"
 
-#: cgraph.c:3135
+#: cgraph.c:3140
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr ""
 
-#: cgraph.c:3142
+#: cgraph.c:3147
 #, gcc-internal-format
 msgid "cgraph count invalid"
 msgstr ""
 
-#: cgraph.c:3147
+#: cgraph.c:3152
 #, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr ""
 
-#: cgraph.c:3152
+#: cgraph.c:3157
 #, fuzzy, gcc-internal-format
 #| msgid "Assume symbols might be invalid"
 msgid "local symbols must be defined"
 msgstr "シンボルが有効であると見なす"
 
-#: cgraph.c:3157
+#: cgraph.c:3162
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr ""
 
-#: cgraph.c:3162
+#: cgraph.c:3167
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr ""
 
-#: cgraph.c:3167
+#: cgraph.c:3172
 #, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr ""
 
-#: cgraph.c:3174
+#: cgraph.c:3179
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for indirect edge from %s"
 msgstr ""
 
-#: cgraph.c:3181
+#: cgraph.c:3186
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr ""
 
-#: cgraph.c:3196
+#: cgraph.c:3201
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr ""
 
-#: cgraph.c:3206
+#: cgraph.c:3211
 #, fuzzy, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr "セクションポインタを欠いています"
 
-#: cgraph.c:3211
+#: cgraph.c:3216
 #, fuzzy, gcc-internal-format
 msgid "multiple inline callers"
 msgstr "重複する `virtual' 指定子"
 
-#: cgraph.c:3218
+#: cgraph.c:3223
 #, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr ""
 
-#: cgraph.c:3239
+#: cgraph.c:3244
 #, fuzzy, gcc-internal-format
 msgid "caller edge count does not match BB count"
 msgstr "左シフト回数が負の数です"
 
-#: cgraph.c:3261
+#: cgraph.c:3266
 #, gcc-internal-format
 msgid "indirect call count does not match BB count"
 msgstr ""
 
-#: cgraph.c:3272
+#: cgraph.c:3277
 #, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr ""
 
-#: cgraph.c:3277
+#: cgraph.c:3282
 #, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr ""
 
-#: cgraph.c:3289
+#: cgraph.c:3294
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr ""
 
-#: cgraph.c:3301
+#: cgraph.c:3306
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr ""
 
-#: cgraph.c:3307
+#: cgraph.c:3312
 #, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr ""
 
-#: cgraph.c:3312
+#: cgraph.c:3317
 #, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr ""
 
-#: cgraph.c:3317
+#: cgraph.c:3322
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr ""
 
-#: cgraph.c:3329
+#: cgraph.c:3334
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr ""
 
-#: cgraph.c:3337
+#: cgraph.c:3342
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr ""
 
-#: cgraph.c:3342
+#: cgraph.c:3347
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr ""
 
-#: cgraph.c:3349
+#: cgraph.c:3354
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr ""
 
-#: cgraph.c:3358
+#: cgraph.c:3363
 #, gcc-internal-format
 msgid "Instrumentation clone does not reference original node"
 msgstr ""
 
-#: cgraph.c:3365
+#: cgraph.c:3370
 #, fuzzy, gcc-internal-format
 #| msgid "alignment of %qD is bigger than original declaration"
 msgid "Not instrumented node has non-NULL original declaration"
 msgstr "%qD の整列は元の宣言より大きいです"
 
-#: cgraph.c:3375
+#: cgraph.c:3380
 #, fuzzy, gcc-internal-format
 #| msgid "alignment of %qD is bigger than original declaration"
 msgid "Instrumented node has wrong original declaration"
 msgstr "%qD の整列は元の宣言より大きいです"
 
-#: cgraph.c:3393
+#: cgraph.c:3398
 #, gcc-internal-format
 msgid "Node has more than one chkp reference"
 msgstr ""
 
-#: cgraph.c:3398
+#: cgraph.c:3403
 #, fuzzy, gcc-internal-format
 msgid "Wrong node is referenced with chkp reference"
 msgstr "参照を参照として宣言できません"
 
-#: cgraph.c:3406
+#: cgraph.c:3411
 #, gcc-internal-format
 msgid "Analyzed node has no reference to instrumented version"
 msgstr ""
 
-#: cgraph.c:3420
+#: cgraph.c:3425
 #, gcc-internal-format
 msgid "Alias chain for instrumented node is broken"
 msgstr ""
 
-#: cgraph.c:3429
+#: cgraph.c:3434
 #, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3434
+#: cgraph.c:3439
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3439
+#: cgraph.c:3444
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr ""
 
-#: cgraph.c:3445
+#: cgraph.c:3450
 #, gcc-internal-format
 msgid "Instrumentation thunk has wrong edge callee"
 msgstr ""
 
-#: cgraph.c:3481
+#: cgraph.c:3486
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr ""
 
-#: cgraph.c:3489
+#: cgraph.c:3494
 #, fuzzy, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr "`%s' は宣言よりも先に使用されました"
 
-#: cgraph.c:3498
+#: cgraph.c:3503
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr ""
 
-#: cgraph.c:3508
+#: cgraph.c:3513
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr ""
 
-#: cgraph.c:3518
+#: cgraph.c:3523
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "reference to dead statement"
 msgstr "文が予期されます"
 
-#: cgraph.c:3531
+#: cgraph.c:3536
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3543
+#: cgraph.c:3548
 #, gcc-internal-format, gfc-internal-format
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3554
+#: cgraph.c:3559
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr "verify_cgraph_node に失敗しました"
 
-#: cgraph.c:3661 varpool.c:306
+#: cgraph.c:3666 varpool.c:306
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: section %s is missing"
 msgstr ""
@@ -20975,12 +20992,12 @@
 msgstr "%qE 属性は %qT が既に定義されているため無視されます"
 
 #. include_self=
-#: cgraphunit.c:981 c/c-decl.c:11282
+#: cgraphunit.c:981 c/c-decl.c:11302
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F が使用されましたが定義されていません"
 
-#: cgraphunit.c:983 c/c-decl.c:11291
+#: cgraphunit.c:983 c/c-decl.c:11311
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "%q+F が %<static%> と宣言されましたが定義されていません"
@@ -21101,12 +21118,12 @@
 msgid "cannot find '%s'"
 msgstr "'%s' が見つかりません"
 
-#: collect-utils.c:183 collect2.c:2361 collect2.c:2560 gcc.c:3080 gcc.c:6856
+#: collect-utils.c:183 collect2.c:2387 collect2.c:2586 gcc.c:3080 gcc.c:6856
 #, gcc-internal-format
 msgid "pex_init failed: %m"
 msgstr "pex_init に失敗しました: %m"
 
-#: collect-utils.c:192 collect2.c:2370 collect2.c:2568 gcc.c:8498
+#: collect-utils.c:192 collect2.c:2396 collect2.c:2594 gcc.c:8498
 #, gcc-internal-format
 msgid "%s: %m"
 msgstr "%s: %m"
@@ -21116,98 +21133,98 @@
 msgid "COLLECT_LTO_WRAPPER must be set"
 msgstr "COLLECT_LTO_WRAPPER が設定されなければいけません"
 
-#: collect2.c:966 gcc.c:7382 lto-wrapper.c:1666
+#: collect2.c:969 gcc.c:7382 lto-wrapper.c:1692
 #: config/i386/intelmic-mkoffload.c:556 config/nvptx/mkoffload.c:405
 #, gcc-internal-format
 msgid "atexit failed"
 msgstr "atexit に失敗しました"
 
-#: collect2.c:1064
+#: collect2.c:1067
 #, gcc-internal-format
 msgid "no arguments"
 msgstr "引数がありません"
 
-#: collect2.c:1303 opts.c:904
+#: collect2.c:1311 opts.c:904
 #, gcc-internal-format
 msgid "LTO support has not been enabled in this configuration"
 msgstr "`この設定内では LTO サポートが有効になっていません"
 
-#: collect2.c:1344
+#: collect2.c:1352
 #, fuzzy, gcc-internal-format
 #| msgid "can%'t open %s: %m"
 msgid "can't open %s: %m"
 msgstr "%s を開けません: %m"
 
-#: collect2.c:1450
+#: collect2.c:1472
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown demangling style '%s'"
 msgstr "不明な名前復元 (demangle) スタイル '%s' です"
 
-#: collect2.c:1546 collect2.c:1729 collect2.c:1769
+#: collect2.c:1574 collect2.c:1757 collect2.c:1797
 #, fuzzy, gcc-internal-format
 #| msgid "fopen %s"
 msgid "fopen %s: %m"
 msgstr "fopen %s"
 
-#: collect2.c:1549 collect2.c:1734 collect2.c:1772
+#: collect2.c:1577 collect2.c:1762 collect2.c:1800
 #, fuzzy, gcc-internal-format
 #| msgid "fclose %s"
 msgid "fclose %s: %m"
 msgstr "fclose %s"
 
-#: collect2.c:2335
+#: collect2.c:2361
 #, gcc-internal-format
 msgid "cannot find 'nm'"
 msgstr "'nm' が見つかりません"
 
-#: collect2.c:2383
+#: collect2.c:2409
 #, fuzzy, gcc-internal-format
 #| msgid "can't open nm output"
 msgid "can't open nm output: %m"
 msgstr "nm の出力を開けません"
 
-#: collect2.c:2467
+#: collect2.c:2493
 #, gcc-internal-format, gfc-internal-format
 msgid "init function found in object %s"
 msgstr "init 関数をオブジェクト %s で見つけました"
 
-#: collect2.c:2478
+#: collect2.c:2504
 #, gcc-internal-format, gfc-internal-format
 msgid "fini function found in object %s"
 msgstr "fini 関数をオブジェクト %s で見つけました"
 
-#: collect2.c:2535
+#: collect2.c:2561
 #, gcc-internal-format
 msgid "cannot find 'ldd'"
 msgstr "'ldd' が見つかりません"
 
-#: collect2.c:2581
+#: collect2.c:2607
 #, fuzzy, gcc-internal-format
 #| msgid "can't open ldd output"
 msgid "can't open ldd output: %m"
 msgstr "ldd の出力を開けません"
 
-#: collect2.c:2599
+#: collect2.c:2625
 #, gcc-internal-format, gfc-internal-format
 msgid "dynamic dependency %s not found"
 msgstr "動的依存関係 %s が見つかりません"
 
-#: collect2.c:2611
+#: collect2.c:2637
 #, gcc-internal-format, gfc-internal-format
 msgid "unable to open dynamic dependency '%s'"
 msgstr "動的依存関係 '%s' を開けません"
 
-#: collect2.c:2765
+#: collect2.c:2791
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: not a COFF file"
 msgstr "%s: COFF ファイルではありません"
 
-#: collect2.c:2930
+#: collect2.c:2961
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: cannot open as COFF file"
 msgstr "%s: COFF ファイルとして開けません"
 
-#: collect2.c:2989
+#: collect2.c:3020
 #, gcc-internal-format, gfc-internal-format
 msgid "library lib%s not found"
 msgstr "ライブラリ lib%s が見つかりません"
@@ -21421,12 +21438,12 @@
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr ""
 
-#: dwarf2out.c:10901
+#: dwarf2out.c:10909
 #, gcc-internal-format
 msgid "-gdwarf-6 is output as version 5 with incompatibilities"
 msgstr ""
 
-#: dwarf2out.c:14415
+#: dwarf2out.c:14423
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
@@ -21546,12 +21563,6 @@
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr ""
 
-#: file-prefix-map.c:50
-#, fuzzy, gcc-internal-format
-#| msgid "valid arguments to %qs are: %s"
-msgid "invalid argument %qs to %qs"
-msgstr "%qs への有効な引数は次の通りです: %s"
-
 #: final.c:1868
 #, gcc-internal-format
 msgid "the frame size of %wd bytes is larger than %wd bytes"
@@ -21572,42 +21583,42 @@
 msgid "large fixed-point constant implicitly truncated to fixed-point type"
 msgstr "大きな固定小数定数が暗黙的に固定整数型に切り詰められました"
 
-#: fold-const.c:4151 fold-const.c:4161
+#: fold-const.c:4157 fold-const.c:4167
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d due to width of bit-field"
 msgstr "ビットフィールド幅のため、比較が常に %d になります"
 
-#: fold-const.c:5478 tree-ssa-reassoc.c:2374 tree-ssa-reassoc.c:3214
+#: fold-const.c:5484 tree-ssa-reassoc.c:2379 tree-ssa-reassoc.c:3219
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
 
-#: fold-const.c:5928 fold-const.c:5942
+#: fold-const.c:5934 fold-const.c:5948
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr "比較が常に %d となります"
 
-#: fold-const.c:6085
+#: fold-const.c:6091
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr ""
 
-#: fold-const.c:6090
+#: fold-const.c:6096
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr ""
 
-#: fold-const.c:8310
+#: fold-const.c:8316
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr ""
 
-#: fold-const.c:8710
+#: fold-const.c:8716
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr ""
 
-#: fold-const.c:12063
+#: fold-const.c:12069
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr ""
@@ -21617,7 +21628,7 @@
 msgid "total size of local objects too large"
 msgstr "局所オブジェクトの総サイズが大きすぎます"
 
-#: function.c:1776 gimplify.c:6270
+#: function.c:1776 gimplify.c:6273
 #, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr "%<asm%> 内で制約を行うことは出来ません"
@@ -21928,7 +21939,7 @@
 msgid "%s: linker input file unused because linking not done"
 msgstr "%s: リンクが完了しなかったのでリンカの入力ファイルは使われませんでした"
 
-#: gcc.c:8420 c-family/c-opts.c:770
+#: gcc.c:8420 c-family/c-opts.c:768
 #, gcc-internal-format
 msgid "cannot use %<-%> as input filename for a precompiled header"
 msgstr ""
@@ -22169,7 +22180,7 @@
 msgid "%G%qD destination unchanged after copying no bytes"
 msgstr ""
 
-#: gimple-fold.c:2052 tree-ssa-strlen.c:2050
+#: gimple-fold.c:2052 tree-ssa-strlen.c:2074
 msgid "%G%qD specified bound %E equals destination size"
 msgstr ""
 
@@ -22193,12 +22204,12 @@
 msgid "null pointer dereference"
 msgstr "NULL ポインタ"
 
-#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12451
-#: tree.c:12488 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10147
-#: c/c-typeck.c:10164 c/gimple-parser.c:1616 c/gimple-parser.c:1624
+#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12455
+#: tree.c:12492 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10152
+#: c/c-typeck.c:10169 c/gimple-parser.c:1616 c/gimple-parser.c:1624
 #: cp/call.c:6493 cp/call.c:8098 cp/constexpr.c:820 cp/constexpr.c:2309
-#: cp/cvt.c:1015 cp/cvt.c:1042 cp/decl.c:7334 cp/decl2.c:5256 cp/pt.c:8334
-#: cp/semantics.c:1836 cp/semantics.c:4053 cp/typeck.c:1700 cp/typeck.c:1895
+#: cp/cvt.c:1015 cp/cvt.c:1042 cp/decl.c:7355 cp/decl2.c:5246 cp/pt.c:8348
+#: cp/semantics.c:1836 cp/semantics.c:4056 cp/typeck.c:1700 cp/typeck.c:1895
 #: cp/typeck.c:3837
 #, gcc-internal-format
 msgid "declared here"
@@ -22209,297 +22220,297 @@
 msgid "nonnull argument %qD compared to NULL"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2517 gimple-ssa-sprintf.c:2637
+#: gimple-ssa-sprintf.c:2555 gimple-ssa-sprintf.c:2675
 #, gcc-internal-format
 msgid "%qE output may be truncated before the last format character"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2519 gimple-ssa-sprintf.c:2639
+#: gimple-ssa-sprintf.c:2557 gimple-ssa-sprintf.c:2677
 #, gcc-internal-format
 msgid "%qE output truncated before the last format character"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2522 gimple-ssa-sprintf.c:2642
+#: gimple-ssa-sprintf.c:2560 gimple-ssa-sprintf.c:2680
 #, gcc-internal-format
 msgid "%qE may write a terminating nul past the end of the destination"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2524 gimple-ssa-sprintf.c:2644
+#: gimple-ssa-sprintf.c:2562 gimple-ssa-sprintf.c:2682
 #, gcc-internal-format
 msgid "%qE writing a terminating nul past the end of the destination"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2534
+#: gimple-ssa-sprintf.c:2572
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size %wu"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.c:2541
+#: gimple-ssa-sprintf.c:2579
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size %wu"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.c:2548
+#: gimple-ssa-sprintf.c:2586
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size %wu"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.c:2559
+#: gimple-ssa-sprintf.c:2597
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2562
+#: gimple-ssa-sprintf.c:2600
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2564
+#: gimple-ssa-sprintf.c:2602
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2576
+#: gimple-ssa-sprintf.c:2614
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2579
+#: gimple-ssa-sprintf.c:2617
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2582
+#: gimple-ssa-sprintf.c:2620
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2591
+#: gimple-ssa-sprintf.c:2629
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2594
+#: gimple-ssa-sprintf.c:2632
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2597
+#: gimple-ssa-sprintf.c:2635
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2606
+#: gimple-ssa-sprintf.c:2644
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2609
+#: gimple-ssa-sprintf.c:2647
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2611
+#: gimple-ssa-sprintf.c:2649
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2653
+#: gimple-ssa-sprintf.c:2691
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size between %wu and %wu"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.c:2660
+#: gimple-ssa-sprintf.c:2698
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size between %wu and %wu"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.c:2668
+#: gimple-ssa-sprintf.c:2706
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size between %wu and %wu"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.c:2680
+#: gimple-ssa-sprintf.c:2718
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2683
+#: gimple-ssa-sprintf.c:2721
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2686
+#: gimple-ssa-sprintf.c:2724
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2699
+#: gimple-ssa-sprintf.c:2737
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2702
+#: gimple-ssa-sprintf.c:2740
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2705
+#: gimple-ssa-sprintf.c:2743
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2715
+#: gimple-ssa-sprintf.c:2753
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2718
+#: gimple-ssa-sprintf.c:2756
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2721
+#: gimple-ssa-sprintf.c:2759
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2730
+#: gimple-ssa-sprintf.c:2768
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2733
+#: gimple-ssa-sprintf.c:2771
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2736
+#: gimple-ssa-sprintf.c:2774
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2825
+#: gimple-ssa-sprintf.c:2863
 #, gcc-internal-format
 msgid "%<%.*s%> directive argument is null"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2890
+#: gimple-ssa-sprintf.c:2928
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes exceeds minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2897
+#: gimple-ssa-sprintf.c:2935
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may exceed minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2900
+#: gimple-ssa-sprintf.c:2938
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes exceeds minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2929
+#: gimple-ssa-sprintf.c:2967
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2936
+#: gimple-ssa-sprintf.c:2974
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2939
+#: gimple-ssa-sprintf.c:2977
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may cause result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2949
+#: gimple-ssa-sprintf.c:2987
 #, gcc-internal-format
 msgid "assuming directive output of %wu byte"
 msgid_plural "assuming directive output of %wu bytes"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.c:2956
+#: gimple-ssa-sprintf.c:2994
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to %qE"
 msgid "directive argument %qE"
 msgstr "%qE への引数が少なすぎます"
 
-#: gimple-ssa-sprintf.c:2958
+#: gimple-ssa-sprintf.c:2996
 #, fuzzy, gcc-internal-format
 #| msgid "%s expects an integer literal in the range [%d, %d]"
 msgid "directive argument in the range [%E, %E]"
 msgstr "%s は [%d, %d] の範囲内の整数リテラルが予期されます"
 
-#: gimple-ssa-sprintf.c:2962
+#: gimple-ssa-sprintf.c:3000
 #, gcc-internal-format
 msgid "using the range [%E, %E] for directive argument"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2982
+#: gimple-ssa-sprintf.c:3020
 #, gcc-internal-format
 msgid "%qE output %wu byte into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2983
+#: gimple-ssa-sprintf.c:3021
 #, gcc-internal-format
 msgid "%qE output %wu bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2987
+#: gimple-ssa-sprintf.c:3025
 #, gcc-internal-format
 msgid "%qE output between %wu and %wu bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2992
+#: gimple-ssa-sprintf.c:3030
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes (assuming %wu) into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2997
+#: gimple-ssa-sprintf.c:3035
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3368
+#: gimple-ssa-sprintf.c:3406
 #, gcc-internal-format
 msgid "%<%.*s%> directive width out of range"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3402
+#: gimple-ssa-sprintf.c:3440
 #, gcc-internal-format
 msgid "%<%.*s%> directive precision out of range"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3893
+#: gimple-ssa-sprintf.c:3931
 #, gcc-internal-format
 msgid "specified bound %wu exceeds maximum object size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3899
+#: gimple-ssa-sprintf.c:3937
 #, gcc-internal-format
 msgid "specified bound %wu exceeds %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3949
+#: gimple-ssa-sprintf.c:3987
 #, fuzzy, gcc-internal-format
 #| msgid "null pointer"
 msgid "null destination pointer"
 msgstr "NULL ポインタ"
 
-#: gimple-ssa-sprintf.c:3966
+#: gimple-ssa-sprintf.c:4004
 #, gcc-internal-format
 msgid "specified bound %wu exceeds the size %wu of the destination object"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3978
+#: gimple-ssa-sprintf.c:4016
 #, fuzzy, gcc-internal-format
 msgid "null format string"
 msgstr "フォーマット文字列が null です"
@@ -22710,10 +22721,10 @@
 msgstr ""
 
 #: gimple-ssa-warn-restrict.c:1678 c/c-decl.c:3603 c/c-decl.c:3874
-#: c/c-typeck.c:8345 cp/class.c:1346 cp/class.c:3098 cp/decl.c:3979
-#: cp/decl.c:10753 cp/decl.c:11151 cp/decl.c:11160 cp/friend.c:384
+#: c/c-typeck.c:8350 cp/class.c:1346 cp/class.c:3102 cp/decl.c:3979
+#: cp/decl.c:10777 cp/decl.c:11175 cp/decl.c:11184 cp/friend.c:384
 #: cp/friend.c:393 cp/parser.c:3275 cp/parser.c:3372 cp/parser.c:3422
-#: cp/parser.c:6327 cp/parser.c:21027
+#: cp/parser.c:6330 cp/parser.c:21024
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD はここで宣言されています"
@@ -22784,224 +22795,224 @@
 msgid "using result of function returning %<void%>"
 msgstr "%<void%> を返す関数の結果を使用しています"
 
-#: gimplify.c:6128
+#: gimplify.c:6131
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid lvalue in asm output %d"
 msgstr ""
 
-#: gimplify.c:6271
+#: gimplify.c:6274
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr ""
 
-#: gimplify.c:6311 gimplify.c:6320
+#: gimplify.c:6314 gimplify.c:6323
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr ""
 
-#: gimplify.c:6928
+#: gimplify.c:6931
 #, fuzzy, gcc-internal-format
 #| msgid "register variable %qD used in nested function"
 msgid "threadprivate variable %qE used in target region"
 msgstr "レジスタ変数 %qD が入れ子になった関数内で使用されています"
 
-#: gimplify.c:6930
+#: gimplify.c:6933
 #, gcc-internal-format
 msgid "enclosing target region"
 msgstr ""
 
-#: gimplify.c:6942
+#: gimplify.c:6945
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in untied task"
 msgstr ""
 
-#: gimplify.c:6944
+#: gimplify.c:6947
 #, gcc-internal-format
 msgid "enclosing task"
 msgstr ""
 
-#: gimplify.c:7016
+#: gimplify.c:7019
 #, fuzzy, gcc-internal-format
 msgid "%qE not specified in enclosing %qs"
 msgstr "`%s' の宣言が矛盾しています"
 
-#: gimplify.c:7018
+#: gimplify.c:7021
 #, fuzzy, gcc-internal-format
 #| msgid "error closing %s: %m"
 msgid "enclosing %qs"
 msgstr "%s を閉じているときにエラーが発生しました: %m"
 
-#: gimplify.c:7143
+#: gimplify.c:7146
 #, gcc-internal-format
 msgid "%qE not specified in enclosing OpenACC %qs construct"
 msgstr ""
 
-#: gimplify.c:7145
+#: gimplify.c:7148
 #, gcc-internal-format
 msgid "enclosing OpenACC %qs construct"
 msgstr ""
 
-#: gimplify.c:7198
+#: gimplify.c:7201
 #, gcc-internal-format
 msgid "%qE with %<link%> clause used in %<routine%> function"
 msgstr ""
 
-#: gimplify.c:7206
+#: gimplify.c:7209
 #, fuzzy, gcc-internal-format
 #| msgid "%qE undeclared (first use in this function)"
 msgid "%qE requires a %<declare%> directive for use in a %<routine%> function"
 msgstr "%qE が宣言されていません (この関数内での最初の使用)"
 
-#: gimplify.c:7272 gimplify.c:7872
+#: gimplify.c:7275 gimplify.c:7875
 #, fuzzy, gcc-internal-format
 #| msgid "variable %q+D declared %<inline%>"
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr "変数 %q+D が %<inline%> と宣言されています"
 
-#: gimplify.c:7293
+#: gimplify.c:7296
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr ""
 
-#: gimplify.c:7411 gimplify.c:7443
+#: gimplify.c:7414 gimplify.c:7446
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE is predetermined linear"
 msgstr "レジスタ変数 `%s' が入れ子関数の中で使われました"
 
-#: gimplify.c:7414
+#: gimplify.c:7417
 #, gcc-internal-format
 msgid "iteration variable %qE should be private"
 msgstr ""
 
-#: gimplify.c:7428
+#: gimplify.c:7431
 #, gcc-internal-format
 msgid "iteration variable %qE should not be firstprivate"
 msgstr ""
 
-#: gimplify.c:7431
+#: gimplify.c:7434
 #, gcc-internal-format
 msgid "iteration variable %qE should not be reduction"
 msgstr ""
 
-#: gimplify.c:7434
+#: gimplify.c:7437
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be linear"
 msgstr "レジスタ変数 `%s' が入れ子関数の中で使われました"
 
-#: gimplify.c:7437
+#: gimplify.c:7440
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be lastprivate"
 msgstr "レジスタ変数 `%s' が入れ子関数の中で使われました"
 
-#: gimplify.c:7440
+#: gimplify.c:7443
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be private"
 msgstr "レジスタ変数 `%s' が入れ子関数の中で使われました"
 
-#: gimplify.c:7742
+#: gimplify.c:7745
 #, gcc-internal-format
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr ""
 
-#: gimplify.c:7949
+#: gimplify.c:7952
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr ""
 
-#: gimplify.c:8160
+#: gimplify.c:8163
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qE appears more than once in map clauses"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
-#: gimplify.c:8464
+#: gimplify.c:8467
 #, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr ""
 
-#: gimplify.c:8484
+#: gimplify.c:8487
 #, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr ""
 
-#: gimplify.c:8510
+#: gimplify.c:8513
 #, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr ""
 
-#: gimplify.c:8775
+#: gimplify.c:8778
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr ""
 
-#: gimplify.c:8808
+#: gimplify.c:8811
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:9000
+#: gimplify.c:9003
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:9051
+#: gimplify.c:9054
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr ""
 
-#: gimplify.c:9133
+#: gimplify.c:9136
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to present_or_copy"
 msgstr ""
 
-#: gimplify.c:9278
+#: gimplify.c:9281
 #, fuzzy, gcc-internal-format
 #| msgid "invalid template declaration of %qD"
 msgid "invalid private reduction on %qE"
 msgstr "%qD の無効なテンプレート宣言です"
 
-#: gimplify.c:11103 omp-low.c:2791
+#: gimplify.c:11106 omp-low.c:2791
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: gimplify.c:11121
+#: gimplify.c:11124
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr ""
 
-#: gimplify.c:11134
+#: gimplify.c:11137
 #, fuzzy, gcc-internal-format
 #| msgid "number of results does not match number of values"
 msgid "number of variables in %<depend(sink)%> clause does not match number of iteration variables"
 msgstr "結果の数が値の数と一致しません"
 
-#: gimplify.c:11147
+#: gimplify.c:11150
 #, gcc-internal-format
 msgid "more than one %<depend(source)%> clause on an %<ordered%> construct"
 msgstr ""
 
-#: gimplify.c:11158
+#: gimplify.c:11161
 #, gcc-internal-format
 msgid "%<depend(source)%> clause specified together with %<depend(sink:)%> clauses on the same construct"
 msgstr ""
 
-#: gimplify.c:12393
+#: gimplify.c:12396
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr "gimplification に失敗しました"
 
-#: gimplify.c:12936
+#: gimplify.c:12939
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr ""
 
-#: gimplify.c:12941
+#: gimplify.c:12944
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr ""
 
-#: gimplify.c:12948
+#: gimplify.c:12951
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr "このコードまで到達した場合、プログラムは中止されます"
@@ -23481,47 +23492,47 @@
 msgid "Max. number of generated reload insns per insn is achieved (%d)\n"
 msgstr ""
 
-#: lto-cgraph.c:1294
+#: lto-cgraph.c:1296
 #, gcc-internal-format, gfc-internal-format
 msgid "bytecode stream: found multiple instances of cgraph node with uid %d"
 msgstr ""
 
-#: lto-cgraph.c:1472
+#: lto-cgraph.c:1474
 #, gcc-internal-format
 msgid "bytecode stream: no caller found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1478
+#: lto-cgraph.c:1480
 #, gcc-internal-format
 msgid "bytecode stream: no callee found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1552
+#: lto-cgraph.c:1554
 #, gcc-internal-format
 msgid "bytecode stream: found empty cgraph node"
 msgstr ""
 
-#: lto-cgraph.c:1730
+#: lto-cgraph.c:1732
 #, gcc-internal-format, gfc-internal-format
 msgid "At most %i profile runs is supported. Perhaps corrupted profile?"
 msgstr ""
 
-#: lto-cgraph.c:1817
+#: lto-cgraph.c:1819
 #, gcc-internal-format, gfc-internal-format
 msgid "Profile information in %s corrupted"
 msgstr ""
 
-#: lto-cgraph.c:1855
+#: lto-cgraph.c:1857
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO cgraph in %s"
 msgstr ""
 
-#: lto-cgraph.c:1865
+#: lto-cgraph.c:1867
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO section refs in %s"
 msgstr ""
 
-#: lto-cgraph.c:1946
+#: lto-cgraph.c:1948
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid rotate insn"
 msgid "invalid offload table in %s"
@@ -23597,90 +23608,96 @@
 msgid "bytecode stream in file %qs generated with LTO version %d.%d instead of the expected %d.%d"
 msgstr ""
 
-#: lto-wrapper.c:117
+#: lto-wrapper.c:118
 #, fuzzy, gcc-internal-format
 #| msgid "deleting LTRANS file %s"
 msgid "deleting LTRANS file %s: %m"
 msgstr "LTRANS ファイル %s を削除しています"
 
-#: lto-wrapper.c:154
+#: lto-wrapper.c:155
 #, gcc-internal-format
 msgid "malformed COLLECT_GCC_OPTIONS"
 msgstr "誤った形式の COLLECT_GCC_OPTIONS です"
 
-#: lto-wrapper.c:308
+#: lto-wrapper.c:309
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "created and used with different endianness"
 msgid "Option %s with different values"
 msgstr "作成時と使用時でエンディアンが異なります"
 
-#: lto-wrapper.c:392
+#: lto-wrapper.c:393
 #, gcc-internal-format, gfc-internal-format
 msgid "Option %s not used consistently in all LTO input files"
 msgstr ""
 
-#: lto-wrapper.c:832
+#: lto-wrapper.c:833
 #, gcc-internal-format, gfc-internal-format
 msgid "problem with building target image for %s\n"
 msgstr ""
 
-#: lto-wrapper.c:852
+#: lto-wrapper.c:853
 #, fuzzy, gcc-internal-format
 #| msgid "no input files"
 msgid "reading input file"
 msgstr "入力ファイルがありません"
 
-#: lto-wrapper.c:857
+#: lto-wrapper.c:858
 #, fuzzy, gcc-internal-format
 #| msgid "%s:error writing output file '%s'\n"
 msgid "writing output file"
 msgstr "%s: 出力ファイル '%s' を書き込み中にエラーが発生しました\n"
 
-#: lto-wrapper.c:889
+#: lto-wrapper.c:890
 #, gcc-internal-format
 msgid "installation error, can't find crtoffloadtable.o"
 msgstr ""
 
-#: lto-wrapper.c:1000 lto-wrapper.c:1012
+#: lto-wrapper.c:1001 lto-wrapper.c:1013
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s: %s"
 msgid "%s: %s\n"
 msgstr "%s: %s"
 
-#: lto-wrapper.c:1056
+#: lto-wrapper.c:1064
 #, gcc-internal-format
 msgid "environment variable COLLECT_GCC must be set"
 msgstr "環境変数 COLLECT_GCC が設定されていなければいけません"
 
-#: lto-wrapper.c:1060 config/nvptx/mkoffload.c:363
+#: lto-wrapper.c:1068 config/nvptx/mkoffload.c:363
 #, gcc-internal-format
 msgid "environment variable COLLECT_GCC_OPTIONS must be set"
 msgstr "環境変数 COLLECT_GCC_OPTIONS が設定されていなければいけません"
 
-#: lto-wrapper.c:1229 lto-wrapper.c:1285
+#: lto-wrapper.c:1237 lto-wrapper.c:1293
 #, fuzzy, gcc-internal-format
 #| msgid "can%'t open %s: %m"
 msgid "cannot open %s: %m"
 msgstr "%s を開けません: %m"
 
-#: lto-wrapper.c:1232 lto-wrapper.c:1291
+#: lto-wrapper.c:1240 lto-wrapper.c:1299
 #, fuzzy, gcc-internal-format
 #| msgid "can%'t read %s: %m"
 msgid "cannot read %s: %m"
 msgstr "%s を読み込めません: %m"
 
-#: lto-wrapper.c:1259
+#: lto-wrapper.c:1267
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid #pragma %s"
 msgid "invalid format of %s"
 msgstr "無効な #pragma %s です"
 
-#: lto-wrapper.c:1482
+#: lto-wrapper.c:1491
 #, fuzzy, gcc-internal-format
 #| msgid "fopen: %s"
 msgid "fopen: %s: %m"
 msgstr "fopen: %s"
 
+#: lto-wrapper.c:1508
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "%s:could not open output file '%s'\n"
+msgid "Corrupted ltrans output file %s"
+msgstr "%s: 出力ファイル '%s' を開けませんでした\n"
+
 #: multiple_target.c:76
 #, fuzzy, gcc-internal-format
 #| msgid "nested functions not supported on this target"
@@ -24046,13 +24063,13 @@
 msgid "unrecognized argument in option %qs"
 msgstr "オプション %qs 内で認識できない引数です"
 
-#: opts-common.c:1198 config/i386/i386.c:3206
+#: opts-common.c:1198 config/i386/i386.c:3209
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
-#: opts-common.c:1201 config/i386/i386.c:3209
+#: opts-common.c:1201 config/i386/i386.c:3212
 #, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "%qs への有効な引数は次の通りです: %s"
@@ -24681,22 +24698,22 @@
 msgid "output operand %d must use %<&%> constraint"
 msgstr "出力被演算子 %d は %<&%> 制約を使用しなければいけません"
 
-#: regcprop.c:1187
+#: regcprop.c:1193
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad next_regno for empty chain (%u)"
 msgstr ""
 
-#: regcprop.c:1199
+#: regcprop.c:1205
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: Loop in regno chain (%u)"
 msgstr ""
 
-#: regcprop.c:1202
+#: regcprop.c:1208
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad oldest_regno (%u)"
 msgstr ""
 
-#: regcprop.c:1214
+#: regcprop.c:1220
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Non-empty reg in chain (%s %u %i)"
 msgstr ""
@@ -24741,7 +24758,7 @@
 msgstr "レジスタが二つの大域レジスタ変数として使われました"
 
 #: reginfo.c:789 config/powerpcspe/powerpcspe.c:32259
-#: config/rs6000/rs6000.c:29453
+#: config/rs6000/rs6000.c:29530
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting types for %q+D"
 msgid "conflicts with %qD"
@@ -24990,158 +25007,163 @@
 msgid "function symbol is not function"
 msgstr "`%s' は関数を返す関数として宣言されています"
 
-#: symtab.c:1006
+#: symtab.c:1005
+#, gcc-internal-format
+msgid "inconsistent `ifunc' attribute"
+msgstr ""
+
+#: symtab.c:1013
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to variables"
 msgid "variable symbol is not variable"
 msgstr "%qE は変数にのみ適用できます"
 
-#: symtab.c:1012
+#: symtab.c:1019
 #, gcc-internal-format
 msgid "node has unknown type"
 msgstr ""
 
-#: symtab.c:1021
+#: symtab.c:1028
 #, gcc-internal-format
 msgid "node not found node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.c:1029
+#: symtab.c:1036
 #, gcc-internal-format
 msgid "node differs from node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.c:1038
+#: symtab.c:1045
 #, gcc-internal-format
 msgid "assembler name hash list corrupted"
 msgstr ""
 
-#: symtab.c:1051
+#: symtab.c:1058
 #, fuzzy, gcc-internal-format
 msgid "node not found in symtab assembler name hash"
 msgstr "メソッド '%s' はクラス内に見つかりません"
 
-#: symtab.c:1058
+#: symtab.c:1065
 #, gcc-internal-format
 msgid "double linked list of assembler names corrupted"
 msgstr ""
 
-#: symtab.c:1063
+#: symtab.c:1070
 #, gcc-internal-format
 msgid "node has body_removed but is definition"
 msgstr ""
 
-#: symtab.c:1068
+#: symtab.c:1075
 #, fuzzy, gcc-internal-format
 #| msgid "called object %qE is not a function"
 msgid "node is analyzed but it is not a definition"
 msgstr "呼び出されたオブジェクト %qE は関数ではありません"
 
-#: symtab.c:1073
+#: symtab.c:1080
 #, gcc-internal-format
 msgid "node is alias but not implicit alias"
 msgstr ""
 
-#: symtab.c:1078
+#: symtab.c:1085
 #, fuzzy, gcc-internal-format
 #| msgid "old-style function definition"
 msgid "node is alias but not definition"
 msgstr "古いスタイルの関数定義です"
 
-#: symtab.c:1083
+#: symtab.c:1090
 #, gcc-internal-format
 msgid "node is weakref but not an transparent_alias"
 msgstr ""
 
-#: symtab.c:1088
+#: symtab.c:1095
 #, gcc-internal-format
 msgid "node is transparent_alias but not an alias"
 msgstr ""
 
-#: symtab.c:1097
+#: symtab.c:1104
 #, gcc-internal-format
 msgid "node is in same_comdat_group list but has no comdat_group"
 msgstr ""
 
-#: symtab.c:1102
+#: symtab.c:1109
 #, gcc-internal-format
 msgid "same_comdat_group list across different groups"
 msgstr ""
 
-#: symtab.c:1107
+#: symtab.c:1114
 #, gcc-internal-format
 msgid "mixing different types of symbol in same comdat groups is not supported"
 msgstr ""
 
-#: symtab.c:1112
+#: symtab.c:1119
 #, gcc-internal-format
 msgid "node is alone in a comdat group"
 msgstr ""
 
-#: symtab.c:1119
+#: symtab.c:1126
 #, gcc-internal-format
 msgid "same_comdat_group is not a circular list"
 msgstr ""
 
-#: symtab.c:1134
+#: symtab.c:1141
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local symbol referred to by %s outside its comdat"
 msgstr ""
 
-#: symtab.c:1144
+#: symtab.c:1151
 #, gcc-internal-format
 msgid "implicit_section flag is set but section isn't"
 msgstr ""
 
-#: symtab.c:1151
+#: symtab.c:1158
 #, gcc-internal-format
 msgid "Both section and comdat group is set"
 msgstr ""
 
-#: symtab.c:1163
+#: symtab.c:1170
 #, gcc-internal-format
 msgid "Alias and target's section differs"
 msgstr ""
 
-#: symtab.c:1170
+#: symtab.c:1177
 #, gcc-internal-format
 msgid "Alias and target's comdat groups differs"
 msgstr ""
 
-#: symtab.c:1185
+#: symtab.c:1192
 #, gcc-internal-format
 msgid "Transparent alias and target's assembler names differs"
 msgstr ""
 
-#: symtab.c:1193
+#: symtab.c:1200
 #, gcc-internal-format
 msgid "Chained transparent aliases"
 msgstr ""
 
-#: symtab.c:1216 symtab.c:1253
+#: symtab.c:1223 symtab.c:1260
 #, fuzzy, gcc-internal-format
 #| msgid "verify_ssa failed"
 msgid "symtab_node::verify failed"
 msgstr "verify_ssa に失敗しました"
 
-#: symtab.c:1249
+#: symtab.c:1256
 #, gcc-internal-format
 msgid "Two symbols with same comdat_group are not linked by the same_comdat_group list."
 msgstr ""
 
-#: symtab.c:1658
+#: symtab.c:1665
 #, fuzzy, gcc-internal-format
 #| msgid "function %qD redeclared as variable"
 msgid "function %q+D part of alias cycle"
 msgstr "関数 %qD が変数として再宣言されました"
 
-#: symtab.c:1660
+#: symtab.c:1667
 #, fuzzy, gcc-internal-format
 #| msgid "variable %q+D set but not used"
 msgid "variable %q+D part of alias cycle"
 msgstr "変数 %q+D が設定されましたが使用されていません"
 
-#: symtab.c:1688
+#: symtab.c:1695
 #, gcc-internal-format
 msgid "section of alias %q+D must match section of its target"
 msgstr ""
@@ -25977,7 +25999,7 @@
 msgid "the first argument of a VEC_COND_EXPR must be of a boolean vector type of the same number of elements as the result"
 msgstr ""
 
-#: tree-cfg.c:4395 c/c-typeck.c:5212
+#: tree-cfg.c:4395 c/c-typeck.c:5217
 #, gcc-internal-format
 msgid "type mismatch in conditional expression"
 msgstr "条件式での型の組合わせが適合しません"
@@ -26342,22 +26364,22 @@
 msgid "missing edge %i->%i"
 msgstr ""
 
-#: tree-cfg.c:9379
+#: tree-cfg.c:9388
 #, gcc-internal-format
 msgid "%<noreturn%> function does return"
 msgstr "%<noreturn%> 関数が戻り (return) ます"
 
-#: tree-cfg.c:9400 tree-cfg.c:9432
+#: tree-cfg.c:9409 tree-cfg.c:9441
 #, gcc-internal-format
 msgid "control reaches end of non-void function"
 msgstr "制御が非 void 関数の終りに到達しました"
 
-#: tree-cfg.c:9498 cp/cvt.c:1039
+#: tree-cfg.c:9507 cp/cvt.c:1039
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgstr "warn_unused_result 属性付きで宣言されている %qD の戻り値を無視しています"
 
-#: tree-cfg.c:9503 cp/cvt.c:1046
+#: tree-cfg.c:9512 cp/cvt.c:1046
 #, gcc-internal-format
 msgid "ignoring return value of function declared with attribute warn_unused_result"
 msgstr "warn_unused_result 属性付きで宣言されている関数の戻り値を無視しています"
@@ -26628,44 +26650,44 @@
 msgid "stmt volatile flag not up-to-date"
 msgstr ""
 
-#: tree-ssa-strlen.c:1975
+#: tree-ssa-strlen.c:1999
 msgid "%G%qD output truncated before terminating nul copying %E byte from a string of the same length"
 msgid_plural "%G%qD output truncated before terminating nul copying %E bytes from a string of the same length"
 msgstr[0] ""
 
-#: tree-ssa-strlen.c:1989
+#: tree-ssa-strlen.c:2013
 msgid "%G%qD output truncated copying %E byte from a string of length %wu"
 msgid_plural "%G%qD output truncated copying %E bytes from a string of length %wu"
 msgstr[0] ""
 
-#: tree-ssa-strlen.c:1996
+#: tree-ssa-strlen.c:2020
 msgid "%G%qD output truncated copying between %wu and %wu bytes from a string of length %wu"
 msgstr ""
 
-#: tree-ssa-strlen.c:2008
+#: tree-ssa-strlen.c:2032
 msgid "%G%qD output may be truncated copying %E byte from a string of length %wu"
 msgid_plural "%G%qD output may be truncated copying %E bytes from a string of length %wu"
 msgstr[0] ""
 
-#: tree-ssa-strlen.c:2015 tree-ssa-strlen.c:2029
+#: tree-ssa-strlen.c:2039 tree-ssa-strlen.c:2053
 msgid "%G%qD output may be truncated copying between %wu and %wu bytes from a string of length %wu"
 msgstr ""
 
-#: tree-ssa-strlen.c:2150
+#: tree-ssa-strlen.c:2174
 msgid "%G%qD output truncated before terminating nul copying as many bytes from a string as its length"
 msgstr ""
 
-#: tree-ssa-strlen.c:2156
+#: tree-ssa-strlen.c:2180
 msgid "%G%qD specified bound depends on the length of the source argument"
 msgstr ""
 
-#: tree-ssa-strlen.c:2163
+#: tree-ssa-strlen.c:2187
 #, fuzzy, gcc-internal-format
 #| msgid "length modifier"
 msgid "length computed here"
 msgstr "長さ修飾子"
 
-#: tree-ssa-uninit.c:191 varasm.c:331
+#: tree-ssa-uninit.c:191 varasm.c:342
 #, gcc-internal-format
 msgid "%qD was declared here"
 msgstr "%qD はここで定義されています"
@@ -26843,27 +26865,27 @@
 msgid "target specific builtin not available"
 msgstr ""
 
-#: tree-vect-generic.c:287
+#: tree-vect-generic.c:283
 #, gcc-internal-format
 msgid "vector operation will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-generic.c:290
+#: tree-vect-generic.c:286
 #, gcc-internal-format
 msgid "vector operation will be expanded in parallel"
 msgstr ""
 
-#: tree-vect-generic.c:341
+#: tree-vect-generic.c:337
 #, gcc-internal-format
 msgid "vector operation will be expanded with a single scalar operation"
 msgstr ""
 
-#: tree-vect-generic.c:941
+#: tree-vect-generic.c:937
 #, gcc-internal-format
 msgid "vector condition will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-generic.c:1373
+#: tree-vect-generic.c:1369
 #, gcc-internal-format
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr ""
@@ -26873,31 +26895,31 @@
 msgid "vectorization did not happen for a simd loop"
 msgstr ""
 
-#: tree-vrp.c:4930 tree-vrp.c:4974
+#: tree-vrp.c:4931 tree-vrp.c:4975
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is above array bounds"
 msgid "array subscript %E is above array bounds of %qT"
 msgstr "配列の添字が配列の境界を上回っています"
 
-#: tree-vrp.c:4956
+#: tree-vrp.c:4957
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is outside array bounds"
 msgid "array subscript [%E, %E] is outside array bounds of %qT"
 msgstr "配列の添字が配列境界の外にあります"
 
-#: tree-vrp.c:4988
+#: tree-vrp.c:4989
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is below array bounds"
 msgid "array subscript %E is below array bounds of %qT"
 msgstr "配列の添字が配列の境界を下回っています"
 
-#: tree-vrp.c:5046
+#: tree-vrp.c:5047
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is below array bounds"
 msgid "array subscript %wi is below array bounds of %qT"
 msgstr "配列の添字が配列の境界を下回っています"
 
-#: tree-vrp.c:5060
+#: tree-vrp.c:5061
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is above array bounds"
 msgid "array subscript %wu is above array bounds of %qT"
@@ -26913,95 +26935,95 @@
 msgid "side-effects element in no-side-effects CONSTRUCTOR"
 msgstr ""
 
-#: tree.c:7852
+#: tree.c:7856
 #, gcc-internal-format
 msgid "arrays of functions are not meaningful"
 msgstr "関数の配列は意味がありません"
 
-#: tree.c:8019
+#: tree.c:8023
 #, gcc-internal-format
 msgid "function return type cannot be function"
 msgstr "関数の返す型が関数であってはなりません"
 
-#: tree.c:9327 tree.c:9412 tree.c:9473
+#: tree.c:9331 tree.c:9416 tree.c:9477
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: %s, have %s in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9364
+#: tree.c:9368
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected none of %s, have %s in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9377
+#: tree.c:9381
 #, gcc-internal-format
 msgid "tree check: expected class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9426
+#: tree.c:9430
 #, gcc-internal-format
 msgid "tree check: did not expect class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9439
+#: tree.c:9443
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected omp_clause %s, have %s in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9499
+#: tree.c:9503
 #, gcc-internal-format
 msgid "tree check: expected tree that contains %qs structure, have %qs in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9513
+#: tree.c:9517
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "RTL check: access of elt %d of vector with last elt %d in %s, at %s:%d"
 msgid "tree check: accessed elt %d of tree_int_cst with %d elts in %s, at %s:%d"
 msgstr "RTL check: ベクトルの elt %d を最後の elt %d (%s 中)と一緒にアクセスします (%s:%d)"
 
-#: tree.c:9525
+#: tree.c:9529
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_vec with %d elts in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9538
+#: tree.c:9542
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of %s with %d operands in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9551
+#: tree.c:9555
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of omp_clause %s with %d operands in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:12446
+#: tree.c:12450
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is deprecated: %s"
 msgid "%qD is deprecated: %s"
 msgstr "%qE は廃止されました: %s"
 
-#: tree.c:12449
+#: tree.c:12453
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is deprecated"
 msgid "%qD is deprecated"
 msgstr "%qE は廃止されました"
 
-#: tree.c:12473 tree.c:12495
+#: tree.c:12477 tree.c:12499
 #, gcc-internal-format
 msgid "%qE is deprecated: %s"
 msgstr "%qE は廃止されました: %s"
 
-#: tree.c:12476 tree.c:12498
+#: tree.c:12480 tree.c:12502
 #, gcc-internal-format
 msgid "%qE is deprecated"
 msgstr "%qE は廃止されました"
 
-#: tree.c:12482 tree.c:12503
+#: tree.c:12486 tree.c:12507
 #, gcc-internal-format, gfc-internal-format
 msgid "type is deprecated: %s"
 msgstr "型は廃止されました: %s"
 
-#: tree.c:12485 tree.c:12506
+#: tree.c:12489 tree.c:12510
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr "型は廃止されました"
@@ -27026,246 +27048,246 @@
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.c:13043
+#: tree.c:13047
 #, gcc-internal-format, gfc-internal-format
 msgid "type variant differs by %s"
 msgstr ""
 
-#: tree.c:13084
+#: tree.c:13088
 #, gcc-internal-format
 msgid "type variant has different TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13086
+#: tree.c:13090
 #, gcc-internal-format
 msgid "type variant's TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13088
+#: tree.c:13092
 #, gcc-internal-format
 msgid "type's TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13108
+#: tree.c:13112
 #, gcc-internal-format
 msgid "type variant with TYPE_ALIAS_SET_KNOWN_P"
 msgstr ""
 
-#: tree.c:13121
+#: tree.c:13125
 #, gcc-internal-format
 msgid "type variant has different TYPE_VFIELD"
 msgstr ""
 
-#: tree.c:13157
+#: tree.c:13161
 #, gcc-internal-format
 msgid "type variant has different TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13159
+#: tree.c:13163
 #, gcc-internal-format
 msgid "type variant's TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13161
+#: tree.c:13165
 #, gcc-internal-format
 msgid "type's TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13199
+#: tree.c:13203
 #, gcc-internal-format
 msgid "type variant has different TYPE_FIELDS"
 msgstr ""
 
-#: tree.c:13201
+#: tree.c:13205
 #, gcc-internal-format
 msgid "first mismatch is field"
 msgstr ""
 
-#: tree.c:13203
+#: tree.c:13207
 #, gcc-internal-format
 msgid "and field"
 msgstr ""
 
-#: tree.c:13220
+#: tree.c:13224
 #, gcc-internal-format
 msgid "type variant has different TREE_TYPE"
 msgstr ""
 
-#: tree.c:13222 tree.c:13233
+#: tree.c:13226 tree.c:13237
 #, gcc-internal-format
 msgid "type variant's TREE_TYPE"
 msgstr ""
 
-#: tree.c:13224 tree.c:13235
+#: tree.c:13228 tree.c:13239
 #, gcc-internal-format
 msgid "type's TREE_TYPE"
 msgstr ""
 
-#: tree.c:13231
+#: tree.c:13235
 #, fuzzy, gcc-internal-format
 #| msgid "ms_hook_prologue is not compatible with nested function"
 msgid "type is not compatible with its variant"
 msgstr "ms_hook_prologue は入れ子になった関数と両立できません"
 
-#: tree.c:13534
+#: tree.c:13538
 #, fuzzy, gcc-internal-format
 #| msgid "environment variable %qs not defined"
 msgid "Main variant is not defined"
 msgstr "環境変数 %qs が定義されていません"
 
-#: tree.c:13539
+#: tree.c:13543
 #, gcc-internal-format
 msgid "TYPE_MAIN_VARIANT has different TYPE_MAIN_VARIANT"
 msgstr ""
 
-#: tree.c:13551
+#: tree.c:13555
 #, gcc-internal-format
 msgid "TYPE_CANONICAL has different TYPE_CANONICAL"
 msgstr ""
 
-#: tree.c:13569
+#: tree.c:13573
 #, gcc-internal-format
 msgid "TYPE_CANONICAL is not compatible"
 msgstr ""
 
-#: tree.c:13577
+#: tree.c:13581
 #, gcc-internal-format
 msgid "TYPE_MODE of TYPE_CANONICAL is not compatible"
 msgstr ""
 
-#: tree.c:13583
+#: tree.c:13587
 #, gcc-internal-format
 msgid "TYPE_CANONICAL of main variant is not main variant"
 msgstr ""
 
-#: tree.c:13599
+#: tree.c:13603
 #, gcc-internal-format
 msgid "TYPE_VFIELD is not FIELD_DECL nor TREE_LIST"
 msgstr ""
 
-#: tree.c:13609
+#: tree.c:13613
 #, gcc-internal-format
 msgid "TYPE_NEXT_PTR_TO is not POINTER_TYPE"
 msgstr ""
 
-#: tree.c:13619
+#: tree.c:13623
 #, gcc-internal-format
 msgid "TYPE_NEXT_REF_TO is not REFERENCE_TYPE"
 msgstr ""
 
-#: tree.c:13640
+#: tree.c:13644
 #, gcc-internal-format
 msgid "TYPE_BINFO is not TREE_BINFO"
 msgstr ""
 
-#: tree.c:13646
+#: tree.c:13650
 #, gcc-internal-format
 msgid "TYPE_BINFO type is not TYPE_MAIN_VARIANT"
 msgstr ""
 
-#: tree.c:13657
+#: tree.c:13661
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not record nor union"
 msgstr ""
 
-#: tree.c:13668
+#: tree.c:13672
 #, gcc-internal-format
 msgid "TYPE_OFFSET_BASETYPE is not record nor union"
 msgstr ""
 
-#: tree.c:13686
+#: tree.c:13690
 #, gcc-internal-format
 msgid "TYPE_ARRAY_MAX_SIZE not INTEGER_CST"
 msgstr ""
 
-#: tree.c:13693
+#: tree.c:13697
 #, gcc-internal-format
 msgid "TYPE_MAX_VALUE_RAW non-NULL"
 msgstr ""
 
-#: tree.c:13700
+#: tree.c:13704
 #, gcc-internal-format
 msgid "TYPE_LANG_SLOT_1 (binfo) field is non-NULL"
 msgstr ""
 
-#: tree.c:13716
+#: tree.c:13720
 #, gcc-internal-format
 msgid "Enum value is not CONST_DECL or INTEGER_CST"
 msgstr ""
 
-#: tree.c:13724
+#: tree.c:13728
 #, gcc-internal-format
 msgid "Enum value type is not INTEGER_TYPE nor convertible to the enum"
 msgstr ""
 
-#: tree.c:13731
+#: tree.c:13735
 #, gcc-internal-format
 msgid "Enum value name is not IDENTIFIER_NODE"
 msgstr ""
 
-#: tree.c:13741
+#: tree.c:13745
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qE has non-integer type"
 msgid "Array TYPE_DOMAIN is not integer type"
 msgstr "配列 %qE のサイズが非整数型です"
 
-#: tree.c:13750
+#: tree.c:13754
 #, fuzzy, gcc-internal-format
 #| msgid "field %qE has incomplete type"
 msgid "TYPE_FIELDS defined in incomplete type"
 msgstr "フィールド %qE が不完全型を持っています"
 
-#: tree.c:13772
+#: tree.c:13776
 #, gcc-internal-format
 msgid "Wrong tree in TYPE_FIELDS list"
 msgstr ""
 
-#: tree.c:13787
+#: tree.c:13791
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is %i while TYPE_CACHED_VALUES is %p"
 msgstr ""
 
-#: tree.c:13793
+#: tree.c:13797
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES is not TREE_VEC"
 msgstr ""
 
-#: tree.c:13806
+#: tree.c:13810
 #, gcc-internal-format
 msgid "wrong TYPE_CACHED_VALUES entry"
 msgstr ""
 
-#: tree.c:13819
+#: tree.c:13823
 #, gcc-internal-format
 msgid "TREE_PURPOSE is non-NULL in TYPE_ARG_TYPES list"
 msgstr ""
 
-#: tree.c:13825
+#: tree.c:13829
 #, gcc-internal-format
 msgid "Wrong entry in TYPE_ARG_TYPES list"
 msgstr ""
 
-#: tree.c:13832
+#: tree.c:13836
 #, gcc-internal-format
 msgid "TYPE_VALUES_RAW field is non-NULL"
 msgstr ""
 
-#: tree.c:13844
+#: tree.c:13848
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is set while it should not"
 msgstr ""
 
-#: tree.c:13850
+#: tree.c:13854
 #, gcc-internal-format
 msgid "TYPE_STRING_FLAG is set on wrong type code"
 msgstr ""
 
-#: tree.c:13860
+#: tree.c:13864
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not main variant"
 msgstr ""
 
-#: tree.c:13867
+#: tree.c:13871
 #, fuzzy, gcc-internal-format
 #| msgid "verify_gimple failed"
 msgid "verify_type failed"
@@ -27291,192 +27313,192 @@
 msgid "corrupted value profile: %s profile counter (%d out of %d) inconsistent with basic-block count (%d)"
 msgstr "破損した値のプロファイルです: %s プロファイルの総合計数 (%d) は BB 数 (%d) と一致しません"
 
-#: var-tracking.c:7166
+#: var-tracking.c:7184
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded with -fvar-tracking-assignments, retrying without"
 msgstr "変数追跡サイズ制限が -fvar-tracking-assignments を超過しています。-fvar-tracking-assignments 無しで再度試みています"
 
-#: var-tracking.c:7170
+#: var-tracking.c:7188
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded"
 msgstr "変数追跡サイズ制限が超過しました"
 
-#: varasm.c:326
+#: varasm.c:337
 #, fuzzy, gcc-internal-format
 #| msgid "%+D causes a section type conflict"
 msgid "%+qD causes a section type conflict with %qD"
 msgstr "%+D によりセクション型が競合します"
 
-#: varasm.c:329
+#: varasm.c:340
 #, fuzzy, gcc-internal-format
 #| msgid "%+D causes a section type conflict"
 msgid "section type conflict with %qD"
 msgstr "%+D によりセクション型が競合します"
 
-#: varasm.c:334
+#: varasm.c:345
 #, fuzzy, gcc-internal-format
 #| msgid "%+D causes a section type conflict"
 msgid "%+qD causes a section type conflict"
 msgstr "%+D によりセクション型が競合します"
 
-#: varasm.c:336
+#: varasm.c:347
 #, fuzzy, gcc-internal-format
 #| msgid "%+D causes a section type conflict"
 msgid "section type conflict"
 msgstr "%+D によりセクション型が競合します"
 
-#: varasm.c:1019
+#: varasm.c:1030
 #, fuzzy, gcc-internal-format
 #| msgid "alignment of %q+D is greater than maximum object file alignment.  Using %d"
 msgid "alignment of %q+D is greater than maximum object file alignment %d"
 msgstr "%q+D の整列がオブジェクトファイルの整列の最大値より大きいです。%d を使用します"
 
-#: varasm.c:1172
+#: varasm.c:1183
 #, fuzzy, gcc-internal-format
 #| msgid "Put zero initialized data in the bss section"
 msgid "only zero initializers are allowed in section %qs"
 msgstr "0 で初期化されるデータを bss セクション内に配置する"
 
-#: varasm.c:1378 varasm.c:1387
+#: varasm.c:1389 varasm.c:1398
 #, gcc-internal-format
 msgid "register name not specified for %q+D"
 msgstr "レジスタ名が %q+D 用に指定されていません"
 
-#: varasm.c:1389
+#: varasm.c:1400
 #, gcc-internal-format
 msgid "invalid register name for %q+D"
 msgstr "無効な %q+D 用のレジスタ名です"
 
-#: varasm.c:1391
+#: varasm.c:1402
 #, gcc-internal-format
 msgid "data type of %q+D isn%'t suitable for a register"
 msgstr "%q+D のデータ型がレジスタに適合しません"
 
-#: varasm.c:1394
+#: varasm.c:1405
 #, fuzzy, gcc-internal-format
 #| msgid "register specified for %q+D isn%'t suitable for data type"
 msgid "the register specified for %q+D cannot be accessed by the current target"
 msgstr "%q+D 用に指定されたレジスタがデータ型に適合しません"
 
-#: varasm.c:1397
+#: varasm.c:1408
 #, fuzzy, gcc-internal-format
 #| msgid "register used for two global register variables"
 msgid "the register specified for %q+D is not general enough to be used as a register variable"
 msgstr "レジスタが二つの大域レジスタ変数として使われました"
 
-#: varasm.c:1400
+#: varasm.c:1411
 #, gcc-internal-format
 msgid "register specified for %q+D isn%'t suitable for data type"
 msgstr "%q+D 用に指定されたレジスタがデータ型に適合しません"
 
-#: varasm.c:1410
+#: varasm.c:1421
 #, gcc-internal-format
 msgid "global register variable has initial value"
 msgstr "大域レジスタ変数が初期値を持っています"
 
-#: varasm.c:1414
+#: varasm.c:1425
 #, gcc-internal-format
 msgid "optimization may eliminate reads and/or writes to register variables"
 msgstr "最適化によりレジスタ変数の読み込み/書き込みが削除されるかもしれません"
 
-#: varasm.c:1460
+#: varasm.c:1471
 #, gcc-internal-format
 msgid "register name given for non-register variable %q+D"
 msgstr "非レジスタ変数 %q+D 用にレジスタ名が与えられました"
 
-#: varasm.c:1870
+#: varasm.c:1881
 #, gcc-internal-format
 msgid "Patchable function entry > size"
 msgstr ""
 
-#: varasm.c:2069
+#: varasm.c:2080
 #, gcc-internal-format
 msgid "thread-local COMMON data not implemented"
 msgstr "スレッド局所 COMMON データは実装されていません"
 
-#: varasm.c:2102
+#: varasm.c:2113
 #, gcc-internal-format
 msgid "requested alignment for %q+D is greater than implemented alignment of %wu"
 msgstr "要求された %q+D 用の整列は実装されている整列 %wu より大きいです"
 
-#: varasm.c:2205 c/c-decl.c:5027 c/c-parser.c:1534
+#: varasm.c:2216 c/c-decl.c:5027 c/c-parser.c:1534
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t known"
 msgstr "%q+D の記憶域サイズが不明です"
 
-#: varasm.c:4910
+#: varasm.c:4921
 #, gcc-internal-format
 msgid "initializer for integer/fixed-point value is too complicated"
 msgstr "整数/固定小数用の初期化子が複雑すぎます"
 
-#: varasm.c:4915
+#: varasm.c:4926
 #, gcc-internal-format
 msgid "initializer for floating value is not a floating constant"
 msgstr "浮動小数点数の初期設定子の値が、浮動小数点定数ではありません"
 
-#: varasm.c:5227
+#: varasm.c:5238
 #, gcc-internal-format
 msgid "invalid initial value for member %qE"
 msgstr "メンバ %qE 用の無効な初期値です"
 
-#: varasm.c:5487
+#: varasm.c:5498
 #, fuzzy, gcc-internal-format
 msgid "%+qD declared weak after being used"
 msgstr "領域 `%s' は関数として宣言されています"
 
-#: varasm.c:5539
+#: varasm.c:5550
 #, fuzzy, gcc-internal-format
 #| msgid "weak declaration of %q+D must precede definition"
 msgid "weak declaration of %q+D being applied to a already existing, static definition"
 msgstr "%q+D の弱い (weak) 宣言は定義の前に無ければ行けません"
 
-#: varasm.c:5575
+#: varasm.c:5586
 #, gcc-internal-format
 msgid "weak declaration of %q+D must be public"
 msgstr "%q+D の弱い (weak) 宣言は公開 (public) でなければいけません"
 
-#: varasm.c:5579
+#: varasm.c:5590
 #, gcc-internal-format
 msgid "weak declaration of %q+D not supported"
 msgstr "%q+D の弱い (weak) 宣言はサポートされていません"
 
-#: varasm.c:5608 varasm.c:5912
+#: varasm.c:5619 varasm.c:5926
 #, gcc-internal-format
 msgid "only weak aliases are supported in this configuration"
 msgstr "弱い別名のみこの設定ではサポートされています"
 
-#: varasm.c:5802
+#: varasm.c:5813
 #, gcc-internal-format
 msgid "weakref is not supported in this configuration"
 msgstr "弱い参照はこの設定ではサポートされていません"
 
-#: varasm.c:5834
+#: varasm.c:5846
 #, fuzzy, gcc-internal-format
 #| msgid "nested functions not supported on this target"
 msgid "ifunc is not supported on this target"
 msgstr "入れ子になった関数はこのターゲットではサポートされていません"
 
-#: varasm.c:5892
+#: varasm.c:5904
 #, gcc-internal-format
 msgid "weakref %q+D ultimately targets itself"
 msgstr ""
 
-#: varasm.c:5894
+#: varasm.c:5906
 #, gcc-internal-format
 msgid "weakref %q+D must have static linkage"
 msgstr "弱い参照 %q+D は静的リンクされなければいけません"
 
-#: varasm.c:5901
+#: varasm.c:5913
 #, gcc-internal-format
 msgid "alias definitions not supported in this configuration"
 msgstr "この設定では別名定義はサポートされていません"
 
-#: varasm.c:5909
+#: varasm.c:5923
 #, gcc-internal-format
 msgid "ifunc is not supported in this configuration"
 msgstr "ifunc はこの設定ではサポートされていません"
 
-#: varasm.c:6127 config/sol2.c:159 config/i386/winnt.c:265
+#: varasm.c:6141 config/sol2.c:159 config/i386/winnt.c:265
 #, gcc-internal-format
 msgid "visibility attribute not supported in this configuration; ignored"
 msgstr "可視性属性はこの設定ではサポートされていません。無視されました"
@@ -27553,486 +27575,492 @@
 msgid "bytecode stream: tag %s is not in the expected range [%s, %s]"
 msgstr ""
 
-#: c-family/c-attribs.c:529
+#: c-family/c-attribs.c:524
+#, fuzzy, gcc-internal-format
+#| msgid "%qE attribute ignored for %qE"
+msgid "%qE attribute ignored for type %qT"
+msgstr "%qE 属性は %qE 用としては無視されます"
+
+#: c-family/c-attribs.c:536
 #, gcc-internal-format
 msgid "%qE attribute ignored for field of type %qT"
 msgstr "%qE 属性は %qT 型のフィールド用としては無視されます"
 
-#: c-family/c-attribs.c:696
+#: c-family/c-attribs.c:706
 #, fuzzy, gcc-internal-format
 #| msgid "visibility argument not a string"
 msgid "no_sanitize argument not a string"
 msgstr "可視性の引数が文字列ではありません"
 
-#: c-family/c-attribs.c:826 ada/gcc-interface/utils.c:6235
+#: c-family/c-attribs.c:837 ada/gcc-interface/utils.c:6240
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "%qE attribute ignored due to conflict with attribute %qs"
 msgstr "%qE 属性は %s 属性と競合します"
 
-#: c-family/c-attribs.c:875
+#: c-family/c-attribs.c:886
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute ignored. Use -fcf-protection option to enable it"
 msgstr "%qE 属性は非クラス型に関しては無視されます"
 
-#: c-family/c-attribs.c:914 c-family/c-attribs.c:920 c-family/c-attribs.c:3388
-#: c-family/c-attribs.c:3423 c-family/c-attribs.c:3429
+#: c-family/c-attribs.c:925 c-family/c-attribs.c:931 c-family/c-attribs.c:3399
+#: c-family/c-attribs.c:3434 c-family/c-attribs.c:3440
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "%qE attribute ignored due to conflict with %qs attribute"
 msgstr "%qE 属性は %s 属性と競合します"
 
-#: c-family/c-attribs.c:976 brig/brig-lang.c:482 lto/lto-lang.c:288
+#: c-family/c-attribs.c:987 brig/brig-lang.c:482 lto/lto-lang.c:288
 #, gcc-internal-format
 msgid "%qE attribute has no effect on unit local functions"
 msgstr "%qE 属性はユニット局所関数に関しては効果がありません"
 
-#: c-family/c-attribs.c:1130
+#: c-family/c-attribs.c:1141
 #, gcc-internal-format
 msgid "%qE attribute have effect only on public objects"
 msgstr "%qE 属性は公開オブジェクトに関してのみ効果があります"
 
-#: c-family/c-attribs.c:1159
+#: c-family/c-attribs.c:1170
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to variables"
 msgid "%qE attribute only affects top level objects"
 msgstr "%qE は変数にのみ適用できます"
 
-#: c-family/c-attribs.c:1198 c-family/c-attribs.c:2682
+#: c-family/c-attribs.c:1209 c-family/c-attribs.c:2693
 #, fuzzy, gcc-internal-format
 #| msgid "using result of function returning %<void%>"
 msgid "%qE attribute on function returning %<void%>"
 msgstr "%<void%> を返す関数の結果を使用しています"
 
-#: c-family/c-attribs.c:1221 c-family/c-pragma.c:419
+#: c-family/c-attribs.c:1232 c-family/c-pragma.c:419
 #, gcc-internal-format
 msgid "scalar_storage_order is not supported because endianness is not uniform"
 msgstr ""
 
-#: c-family/c-attribs.c:1238
+#: c-family/c-attribs.c:1249
 #, gcc-internal-format
 msgid "scalar_storage_order argument must be one of \"big-endian\" or \"little-endian\""
 msgstr ""
 
-#: c-family/c-attribs.c:1334
+#: c-family/c-attribs.c:1345
 #, gcc-internal-format
 msgid "destructor priorities are not supported"
 msgstr "デストラクタのプロパティはサポートされません"
 
-#: c-family/c-attribs.c:1336
+#: c-family/c-attribs.c:1347
 #, gcc-internal-format
 msgid "constructor priorities are not supported"
 msgstr "コンストラクタのプロパティはサポートされません"
 
-#: c-family/c-attribs.c:1358
+#: c-family/c-attribs.c:1369
 #, gcc-internal-format, gfc-internal-format
 msgid "destructor priorities from 0 to %d are reserved for the implementation"
 msgstr "0 から %d までのデストラクタの優先度は実装によって予約されています"
 
-#: c-family/c-attribs.c:1363
+#: c-family/c-attribs.c:1374
 #, gcc-internal-format, gfc-internal-format
 msgid "constructor priorities from 0 to %d are reserved for the implementation"
 msgstr "0 から %d までのコンストラクタの優先度は実装によって予約されています"
 
-#: c-family/c-attribs.c:1371
+#: c-family/c-attribs.c:1382
 #, gcc-internal-format, gfc-internal-format
 msgid "destructor priorities must be integers from 0 to %d inclusive"
 msgstr "デストラクタの優先度は 0 から %d までに含まれる整数でなければいけません"
 
-#: c-family/c-attribs.c:1374
+#: c-family/c-attribs.c:1385
 #, gcc-internal-format, gfc-internal-format
 msgid "constructor priorities must be integers from 0 to %d inclusive"
 msgstr "コンストラクタの優先度は 0 から %d までに含まれる整数でなければいけません"
 
-#: c-family/c-attribs.c:1527
+#: c-family/c-attribs.c:1538
 #, gcc-internal-format
 msgid "unknown machine mode %qE"
 msgstr "不明なマシンモード %qE です"
 
-#: c-family/c-attribs.c:1557
+#: c-family/c-attribs.c:1568
 #, gcc-internal-format
 msgid "specifying vector types with __attribute__ ((mode)) is deprecated"
 msgstr "ベクトル型を __attribute__ ((mode)) で指定することは廃止されています"
 
-#: c-family/c-attribs.c:1560
+#: c-family/c-attribs.c:1571
 #, gcc-internal-format
 msgid "use __attribute__ ((vector_size)) instead"
 msgstr "代わりに __attribute__ ((vector_size)) を使用してください"
 
-#: c-family/c-attribs.c:1569
+#: c-family/c-attribs.c:1580
 #, gcc-internal-format
 msgid "unable to emulate %qs"
 msgstr "%qs をエミュレートできません"
 
-#: c-family/c-attribs.c:1582
+#: c-family/c-attribs.c:1593
 #, gcc-internal-format
 msgid "invalid pointer mode %qs"
 msgstr "無効なポインタモード %qs です"
 
-#: c-family/c-attribs.c:1599
+#: c-family/c-attribs.c:1610
 #, gcc-internal-format
 msgid "signedness of type and machine mode %qs don%'t match"
 msgstr "型の符号とマシンモード %qs が適合しません"
 
-#: c-family/c-attribs.c:1610
+#: c-family/c-attribs.c:1621
 #, gcc-internal-format
 msgid "no data type for mode %qs"
 msgstr "モード %qs 用のデータ型がありません"
 
-#: c-family/c-attribs.c:1620
+#: c-family/c-attribs.c:1631
 #, gcc-internal-format
 msgid "cannot use mode %qs for enumeral types"
 msgstr "モード %qs を列挙型用に使用できません"
 
-#: c-family/c-attribs.c:1647
+#: c-family/c-attribs.c:1658
 #, gcc-internal-format
 msgid "mode %qs applied to inappropriate type"
 msgstr "モード %qs が適切でない型に適用されています"
 
-#: c-family/c-attribs.c:1669
+#: c-family/c-attribs.c:1680
 #, gcc-internal-format
 msgid "section attributes are not supported for this target"
 msgstr "セクション属性はこのターゲットでは実装されていません"
 
-#: c-family/c-attribs.c:1675
+#: c-family/c-attribs.c:1686
 #, gcc-internal-format
 msgid "section attribute not allowed for %q+D"
 msgstr "セクション属性は %q+D 用には許可されていません"
 
-#: c-family/c-attribs.c:1681
+#: c-family/c-attribs.c:1692
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute argument not a string constant"
 msgid "section attribute argument not a string constant"
 msgstr "%qE 属性の引数が文字列定数ではありません"
 
-#: c-family/c-attribs.c:1690
+#: c-family/c-attribs.c:1701
 #, gcc-internal-format
 msgid "section attribute cannot be specified for local variables"
 msgstr "section 属性は局所変数用には指定できません"
 
-#: c-family/c-attribs.c:1700 config/bfin/bfin.c:4806 config/bfin/bfin.c:4857
+#: c-family/c-attribs.c:1711 config/bfin/bfin.c:4806 config/bfin/bfin.c:4857
 #: config/bfin/bfin.c:4883 config/bfin/bfin.c:4896
 #, gcc-internal-format
 msgid "section of %q+D conflicts with previous declaration"
 msgstr "%q+D のセクションが前の宣言と競合しています"
 
-#: c-family/c-attribs.c:1708
+#: c-family/c-attribs.c:1719
 #, gcc-internal-format
 msgid "section of %q+D cannot be overridden"
 msgstr "%q+D のセクションは上書きできません"
 
-#: c-family/c-attribs.c:1773
+#: c-family/c-attribs.c:1784
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "requested alignment is too large"
 msgid "requested alignment %d is larger than %d"
 msgstr "要求された整列が大きすぎます"
 
-#: c-family/c-attribs.c:1866
+#: c-family/c-attribs.c:1877
 #, gcc-internal-format
 msgid "alignment may not be specified for %q+D"
 msgstr "%q+D 用の整列が指定されていないようです"
 
-#: c-family/c-attribs.c:1886
+#: c-family/c-attribs.c:1897
 #, fuzzy, gcc-internal-format
 msgid "ignoring attribute %<%E (%u)%> because it conflicts with attribute %<%E (%u)%>"
 msgstr "データ領域 '%s' は前の宣言と矛盾します"
 
 #. Do not error out for attribute warn_if_not_aligned.
-#: c-family/c-attribs.c:1891 c-family/c-attribs.c:1920
+#: c-family/c-attribs.c:1902 c-family/c-attribs.c:1931
 #, gcc-internal-format
 msgid "alignment for %q+D must be at least %d"
 msgstr "%q+D 用の整列は最低 %d でなければいけません"
 
-#: c-family/c-attribs.c:1916
+#: c-family/c-attribs.c:1927
 #, gcc-internal-format
 msgid "alignment for %q+D was previously specified as %d and may not be decreased"
 msgstr "%q+D 用の整列は前に %d として指定されていて、減らすことは出来ません"
 
-#: c-family/c-attribs.c:1943
+#: c-family/c-attribs.c:1954
 #, fuzzy, gcc-internal-format
 #| msgid "alignment may not be specified for %q+D"
 msgid "%<warn_if_not_aligned%> may not be specified for %q+D"
 msgstr "%q+D 用の整列が指定されていないようです"
 
-#: c-family/c-attribs.c:1986
+#: c-family/c-attribs.c:1997
 #, fuzzy, gcc-internal-format
 msgid "inline function %q+D declared weak"
 msgstr "インライン関数 %q+D を弱いとして宣言できません"
 
-#: c-family/c-attribs.c:1991
+#: c-family/c-attribs.c:2002
 #, gcc-internal-format
 msgid "indirect function %q+D cannot be declared weak"
 msgstr "間接関数 %q+D を弱いとして宣言できません"
 
-#: c-family/c-attribs.c:2015
+#: c-family/c-attribs.c:2026
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to functions"
 msgid "%qE attribute is only applicable on functions"
 msgstr "%qE 属性は関数へのみ適用されます"
 
-#: c-family/c-attribs.c:2046
+#: c-family/c-attribs.c:2057
 #, gcc-internal-format
 msgid "%q+D defined both normally and as %qE attribute"
 msgstr "%q+D が通常と %qE 属性との両方で定義されています"
 
-#: c-family/c-attribs.c:2054
+#: c-family/c-attribs.c:2065
 #, gcc-internal-format
 msgid "weak %q+D cannot be defined %qE"
 msgstr "弱い %q+D は %qE として定義できません"
 
-#: c-family/c-attribs.c:2071 c-family/c-attribs.c:2582
+#: c-family/c-attribs.c:2082 c-family/c-attribs.c:2593
 #, gcc-internal-format
 msgid "attribute %qE argument not a string"
 msgstr "属性 %qE の引数が文字列ではありません"
 
-#: c-family/c-attribs.c:2106
+#: c-family/c-attribs.c:2117
 #, fuzzy, gcc-internal-format
 msgid "%+qD declared alias after being used"
 msgstr "領域 `%s' は関数として宣言されています"
 
-#: c-family/c-attribs.c:2108
+#: c-family/c-attribs.c:2119
 #, fuzzy, gcc-internal-format
 msgid "%+qD declared ifunc after being used"
 msgstr "領域 `%s' は関数として宣言されています"
 
-#: c-family/c-attribs.c:2159
+#: c-family/c-attribs.c:2170
 #, gcc-internal-format
 msgid "indirect function %q+D cannot be declared weakref"
 msgstr "間接関数 %q+D は弱い参照として宣言できません"
 
-#: c-family/c-attribs.c:2181
+#: c-family/c-attribs.c:2192
 #, gcc-internal-format
 msgid "weakref attribute must appear before alias attribute"
 msgstr "弱い参照属性は別名属性より前に出現しなければいけません"
 
-#: c-family/c-attribs.c:2193
+#: c-family/c-attribs.c:2204
 #, fuzzy, gcc-internal-format
 #| msgid "%qE declared %<threadprivate%> after first use"
 msgid "%+qD declared weakref after being used"
 msgstr "%qE は最初に使用した後に %<threadprivate%> と宣言されています"
 
-#: c-family/c-attribs.c:2217
+#: c-family/c-attribs.c:2228
 #, gcc-internal-format
 msgid "%qE attribute ignored on non-class types"
 msgstr "%qE 属性は非クラス型に関しては無視されます"
 
-#: c-family/c-attribs.c:2223
+#: c-family/c-attribs.c:2234
 #, gcc-internal-format
 msgid "%qE attribute ignored because %qT is already defined"
 msgstr "%qE 属性は %qT が既に定義されているため無視されます"
 
-#: c-family/c-attribs.c:2236
+#: c-family/c-attribs.c:2247
 #, gcc-internal-format
 msgid "visibility argument not a string"
 msgstr "可視性の引数が文字列ではありません"
 
-#: c-family/c-attribs.c:2248
+#: c-family/c-attribs.c:2259
 #, gcc-internal-format
 msgid "%qE attribute ignored on types"
 msgstr "%qE 属性は型に関しては無視されます"
 
-#: c-family/c-attribs.c:2264
+#: c-family/c-attribs.c:2275
 #, gcc-internal-format
 msgid "visibility argument must be one of \"default\", \"hidden\", \"protected\" or \"internal\""
 msgstr "可視性の引数は \"default\"、\"hidden\"、\"protected\" または \"internal\" のうち一つでなければいけません"
 
-#: c-family/c-attribs.c:2275
+#: c-family/c-attribs.c:2286
 #, gcc-internal-format
 msgid "%qD redeclared with different visibility"
 msgstr "%qD が別の可視性で再宣言されました"
 
-#: c-family/c-attribs.c:2278 c-family/c-attribs.c:2282
+#: c-family/c-attribs.c:2289 c-family/c-attribs.c:2293
 #, gcc-internal-format
 msgid "%qD was declared %qs which implies default visibility"
 msgstr "%qD は %qs として宣言されていて、暗黙的にデフォルトの可視性になります"
 
-#: c-family/c-attribs.c:2320
+#: c-family/c-attribs.c:2331
 #, gcc-internal-format
 msgid "tls_model argument not a string"
 msgstr "tls_model の引数が文字列ではありません"
 
-#: c-family/c-attribs.c:2333
+#: c-family/c-attribs.c:2344
 #, gcc-internal-format
 msgid "tls_model argument must be one of \"local-exec\", \"initial-exec\", \"local-dynamic\" or \"global-dynamic\""
 msgstr "tls_model の引数は \"local-exec\"、\"initial-exec\"、\"local-dynamic\" または \"global-dynamic\" のうちの一つでなければいけません"
 
-#: c-family/c-attribs.c:2353 c-family/c-attribs.c:2656
-#: c-family/c-attribs.c:3497 config/m32c/m32c.c:2944
+#: c-family/c-attribs.c:2364 c-family/c-attribs.c:2667
+#: c-family/c-attribs.c:3508 config/m32c/m32c.c:2944
 #, gcc-internal-format
 msgid "%qE attribute applies only to functions"
 msgstr "%qE 属性は関数にのみ適用できます"
 
-#: c-family/c-attribs.c:2417
+#: c-family/c-attribs.c:2428
 #, gcc-internal-format
 msgid "alloc_size parameter outside range"
 msgstr "alloc_size パラメータが範囲外です"
 
-#: c-family/c-attribs.c:2443
+#: c-family/c-attribs.c:2454
 #, fuzzy, gcc-internal-format
 #| msgid "alloc_size parameter outside range"
 msgid "alloc_align parameter outside range"
 msgstr "alloc_size パラメータが範囲外です"
 
-#: c-family/c-attribs.c:2467
+#: c-family/c-attribs.c:2478
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute argument not an integer constant"
 msgid "assume_aligned parameter not integer constant"
 msgstr "%qE 属性の引数が整数定数ではありません"
 
-#: c-family/c-attribs.c:2595
+#: c-family/c-attribs.c:2606
 #, gcc-internal-format
 msgid "only %<inbranch%> and %<notinbranch%> flags are allowed for %<__simd__%> attribute"
 msgstr ""
 
-#: c-family/c-attribs.c:2662 c-family/c-attribs.c:3503
+#: c-family/c-attribs.c:2673 c-family/c-attribs.c:3514
 #, gcc-internal-format
 msgid "can%'t set %qE attribute after definition"
 msgstr "定義の後に %qE 属性を設定できません"
 
-#: c-family/c-attribs.c:2727
+#: c-family/c-attribs.c:2738
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored"
 msgid "%qE attribute duplicated"
 msgstr "%qE 属性は無視されました"
 
-#: c-family/c-attribs.c:2729
+#: c-family/c-attribs.c:2740
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored for %qE"
 msgid "%qE attribute follows %qE"
 msgstr "%qE 属性は %qE 用としては無視されます"
 
-#: c-family/c-attribs.c:2828
+#: c-family/c-attribs.c:2839
 #, fuzzy, gcc-internal-format
 #| msgid "previously declared here"
 msgid "type was previously declared %qE"
 msgstr "前はここで宣言されました"
 
-#: c-family/c-attribs.c:2841 cp/class.c:4397
+#: c-family/c-attribs.c:2852 cp/class.c:4401
 #, fuzzy, gcc-internal-format
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
 msgstr "非関数 `%s' の引数に format 属性が指定されました"
 
-#: c-family/c-attribs.c:2899
+#: c-family/c-attribs.c:2910
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute argument not an integer constant"
 msgid "%qE argument not an identifier"
 msgstr "%qE 属性の引数が整数定数ではありません"
 
-#: c-family/c-attribs.c:2910
+#: c-family/c-attribs.c:2921
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not declared in %qD"
 msgid "%qD is not compatible with %qD"
 msgstr "%qD は %qD 内では宣言されていません"
 
-#: c-family/c-attribs.c:2913
+#: c-family/c-attribs.c:2924
 #, fuzzy, gcc-internal-format
 msgid "%qE argument is not a function"
 msgstr "呼び出されたオブジェクトは関数ではありません"
 
-#: c-family/c-attribs.c:2961
+#: c-family/c-attribs.c:2972
 #, gcc-internal-format
 msgid "deprecated message is not a string"
 msgstr "廃止された (deprecated) メッセージが文字列ではありません"
 
-#: c-family/c-attribs.c:3002
+#: c-family/c-attribs.c:3013
 #, gcc-internal-format
 msgid "%qE attribute ignored for %qE"
 msgstr "%qE 属性は %qE 用としては無視されます"
 
-#: c-family/c-attribs.c:3065
+#: c-family/c-attribs.c:3076
 #, gcc-internal-format
 msgid "invalid vector type for attribute %qE"
 msgstr "%qE 属性用としては無効なベクトル型です"
 
-#: c-family/c-attribs.c:3071 ada/gcc-interface/utils.c:3896
+#: c-family/c-attribs.c:3082 ada/gcc-interface/utils.c:3899
 #, gcc-internal-format
 msgid "vector size not an integral multiple of component size"
 msgstr "ベクトルのサイズが要素のサイズの整数倍ではありません"
 
-#: c-family/c-attribs.c:3077 ada/gcc-interface/utils.c:3903
+#: c-family/c-attribs.c:3088 ada/gcc-interface/utils.c:3906
 #, gcc-internal-format
 msgid "zero vector size"
 msgstr "ベクトルのサイズが 0 です"
 
-#: c-family/c-attribs.c:3085
+#: c-family/c-attribs.c:3096
 #, gcc-internal-format
 msgid "number of components of the vector not a power of two"
 msgstr "ベクトルの要素の数が 2 の累乗ではありません"
 
-#: c-family/c-attribs.c:3118 ada/gcc-interface/utils.c:6092
+#: c-family/c-attribs.c:3129 ada/gcc-interface/utils.c:6098
 #, gcc-internal-format
 msgid "nonnull attribute without arguments on a non-prototype"
 msgstr ""
 
-#: c-family/c-attribs.c:3137 ada/gcc-interface/utils.c:6106
+#: c-family/c-attribs.c:3148 ada/gcc-interface/utils.c:6112
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument has invalid operand number (argument %lu)"
 msgstr ""
 
-#: c-family/c-attribs.c:3159 ada/gcc-interface/utils.c:6128
+#: c-family/c-attribs.c:3170 ada/gcc-interface/utils.c:6134
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument with out-of-range operand number (argument %lu, operand %lu)"
 msgstr ""
 
-#: c-family/c-attribs.c:3168 ada/gcc-interface/utils.c:6137
+#: c-family/c-attribs.c:3179 ada/gcc-interface/utils.c:6143
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument references non-pointer operand (argument %lu, operand %lu)"
 msgstr ""
 
-#: c-family/c-attribs.c:3208
+#: c-family/c-attribs.c:3219
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored for field of type %qT"
 msgid "%qE attribute ignored on objects of type %qT"
 msgstr "%qE 属性は %qT 型のフィールド用としては無視されます"
 
-#: c-family/c-attribs.c:3216
+#: c-family/c-attribs.c:3227
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute does not apply to types"
 msgid "%qE attribute does not apply to functions"
 msgstr "%qE 属性は型に適用できません"
 
-#: c-family/c-attribs.c:3273
+#: c-family/c-attribs.c:3284
 #, gcc-internal-format
 msgid "cleanup argument not an identifier"
 msgstr ""
 
-#: c-family/c-attribs.c:3280
+#: c-family/c-attribs.c:3291
 #, gcc-internal-format
 msgid "cleanup argument not a function"
 msgstr ""
 
-#: c-family/c-attribs.c:3317
+#: c-family/c-attribs.c:3328
 #, gcc-internal-format
 msgid "%qE attribute requires prototypes with named arguments"
 msgstr "%qE 属性は名前付き引数があるプロトタイプが必要です"
 
-#: c-family/c-attribs.c:3325
+#: c-family/c-attribs.c:3336
 #, gcc-internal-format
 msgid "%qE attribute only applies to variadic functions"
 msgstr ""
 
-#: c-family/c-attribs.c:3341 ada/gcc-interface/utils.c:6179
+#: c-family/c-attribs.c:3352 ada/gcc-interface/utils.c:6185
 #, gcc-internal-format
 msgid "requested position is not an integer constant"
 msgstr ""
 
-#: c-family/c-attribs.c:3349 ada/gcc-interface/utils.c:6186
+#: c-family/c-attribs.c:3360 ada/gcc-interface/utils.c:6192
 #, gcc-internal-format
 msgid "requested position is less than zero"
 msgstr ""
 
-#: c-family/c-attribs.c:3404
+#: c-family/c-attribs.c:3415
 #, gcc-internal-format
 msgid "empty string in attribute %<target%>"
 msgstr ""
 
-#: c-family/c-attribs.c:3520
+#: c-family/c-attribs.c:3531
 #, fuzzy, gcc-internal-format
 msgid "returns_nonnull attribute on a function not returning a pointer"
 msgstr "戻り型が void の関数で、`return' に値があります"
 
-#: c-family/c-attribs.c:3535
+#: c-family/c-attribs.c:3546
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to function types"
 msgid "%qE attribute is only valid on %<struct%> type"
@@ -28080,13 +28108,13 @@
 msgid "__builtin_shuffle argument vector(s) inner type must have the same size as inner type of the mask"
 msgstr ""
 
-#: c-family/c-common.c:1262 c-family/c-warn.c:1194
+#: c-family/c-common.c:1262 c-family/c-warn.c:1202
 #, fuzzy, gcc-internal-format
 #| msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgid "unsigned conversion from %qT to %qT changes value from %qE to %qE"
 msgstr "関数へ引数を渡すときに %qT から %qT へ暗黙的に変換されます"
 
-#: c-family/c-common.c:1267 c-family/c-warn.c:1202
+#: c-family/c-common.c:1267 c-family/c-warn.c:1210
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "unsigned conversion from %qT to %qT changes the value of %qE"
@@ -28221,7 +28249,7 @@
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "真偽値として使われる代入のまわりでは、丸括弧の使用をお勧めします"
 
-#: c-family/c-common.c:3518 c/c-decl.c:4325 c/c-decl.c:6430 c/c-typeck.c:14177
+#: c-family/c-common.c:3518 c/c-decl.c:4325 c/c-decl.c:6450 c/c-typeck.c:14182
 #, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr "%<restrict%> の誤った使用法です"
@@ -28303,7 +28331,7 @@
 msgid "duplicate case value"
 msgstr "重複した case の値です"
 
-#: c-family/c-common.c:4867 c-family/c-warn.c:2216
+#: c-family/c-common.c:4867 c-family/c-warn.c:2225
 #, gcc-internal-format
 msgid "previously used here"
 msgstr "前にここで使われました"
@@ -28350,210 +28378,210 @@
 msgid "missing sentinel in function call"
 msgstr ""
 
-#: c-family/c-common.c:5411
+#: c-family/c-common.c:5409
 #, gcc-internal-format, gfc-internal-format
 msgid "null argument where non-null required (argument %lu)"
 msgstr ""
 
-#: c-family/c-common.c:5506 c-family/c-common.c:5553
+#: c-family/c-common.c:5504 c-family/c-common.c:5551
 #, fuzzy, gcc-internal-format
 #| msgid "bad option %s to pragma attribute"
 msgid "bad option %qs to attribute %<optimize%>"
 msgstr "pragma 属性への間違ったオプション %s です"
 
-#: c-family/c-common.c:5509 c-family/c-common.c:5557
+#: c-family/c-common.c:5507 c-family/c-common.c:5555
 #, fuzzy, gcc-internal-format
 #| msgid "bad option %s to pragma attribute"
 msgid "bad option %qs to pragma %<optimize%>"
 msgstr "pragma 属性への間違ったオプション %s です"
 
-#: c-family/c-common.c:5589
+#: c-family/c-common.c:5587
 #, gcc-internal-format
 msgid "%<fallthrough%> attribute specified multiple times"
 msgstr ""
 
-#: c-family/c-common.c:5593
+#: c-family/c-common.c:5591
 #, fuzzy, gcc-internal-format
 msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr "仮引数 `%s' で指定された記憶クラス"
 
-#: c-family/c-common.c:5733 c-family/c-common.c:6485 c-family/c-common.c:6558
+#: c-family/c-common.c:5731 c-family/c-common.c:6477 c-family/c-common.c:6550
 #: c/c-typeck.c:3555
 #, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr "関数 %qE へ渡す引数が少なすぎます"
 
-#: c-family/c-common.c:5738 c-family/c-common.c:6584 c/c-typeck.c:3284
+#: c-family/c-common.c:5736 c-family/c-common.c:6576 c/c-typeck.c:3284
 #, gcc-internal-format
 msgid "too many arguments to function %qE"
 msgstr "関数 %qE への引数が多すぎます"
 
-#: c-family/c-common.c:5769
+#: c-family/c-common.c:5767
 #, fuzzy, gcc-internal-format
 #| msgid "third argument to %<__builtin_prefetch%> must be a constant"
 msgid "third argument to function %qE must be a constant integer"
 msgstr "%<__builtin_prefetch%> への第三引数は定数でなければいけません"
 
-#: c-family/c-common.c:5794
+#: c-family/c-common.c:5792
 #, gcc-internal-format
 msgid "second argument to function %qE must be a constant integer power of 2 between %qi and %qu bits"
 msgstr ""
 
-#: c-family/c-common.c:5815 c-family/c-common.c:5859
+#: c-family/c-common.c:5813 c-family/c-common.c:5857
 #, gcc-internal-format
 msgid "non-floating-point argument in call to function %qE"
 msgstr "関数 %qE の呼び出し内に非浮動小数点引数があります"
 
-#: c-family/c-common.c:5838
+#: c-family/c-common.c:5836
 #, gcc-internal-format
 msgid "non-floating-point arguments in call to function %qE"
 msgstr "関数 %qE の呼び出し内に非浮動小数点引数があります"
 
-#: c-family/c-common.c:5852
+#: c-family/c-common.c:5850
 #, gcc-internal-format
 msgid "non-const integer argument %u in call to function %qE"
 msgstr "%u 番目の引数が非定数整数の関数呼び出し %qE があります"
 
-#: c-family/c-common.c:5872
+#: c-family/c-common.c:5870
 #, fuzzy, gcc-internal-format
 #| msgid "non-const integer argument %u in call to function %qE"
 msgid "non-integer argument 3 in call to function %qE"
 msgstr "%u 番目の引数が非定数整数の関数呼び出し %qE があります"
 
-#: c-family/c-common.c:5889 c-family/c-common.c:5925
+#: c-family/c-common.c:5887 c-family/c-common.c:5923
 #, fuzzy, gcc-internal-format
 #| msgid "non-const integer argument %u in call to function %qE"
 msgid "argument %u in call to function %qE does not have integral type"
 msgstr "%u 番目の引数が非定数整数の関数呼び出し %qE があります"
 
-#: c-family/c-common.c:5896
+#: c-family/c-common.c:5894
 #, gcc-internal-format
 msgid "argument 3 in call to function %qE does not have pointer to integral type"
 msgstr ""
 
-#: c-family/c-common.c:5902
+#: c-family/c-common.c:5900
 #, fuzzy, gcc-internal-format
 msgid "argument 3 in call to function %qE has pointer to enumerated type"
 msgstr "不完全型への変換です"
 
-#: c-family/c-common.c:5908
+#: c-family/c-common.c:5906
 #, gcc-internal-format
 msgid "argument 3 in call to function %qE has pointer to boolean type"
 msgstr ""
 
-#: c-family/c-common.c:5931
+#: c-family/c-common.c:5929
 #, fuzzy, gcc-internal-format
 #| msgid "non-const integer argument %u in call to function %qE"
 msgid "argument 3 in call to function %qE has enumerated type"
 msgstr "%u 番目の引数が非定数整数の関数呼び出し %qE があります"
 
-#: c-family/c-common.c:5937
+#: c-family/c-common.c:5935
 #, fuzzy, gcc-internal-format
 #| msgid "non-const integer argument %u in call to function %qE"
 msgid "argument 3 in call to function %qE has boolean type"
 msgstr "%u 番目の引数が非定数整数の関数呼び出し %qE があります"
 
-#: c-family/c-common.c:6184
+#: c-family/c-common.c:6183
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to static data member %qD"
 msgstr "%<offsetof%> を静的データメンバ %qD へ適用できません"
 
-#: c-family/c-common.c:6189
+#: c-family/c-common.c:6188
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> when %<operator[]%> is overloaded"
 msgstr "%<offsetof%> は %<operator[]%> がオーバーロードされているときには適用できません"
 
-#: c-family/c-common.c:6196
+#: c-family/c-common.c:6195
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to a non constant address"
 msgstr "一定ではないアドレスへ %<offsetof%> を適用できません"
 
-#: c-family/c-common.c:6209
+#: c-family/c-common.c:6208
 #, gcc-internal-format
 msgid "attempt to take address of bit-field structure member %qD"
 msgstr "ビットフィールドである構造体のメンバ %qD のアドレスを取得しようとする試みです"
 
-#: c-family/c-common.c:6261
+#: c-family/c-common.c:6260
 #, gcc-internal-format
 msgid "index %E denotes an offset greater than size of %qT"
 msgstr ""
 
-#: c-family/c-common.c:6427 cp/init.c:3004 cp/init.c:3023
+#: c-family/c-common.c:6419 cp/init.c:3020 cp/init.c:3039
 #, gcc-internal-format
 msgid "size of array is too large"
 msgstr "配列のサイズが大きすぎます"
 
-#: c-family/c-common.c:6517
+#: c-family/c-common.c:6509
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible type for argument %d of %qE"
 msgid "operand type %qT is incompatible with argument %d of %qE"
 msgstr "%d 番目の %qE の引数用の互換性がない型です"
 
-#: c-family/c-common.c:6651
+#: c-family/c-common.c:6643
 #, fuzzy, gcc-internal-format
 #| msgid "not enough arguments to function %qE"
 msgid "incorrect number of arguments to function %qE"
 msgstr "関数 %qE へ十分な引数がありません"
 
-#: c-family/c-common.c:6665
+#: c-family/c-common.c:6657
 #, fuzzy, gcc-internal-format
 #| msgid "argument %d of %qE must be an address"
 msgid "argument 1 of %qE must be a non-void pointer type"
 msgstr "%d 番目の %qE の引数はアドレスでなければいけません"
 
-#: c-family/c-common.c:6674
+#: c-family/c-common.c:6666
 #, fuzzy, gcc-internal-format
 #| msgid "%Kfirst argument of %D must be a pointer, second integer constant"
 msgid "argument 1 of %qE must be a pointer to a constant size type"
 msgstr "%K %D の第一引数がポインタ、第二引数が整数定数でなければいけません"
 
-#: c-family/c-common.c:6685
+#: c-family/c-common.c:6677
 #, fuzzy, gcc-internal-format
 #| msgid "%Kfirst argument of %D must be a pointer, second integer constant"
 msgid "argument 1 of %qE must be a pointer to a nonzero size object"
 msgstr "%K %D の第一引数がポインタ、第二引数が整数定数でなければいけません"
 
-#: c-family/c-common.c:6706
+#: c-family/c-common.c:6698
 #, fuzzy, gcc-internal-format
 #| msgid "argument %d of %qE must be an address"
 msgid "argument %d of %qE must be a pointer type"
 msgstr "%d 番目の %qE の引数はアドレスでなければいけません"
 
-#: c-family/c-common.c:6714
+#: c-family/c-common.c:6706
 #, fuzzy, gcc-internal-format
 #| msgid "argument %d of %qE might be a candidate for a format attribute"
 msgid "argument %d of %qE must be a pointer to a constant size type"
 msgstr "%d 番目の %qE の引数は format 属性の候補のようです"
 
-#: c-family/c-common.c:6720
+#: c-family/c-common.c:6712
 #, fuzzy, gcc-internal-format
 #| msgid "argument %d of %qE must be a multiple of %d"
 msgid "argument %d of %qE must not be a pointer to a function"
 msgstr "%d 番目の %qE の引数は %d の倍数でなければいけません"
 
-#: c-family/c-common.c:6728
+#: c-family/c-common.c:6720
 #, fuzzy, gcc-internal-format
 msgid "size mismatch in argument %d of %qE"
 msgstr "引数 %d 個の `%s' を渡します"
 
-#: c-family/c-common.c:6740
+#: c-family/c-common.c:6732
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible type for argument %d of %qE"
 msgid "non-integer memory model argument %d of %qE"
 msgstr "%d 番目の %qE の引数用の互換性がない型です"
 
-#: c-family/c-common.c:6753
+#: c-family/c-common.c:6745
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible type for argument %d of %qE"
 msgid "invalid memory model argument %d of %qE"
 msgstr "%d 番目の %qE の引数用の互換性がない型です"
 
-#: c-family/c-common.c:7672
+#: c-family/c-common.c:7664
 #, gcc-internal-format
 msgid "index value is out of bound"
 msgstr ""
 
-#: c-family/c-common.c:7714 c-family/c-common.c:7763 c-family/c-common.c:7779
+#: c-family/c-common.c:7706 c-family/c-common.c:7755 c-family/c-common.c:7771
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "conversion of scalar %qT to vector %qT involves truncation"
@@ -28561,23 +28589,23 @@
 
 #. Reject arguments that are built-in functions with
 #. no library fallback.
-#: c-family/c-common.c:7867
+#: c-family/c-common.c:7859
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %qD takes one argument only"
 msgid "built-in function %qE must be directly called"
 msgstr "組み込み関数 %qD は単一の引数をとります"
 
-#: c-family/c-common.c:7889 c/c-decl.c:6177
+#: c-family/c-common.c:7881 c/c-decl.c:6197
 #, gcc-internal-format
 msgid "size of array %qE is too large"
 msgstr "配列 %qE のサイズが大きすぎます"
 
-#: c-family/c-common.c:7891 c/c-decl.c:6180
+#: c-family/c-common.c:7883 c/c-decl.c:6200
 #, gcc-internal-format
 msgid "size of unnamed array is too large"
 msgstr "無名配列のサイズが大きすぎます"
 
-#: c-family/c-common.c:7921
+#: c-family/c-common.c:7913
 #, gcc-internal-format
 msgid "environment variable SOURCE_DATE_EPOCH must expand to a non-negative integer less than or equal to %wd"
 msgstr ""
@@ -29110,7 +29138,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr ""
 
-#: c-family/c-omp.c:557 cp/semantics.c:8186
+#: c-family/c-omp.c:557 cp/semantics.c:8189
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr ""
@@ -29126,22 +29154,22 @@
 msgid "%qE is not initialized"
 msgstr "%qE は初期化されていません"
 
-#: c-family/c-omp.c:599 cp/semantics.c:8076
+#: c-family/c-omp.c:599 cp/semantics.c:8079
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.c:704 cp/semantics.c:7732
+#: c-family/c-omp.c:704 cp/semantics.c:7735
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.c:711 cp/semantics.c:8082
+#: c-family/c-omp.c:711 cp/semantics.c:8085
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "増分式がありません"
 
-#: c-family/c-omp.c:775 cp/semantics.c:7847
+#: c-family/c-omp.c:775 cp/semantics.c:7850
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "無効な増分式です"
@@ -29199,114 +29227,129 @@
 msgid "%<-Wabi=1%> is not supported, using =2"
 msgstr "このターゲットでは %<__int128%> はサポートされていません"
 
-#: c-family/c-opts.c:612 fortran/cpp.c:350
+#: c-family/c-opts.c:610 fortran/cpp.c:350
 #, gcc-internal-format
 msgid "output filename specified twice"
 msgstr "出力ファイル名が二回指定されています"
 
-#: c-family/c-opts.c:799
+#: c-family/c-opts.c:797
 #, gcc-internal-format
 msgid "-fexcess-precision=standard for C++"
 msgstr ""
 
-#: c-family/c-opts.c:834
+#: c-family/c-opts.c:832
 #, gcc-internal-format
 msgid "-fno-gnu89-inline is only supported in GNU99 or C99 mode"
 msgstr "-fno-gnu89-inline は GNU99 または C99 モードでのみサポートされます"
 
-#: c-family/c-opts.c:880
+#: c-family/c-opts.c:878
 #, gcc-internal-format
 msgid "-Wformat-y2k ignored without -Wformat"
 msgstr "-Wformat-y2k は無視されました (-Wformat がありません)"
 
-#: c-family/c-opts.c:882
+#: c-family/c-opts.c:880
 #, gcc-internal-format
 msgid "-Wformat-extra-args ignored without -Wformat"
 msgstr "-Wformat-extra-args は無視されました (-Wformat がありません)"
 
-#: c-family/c-opts.c:884
+#: c-family/c-opts.c:882
 #, gcc-internal-format
 msgid "-Wformat-zero-length ignored without -Wformat"
 msgstr "-Wformat-zero-length は無視されました (-Wformat がありません)"
 
-#: c-family/c-opts.c:886
+#: c-family/c-opts.c:884
 #, gcc-internal-format
 msgid "-Wformat-nonliteral ignored without -Wformat"
 msgstr "-Wformat-nonliteral は無視されました (-Wformat がありません)"
 
-#: c-family/c-opts.c:888
+#: c-family/c-opts.c:886
 #, gcc-internal-format
 msgid "-Wformat-contains-nul ignored without -Wformat"
 msgstr "-Wformat-contains-nul は無視されました (-Wformat がありません)"
 
-#: c-family/c-opts.c:890
+#: c-family/c-opts.c:888
 #, gcc-internal-format
 msgid "-Wformat-security ignored without -Wformat"
 msgstr "-Wformat-security は無視されました (-Wformat がありません)"
 
-#: c-family/c-opts.c:928
+#: c-family/c-opts.c:918
 #, fuzzy, gcc-internal-format
 #| msgid "-falign-loops=%d is not supported"
 msgid "%<-fabi-compat-version=1%> is not supported, using =2"
 msgstr "-falign-loops=%d はサポートされていません"
 
-#: c-family/c-opts.c:988
+#: c-family/c-opts.c:944
+#, gcc-internal-format
+msgid "-Wabi won't warn about anything"
+msgstr ""
+
+#: c-family/c-opts.c:946
+#, gcc-internal-format
+msgid "-Wabi warns about differences from the most up-to-date ABI, which is also used by default"
+msgstr ""
+
+#: c-family/c-opts.c:949
+#, gcc-internal-format
+msgid "use e.g. -Wabi=11 to warn about changes from GCC 7"
+msgstr ""
+
+#: c-family/c-opts.c:1003
 #, fuzzy, gcc-internal-format
 #| msgid "nested functions not supported on this target"
 msgid "external TLS initialization functions not supported on this target"
 msgstr "入れ子になった関数はこのターゲットではサポートされていません"
 
-#: c-family/c-opts.c:1001
+#: c-family/c-opts.c:1016
 #, gcc-internal-format, gfc-internal-format
 msgid "too many filenames given.  Type %s --help for usage"
 msgstr "与えられたファイル名が多すぎます。使用法に関しては %s --help を参照してください"
 
-#: c-family/c-opts.c:1016
+#: c-family/c-opts.c:1031
 #, gcc-internal-format
 msgid "opening output file %s: %m"
 msgstr "出力ファイル %s を開いています: %m"
 
-#: c-family/c-opts.c:1036
+#: c-family/c-opts.c:1051
 #, gcc-internal-format, gfc-internal-format
 msgid "the \"%s\" debug format cannot be used with pre-compiled headers"
 msgstr ""
 
-#: c-family/c-opts.c:1190
+#: c-family/c-opts.c:1205
 #, gcc-internal-format
 msgid "opening dependency file %s: %m"
 msgstr "依存関係ファイル %s を開いています: %m"
 
-#: c-family/c-opts.c:1201
+#: c-family/c-opts.c:1216
 #, gcc-internal-format
 msgid "closing dependency file %s: %m"
 msgstr "依存関係ファイル %s を開いています: %m"
 
-#: c-family/c-opts.c:1204
+#: c-family/c-opts.c:1219
 #, gcc-internal-format
 msgid "when writing output to %s: %m"
 msgstr "出力を %s へ書き込み中です: %m"
 
-#: c-family/c-opts.c:1284
+#: c-family/c-opts.c:1299
 #, gcc-internal-format
 msgid "to generate dependencies you must specify either -M or -MM"
 msgstr "依存関係を生成するためには -M または -MM のいずれかを指定しなければいけません"
 
-#: c-family/c-opts.c:1307
+#: c-family/c-opts.c:1322
 #, gcc-internal-format
 msgid "-MG may only be used with -M or -MM"
 msgstr "-MG は -M または -MM と併せてのみ使用できます"
 
-#: c-family/c-opts.c:1340
+#: c-family/c-opts.c:1355
 #, gcc-internal-format
 msgid "-fdirectives-only is incompatible with -Wunused_macros"
 msgstr "-fdirectives-only は -Wunused_macros と併用できません"
 
-#: c-family/c-opts.c:1342
+#: c-family/c-opts.c:1357
 #, gcc-internal-format
 msgid "-fdirectives-only is incompatible with -traditional"
 msgstr "-fdirectives-only は -traditional と併用できません"
 
-#: c-family/c-opts.c:1534
+#: c-family/c-opts.c:1549
 #, gcc-internal-format
 msgid "too late for # directive to set debug directory"
 msgstr "デバッグディレクトリを設定する # 指示が遅すぎます"
@@ -29696,754 +29739,754 @@
 msgid "wrong type argument to %s"
 msgstr "%s への間違った型の引数です"
 
-#: c-family/c-warn.c:53 c-family/c-warn.c:66 cp/constexpr.c:1847
+#: c-family/c-warn.c:54 c-family/c-warn.c:67 cp/constexpr.c:1847
 #: cp/constexpr.c:4099
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "定数式内でオーバーフローしました"
 
-#: c-family/c-warn.c:93
+#: c-family/c-warn.c:94
 #, fuzzy, gcc-internal-format
 #| msgid "integer overflow in expression"
 msgid "integer overflow in expression %qE of type %qT results in %qE"
 msgstr "式内で整数がオーバーフローしました"
 
-#: c-family/c-warn.c:95
+#: c-family/c-warn.c:96
 #, fuzzy, gcc-internal-format
 #| msgid "integer overflow in expression"
 msgid "integer overflow in expression of type %qT results in %qE"
 msgstr "式内で整数がオーバーフローしました"
 
-#: c-family/c-warn.c:101
+#: c-family/c-warn.c:102
 #, fuzzy, gcc-internal-format
 #| msgid "floating point overflow in expression"
 msgid "floating point overflow in expression %qE of type %qT results in %qE"
 msgstr "式内で浮動小数点数がオーバーフローしました"
 
-#: c-family/c-warn.c:103
+#: c-family/c-warn.c:104
 #, fuzzy, gcc-internal-format
 #| msgid "floating point overflow in expression"
 msgid "floating point overflow in expression of type %qT results in %qE"
 msgstr "式内で浮動小数点数がオーバーフローしました"
 
-#: c-family/c-warn.c:109
+#: c-family/c-warn.c:110
 #, fuzzy, gcc-internal-format
 #| msgid "fixed-point overflow in expression"
 msgid "fixed-point overflow in expression %qE of type %qT results in %qE"
 msgstr "式内で固定小数点数がオーバーフローしました"
 
-#: c-family/c-warn.c:111
+#: c-family/c-warn.c:112
 #, fuzzy, gcc-internal-format
 #| msgid "fixed-point overflow in expression"
 msgid "fixed-point overflow in expression of type %qT results in %qE"
 msgstr "式内で固定小数点数がオーバーフローしました"
 
-#: c-family/c-warn.c:117
+#: c-family/c-warn.c:118
 #, fuzzy, gcc-internal-format
 #| msgid "vector overflow in expression"
 msgid "vector overflow in expression %qE of type %qT results in %qE"
 msgstr "式内でベクトルがオーバーフローしました"
 
-#: c-family/c-warn.c:119
+#: c-family/c-warn.c:120
 #, fuzzy, gcc-internal-format
 #| msgid "vector overflow in expression"
 msgid "vector overflow in expression of type %qT results in %qE"
 msgstr "式内でベクトルがオーバーフローしました"
 
-#: c-family/c-warn.c:126
+#: c-family/c-warn.c:127
 #, fuzzy, gcc-internal-format
 #| msgid "complex integer overflow in expression"
 msgid "complex integer overflow in expression %qE of type %qT results in %qE"
 msgstr "式内で複素整数がオーバーフローしました"
 
-#: c-family/c-warn.c:128
+#: c-family/c-warn.c:129
 #, fuzzy, gcc-internal-format
 #| msgid "complex integer overflow in expression"
 msgid "complex integer overflow in expression of type %qT results in %qE"
 msgstr "式内で複素整数がオーバーフローしました"
 
-#: c-family/c-warn.c:132
+#: c-family/c-warn.c:133
 #, fuzzy, gcc-internal-format
 #| msgid "complex floating point overflow in expression"
 msgid "complex floating point overflow in expression %qE of type %qT results in %qE"
 msgstr "式内で複素浮動小数点数がオーバーフローしました"
 
-#: c-family/c-warn.c:134
+#: c-family/c-warn.c:135
 #, fuzzy, gcc-internal-format
 #| msgid "complex floating point overflow in expression"
 msgid "complex floating point overflow in expression of type %qT results in %qE"
 msgstr "式内で複素浮動小数点数がオーバーフローしました"
 
-#: c-family/c-warn.c:216
+#: c-family/c-warn.c:217
 #, gcc-internal-format
 msgid "logical %<or%> applied to non-boolean constant"
 msgstr "論理 %<or%> が非真偽定数に適用されています"
 
-#: c-family/c-warn.c:219
+#: c-family/c-warn.c:220
 #, gcc-internal-format
 msgid "logical %<and%> applied to non-boolean constant"
 msgstr "論理 %<and%> が非真偽定数に適用されています"
 
-#: c-family/c-warn.c:289
+#: c-family/c-warn.c:290
 #, gcc-internal-format
 msgid "logical %<or%> of collectively exhaustive tests is always true"
 msgstr ""
 
-#: c-family/c-warn.c:293
+#: c-family/c-warn.c:294
 #, gcc-internal-format
 msgid "logical %<and%> of mutually exclusive tests is always false"
 msgstr "相互に排他的な値の論理 %<and%> 演算は常に偽 (false) となります"
 
-#: c-family/c-warn.c:303
+#: c-family/c-warn.c:304
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand in unary expression"
 msgid "logical %<or%> of equal expressions"
 msgstr "単項演算式内で無効な被演算子です"
 
-#: c-family/c-warn.c:306
+#: c-family/c-warn.c:307
 #, fuzzy, gcc-internal-format
 #| msgid "logical %<and%> of mutually exclusive tests is always false"
 msgid "logical %<and%> of equal expressions"
 msgstr "相互に排他的な値の論理 %<and%> 演算は常に偽 (false) となります"
 
-#: c-family/c-warn.c:384
+#: c-family/c-warn.c:385
 #, gcc-internal-format
 msgid "bitwise comparison always evaluates to false"
 msgstr ""
 
-#: c-family/c-warn.c:387
+#: c-family/c-warn.c:388
 #, fuzzy, gcc-internal-format
 #| msgid "the address of %qD will always evaluate as %<true%>"
 msgid "bitwise comparison always evaluates to true"
 msgstr "%qD のアドレスは常に %<true%> と評価されます"
 
-#: c-family/c-warn.c:441
+#: c-family/c-warn.c:442
 #, gcc-internal-format
 msgid "self-comparison always evaluates to true"
 msgstr ""
 
-#: c-family/c-warn.c:444
+#: c-family/c-warn.c:445
 #, gcc-internal-format
 msgid "self-comparison always evaluates to false"
 msgstr ""
 
-#: c-family/c-warn.c:494
+#: c-family/c-warn.c:495
 #, gcc-internal-format
 msgid "logical not is only applied to the left hand side of comparison"
 msgstr ""
 
-#: c-family/c-warn.c:502
+#: c-family/c-warn.c:503
 #, gcc-internal-format
 msgid "add parentheses around left hand side expression to silence this warning"
 msgstr ""
 
-#: c-family/c-warn.c:636
+#: c-family/c-warn.c:637
 #, gcc-internal-format
 msgid "type-punning to incomplete type might break strict-aliasing rules"
 msgstr ""
 
-#: c-family/c-warn.c:654
+#: c-family/c-warn.c:655
 #, gcc-internal-format
 msgid "dereferencing type-punned pointer will break strict-aliasing rules"
 msgstr ""
 
-#: c-family/c-warn.c:662 c-family/c-warn.c:680
+#: c-family/c-warn.c:663 c-family/c-warn.c:681
 #, gcc-internal-format
 msgid "dereferencing type-punned pointer might break strict-aliasing rules"
 msgstr ""
 
-#: c-family/c-warn.c:803
+#: c-family/c-warn.c:811
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to use the size of the destination?"
 msgstr ""
 
-#: c-family/c-warn.c:834
+#: c-family/c-warn.c:842
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the destination; did you mean to remove the addressof?"
 msgstr ""
 
-#: c-family/c-warn.c:841
+#: c-family/c-warn.c:849
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the destination; did you mean to provide an explicit length?"
 msgstr ""
 
-#: c-family/c-warn.c:846
+#: c-family/c-warn.c:854
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the destination; did you mean to dereference it?"
 msgstr ""
 
-#: c-family/c-warn.c:858
+#: c-family/c-warn.c:866
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the destination; expected %qT or an explicit length"
 msgstr ""
 
-#: c-family/c-warn.c:874
+#: c-family/c-warn.c:882
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to remove the addressof?"
 msgstr ""
 
-#: c-family/c-warn.c:881
+#: c-family/c-warn.c:889
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to provide an explicit length?"
 msgstr ""
 
-#: c-family/c-warn.c:886
+#: c-family/c-warn.c:894
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to dereference it?"
 msgstr ""
 
-#: c-family/c-warn.c:898
+#: c-family/c-warn.c:906
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the source; expected %qT or an explicit length"
 msgstr ""
 
-#: c-family/c-warn.c:914
+#: c-family/c-warn.c:922
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the first source; did you mean to remove the addressof?"
 msgstr ""
 
-#: c-family/c-warn.c:921
+#: c-family/c-warn.c:929
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the first source; did you mean to provide an explicit length?"
 msgstr ""
 
-#: c-family/c-warn.c:926
+#: c-family/c-warn.c:934
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the first source; did you mean to dereference it?"
 msgstr ""
 
-#: c-family/c-warn.c:938
+#: c-family/c-warn.c:946
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the first source; expected %qT or an explicit length"
 msgstr ""
 
-#: c-family/c-warn.c:954
+#: c-family/c-warn.c:962
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the second source; did you mean to remove the addressof?"
 msgstr ""
 
-#: c-family/c-warn.c:961
+#: c-family/c-warn.c:969
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the second source; did you mean to provide an explicit length?"
 msgstr ""
 
-#: c-family/c-warn.c:966
+#: c-family/c-warn.c:974
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the second source; did you mean to dereference it?"
 msgstr ""
 
-#: c-family/c-warn.c:978
+#: c-family/c-warn.c:986
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the second source; expected %qT or an explicit length"
 msgstr ""
 
-#: c-family/c-warn.c:1007 c-family/c-warn.c:1014
+#: c-family/c-warn.c:1015 c-family/c-warn.c:1022
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%>-qualified parameter type %qT of %q+D"
 msgstr "仮引数 `%s' は無効です"
 
-#: c-family/c-warn.c:1024
+#: c-family/c-warn.c:1032
 #, gcc-internal-format
 msgid "first argument of %q+D should be %<int%>"
 msgstr "%q+D の第一引数は %<int%> であるべきです"
 
-#: c-family/c-warn.c:1033
+#: c-family/c-warn.c:1041
 #, gcc-internal-format
 msgid "second argument of %q+D should be %<char **%>"
 msgstr "%q+D の第二引数は %<char **%> であるべきです"
 
-#: c-family/c-warn.c:1042
+#: c-family/c-warn.c:1050
 #, gcc-internal-format
 msgid "third argument of %q+D should probably be %<char **%>"
 msgstr "%q+D の第三引数は %<char **%> とすべきでしょう"
 
-#: c-family/c-warn.c:1053
+#: c-family/c-warn.c:1061
 #, gcc-internal-format
 msgid "%q+D takes only zero or two arguments"
 msgstr "%q+D は 0 個または 2 個の引数のみとります"
 
-#: c-family/c-warn.c:1057
+#: c-family/c-warn.c:1065
 #, fuzzy, gcc-internal-format
 #| msgid "field %qE declared as a function"
 msgid "%q+D declared as variadic function"
 msgstr "フィールド %qE が関数として宣言されています"
 
-#: c-family/c-warn.c:1099
+#: c-family/c-warn.c:1107
 #, gcc-internal-format
 msgid "conversion to %qT from boolean expression"
 msgstr "真偽式から %qT への変換です"
 
-#: c-family/c-warn.c:1117 c-family/c-warn.c:1192
+#: c-family/c-warn.c:1125 c-family/c-warn.c:1200
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "conversion from %qT to %qT changes value from %qE to %qE"
 msgstr "%qT から %qT への変換が曖昧です"
 
-#: c-family/c-warn.c:1121 c-family/c-warn.c:1200
+#: c-family/c-warn.c:1129 c-family/c-warn.c:1208
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "conversion from %qT to %qT changes the value of %qE"
 msgstr "%qT から %qT への変換が曖昧です"
 
-#: c-family/c-warn.c:1141
+#: c-family/c-warn.c:1149
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "conversion from %qT to %qT discards imaginary component"
 msgstr "%qT から %qT への変換が曖昧です"
 
-#: c-family/c-warn.c:1153
+#: c-family/c-warn.c:1161
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %qT from %qT may alter its value"
 msgid "conversion from %qT to %qT may change value"
 msgstr "%qT への %qT からの変換はその値が変更になるかもしれません"
 
-#: c-family/c-warn.c:1213 c-family/c-warn.c:1230 c-family/c-warn.c:1247
+#: c-family/c-warn.c:1221 c-family/c-warn.c:1238 c-family/c-warn.c:1255
 #, fuzzy, gcc-internal-format
 #| msgid "implicit conversion from %qT to %qT when passing argument to function"
 msgid "overflow in conversion from %qT to %qT changes value from %qE to %qE"
 msgstr "関数へ引数を渡すときに %qT から %qT へ暗黙的に変換されます"
 
-#: c-family/c-warn.c:1218 c-family/c-warn.c:1235 c-family/c-warn.c:1252
+#: c-family/c-warn.c:1226 c-family/c-warn.c:1243 c-family/c-warn.c:1260
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "overflow in conversion from %qT to %qT changes the value of %qE"
 msgstr "%qT から %qT への変換が曖昧です"
 
-#: c-family/c-warn.c:1282
+#: c-family/c-warn.c:1290
 #, gcc-internal-format
 msgid "case value %qs not in enumerated type"
 msgstr "case 値 %qs は列挙型ではありません"
 
-#: c-family/c-warn.c:1287
+#: c-family/c-warn.c:1295
 #, gcc-internal-format
 msgid "case value %qs not in enumerated type %qT"
 msgstr "case 値 %qs は列挙型 %qT ではありません"
 
-#: c-family/c-warn.c:1348
+#: c-family/c-warn.c:1356
 #, gcc-internal-format
 msgid "switch missing default case"
 msgstr "default の case が無い switch です"
 
-#: c-family/c-warn.c:1393
+#: c-family/c-warn.c:1401
 #, gcc-internal-format
 msgid "switch condition has boolean value"
 msgstr ""
 
-#: c-family/c-warn.c:1466
+#: c-family/c-warn.c:1474
 #, gcc-internal-format
 msgid "enumeration value %qE not handled in switch"
 msgstr "列挙値 %qE は switch 内で取り扱われません"
 
-#: c-family/c-warn.c:1494
+#: c-family/c-warn.c:1502
 #, gcc-internal-format
 msgid "the omitted middle operand in ?: will always be %<true%>, suggest explicit middle operand"
 msgstr ""
 
-#: c-family/c-warn.c:1515
+#: c-family/c-warn.c:1523
 #, gcc-internal-format
 msgid "assignment of member %qD in read-only object"
 msgstr "読み取り専用オブジェクト内のメンバ %qD への代入です"
 
-#: c-family/c-warn.c:1517
+#: c-family/c-warn.c:1525
 #, gcc-internal-format
 msgid "increment of member %qD in read-only object"
 msgstr "読み取り専用オブジェクト内のメンバ %qD の増分です"
 
-#: c-family/c-warn.c:1519
+#: c-family/c-warn.c:1527
 #, gcc-internal-format
 msgid "decrement of member %qD in read-only object"
 msgstr "読み取り専用オブジェクト内のメンバ %qD の減分です"
 
-#: c-family/c-warn.c:1521
+#: c-family/c-warn.c:1529
 #, gcc-internal-format
 msgid "member %qD in read-only object used as %<asm%> output"
 msgstr "読み取り専用オブジェクト内のメンバ %qD が %<asm%> の出力として使用されています"
 
-#: c-family/c-warn.c:1525
+#: c-family/c-warn.c:1533
 #, gcc-internal-format
 msgid "assignment of read-only member %qD"
 msgstr "読み取り専用メンバ %qD への代入です"
 
-#: c-family/c-warn.c:1526
+#: c-family/c-warn.c:1534
 #, gcc-internal-format
 msgid "increment of read-only member %qD"
 msgstr "読み取り専用メンバ %qD の増分です"
 
-#: c-family/c-warn.c:1527
+#: c-family/c-warn.c:1535
 #, gcc-internal-format
 msgid "decrement of read-only member %qD"
 msgstr "読み取り専用メンバ %qD の減分です"
 
-#: c-family/c-warn.c:1528
+#: c-family/c-warn.c:1536
 #, gcc-internal-format
 msgid "read-only member %qD used as %<asm%> output"
 msgstr "読み取り専用メンバ %qD が %<asm%> の出力として使用されています"
 
-#: c-family/c-warn.c:1532
+#: c-family/c-warn.c:1540
 #, gcc-internal-format
 msgid "assignment of read-only variable %qD"
 msgstr "読み取り専用変数 %qD への代入です"
 
-#: c-family/c-warn.c:1533
+#: c-family/c-warn.c:1541
 #, gcc-internal-format
 msgid "increment of read-only variable %qD"
 msgstr "読み取り専用変数 %qD の増分です"
 
-#: c-family/c-warn.c:1534
+#: c-family/c-warn.c:1542
 #, gcc-internal-format
 msgid "decrement of read-only variable %qD"
 msgstr "読み取り専用変数 %qD の減分です"
 
-#: c-family/c-warn.c:1535
+#: c-family/c-warn.c:1543
 #, gcc-internal-format
 msgid "read-only variable %qD used as %<asm%> output"
 msgstr "読み取り専用変数 %qD が %<asm%> の出力として使用されています"
 
-#: c-family/c-warn.c:1538
+#: c-family/c-warn.c:1546
 #, gcc-internal-format
 msgid "assignment of read-only parameter %qD"
 msgstr "読み取り専用パラメータ %qD への代入です"
 
-#: c-family/c-warn.c:1539
+#: c-family/c-warn.c:1547
 #, gcc-internal-format
 msgid "increment of read-only parameter %qD"
 msgstr "読み取り専用パラメータ %qD の増分です"
 
-#: c-family/c-warn.c:1540
+#: c-family/c-warn.c:1548
 #, gcc-internal-format
 msgid "decrement of read-only parameter %qD"
 msgstr "読み取り専用パラメータ %qD の減分です"
 
-#: c-family/c-warn.c:1541
+#: c-family/c-warn.c:1549
 #, gcc-internal-format
 msgid "read-only parameter %qD use as %<asm%> output"
 msgstr "読み取り専用パラメータ %qD が %<asm%> の出力として使用されています"
 
-#: c-family/c-warn.c:1546
+#: c-family/c-warn.c:1554
 #, gcc-internal-format
 msgid "assignment of read-only named return value %qD"
 msgstr "読み取り専用名前付き戻り値 %qD への代入です"
 
-#: c-family/c-warn.c:1548
+#: c-family/c-warn.c:1556
 #, gcc-internal-format
 msgid "increment of read-only named return value %qD"
 msgstr "読み取り専用名前付き戻り値 %qD の増分です"
 
-#: c-family/c-warn.c:1550
+#: c-family/c-warn.c:1558
 #, gcc-internal-format
 msgid "decrement of read-only named return value %qD"
 msgstr "読み取り専用名前付き戻り値 %qD の減分です"
 
-#: c-family/c-warn.c:1552
+#: c-family/c-warn.c:1560
 #, gcc-internal-format
 msgid "read-only named return value %qD used as %<asm%>output"
 msgstr "読み取り専用名前付き戻り値 %qD が %<asm%> の出力として使用されています"
 
-#: c-family/c-warn.c:1557
+#: c-family/c-warn.c:1565
 #, gcc-internal-format
 msgid "assignment of function %qD"
 msgstr "関数 %qD への代入です"
 
-#: c-family/c-warn.c:1558
+#: c-family/c-warn.c:1566
 #, gcc-internal-format
 msgid "increment of function %qD"
 msgstr "関数 %qD の増分です"
 
-#: c-family/c-warn.c:1559
+#: c-family/c-warn.c:1567
 #, gcc-internal-format
 msgid "decrement of function %qD"
 msgstr "関数 %qD の減分です"
 
-#: c-family/c-warn.c:1560
+#: c-family/c-warn.c:1568
 #, gcc-internal-format
 msgid "function %qD used as %<asm%> output"
 msgstr "関数 %qD が %<asm%> の出力として使用されています"
 
-#: c-family/c-warn.c:1563 c/c-typeck.c:4762
+#: c-family/c-warn.c:1571 c/c-typeck.c:4767
 #, gcc-internal-format
 msgid "assignment of read-only location %qE"
 msgstr "読み取り専用位置 %qE への代入です"
 
-#: c-family/c-warn.c:1564 c/c-typeck.c:4765
+#: c-family/c-warn.c:1572 c/c-typeck.c:4770
 #, gcc-internal-format
 msgid "increment of read-only location %qE"
 msgstr "読み取り専用位置 %qE の増分です"
 
-#: c-family/c-warn.c:1565 c/c-typeck.c:4768
+#: c-family/c-warn.c:1573 c/c-typeck.c:4773
 #, gcc-internal-format
 msgid "decrement of read-only location %qE"
 msgstr "読み取り専用位置 %qE の減分です"
 
-#: c-family/c-warn.c:1566
+#: c-family/c-warn.c:1574
 #, gcc-internal-format
 msgid "read-only location %qE used as %<asm%> output"
 msgstr "読み取り専用位置 %qE が %<asm%> の出力として使用されています"
 
-#: c-family/c-warn.c:1580
+#: c-family/c-warn.c:1588
 #, gcc-internal-format
 msgid "lvalue required as left operand of assignment"
 msgstr "代入の左側の被演算子として左辺値が必要です"
 
-#: c-family/c-warn.c:1583
+#: c-family/c-warn.c:1591
 #, gcc-internal-format
 msgid "lvalue required as increment operand"
 msgstr "増分の被演算子として左辺値が必要です"
 
-#: c-family/c-warn.c:1586
+#: c-family/c-warn.c:1594
 #, gcc-internal-format
 msgid "lvalue required as decrement operand"
 msgstr "減分の被演算子として左辺値が必要です"
 
-#: c-family/c-warn.c:1589
+#: c-family/c-warn.c:1597
 #, gcc-internal-format
 msgid "lvalue required as unary %<&%> operand"
 msgstr "単項 %<&%> の被演算子として左辺値が必要です"
 
-#: c-family/c-warn.c:1592
+#: c-family/c-warn.c:1600
 #, gcc-internal-format
 msgid "lvalue required in asm statement"
 msgstr "アセンブラ文内に左辺値が必要です"
 
-#: c-family/c-warn.c:1609
+#: c-family/c-warn.c:1617
 #, gcc-internal-format
 msgid "invalid type argument (have %qT)"
 msgstr "無効な型の引数です (%qT 型です)"
 
-#: c-family/c-warn.c:1613
+#: c-family/c-warn.c:1621
 #, gcc-internal-format
 msgid "invalid type argument of array indexing (have %qT)"
 msgstr ""
 
-#: c-family/c-warn.c:1618
+#: c-family/c-warn.c:1626
 #, gcc-internal-format
 msgid "invalid type argument of unary %<*%> (have %qT)"
 msgstr "単項演算子 %<*%> の無効な型の引数です (%qT 型です)"
 
-#: c-family/c-warn.c:1623
+#: c-family/c-warn.c:1631
 #, gcc-internal-format
 msgid "invalid type argument of %<->%> (have %qT)"
 msgstr "%<->%> の無効な型の引数です (%qT 型です)"
 
-#: c-family/c-warn.c:1628
+#: c-family/c-warn.c:1636
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument of %<->%> (have %qT)"
 msgid "invalid type argument of %<->*%> (have %qT)"
 msgstr "%<->%> の無効な型の引数です (%qT 型です)"
 
-#: c-family/c-warn.c:1633
+#: c-family/c-warn.c:1641
 #, gcc-internal-format
 msgid "invalid type argument of implicit conversion (have %qT)"
 msgstr "暗黙的な変換の無効な型の引数です (%qT 型です)"
 
-#: c-family/c-warn.c:1654
+#: c-family/c-warn.c:1662
 #, gcc-internal-format
 msgid "array subscript has type %<char%>"
 msgstr "配列の添字が %<char%> 型です"
 
-#: c-family/c-warn.c:1689 c-family/c-warn.c:1692
+#: c-family/c-warn.c:1697 c-family/c-warn.c:1700
 #, gcc-internal-format
 msgid "suggest parentheses around %<+%> inside %<<<%>"
 msgstr "%<<<%> 内にある %<+%> の周りに小括弧を付けることを推奨します"
 
-#: c-family/c-warn.c:1695 c-family/c-warn.c:1698
+#: c-family/c-warn.c:1703 c-family/c-warn.c:1706
 #, gcc-internal-format
 msgid "suggest parentheses around %<-%> inside %<<<%>"
 msgstr "%<<<%> 内にある %<-%> の周りに小括弧を付けることを推奨します"
 
-#: c-family/c-warn.c:1704 c-family/c-warn.c:1707
+#: c-family/c-warn.c:1712 c-family/c-warn.c:1715
 #, gcc-internal-format
 msgid "suggest parentheses around %<+%> inside %<>>%>"
 msgstr "%<>>%> 内にある %<+%> の周りに小括弧を付けることを推奨します"
 
-#: c-family/c-warn.c:1710 c-family/c-warn.c:1713
+#: c-family/c-warn.c:1718 c-family/c-warn.c:1721
 #, gcc-internal-format
 msgid "suggest parentheses around %<-%> inside %<>>%>"
 msgstr "%<>>%> 内にある %<-%> の周りに小括弧を付けることを推奨します"
 
-#: c-family/c-warn.c:1719 c-family/c-warn.c:1722
+#: c-family/c-warn.c:1727 c-family/c-warn.c:1730
 #, gcc-internal-format
 msgid "suggest parentheses around %<&&%> within %<||%>"
 msgstr "%<||%> 内にある %<&&%> の周りに小括弧を付けることを推奨します"
 
-#: c-family/c-warn.c:1729 c-family/c-warn.c:1733
+#: c-family/c-warn.c:1737 c-family/c-warn.c:1741
 #, gcc-internal-format
 msgid "suggest parentheses around arithmetic in operand of %<|%>"
 msgstr "%<|%> の被演算子内にある計算の周りに小括弧を付けることを推奨します"
 
-#: c-family/c-warn.c:1737 c-family/c-warn.c:1740
+#: c-family/c-warn.c:1745 c-family/c-warn.c:1748
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<|%>"
 msgstr "%<|%> の被演算子内にある比較の周りに小括弧を付けることを推奨します"
 
-#: c-family/c-warn.c:1745
+#: c-family/c-warn.c:1753
 #, gcc-internal-format
 msgid "suggest parentheses around operand of %<!%> or change %<|%> to %<||%> or %<!%> to %<~%>"
 msgstr "%<!%> の被演算子の周りに小括弧を付ける、または %<|%> から %<||%> へ変更する、または %<!%> から %<~%> へ変更することを推奨します"
 
-#: c-family/c-warn.c:1753 c-family/c-warn.c:1757
+#: c-family/c-warn.c:1761 c-family/c-warn.c:1765
 #, gcc-internal-format
 msgid "suggest parentheses around arithmetic in operand of %<^%>"
 msgstr "%<^%> の被演算子内にある計算の周りに小括弧を付けることを推奨します"
 
-#: c-family/c-warn.c:1761 c-family/c-warn.c:1764
+#: c-family/c-warn.c:1769 c-family/c-warn.c:1772
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<^%>"
 msgstr "%<^%> の被演算子内にある比較の周りに小括弧を付けることを推奨します"
 
-#: c-family/c-warn.c:1770 c-family/c-warn.c:1773
+#: c-family/c-warn.c:1778 c-family/c-warn.c:1781
 #, gcc-internal-format
 msgid "suggest parentheses around %<+%> in operand of %<&%>"
 msgstr "%<&%> の被演算子内にある %<+%> の周りに小括弧を付けることを推奨します"
 
-#: c-family/c-warn.c:1776 c-family/c-warn.c:1779
+#: c-family/c-warn.c:1784 c-family/c-warn.c:1787
 #, gcc-internal-format
 msgid "suggest parentheses around %<-%> in operand of %<&%>"
 msgstr "%<&%> の被演算子内にある %<-%> の周りに小括弧を付けることを推奨します"
 
-#: c-family/c-warn.c:1783 c-family/c-warn.c:1786
+#: c-family/c-warn.c:1791 c-family/c-warn.c:1794
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<&%>"
 msgstr "%<&%> の被演算子内にある比較の周りに小括弧を付けることを推奨します"
 
-#: c-family/c-warn.c:1791
+#: c-family/c-warn.c:1799
 #, gcc-internal-format
 msgid "suggest parentheses around operand of %<!%> or change %<&%> to %<&&%> or %<!%> to %<~%>"
 msgstr "%<!%> の被演算子の周りに小括弧を付ける、または %<&%> から %<&&%> へ変更する、または %<!%> から %<~%> へ変更することを推奨します"
 
-#: c-family/c-warn.c:1798 c-family/c-warn.c:1801
+#: c-family/c-warn.c:1806 c-family/c-warn.c:1809
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<==%>"
 msgstr "%<==%> の被演算子内にある比較の周りに小括弧を付けることを推奨します"
 
-#: c-family/c-warn.c:1806 c-family/c-warn.c:1809
+#: c-family/c-warn.c:1814 c-family/c-warn.c:1817
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<!=%>"
 msgstr "%<!=%> の被演算子内にある比較の周りに小括弧を付けることを推奨します"
 
-#: c-family/c-warn.c:1819 c-family/c-warn.c:1825
+#: c-family/c-warn.c:1827 c-family/c-warn.c:1833
 #, gcc-internal-format
 msgid "comparisons like %<X<=Y<=Z%> do not have their mathematical meaning"
 msgstr "%<X<=Y<=Z%> のような比較は数学と同じような意味にはなりません"
 
-#: c-family/c-warn.c:1841
+#: c-family/c-warn.c:1849
 #, gcc-internal-format
 msgid "label %q+D defined but not used"
 msgstr "ラベル %q+D が定義されていますが使用されていません"
 
-#: c-family/c-warn.c:1843
+#: c-family/c-warn.c:1851
 #, gcc-internal-format
 msgid "label %q+D declared but not defined"
 msgstr "ラベル %q+D が宣言されましたが定義されていません"
 
-#: c-family/c-warn.c:1866
+#: c-family/c-warn.c:1874
 #, gcc-internal-format
 msgid "division by zero"
 msgstr "ゼロ除算が発生しました"
 
-#: c-family/c-warn.c:1886
+#: c-family/c-warn.c:1894
 #, gcc-internal-format
 msgid "%<memset%> used with constant zero length parameter; this could be due to transposed parameters"
 msgstr ""
 
-#: c-family/c-warn.c:1909
+#: c-family/c-warn.c:1918
 #, gcc-internal-format
 msgid "%<memset%> used with length equal to number of elements without multiplication by element size"
 msgstr ""
 
-#: c-family/c-warn.c:1948 c/c-typeck.c:11499 c/c-typeck.c:11667
+#: c-family/c-warn.c:1957 c/c-typeck.c:11504 c/c-typeck.c:11672
 #: cp/typeck.c:5048
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr "型 %qT と %qT の間での比較です"
 
-#: c-family/c-warn.c:1998
+#: c-family/c-warn.c:2007
 #, gcc-internal-format
 msgid "comparison of integer expressions of different signedness: %qT and %qT"
 msgstr ""
 
-#: c-family/c-warn.c:2051
+#: c-family/c-warn.c:2060
 #, gcc-internal-format
 msgid "promoted ~unsigned is always non-zero"
 msgstr ""
 
-#: c-family/c-warn.c:2054
+#: c-family/c-warn.c:2063
 #, gcc-internal-format
 msgid "comparison of promoted ~unsigned with constant"
 msgstr "~で反転された格上げ符号無し型と定数との比較です"
 
-#: c-family/c-warn.c:2064
+#: c-family/c-warn.c:2073
 #, gcc-internal-format
 msgid "comparison of promoted ~unsigned with unsigned"
 msgstr "~で反転された格上げ符号無し型と符号無し型との比較です"
 
-#: c-family/c-warn.c:2118
+#: c-family/c-warn.c:2127
 #, fuzzy, gcc-internal-format
 #| msgid "unused parameter %q+D"
 msgid "unused parameter %qD"
 msgstr "仮引数 %q+D が未使用です"
 
-#: c-family/c-warn.c:2180
+#: c-family/c-warn.c:2189
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D defined but not used"
 msgid "typedef %qD locally defined but not used"
 msgstr "%q+D が定義されましたが使用されません"
 
-#: c-family/c-warn.c:2215
+#: c-family/c-warn.c:2224
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<const%>"
 msgid "duplicated %<if%> condition"
 msgstr "重複した %<const%> です"
 
-#: c-family/c-warn.c:2244
+#: c-family/c-warn.c:2253
 #, gcc-internal-format
 msgid "optimization attribute on %qD follows definition but the attribute doesn%'t match"
 msgstr ""
 
-#: c-family/c-warn.c:2254
+#: c-family/c-warn.c:2261
 #, fuzzy, gcc-internal-format
 #| msgid "inline declaration of %qD follows declaration with attribute noinline"
 msgid "inline declaration of %qD follows declaration with attribute %qs"
 msgstr "%qD のインライン宣言の後に非インライン属性の宣言があります"
 
-#: c-family/c-warn.c:2259
+#: c-family/c-warn.c:2266
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D with attribute noinline follows inline declaration "
 msgid "declaration of %q+D with attribute %qs follows inline declaration"
 msgstr "%q+D の非インライン属性での宣言の後にインライン宣言があります"
 
-#: c-family/c-warn.c:2306
+#: c-family/c-warn.c:2313
 #, gcc-internal-format
 msgid "result of %qE requires %u bits to represent, but %qT only has %u bits"
 msgstr ""
 
-#: c-family/c-warn.c:2344 c-family/c-warn.c:2368
+#: c-family/c-warn.c:2351 c-family/c-warn.c:2375
 #, fuzzy, gcc-internal-format
 #| msgid "comparison of unsigned expression < 0 is always false"
 msgid "comparison of constant %qE with boolean expression is always false"
 msgstr "符号無しの式 < 0 という比較は常に false です"
 
-#: c-family/c-warn.c:2347 c-family/c-warn.c:2365
+#: c-family/c-warn.c:2354 c-family/c-warn.c:2372
 #, fuzzy, gcc-internal-format
 #| msgid "comparison of unsigned expression >= 0 is always true"
 msgid "comparison of constant %qE with boolean expression is always true"
 msgstr "符号無しの式 >= 0 という比較は常に true です"
 
-#: c-family/c-warn.c:2415
+#: c-family/c-warn.c:2422
 msgid "passing argument %i to restrict-qualified parameter aliases with argument %Z"
 msgid_plural "passing argument %i to restrict-qualified parameter aliases with arguments %Z"
 msgstr[0] ""
 
-#: c-family/c-warn.c:2480 c/c-typeck.c:5288 cp/call.c:5365
+#: c-family/c-warn.c:2487 c/c-typeck.c:5293 cp/call.c:5365
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr ""
 
-#: c-family/c-warn.c:2586
+#: c-family/c-warn.c:2593
 #, gcc-internal-format
 msgid "macro expands to multiple statements"
 msgstr ""
 
-#: c-family/c-warn.c:2587
+#: c-family/c-warn.c:2594
 #, gcc-internal-format
 msgid "some parts of macro expansion are not guarded by this %qs clause"
 msgstr ""
@@ -30458,7 +30501,7 @@
 msgid "too many input files"
 msgstr "入力ファイルが多すぎます"
 
-#: common/config/aarch64/aarch64-common.c:319 config/aarch64/aarch64.c:10686
+#: common/config/aarch64/aarch64-common.c:319 config/aarch64/aarch64.c:10702
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %s for -mfpu"
 msgid "unknown value %qs for -mcpu"
@@ -30491,7 +30534,7 @@
 msgstr ""
 
 #: common/config/arm/arm-common.c:322 common/config/arm/arm-common.c:376
-#: common/config/arm/arm-common.c:423 config/aarch64/aarch64.c:10639
+#: common/config/arm/arm-common.c:423 config/aarch64/aarch64.c:10655
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments are: %s; did you mean %qs?"
@@ -30498,7 +30541,7 @@
 msgstr "%qs への有効な引数は次の通りです: %s"
 
 #: common/config/arm/arm-common.c:325 common/config/arm/arm-common.c:379
-#: common/config/arm/arm-common.c:426 config/aarch64/aarch64.c:10642
+#: common/config/arm/arm-common.c:426 config/aarch64/aarch64.c:10658
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments are: %s"
@@ -30995,13 +31038,13 @@
 msgid "profiler support for VxWorks"
 msgstr "VxWorks 用のプロファイルサポート"
 
-#: config/aarch64/aarch64-builtins.c:1109 config/arm/arm-builtins.c:2262
+#: config/aarch64/aarch64-builtins.c:1109 config/arm/arm-builtins.c:2272
 #, fuzzy, gcc-internal-format
 #| msgid "argument must be a constant"
 msgid "%Kargument %d must be a constant immediate"
 msgstr "引数は定数でなければいけません"
 
-#: config/aarch64/aarch64-builtins.c:1180 config/arm/arm-builtins.c:2492
+#: config/aarch64/aarch64-builtins.c:1180 config/arm/arm-builtins.c:2502
 #, fuzzy, gcc-internal-format
 #| msgid "mask must be an immediate"
 msgid "%Klane index must be a constant immediate"
@@ -31012,186 +31055,186 @@
 msgid "%Ktotal size and element size must be a non-zero constant immediate"
 msgstr ""
 
-#: config/aarch64/aarch64.c:1053
+#: config/aarch64/aarch64.c:1069
 #, fuzzy, gcc-internal-format
 #| msgid "RTP PIC is incompatible with Thumb"
 msgid "%qs is incompatible with %s %s"
 msgstr "RTP PIC は Thumb では使用できません"
 
-#: config/aarch64/aarch64.c:1055
+#: config/aarch64/aarch64.c:1071
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with %s %s"
 msgstr ""
 
-#: config/aarch64/aarch64.c:3772
+#: config/aarch64/aarch64.c:3788
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10287
+#: config/aarch64/aarch64.c:10303
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown flag passed in -moverride=%s (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10331
+#: config/aarch64/aarch64.c:10347
 #, gcc-internal-format, gfc-internal-format
 msgid "%s string ill-formed\n"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10388
+#: config/aarch64/aarch64.c:10404
 #, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10406
+#: config/aarch64/aarch64.c:10422
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unknown spec function %qs"
 msgid "unknown tuning option (%s)"
 msgstr "不明な spec 関数 %qs です"
 
-#: config/aarch64/aarch64.c:10683
+#: config/aarch64/aarch64.c:10699
 #, gcc-internal-format
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10690
+#: config/aarch64/aarch64.c:10706
 #, fuzzy, gcc-internal-format
 #| msgid "invalid thread pointer option: -mtp=%s"
 msgid "invalid feature modifier in %<-mcpu=%s%>"
 msgstr "無効なスレッドポインタオプションです: -mtp=%s"
 
-#: config/aarch64/aarch64.c:10717
+#: config/aarch64/aarch64.c:10733
 #, gcc-internal-format
 msgid "missing arch name in %<-march=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10720
+#: config/aarch64/aarch64.c:10736
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %s for -mfpu"
 msgid "unknown value %qs for -march"
 msgstr "-mfpu 用の不明な値 %s です"
 
-#: config/aarch64/aarch64.c:10724
+#: config/aarch64/aarch64.c:10740
 #, fuzzy, gcc-internal-format
 #| msgid "invalid thread pointer option: -mtp=%s"
 msgid "invalid feature modifier in %<-march=%s%>"
 msgstr "無効なスレッドポインタオプションです: -mtp=%s"
 
-#: config/aarch64/aarch64.c:10750
+#: config/aarch64/aarch64.c:10766
 #, gcc-internal-format
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10753
+#: config/aarch64/aarch64.c:10769
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %s for -mfpu"
 msgid "unknown value %qs for -mtune"
 msgstr "-mfpu 用の不明な値 %s です"
 
-#: config/aarch64/aarch64.c:10871 config/arm/arm.c:3173
+#: config/aarch64/aarch64.c:10887 config/arm/arm.c:3173
 #, gcc-internal-format, gfc-internal-format
 msgid "switch -mcpu=%s conflicts with -march=%s switch"
 msgstr "-mcpu=%s スイッチが -march=%s スイッチと競合しています"
 
-#: config/aarch64/aarch64.c:10906
+#: config/aarch64/aarch64.c:10922
 #, fuzzy, gcc-internal-format
 #| msgid "does not support multilib"
 msgid "assembler does not support -mabi=ilp32"
 msgstr "multilib はサポートしません"
 
-#: config/aarch64/aarch64.c:10913
+#: config/aarch64/aarch64.c:10929
 #, gcc-internal-format
 msgid "return address signing is only supported for -mabi=lp64"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10975
+#: config/aarch64/aarch64.c:10991
 #, gcc-internal-format
 msgid "code model %qs with -f%s"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11138
+#: config/aarch64/aarch64.c:11154
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11141
+#: config/aarch64/aarch64.c:11157
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11145 config/aarch64/aarch64.c:11184
-#: config/aarch64/aarch64.c:11257
+#: config/aarch64/aarch64.c:11161 config/aarch64/aarch64.c:11200
+#: config/aarch64/aarch64.c:11273
 #, gcc-internal-format
 msgid "invalid value (\"%s\") in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11177
+#: config/aarch64/aarch64.c:11193
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11180
+#: config/aarch64/aarch64.c:11196
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11213
+#: config/aarch64/aarch64.c:11229
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"tune=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11253
+#: config/aarch64/aarch64.c:11269
 #, fuzzy, gcc-internal-format
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr "%<#pragma pack%> の後に %<(%> がありません - 無視されました"
 
-#: config/aarch64/aarch64.c:11306 config/aarch64/aarch64.c:11483
+#: config/aarch64/aarch64.c:11322 config/aarch64/aarch64.c:11499
 #, fuzzy, gcc-internal-format
 #| msgid "malformed %<#pragma init%>"
 msgid "malformed %<target()%> pragma or attribute"
 msgstr "間違った形式の %<#pragma init%> です"
 
-#: config/aarch64/aarch64.c:11354
+#: config/aarch64/aarch64.c:11370
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11362
+#: config/aarch64/aarch64.c:11378
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11416
+#: config/aarch64/aarch64.c:11432
 #, fuzzy, gcc-internal-format
 #| msgid "attribute(target(\"%s\")) is unknown"
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr "attribute(target(\"%s\")) が不明です"
 
-#: config/aarch64/aarch64.c:11473 config/arm/arm.c:30742
-#: config/i386/i386.c:5440 config/powerpcspe/powerpcspe.c:39760
-#: config/rs6000/rs6000.c:36904 config/s390/s390.c:15746
+#: config/aarch64/aarch64.c:11489 config/arm/arm.c:30742
+#: config/i386/i386.c:5443 config/powerpcspe/powerpcspe.c:39760
+#: config/rs6000/rs6000.c:36960 config/s390/s390.c:15746
 #, fuzzy, gcc-internal-format
 #| msgid "attribute %qE argument not a string"
 msgid "attribute %<target%> argument not a string"
 msgstr "属性 %qE の引数が文字列ではありません"
 
-#: config/aarch64/aarch64.c:11500
+#: config/aarch64/aarch64.c:11516
 #, fuzzy, gcc-internal-format
 #| msgid "attribute(target(\"%s\")) is unknown"
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr "attribute(target(\"%s\")) が不明です"
 
-#: config/aarch64/aarch64.c:11509
+#: config/aarch64/aarch64.c:11525
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13571
+#: config/aarch64/aarch64.c:13587
 #, gcc-internal-format
 msgid "%Klane %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13573
+#: config/aarch64/aarch64.c:13589
 #, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr ""
@@ -31251,8 +31294,8 @@
 msgid "bad value %qs for -mmemory-latency"
 msgstr "-mmemory-latency 用の間違った値 %qs です"
 
-#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6526
-#: config/arc/arc.c:6800 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
+#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6517
+#: config/arc/arc.c:6791 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
 #: config/tilepro/tilepro.c:3108
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -31368,11 +31411,11 @@
 #: config/arm/arm.c:7029 config/avr/avr.c:9718 config/avr/avr.c:9734
 #: config/bfin/bfin.c:4705 config/bfin/bfin.c:4766 config/bfin/bfin.c:4795
 #: config/epiphany/epiphany.c:491 config/h8300/h8300.c:5459
-#: config/i386/i386.c:6452 config/i386/i386.c:12479 config/i386/i386.c:41424
-#: config/i386/i386.c:41474 config/i386/i386.c:41544 config/m68k/m68k.c:780
+#: config/i386/i386.c:6455 config/i386/i386.c:12482 config/i386/i386.c:41418
+#: config/i386/i386.c:41468 config/i386/i386.c:41538 config/m68k/m68k.c:780
 #: config/mcore/mcore.c:3070 config/nvptx/nvptx.c:4611
 #: config/powerpcspe/powerpcspe.c:35785 config/riscv/riscv.c:2698
-#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:32982
+#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:33038
 #: config/rx/rx.c:2719 config/rx/rx.c:2745 config/s390/s390.c:1056
 #: config/s390/s390.c:1143 config/sh/sh.c:8428 config/sh/sh.c:8446
 #: config/sh/sh.c:8470 config/sh/sh.c:8541 config/sh/sh.c:8564
@@ -31382,146 +31425,146 @@
 msgid "%qE attribute only applies to functions"
 msgstr "%qE 属性は関数へのみ適用されます"
 
-#: config/arc/arc.c:6425
+#: config/arc/arc.c:6416
 #, fuzzy, gcc-internal-format
 #| msgid "%<__builtin_next_arg%> called without an argument"
 msgid "__builtin_arc_aligned with non-constant alignment"
 msgstr "%<__builtin_next_arg%> が引数無しで呼び出されました"
 
-#: config/arc/arc.c:6433
+#: config/arc/arc.c:6424
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to %<__builtin_frame_address%>"
 msgid "invalid alignment value for __builtin_arc_aligned"
 msgstr "%<__builtin_frame_address%> への無効な引数です"
 
-#: config/arc/arc.c:6596
+#: config/arc/arc.c:6587
 #, fuzzy, gcc-internal-format
 #| msgid "-mcorea should be used with -mmulticore"
 msgid "operand 1 should be an unsigned 3-bit immediate"
 msgstr "-mcorea は -mmulticore と併せて使用するべきです"
 
-#: config/arc/arc.c:6637 config/arc/arc.c:6734
+#: config/arc/arc.c:6628 config/arc/arc.c:6725
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6670 config/arc/arc.c:6702
+#: config/arc/arc.c:6661 config/arc/arc.c:6693
 #, gcc-internal-format
 msgid "operand 1 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6674 config/arc/arc.c:6706
+#: config/arc/arc.c:6665 config/arc/arc.c:6697
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 8-bit value"
 msgstr ""
 
-#: config/arc/arc.c:6738
+#: config/arc/arc.c:6729
 #, gcc-internal-format
 msgid "operand 3 should be an unsigned 8-bit value"
 msgstr ""
 
-#: config/arc/arc.c:6771
+#: config/arc/arc.c:6762
 #, gcc-internal-format
 msgid "operand 4 should be an unsigned 8-bit value (0-255)"
 msgstr ""
 
-#: config/arc/arc.c:6775
+#: config/arc/arc.c:6766
 #, gcc-internal-format
 msgid "operand 3 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6782
+#: config/arc/arc.c:6773
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (subreg 0-7)"
 msgstr ""
 
-#: config/arc/arc.c:6785
+#: config/arc/arc.c:6776
 #, gcc-internal-format
 msgid "operand 2 should be an even 3-bit value (subreg 0,2,4,6)"
 msgstr ""
 
-#: config/arc/arc.c:6832
+#: config/arc/arc.c:6823
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "symbol used as immediate operand"
 msgid "builtin requires an immediate for operand %d"
 msgstr "即値被演算子として使用されるシンボルです"
 
-#: config/arc/arc.c:6837
+#: config/arc/arc.c:6828
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "operand %d should be a 6 bit unsigned immediate"
 msgstr "第二引数は 5 ビット符号無しリテラルでなければいけません"
 
-#: config/arc/arc.c:6841
+#: config/arc/arc.c:6832
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "operand %d should be a 8 bit unsigned immediate"
 msgstr "第二引数は 5 ビット符号無しリテラルでなければいけません"
 
-#: config/arc/arc.c:6845
+#: config/arc/arc.c:6836
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "operand %d should be a 3 bit unsigned immediate"
 msgstr "第二引数は 5 ビット符号無しリテラルでなければいけません"
 
-#: config/arc/arc.c:6848
+#: config/arc/arc.c:6839
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown builtin immediate operand type for operand %d"
 msgstr ""
 
-#: config/arc/arc.c:6899
+#: config/arc/arc.c:6890
 #, gcc-internal-format
 msgid "register number must be a compile-time constant. Try giving higher optimization levels"
 msgstr ""
 
-#: config/arc/arc.c:7685
+#: config/arc/arc.c:7747
 #, gcc-internal-format
 msgid "Insn addresses not set after shorten_branches"
 msgstr ""
 
-#: config/arc/arc.c:7894
+#: config/arc/arc.c:7956
 #, fuzzy, gcc-internal-format
 #| msgid "Bad address, not register:"
 msgid "insn addresses not freed"
 msgstr "誤ったアドレスです。レジスタではありません:"
 
-#: config/arc/arc.c:10682
+#: config/arc/arc.c:10670
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only available for 32-bit"
 msgid "%qE attribute only valid for ARCv2 architecture"
 msgstr "%qE 属性は 32 ビットでのみ使用できます"
 
-#: config/arc/arc.c:10690 config/arc/arc.c:10729
+#: config/arc/arc.c:10678 config/arc/arc.c:10717
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qE attribute is not a string constant"
 msgid "argument of %qE attribute is missing"
 msgstr "%qE 属性の引数が文字列定数ではありません"
 
-#: config/arc/arc.c:10701 config/arc/arc.c:10740 config/arc/arc.c:10842
+#: config/arc/arc.c:10689 config/arc/arc.c:10728 config/arc/arc.c:10830
 #: config/avr/avr.c:9790
 #, gcc-internal-format
 msgid "%qE attribute allows only an integer constant argument"
 msgstr "%qE 属性は整数定数引数のみ許可されています"
 
-#: config/arc/arc.c:10721
+#: config/arc/arc.c:10709
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only available for 32-bit"
 msgid "%qE attribute only valid for ARC EM architecture"
 msgstr "%qE 属性は 32 ビットでのみ使用できます"
 
-#: config/arc/arc.c:10776
+#: config/arc/arc.c:10764
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to function types"
 msgid "%qE attribute only applies to types"
 msgstr "%qE 属性は関数型にのみ適用できます"
 
-#: config/arc/arc.c:10782
+#: config/arc/arc.c:10770
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored"
 msgid "argument of %qE attribute ignored"
 msgstr "%qE 属性は無視されました"
 
-#: config/arc/arc.c:10832 config/avr/avr.c:9777 config/bfin/bfin.c:4827
+#: config/arc/arc.c:10820 config/avr/avr.c:9777 config/bfin/bfin.c:4827
 #: config/i386/winnt.c:63 config/msp430/msp430.c:2018
 #: config/nvptx/nvptx.c:4634
 #, gcc-internal-format
@@ -31528,176 +31571,176 @@
 msgid "%qE attribute only applies to variables"
 msgstr "%qE は変数にのみ適用できます"
 
-#: config/arm/arm-builtins.c:2370
+#: config/arm/arm-builtins.c:2380
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "this builtin is not supported for this target"
 msgstr "-fdata-sections はこのターゲットではサポートされていません"
 
-#: config/arm/arm-builtins.c:2475
+#: config/arm/arm-builtins.c:2485
 #, gcc-internal-format
 msgid "You must enable NEON instructions (e.g. -mfloat-abi=softfp -mfpu=neon) to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2513
+#: config/arm/arm-builtins.c:2523
 #, gcc-internal-format
 msgid "You must enable VFP instructions to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2573
+#: config/arm/arm-builtins.c:2583
 #, gcc-internal-format
 msgid "You must enable crypto instructions (e.g. include -mfloat-abi=softfp -mfpu=crypto-neon...) to use these intrinsics."
 msgstr ""
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:2633 config/arm/arm-builtins.c:2737
+#: config/arm/arm-builtins.c:2643 config/arm/arm-builtins.c:2747
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr "セレクタは即値でなければなりません"
 
-#: config/arm/arm-builtins.c:2641 config/arm/arm-builtins.c:2686
-#: config/arm/arm-builtins.c:2744 config/arm/arm-builtins.c:2753
+#: config/arm/arm-builtins.c:2651 config/arm/arm-builtins.c:2696
+#: config/arm/arm-builtins.c:2754 config/arm/arm-builtins.c:2763
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2646 config/arm/arm-builtins.c:2755
+#: config/arm/arm-builtins.c:2656 config/arm/arm-builtins.c:2765
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2651 config/arm/arm-builtins.c:2757
+#: config/arm/arm-builtins.c:2661 config/arm/arm-builtins.c:2767
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2823
+#: config/arm/arm-builtins.c:2833
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr "マスクは即値でなければなりません"
 
-#: config/arm/arm-builtins.c:2828
+#: config/arm/arm-builtins.c:2838
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute argument should be between 0 to 255"
 msgid "the range of mask should be in 0 to 255"
 msgstr "%qE 属性引数は 0 と 255 の間であるべきです"
 
-#: config/arm/arm-builtins.c:3016
+#: config/arm/arm-builtins.c:3026
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3018
+#: config/arm/arm-builtins.c:3028
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3020
+#: config/arm/arm-builtins.c:3030
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3022
+#: config/arm/arm-builtins.c:3032
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3028
+#: config/arm/arm-builtins.c:3038
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3030
+#: config/arm/arm-builtins.c:3040
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3035
+#: config/arm/arm-builtins.c:3045
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3037
+#: config/arm/arm-builtins.c:3047
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3039
+#: config/arm/arm-builtins.c:3049
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3041
+#: config/arm/arm-builtins.c:3051
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3043
+#: config/arm/arm-builtins.c:3053
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3045
+#: config/arm/arm-builtins.c:3055
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3047
+#: config/arm/arm-builtins.c:3057
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3049
+#: config/arm/arm-builtins.c:3059
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3051
+#: config/arm/arm-builtins.c:3061
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3053
+#: config/arm/arm-builtins.c:3063
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3055
+#: config/arm/arm-builtins.c:3065
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3057
+#: config/arm/arm-builtins.c:3067
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3059
+#: config/arm/arm-builtins.c:3069
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3061
+#: config/arm/arm-builtins.c:3071
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3063
+#: config/arm/arm-builtins.c:3073
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3065
+#: config/arm/arm-builtins.c:3075
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3067
+#: config/arm/arm-builtins.c:3077
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3069
+#: config/arm/arm-builtins.c:3079
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr ""
@@ -32668,18 +32711,18 @@
 msgid "can%'t set position in PCH file: %m"
 msgstr "PCH ファイル内で位置を設定できません: %m"
 
-#: config/i386/i386.c:3177
+#: config/i386/i386.c:3180
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized argument in option %qs"
 msgid "wrong argument %qs to option %qs"
 msgstr "オプション %qs 内で認識できない引数です"
 
-#: config/i386/i386.c:3183
+#: config/i386/i386.c:3186
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr ""
 
-#: config/i386/i386.c:3193
+#: config/i386/i386.c:3196
 #, fuzzy, gcc-internal-format
 #| msgid "register name not specified for %q+D"
 msgid "wrong strategy name %qs specified for option %qs"
@@ -32686,47 +32729,47 @@
 msgstr "レジスタ名が %q+D 用に指定されていません"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3219
+#: config/i386/i386.c:3222
 #, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386.c:3232
+#: config/i386/i386.c:3235
 #, fuzzy, gcc-internal-format
 #| msgid "alignment may not be specified for %q+D"
 msgid "unknown alignment %qs specified for option %qs"
 msgstr "%q+D 用の整列が指定されていないようです"
 
-#: config/i386/i386.c:3242
+#: config/i386/i386.c:3245
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr ""
 
-#: config/i386/i386.c:3249
+#: config/i386/i386.c:3252
 #, fuzzy, gcc-internal-format
 #| msgid "no class name specified with %qs"
 msgid "too many size ranges specified in option %qs"
 msgstr "%qs にクラス名が指定されていません"
 
-#: config/i386/i386.c:3302
+#: config/i386/i386.c:3305
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unknown register name: %s"
 msgid "unknown parameter to option -mtune-ctrl: %s"
 msgstr "不明なレジスタ名です: %s"
 
-#: config/i386/i386.c:3726
+#: config/i386/i386.c:3729
 #, fuzzy, gcc-internal-format
 #| msgid "64-bit ABI not supported in ESA/390 mode"
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "64 ビット ABI は ESA/390 モード内ではサポートされていません"
 
-#: config/i386/i386.c:3775
+#: config/i386/i386.c:3778
 #, fuzzy, gcc-internal-format
 #| msgid "%stune=x86-64%s is deprecated; use %stune=k8%s or %stune=generic%s instead as appropriate"
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "%stune=x86-64%s は廃止されました。代わりに %stune=k8%s または %stune=generic%s の適切な方を使用してください"
 
-#: config/i386/i386.c:3777
+#: config/i386/i386.c:3780
 #, fuzzy, gcc-internal-format
 #| msgid "%stune=x86-64%s is deprecated; use %stune=k8%s or %stune=generic%s instead as appropriate"
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
@@ -32733,526 +32776,526 @@
 msgstr "%stune=x86-64%s は廃止されました。代わりに %stune=k8%s または %stune=generic%s の適切な方を使用してください"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3804
+#: config/i386/i386.c:3807
 #, gcc-internal-format
 msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386.c:3821
+#: config/i386/i386.c:3824
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in the %s bit mode"
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "コードモデル %qs は %s ビットモード内ではサポートされません"
 
-#: config/i386/i386.c:3833
+#: config/i386/i386.c:3836
 #, fuzzy, gcc-internal-format
 #| msgid "profiling not supported with -mg"
 msgid "-mabi=ms not supported with X32 ABI"
 msgstr "-mg でのプロファイルはサポートされていません"
 
-#: config/i386/i386.c:3851 config/i386/i386.c:3860 config/i386/i386.c:3872
-#: config/i386/i386.c:3883 config/i386/i386.c:3894
+#: config/i386/i386.c:3854 config/i386/i386.c:3863 config/i386/i386.c:3875
+#: config/i386/i386.c:3886 config/i386/i386.c:3897
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "コードモデル %qs は %s ビットモード内ではサポートされません"
 
-#: config/i386/i386.c:3863 config/i386/i386.c:3875
+#: config/i386/i386.c:3866 config/i386/i386.c:3878
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in the %s bit mode"
 msgid "code model %qs not supported in x32 mode"
 msgstr "コードモデル %qs は %s ビットモード内ではサポートされません"
 
-#: config/i386/i386.c:3881 config/i386/i386.c:3890 config/i386/i386.c:5213
+#: config/i386/i386.c:3884 config/i386/i386.c:3893 config/i386/i386.c:5216
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "コードモデル %s は PIC モードをサポートしません"
 
-#: config/i386/i386.c:3918
+#: config/i386/i386.c:3921
 #, fuzzy, gcc-internal-format
 #| msgid "-m%s not supported in this configuration"
 msgid "-masm=intel not supported in this configuration"
 msgstr "-m%s はこの設定ではサポートされていません"
 
-#: config/i386/i386.c:3923
+#: config/i386/i386.c:3926
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "%i ビットモードが使用できるようにコンパイルされていません"
 
-#: config/i386/i386.c:3932
+#: config/i386/i386.c:3935
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386.c:3934
+#: config/i386/i386.c:3937
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386.c:3941
+#: config/i386/i386.c:3944
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386.c:3943
+#: config/i386/i386.c:3946
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386.c:3951 config/i386/i386.c:4265
+#: config/i386/i386.c:3954 config/i386/i386.c:4268
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "選択した CPU は x86-64 命令セットをサポートしていません"
 
-#: config/i386/i386.c:4197 config/i386/i386.c:4200
+#: config/i386/i386.c:4200 config/i386/i386.c:4203
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "Intel MPX does not support x32"
 msgstr "%s は %s をサポートしません"
 
-#: config/i386/i386.c:4205
+#: config/i386/i386.c:4208
 #, fuzzy, gcc-internal-format
 msgid "bad value (%qs) for %<-march=%> switch"
 msgstr "-mcmodel= スイッチ用の誤った値 %s です"
 
-#: config/i386/i386.c:4206
+#: config/i386/i386.c:4209
 #, fuzzy, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"arch=\")%> attribute"
 msgstr "-mcmodel= スイッチ用の誤った値 %s です"
 
-#: config/i386/i386.c:4228
+#: config/i386/i386.c:4231
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
-#: config/i386/i386.c:4230
+#: config/i386/i386.c:4233
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4235
+#: config/i386/i386.c:4238
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
-#: config/i386/i386.c:4236
+#: config/i386/i386.c:4239
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
-#: config/i386/i386.c:4284
+#: config/i386/i386.c:4287
 #, fuzzy, gcc-internal-format
 msgid "bad value (%qs) for %<-mtune=%> switch"
 msgstr "-mtune スイッチ用の間違った値 %qs です"
 
-#: config/i386/i386.c:4285
+#: config/i386/i386.c:4288
 #, fuzzy, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"tune=\")%> attribute"
 msgstr "-mtune スイッチ用の間違った値 %qs です"
 
-#: config/i386/i386.c:4305
+#: config/i386/i386.c:4308
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
-#: config/i386/i386.c:4307
+#: config/i386/i386.c:4310
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4312
+#: config/i386/i386.c:4315
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
-#: config/i386/i386.c:4313
+#: config/i386/i386.c:4316
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
-#: config/i386/i386.c:4379
+#: config/i386/i386.c:4382
 #, fuzzy, gcc-internal-format
 #| msgid "%sregparm%s is ignored in 64-bit mode"
 msgid "-mregparm is ignored in 64-bit mode"
 msgstr "%sregparm%s は 64 ビットモードでは無視されます"
 
-#: config/i386/i386.c:4381
+#: config/i386/i386.c:4384
 #, gcc-internal-format
 msgid "-mregparm is ignored for Intel MCU psABI"
 msgstr ""
 
-#: config/i386/i386.c:4384
+#: config/i386/i386.c:4387
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%sregparm=%d%s is not between 0 and %d"
 msgid "-mregparm=%d is not between 0 and %d"
 msgstr "%sregparm=%d%s が 0 と %d の間ではありません"
 
-#: config/i386/i386.c:4417
+#: config/i386/i386.c:4420
 #, fuzzy, gcc-internal-format
 #| msgid "%srtd%s is ignored in 64bit mode"
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "%srtd%s は 64 ビットモードでは無視されます"
 
-#: config/i386/i386.c:4418
+#: config/i386/i386.c:4421
 #, fuzzy, gcc-internal-format
 #| msgid "%srtd%s is ignored in 64bit mode"
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "%srtd%s は 64 ビットモードでは無視されます"
 
-#: config/i386/i386.c:4497
+#: config/i386/i386.c:4500
 #, fuzzy, gcc-internal-format
 #| msgid "%spreferred-stack-boundary%s is not supported for this target"
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "%spreferred-stack-boundary%s はこのターゲットではサポートされていません"
 
-#: config/i386/i386.c:4500
+#: config/i386/i386.c:4503
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%spreferred-stack-boundary=%d%s is not between %d and %d"
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr "%spreferred-stack-boundary=%d%s が %d と %d の間ではありません"
 
-#: config/i386/i386.c:4523
+#: config/i386/i386.c:4526
 #, gcc-internal-format, gfc-internal-format
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr "-mincoming-stack-boundary=%d が %d と 12 の間ではありません"
 
-#: config/i386/i386.c:4536
+#: config/i386/i386.c:4539
 #, fuzzy, gcc-internal-format
 #| msgid "-mno-fentry isn%'t compatible with SEH"
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "-mno-fentry は SEH と互換性がありません"
 
-#: config/i386/i386.c:4539
+#: config/i386/i386.c:4542
 #, fuzzy, gcc-internal-format
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr "ret 命令は実装されていません"
 
-#: config/i386/i386.c:4545
+#: config/i386/i386.c:4548
 #, fuzzy, gcc-internal-format
 #| msgid "%ssseregparm%s used without SSE enabled"
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "%ssseregparm%s が SSE が有効ではない状態で使用されています"
 
-#: config/i386/i386.c:4546
+#: config/i386/i386.c:4549
 #, fuzzy, gcc-internal-format
 #| msgid "%ssseregparm%s used without SSE enabled"
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "%ssseregparm%s が SSE が有効ではない状態で使用されています"
 
-#: config/i386/i386.c:4556
+#: config/i386/i386.c:4559
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "SSE 命令セットが無効になっています。 387 数値演算を使用します"
 
-#: config/i386/i386.c:4563
+#: config/i386/i386.c:4566
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "387 命令セットが無効になっています。SSE 数値演算を使用します"
 
-#: config/i386/i386.c:4613
+#: config/i386/i386.c:4616
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr ""
 
-#: config/i386/i386.c:4615
+#: config/i386/i386.c:4618
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr ""
 
-#: config/i386/i386.c:4629
+#: config/i386/i386.c:4632
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr ""
 
-#: config/i386/i386.c:4631
+#: config/i386/i386.c:4634
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr ""
 
-#: config/i386/i386.c:4741
+#: config/i386/i386.c:4744
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr ""
 
-#: config/i386/i386.c:4744
+#: config/i386/i386.c:4747
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr "-mno-fentry は SEH と互換性がありません"
 
-#: config/i386/i386.c:4748
+#: config/i386/i386.c:4751
 #, gcc-internal-format
 msgid "-mcall-ms2sysv-xlogues isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386.c:4813 config/powerpcspe/powerpcspe.c:5663
+#: config/i386/i386.c:4816 config/powerpcspe/powerpcspe.c:5663
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown option for -mrecip=%s"
 msgstr "-mrecip=%s 用の不明なオプションです"
 
-#: config/i386/i386.c:4870 config/powerpcspe/powerpcspe.c:5339
+#: config/i386/i386.c:4873 config/powerpcspe/powerpcspe.c:5339
 #, gcc-internal-format
 msgid "%qs is not a valid number in -mstack-protector-guard-offset="
 msgstr ""
 
-#: config/i386/i386.c:4875 config/powerpcspe/powerpcspe.c:5344
+#: config/i386/i386.c:4878 config/powerpcspe/powerpcspe.c:5344
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid option to the preprocessor"
 msgid "%qs is not a valid offset in -mstack-protector-guard-offset="
 msgstr "%qs は前処理の有効なオプションではありません"
 
-#: config/i386/i386.c:4907 config/powerpcspe/powerpcspe.c:5356
+#: config/i386/i386.c:4910 config/powerpcspe/powerpcspe.c:5356
 #, gcc-internal-format
 msgid "%qs is not a valid base register in -mstack-protector-guard-reg="
 msgstr ""
 
-#: config/i386/i386.c:5506 config/i386/i386.c:5553 config/s390/s390.c:15812
+#: config/i386/i386.c:5509 config/i386/i386.c:5556 config/s390/s390.c:15812
 #: config/s390/s390.c:15862 config/s390/s390.c:15879
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr "attribute(target(\"%s\")) が不明です"
 
-#: config/i386/i386.c:5534
+#: config/i386/i386.c:5537
 #, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr "option(\"%s\") は既に指定されています"
 
-#: config/i386/i386.c:5837
+#: config/i386/i386.c:5840
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and cdecl attributes are not compatible"
 msgid "interrupt and naked attributes are not compatible"
 msgstr "stdcall と cdecl 属性は併用できません"
 
-#: config/i386/i386.c:5852
+#: config/i386/i386.c:5855
 #, gcc-internal-format
 msgid "Only DWARF debug format is supported for interrupt service routine."
 msgstr ""
 
-#: config/i386/i386.c:5901
+#: config/i386/i386.c:5904
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s と -mcall-%s は併用できません"
 
-#: config/i386/i386.c:5913
+#: config/i386/i386.c:5916
 #, gcc-internal-format
 msgid "%<-mindirect-branch=thunk-extern%>, %<-fcf-protection=branch%> and %<-fcheck-pointer-bounds%> are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5949
+#: config/i386/i386.c:5952
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s と -mcall-%s は併用できません"
 
-#: config/i386/i386.c:6047
+#: config/i386/i386.c:6050
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "2 byte cop instructions are not allowed in 64-bit VLIW mode"
 msgid "%s instructions aren't allowed in %s service routine"
 msgstr "2 バイト cop 命令は 64 ビット VLIW モードでは許可されていません"
 
-#: config/i386/i386.c:6051
+#: config/i386/i386.c:6054
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in function with no_caller_saved_registers attribute"
 msgstr ""
 
-#: config/i386/i386.c:6465 config/i386/i386.c:6516
+#: config/i386/i386.c:6468 config/i386/i386.c:6519
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "fastcall と regparm 属性は併用できません"
 
-#: config/i386/i386.c:6470
+#: config/i386/i386.c:6473
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "regparam と thiscall 属性は併用できません"
 
-#: config/i386/i386.c:6477 config/i386/i386.c:41444
+#: config/i386/i386.c:6480 config/i386/i386.c:41438
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "%qE 属性には整数定数引数が必要です"
 
-#: config/i386/i386.c:6483
+#: config/i386/i386.c:6486
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "%qE 属性への引数が %d より大きいです"
 
-#: config/i386/i386.c:6508 config/i386/i386.c:6551
+#: config/i386/i386.c:6511 config/i386/i386.c:6554
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "fastcall と cdecl 属性は併用できません"
 
-#: config/i386/i386.c:6512
+#: config/i386/i386.c:6515
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "fastcall と stdcall 属性は併用できません"
 
-#: config/i386/i386.c:6520 config/i386/i386.c:6569
+#: config/i386/i386.c:6523 config/i386/i386.c:6572
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "fastcall と thiscall 属性は併用できません"
 
-#: config/i386/i386.c:6530 config/i386/i386.c:6547
+#: config/i386/i386.c:6533 config/i386/i386.c:6550
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "stdcall と cdecl 属性は併用できません"
 
-#: config/i386/i386.c:6534
+#: config/i386/i386.c:6537
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "stdcall と fastcall 属性は併用できません"
 
-#: config/i386/i386.c:6538 config/i386/i386.c:6565
+#: config/i386/i386.c:6541 config/i386/i386.c:6568
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "stdcall と thiscall 属性は併用できません"
 
-#: config/i386/i386.c:6555 config/i386/i386.c:6573
+#: config/i386/i386.c:6558 config/i386/i386.c:6576
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "cdecl と thiscall 属性は併用できません"
 
-#: config/i386/i386.c:6561
+#: config/i386/i386.c:6564
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute is used for none class-method"
 msgid "%qE attribute is used for non-class method"
 msgstr "%qE 属性が非クラスメソッド用に使用されています"
 
-#: config/i386/i386.c:6805
+#: config/i386/i386.c:6808
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "SSE/SSE2 が有効でない状態で sseregparm 属性付きの %qD を呼び出しています"
 
-#: config/i386/i386.c:6808
+#: config/i386/i386.c:6811
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "SSE/SSE2 が有効でない状態で sseregparm 属性付きの %qT を呼び出しています<"
 
-#: config/i386/i386.c:7126
+#: config/i386/i386.c:7129
 #, fuzzy, gcc-internal-format
 #| msgid "does not support multilib"
 msgid "X32 does not support ms_abi attribute"
 msgstr "multilib はサポートしません"
 
-#: config/i386/i386.c:7160
+#: config/i386/i386.c:7163
 #, gcc-internal-format
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr "ms_hook_prologue は入れ子になった関数と両立できません"
 
-#: config/i386/i386.c:7502
+#: config/i386/i386.c:7505
 #, fuzzy, gcc-internal-format
 #| msgid "MMX vector argument without MMX enabled changes the ABI"
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr "MMX が有効でない状態での MMX ベクトル引数は ABI を変更します"
 
-#: config/i386/i386.c:7508
+#: config/i386/i386.c:7511
 #, fuzzy, gcc-internal-format
 #| msgid "MMX vector return without MMX enabled changes the ABI"
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr "MMX が有効でない状態での MMX ベクトル戻し (return) は ABI を変更します"
 
-#: config/i386/i386.c:7522
+#: config/i386/i386.c:7525
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7528
+#: config/i386/i386.c:7531
 #, fuzzy, gcc-internal-format
 #| msgid "MMX vector return without MMX enabled changes the ABI"
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr "MMX が有効でない状態での MMX ベクトル戻し (return) は ABI を変更します"
 
-#: config/i386/i386.c:7544
+#: config/i386/i386.c:7547
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr "SSE が有効でない状態での SSE ベクトル引数は ABI を変更します"
 
-#: config/i386/i386.c:7550
+#: config/i386/i386.c:7553
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr "SSE が有効でない状態での SSE ベクトル戻し (return) は ABI を変更します"
 
-#: config/i386/i386.c:7566
+#: config/i386/i386.c:7569
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr "MMX が有効でない状態での MMX ベクトル引数は ABI を変更します"
 
-#: config/i386/i386.c:7572
+#: config/i386/i386.c:7575
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr "MMX が有効でない状態での MMX ベクトル戻し (return) は ABI を変更します"
 
-#: config/i386/i386.c:7754
+#: config/i386/i386.c:7757
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr "可変長配列メンバを持つ構造体を渡す ABI は GCC 4.4 で変更になっています"
 
-#: config/i386/i386.c:7871
+#: config/i386/i386.c:7874
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr "long double を持つ共用体を渡す ABI は GCC 4.4 で変更になっています"
 
-#: config/i386/i386.c:7989
+#: config/i386/i386.c:7992
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr "複素浮動小数メンバを持つ構造体を渡す ABI は GCC 4.4 で変更になっています"
 
-#: config/i386/i386.c:8152
+#: config/i386/i386.c:8155
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr "SSE が無効の状態で SSE レジスタを戻して (return) います"
 
-#: config/i386/i386.c:8158
+#: config/i386/i386.c:8161
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr "SSE が無効の状態で SSE レジスタ引数があります"
 
-#: config/i386/i386.c:8174
+#: config/i386/i386.c:8177
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr "x87 が無効な状態で x87 レジスタを戻して (return) います"
 
-#: config/i386/i386.c:8471 config/i386/i386.c:8750 config/i386/i386.c:9276
+#: config/i386/i386.c:8474 config/i386/i386.c:8753 config/i386/i386.c:9279
 #, fuzzy, gcc-internal-format
 #| msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr "SSE/SSE2 が有効でない状態で sseregparm 属性付きの %qD を呼び出しています"
 
-#: config/i386/i386.c:8473 config/i386/i386.c:8752 config/i386/i386.c:9278
+#: config/i386/i386.c:8476 config/i386/i386.c:8755 config/i386/i386.c:9281
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr ""
 
-#: config/i386/i386.c:9178
+#: config/i386/i386.c:9181
 #, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr "%d バイト整列の仮引数を渡す ABI は GCC 4.6 で変更になっています"
 
-#: config/i386/i386.c:11601
+#: config/i386/i386.c:11604
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ms_hook_prologue is not compatible with nested function"
 msgid "-mcall-ms2sysv-xlogues is not compatible with %s"
 msgstr "ms_hook_prologue は入れ子になった関数と両立できません"
 
-#: config/i386/i386.c:13593
+#: config/i386/i386.c:13596
 #, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr "ms_hook_prologue 属性は 32 ビット用の -mfentry と併用できません"
 
-#: config/i386/i386.c:13683
+#: config/i386/i386.c:13686
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr ""
 
-#: config/i386/i386.c:14970
+#: config/i386/i386.c:14973
 #, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr ""
 
-#: config/i386/i386.c:14990
+#: config/i386/i386.c:14993
 #, fuzzy, gcc-internal-format
 #| msgid "%<-fsplit-stack%> is not supported by this compiler configuration"
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
@@ -33260,335 +33303,335 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:15001
+#: config/i386/i386.c:15004
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr ""
 
-#: config/i386/i386.c:17939
+#: config/i386/i386.c:17942
 #, gcc-internal-format
 msgid "'V' modifier on non-integer register"
 msgstr ""
 
-#: config/i386/i386.c:17950 config/i386/i386.c:17964
+#: config/i386/i386.c:17953 config/i386/i386.c:17967
 #, gcc-internal-format
 msgid "unsupported size for integer register"
 msgstr ""
 
-#: config/i386/i386.c:17996
+#: config/i386/i386.c:17999
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr ""
 
-#: config/i386/i386.c:18011
+#: config/i386/i386.c:18014
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr ""
 
-#: config/i386/i386.c:18202
+#: config/i386/i386.c:18205
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand type used with operand code '%c'"
 msgid "non-integer operand used with operand code 'z'"
 msgstr "被演算子コード '%c' に無効な被演算子型が使用されました"
 
-#: config/i386/i386.c:28467
+#: config/i386/i386.c:28470
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine can't be called directly"
 msgstr "割り込みサービスルーチンを Thumb モードでコード化することはできません"
 
-#: config/i386/i386.c:29995
+#: config/i386/i386.c:29998
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in -fabi-version=12 (GCC 8)"
 msgstr ""
 
-#: config/i386/i386.c:32435
+#: config/i386/i386.c:32438
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr ""
 
-#: config/i386/i386.c:32485
+#: config/i386/i386.c:32488
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for %s"
 msgstr ""
 
-#: config/i386/i386.c:32495
+#: config/i386/i386.c:32498
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr ""
 
-#: config/i386/i386.c:32657
+#: config/i386/i386.c:32660
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386.c:32662 config/i386/i386.c:32938
-#: config/rs6000/rs6000.c:37850
+#: config/i386/i386.c:32665 config/i386/i386.c:32941
+#: config/rs6000/rs6000.c:37906
 #, fuzzy, gcc-internal-format
 #| msgid "static linking is not supported"
 msgid "Virtual function multiversioning not supported"
 msgstr "静的リンクはサポートされていません"
 
-#: config/i386/i386.c:32795 config/rs6000/rs6000.c:37607
+#: config/i386/i386.c:32798 config/rs6000/rs6000.c:37663
 #, fuzzy, gcc-internal-format
 #| msgid "nested functions not supported on this target"
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "入れ子になった関数はこのターゲットではサポートされていません"
 
-#: config/i386/i386.c:33207
+#: config/i386/i386.c:33210
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs must be a 2-bit unsigned literal"
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr "%qs への引数は 2 ビット符号無しリテラルでなければいけません"
 
-#: config/i386/i386.c:33232 config/i386/i386.c:33282
+#: config/i386/i386.c:33235 config/i386/i386.c:33285
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "parameter %qD set but not used"
 msgid "Parameter to builtin not valid: %s"
 msgstr "仮引数 %qD が設定されましたが使用されません"
 
-#: config/i386/i386.c:33975 config/i386/i386.c:35415
+#: config/i386/i386.c:33978 config/i386/i386.c:35418
 #, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "最後の引数は 2 ビット即値でなければいけません"
 
-#: config/i386/i386.c:34370
+#: config/i386/i386.c:34373
 #, fuzzy, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "第五引数は 8 ビット即値でなければいけません"
 
-#: config/i386/i386.c:34465
+#: config/i386/i386.c:34468
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "第三引数は 8 ビット即値でなければいけません"
 
-#: config/i386/i386.c:35346
+#: config/i386/i386.c:35349
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 1-bit immediate"
 msgid "the last argument must be an 1-bit immediate"
 msgstr "最後の引数は 1 ビット即値でなければいけません"
 
-#: config/i386/i386.c:35361
+#: config/i386/i386.c:35364
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 32-bit immediate"
 msgid "the last argument must be a 3-bit immediate"
 msgstr "最後の引数は 32 ビット即値でなければいけません"
 
-#: config/i386/i386.c:35394
+#: config/i386/i386.c:35397
 #, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "最後の引数は 4 ビット即値でなければいけません"
 
-#: config/i386/i386.c:35434
+#: config/i386/i386.c:35437
 #, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "最後の引数は 1 ビット即値でなければいけません"
 
-#: config/i386/i386.c:35447
+#: config/i386/i386.c:35450
 #, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "最後の引数は 5 ビット即値でなければいけません"
 
-#: config/i386/i386.c:35457
+#: config/i386/i386.c:35460
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "最後の引数の前の引数は 8 ビット即値でなければいけません"
 
-#: config/i386/i386.c:35462 config/i386/i386.c:36249
+#: config/i386/i386.c:35465 config/i386/i386.c:36252
 #, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "最後の引数は 8 ビット即値でなければいけません"
 
-#: config/i386/i386.c:35596
+#: config/i386/i386.c:35599
 #, fuzzy, gcc-internal-format
 #| msgid "argument must be a constant"
 msgid "the third argument must be comparison constant"
 msgstr "引数は定数でなければいけません"
 
-#: config/i386/i386.c:35601
+#: config/i386/i386.c:35604
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect comparison mode"
 msgstr "正しくない命令:"
 
-#: config/i386/i386.c:35607 config/i386/i386.c:35814
+#: config/i386/i386.c:35610 config/i386/i386.c:35817
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect rounding operand"
 msgstr "正しくない命令:"
 
-#: config/i386/i386.c:35796
+#: config/i386/i386.c:35799
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 4-bit immediate"
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "最後の引数は 4 ビット即値でなければいけません"
 
-#: config/i386/i386.c:35802
+#: config/i386/i386.c:35805
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 5-bit immediate"
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "最後の引数は 5 ビット即値でなければいけません"
 
-#: config/i386/i386.c:35805
+#: config/i386/i386.c:35808
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be an 8-bit immediate"
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "最後の引数は 8 ビット即値でなければいけません"
 
-#: config/i386/i386.c:36247
+#: config/i386/i386.c:36250
 #, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "最後の引数は 32 ビット即値でなければいけません"
 
-#: config/i386/i386.c:36329 config/powerpcspe/powerpcspe.c:16219
-#: config/rs6000/rs6000.c:15304
+#: config/i386/i386.c:36332 config/powerpcspe/powerpcspe.c:16219
+#: config/rs6000/rs6000.c:15348
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr ""
 
-#: config/i386/i386.c:36539
+#: config/i386/i386.c:36542
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr ""
 
-#: config/i386/i386.c:36543
+#: config/i386/i386.c:36546
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "%qE は isa オプション %s が必要です"
 
-#: config/i386/i386.c:37381
+#: config/i386/i386.c:37375
 #, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "最後の引数は即値でなければいけません"
 
-#: config/i386/i386.c:38108 config/i386/i386.c:38290
+#: config/i386/i386.c:38102 config/i386/i386.c:38284
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 2-bit immediate"
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "最後の引数は 2 ビット即値でなければいけません"
 
-#: config/i386/i386.c:38343
+#: config/i386/i386.c:38337
 #, fuzzy, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "第五引数は 8 ビット即値でなければいけません"
 
-#: config/i386/i386.c:38349
+#: config/i386/i386.c:38343
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect hint operand"
 msgstr "正しくない命令:"
 
-#: config/i386/i386.c:38368
+#: config/i386/i386.c:38362
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be an 8-bit immediate"
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr "最後の引数は 8 ビット即値でなければいけません"
 
-#: config/i386/i386.c:41431
+#: config/i386/i386.c:41425
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "%qE 属性は 32 ビットでのみ使用できます"
 
-#: config/i386/i386.c:41452
+#: config/i386/i386.c:41446
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "%qE 属性への引数が 0 でも 1 でもありません"
 
-#: config/i386/i386.c:41485 config/i386/i386.c:41494
+#: config/i386/i386.c:41479 config/i386/i386.c:41488
 #, gcc-internal-format
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr "ms_abi と sysv_abi 属性は互換性がありません"
 
-#: config/i386/i386.c:41530 config/powerpcspe/powerpcspe.c:35868
-#: config/rs6000/rs6000.c:33065
+#: config/i386/i386.c:41524 config/powerpcspe/powerpcspe.c:35868
+#: config/rs6000/rs6000.c:33121
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "互換性がない %qE 属性は無視されました"
 
-#: config/i386/i386.c:41555 config/i386/i386.c:41577 config/ia64/ia64.c:815
+#: config/i386/i386.c:41549 config/i386/i386.c:41571 config/ia64/ia64.c:815
 #: config/s390/s390.c:1153
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "%qE 属性は文字列定数引数を必要とします"
 
-#: config/i386/i386.c:41565 config/i386/i386.c:41587 config/s390/s390.c:1182
+#: config/i386/i386.c:41559 config/i386/i386.c:41581 config/s390/s390.c:1182
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qE attribute is not a string constant"
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "%qE 属性の引数が文字列定数ではありません"
 
-#: config/i386/i386.c:41619
+#: config/i386/i386.c:41613
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386.c:41626
+#: config/i386/i386.c:41620
 #, gcc-internal-format, gfc-internal-format
 msgid "interrupt service routine should have unsigned %sint as the second argument"
 msgstr ""
 
-#: config/i386/i386.c:41636
+#: config/i386/i386.c:41630
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386.c:41639
+#: config/i386/i386.c:41633
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine can't have non-void return value"
 msgstr "割り込みサービスルーチンを Thumb モードでコード化することはできません"
 
-#: config/i386/i386.c:44676
+#: config/i386/i386.c:44670
 #, gcc-internal-format
 msgid "alternatives not allowed in asm flag output"
 msgstr ""
 
-#: config/i386/i386.c:44740
+#: config/i386/i386.c:44734
 #, fuzzy, gcc-internal-format
 #| msgid "unknown IRA algorithm %qs"
 msgid "unknown asm flag output %qs"
 msgstr "不明な IRA アルゴリズム %qs です"
 
-#: config/i386/i386.c:44769
+#: config/i386/i386.c:44763
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand output code"
 msgid "invalid type for asm flag output"
 msgstr "無効な被演算子出力コード"
 
-#: config/i386/i386.c:50634
+#: config/i386/i386.c:50628
 #, fuzzy, gcc-internal-format
 #| msgid "unknown architecture %qs"
 msgid "unknown architecture specific memory model"
 msgstr "不明なアーキテクチャ %qs です"
 
-#: config/i386/i386.c:50641
+#: config/i386/i386.c:50635
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50647
+#: config/i386/i386.c:50641
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50671 config/i386/i386.c:50787
+#: config/i386/i386.c:50665 config/i386/i386.c:50781
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "unsupported simdlen %d"
 msgstr "サポートされていない組み合わせです: %s"
 
-#: config/i386/i386.c:50690
+#: config/i386/i386.c:50684
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd"
 msgstr ""
 
-#: config/i386/i386.c:50712
+#: config/i386/i386.c:50706
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument type to builtin function"
 msgid "unsupported argument type %qT for simd"
 msgstr "組み込み関数へのサポートされていない引数の型です"
 
-#: config/i386/i386.c:51033
+#: config/i386/i386.c:51027
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr ""
@@ -33815,7 +33858,7 @@
 msgstr "interrupt_thread は fido 上でのみ使用出来ます"
 
 #: config/m68k/m68k.c:1128 config/powerpcspe/powerpcspe.c:28512
-#: config/rs6000/rs6000.c:25791
+#: config/rs6000/rs6000.c:25868
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "スタック制限式はサポートされていません"
@@ -34430,10 +34473,10 @@
 
 #. Trampoline is not supported on reduced-set registers yet.
 #: config/nds32/nds32.c:2327 config/nds32/nds32.c:2381
-#: config/nds32/nds32.c:3127 config/nds32/nds32.c:3201
-#: config/nds32/nds32.c:3216 config/nds32/nds32.c:3222
-#: config/nds32/nds32.c:3284 config/nds32/nds32.c:3290
-#: config/nds32/nds32.c:3322
+#: config/nds32/nds32.c:3128 config/nds32/nds32.c:3202
+#: config/nds32/nds32.c:3217 config/nds32/nds32.c:3223
+#: config/nds32/nds32.c:3285 config/nds32/nds32.c:3291
+#: config/nds32/nds32.c:3323
 #, fuzzy, gcc-internal-format
 #| msgid "nested functions not supported on this target"
 msgid "a nested function is not supported for reduced registers"
@@ -34440,54 +34483,54 @@
 msgstr "入れ子になった関数はこのターゲットではサポートされていません"
 
 #. The enum index value for array size is out of range.
-#: config/nds32/nds32.c:3025
+#: config/nds32/nds32.c:3026
 #, fuzzy, gcc-internal-format
 #| msgid "invalid register in the instruction"
 msgid "intrinsic register index is out of range"
 msgstr "命令に対して無効なレジスタです"
 
-#: config/nds32/nds32.c:3041 config/nds32/nds32.c:3048
-#: config/nds32/nds32.c:3055 config/nds32/nds32.c:3062
-#: config/nds32/nds32.c:3069
+#: config/nds32/nds32.c:3042 config/nds32/nds32.c:3049
+#: config/nds32/nds32.c:3056 config/nds32/nds32.c:3063
+#: config/nds32/nds32.c:3070
 #, fuzzy, gcc-internal-format
 msgid "CCTL intrinsic function subtype out of range!"
 msgstr "言語 %s は認識できません"
 
-#: config/nds32/nds32.c:3508
+#: config/nds32/nds32.c:3509
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute %qE"
 msgid "invalid id value for interrupt/exception attribute"
 msgstr "%qE 属性用としては無効なベクトル型です"
 
-#: config/nds32/nds32.c:3536
+#: config/nds32/nds32.c:3537
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "invalid id value for reset attribute"
 msgstr "%qs 属性の引数が無効です"
 
-#: config/nds32/nds32.c:3552
+#: config/nds32/nds32.c:3553
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "invalid nmi function for reset attribute"
 msgstr "%qs 属性の引数が無効です"
 
-#: config/nds32/nds32.c:3565
+#: config/nds32/nds32.c:3566
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "invalid warm function for reset attribute"
 msgstr "%qs 属性の引数が無効です"
 
-#: config/nds32/nds32.c:3638
+#: config/nds32/nds32.c:3639
 #, gcc-internal-format
 msgid "Disable FPU ISA, the ABI option must be enable '-mfloat-abi=soft'"
 msgstr ""
 
-#: config/nds32/nds32.c:3641
+#: config/nds32/nds32.c:3642
 #, gcc-internal-format
 msgid "'-mabi=2fp+' option only support when FPU available, must be enable '-mext-fpu-sp' or '-mext-fpu-dp'"
 msgstr ""
 
-#: config/nds32/nds32.c:3647
+#: config/nds32/nds32.c:3648
 #, fuzzy, gcc-internal-format
 #| msgid "Generate position-independent code if possible (large mode)"
 msgid "position-independent code not supported"
@@ -34840,12 +34883,12 @@
 msgid "junk at end of #pragma longcall"
 msgstr "#pragma longcall の末尾にゴミがあります"
 
-#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6154
+#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6152
 #, gcc-internal-format
 msgid "vec_lvsl is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6158
+#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6156
 #, gcc-internal-format
 msgid "vec_lvsr is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
@@ -34899,7 +34942,7 @@
 msgid "vec_insert only accepts 3 arguments"
 msgstr "vec_insert は 3 個の引数のみ受け付けます"
 
-#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6868
+#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6866
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE makes integer from pointer without a cast"
 msgid "passing arg %d of %qE discards qualifiers from pointer target type"
@@ -34988,7 +35031,7 @@
 msgid "target attribute or pragma changes SPE ABI"
 msgstr "target 属性または pragma が SPE ABI を変更します"
 
-#: config/powerpcspe/powerpcspe.c:4351 config/rs6000/rs6000.c:4223
+#: config/powerpcspe/powerpcspe.c:4351 config/rs6000/rs6000.c:4243
 #, gcc-internal-format
 msgid "AltiVec not supported in this target"
 msgstr ""
@@ -35136,7 +35179,7 @@
 msgid "-mvsx-small-integer requires -mpower8-vector, -mupper-regs-di, and -mdirect-move"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4959 config/rs6000/rs6000.c:4601
+#: config/powerpcspe/powerpcspe.c:4959 config/rs6000/rs6000.c:4628
 #, gcc-internal-format
 msgid "target attribute or pragma changes long double size"
 msgstr "target 属性または pragma が long double のサイズを変更します"
@@ -35177,22 +35220,22 @@
 msgstr "-mveclibabi= スイッチ用の不明なベクトルライブラリ ABI 型 (%s) です"
 
 #: config/powerpcspe/powerpcspe.c:5140 config/powerpcspe/powerpcspe.c:5155
-#: config/rs6000/rs6000.c:4766 config/rs6000/rs6000.c:4781
+#: config/rs6000/rs6000.c:4791 config/rs6000/rs6000.c:4806
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr "target 属性または pragma が AltiVec ABI を変更します"
 
-#: config/powerpcspe/powerpcspe.c:5168 config/rs6000/rs6000.c:4794
+#: config/powerpcspe/powerpcspe.c:5168 config/rs6000/rs6000.c:4819
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr "target 属性または pragma が darwin64 ABI を変更します"
 
-#: config/powerpcspe/powerpcspe.c:5234 config/rs6000/rs6000.c:4828
+#: config/powerpcspe/powerpcspe.c:5234 config/rs6000/rs6000.c:4853
 #, gcc-internal-format
 msgid "target attribute or pragma changes single precision floating point"
 msgstr "target 属性または pragma が単精度浮動小数点を変更します"
 
-#: config/powerpcspe/powerpcspe.c:5237 config/rs6000/rs6000.c:4831
+#: config/powerpcspe/powerpcspe.c:5237 config/rs6000/rs6000.c:4856
 #, gcc-internal-format
 msgid "target attribute or pragma changes double precision floating point"
 msgstr "target 属性または pragma が倍精度浮動小数点を変更します"
@@ -35202,13 +35245,13 @@
 msgid "-mstack-protector-guard=tls needs a valid base register"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:8415 config/rs6000/rs6000.c:7925
+#: config/powerpcspe/powerpcspe.c:8415 config/rs6000/rs6000.c:7950
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr "%d バイト整列の仮引数を渡す ABI は GCC 4.6 で変更になっています"
 
-#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11237
+#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11269
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
@@ -35218,7 +35261,7 @@
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11595
+#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11633
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
@@ -35229,13 +35272,13 @@
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12604
+#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12648
 #, fuzzy, gcc-internal-format
 #| msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr "複素浮動小数メンバを持つ構造体を渡す ABI は GCC 4.4 で変更になっています"
 
-#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12779
+#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12823
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
@@ -35246,30 +35289,30 @@
 msgid "internal error: builtin function %s already processed"
 msgstr "内部エラー: %s への組み込み関数は既に処理されています"
 
-#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:13971
+#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:14015
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "argument 1 must be an 8-bit field value"
 msgstr "第一引数は 5 ビット符号付きリテラルでなければいけません"
 
-#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14015
+#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14059
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "第一引数は 5 ビット符号付きリテラルでなければいけません"
 
 #: config/powerpcspe/powerpcspe.c:14934 config/powerpcspe/powerpcspe.c:16803
-#: config/rs6000/rs6000.c:14101
+#: config/rs6000/rs6000.c:14145
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "第二引数は 5 ビット符号無しリテラルでなければいけません"
 
-#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14119
+#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14163
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "第二引数は 5 ビット符号無しリテラルでなければいけません"
 
-#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14135
+#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14179
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 7-bit unsigned literal"
@@ -35291,13 +35334,13 @@
 msgid "builtin %s is only valid in 64-bit mode"
 msgstr "%srtd%s は 64 ビットモードでは無視されます"
 
-#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14791
+#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14835
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument %d must be an unsigned literal"
 msgstr "第二引数は 5 ビット符号無しリテラルでなければいけません"
 
-#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14793
+#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14837
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument %d is an unsigned literal that is out of range"
@@ -35323,58 +35366,58 @@
 msgid "hwcap %s is an invalid argument to builtin %s"
 msgstr "%qs は -mcpu= への引数としては無効です"
 
-#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15065
+#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15109
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "第三引数は 4 ビット符号無しリテラルでなければいけません"
 
-#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15090
+#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15134
 #, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "第三引数は 2 ビット符号無しリテラルでなければいけません"
 
-#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15110
+#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15154
 #, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "第三引数は 1 ビット符号無しリテラルでなければいけません"
 
-#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15122
+#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15166
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "argument 1 must be 0 or 2"
 msgstr "数値は 0 または 1 でなければいけません"
 
-#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15134
+#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15178
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 1-bit unsigned literal"
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "第三引数は 1 ビット符号無しリテラルでなければいけません"
 
-#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15148
+#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15192
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "第二引数は 5 ビット符号無しリテラルでなければいけません"
 
-#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15160
+#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15204
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "argument 2 must be 0 or 1"
 msgstr "数値は 0 または 1 でなければいけません"
 
-#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15168
+#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15212
 #, fuzzy, gcc-internal-format
 #| msgid "argument %d of %qE must be in the range %d...%d"
 msgid "argument 3 must be in the range 0..15"
 msgstr "%d 番目の %qE の引数は %d...%d の範囲でなければいけません"
 
-#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15237
-#: config/rs6000/rs6000.c:15569
+#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15281
+#: config/rs6000/rs6000.c:15613
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "%qs への引数は 2 ビット符号無しリテラルでなければいけません"
 
-#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15394
+#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15438
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr ""
@@ -35515,7 +35558,7 @@
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr "内部エラー: 組み込み関数 %s の第 %d 引数が予期しない引数型 %s を持っています"
 
-#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25758
+#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25835
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr "スタックフレームが大きすぎます"
@@ -35525,13 +35568,13 @@
 msgid "-fsplit-stack uses register r29"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29459
+#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29536
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC target is not supported for this machine"
 msgid "Stack frame larger than 2G is not supported for -fsplit-stack"
 msgstr "#pragma GCC target はこのマシン用にはサポートされていません"
 
-#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30447
+#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30524
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr ""
@@ -35541,22 +35584,22 @@
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32830
+#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32907
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "AltiVec 型内での %<long double%> の使用は無効です"
 
-#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32832
+#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32909
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "AltiVec 型内での真偽型 (boolean) の使用は無効です"
 
-#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32834
+#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32911
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "AltiVec 型内での %<complex%> の使用は無効です"
 
-#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32836
+#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32913
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr "AltiVec 型内での十進浮動小数点の使用は無効です"
@@ -35566,7 +35609,7 @@
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr "-mvsx 無しで 64 ビットコード用の AltiVec 型内での %<long%> の使用は無効です"
 
-#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32845
+#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32922
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "AltiVec 型内での %<long%> の使用は廃止されました。%<int%> を使用してください"
@@ -36122,79 +36165,79 @@
 "Please use an explicit cpu name.  Valid cpu names are: %s"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6168 config/rs6000/rs6000-c.c:6219
-#: config/rs6000/rs6000-c.c:6489 config/rs6000/rs6000-c.c:6555
-#: config/rs6000/rs6000-c.c:6916 config/rs6000/rs6000-c.c:6963
+#: config/rs6000/rs6000-c.c:6166 config/rs6000/rs6000-c.c:6217
+#: config/rs6000/rs6000-c.c:6487 config/rs6000/rs6000-c.c:6553
+#: config/rs6000/rs6000-c.c:6914 config/rs6000/rs6000-c.c:6961
 #, fuzzy, gcc-internal-format
 #| msgid "%s only accepts 2 arguments"
 msgid "builtin %qs only accepts 2 arguments"
 msgstr "%s は 2 この引数のみ受け付けます"
 
-#: config/rs6000/rs6000-c.c:6292 config/rs6000/rs6000-c.c:6375
-#: config/rs6000/rs6000-c.c:6736
+#: config/rs6000/rs6000-c.c:6290 config/rs6000/rs6000-c.c:6373
+#: config/rs6000/rs6000-c.c:6734
 #, fuzzy, gcc-internal-format
 #| msgid "%s only accepts 2 arguments"
 msgid "builtin %qs only accepts 3 arguments"
 msgstr "%s は 2 この引数のみ受け付けます"
 
-#: config/rs6000/rs6000-c.c:6484
+#: config/rs6000/rs6000-c.c:6482
 #, fuzzy, gcc-internal-format
 #| msgid "%s only accepts 1 argument"
 msgid "builtin %qs only accepts 1 argument"
 msgstr "%s は 1 個の引数のみ受け付けます"
 
-#: config/rs6000/rs6000-c.c:7054
+#: config/rs6000/rs6000-c.c:7052
 #, gcc-internal-format
 msgid "builtin %qs requires builtin %qs"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:7058
+#: config/rs6000/rs6000-c.c:7056
 #, fuzzy, gcc-internal-format
 #| msgid "ifunc is not supported in this configuration"
 msgid "builtin function %qs not supported in this compiler configuration"
 msgstr "ifunc はこの設定ではサポートされていません"
 
-#: config/rs6000/rs6000-c.c:7068
+#: config/rs6000/rs6000-c.c:7066
 #, gcc-internal-format
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3754 config/rs6000/rs6000.c:3757
-#: config/rs6000/rs6000.c:3760
+#: config/rs6000/rs6000.c:3772 config/rs6000/rs6000.c:3775
+#: config/rs6000/rs6000.c:3778
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is predetermined %qs for %qs"
 msgid "%qs requires %qs or %qs"
 msgstr "%qE は %qs (%qs 用) として前もって決められています"
 
-#: config/rs6000/rs6000.c:3861
+#: config/rs6000/rs6000.c:3879
 #, fuzzy, gcc-internal-format
 #| msgid "-maix64 requires PowerPC64 architecture remain enabled"
 msgid "%qs requires PowerPC64 architecture, enabling"
 msgstr "-maix64 は PowerPC64 アーキテクチャが有効のまま残されていることが必要です"
 
-#: config/rs6000/rs6000.c:4037
+#: config/rs6000/rs6000.c:4057
 #, gcc-internal-format
 msgid "%qs command-line option is deprecated"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4048
+#: config/rs6000/rs6000.c:4068
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-power is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgid "%qs is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr "-malign-power は 64 ビット Darwin ではサポートされていません。インストールされている C および C++ ライブラリと互換性がありません"
 
-#: config/rs6000/rs6000.c:4147
+#: config/rs6000/rs6000.c:4167
 #, gcc-internal-format
 msgid "will not generate %qs instructions because assembler lacks %qs support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4240
+#: config/rs6000/rs6000.c:4260
 #, fuzzy, gcc-internal-format
 #| msgid "-mstring is not supported on little endian systems"
 msgid "%qs is not supported on little endian systems"
 msgstr "-mstring はリトルエンディアンシステム上ではサポートされていません"
 
-#: config/rs6000/rs6000.c:4333
+#: config/rs6000/rs6000.c:4353
 #, gcc-internal-format
 msgid "power9 target option is incompatible with %<%s=<xxx>%> for <xxx> less than power9"
 msgstr ""
@@ -36201,7 +36244,7 @@
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:4341
+#: config/rs6000/rs6000.c:4361
 #, fuzzy, gcc-internal-format
 #| msgid "-mcmodel incompatible with other toc options"
 msgid "%qs incompatible with explicitly disabled options"
@@ -36211,127 +36254,127 @@
 #. error messages.  However, if users have managed to select
 #. power9-fusion without selecting power8-fusion, they
 #. already know about undocumented flags.
-#: config/rs6000/rs6000.c:4366 config/rs6000/rs6000.c:4373
-#: config/rs6000/rs6000.c:4380 config/rs6000/rs6000.c:4388
-#: config/rs6000/rs6000.c:4407 config/rs6000/rs6000.c:4464
-#: config/rs6000/rs6000.c:4468 config/rs6000/rs6000.c:4485
-#: config/rs6000/rs6000.c:4538 config/rs6000/rs6000.c:4565
-#: config/rs6000/rs6000.c:4580 config/rs6000/rs6000.c:4588
-#: config/rs6000/rs6000.c:4684
+#: config/rs6000/rs6000.c:4386 config/rs6000/rs6000.c:4393
+#: config/rs6000/rs6000.c:4400 config/rs6000/rs6000.c:4408
+#: config/rs6000/rs6000.c:4427 config/rs6000/rs6000.c:4484
+#: config/rs6000/rs6000.c:4488 config/rs6000/rs6000.c:4505
+#: config/rs6000/rs6000.c:4558 config/rs6000/rs6000.c:4585
+#: config/rs6000/rs6000.c:4600 config/rs6000/rs6000.c:4608
+#: config/rs6000/rs6000.c:4709
 #, gcc-internal-format
 msgid "%qs requires %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4625
+#: config/rs6000/rs6000.c:4650
 #, fuzzy, gcc-internal-format
 #| msgid "using IEEE extended precision long double"
 msgid "Using IEEE extended precision long double"
 msgstr "IEEE 拡張精度 long double を使用しています"
 
-#: config/rs6000/rs6000.c:4627
+#: config/rs6000/rs6000.c:4652
 #, fuzzy, gcc-internal-format
 #| msgid "using IBM extended precision long double"
 msgid "Using IBM extended precision long double"
 msgstr "IBM 拡張精度 long double を使用しています"
 
-#: config/rs6000/rs6000.c:4644
+#: config/rs6000/rs6000.c:4669
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "%qs requires VSX support"
 msgstr "%s は %s をサポートしません"
 
-#: config/rs6000/rs6000.c:4653
+#: config/rs6000/rs6000.c:4678
 #, gcc-internal-format
 msgid "The -mfloat128 option may not be fully supported"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4676
+#: config/rs6000/rs6000.c:4701
 #, gcc-internal-format
 msgid "%qs requires full ISA 3.0 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4743
+#: config/rs6000/rs6000.c:4768
 #, fuzzy, gcc-internal-format
 #| msgid "unknown vectorization library ABI type (%s) for -mveclibabi= switch"
 msgid "unknown vectorization library ABI type (%qs) for %qs switch"
 msgstr "-mveclibabi= スイッチ用の不明なベクトルライブラリ ABI 型 (%s) です"
 
-#: config/rs6000/rs6000.c:4930
+#: config/rs6000/rs6000.c:4955
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "%qs is not a valid number in %qs"
 msgstr "%qs は %qs 用には有効ではありません"
 
-#: config/rs6000/rs6000.c:4935
+#: config/rs6000/rs6000.c:4960
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "%qs is not a valid offset in %qs"
 msgstr "%qs は %qs 用には有効ではありません"
 
-#: config/rs6000/rs6000.c:4947
+#: config/rs6000/rs6000.c:4972
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "%qs is not a valid base register in %qs"
 msgstr "%qs は %qs 用には有効ではありません"
 
-#: config/rs6000/rs6000.c:4955
+#: config/rs6000/rs6000.c:4980
 #, fuzzy, gcc-internal-format
 #| msgid "can%'t use %qs as a call-used register"
 msgid "%qs needs a valid base register"
 msgstr "%qs を呼び出しで使用されるレジスタとして使用できません"
 
-#: config/rs6000/rs6000.c:5253
+#: config/rs6000/rs6000.c:5278
 #, fuzzy, gcc-internal-format
 #| msgid "unknown option for -mrecip=%s"
 msgid "unknown option for %<%s=%s%>"
 msgstr "-mrecip=%s 用の不明なオプションです"
 
-#: config/rs6000/rs6000.c:5290
+#: config/rs6000/rs6000.c:5315
 #, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11401
+#: config/rs6000/rs6000.c:11439
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11862
+#: config/rs6000/rs6000.c:11906
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13572
+#: config/rs6000/rs6000.c:13616
 #, fuzzy, gcc-internal-format
 #| msgid "internal error: builtin function to %s already processed"
 msgid "internal error: builtin function %qs already processed"
 msgstr "内部エラー: %s への組み込み関数は既に処理されています"
 
-#: config/rs6000/rs6000.c:14150
+#: config/rs6000/rs6000.c:14194
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 1-bit unsigned literal"
 msgstr "第二引数は 5 ビット符号無しリテラルでなければいけません"
 
-#: config/rs6000/rs6000.c:14189
+#: config/rs6000/rs6000.c:14233
 #, fuzzy, gcc-internal-format
 #| msgid "argument must be a constant"
 msgid "argument 1 of %qs must be a constant"
 msgstr "引数は定数でなければいけません"
 
-#: config/rs6000/rs6000.c:14247 config/rs6000/rs6000.c:15898
+#: config/rs6000/rs6000.c:14291 config/rs6000/rs6000.c:15942
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument 1 of %qs is out of range"
 msgstr "__builtin_spe_predicate の第一引数が範囲外です"
 
-#: config/rs6000/rs6000.c:14742
+#: config/rs6000/rs6000.c:14786
 #, fuzzy, gcc-internal-format
 #| msgid "%srtd%s is ignored in 64bit mode"
 msgid "builtin %qs is only valid in 64-bit mode"
 msgstr "%srtd%s は 64 ビットモードでは無視されます"
 
-#: config/rs6000/rs6000.c:14939
+#: config/rs6000/rs6000.c:14983
 #, fuzzy, gcc-internal-format
 #| msgid "%s only accepts 1 argument"
 msgid "builtin %qs only accepts a string argument"
@@ -36338,7 +36381,7 @@
 msgstr "%s は 1 個の引数のみ受け付けます"
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000.c:14958
+#: config/rs6000/rs6000.c:15002
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is an invalid argument to -mcpu="
 msgid "cpu %qs is an invalid argument to builtin %qs"
@@ -36345,140 +36388,141 @@
 msgstr "%qs は -mcpu= への引数としては無効です"
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000.c:14986
+#: config/rs6000/rs6000.c:15030
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is an invalid argument to -mcpu="
 msgid "%s %qs is an invalid argument to builtin %qs"
 msgstr "%qs は -mcpu= への引数としては無効です"
 
-#: config/rs6000/rs6000.c:15012
+#: config/rs6000/rs6000.c:15056
 #, gcc-internal-format
 msgid "builtin %qs needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15616
+#: config/rs6000/rs6000.c:15660
 #, fuzzy, gcc-internal-format
 #| msgid "second argument of %q+D should be %<char **%>"
 msgid "second argument to %qs must be 0..12"
 msgstr "%q+D の第二引数は %<char **%> であるべきです"
 
-#: config/rs6000/rs6000.c:15631
+#: config/rs6000/rs6000.c:15675
 #, fuzzy, gcc-internal-format
 #| msgid "valid arguments to %qs are: %s"
 msgid "third argument to %qs must be 0..12"
 msgstr "%qs への有効な引数は次の通りです: %s"
 
-#: config/rs6000/rs6000.c:15850
+#: config/rs6000/rs6000.c:15894
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument must be a constant"
 msgid "argument 1 of %s must be a constant"
 msgstr "引数は定数でなければいけません"
 
-#: config/rs6000/rs6000.c:15932
+#: config/rs6000/rs6000.c:15976
 #, fuzzy, gcc-internal-format
 #| msgid "this builtin function is only available on the fr450"
 msgid "builtin function %qs is only valid for the cell processor"
 msgstr "この組み込み関数は fr450 上でのみ利用できます"
 
-#: config/rs6000/rs6000.c:15934 config/rs6000/rs6000.c:15936
-#: config/rs6000/rs6000.c:15938 config/rs6000/rs6000.c:15940
-#: config/rs6000/rs6000.c:15946 config/rs6000/rs6000.c:15948
-#: config/rs6000/rs6000.c:15955 config/rs6000/rs6000.c:15962
-#: config/rs6000/rs6000.c:15969 config/rs6000/rs6000.c:15975
+#: config/rs6000/rs6000.c:15978 config/rs6000/rs6000.c:15980
+#: config/rs6000/rs6000.c:15982 config/rs6000/rs6000.c:15984
+#: config/rs6000/rs6000.c:15990 config/rs6000/rs6000.c:15992
+#: config/rs6000/rs6000.c:15999 config/rs6000/rs6000.c:16006
+#: config/rs6000/rs6000.c:16011 config/rs6000/rs6000.c:16014
+#: config/rs6000/rs6000.c:16018 config/rs6000/rs6000.c:16024
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
 msgid "builtin function %qs requires the %qs option"
 msgstr "組み込み関数 %qD は %<-mconstant-cfstrings%> フラグを要求します"
 
-#: config/rs6000/rs6000.c:15943 config/rs6000/rs6000.c:15952
-#: config/rs6000/rs6000.c:15959 config/rs6000/rs6000.c:15966
+#: config/rs6000/rs6000.c:15987 config/rs6000/rs6000.c:15996
+#: config/rs6000/rs6000.c:16003
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
 msgid "builtin function %qs requires the %qs and %qs options"
 msgstr "組み込み関数 %qD は %<-mconstant-cfstrings%> フラグを要求します"
 
-#: config/rs6000/rs6000.c:15972
+#: config/rs6000/rs6000.c:16021
 #, gcc-internal-format
 msgid "builtin function %qs requires ISA 3.0 IEEE 128-bit floating point"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15978
+#: config/rs6000/rs6000.c:16027
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
 msgid "builtin function %qs requires the %qs (or newer), and %qs or %qs options"
 msgstr "組み込み関数 %qD は %<-mconstant-cfstrings%> フラグを要求します"
 
-#: config/rs6000/rs6000.c:15982
+#: config/rs6000/rs6000.c:16031
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %qE not supported for MIPS16"
 msgid "builtin function %qs is not supported with the current options"
 msgstr "組み込み関数 %qE は MIPS16 用にはサポートされていません"
 
-#: config/rs6000/rs6000.c:18218
+#: config/rs6000/rs6000.c:18290
 #, fuzzy, gcc-internal-format
 #| msgid "internal error: builtin function %s had an unexpected return type %s"
 msgid "internal error: builtin function %qs had an unexpected return type %qs"
 msgstr "内部エラー: 組み込み関数 %s が予期しない戻り型 %s を持っています"
 
-#: config/rs6000/rs6000.c:18235
+#: config/rs6000/rs6000.c:18307
 #, fuzzy, gcc-internal-format
 #| msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgid "internal error: builtin function %qs, argument %d had unexpected argument type %qs"
 msgstr "内部エラー: 組み込み関数 %s の第 %d 引数が予期しない引数型 %s を持っています"
 
-#: config/rs6000/rs6000.c:29451
+#: config/rs6000/rs6000.c:29528
 #, fuzzy, gcc-internal-format
 #| msgid "Use registers r2 and r5"
 msgid "%qs uses register r29"
 msgstr "レジスタ r2 と r5 を使用する"
 
-#: config/rs6000/rs6000.c:32748
+#: config/rs6000/rs6000.c:32825
 #, fuzzy, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "`this' は右辺値式であり、そのアドレスを取ることはできません"
 
-#: config/rs6000/rs6000.c:32842
+#: config/rs6000/rs6000.c:32919
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "-mvsx 無しで 64 ビットコード用の AltiVec 型内での %<long%> の使用は無効です"
 
-#: config/rs6000/rs6000.c:32850
+#: config/rs6000/rs6000.c:32927
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long long%> in AltiVec types is invalid without -mvsx"
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "-mvsx 無しで AltiVec 型内での %<long long%> の使用は無効です"
 
-#: config/rs6000/rs6000.c:32853
+#: config/rs6000/rs6000.c:32930
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<double%> in AltiVec types is invalid without -mvsx"
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "-mvsx 無しで AltiVec 型内での %<double%> の使用は無効です"
 
-#: config/rs6000/rs6000.c:36876
+#: config/rs6000/rs6000.c:36932
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cpu \"%s\" for %s\"%s\"%s"
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "CPU \"%s\" は %s\"%s\"%s 用には無効です"
 
-#: config/rs6000/rs6000.c:36879
+#: config/rs6000/rs6000.c:36935
 #, fuzzy, gcc-internal-format
 #| msgid "%s\"%s\"%s is not allowed"
 msgid "%s%qs%s is not allowed"
 msgstr "%s\"%s\"%s は許可されていません"
 
-#: config/rs6000/rs6000.c:36881
+#: config/rs6000/rs6000.c:36937
 #, fuzzy, gcc-internal-format
 #| msgid "%s\"%s\"%s is invalid"
 msgid "%s%qs%s is invalid"
 msgstr "%s\"%s\"%s は無効です"
 
-#: config/rs6000/rs6000.c:37416
+#: config/rs6000/rs6000.c:37472
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:37575
+#: config/rs6000/rs6000.c:37631
 #, gcc-internal-format
 msgid "target_clones attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
@@ -37259,49 +37303,49 @@
 msgid "subprogram %q+F not marked Inline"
 msgstr ""
 
-#: ada/gcc-interface/trans.c:6404
+#: ada/gcc-interface/trans.c:6401
 #, gcc-internal-format
 msgid "out-of-bounds access may be optimized away"
 msgstr ""
 
-#: ada/gcc-interface/trans.c:6406
+#: ada/gcc-interface/trans.c:6403
 #, gcc-internal-format
 msgid "containing loop"
 msgstr ""
 
-#: ada/gcc-interface/utils.c:3887
+#: ada/gcc-interface/utils.c:3890
 #, gcc-internal-format
 msgid "invalid element type for attribute %qs"
 msgstr "%qs 属性用の無効なエレメント型です"
 
-#: ada/gcc-interface/utils.c:3911
+#: ada/gcc-interface/utils.c:3914
 #, fuzzy, gcc-internal-format
 #| msgid "number of components of the vector not a power of two"
 msgid "number of components of vector not a power of two"
 msgstr "ベクトルの要素の数が 2 の累乗ではありません"
 
-#: ada/gcc-interface/utils.c:6037 ada/gcc-interface/utils.c:6215
-#: ada/gcc-interface/utils.c:6322
+#: ada/gcc-interface/utils.c:6043 ada/gcc-interface/utils.c:6220
+#: ada/gcc-interface/utils.c:6327
 #, gcc-internal-format
 msgid "%qs attribute ignored"
 msgstr "%qs 属性が無視されました"
 
-#: ada/gcc-interface/utils.c:6158
+#: ada/gcc-interface/utils.c:6164
 #, gcc-internal-format
 msgid "%qs attribute requires prototypes with named arguments"
 msgstr "%qs 属性は名前付き引数を持つプロトタイプが必要です"
 
-#: ada/gcc-interface/utils.c:6167
+#: ada/gcc-interface/utils.c:6173
 #, gcc-internal-format
 msgid "%qs attribute only applies to variadic functions"
 msgstr ""
 
-#: ada/gcc-interface/utils.c:6282
+#: ada/gcc-interface/utils.c:6287
 #, gcc-internal-format
 msgid "%qE attribute has no effect"
 msgstr "%qE 属性は効果がありません"
 
-#: ada/gcc-interface/utils.c:6406
+#: ada/gcc-interface/utils.c:6411
 #, gcc-internal-format
 msgid "attribute %qs applies to array types only"
 msgstr "%qs 属性は配列型のみに適用できます"
@@ -37317,7 +37361,7 @@
 #. an unprototyped function, it is compile-time undefined;
 #. making it a constraint in that case was rejected in
 #. DR#252.
-#: c/c-convert.c:101 c/c-typeck.c:2175 c/c-typeck.c:6507 c/c-typeck.c:12138
+#: c/c-convert.c:101 c/c-typeck.c:2175 c/c-typeck.c:6512 c/c-typeck.c:12143
 #: cp/typeck.c:2027 cp/typeck.c:7977 cp/typeck.c:8742
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
@@ -37378,7 +37422,7 @@
 msgid "type of array %q+D completed incompatibly with implicit initialization"
 msgstr ""
 
-#: c/c-decl.c:1567 c/c-decl.c:6701 c/c-decl.c:7574 c/c-decl.c:8381
+#: c/c-decl.c:1567 c/c-decl.c:6721 c/c-decl.c:7594 c/c-decl.c:8401
 #, gcc-internal-format
 msgid "originally defined here"
 msgstr "元々はここで定義されました"
@@ -37791,16 +37835,11 @@
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.c:4548 c/c-decl.c:7147
+#: c/c-decl.c:4548 c/c-decl.c:7167
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr "%<[*]%> は関数プロトタイプスコープ以外では許可されていません"
 
-#: c/c-decl.c:4635 cp/decl2.c:1520
-#, gcc-internal-format
-msgid "%q+D in declare target directive does not have mappable type"
-msgstr ""
-
 #: c/c-decl.c:4693
 #, gcc-internal-format
 msgid "%q+D is usually a function"
@@ -37826,7 +37865,7 @@
 #. of VLAs themselves count as VLAs, it does not make
 #. sense to permit them to be initialized given that
 #. ordinary VLAs may not be initialized.
-#: c/c-decl.c:4732 c/c-decl.c:4747 c/c-typeck.c:7630
+#: c/c-decl.c:4732 c/c-decl.c:4747 c/c-typeck.c:7635
 #, gcc-internal-format
 msgid "variable-sized object may not be initialized"
 msgstr "可変長オブジェクトが初期化されないようです"
@@ -37886,205 +37925,210 @@
 msgid "uninitialized const %qD is invalid in C++"
 msgstr "初期化されていない定数 %qD は C++ 内では無効です"
 
-#: c/c-decl.c:5268
+#: c/c-decl.c:5224 cp/decl.c:7318
 #, gcc-internal-format
+msgid "%q+D in declare target directive does not have mappable type"
+msgstr ""
+
+#: c/c-decl.c:5288
+#, gcc-internal-format
 msgid "ISO C forbids forward parameter declarations"
 msgstr "ISO C は前方仮引数宣言を禁じます"
 
-#: c/c-decl.c:5371
+#: c/c-decl.c:5391
 #, gcc-internal-format
 msgid "defining a type in a compound literal is invalid in C++"
 msgstr "複合リテラル内での型定義は C++ では無効です"
 
-#: c/c-decl.c:5425 c/c-decl.c:5440
+#: c/c-decl.c:5445 c/c-decl.c:5460
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant"
 msgstr "ビットフィールド %qs の幅が整数定数ではありません"
 
-#: c/c-decl.c:5435
+#: c/c-decl.c:5455
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant expression"
 msgstr "ビットフィールド %qs の幅が整数定数式ではありません"
 
-#: c/c-decl.c:5446
+#: c/c-decl.c:5466
 #, gcc-internal-format
 msgid "negative width in bit-field %qs"
 msgstr "ビットフィールド %qs の幅が負です"
 
-#: c/c-decl.c:5451
+#: c/c-decl.c:5471
 #, gcc-internal-format
 msgid "zero width for bit-field %qs"
 msgstr "ビットフィールド %qs の幅が 0 です"
 
-#: c/c-decl.c:5461
+#: c/c-decl.c:5481
 #, gcc-internal-format
 msgid "bit-field %qs has invalid type"
 msgstr "ビットフィールド %qs が無効な型を持っています"
 
-#: c/c-decl.c:5467
+#: c/c-decl.c:5487
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare bit-field %qD with function type"
 msgid "cannot declare bit-field %qs with %<warn_if_not_aligned%> type"
 msgstr "ビットフィールド %qD を関数型として宣言できません"
 
-#: c/c-decl.c:5478
+#: c/c-decl.c:5498
 #, gcc-internal-format
 msgid "type of bit-field %qs is a GCC extension"
 msgstr "ビットフィールド %qs の型は GCC 拡張です"
 
-#: c/c-decl.c:5484
+#: c/c-decl.c:5504
 #, gcc-internal-format
 msgid "width of %qs exceeds its type"
 msgstr "%qs の幅がそのサイズを超えています"
 
-#: c/c-decl.c:5497
+#: c/c-decl.c:5517
 #, gcc-internal-format
 msgid "%qs is narrower than values of its type"
 msgstr "%qs の幅はその型の値より狭いです"
 
-#: c/c-decl.c:5512
+#: c/c-decl.c:5532
 #, gcc-internal-format
 msgid "ISO C90 forbids array %qE whose size can%'t be evaluated"
 msgstr "ISO C90 はサイズを評価できない配列 %qE を禁止しています"
 
-#: c/c-decl.c:5515
+#: c/c-decl.c:5535
 #, gcc-internal-format
 msgid "ISO C90 forbids array whose size can%'t be evaluated"
 msgstr "ISO C90 はサイズが評価できない配列を禁止しています"
 
-#: c/c-decl.c:5522
+#: c/c-decl.c:5542
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array %qE"
 msgstr "ISO C90 は可変長の配列 %qE を禁止しています"
 
-#: c/c-decl.c:5524
+#: c/c-decl.c:5544
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array"
 msgstr "ISO C90 は可変長の配列を禁止しています"
 
-#: c/c-decl.c:5733 c/c-decl.c:6107 c/c-decl.c:6117
+#: c/c-decl.c:5753 c/c-decl.c:6127 c/c-decl.c:6137
 #, gcc-internal-format
 msgid "variably modified %qE at file scope"
 msgstr "ファイルスコープの可変 %qE です"
 
-#: c/c-decl.c:5735
+#: c/c-decl.c:5755
 #, gcc-internal-format
 msgid "variably modified field at file scope"
 msgstr "ファイルスコープの可変フィールドです"
 
-#: c/c-decl.c:5755
+#: c/c-decl.c:5775
 #, gcc-internal-format
 msgid "type defaults to %<int%> in declaration of %qE"
 msgstr "型がデフォルトの %<int%> に %qE の宣言内でなります"
 
-#: c/c-decl.c:5759
+#: c/c-decl.c:5779
 #, gcc-internal-format
 msgid "type defaults to %<int%> in type name"
 msgstr "型がデフォルトの %<int%> に型名内でなります"
 
-#: c/c-decl.c:5791
+#: c/c-decl.c:5811
 #, gcc-internal-format
 msgid "duplicate %<const%>"
 msgstr "重複した %<const%> です"
 
-#: c/c-decl.c:5793
+#: c/c-decl.c:5813
 #, gcc-internal-format
 msgid "duplicate %<restrict%>"
 msgstr "重複した %<restrict%> です"
 
-#: c/c-decl.c:5795
+#: c/c-decl.c:5815
 #, gcc-internal-format
 msgid "duplicate %<volatile%>"
 msgstr "重複した %<volatile%> です"
 
-#: c/c-decl.c:5797
+#: c/c-decl.c:5817
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<restrict%>"
 msgid "duplicate %<_Atomic%>"
 msgstr "重複した %<restrict%> です"
 
-#: c/c-decl.c:5800
+#: c/c-decl.c:5820
 #, gcc-internal-format, gfc-internal-format
 msgid "conflicting named address spaces (%s vs %s)"
 msgstr "名前付きアドレス空間 (%s と %s) が競合しています"
 
-#: c/c-decl.c:5823 c/c-parser.c:2821
+#: c/c-decl.c:5843 c/c-parser.c:2821
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified array type"
 msgstr ""
 
-#: c/c-decl.c:5837
+#: c/c-decl.c:5857
 #, gcc-internal-format
 msgid "function definition declared %<auto%>"
 msgstr "関数定義が %<auto%> と宣言されています"
 
-#: c/c-decl.c:5839
+#: c/c-decl.c:5859
 #, gcc-internal-format
 msgid "function definition declared %<register%>"
 msgstr "関数定義が %<register%> と宣言されています"
 
-#: c/c-decl.c:5841
+#: c/c-decl.c:5861
 #, gcc-internal-format
 msgid "function definition declared %<typedef%>"
 msgstr "関数定義が %<typedef%> と宣言されています"
 
-#: c/c-decl.c:5843
+#: c/c-decl.c:5863
 #, fuzzy, gcc-internal-format
 #| msgid "function definition declared %<auto%>"
 msgid "function definition declared %qs"
 msgstr "関数定義が %<auto%> と宣言されています"
 
-#: c/c-decl.c:5861
+#: c/c-decl.c:5881
 #, gcc-internal-format
 msgid "storage class specified for structure field %qE"
 msgstr "構造体フィールド %qE 用に記憶域クラスが指定されています"
 
-#: c/c-decl.c:5864
+#: c/c-decl.c:5884
 #, gcc-internal-format
 msgid "storage class specified for structure field"
 msgstr "構造体フィールド用に記憶域クラスが指定されています"
 
-#: c/c-decl.c:5868
+#: c/c-decl.c:5888
 #, gcc-internal-format
 msgid "storage class specified for parameter %qE"
 msgstr "仮引数 %qE 用に記憶域クラスが指定されました"
 
-#: c/c-decl.c:5871
+#: c/c-decl.c:5891
 #, gcc-internal-format
 msgid "storage class specified for unnamed parameter"
 msgstr "無名仮引数用に記憶域クラスが指定されました"
 
-#: c/c-decl.c:5874 cp/decl.c:10935
+#: c/c-decl.c:5894 cp/decl.c:10959
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "型名用に記憶域クラスが指定されました"
 
-#: c/c-decl.c:5891
+#: c/c-decl.c:5911
 #, gcc-internal-format
 msgid "%qE initialized and declared %<extern%>"
 msgstr "%qE が初期化され、 %<extern%> として宣言されています"
 
-#: c/c-decl.c:5895
+#: c/c-decl.c:5915
 #, gcc-internal-format
 msgid "%qE has both %<extern%> and initializer"
 msgstr "%qE が %<extern%> と初期化子の両方を持っています"
 
-#: c/c-decl.c:5900
+#: c/c-decl.c:5920
 #, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<auto%>"
 msgstr "%qE のファイルスコープ宣言は %<auto%> を指定します"
 
-#: c/c-decl.c:5904
+#: c/c-decl.c:5924
 #, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<register%>"
 msgstr "%qE のファイルスコープ宣言は %<register%> を指定します"
 
-#: c/c-decl.c:5909
+#: c/c-decl.c:5929
 #, gcc-internal-format
 msgid "nested function %qE declared %<extern%>"
 msgstr "入れ子になった関数 %qE が %<extern%> と宣言されています"
 
-#: c/c-decl.c:5912
+#: c/c-decl.c:5932
 #, fuzzy, gcc-internal-format
 #| msgid "function-scope %qE implicitly auto and declared %<__thread%>"
 msgid "function-scope %qE implicitly auto and declared %qs"
@@ -38093,723 +38137,723 @@
 #. Only the innermost declarator (making a parameter be of
 #. array type which is converted to pointer type)
 #. may have static or type qualifiers.
-#: c/c-decl.c:5959 c/c-decl.c:6328
+#: c/c-decl.c:5979 c/c-decl.c:6348
 #, gcc-internal-format
 msgid "static or type qualifiers in non-parameter array declarator"
 msgstr "仮引数で無い配列宣言内の静的または型修飾子です"
 
-#: c/c-decl.c:6007
+#: c/c-decl.c:6027
 #, gcc-internal-format
 msgid "declaration of %qE as array of voids"
 msgstr "void の配列としての %qE の宣言です"
 
-#: c/c-decl.c:6009
+#: c/c-decl.c:6029
 #, gcc-internal-format
 msgid "declaration of type name as array of voids"
 msgstr "void の配列としての型名の宣言です"
 
-#: c/c-decl.c:6016
+#: c/c-decl.c:6036
 #, gcc-internal-format
 msgid "declaration of %qE as array of functions"
 msgstr "関数の配列としての %qE の宣言です"
 
-#: c/c-decl.c:6019
+#: c/c-decl.c:6039
 #, gcc-internal-format
 msgid "declaration of type name as array of functions"
 msgstr "関数の配列としての型名の宣言です"
 
-#: c/c-decl.c:6027 c/c-decl.c:8085
+#: c/c-decl.c:6047 c/c-decl.c:8105
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr ""
 
-#: c/c-decl.c:6053
+#: c/c-decl.c:6073
 #, gcc-internal-format
 msgid "size of array %qE has non-integer type"
 msgstr "配列 %qE のサイズが非整数型です"
 
-#: c/c-decl.c:6057
+#: c/c-decl.c:6077
 #, gcc-internal-format
 msgid "size of unnamed array has non-integer type"
 msgstr "無名配列のサイズが非整数型です"
 
-#: c/c-decl.c:6064
+#: c/c-decl.c:6084
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qE has non-integer type"
 msgid "size of array %qE has incomplete type"
 msgstr "配列 %qE のサイズが非整数型です"
 
-#: c/c-decl.c:6067
+#: c/c-decl.c:6087
 #, fuzzy, gcc-internal-format
 #| msgid "size of unnamed array has non-integer type"
 msgid "size of unnamed array has incomplete type"
 msgstr "無名配列のサイズが非整数型です"
 
-#: c/c-decl.c:6078
+#: c/c-decl.c:6098
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array %qE"
 msgstr "ISO C はサイズが 0 の配列 %qE を禁止しています"
 
-#: c/c-decl.c:6081
+#: c/c-decl.c:6101
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array"
 msgstr "ISO C はサイズが 0 の配列を禁止しています"
 
-#: c/c-decl.c:6090
+#: c/c-decl.c:6110
 #, gcc-internal-format
 msgid "size of array %qE is negative"
 msgstr "配列 %qE のサイズが負です"
 
-#: c/c-decl.c:6092
+#: c/c-decl.c:6112
 #, gcc-internal-format
 msgid "size of unnamed array is negative"
 msgstr "無名配列のサイズが負です"
 
-#: c/c-decl.c:6216 c/c-decl.c:6871
+#: c/c-decl.c:6236 c/c-decl.c:6891
 #, gcc-internal-format
 msgid "ISO C90 does not support flexible array members"
 msgstr ""
 
 #. C99 6.7.5.2p4
-#: c/c-decl.c:6238
+#: c/c-decl.c:6258
 #, gcc-internal-format
 msgid "%<[*]%> not in a declaration"
 msgstr "宣言内にない %<[*]%> です"
 
-#: c/c-decl.c:6251
+#: c/c-decl.c:6271
 #, fuzzy, gcc-internal-format
 #| msgid "array type has incomplete element type"
 msgid "array type has incomplete element type %qT"
 msgstr "配列の型が不完全要素型を持っています"
 
-#: c/c-decl.c:6257
+#: c/c-decl.c:6277
 #, gcc-internal-format
 msgid "declaration of %qE as multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: c/c-decl.c:6261
+#: c/c-decl.c:6281
 #, gcc-internal-format
 msgid "declaration of multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: c/c-decl.c:6364
+#: c/c-decl.c:6384
 #, gcc-internal-format
 msgid "%qE declared as function returning a function"
 msgstr "%qE は関数を返す関数と宣言されています"
 
-#: c/c-decl.c:6367
+#: c/c-decl.c:6387
 #, gcc-internal-format
 msgid "type name declared as function returning a function"
 msgstr "型名は関数を返す関数として宣言されています"
 
-#: c/c-decl.c:6374
+#: c/c-decl.c:6394
 #, gcc-internal-format
 msgid "%qE declared as function returning an array"
 msgstr "%qE は配列を返す関数として宣言されています"
 
-#: c/c-decl.c:6377
+#: c/c-decl.c:6397
 #, gcc-internal-format
 msgid "type name declared as function returning an array"
 msgstr "型名は配列を返す関数として定義されています"
 
-#: c/c-decl.c:6418
+#: c/c-decl.c:6438
 #, gcc-internal-format
 msgid "function definition has qualified void return type"
 msgstr "関数定義が void 戻り型の修飾子を持っています"
 
-#: c/c-decl.c:6421 cp/decl.c:11201
+#: c/c-decl.c:6441 cp/decl.c:11225
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "関数戻り値の型修飾子は無視されました"
 
-#: c/c-decl.c:6459 c/c-decl.c:6668 c/c-decl.c:6721 c/c-decl.c:6805
-#: c/c-decl.c:6926 c/c-parser.c:2823
+#: c/c-decl.c:6479 c/c-decl.c:6688 c/c-decl.c:6741 c/c-decl.c:6825
+#: c/c-decl.c:6946 c/c-parser.c:2823
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids qualified function types"
 msgid "%<_Atomic%>-qualified function type"
 msgstr "ISO C は関数型の修飾子を禁止しています"
 
-#: c/c-decl.c:6465 c/c-decl.c:6674 c/c-decl.c:6810 c/c-decl.c:6931
+#: c/c-decl.c:6485 c/c-decl.c:6694 c/c-decl.c:6830 c/c-decl.c:6951
 #, gcc-internal-format
 msgid "ISO C forbids qualified function types"
 msgstr "ISO C は関数型の修飾子を禁止しています"
 
-#: c/c-decl.c:6559
+#: c/c-decl.c:6579
 #, gcc-internal-format
 msgid "%qs combined with %<auto%> qualifier for %qE"
 msgstr "%qs が %<auto%> 修飾子と %qE 用に組み合わされています"
 
-#: c/c-decl.c:6563
+#: c/c-decl.c:6583
 #, gcc-internal-format
 msgid "%qs combined with %<register%> qualifier for %qE"
 msgstr "%qs が %<register%> 修飾子と %qE 用に組み合わされています"
 
-#: c/c-decl.c:6569
+#: c/c-decl.c:6589
 #, gcc-internal-format
 msgid "%qs specified for auto variable %qE"
 msgstr "%qs が自動変数 %qE 用に指定されています"
 
-#: c/c-decl.c:6585
+#: c/c-decl.c:6605
 #, gcc-internal-format
 msgid "%qs specified for parameter %qE"
 msgstr "%qs が仮引数 %qE 用に指定されています"
 
-#: c/c-decl.c:6588
+#: c/c-decl.c:6608
 #, gcc-internal-format
 msgid "%qs specified for unnamed parameter"
 msgstr "%qs が無名仮引数用に指定されました"
 
-#: c/c-decl.c:6594
+#: c/c-decl.c:6614
 #, gcc-internal-format
 msgid "%qs specified for structure field %qE"
 msgstr "%qs が構造体フィールド %qE 用に指定されています"
 
-#: c/c-decl.c:6597
+#: c/c-decl.c:6617
 #, gcc-internal-format
 msgid "%qs specified for structure field"
 msgstr "%qs が構造体フィールド用に指定されています"
 
-#: c/c-decl.c:6612
+#: c/c-decl.c:6632
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qs has invalid type"
 msgid "bit-field %qE has atomic type"
 msgstr "ビットフィールド %qs が無効な型を持っています"
 
-#: c/c-decl.c:6614
+#: c/c-decl.c:6634
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qs has invalid type"
 msgid "bit-field has atomic type"
 msgstr "ビットフィールド %qs が無効な型を持っています"
 
-#: c/c-decl.c:6623
+#: c/c-decl.c:6643
 #, fuzzy, gcc-internal-format
 #| msgid "alignment may not be specified for %q+D"
 msgid "alignment specified for typedef %qE"
 msgstr "%q+D 用の整列が指定されていないようです"
 
-#: c/c-decl.c:6625
+#: c/c-decl.c:6645
 #, fuzzy, gcc-internal-format
 #| msgid "%qs specified for parameter %qE"
 msgid "alignment specified for %<register%> object %qE"
 msgstr "%qs が仮引数 %qE 用に指定されています"
 
-#: c/c-decl.c:6630
+#: c/c-decl.c:6650
 #, fuzzy, gcc-internal-format
 #| msgid "%qs specified for parameter %qE"
 msgid "alignment specified for parameter %qE"
 msgstr "%qs が仮引数 %qE 用に指定されています"
 
-#: c/c-decl.c:6632
+#: c/c-decl.c:6652
 #, fuzzy, gcc-internal-format
 #| msgid "%qs specified for unnamed parameter"
 msgid "alignment specified for unnamed parameter"
 msgstr "%qs が無名仮引数用に指定されました"
 
-#: c/c-decl.c:6637
+#: c/c-decl.c:6657
 #, fuzzy, gcc-internal-format
 #| msgid "alignment may not be specified for %q+D"
 msgid "alignment specified for bit-field %qE"
 msgstr "%q+D 用の整列が指定されていないようです"
 
-#: c/c-decl.c:6639
+#: c/c-decl.c:6659
 #, fuzzy, gcc-internal-format
 #| msgid "%qs specified for unnamed parameter"
 msgid "alignment specified for unnamed bit-field"
 msgstr "%qs が無名仮引数用に指定されました"
 
-#: c/c-decl.c:6642
+#: c/c-decl.c:6662
 #, fuzzy, gcc-internal-format
 #| msgid "assignment of function %qD"
 msgid "alignment specified for function %qE"
 msgstr "関数 %qD への代入です"
 
-#: c/c-decl.c:6649
+#: c/c-decl.c:6669
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of %qE"
 msgstr ""
 
-#: c/c-decl.c:6652
+#: c/c-decl.c:6672
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of unnamed field"
 msgstr ""
 
-#: c/c-decl.c:6683
+#: c/c-decl.c:6703
 #, gcc-internal-format
 msgid "typedef %q+D declared %<inline%>"
 msgstr "typedef %q+D が %<inline%> と宣言されています"
 
-#: c/c-decl.c:6685
+#: c/c-decl.c:6705
 #, fuzzy, gcc-internal-format
 #| msgid "typedef %q+D declared %<inline%>"
 msgid "typedef %q+D declared %<_Noreturn%>"
 msgstr "typedef %q+D が %<inline%> と宣言されています"
 
-#: c/c-decl.c:6727
+#: c/c-decl.c:6747
 #, gcc-internal-format
 msgid "ISO C forbids const or volatile function types"
 msgstr "ISO C は const や volatile の関数型を禁止しています"
 
 #. C99 6.7.2.1p8
-#: c/c-decl.c:6738
+#: c/c-decl.c:6758
 #, gcc-internal-format
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "構造体または共用体のメンバは可変型を持つことは出来ません"
 
-#: c/c-decl.c:6755 cp/decl.c:9989
+#: c/c-decl.c:6775 cp/decl.c:10010
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "変数またはフィールド %qE が void と宣言されています"
 
-#: c/c-decl.c:6795
+#: c/c-decl.c:6815
 #, gcc-internal-format
 msgid "attributes in parameter array declarator ignored"
 msgstr "仮引数配列宣言内の属性が無視されました"
 
-#: c/c-decl.c:6837
+#: c/c-decl.c:6857
 #, gcc-internal-format
 msgid "parameter %q+D declared %<inline%>"
 msgstr "仮引数 %q+D が %<inline%> と宣言されています"
 
-#: c/c-decl.c:6839
+#: c/c-decl.c:6859
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared %<inline%>"
 msgid "parameter %q+D declared %<_Noreturn%>"
 msgstr "仮引数 %q+D が %<inline%> と宣言されています"
 
-#: c/c-decl.c:6852
+#: c/c-decl.c:6872
 #, gcc-internal-format
 msgid "field %qE declared as a function"
 msgstr "フィールド %qE が関数として宣言されています"
 
-#: c/c-decl.c:6859
+#: c/c-decl.c:6879
 #, gcc-internal-format
 msgid "field %qE has incomplete type"
 msgstr "フィールド %qE が不完全型を持っています"
 
-#: c/c-decl.c:6861
+#: c/c-decl.c:6881
 #, gcc-internal-format
 msgid "unnamed field has incomplete type"
 msgstr "無名フィールドが不完全型を持っています"
 
-#: c/c-decl.c:6897 c/c-decl.c:6908 c/c-decl.c:6911
+#: c/c-decl.c:6917 c/c-decl.c:6928 c/c-decl.c:6931
 #, gcc-internal-format
 msgid "invalid storage class for function %qE"
 msgstr "関数 %qE 用の無効な記憶域クラスです"
 
-#: c/c-decl.c:6968
+#: c/c-decl.c:6988
 #, gcc-internal-format
 msgid "cannot inline function %<main%>"
 msgstr "関数 %<main%> をインラインに出来ません"
 
-#: c/c-decl.c:6970
+#: c/c-decl.c:6990
 #, fuzzy, gcc-internal-format
 #| msgid "%qE initialized and declared %<extern%>"
 msgid "%<main%> declared %<_Noreturn%>"
 msgstr "%qE が初期化され、 %<extern%> として宣言されています"
 
-#: c/c-decl.c:6981
+#: c/c-decl.c:7001
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C99 does not support %<_Static_assert%>"
 msgid "ISO C99 does not support %<_Noreturn%>"
 msgstr "ISO C99 は %<_Static_assert%> をサポートしません"
 
-#: c/c-decl.c:6984
+#: c/c-decl.c:7004
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<long long%>"
 msgid "ISO C90 does not support %<_Noreturn%>"
 msgstr "ISO C90 は %<long long%> をサポートしません"
 
-#: c/c-decl.c:7013
+#: c/c-decl.c:7033
 #, gcc-internal-format
 msgid "variable previously declared %<static%> redeclared %<extern%>"
 msgstr "前に %<static%> と宣言された変数が %<extern%> と再宣言されています"
 
-#: c/c-decl.c:7023
+#: c/c-decl.c:7043
 #, gcc-internal-format
 msgid "variable %q+D declared %<inline%>"
 msgstr "変数 %q+D が %<inline%> と宣言されています"
 
-#: c/c-decl.c:7025
+#: c/c-decl.c:7045
 #, fuzzy, gcc-internal-format
 #| msgid "variable %q+D declared %<inline%>"
 msgid "variable %q+D declared %<_Noreturn%>"
 msgstr "変数 %q+D が %<inline%> と宣言されています"
 
-#: c/c-decl.c:7060
+#: c/c-decl.c:7080
 #, gcc-internal-format
 msgid "non-nested function with variably modified type"
 msgstr "可変型の入れ子になっていない関数です"
 
-#: c/c-decl.c:7062
+#: c/c-decl.c:7082
 #, gcc-internal-format
 msgid "object with variably modified type must have no linkage"
 msgstr "可変型のオブジェクトはリンクされてはいけません"
 
-#: c/c-decl.c:7153 c/c-decl.c:8821
+#: c/c-decl.c:7173 c/c-decl.c:8841
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr "関数宣言がプロトタイプではありません"
 
-#: c/c-decl.c:7163
+#: c/c-decl.c:7183
 #, gcc-internal-format
 msgid "parameter names (without types) in function declaration"
 msgstr "関数宣言中に（型の無い）仮引数名があります"
 
-#: c/c-decl.c:7201
+#: c/c-decl.c:7221
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has incomplete type"
 msgstr "仮引数 %u (%q+D) が不完全型を持っています"
 
-#: c/c-decl.c:7205
+#: c/c-decl.c:7225
 #, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has incomplete type"
 msgstr "仮引数 %u が不完全型を持っています"
 
-#: c/c-decl.c:7216
+#: c/c-decl.c:7236
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has void type"
 msgstr "仮引数 %u (%q+D) が void 型を持っています"
 
-#: c/c-decl.c:7220
+#: c/c-decl.c:7240
 #, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has void type"
 msgstr "仮引数 %u が void 型を持っています"
 
-#: c/c-decl.c:7294
+#: c/c-decl.c:7314
 #, gcc-internal-format
 msgid "%<void%> as only parameter may not be qualified"
 msgstr "唯一の仮引数となる %<void%> には修飾子がつきません"
 
-#: c/c-decl.c:7298 c/c-decl.c:7334
+#: c/c-decl.c:7318 c/c-decl.c:7354
 #, gcc-internal-format
 msgid "%<void%> must be the only parameter"
 msgstr "%<void%> は唯一の仮引数でなければいけません"
 
-#: c/c-decl.c:7328
+#: c/c-decl.c:7348
 #, gcc-internal-format
 msgid "parameter %q+D has just a forward declaration"
 msgstr "仮引数 %q+D は直前に定義されています"
 
-#: c/c-decl.c:7374
+#: c/c-decl.c:7394
 #, gcc-internal-format
 msgid "%<%s %E%> declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr ""
 
-#: c/c-decl.c:7380
+#: c/c-decl.c:7400
 #, gcc-internal-format, gfc-internal-format
 msgid "anonymous %s declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr ""
 
-#: c/c-decl.c:7482
+#: c/c-decl.c:7502
 #, gcc-internal-format
 msgid "enum type defined here"
 msgstr "列挙型がここで定義されています"
 
-#: c/c-decl.c:7488
+#: c/c-decl.c:7508
 #, gcc-internal-format
 msgid "struct defined here"
 msgstr "構造体がここで定義されています"
 
-#: c/c-decl.c:7494
+#: c/c-decl.c:7514
 #, gcc-internal-format
 msgid "union defined here"
 msgstr "共用体がここで定義されています"
 
-#: c/c-decl.c:7570
+#: c/c-decl.c:7590
 #, gcc-internal-format
 msgid "redefinition of %<union %E%>"
 msgstr "%<union %E%> の再定義です"
 
-#: c/c-decl.c:7572
+#: c/c-decl.c:7592
 #, gcc-internal-format
 msgid "redefinition of %<struct %E%>"
 msgstr "%<struct %E%> の再定義です"
 
-#: c/c-decl.c:7581
+#: c/c-decl.c:7601
 #, gcc-internal-format
 msgid "nested redefinition of %<union %E%>"
 msgstr "%<union %E%> の入れ子になった再定義です"
 
-#: c/c-decl.c:7583
+#: c/c-decl.c:7603
 #, gcc-internal-format
 msgid "nested redefinition of %<struct %E%>"
 msgstr "%<struct %E%> の入れ子になった再定義です"
 
-#: c/c-decl.c:7613 c/c-decl.c:8400
+#: c/c-decl.c:7633 c/c-decl.c:8420
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr "%qs 式内での型定義は C++ では無効です"
 
-#: c/c-decl.c:7680 cp/decl.c:4802
+#: c/c-decl.c:7700 cp/decl.c:4802
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "宣言が何も宣言していません"
 
-#: c/c-decl.c:7685
+#: c/c-decl.c:7705
 #, gcc-internal-format
 msgid "ISO C99 doesn%'t support unnamed structs/unions"
 msgstr "ISO C99 は無名構造体/共用体をサポートしません"
 
-#: c/c-decl.c:7688
+#: c/c-decl.c:7708
 #, gcc-internal-format
 msgid "ISO C90 doesn%'t support unnamed structs/unions"
 msgstr "ISO C90 は無名構造体/共用体をサポートしません"
 
-#: c/c-decl.c:7781 c/c-decl.c:7799 c/c-decl.c:7860
+#: c/c-decl.c:7801 c/c-decl.c:7819 c/c-decl.c:7880
 #, gcc-internal-format
 msgid "duplicate member %q+D"
 msgstr "重複したメンバ %q+D です"
 
-#: c/c-decl.c:7886
+#: c/c-decl.c:7906
 #, gcc-internal-format
 msgid "empty struct has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.c:7889
+#: c/c-decl.c:7909
 #, gcc-internal-format
 msgid "empty union has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.c:7994
+#: c/c-decl.c:8014
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr "共用体に名前付きメンバがありません"
 
-#: c/c-decl.c:7996
+#: c/c-decl.c:8016
 #, gcc-internal-format
 msgid "union has no members"
 msgstr "共用体にメンバがありません"
 
-#: c/c-decl.c:8001
+#: c/c-decl.c:8021
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr "構造体に名前付きメンバがありません"
 
-#: c/c-decl.c:8003
+#: c/c-decl.c:8023
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr "構造体にメンバがありません"
 
-#: c/c-decl.c:8064 cp/decl.c:12069
+#: c/c-decl.c:8084 cp/decl.c:12093
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "共用体に可変配列メンバがあります"
 
-#: c/c-decl.c:8070
+#: c/c-decl.c:8090
 #, gcc-internal-format
 msgid "flexible array member not at end of struct"
 msgstr "構造体の最後ではない所に可変配列メンバがあります"
 
-#: c/c-decl.c:8076
+#: c/c-decl.c:8096
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member in union"
 msgid "flexible array member in a struct with no named members"
 msgstr "共用体に可変配列メンバがあります"
 
-#: c/c-decl.c:8107
+#: c/c-decl.c:8127
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qE is too large"
 msgid "type %qT is too large"
 msgstr "配列 %qE のサイズが大きすぎます"
 
-#: c/c-decl.c:8230
+#: c/c-decl.c:8250
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr "共用体を透過的にできません"
 
-#: c/c-decl.c:8372
+#: c/c-decl.c:8392
 #, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr "%<enum %E%> の入れ子になった再定義です"
 
 #. This enum is a named one that has been declared already.
-#: c/c-decl.c:8379
+#: c/c-decl.c:8399
 #, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr "%<enum %E%> の再定義です"
 
-#: c/c-decl.c:8458 cp/decl.c:14423
+#: c/c-decl.c:8478 cp/decl.c:14447
 #, gcc-internal-format
 msgid "specified mode too small for enumeral values"
 msgstr "指定したモードは列挙値用には小さすぎます"
 
-#: c/c-decl.c:8473
+#: c/c-decl.c:8493
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr "列挙値が整数の範囲の最大値を超えました"
 
-#: c/c-decl.c:8587 c/c-decl.c:8603
+#: c/c-decl.c:8607 c/c-decl.c:8623
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr "%qE 用の列挙値が整数定数ではありません"
 
-#: c/c-decl.c:8598
+#: c/c-decl.c:8618
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr "%qE の列挙値が整数定数式ではありません"
 
-#: c/c-decl.c:8622
+#: c/c-decl.c:8642
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr "列挙値がオーバーフローしました"
 
-#: c/c-decl.c:8630
+#: c/c-decl.c:8650
 #, gcc-internal-format
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "ISO C は列挙値を %<int%> の範囲に制限しています"
 
-#: c/c-decl.c:8715 cp/decl.c:5104 cp/decl.c:14955
+#: c/c-decl.c:8735 cp/decl.c:5104 cp/decl.c:14979
 #, gcc-internal-format
 msgid "inline function %qD given attribute noinline"
 msgstr "非インライン (noinline) 属性が与えられたインライン関数 %qD です"
 
-#: c/c-decl.c:8733
+#: c/c-decl.c:8753
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr "戻り値の型が不完全型です"
 
-#: c/c-decl.c:8744
+#: c/c-decl.c:8764
 #, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr "戻り値の型をデフォルトの %<int%> にします"
 
-#: c/c-decl.c:8771
+#: c/c-decl.c:8791
 #, fuzzy, gcc-internal-format
 #| msgid "Warn about global functions without prototypes"
 msgid "%q+D defined as variadic function without prototype"
 msgstr "プロトタイプ無しの大域関数に関して警告する"
 
-#: c/c-decl.c:8830
+#: c/c-decl.c:8850
 #, gcc-internal-format
 msgid "no previous prototype for %qD"
 msgstr "前に %qD 用のプロトタイプがありません"
 
-#: c/c-decl.c:8839
+#: c/c-decl.c:8859
 #, gcc-internal-format
 msgid "%qD was used with no prototype before its definition"
 msgstr "%qD がプロトタイプ無しで、定義される前に使用されました"
 
-#: c/c-decl.c:8847 cp/decl.c:15090
+#: c/c-decl.c:8867 cp/decl.c:15114
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "前に %qD 用の定義がありません"
 
-#: c/c-decl.c:8857
+#: c/c-decl.c:8877
 #, gcc-internal-format
 msgid "%qD was used with no declaration before its definition"
 msgstr "%qD はその定義の前で宣言しないで使用されました"
 
-#: c/c-decl.c:8876
+#: c/c-decl.c:8896
 #, gcc-internal-format
 msgid "return type of %qD is not %<int%>"
 msgstr "%qD の戻り型が %<int%> ではありません"
 
-#: c/c-decl.c:8878
+#: c/c-decl.c:8898
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr ""
 
-#: c/c-decl.c:8885
+#: c/c-decl.c:8905
 #, gcc-internal-format
 msgid "%qD is normally a non-static function"
 msgstr "%qD は通常は非静的関数です。"
 
-#: c/c-decl.c:8922
+#: c/c-decl.c:8942
 #, gcc-internal-format
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr "プロトタイプ関数宣言内で古いスタイルの仮引数宣言です"
 
-#: c/c-decl.c:8937
+#: c/c-decl.c:8957
 #, gcc-internal-format
 msgid "traditional C rejects ISO C style function definitions"
 msgstr "伝統的な C では ISO C スタイルの関数定義は拒否されます"
 
-#: c/c-decl.c:8953
+#: c/c-decl.c:8973
 #, gcc-internal-format
 msgid "parameter name omitted"
 msgstr "仮引数名が省略されています"
 
-#: c/c-decl.c:8990
+#: c/c-decl.c:9010
 #, gcc-internal-format
 msgid "old-style function definition"
 msgstr "古いスタイルの関数定義です"
 
-#: c/c-decl.c:8999
+#: c/c-decl.c:9019
 #, gcc-internal-format
 msgid "parameter name missing from parameter list"
 msgstr "仮引数リストに仮引数名がありません"
 
-#: c/c-decl.c:9015
+#: c/c-decl.c:9035
 #, gcc-internal-format
 msgid "%qD declared as a non-parameter"
 msgstr "%qD は非仮引数として宣言されています"
 
-#: c/c-decl.c:9023
+#: c/c-decl.c:9043
 #, gcc-internal-format
 msgid "multiple parameters named %qD"
 msgstr "複数の仮引数が %qD という名前です"
 
-#: c/c-decl.c:9032
+#: c/c-decl.c:9052
 #, gcc-internal-format
 msgid "parameter %qD declared with void type"
 msgstr "仮引数 %qD が void 型で宣言されています"
 
-#: c/c-decl.c:9061 c/c-decl.c:9066
+#: c/c-decl.c:9081 c/c-decl.c:9086
 #, gcc-internal-format
 msgid "type of %qD defaults to %<int%>"
 msgstr "%qD の型をデフォルトの %<int%> にします"
 
-#: c/c-decl.c:9086
+#: c/c-decl.c:9106
 #, gcc-internal-format
 msgid "parameter %qD has incomplete type"
 msgstr "仮引数 %qD が不完全型を持っています"
 
-#: c/c-decl.c:9093
+#: c/c-decl.c:9113
 #, gcc-internal-format
 msgid "declaration for parameter %qD but no such parameter"
 msgstr "仮引数 %qD 用の宣言がありますが、そのような仮引数はありません"
 
-#: c/c-decl.c:9146
+#: c/c-decl.c:9166
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr "引数の数が組み込みプロトタイプと一致しません"
 
-#: c/c-decl.c:9157
+#: c/c-decl.c:9177
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr "引数の数がプロトタイプと一致しません"
 
-#: c/c-decl.c:9160 c/c-decl.c:9207 c/c-decl.c:9221
+#: c/c-decl.c:9180 c/c-decl.c:9227 c/c-decl.c:9241
 #, gcc-internal-format
 msgid "prototype declaration"
 msgstr "プロトタイプ宣言です"
 
-#: c/c-decl.c:9199
+#: c/c-decl.c:9219
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr ""
 
-#: c/c-decl.c:9204
+#: c/c-decl.c:9224
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr ""
 
-#: c/c-decl.c:9214
+#: c/c-decl.c:9234
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr "引数 %qD が組み込みプロトタイプと一致しません"
 
-#: c/c-decl.c:9219
+#: c/c-decl.c:9239
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr "引数 %qD がプロトタイプと一致しません"
 
-#: c/c-decl.c:9470 cp/decl.c:15873
+#: c/c-decl.c:9490 cp/decl.c:15897
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "非 void を戻す関数内に return 文がありません"
 
-#: c/c-decl.c:9490 cp/decl.c:15905
+#: c/c-decl.c:9510 cp/decl.c:15929
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "仮引数 %qD が設定されましたが使用されません"
@@ -38817,263 +38861,263 @@
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:9586
+#: c/c-decl.c:9606
 #, fuzzy, gcc-internal-format
 #| msgid "%<for%> loop initial declarations are only allowed in C99 mode"
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "%<for%> ループ初期化宣言は C99 モード内でのみ許可されています"
 
-#: c/c-decl.c:9591
+#: c/c-decl.c:9611
 #, fuzzy, gcc-internal-format
 #| msgid "use option -std=c99 or -std=gnu99 to compile your code"
 msgid "use option -std=c99, -std=gnu99, -std=c11 or -std=gnu11 to compile your code"
 msgstr "オプション -std=c99 または -std=gnu99 をコードコンパイル時に使用してください"
 
-#: c/c-decl.c:9626
+#: c/c-decl.c:9646
 #, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "静的変数 %qD の宣言が %<for%> ループ初期化宣言内にあります"
 
-#: c/c-decl.c:9630
+#: c/c-decl.c:9650
 #, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "%<extern%> 変数 %qD の宣言が %<for%> ループ初期化宣言内にあります"
 
-#: c/c-decl.c:9637
+#: c/c-decl.c:9657
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "%<struct %E%> が %<for%> ループ初期化宣言内で宣言されています"
 
-#: c/c-decl.c:9642
+#: c/c-decl.c:9662
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "%<union %E%> が %<for%> ループ初期化宣言内で宣言されています"
 
-#: c/c-decl.c:9646
+#: c/c-decl.c:9666
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "%<enum %E%> が %<for%> ループ初期化宣言内で宣言されています"
 
-#: c/c-decl.c:9650
+#: c/c-decl.c:9670
 #, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "非変数 %qD の宣言が %<for%> ループ初期化宣言内にあります"
 
-#: c/c-decl.c:9900
+#: c/c-decl.c:9920
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr "互換性のないアドレス空間修飾子 %qs と %qs です"
 
-#: c/c-decl.c:9958 c/c-decl.c:9965
+#: c/c-decl.c:9978 c/c-decl.c:9985
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "duplicate %qE declaration specifier"
 msgstr "宣言指定が予期されます"
 
-#: c/c-decl.c:9992 c/c-decl.c:10376 c/c-decl.c:10766
+#: c/c-decl.c:10012 c/c-decl.c:10396 c/c-decl.c:10786
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr "宣言指定内に二個またはそれ以上の型があります"
 
-#: c/c-decl.c:10004 cp/parser.c:28261
+#: c/c-decl.c:10024 cp/parser.c:28258
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> は GCC にとって長すぎます"
 
-#: c/c-decl.c:10017
+#: c/c-decl.c:10037
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C90 は %<long long%> をサポートしません"
 
-#: c/c-decl.c:10246 c/c-parser.c:8848
+#: c/c-decl.c:10266 c/c-parser.c:8848
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C90 は複素数型をサポートしません"
 
-#: c/c-decl.c:10292
+#: c/c-decl.c:10312
 #, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr ""
 
-#: c/c-decl.c:10363 c/c-decl.c:10923
+#: c/c-decl.c:10383 c/c-decl.c:10943
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "%qE が重複しています"
 
-#: c/c-decl.c:10419
+#: c/c-decl.c:10439
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support %<__int128%> type"
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C は %<__int128%> 型をサポートしません"
 
-#: c/c-decl.c:10441
+#: c/c-decl.c:10461
 #, fuzzy, gcc-internal-format
 #| msgid "%<__int128%> is not supported for this target"
 msgid "%<__int%d%> is not supported on this target"
 msgstr "%<__int128%> はこのターゲットではサポートされていません"
 
-#: c/c-decl.c:10484
+#: c/c-decl.c:10504
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support complex types"
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C90 は複素数型をサポートしません"
 
-#: c/c-decl.c:10603
+#: c/c-decl.c:10623
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support %<__int128%> type"
 msgid "ISO C does not support the %<_Float%d%s%> type"
 msgstr "ISO C は %<__int128%> 型をサポートしません"
 
-#: c/c-decl.c:10653
+#: c/c-decl.c:10673
 #, fuzzy, gcc-internal-format
 #| msgid "%<__int128%> is not supported for this target"
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "%<__int128%> はこのターゲットではサポートされていません"
 
-#: c/c-decl.c:10724
+#: c/c-decl.c:10744
 #, gcc-internal-format
 msgid "ISO C does not support decimal floating point"
 msgstr "ISO C は十進浮動小数点をサポートしません"
 
-#: c/c-decl.c:10747 c/c-decl.c:11013 c/c-parser.c:7842
+#: c/c-decl.c:10767 c/c-decl.c:11033 c/c-parser.c:7842
 #, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "固定小数点型はこのターゲットではサポートされていません"
 
-#: c/c-decl.c:10749
+#: c/c-decl.c:10769
 #, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C は固定小数点型をサポートしません"
 
-#: c/c-decl.c:10784
+#: c/c-decl.c:10804
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr ""
 
-#: c/c-decl.c:10797
+#: c/c-decl.c:10817
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr ""
 
-#: c/c-decl.c:10845
+#: c/c-decl.c:10865
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qE は宣言の開始ではありません"
 
-#: c/c-decl.c:10866
+#: c/c-decl.c:10886
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<auto%>"
 msgid "%qE used with %<auto%>"
 msgstr "%<__thread%> が %<auto%> と併せて使用されています"
 
-#: c/c-decl.c:10868
+#: c/c-decl.c:10888
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<register%>"
 msgid "%qE used with %<register%>"
 msgstr "%<__thread%> が %<register%> と併せて使用されています"
 
-#: c/c-decl.c:10870
+#: c/c-decl.c:10890
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<typedef%>"
 msgid "%qE used with %<typedef%>"
 msgstr "%<__thread%> が %<typedef%> と併せて使用されています"
 
-#: c/c-decl.c:10884 c/c-parser.c:7360
+#: c/c-decl.c:10904 c/c-parser.c:7360
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "ISO C99 does not support %qE"
 msgstr "%s は %s をサポートしません"
 
-#: c/c-decl.c:10887 c/c-parser.c:7363
+#: c/c-decl.c:10907 c/c-parser.c:7363
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<long long%>"
 msgid "ISO C90 does not support %qE"
 msgstr "ISO C90 は %<long long%> をサポートしません"
 
-#: c/c-decl.c:10899
+#: c/c-decl.c:10919
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<__thread%> が %<extern%> の前にあります"
 
-#: c/c-decl.c:10908
+#: c/c-decl.c:10928
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<__thread%> が %<static%> の前にあります"
 
-#: c/c-decl.c:10921
+#: c/c-decl.c:10941
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr ""
 
-#: c/c-decl.c:10929
+#: c/c-decl.c:10949
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr "宣言指定内に複数の記憶域クラスがあります"
 
-#: c/c-decl.c:10937
+#: c/c-decl.c:10957
 #, fuzzy, gcc-internal-format
 #| msgid "%qs must be used with %qs"
 msgid "%qs used with %qE"
 msgstr "%qs は %qs と併用しなければいけません"
 
-#: c/c-decl.c:11010
+#: c/c-decl.c:11030
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "%<_Sat%> が %<_Fract%> または %<_Accum%> 無しで使用されています"
 
-#: c/c-decl.c:11025
+#: c/c-decl.c:11045
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C は単なる %<complex%> を %<double complex%> を意味するものとしてはサポートしません"
 
-#: c/c-decl.c:11076 c/c-decl.c:11092 c/c-decl.c:11118
+#: c/c-decl.c:11096 c/c-decl.c:11112 c/c-decl.c:11138
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C は複素整数型をサポートしません"
 
-#: c/c-decl.c:11514 cp/semantics.c:5348
+#: c/c-decl.c:11534 cp/semantics.c:5351
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:11518 cp/semantics.c:5352
+#: c/c-decl.c:11538 cp/semantics.c:5355
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.c:385 c/c-typeck.c:11426 cp/typeck.c:4680
+#: c/c-fold.c:385 c/c-typeck.c:11431 cp/typeck.c:4680
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count is negative"
 msgid "left shift of negative value"
 msgstr "左シフト回数が負です"
 
-#: c/c-fold.c:395 c/c-typeck.c:11435 cp/typeck.c:4688
+#: c/c-fold.c:395 c/c-typeck.c:11440 cp/typeck.c:4688
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "左シフト回数が負です"
 
-#: c/c-fold.c:396 c/c-typeck.c:11365 cp/typeck.c:4633
+#: c/c-fold.c:396 c/c-typeck.c:11370 cp/typeck.c:4633
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "右シフト回数が負です"
 
-#: c/c-fold.c:404 c/c-typeck.c:11454 cp/typeck.c:4696
+#: c/c-fold.c:404 c/c-typeck.c:11459 cp/typeck.c:4696
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "左シフト回数 >= 型の幅となっています"
 
-#: c/c-fold.c:405 c/c-typeck.c:11389 cp/typeck.c:4641
+#: c/c-fold.c:405 c/c-typeck.c:11394 cp/typeck.c:4641
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "右シフト回数 >= 型の幅となっています"
 
-#: c/c-fold.c:412 c/c-typeck.c:11446
+#: c/c-fold.c:412 c/c-typeck.c:11451
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count >= width of type"
 msgid "left shift count >= width of vector element"
 msgstr "左シフト回数 >= 型の幅となっています"
 
-#: c/c-fold.c:413 c/c-typeck.c:11376
+#: c/c-fold.c:413 c/c-typeck.c:11381
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count >= width of type"
 msgid "right shift count >= width of vector element"
@@ -39094,7 +39138,7 @@
 msgid "to match this %qs"
 msgstr ""
 
-#: c/c-parser.c:1216 cp/parser.c:28484
+#: c/c-parser.c:1216 cp/parser.c:28481
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr "行末 (EOL) が予期されます"
@@ -39136,7 +39180,7 @@
 msgstr "不明な型名 %qE です"
 
 #: c/c-parser.c:1848 c/c-parser.c:11129 c/c-parser.c:16147 c/c-parser.c:16585
-#: c/c-parser.c:17061 cp/parser.c:36007 cp/parser.c:38993
+#: c/c-parser.c:17061 cp/parser.c:36004 cp/parser.c:38990
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "宣言指定が予期されます"
@@ -39152,7 +39196,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "%<;%>、識別子または %<(%> が予期されます"
 
-#: c/c-parser.c:1906 cp/parser.c:30161 cp/parser.c:30235
+#: c/c-parser.c:1906 cp/parser.c:30158 cp/parser.c:30232
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr ""
@@ -39209,7 +39253,7 @@
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr ""
 
-#: c/c-parser.c:2220 cp/parser.c:13002 cp/parser.c:13159
+#: c/c-parser.c:2220 cp/parser.c:12999 cp/parser.c:13156
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "%<,%> または %<;%> が予期されます"
@@ -39237,7 +39281,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C90 は %<_Static_assert%> をサポートしません"
 
-#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38634
+#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38631
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr "文字列リテラルが予期されます"
@@ -39304,13 +39348,13 @@
 #: c/c-parser.c:10745 c/c-parser.c:10798 c/c-parser.c:10814 c/c-parser.c:10860
 #: c/c-parser.c:11496 c/c-parser.c:11537 c/c-parser.c:13445 c/c-parser.c:13681
 #: c/c-parser.c:15544 c/c-parser.c:18218 c/gimple-parser.c:1058
-#: c/gimple-parser.c:1096 cp/parser.c:28487 cp/parser.c:31013
-#: cp/parser.c:31043 cp/parser.c:31113 cp/parser.c:33230 cp/parser.c:38350
+#: c/gimple-parser.c:1096 cp/parser.c:28484 cp/parser.c:31010
+#: cp/parser.c:31040 cp/parser.c:31110 cp/parser.c:33227 cp/parser.c:38347
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "識別子が予期されます"
 
-#: c/c-parser.c:2995 cp/parser.c:18384
+#: c/c-parser.c:2995 cp/parser.c:18381
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "列挙型リストの最後にコンマがあります"
@@ -39481,12 +39525,12 @@
 msgid "expected statement"
 msgstr "文が予期されます"
 
-#: c/c-parser.c:5639 cp/parser.c:12516
+#: c/c-parser.c:5639 cp/parser.c:12513
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "%<if%> 文内の空の本体は中括弧で括ることを推奨します"
 
-#: c/c-parser.c:5681 cp/parser.c:12519
+#: c/c-parser.c:5681 cp/parser.c:12516
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "%<else%> 文内の空の本体は中括弧で括ることを推奨します"
@@ -39859,7 +39903,7 @@
 msgid "%<__builtin_complex%> operands of different types"
 msgstr "%<__builtin_longjmp%> の第二引数は 1 でなければいけません"
 
-#: c/c-parser.c:8891 cp/parser.c:6918
+#: c/c-parser.c:8891 cp/parser.c:6921
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgid "wrong number of arguments to %<__builtin_shuffle%>"
@@ -39920,79 +39964,79 @@
 msgid "no type or storage class may be specified here,"
 msgstr "型または記憶域クラスがここで指定されていません、"
 
-#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31073
+#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31070
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "不明な property 属性です"
 
-#: c/c-parser.c:10682 cp/parser.c:31033
+#: c/c-parser.c:10682 cp/parser.c:31030
 #, fuzzy, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "%<#pragma pack%> の後に %<(%> がありません - 無視されました"
 
-#: c/c-parser.c:10685 cp/parser.c:31036
+#: c/c-parser.c:10685 cp/parser.c:31033
 #, fuzzy, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "%<#pragma pack%> の後に %<(%> がありません - 無視されました"
 
-#: c/c-parser.c:10699 cp/parser.c:31051
+#: c/c-parser.c:10699 cp/parser.c:31048
 #, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "%<setter%> 属性は一回のみ指定できます"
 
-#: c/c-parser.c:10704 cp/parser.c:31057
+#: c/c-parser.c:10704 cp/parser.c:31054
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr "setter 名は %<:%> で終端されなければいけません"
 
-#: c/c-parser.c:10711 cp/parser.c:31065
+#: c/c-parser.c:10711 cp/parser.c:31062
 #, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "%<getter%> 属性は一回のみ指定できます"
 
-#: c/c-parser.c:10905 cp/parser.c:38674
+#: c/c-parser.c:10905 cp/parser.c:38671
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
 #: c/c-parser.c:10949 c/c-parser.c:16582 c/c-parser.c:16840 c/c-parser.c:16899
-#: c/c-parser.c:16983 cp/parser.c:36004 cp/parser.c:36298 cp/parser.c:36386
-#: cp/parser.c:36457 cp/parser.c:38721 cp/parser.c:38736 cp/parser.c:38752
-#: cp/parser.c:38768 cp/parser.c:38784 cp/parser.c:38811 cp/parser.c:38824
-#: cp/parser.c:38847 cp/parser.c:38860
+#: c/c-parser.c:16983 cp/parser.c:36001 cp/parser.c:36295 cp/parser.c:36383
+#: cp/parser.c:36454 cp/parser.c:38718 cp/parser.c:38733 cp/parser.c:38749
+#: cp/parser.c:38765 cp/parser.c:38781 cp/parser.c:38808 cp/parser.c:38821
+#: cp/parser.c:38844 cp/parser.c:38857
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp flush%> may only be used in compound statements"
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<#pragma omp flush%> は複合文内でのみ使用できます"
 
-#: c/c-parser.c:10972 cp/parser.c:38837
+#: c/c-parser.c:10972 cp/parser.c:38834
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<#pragma GCC pch_preprocess%> は最初に無ければいけません"
 
-#: c/c-parser.c:11050 cp/parser.c:38918
+#: c/c-parser.c:11050 cp/parser.c:38915
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr ""
 
-#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38947 cp/parser.c:38980
+#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38944 cp/parser.c:38977
 #, fuzzy, gcc-internal-format
 #| msgid "for statement expected"
 msgid "for, while or do statement expected"
 msgstr "for 文が予期されます"
 
-#: c/c-parser.c:11111 cp/parser.c:38711
+#: c/c-parser.c:11111 cp/parser.c:38708
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%> は最初に無ければいけません"
 
-#: c/c-parser.c:11421 cp/parser.c:31457
+#: c/c-parser.c:11421 cp/parser.c:31454
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "%qs 句が多すぎます"
 
-#: c/c-parser.c:11443 cp/parser.c:31994
+#: c/c-parser.c:11443 cp/parser.c:31991
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "expected integer expression before ')'"
@@ -40009,59 +40053,59 @@
 msgid "%qD is not a variable"
 msgstr "%qD は変数ではありません"
 
-#: c/c-parser.c:11746 cp/semantics.c:6808
+#: c/c-parser.c:11746 cp/semantics.c:6811
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qD is not a pointer variable"
 msgstr "%qD は変数ではありません"
 
-#: c/c-parser.c:11788 cp/parser.c:32073
+#: c/c-parser.c:11788 cp/parser.c:32070
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:11865 cp/parser.c:32137
+#: c/c-parser.c:11865 cp/parser.c:32134
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<none%> or %<present%>"
 msgstr "%<none%> または %<shared%> が予期されます"
 
-#: c/c-parser.c:11867 cp/parser.c:32139
+#: c/c-parser.c:11867 cp/parser.c:32136
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "%<none%> または %<shared%> が予期されます"
 
-#: c/c-parser.c:11968 cp/parser.c:32242
+#: c/c-parser.c:11968 cp/parser.c:32239
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "%<;%>、%<,%> または %<)%> が予期されます"
 
-#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32260
-#: cp/parser.c:36290 cp/parser.c:36378
+#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32257
+#: cp/parser.c:36287 cp/parser.c:36375
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<catch%>"
 msgid "expected %<data%>"
 msgstr "%<catch%> が予期されます"
 
-#: c/c-parser.c:12035 cp/parser.c:32313
+#: c/c-parser.c:12035 cp/parser.c:32310
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:12042 cp/parser.c:32320
+#: c/c-parser.c:12042 cp/parser.c:32317
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<if%> clauses"
 msgstr "%qs 句が多すぎます"
 
-#: c/c-parser.c:12044 cp/parser.c:32322
+#: c/c-parser.c:12044 cp/parser.c:32319
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<if%> clauses without modifier"
 msgstr "%qs 句が多すぎます"
 
-#: c/c-parser.c:12050 cp/parser.c:32328
+#: c/c-parser.c:12050 cp/parser.c:32325
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -40084,93 +40128,93 @@
 msgid "%<num_tasks%> value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: c/c-parser.c:12229 cp/semantics.c:6992
+#: c/c-parser.c:12229 cp/semantics.c:6995
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<grainsize%> value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: c/c-parser.c:12276 cp/semantics.c:7021
+#: c/c-parser.c:12276 cp/semantics.c:7024
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<priority%> value must be non-negative"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32545 cp/parser.c:32552
+#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32542 cp/parser.c:32549
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<throw%>"
 msgid "expected %<tofrom%>"
 msgstr "%<throw%> が予期されます"
 
-#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32561 cp/parser.c:32568
+#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32558 cp/parser.c:32565
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>"
 msgid "expected %<scalar%>"
 msgstr "%<class%> が予期されます"
 
-#: c/c-parser.c:12425 cp/semantics.c:6299
+#: c/c-parser.c:12425 cp/semantics.c:6302
 #, fuzzy, gcc-internal-format
 #| msgid "index must be integer"
 msgid "%qs expression must be integral"
 msgstr "添え字は整数でなければいけません"
 
-#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6331
+#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6334
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%qs value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: c/c-parser.c:12499 cp/parser.c:31853
+#: c/c-parser.c:12499 cp/parser.c:31850
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments"
 msgid "too many %<static%> arguments"
 msgstr "引数が多すぎます"
 
-#: c/c-parser.c:12533 cp/parser.c:31886
+#: c/c-parser.c:12533 cp/parser.c:31883
 #, fuzzy, gcc-internal-format
 msgid "unexpected argument"
 msgstr "packed 属性は必要ありません"
 
-#: c/c-parser.c:12699 cp/semantics.c:7120
+#: c/c-parser.c:12699 cp/semantics.c:7123
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute argument not an integer constant"
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "%qE 属性の引数が整数定数ではありません"
 
-#: c/c-parser.c:12765 cp/parser.c:32626
+#: c/c-parser.c:12765 cp/parser.c:32623
 #, fuzzy, gcc-internal-format
 #| msgid "ordered comparison of pointer with integer zero"
 msgid "ordered argument needs positive constant integer expression"
 msgstr "整数 0 とポインタとの順序比較です"
 
-#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37643
+#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37640
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, or %<||%>"
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "%<+%>、%<*%>、%<-%>、%<&%>、%<^%>、%<|%>、%<&&%> または %<||%> が予期されます"
 
-#: c/c-parser.c:12967 cp/parser.c:32840
+#: c/c-parser.c:12967 cp/parser.c:32837
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr ""
 
-#: c/c-parser.c:13021 cp/parser.c:32856
+#: c/c-parser.c:13021 cp/parser.c:32853
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "スケジュール %<runtime%> は %<chunk_size%> 仮引数をとりません"
 
-#: c/c-parser.c:13025 cp/parser.c:32859
+#: c/c-parser.c:13025 cp/parser.c:32856
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "スケジュール %<auto%> は %<chunk_size%> 仮引数をとりません"
 
-#: c/c-parser.c:13037 cp/semantics.c:6389
+#: c/c-parser.c:13037 cp/semantics.c:6392
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "chunk size value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: c/c-parser.c:13060 cp/parser.c:32879
+#: c/c-parser.c:13060 cp/parser.c:32876
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "`無効なスケジュールの種類です"
@@ -40181,13 +40225,13 @@
 msgid "%<num_teams%> value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: c/c-parser.c:13226 cp/semantics.c:6479
+#: c/c-parser.c:13226 cp/semantics.c:6482
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<thread_limit%> value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: c/c-parser.c:13271 cp/semantics.c:6589
+#: c/c-parser.c:13271 cp/semantics.c:6592
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr ""
@@ -40207,19 +40251,19 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:13584 cp/parser.c:33374 cp/parser.c:33599
+#: c/c-parser.c:13584 cp/parser.c:33371 cp/parser.c:33596
 #, fuzzy, gcc-internal-format
 #| msgid "invalid schedule kind"
 msgid "invalid depend kind"
 msgstr "`無効なスケジュールの種類です"
 
-#: c/c-parser.c:13669 cp/parser.c:33447
+#: c/c-parser.c:13669 cp/parser.c:33444
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mask"
 msgid "invalid map kind"
 msgstr "無効なマスクです"
 
-#: c/c-parser.c:13767 cp/parser.c:33546
+#: c/c-parser.c:13767 cp/parser.c:33543
 #, fuzzy, gcc-internal-format
 #| msgid "invalid schedule kind"
 msgid "invalid dist_schedule kind"
@@ -40231,72 +40275,72 @@
 msgid "invalid proc_bind kind"
 msgstr "`無効なスケジュールの種類です"
 
-#: c/c-parser.c:14059 cp/parser.c:33825
+#: c/c-parser.c:14059 cp/parser.c:33822
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected %<#pragma acc%> clause"
 msgstr "%<#pragma omp%> 句が予期されます"
 
-#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33836 cp/parser.c:34143
+#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33833 cp/parser.c:34140
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs は %qs 用には有効ではありません"
 
-#: c/c-parser.c:14214 cp/parser.c:34010
+#: c/c-parser.c:14214 cp/parser.c:34007
 #, fuzzy, gcc-internal-format
 #| msgid "%qs must be used with %qs"
 msgid "%qs must be the first clause of %qs"
 msgstr "%qs は %qs と併用しなければいけません"
 
-#: c/c-parser.c:14334 cp/parser.c:34132
+#: c/c-parser.c:14334 cp/parser.c:34129
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "%<#pragma omp%> 句が予期されます"
 
-#: c/c-parser.c:14472 cp/parser.c:36803
+#: c/c-parser.c:14472 cp/parser.c:36800
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14482 cp/parser.c:36813
+#: c/c-parser.c:14482 cp/parser.c:36810
 #, fuzzy, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr "セクション属性は `%s' には使えません"
 
-#: c/c-parser.c:14502 cp/parser.c:36833
+#: c/c-parser.c:14502 cp/parser.c:36830
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr ""
 
-#: c/c-parser.c:14513 cp/parser.c:36844
+#: c/c-parser.c:14513 cp/parser.c:36841
 #, fuzzy, gcc-internal-format
 #| msgid "variably modified field at file scope"
 msgid "invalid OpenACC clause at file scope"
 msgstr "ファイルスコープの可変フィールドです"
 
-#: c/c-parser.c:14520 cp/parser.c:36851
+#: c/c-parser.c:14520 cp/parser.c:36848
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "%<extern%> 変数 %qD の宣言が %<for%> ループ初期化宣言内にあります"
 
-#: c/c-parser.c:14528 cp/parser.c:36859
+#: c/c-parser.c:14528 cp/parser.c:36856
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14540 cp/parser.c:36871
+#: c/c-parser.c:14540 cp/parser.c:36868
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14632 cp/parser.c:36957
+#: c/c-parser.c:14632 cp/parser.c:36954
 #, fuzzy, gcc-internal-format
 #| msgid "expected a string after %<#pragma message%>"
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "%<#pragma message%> の後に文字列が予期されます"
 
-#: c/c-parser.c:14648 cp/parser.c:36974
+#: c/c-parser.c:14648 cp/parser.c:36971
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr ""
@@ -40312,7 +40356,7 @@
 msgid "expected function name"
 msgstr "関数が予期されます"
 
-#: c/c-parser.c:14893 cp/parser.c:38064
+#: c/c-parser.c:14893 cp/parser.c:38061
 #, fuzzy, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr "メンバ関数の名前を欠いています"
@@ -40322,44 +40366,44 @@
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14953 cp/parser.c:38118 cp/parser.c:38160
+#: c/c-parser.c:14953 cp/parser.c:38115 cp/parser.c:38157
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14970 cp/parser.c:38174
+#: c/c-parser.c:14970 cp/parser.c:38171
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> already applied to %qD"
 msgstr ""
 
-#: c/c-parser.c:14979 cp/parser.c:38183
+#: c/c-parser.c:14979 cp/parser.c:38180
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr ""
 
-#: c/c-parser.c:14980 cp/parser.c:38184
+#: c/c-parser.c:14980 cp/parser.c:38181
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma align%> must appear before the declaration of %D, ignoring"
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<#pragma align%> は %D の前に現れなければいけません。無視しています"
 
-#: c/c-parser.c:15023 cp/parser.c:37152
+#: c/c-parser.c:15023 cp/parser.c:37149
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
 
-#: c/c-parser.c:15435 cp/parser.c:34511 cp/parser.c:34537
+#: c/c-parser.c:15435 cp/parser.c:34508 cp/parser.c:34534
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operator for %<#pragma omp atomic%>"
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "%<#pragma omp atomic%> 用の無効な演算子です"
 
-#: c/c-parser.c:15439 cp/parser.c:34568 cp/parser.c:34584
+#: c/c-parser.c:15439 cp/parser.c:34565 cp/parser.c:34581
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "%<#pragma omp atomic%> 用の無効な演算子です"
 
-#: c/c-parser.c:15488 cp/semantics.c:8401 cp/semantics.c:8411
+#: c/c-parser.c:15488 cp/semantics.c:8404 cp/semantics.c:8414
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
@@ -40369,22 +40413,22 @@
 msgid "expected %<(%> or end of line"
 msgstr "%<(%> またはファイル終端 (EOF) が予期されます"
 
-#: c/c-parser.c:15619 cp/parser.c:35103
+#: c/c-parser.c:15619 cp/parser.c:35100
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:15630 cp/parser.c:35114
+#: c/c-parser.c:15630 cp/parser.c:35111
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:15648 cp/parser.c:35141
+#: c/c-parser.c:15648 cp/parser.c:35138
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "for 文が予期されます"
 
-#: c/c-parser.c:15718 cp/semantics.c:8066 cp/semantics.c:8153
+#: c/c-parser.c:15718 cp/semantics.c:8069 cp/semantics.c:8156
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr ""
@@ -40394,76 +40438,76 @@
 msgid "not enough perfectly nested loops"
 msgstr "ループが完全な入れ子になっていません"
 
-#: c/c-parser.c:15862 cp/parser.c:35364
+#: c/c-parser.c:15862 cp/parser.c:35361
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.c:15909 cp/parser.c:35184 cp/parser.c:35226 cp/pt.c:16385
+#: c/c-parser.c:15909 cp/parser.c:35181 cp/parser.c:35223 cp/pt.c:16407
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr ""
 
-#: c/c-parser.c:16000 cp/parser.c:35437
+#: c/c-parser.c:16000 cp/parser.c:35434
 #, fuzzy, gcc-internal-format
 #| msgid "%<void%> as only parameter may not be qualified"
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "唯一の仮引数となる %<void%> には修飾子がつきません"
 
-#: c/c-parser.c:16166 cp/parser.c:35600
+#: c/c-parser.c:16166 cp/parser.c:35597
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr "%<#pragma omp barrier%> は複合文内でのみ使用できます"
 
-#: c/c-parser.c:16374 cp/parser.c:35799
+#: c/c-parser.c:16374 cp/parser.c:35796
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<operator%>"
 msgid "expected %<for%> after %qs"
 msgstr "%<operator%> が予期されます"
 
-#: c/c-parser.c:16573 cp/parser.c:35995
+#: c/c-parser.c:16573 cp/parser.c:35992
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<using%>"
 msgid "expected %<point%>"
 msgstr "%<using%> が予期されます"
 
-#: c/c-parser.c:16793 cp/parser.c:36232
+#: c/c-parser.c:16793 cp/parser.c:36229
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16806 cp/parser.c:36245
+#: c/c-parser.c:16806 cp/parser.c:36242
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16853 cp/parser.c:36470
+#: c/c-parser.c:16853 cp/parser.c:36467
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:16925 cp/parser.c:36325
+#: c/c-parser.c:16925 cp/parser.c:36322
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16937 cp/parser.c:36337
+#: c/c-parser.c:16937 cp/parser.c:36334
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17011 cp/parser.c:36414
+#: c/c-parser.c:17011 cp/parser.c:36411
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17024 cp/parser.c:36427
+#: c/c-parser.c:17024 cp/parser.c:36424
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17238 cp/parser.c:36680
+#: c/c-parser.c:17238 cp/parser.c:36677
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -40484,34 +40528,34 @@
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17395 cp/parser.c:37273
+#: c/c-parser.c:17395 cp/parser.c:37270
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17474 cp/parser.c:37343
+#: c/c-parser.c:17474 cp/parser.c:37340
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> with clauses in between %<#pragma omp declare target%> without clauses and %<#pragma omp end declare target%>"
 msgstr ""
 
-#: c/c-parser.c:17493 cp/parser.c:37362
+#: c/c-parser.c:17493 cp/parser.c:37359
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17534 cp/parser.c:37409
+#: c/c-parser.c:17534 cp/parser.c:37406
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<try%>"
 msgid "expected %<target%>"
 msgstr "%<try%> が予期されます"
 
-#: c/c-parser.c:17541 cp/parser.c:37416
+#: c/c-parser.c:17541 cp/parser.c:37413
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<decltype%>"
 msgid "expected %<declare%>"
 msgstr "%<decltype%> が予期されます"
 
-#: c/c-parser.c:17547 cp/parser.c:37423
+#: c/c-parser.c:17547 cp/parser.c:37420
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC pop_options%> without a corresponding %<#pragma GCC push_options%>"
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
@@ -40569,48 +40613,48 @@
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:17947 cp/parser.c:37868
+#: c/c-parser.c:17947 cp/parser.c:37865
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp section%> or %<}%>"
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr "%<#pragma omp section%> または %<}%> が予期されます"
 
-#: c/c-parser.c:18162 cp/semantics.c:7531
+#: c/c-parser.c:18162 cp/semantics.c:7534
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE は最初に使用した後に %<threadprivate%> と宣言されています"
 
-#: c/c-parser.c:18164 cp/semantics.c:7533
+#: c/c-parser.c:18164 cp/semantics.c:7536
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "自動変数 %qE は %<threadprivate%> になることは出来ません"
 
-#: c/c-parser.c:18168 cp/semantics.c:7535
+#: c/c-parser.c:18168 cp/semantics.c:7538
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%<threadprivate%> %qE は不完全型を持っています"
 
-#: c/c-parser.c:18368 cp/parser.c:38565
+#: c/c-parser.c:18368 cp/parser.c:38562
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:18374 cp/parser.c:38571
+#: c/c-parser.c:18374 cp/parser.c:38568
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
 
-#: c/c-parser.c:18383 cp/parser.c:38580
+#: c/c-parser.c:18383 cp/parser.c:38577
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.c:18385 cp/parser.c:38583
+#: c/c-parser.c:18385 cp/parser.c:38580
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.c:18391 cp/parser.c:38589
+#: c/c-parser.c:18391 cp/parser.c:38586
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
@@ -40626,7 +40670,7 @@
 msgid "%qD has an incomplete type %qT"
 msgstr "%qD は不完全型を持っています"
 
-#: c/c-typeck.c:237 c/c-typeck.c:9994 c/c-typeck.c:10036 cp/call.c:4147
+#: c/c-typeck.c:237 c/c-typeck.c:9999 c/c-typeck.c:10041 cp/call.c:4147
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "void 式の無効な使用法です"
@@ -40706,13 +40750,13 @@
 msgid "converting an array compound literal to a pointer is ill-formed in C++"
 msgstr "複合リテラル内での型定義は C++ では無効です"
 
-#: c/c-typeck.c:2417 c/c-typeck.c:8641
+#: c/c-typeck.c:2417 c/c-typeck.c:8646
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%qT has no member named %qE; did you mean %qE?"
 msgstr "%qT は %qE という名前のメンバを持っていません"
 
-#: c/c-typeck.c:2421 c/c-typeck.c:8645
+#: c/c-typeck.c:2421 c/c-typeck.c:8650
 #, gcc-internal-format
 msgid "%qT has no member named %qE"
 msgstr "%qT は %qE という名前のメンバを持っていません"
@@ -40915,474 +40959,474 @@
 msgid "pointer to a function used in subtraction"
 msgstr "関数ポインタの差を求めようとしています"
 
-#: c/c-typeck.c:3847
+#: c/c-typeck.c:3852
 #, gcc-internal-format
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "不完全型へのポインタに関する計算です"
 
-#: c/c-typeck.c:3852 cp/typeck.c:5562
+#: c/c-typeck.c:3857 cp/typeck.c:5562
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr "不完全型へのポインタに関する計算です"
 
-#: c/c-typeck.c:4283
+#: c/c-typeck.c:4288
 #, fuzzy, gcc-internal-format
 #| msgid "expected boolean expression"
 msgid "%<~%> on a boolean expression"
 msgstr "真偽式が予期されます"
 
-#: c/c-typeck.c:4287
+#: c/c-typeck.c:4292
 #, gcc-internal-format
 msgid "did you mean to use logical not?"
 msgstr ""
 
-#: c/c-typeck.c:4296
+#: c/c-typeck.c:4301
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support %<~%> for complex conjugation"
 msgstr "ISO C は複素共役用の `~' を受け付けません"
 
-#: c/c-typeck.c:4335
+#: c/c-typeck.c:4340
 #, gcc-internal-format
 msgid "wrong type argument to unary exclamation mark"
 msgstr "単項感嘆符(!)への引数の型が間違っています"
 
-#: c/c-typeck.c:4393
+#: c/c-typeck.c:4398
 #, gcc-internal-format
 msgid "increment of enumeration value is invalid in C++"
 msgstr "列挙値の増分は C++ では無効です"
 
-#: c/c-typeck.c:4396
+#: c/c-typeck.c:4401
 #, gcc-internal-format
 msgid "decrement of enumeration value is invalid in C++"
 msgstr "列挙値の減分は C++ では無効です"
 
-#: c/c-typeck.c:4403
+#: c/c-typeck.c:4408
 #, fuzzy, gcc-internal-format
 #| msgid "expected boolean expression"
 msgid "increment of a boolean expression"
 msgstr "真偽式が予期されます"
 
-#: c/c-typeck.c:4406
+#: c/c-typeck.c:4411
 #, fuzzy, gcc-internal-format
 #| msgid "expected boolean expression"
 msgid "decrement of a boolean expression"
 msgstr "真偽式が予期されます"
 
-#: c/c-typeck.c:4422
+#: c/c-typeck.c:4427
 #, gcc-internal-format
 msgid "ISO C does not support %<++%> and %<--%> on complex types"
 msgstr "ISO C は複素数型に関する %<++%> と %<--%> をサポートしません"
 
-#: c/c-typeck.c:4447 c/c-typeck.c:4481
+#: c/c-typeck.c:4452 c/c-typeck.c:4486
 #, gcc-internal-format
 msgid "wrong type argument to increment"
 msgstr "増分する引数の型が間違っています"
 
-#: c/c-typeck.c:4449 c/c-typeck.c:4484
+#: c/c-typeck.c:4454 c/c-typeck.c:4489
 #, gcc-internal-format
 msgid "wrong type argument to decrement"
 msgstr "減分する引数の型が間違っています"
 
-#: c/c-typeck.c:4469
+#: c/c-typeck.c:4474
 #, fuzzy, gcc-internal-format
 msgid "increment of pointer to an incomplete type %qT"
 msgstr "不完全型へのポインタに対する演算"
 
-#: c/c-typeck.c:4473
+#: c/c-typeck.c:4478
 #, fuzzy, gcc-internal-format
 msgid "decrement of pointer to an incomplete type %qT"
 msgstr "不完全型のポインタへの間接参照"
 
-#: c/c-typeck.c:4577
+#: c/c-typeck.c:4582
 #, gcc-internal-format
 msgid "taking address of expression of type %<void%>"
 msgstr "%<void%> 型の式のアドレスを取得しています"
 
-#: c/c-typeck.c:4636
+#: c/c-typeck.c:4641
 #, gcc-internal-format
 msgid "cannot take address of bit-field %qD"
 msgstr "ビットフィールド %qD のアドレスを取得できません"
 
-#: c/c-typeck.c:4649
+#: c/c-typeck.c:4654
 #, fuzzy, gcc-internal-format
 msgid "cannot take address of scalar with reverse storage order"
 msgstr "`this' は右辺値式であり、そのアドレスを取ることはできません"
 
-#: c/c-typeck.c:4657
+#: c/c-typeck.c:4662
 #, fuzzy, gcc-internal-format
 #| msgid "address of register variable %qD requested"
 msgid "address of array with reverse scalar storage order requested"
 msgstr "レジスタ変数 %qD のアドレスが要求されました"
 
-#: c/c-typeck.c:4838
+#: c/c-typeck.c:4843
 #, gcc-internal-format
 msgid "global register variable %qD used in nested function"
 msgstr "帯域レジスタ変数 %qD が入れ子になった関数内で使用されています"
 
-#: c/c-typeck.c:4841
+#: c/c-typeck.c:4846
 #, gcc-internal-format
 msgid "register variable %qD used in nested function"
 msgstr "レジスタ変数 %qD が入れ子になった関数内で使用されています"
 
-#: c/c-typeck.c:4846
+#: c/c-typeck.c:4851
 #, gcc-internal-format
 msgid "address of global register variable %qD requested"
 msgstr "大域レジスタ変数 %qD のアドレスが要求されました"
 
-#: c/c-typeck.c:4848
+#: c/c-typeck.c:4853
 #, gcc-internal-format
 msgid "address of register variable %qD requested"
 msgstr "レジスタ変数 %qD のアドレスが要求されました"
 
-#: c/c-typeck.c:4951
+#: c/c-typeck.c:4956
 #, gcc-internal-format
 msgid "non-lvalue array in conditional expression"
 msgstr ""
 
-#: c/c-typeck.c:5033
+#: c/c-typeck.c:5038
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other result of conditional"
 msgstr ""
 
-#: c/c-typeck.c:5092 c/c-typeck.c:5098
+#: c/c-typeck.c:5097 c/c-typeck.c:5103
 #, gcc-internal-format
 msgid "operand of ?: changes signedness from %qT to %qT due to unsignedness of other operand"
 msgstr ""
 
-#: c/c-typeck.c:5115
+#: c/c-typeck.c:5120
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr with only one void side"
 msgstr "ISO C は片側だけが void となる条件式を禁止しています"
 
-#: c/c-typeck.c:5132
+#: c/c-typeck.c:5137
 #, gcc-internal-format
 msgid "pointers to disjoint address spaces used in conditional expression"
 msgstr ""
 
-#: c/c-typeck.c:5143 c/c-typeck.c:5160
+#: c/c-typeck.c:5148 c/c-typeck.c:5165
 #, fuzzy, gcc-internal-format
 #| msgid "pointer type mismatch in conditional expression"
 msgid "pointer to array loses qualifier in conditional expression"
 msgstr "条件式内でポインタ型が一致しません"
 
-#: c/c-typeck.c:5148 c/c-typeck.c:5165
+#: c/c-typeck.c:5153 c/c-typeck.c:5170
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr between %<void *%> and function pointer"
 msgstr "ISO C は %<void *%> と関数ポインタ間の比較式を禁止しています"
 
-#: c/c-typeck.c:5178
+#: c/c-typeck.c:5183
 #, gcc-internal-format
 msgid "pointer type mismatch in conditional expression"
 msgstr "条件式内でポインタ型が一致しません"
 
-#: c/c-typeck.c:5187 c/c-typeck.c:5198
+#: c/c-typeck.c:5192 c/c-typeck.c:5203
 #, gcc-internal-format
 msgid "pointer/integer type mismatch in conditional expression"
 msgstr "条件式内でポインタ型と整数型が適合しません"
 
-#: c/c-typeck.c:5336
+#: c/c-typeck.c:5341
 #, gcc-internal-format
 msgid "left-hand operand of comma expression has no effect"
 msgstr "カンマ演算子の左側の式に効力がありません"
 
-#: c/c-typeck.c:5354 c/c-typeck.c:10636
+#: c/c-typeck.c:5359 c/c-typeck.c:10641
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "right-hand operand of comma expression has no effect"
 msgstr "カンマ演算子の左側の式に効力がありません"
 
-#: c/c-typeck.c:5423
+#: c/c-typeck.c:5428
 msgid "cast adds %q#v qualifier to function type"
 msgstr ""
 
-#: c/c-typeck.c:5429
+#: c/c-typeck.c:5434
 msgid "cast discards %qv qualifier from pointer target type"
 msgstr ""
 
-#: c/c-typeck.c:5464
+#: c/c-typeck.c:5469
 #, gcc-internal-format
 msgid "to be safe all intermediate pointers in cast from %qT to %qT must be %<const%> qualified"
 msgstr ""
 
-#: c/c-typeck.c:5554
+#: c/c-typeck.c:5559
 #, gcc-internal-format
 msgid "cast specifies array type"
 msgstr "キャストが配列型を指定しています"
 
-#: c/c-typeck.c:5560
+#: c/c-typeck.c:5565
 #, gcc-internal-format
 msgid "cast specifies function type"
 msgstr "キャストは関数型を指定しています"
 
-#: c/c-typeck.c:5575
+#: c/c-typeck.c:5580
 #, gcc-internal-format
 msgid "ISO C forbids casting nonscalar to the same type"
 msgstr "ISO C は非スカラーから同じ型へのキャストを禁止しています"
 
-#: c/c-typeck.c:5595
+#: c/c-typeck.c:5600
 #, gcc-internal-format
 msgid "ISO C forbids casts to union type"
 msgstr "ISO C は共用体型へのキャストを禁止しています"
 
-#: c/c-typeck.c:5605
+#: c/c-typeck.c:5610
 #, gcc-internal-format
 msgid "cast to union type from type not present in union"
 msgstr "共用体の中にない型から共用体型へキャストしています"
 
-#: c/c-typeck.c:5640
+#: c/c-typeck.c:5645
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint generic address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5645
+#: c/c-typeck.c:5650
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to generic address space pointer from disjoint %s address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5650
+#: c/c-typeck.c:5655
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint %s address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5670
+#: c/c-typeck.c:5675
 #, gcc-internal-format
 msgid "cast increases required alignment of target type"
 msgstr ""
 
-#: c/c-typeck.c:5681
+#: c/c-typeck.c:5686
 #, gcc-internal-format
 msgid "cast from pointer to integer of different size"
 msgstr "ポインタから異なるサイズの整数へのキャストです"
 
-#: c/c-typeck.c:5686
+#: c/c-typeck.c:5691
 #, gcc-internal-format
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "型 %qT の関数呼び出しから一致しない型 %qT へのキャストです"
 
-#: c/c-typeck.c:5695 cp/typeck.c:7811
+#: c/c-typeck.c:5700 cp/typeck.c:7811
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "異なるサイズの整数からポインタへのキャストです"
 
-#: c/c-typeck.c:5709
+#: c/c-typeck.c:5714
 #, gcc-internal-format
 msgid "ISO C forbids conversion of function pointer to object pointer type"
 msgstr "ISO C は関数ポインタからオブジェクトポインタ型への変換を禁止しています"
 
-#: c/c-typeck.c:5718
+#: c/c-typeck.c:5723
 #, gcc-internal-format
 msgid "ISO C forbids conversion of object pointer to function pointer type"
 msgstr "ISO C はオブジェクトのポインタから関数のポインタ型への変換を禁止しています"
 
-#: c/c-typeck.c:5728
+#: c/c-typeck.c:5733
 #, fuzzy, gcc-internal-format
 #| msgid "can%'t convert from incomplete type %qT to %qT"
 msgid "cast between incompatible function types from %qT to %qT"
 msgstr "不完全型 %qT から %qT へ変換できません"
 
-#: c/c-typeck.c:5815
+#: c/c-typeck.c:5820
 #, gcc-internal-format
 msgid "defining a type in a cast is invalid in C++"
 msgstr "キャスト内での型定義は C++ 内では無効です"
 
-#: c/c-typeck.c:5856
+#: c/c-typeck.c:5861
 #, fuzzy, gcc-internal-format
 #| msgid "assignment suppression"
 msgid "assignment to expression with array type"
 msgstr "代入の抑制"
 
-#: c/c-typeck.c:5982
+#: c/c-typeck.c:5987
 #, gcc-internal-format
 msgid "enum conversion in assignment is invalid in C++"
 msgstr "代入内での列挙型の変換は C++ 内では無効です"
 
-#: c/c-typeck.c:6180 c/c-typeck.c:6202 c/c-typeck.c:6226
+#: c/c-typeck.c:6185 c/c-typeck.c:6207 c/c-typeck.c:6231
 #, gcc-internal-format
 msgid "(near initialization for %qs)"
 msgstr "(%qs 用の初期化付近)"
 
-#: c/c-typeck.c:6241
+#: c/c-typeck.c:6246
 #, gcc-internal-format
 msgid "array initialized from parenthesized string constant"
 msgstr "小括弧で括られた文字列定数で配列が初期化されています"
 
-#: c/c-typeck.c:6284 c/c-typeck.c:6476 c/c-typeck.c:6908
+#: c/c-typeck.c:6289 c/c-typeck.c:6481 c/c-typeck.c:6913
 #, gcc-internal-format
 msgid "expected %qT but argument is of type %qT"
 msgstr ""
 
-#: c/c-typeck.c:6471
+#: c/c-typeck.c:6476
 #, gcc-internal-format
 msgid "enum conversion when passing argument %d of %qE is invalid in C++"
 msgstr "%d 番目の %qE の引数を渡すときの列挙型の変換は C++ 内では無効です"
 
-#: c/c-typeck.c:6480
+#: c/c-typeck.c:6485
 #, fuzzy, gcc-internal-format
 #| msgid "enum conversion in assignment is invalid in C++"
 msgid "enum conversion from %qT to %qT in assignment is invalid in C++"
 msgstr "代入内での列挙型の変換は C++ 内では無効です"
 
-#: c/c-typeck.c:6484
+#: c/c-typeck.c:6489
 #, fuzzy, gcc-internal-format
 #| msgid "enum conversion in initialization is invalid in C++"
 msgid "enum conversion from %qT to %qT in initialization is invalid in C++"
 msgstr "初期化内での列挙型の変換は C++ では無効です"
 
-#: c/c-typeck.c:6489
+#: c/c-typeck.c:6494
 #, fuzzy, gcc-internal-format
 #| msgid "enum conversion in return is invalid in C++"
 msgid "enum conversion from %qT to %qT in return is invalid in C++"
 msgstr "return 内での列挙型の変換は C++ では無効です"
 
-#: c/c-typeck.c:6523
+#: c/c-typeck.c:6528
 #, fuzzy, gcc-internal-format
 msgid "cannot pass rvalue to reference parameter"
 msgstr "参照型に対して new を適用できません"
 
-#: c/c-typeck.c:6656 c/c-typeck.c:6942
+#: c/c-typeck.c:6661 c/c-typeck.c:6947
 msgid "passing argument %d of %qE makes %q#v qualified function pointer from unqualified"
 msgstr ""
 
-#: c/c-typeck.c:6659 c/c-typeck.c:6945
+#: c/c-typeck.c:6664 c/c-typeck.c:6950
 msgid "assignment makes %q#v qualified function pointer from unqualified"
 msgstr ""
 
-#: c/c-typeck.c:6662 c/c-typeck.c:6947
+#: c/c-typeck.c:6667 c/c-typeck.c:6952
 msgid "initialization makes %q#v qualified function pointer from unqualified"
 msgstr ""
 
-#: c/c-typeck.c:6665 c/c-typeck.c:6949
+#: c/c-typeck.c:6670 c/c-typeck.c:6954
 msgid "return makes %q#v qualified function pointer from unqualified"
 msgstr ""
 
-#: c/c-typeck.c:6673 c/c-typeck.c:6840 c/c-typeck.c:6883
+#: c/c-typeck.c:6678 c/c-typeck.c:6845 c/c-typeck.c:6888
 msgid "passing argument %d of %qE discards %qv qualifier from pointer target type"
 msgstr ""
 
-#: c/c-typeck.c:6675 c/c-typeck.c:6842 c/c-typeck.c:6885
+#: c/c-typeck.c:6680 c/c-typeck.c:6847 c/c-typeck.c:6890
 msgid "assignment discards %qv qualifier from pointer target type"
 msgstr ""
 
-#: c/c-typeck.c:6677 c/c-typeck.c:6844 c/c-typeck.c:6887
+#: c/c-typeck.c:6682 c/c-typeck.c:6849 c/c-typeck.c:6892
 msgid "initialization discards %qv qualifier from pointer target type"
 msgstr ""
 
-#: c/c-typeck.c:6679 c/c-typeck.c:6846 c/c-typeck.c:6889
+#: c/c-typeck.c:6684 c/c-typeck.c:6851 c/c-typeck.c:6894
 msgid "return discards %qv qualifier from pointer target type"
 msgstr ""
 
-#: c/c-typeck.c:6688
+#: c/c-typeck.c:6693
 #, gcc-internal-format
 msgid "ISO C prohibits argument conversion to union type"
 msgstr "ISO C では引数から共用体への変換を禁止しています"
 
-#: c/c-typeck.c:6750
+#: c/c-typeck.c:6755
 #, gcc-internal-format
 msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgstr ""
 
-#: c/c-typeck.c:6762
+#: c/c-typeck.c:6767
 #, gcc-internal-format
 msgid "passing argument %d of %qE from pointer to non-enclosed address space"
 msgstr ""
 
-#: c/c-typeck.c:6766
+#: c/c-typeck.c:6771
 #, gcc-internal-format
 msgid "assignment from pointer to non-enclosed address space"
 msgstr ""
 
-#: c/c-typeck.c:6770
+#: c/c-typeck.c:6775
 #, gcc-internal-format
 msgid "initialization from pointer to non-enclosed address space"
 msgstr ""
 
-#: c/c-typeck.c:6774
+#: c/c-typeck.c:6779
 #, gcc-internal-format
 msgid "return from pointer to non-enclosed address space"
 msgstr ""
 
-#: c/c-typeck.c:6792
+#: c/c-typeck.c:6797
 #, gcc-internal-format
 msgid "argument %d of %qE might be a candidate for a format attribute"
 msgstr "%d 番目の %qE の引数は format 属性の候補のようです"
 
-#: c/c-typeck.c:6798
+#: c/c-typeck.c:6803
 #, gcc-internal-format
 msgid "assignment left-hand side might be a candidate for a format attribute"
 msgstr "左辺への代入は format 属性の候補のようです"
 
-#: c/c-typeck.c:6803
+#: c/c-typeck.c:6808
 #, gcc-internal-format
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "左辺の初期化は format 属性の候補のようです"
 
-#: c/c-typeck.c:6808 cp/typeck.c:8891
+#: c/c-typeck.c:6813 cp/typeck.c:8891
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "戻り型は format 属性の候補のようです"
 
-#: c/c-typeck.c:6857
+#: c/c-typeck.c:6862
 #, gcc-internal-format
 msgid "ISO C forbids passing argument %d of %qE between function pointer and %<void *%>"
 msgstr ""
 
-#: c/c-typeck.c:6860
+#: c/c-typeck.c:6865
 #, gcc-internal-format
 msgid "ISO C forbids assignment between function pointer and %<void *%>"
 msgstr "ISO C は関数のポインタと %<void *%> 間の代入を禁止しています"
 
-#: c/c-typeck.c:6862
+#: c/c-typeck.c:6867
 #, gcc-internal-format
 msgid "ISO C forbids initialization between function pointer and %<void *%>"
 msgstr "ISO C は関数ポインタと %<void *%> 間の初期化を禁止しています"
 
-#: c/c-typeck.c:6864
+#: c/c-typeck.c:6869
 #, gcc-internal-format
 msgid "ISO C forbids return between function pointer and %<void *%>"
 msgstr "ISO C は関数ポインタと %<void *%> の間の戻りを禁止しています"
 
-#: c/c-typeck.c:6904
+#: c/c-typeck.c:6909
 #, gcc-internal-format
 msgid "pointer targets in passing argument %d of %qE differ in signedness"
 msgstr "%d 番目の %qE の引数を渡すときのポインタの先の符号が異なります"
 
-#: c/c-typeck.c:6913
+#: c/c-typeck.c:6918
 #, fuzzy, gcc-internal-format
 #| msgid "pointer targets in assignment differ in signedness"
 msgid "pointer targets in assignment from %qT to %qT differ in signedness"
 msgstr "代入でのポインタの先の符号が異なります"
 
-#: c/c-typeck.c:6918
+#: c/c-typeck.c:6923
 #, fuzzy, gcc-internal-format
 #| msgid "pointer targets in initialization differ in signedness"
 msgid "pointer targets in initialization of %qT from %qT differ in signedness"
 msgstr "初期化でのポインタの先の符号が異なります"
 
-#: c/c-typeck.c:6923
+#: c/c-typeck.c:6928
 #, fuzzy, gcc-internal-format
 #| msgid "pointer targets in passing argument %d of %qE differ in signedness"
 msgid "pointer targets in returning %qT from a function with return type %qT differ in signedness"
 msgstr "%d 番目の %qE の引数を渡すときのポインタの先の符号が異なります"
 
-#: c/c-typeck.c:6961
+#: c/c-typeck.c:6966
 #, gcc-internal-format
 msgid "passing argument %d of %qE from incompatible pointer type"
 msgstr "互換性のないポインタ型から %d 番目の %qE の引数に渡しています"
 
-#: c/c-typeck.c:6967
+#: c/c-typeck.c:6972
 #, fuzzy, gcc-internal-format
 #| msgid "assignment from incompatible pointer type"
 msgid "assignment to %qT from incompatible pointer type %qT"
 msgstr "互換性のないポインタ型からの代入です"
 
-#: c/c-typeck.c:6972
+#: c/c-typeck.c:6977
 #, fuzzy, gcc-internal-format
 #| msgid "initialization from incompatible pointer type"
 msgid "initialization of %qT from incompatible pointer type %qT"
 msgstr "互換性のないポインタ型からの初期化です"
 
-#: c/c-typeck.c:6977
+#: c/c-typeck.c:6982
 #, fuzzy, gcc-internal-format
 #| msgid "return from incompatible pointer type"
 msgid "returning %qT from a function with incompatible return type %qT"
@@ -41390,816 +41434,816 @@
 
 #. ??? This should not be an error when inlining calls to
 #. unprototyped functions.
-#: c/c-typeck.c:6991 c/c-typeck.c:7514 cp/typeck.c:2063
+#: c/c-typeck.c:6996 c/c-typeck.c:7519 cp/typeck.c:2063
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "非左辺値配列の無効な使用です"
 
-#: c/c-typeck.c:7004
+#: c/c-typeck.c:7009
 #, gcc-internal-format
 msgid "passing argument %d of %qE makes pointer from integer without a cast"
 msgstr "%d 番目の %qE の引数へ渡すときに整数からキャスト無しにポインタを作成しています"
 
-#: c/c-typeck.c:7010
+#: c/c-typeck.c:7015
 #, fuzzy, gcc-internal-format
 #| msgid "assignment makes pointer from integer without a cast"
 msgid "assignment to %qT from %qT makes pointer from integer without a cast"
 msgstr "代入で整数からキャスト無しにポインタを作成しています"
 
-#: c/c-typeck.c:7015
+#: c/c-typeck.c:7020
 #, fuzzy, gcc-internal-format
 #| msgid "initialization makes pointer from integer without a cast"
 msgid "initialization of %qT from %qT makes pointer from integer without a cast"
 msgstr "初期化で整数からキャスト無しにポインタを作成しています"
 
-#: c/c-typeck.c:7019
+#: c/c-typeck.c:7024
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE makes pointer from integer without a cast"
 msgid "returning %qT from a function with return type %qT makes pointer from integer without a cast"
 msgstr "%d 番目の %qE の引数へ渡すときに整数からキャスト無しにポインタを作成しています"
 
-#: c/c-typeck.c:7035
+#: c/c-typeck.c:7040
 #, gcc-internal-format
 msgid "passing argument %d of %qE makes integer from pointer without a cast"
 msgstr "passing argument %d 番目の %qE の引数を渡すときにポインタからキャスト無しに整数を作成しています"
 
-#: c/c-typeck.c:7041
+#: c/c-typeck.c:7046
 #, fuzzy, gcc-internal-format
 #| msgid "assignment makes integer from pointer without a cast"
 msgid "assignment to %qT from %qT makes integer from pointer without a cast"
 msgstr "代入でポインタからキャスト無しに整数を作成しています"
 
-#: c/c-typeck.c:7046
+#: c/c-typeck.c:7051
 #, fuzzy, gcc-internal-format
 #| msgid "initialization makes integer from pointer without a cast"
 msgid "initialization of %qT from %qT makes integer from pointer without a cast"
 msgstr "初期化でポインタからキャスト無しに整数を作成しています"
 
-#: c/c-typeck.c:7050
+#: c/c-typeck.c:7055
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE makes integer from pointer without a cast"
 msgid "returning %qT from a function with return type %qT makes integer from pointer without a cast"
 msgstr "passing argument %d 番目の %qE の引数を渡すときにポインタからキャスト無しに整数を作成しています"
 
-#: c/c-typeck.c:7073
+#: c/c-typeck.c:7078
 #, gcc-internal-format
 msgid "incompatible type for argument %d of %qE"
 msgstr "%d 番目の %qE の引数用の互換性がない型です"
 
-#: c/c-typeck.c:7078
+#: c/c-typeck.c:7083
 #, gcc-internal-format
 msgid "incompatible types when assigning to type %qT from type %qT"
 msgstr "型 %qT への型 %qT からの代入時に互換性のない型です"
 
-#: c/c-typeck.c:7083
+#: c/c-typeck.c:7088
 #, gcc-internal-format
 msgid "incompatible types when initializing type %qT using type %qT"
 msgstr "型 %qT を型 %qT を使用して初期化時に互換性のない型です"
 
-#: c/c-typeck.c:7088
+#: c/c-typeck.c:7093
 #, gcc-internal-format
 msgid "incompatible types when returning type %qT but %qT was expected"
 msgstr "型 %qT を戻すときに互換性のない型です。型 %qT が予期されます"
 
-#: c/c-typeck.c:7152
+#: c/c-typeck.c:7157
 #, gcc-internal-format
 msgid "traditional C rejects automatic aggregate initialization"
 msgstr "伝統的な C では自動集約初期化を拒否します"
 
-#: c/c-typeck.c:7388 c/c-typeck.c:8284 cp/typeck2.c:1045
+#: c/c-typeck.c:7393 c/c-typeck.c:8289 cp/typeck2.c:1045
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "可変配列メンバを初期化しています"
 
-#: c/c-typeck.c:7398 cp/typeck2.c:1059
+#: c/c-typeck.c:7403 cp/typeck2.c:1059
 #, gcc-internal-format
 msgid "char-array initialized from wide string"
 msgstr "ワイド文字列から char 配列が初期化されています"
 
-#: c/c-typeck.c:7407
+#: c/c-typeck.c:7412
 #, gcc-internal-format
 msgid "wide character array initialized from non-wide string"
 msgstr "非ワイド文字列でワイド文字配列が初期化されています"
 
-#: c/c-typeck.c:7413
+#: c/c-typeck.c:7418
 #, gcc-internal-format
 msgid "wide character array initialized from incompatible wide string"
 msgstr "互換性のないワイド文字列でワイド文字配列が初期化されています"
 
-#: c/c-typeck.c:7446
+#: c/c-typeck.c:7451
 #, gcc-internal-format
 msgid "array of inappropriate type initialized from string constant"
 msgstr "適切でない型の配列が文字列定数で初期化されています"
 
-#: c/c-typeck.c:7533 c/c-typeck.c:7557 c/c-typeck.c:7560 c/c-typeck.c:7568
-#: c/c-typeck.c:7608 c/c-typeck.c:9131 c/c-typeck.c:9181
+#: c/c-typeck.c:7538 c/c-typeck.c:7562 c/c-typeck.c:7565 c/c-typeck.c:7573
+#: c/c-typeck.c:7613 c/c-typeck.c:9136 c/c-typeck.c:9186
 #, gcc-internal-format
 msgid "initializer element is not constant"
 msgstr "初期化子の要素が定数ではありません"
 
-#: c/c-typeck.c:7542
+#: c/c-typeck.c:7547
 #, gcc-internal-format
 msgid "array initialized from non-constant array expression"
 msgstr "配列が非定数配列式で初期化されています"
 
-#: c/c-typeck.c:7573 c/c-typeck.c:7621 c/c-typeck.c:9191
+#: c/c-typeck.c:7578 c/c-typeck.c:7626 c/c-typeck.c:9196
 #, gcc-internal-format
 msgid "initializer element is not a constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: c/c-typeck.c:7615 c/c-typeck.c:9186
+#: c/c-typeck.c:7620 c/c-typeck.c:9191
 #, gcc-internal-format
 msgid "initializer element is not computable at load time"
 msgstr "初期化子の要素がロード時に計算出来ません"
 
-#: c/c-typeck.c:7634
+#: c/c-typeck.c:7639
 #, gcc-internal-format
 msgid "invalid initializer"
 msgstr "無効な初期化子です"
 
-#: c/c-typeck.c:7912 cp/decl.c:6396
+#: c/c-typeck.c:7917 cp/decl.c:6396
 #, fuzzy, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "可変長オブジェクトは初期化されないことになるでしょう"
 
-#: c/c-typeck.c:8132
+#: c/c-typeck.c:8137
 #, gcc-internal-format
 msgid "extra brace group at end of initializer"
 msgstr "初期化子の終わりに余分なブレースのグループ"
 
-#: c/c-typeck.c:8215
+#: c/c-typeck.c:8220
 #, gcc-internal-format
 msgid "braces around scalar initializer"
 msgstr "スカラー初期化子が中括弧で囲まれています"
 
-#: c/c-typeck.c:8281 c/c-typeck.c:9615 cp/typeck2.c:1084 cp/typeck2.c:1297
+#: c/c-typeck.c:8286 c/c-typeck.c:9620 cp/typeck2.c:1084 cp/typeck2.c:1297
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "入れ子になったコンテキスト内で可変配列メンバを初期化しています"
 
-#: c/c-typeck.c:8318
+#: c/c-typeck.c:8323
 #, gcc-internal-format
 msgid "missing braces around initializer"
 msgstr "初期化子の周りに中括弧がありません"
 
-#: c/c-typeck.c:8341
+#: c/c-typeck.c:8346
 #, fuzzy, gcc-internal-format
 msgid "missing initializer for field %qD of %qT"
 msgstr "初期化子を欠いています"
 
-#: c/c-typeck.c:8365
+#: c/c-typeck.c:8370
 #, gcc-internal-format
 msgid "empty scalar initializer"
 msgstr "空のスカラー初期化子です"
 
-#: c/c-typeck.c:8370
+#: c/c-typeck.c:8375
 #, gcc-internal-format
 msgid "extra elements in scalar initializer"
 msgstr "スカラー初期化子内に余分な要素があります"
 
-#: c/c-typeck.c:8483 c/c-typeck.c:8565
+#: c/c-typeck.c:8488 c/c-typeck.c:8570
 #, gcc-internal-format
 msgid "array index in non-array initializer"
 msgstr ""
 
-#: c/c-typeck.c:8488 c/c-typeck.c:8627
+#: c/c-typeck.c:8493 c/c-typeck.c:8632
 #, gcc-internal-format
 msgid "field name not in record or union initializer"
 msgstr "レコードや共用体初期化子にフィールド名がありません"
 
-#: c/c-typeck.c:8538
+#: c/c-typeck.c:8543
 #, gcc-internal-format
 msgid "array index in initializer not of integer type"
 msgstr ""
 
-#: c/c-typeck.c:8547 c/c-typeck.c:8556
+#: c/c-typeck.c:8552 c/c-typeck.c:8561
 #, gcc-internal-format
 msgid "array index in initializer is not an integer constant expression"
 msgstr ""
 
-#: c/c-typeck.c:8561 c/c-typeck.c:8563
+#: c/c-typeck.c:8566 c/c-typeck.c:8568
 #, gcc-internal-format
 msgid "nonconstant array index in initializer"
 msgstr "初期化子内に非定数の配列インデックスがあります"
 
-#: c/c-typeck.c:8567 c/c-typeck.c:8570
+#: c/c-typeck.c:8572 c/c-typeck.c:8575
 #, gcc-internal-format
 msgid "array index in initializer exceeds array bounds"
 msgstr "初期化子内の配列インデックスが配列の境界を超えました"
 
-#: c/c-typeck.c:8589
+#: c/c-typeck.c:8594
 #, gcc-internal-format
 msgid "empty index range in initializer"
 msgstr "初期化子内に空の範囲インデックスがあります"
 
-#: c/c-typeck.c:8598
+#: c/c-typeck.c:8603
 #, gcc-internal-format
 msgid "array index range in initializer exceeds array bounds"
 msgstr "初期化子の範囲インデックスが配列の境界を超えました"
 
-#: c/c-typeck.c:8700 c/c-typeck.c:8730 c/c-typeck.c:9274
+#: c/c-typeck.c:8705 c/c-typeck.c:8735 c/c-typeck.c:9279
 #, gcc-internal-format
 msgid "initialized field with side-effects overwritten"
 msgstr "初期化されたフィールドが副作用で上書きされます"
 
-#: c/c-typeck.c:8704 c/c-typeck.c:8734 c/c-typeck.c:9277
+#: c/c-typeck.c:8709 c/c-typeck.c:8739 c/c-typeck.c:9282
 #, gcc-internal-format
 msgid "initialized field overwritten"
 msgstr "初期化されたフィールドが上書きされます"
 
-#: c/c-typeck.c:9208
+#: c/c-typeck.c:9213
 #, gcc-internal-format
 msgid "enum conversion in initialization is invalid in C++"
 msgstr "初期化内での列挙型の変換は C++ では無効です"
 
-#: c/c-typeck.c:9496
+#: c/c-typeck.c:9501
 #, gcc-internal-format
 msgid "excess elements in char array initializer"
 msgstr "char 配列初期化子内の要素が多すぎます"
 
-#: c/c-typeck.c:9503 c/c-typeck.c:9574
+#: c/c-typeck.c:9508 c/c-typeck.c:9579
 #, gcc-internal-format
 msgid "excess elements in struct initializer"
 msgstr "構造体初期化子内の要素が多すぎます"
 
-#: c/c-typeck.c:9518
+#: c/c-typeck.c:9523
 #, gcc-internal-format
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr ""
 
-#: c/c-typeck.c:9589
+#: c/c-typeck.c:9594
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr ""
 
-#: c/c-typeck.c:9687
+#: c/c-typeck.c:9692
 #, gcc-internal-format
 msgid "excess elements in union initializer"
 msgstr "共用体初期化子内の要素が多すぎます"
 
-#: c/c-typeck.c:9709
+#: c/c-typeck.c:9714
 #, gcc-internal-format
 msgid "traditional C rejects initialization of unions"
 msgstr "伝統的な C では共用体の初期化を拒否します"
 
-#: c/c-typeck.c:9777
+#: c/c-typeck.c:9782
 #, gcc-internal-format
 msgid "excess elements in array initializer"
 msgstr "配列初期化子内の要素が多すぎます"
 
-#: c/c-typeck.c:9811
+#: c/c-typeck.c:9816
 #, gcc-internal-format
 msgid "excess elements in vector initializer"
 msgstr "ベクトル初期化子内の要素が多すぎます"
 
-#: c/c-typeck.c:9843
+#: c/c-typeck.c:9848
 #, gcc-internal-format
 msgid "excess elements in scalar initializer"
 msgstr "スカラー初期化子内の要素が多すぎます"
 
-#: c/c-typeck.c:10086
+#: c/c-typeck.c:10091
 #, gcc-internal-format
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C は %<goto *expr;%> を禁止しています"
 
-#: c/c-typeck.c:10113 c/gimple-parser.c:1604 cp/typeck.c:9113
+#: c/c-typeck.c:10118 c/gimple-parser.c:1604 cp/typeck.c:9113
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "%<noreturn%> と宣言されている関数が %<return%> 文を持っています"
 
-#: c/c-typeck.c:10139 c/c-typeck.c:10143
+#: c/c-typeck.c:10144 c/c-typeck.c:10148
 #, gcc-internal-format
 msgid "%<return%> with no value, in function returning non-void"
 msgstr "非 void を戻す関数内に値が無い %<return%> があります"
 
-#: c/c-typeck.c:10157 c/gimple-parser.c:1614
+#: c/c-typeck.c:10162 c/gimple-parser.c:1614
 #, gcc-internal-format
 msgid "%<return%> with a value, in function returning void"
 msgstr "void を戻す関数内に値が有る %<return%> があります"
 
-#: c/c-typeck.c:10160
+#: c/c-typeck.c:10165
 #, gcc-internal-format
 msgid "ISO C forbids %<return%> with expression, in function returning void"
 msgstr "ISO C は void を戻す関数内で、式をがある %<return%> を禁止しています"
 
-#: c/c-typeck.c:10236
+#: c/c-typeck.c:10241
 #, fuzzy, gcc-internal-format
 #| msgid "function returns address of local variable"
 msgid "function returns address of label"
 msgstr "関数が局所変数のアドレスを返します"
 
-#: c/c-typeck.c:10327 cp/semantics.c:1171
+#: c/c-typeck.c:10332 cp/semantics.c:1171
 #, gcc-internal-format
 msgid "switch quantity not an integer"
 msgstr "switch の内容が整数ではありません"
 
-#: c/c-typeck.c:10352
+#: c/c-typeck.c:10357
 #, gcc-internal-format
 msgid "%<long%> switch expression not converted to %<int%> in ISO C"
 msgstr "ISO C では %<long%> による switch 文は %<int%> による switch に変換されます"
 
-#: c/c-typeck.c:10390 c/c-typeck.c:10398
+#: c/c-typeck.c:10395 c/c-typeck.c:10403
 #, gcc-internal-format
 msgid "case label is not an integer constant expression"
 msgstr "case ラベルは整数定数式に出来ません"
 
-#: c/c-typeck.c:10404 cp/parser.c:11067
+#: c/c-typeck.c:10409 cp/parser.c:11067
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "switch 文の外にある case ラベルです"
 
-#: c/c-typeck.c:10406
+#: c/c-typeck.c:10411
 #, gcc-internal-format
 msgid "%<default%> label not within a switch statement"
 msgstr "switch 文の外にある %<default%> ラベルです"
 
-#: c/c-typeck.c:10578 cp/parser.c:12356
+#: c/c-typeck.c:10583 cp/parser.c:12353
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "ループまたは switch 文の外にある break 文です"
 
-#: c/c-typeck.c:10580 cp/parser.c:12379
+#: c/c-typeck.c:10585 cp/parser.c:12376
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "ループの外にある continue 文です"
 
-#: c/c-typeck.c:10585 cp/parser.c:12369
+#: c/c-typeck.c:10590 cp/parser.c:12366
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr "OpenMP のループ用に break 文が使用されています"
 
-#: c/c-typeck.c:10590
+#: c/c-typeck.c:10595
 #, fuzzy, gcc-internal-format
 #| msgid "break statement not within loop or switch"
 msgid "break statement within %<#pragma simd%> loop body"
 msgstr "ループまたは switch 文の外にある break 文です"
 
-#: c/c-typeck.c:10592
+#: c/c-typeck.c:10597
 #, fuzzy, gcc-internal-format
 #| msgid "continue statement not within a loop"
 msgid "continue statement within %<#pragma simd%> loop body"
 msgstr "ループの外にある continue 文です"
 
-#: c/c-typeck.c:10618 cp/cp-gimplify.c:432
+#: c/c-typeck.c:10623 cp/cp-gimplify.c:432
 #, gcc-internal-format
 msgid "statement with no effect"
 msgstr "効果がない文です"
 
-#: c/c-typeck.c:10662
+#: c/c-typeck.c:10667
 #, gcc-internal-format
 msgid "expression statement has incomplete type"
 msgstr "式の中の文に不完全型があります"
 
-#: c/c-typeck.c:11476 c/c-typeck.c:11644 cp/typeck.c:5017
+#: c/c-typeck.c:11481 c/c-typeck.c:11649 cp/typeck.c:5017
 #, fuzzy, gcc-internal-format
 #| msgid "Warn about comparison of different enum types"
 msgid "comparing vectors with different element types"
 msgstr "異なる列挙型の比較に関して警告する"
 
-#: c/c-typeck.c:11484 c/c-typeck.c:11652 cp/typeck.c:5030
+#: c/c-typeck.c:11489 c/c-typeck.c:11657 cp/typeck.c:5030
 #, fuzzy, gcc-internal-format
 #| msgid "different number of results"
 msgid "comparing vectors with different number of elements"
 msgstr "結果の数が異なります"
 
-#: c/c-typeck.c:11509 c/c-typeck.c:11677 cp/typeck.c:5058
+#: c/c-typeck.c:11514 c/c-typeck.c:11682 cp/typeck.c:5058
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr ""
 
-#: c/c-typeck.c:11523 cp/typeck.c:4743
+#: c/c-typeck.c:11528 cp/typeck.c:4743
 #, gcc-internal-format
 msgid "comparing floating point with == or != is unsafe"
 msgstr "浮動小数点の比較で == や != を使うのは安全ではありません"
 
-#: c/c-typeck.c:11541 c/c-typeck.c:11562
+#: c/c-typeck.c:11546 c/c-typeck.c:11567
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<false%> for the address of %qD will never be NULL"
 msgstr ""
 
-#: c/c-typeck.c:11547 c/c-typeck.c:11568
+#: c/c-typeck.c:11552 c/c-typeck.c:11573
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<true%> for the address of %qD will never be NULL"
 msgstr ""
 
-#: c/c-typeck.c:11589 c/c-typeck.c:11718
+#: c/c-typeck.c:11594 c/c-typeck.c:11723
 #, gcc-internal-format
 msgid "comparison of pointers to disjoint address spaces"
 msgstr ""
 
-#: c/c-typeck.c:11596 c/c-typeck.c:11602
+#: c/c-typeck.c:11601 c/c-typeck.c:11607
 #, gcc-internal-format
 msgid "ISO C forbids comparison of %<void *%> with function pointer"
 msgstr "ISO C は %<void *%> と関数ポインタの比較を禁止しています"
 
-#: c/c-typeck.c:11609 c/c-typeck.c:11728
+#: c/c-typeck.c:11614 c/c-typeck.c:11733
 #, gcc-internal-format
 msgid "comparison of distinct pointer types lacks a cast"
 msgstr "型が全く異なるポインタの比較でキャストを欠いています"
 
-#: c/c-typeck.c:11621 c/c-typeck.c:11626 c/c-typeck.c:11754 c/c-typeck.c:11759
+#: c/c-typeck.c:11626 c/c-typeck.c:11631 c/c-typeck.c:11759 c/c-typeck.c:11764
 #, gcc-internal-format
 msgid "comparison between pointer and integer"
 msgstr "ポインタと整数との比較を行なっています"
 
-#: c/c-typeck.c:11706
+#: c/c-typeck.c:11711
 #, gcc-internal-format
 msgid "comparison of complete and incomplete pointers"
 msgstr "完全なポインタと不完全なポインタとの比較です"
 
-#: c/c-typeck.c:11708
+#: c/c-typeck.c:11713
 #, gcc-internal-format
 msgid "ISO C forbids ordered comparisons of pointers to functions"
 msgstr "ISO C 関数ポインタの順序比較を禁じます"
 
-#: c/c-typeck.c:11713
+#: c/c-typeck.c:11718
 #, gcc-internal-format
 msgid "ordered comparison of pointer with null pointer"
 msgstr "NULL ポインタがあるポインタの順序比較です"
 
-#: c/c-typeck.c:11736 c/c-typeck.c:11739 c/c-typeck.c:11746 c/c-typeck.c:11749
+#: c/c-typeck.c:11741 c/c-typeck.c:11744 c/c-typeck.c:11751 c/c-typeck.c:11754
 #: cp/typeck.c:5081 cp/typeck.c:5088
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "整数 0 とポインタとの順序比較です"
 
-#: c/c-typeck.c:11811
+#: c/c-typeck.c:11816
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
 msgstr ""
 
-#: c/c-typeck.c:12126
+#: c/c-typeck.c:12131
 #, gcc-internal-format
 msgid "used array that cannot be converted to pointer where scalar is required"
 msgstr "スカラーが必要な場所にポインタに変換できない配列が使用されています"
 
-#: c/c-typeck.c:12130
+#: c/c-typeck.c:12135
 #, gcc-internal-format
 msgid "used struct type value where scalar is required"
 msgstr "スカラーが必要な場所で構造体型の値が使用されています"
 
-#: c/c-typeck.c:12134
+#: c/c-typeck.c:12139
 #, gcc-internal-format
 msgid "used union type value where scalar is required"
 msgstr "スカラーが必要な場所で共用体型の値が使用されています"
 
-#: c/c-typeck.c:12150
+#: c/c-typeck.c:12155
 #, fuzzy, gcc-internal-format
 #| msgid "used struct type value where scalar is required"
 msgid "used vector type where scalar is required"
 msgstr "スカラーが必要な場所で構造体型の値が使用されています"
 
-#: c/c-typeck.c:12340 cp/semantics.c:8508
+#: c/c-typeck.c:12345 cp/semantics.c:8511
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12379 cp/semantics.c:8545
+#: c/c-typeck.c:12384 cp/semantics.c:8548
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12423 c/c-typeck.c:13581 c/c-typeck.c:13642 c/c-typeck.c:13704
+#: c/c-typeck.c:12428 c/c-typeck.c:13586 c/c-typeck.c:13647 c/c-typeck.c:13709
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "%qs 句が多すぎます"
 
-#: c/c-typeck.c:12436 c/c-typeck.c:13628 cp/semantics.c:4546
-#: cp/semantics.c:6717
+#: c/c-typeck.c:12441 c/c-typeck.c:13633 cp/semantics.c:4549
+#: cp/semantics.c:6720
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12445 c/c-typeck.c:13652 cp/semantics.c:4556
-#: cp/semantics.c:6735
+#: c/c-typeck.c:12450 c/c-typeck.c:13657 cp/semantics.c:4559
+#: cp/semantics.c:6738
 #, fuzzy, gcc-internal-format
 msgid "%qE is a member of a union"
 msgstr "メンバ関数の名前を欠いています"
 
-#: c/c-typeck.c:12455 cp/semantics.c:4570 cp/semantics.c:6760
+#: c/c-typeck.c:12460 cp/semantics.c:4573 cp/semantics.c:6763
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "インスタンス変数 `%s' は %s と宣言されています"
 
-#: c/c-typeck.c:12459 c/c-typeck.c:13669 cp/semantics.c:4574
-#: cp/semantics.c:6763
+#: c/c-typeck.c:12464 c/c-typeck.c:13674 cp/semantics.c:4577
+#: cp/semantics.c:6766
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qE は句 %qs 内では変数ではありません"
 
-#: c/c-typeck.c:12466
+#: c/c-typeck.c:12471
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "%<_Atomic%> %qD in %qs clause"
 msgstr "%qs 句が多すぎます"
 
-#: c/c-typeck.c:12475 c/c-typeck.c:13676 c/c-typeck.c:13778
-#: cp/semantics.c:4591 cp/semantics.c:6769 cp/semantics.c:6931
+#: c/c-typeck.c:12480 c/c-typeck.c:13681 c/c-typeck.c:13783
+#: cp/semantics.c:4594 cp/semantics.c:6772 cp/semantics.c:6934
 #, fuzzy, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "インスタンス変数 `%s' は %s と宣言されています"
 
-#: c/c-typeck.c:12511 cp/semantics.c:4623
+#: c/c-typeck.c:12516 cp/semantics.c:4626
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "low bound %qE of array section does not have integral type"
 msgstr "配列 new でのサイズは完全な型を持たねばなりません"
 
-#: c/c-typeck.c:12518 cp/semantics.c:4630
+#: c/c-typeck.c:12523 cp/semantics.c:4633
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "length %qE of array section does not have integral type"
 msgstr "配列 new でのサイズは完全な型を持たねばなりません"
 
-#: c/c-typeck.c:12545 c/c-typeck.c:12609 c/c-typeck.c:12867
-#: cp/semantics.c:4666 cp/semantics.c:4730
+#: c/c-typeck.c:12550 c/c-typeck.c:12614 c/c-typeck.c:12872
+#: cp/semantics.c:4669 cp/semantics.c:4733
 #, fuzzy, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr "セクション属性は `%s' には使えません"
 
-#: c/c-typeck.c:12564 cp/semantics.c:4685
+#: c/c-typeck.c:12569 cp/semantics.c:4688
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12572 cp/semantics.c:4693
+#: c/c-typeck.c:12577 cp/semantics.c:4696
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12581 c/c-typeck.c:12691 cp/semantics.c:4702
-#: cp/semantics.c:4812
+#: c/c-typeck.c:12586 c/c-typeck.c:12696 cp/semantics.c:4705
+#: cp/semantics.c:4815
 #, fuzzy, gcc-internal-format
 #| msgid "variable length array is used"
 msgid "negative length in array section in %qs clause"
 msgstr "可変長配列が使用されています"
 
-#: c/c-typeck.c:12598 cp/semantics.c:4719
+#: c/c-typeck.c:12603 cp/semantics.c:4722
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12635 cp/semantics.c:4756
+#: c/c-typeck.c:12640 cp/semantics.c:4759
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12650 cp/semantics.c:4771
+#: c/c-typeck.c:12655 cp/semantics.c:4774
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12683 cp/semantics.c:4804
+#: c/c-typeck.c:12688 cp/semantics.c:4807
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12701 c/c-typeck.c:12810 cp/semantics.c:4822
-#: cp/semantics.c:4934
+#: c/c-typeck.c:12706 c/c-typeck.c:12815 cp/semantics.c:4825
+#: cp/semantics.c:4937
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12709 cp/semantics.c:4830
+#: c/c-typeck.c:12714 cp/semantics.c:4833
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qE does not have pointer or array type"
 msgstr "ベクトル型の delete ですが、ポインタでも配列型でもありません"
 
-#: c/c-typeck.c:13103 c/c-typeck.c:13113
+#: c/c-typeck.c:13108 c/c-typeck.c:13118
 #, gcc-internal-format
 msgid "%qD in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: c/c-typeck.c:13130
+#: c/c-typeck.c:13135
 #, gcc-internal-format
 msgid "%<_Atomic%> %qE in %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13178
+#: c/c-typeck.c:13183
 #, gcc-internal-format
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "%qE は %<reduction(%s)%> 用の無効な型を持っています"
 
-#: c/c-typeck.c:13187 cp/semantics.c:5755
+#: c/c-typeck.c:13192 cp/semantics.c:5758
 #, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr ""
 
-#: c/c-typeck.c:13275
+#: c/c-typeck.c:13280
 #, fuzzy, gcc-internal-format
 #| msgid "variable length array is used"
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "可変長配列が使用されています"
 
-#: c/c-typeck.c:13293 c/c-typeck.c:13836 cp/semantics.c:7249
+#: c/c-typeck.c:13298 c/c-typeck.c:13841 cp/semantics.c:7252
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13305 cp/semantics.c:7289
+#: c/c-typeck.c:13310 cp/semantics.c:7292
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE は %<threadprivate%> (%<copyin%> 用として) でなければいけません"
 
-#: c/c-typeck.c:13319 cp/semantics.c:5929
+#: c/c-typeck.c:13324 cp/semantics.c:5932
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr ""
 
-#: c/c-typeck.c:13327
+#: c/c-typeck.c:13332
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with type %qT"
 msgstr ""
 
-#: c/c-typeck.c:13335
+#: c/c-typeck.c:13340
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13354 cp/semantics.c:5999
+#: c/c-typeck.c:13359 cp/semantics.c:6002
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
-#: c/c-typeck.c:13384 c/c-typeck.c:13771 cp/semantics.c:6083
-#: cp/semantics.c:6924
+#: c/c-typeck.c:13389 c/c-typeck.c:13776 cp/semantics.c:6086
+#: cp/semantics.c:6927
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE は句 %qs 内では変数ではありません"
 
-#: c/c-typeck.c:13393 cp/semantics.c:6092
+#: c/c-typeck.c:13398 cp/semantics.c:6095
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qD appears more than once in reduction clauses"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
-#: c/c-typeck.c:13404 c/c-typeck.c:13434 c/c-typeck.c:13463
+#: c/c-typeck.c:13409 c/c-typeck.c:13439 c/c-typeck.c:13468
 #, gcc-internal-format
 msgid "%qE appears more than once in data clauses"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
-#: c/c-typeck.c:13411 c/c-typeck.c:13440 c/c-typeck.c:13600 c/c-typeck.c:13714
-#: c/c-typeck.c:13720 c/c-typeck.c:13733 c/c-typeck.c:13742
-#: cp/semantics.c:6102 cp/semantics.c:6109 cp/semantics.c:6160
-#: cp/semantics.c:6166 cp/semantics.c:6203 cp/semantics.c:6680
-#: cp/semantics.c:6817 cp/semantics.c:6823 cp/semantics.c:6836
-#: cp/semantics.c:6845
+#: c/c-typeck.c:13416 c/c-typeck.c:13445 c/c-typeck.c:13605 c/c-typeck.c:13719
+#: c/c-typeck.c:13725 c/c-typeck.c:13738 c/c-typeck.c:13747
+#: cp/semantics.c:6105 cp/semantics.c:6112 cp/semantics.c:6163
+#: cp/semantics.c:6169 cp/semantics.c:6206 cp/semantics.c:6683
+#: cp/semantics.c:6820 cp/semantics.c:6826 cp/semantics.c:6839
+#: cp/semantics.c:6848
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
-#: c/c-typeck.c:13413 c/c-typeck.c:13442 c/c-typeck.c:13722 c/c-typeck.c:13744
-#: cp/semantics.c:6111 cp/semantics.c:6168 cp/semantics.c:6825
-#: cp/semantics.c:6847
+#: c/c-typeck.c:13418 c/c-typeck.c:13447 c/c-typeck.c:13727 c/c-typeck.c:13749
+#: cp/semantics.c:6114 cp/semantics.c:6171 cp/semantics.c:6828
+#: cp/semantics.c:6850
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qD appears both in data and map clauses"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
-#: c/c-typeck.c:13427 cp/semantics.c:6154
+#: c/c-typeck.c:13432 cp/semantics.c:6157
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "%qE は %<firstprivate%> 句内では変数ではありません"
 
-#: c/c-typeck.c:13456 cp/semantics.c:6197
+#: c/c-typeck.c:13461 cp/semantics.c:6200
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "%qE は %<lastprivate%> 句内では変数ではありません"
 
-#: c/c-typeck.c:13475 cp/semantics.c:6545
+#: c/c-typeck.c:13480 cp/semantics.c:6548
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "%qE は句 %qs 内では変数ではありません"
 
-#: c/c-typeck.c:13482
+#: c/c-typeck.c:13487
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array"
 msgstr "ベクトル型の delete ですが、ポインタでも配列型でもありません"
 
-#: c/c-typeck.c:13489
+#: c/c-typeck.c:13494
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<aligned%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13496
+#: c/c-typeck.c:13501
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
-#: c/c-typeck.c:13551 cp/semantics.c:6627
+#: c/c-typeck.c:13556 cp/semantics.c:6630
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr "%qE は句 %qs 内では変数ではありません"
 
-#: c/c-typeck.c:13573 cp/semantics.c:6658
+#: c/c-typeck.c:13578 cp/semantics.c:6661
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13597 c/c-typeck.c:13731 cp/semantics.c:6677
-#: cp/semantics.c:6834
+#: c/c-typeck.c:13602 c/c-typeck.c:13736 cp/semantics.c:6680
+#: cp/semantics.c:6837
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
-#: c/c-typeck.c:13603 c/c-typeck.c:13735 cp/semantics.c:6683
-#: cp/semantics.c:6838
+#: c/c-typeck.c:13608 c/c-typeck.c:13740 cp/semantics.c:6686
+#: cp/semantics.c:6841
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qD appears more than once in map clauses"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
-#: c/c-typeck.c:13635 cp/semantics.c:6724
+#: c/c-typeck.c:13640 cp/semantics.c:6727
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qE は句 %qs 内では変数ではありません"
 
-#: c/c-typeck.c:13695 c/c-typeck.c:13785 cp/semantics.c:6799
-#: cp/semantics.c:6938
+#: c/c-typeck.c:13700 c/c-typeck.c:13790 cp/semantics.c:6802
+#: cp/semantics.c:6941
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "インスタンス変数 `%s' は %s と宣言されています"
 
-#: c/c-typeck.c:13766 cp/semantics.c:6918
+#: c/c-typeck.c:13771 cp/semantics.c:6921
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE は句 %qs 内では変数ではありません"
 
-#: c/c-typeck.c:13794 cp/semantics.c:6947
+#: c/c-typeck.c:13799 cp/semantics.c:6950
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
-#: c/c-typeck.c:13808 cp/semantics.c:6962
+#: c/c-typeck.c:13813 cp/semantics.c:6965
 #, fuzzy, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "インスタンス変数 `%s' は %s と宣言されています"
 
-#: c/c-typeck.c:13811 cp/semantics.c:6964
+#: c/c-typeck.c:13816 cp/semantics.c:6967
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qE は句 %qs 内では変数ではありません"
 
-#: c/c-typeck.c:13826
+#: c/c-typeck.c:13831
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "ベクトル型の delete ですが、ポインタでも配列型でもありません"
 
-#: c/c-typeck.c:13900 cp/semantics.c:6359
+#: c/c-typeck.c:13905 cp/semantics.c:6362
 #, gcc-internal-format
 msgid "%<nonmonotonic%> modifier specified for %qs schedule kind"
 msgstr ""
 
-#: c/c-typeck.c:13931 cp/semantics.c:7141
+#: c/c-typeck.c:13936 cp/semantics.c:7144
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:13981 cp/semantics.c:7332
+#: c/c-typeck.c:13986 cp/semantics.c:7335
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE は %qs (%qs 用) として前もって決められています"
 
-#: c/c-typeck.c:14001 cp/semantics.c:7223
+#: c/c-typeck.c:14006 cp/semantics.c:7226
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:14013 cp/semantics.c:7236
+#: c/c-typeck.c:14018 cp/semantics.c:7239
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14031 cp/semantics.c:7203
+#: c/c-typeck.c:14036 cp/semantics.c:7206
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14204
+#: c/c-typeck.c:14209
 #, gcc-internal-format
 msgid "cannot use %<va_arg%> with reverse storage order"
 msgstr ""
 
-#: c/c-typeck.c:14209
+#: c/c-typeck.c:14214
 #, fuzzy, gcc-internal-format
 #| msgid "first argument to %<va_arg%> not of type %<va_list%>"
 msgid "second argument to %<va_arg%> is of incomplete type %qT"
 msgstr "%<va_arg%> の第一引数が %<va_list%> 型ではありません"
 
-#: c/c-typeck.c:14215
+#: c/c-typeck.c:14220
 #, gcc-internal-format
 msgid "C++ requires promoted type, not enum type, in %<va_arg%>"
 msgstr ""
@@ -42331,7 +42375,7 @@
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "第 %d 引数を %qT から %qT へ変換する方法が不明です"
 
-#: cp/call.c:3441 cp/pt.c:6495
+#: cp/call.c:3441 cp/pt.c:6509
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -42646,7 +42690,7 @@
 msgid "%q#D is private within this context"
 msgstr "マクロ引数内でディレクトリを使うことはできません"
 
-#: cp/call.c:6478 cp/decl.c:7343
+#: cp/call.c:6478 cp/decl.c:7364
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "declared private here"
@@ -42657,7 +42701,7 @@
 msgid "%q#D is protected within this context"
 msgstr "マクロ引数内でディレクトリを使うことはできません"
 
-#: cp/call.c:6486 cp/decl.c:7344
+#: cp/call.c:6486 cp/decl.c:7365
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "declared protected here"
@@ -42973,7 +43017,7 @@
 msgid "call to non-function %qD"
 msgstr "非関数 %qD の呼び出しです"
 
-#: cp/call.c:9119 cp/pt.c:15053 cp/typeck.c:2901
+#: cp/call.c:9119 cp/pt.c:15075 cp/typeck.c:2901
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "コンストラクタ %<%T::%D%> を直接呼び出すことは出来ません"
@@ -43193,277 +43237,277 @@
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr ""
 
-#: cp/class.c:2098
+#: cp/class.c:2103
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr "クラス %qT 内の全てのメンバ関数が非公開です"
 
-#: cp/class.c:2110
+#: cp/class.c:2115
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr "%q#T はフレンドが無い非公開デストラクタのみ定義しています"
 
-#: cp/class.c:2152
+#: cp/class.c:2156
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr "%q#T はフレンドが無い非公開コンストラクタのみ定義しています"
 
-#: cp/class.c:2156
+#: cp/class.c:2160
 #, gcc-internal-format
 msgid "%q#D is public, but requires an existing %q#T object"
 msgstr ""
 
-#: cp/class.c:2430
+#: cp/class.c:2434
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr ""
 
-#: cp/class.c:2785
+#: cp/class.c:2789
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D cannot be overloaded"
 msgid "%qD can be marked override"
 msgstr "%q+#D はオーバーロードすることが出来ません"
 
-#: cp/class.c:2797
+#: cp/class.c:2801
 #, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr ""
 
-#: cp/class.c:2799
+#: cp/class.c:2803
 #, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr ""
 
-#: cp/class.c:2861
+#: cp/class.c:2865
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was hidden"
 msgid "%qD was hidden"
 msgstr "%q+D は隠されています"
 
-#: cp/class.c:2863
+#: cp/class.c:2867
 #, fuzzy, gcc-internal-format
 #| msgid "        %qD"
 msgid "  by %qD"
 msgstr "        %qD"
 
-#: cp/class.c:2896
+#: cp/class.c:2900
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D invalid; an anonymous union can only have non-static data members"
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "%q+#D は無効です。無名共用体は非静的データメンバのみ持つことが出来ます"
 
-#: cp/class.c:2906 cp/name-lookup.c:3293 cp/parser.c:19720
+#: cp/class.c:2910 cp/name-lookup.c:3293 cp/parser.c:19717
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
 
-#: cp/class.c:3097
+#: cp/class.c:3101
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr ""
 
-#: cp/class.c:3213
+#: cp/class.c:3217
 #, gcc-internal-format
 msgid "bit-field %q+#D with non-integral type"
 msgstr "ビットフィールド %q+#D が非整数型です"
 
-#: cp/class.c:3229
+#: cp/class.c:3233
 #, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr "ビットフィールド %q+D の幅が整数定数ではありません"
 
-#: cp/class.c:3234
+#: cp/class.c:3238
 #, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr "ビットフィールド %q+D の幅が負です"
 
-#: cp/class.c:3239
+#: cp/class.c:3243
 #, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr "ビットフィールド %q+D の幅が 0 です"
 
-#: cp/class.c:3249
+#: cp/class.c:3253
 #, fuzzy, gcc-internal-format
 #| msgid "width of %q+D exceeds its type"
 msgid "width of %qD exceeds its type"
 msgstr "%q+D の幅が型の大きさを超えています"
 
-#: cp/class.c:3255
+#: cp/class.c:3259
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is too small to hold all values of %q#T"
 msgid "%qD is too small to hold all values of %q#T"
 msgstr "%q+D は %q#T の全ての値を持つには小さすぎます"
 
-#: cp/class.c:3316
+#: cp/class.c:3320
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr "コンストラクタを持つメンバ %q+#D は共用体内では許可されていません"
 
-#: cp/class.c:3319
+#: cp/class.c:3323
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr "デストラクタを持つメンバ %q+#D は共用体内では許可されていません"
 
-#: cp/class.c:3321
+#: cp/class.c:3325
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr "コピー代入演算子を持つメンバ %q+#D は共用体内では許可されていません"
 
-#: cp/class.c:3325
+#: cp/class.c:3329
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/class.c:3453
+#: cp/class.c:3457
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D may not be static because it is a member of a union"
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr "%q+D は共用体のメンバのため静的ではありません"
 
-#: cp/class.c:3460
+#: cp/class.c:3464
 #, fuzzy, gcc-internal-format
 #| msgid "non-static const member %q+#D in class without a constructor"
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr "コンストラクタが無いクラス内に非静的定数メンバ %q+#D があります"
 
-#: cp/class.c:3470
+#: cp/class.c:3474
 #, gcc-internal-format
 msgid "field %q+D invalidly declared function type"
 msgstr "フィールド %q+D はが関数型として無効な宣言をされました"
 
-#: cp/class.c:3476
+#: cp/class.c:3480
 #, gcc-internal-format
 msgid "field %q+D invalidly declared method type"
 msgstr "フィールド %q+D はメソッド型として無効な宣言をされました"
 
-#: cp/class.c:3536
+#: cp/class.c:3540
 #, gcc-internal-format
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr ""
 
-#: cp/class.c:3585
+#: cp/class.c:3589
 #, fuzzy, gcc-internal-format
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr "非メンバ `%s' を `mutable' とは宣言できません"
 
-#: cp/class.c:3591
+#: cp/class.c:3595
 #, fuzzy, gcc-internal-format
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr "非メンバ `%s' を `mutable' とは宣言できません"
 
-#: cp/class.c:3617
+#: cp/class.c:3621
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr "共用体 %qT 内の複数のフィールドが初期化されました"
 
-#: cp/class.c:3658
+#: cp/class.c:3662
 #, fuzzy, gcc-internal-format
 #| msgid "field %q+#D with same name as class"
 msgid "field %q#D with same name as class"
 msgstr "フィールド %q+#D がクラス名と同じです"
 
-#: cp/class.c:3681
+#: cp/class.c:3685
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr "%q#T がポインタデータメンバを持っています"
 
-#: cp/class.c:3686
+#: cp/class.c:3690
 #, gcc-internal-format
 msgid "  but does not override %<%T(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:3688
+#: cp/class.c:3692
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:3692
+#: cp/class.c:3696
 #, gcc-internal-format
 msgid "  but does not override %<operator=(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:4097
+#: cp/class.c:4101
 #, gcc-internal-format
 msgid "alignment of %qD increased in -fabi-version=9 (GCC 5.2)"
 msgstr ""
 
-#: cp/class.c:4100
+#: cp/class.c:4104
 #, fuzzy, gcc-internal-format
 #| msgid "alignment of %qD is bigger than original declaration"
 msgid "alignment of %qD will increase in -fabi-version=9"
 msgstr "%qD の整列は元の宣言より大きいです"
 
-#: cp/class.c:4378
+#: cp/class.c:4382
 #, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "非仮想関数 %q+D 用の初期化子が指定されています"
 
-#: cp/class.c:4813
+#: cp/class.c:4817
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr ""
 
-#: cp/class.c:4834
+#: cp/class.c:4838
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr ""
 
-#: cp/class.c:5350 cp/constexpr.c:237
+#: cp/class.c:5367 cp/constexpr.c:237
 #, gcc-internal-format
 msgid "enclosing class of %<constexpr%> non-static member function %q+#D is not a literal type"
 msgstr ""
 
-#: cp/class.c:5374
+#: cp/class.c:5391
 #, fuzzy, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr "クラスタイプ項を欠いています"
 
-#: cp/class.c:5377
+#: cp/class.c:5394
 #, gcc-internal-format
 msgid "  %qT is a closure type, which is only literal in C++17 and later"
 msgstr ""
 
-#: cp/class.c:5380
+#: cp/class.c:5397
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "  %q+T has a non-trivial destructor"
 msgstr "基底クラス %q#T が非仮想デストラクタを持っています"
 
-#: cp/class.c:5387
+#: cp/class.c:5404
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no %<constexpr%> constructor that is not a copy or move constructor"
 msgstr ""
 
-#: cp/class.c:5420
+#: cp/class.c:5437
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "基底クラス %q#T が非仮想デストラクタを持っています"
 
-#: cp/class.c:5435
+#: cp/class.c:5452
 #, fuzzy, gcc-internal-format
 msgid "  non-static data member %qD has non-literal type"
 msgstr "関数を inline にできません"
 
-#: cp/class.c:5442
+#: cp/class.c:5459
 #, fuzzy, gcc-internal-format
 msgid "  non-static data member %qD has volatile type"
 msgstr "メンバへのポインタでの無効な `%s' の使用"
 
-#: cp/class.c:5561
+#: cp/class.c:5578
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "基底クラス %q#T が非仮想デストラクタを持っています"
 
-#: cp/class.c:5590
+#: cp/class.c:5607
 #, fuzzy, gcc-internal-format
 #| msgid "non-static reference %q+#D in class without a constructor"
 msgid "non-static reference %q#D in class without a constructor"
 msgstr "コンストラクタが無いクラス内に非静的参照 %q+#D があります"
 
-#: cp/class.c:5596
+#: cp/class.c:5613
 #, fuzzy, gcc-internal-format
 #| msgid "non-static const member %q+#D in class without a constructor"
 msgid "non-static const member %q#D in class without a constructor"
@@ -43471,161 +43515,161 @@
 
 #. If the function is defaulted outside the class, we just
 #. give the synthesis error.
-#: cp/class.c:5624
+#: cp/class.c:5641
 #, gcc-internal-format
 msgid "%q+D declared to take const reference, but implicit declaration would take non-const"
 msgstr "%q+D は定数参照を取るように宣言されていますが、暗黙的な宣言では非定数参照を取ります"
 
-#: cp/class.c:5898
+#: cp/class.c:5915
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr "直接の基底 %qT は曖昧なため %qT 内でアクセスできません"
 
-#: cp/class.c:5910
+#: cp/class.c:5927
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr "仮想基底 %qT は曖昧なため %qT 内ではアクセスできません"
 
-#: cp/class.c:6133
+#: cp/class.c:6150
 #, fuzzy, gcc-internal-format
 #| msgid "offset of %q+D is not ABI-compliant and may change in a future version of GCC"
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr "%q+D のオフセットは ABI に適合していないため将来のバージョンの GCC では変更になるかもしれません"
 
-#: cp/class.c:6291
+#: cp/class.c:6308
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qE is too large"
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr "配列 %qE のサイズが大きすぎます"
 
-#: cp/class.c:6576
+#: cp/class.c:6593
 #, gcc-internal-format
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr ""
 
-#: cp/class.c:6578
+#: cp/class.c:6595
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of flexible array member"
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr "可変配列メンバの無効な使用法です"
 
-#: cp/class.c:6583
+#: cp/class.c:6600
 #, fuzzy, gcc-internal-format
 msgid "array member %q#D declared here"
 msgstr "`%s' は前にここで宣言されました"
 
-#: cp/class.c:6610
+#: cp/class.c:6627
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member not at end of struct"
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr "構造体の最後ではない所に可変配列メンバがあります"
 
-#: cp/class.c:6612
+#: cp/class.c:6629
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member in otherwise empty struct"
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr "構造体に可変配列メンバ以外のメンバがありません"
 
-#: cp/class.c:6620 cp/class.c:6650
+#: cp/class.c:6637 cp/class.c:6667
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %q#T"
 msgid "in the definition of %q#T"
 msgstr "%q#T が再定義されています"
 
-#: cp/class.c:6628
+#: cp/class.c:6645
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member not at end of struct"
 msgid "flexible array member %qD not at end of %q#T"
 msgstr "構造体の最後ではない所に可変配列メンバがあります"
 
-#: cp/class.c:6630
+#: cp/class.c:6647
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member in otherwise empty struct"
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr "構造体に可変配列メンバ以外のメンバがありません"
 
-#: cp/class.c:6648
+#: cp/class.c:6665
 #, fuzzy, gcc-internal-format
 msgid "next member %q#D declared here"
 msgstr "`%s' は前にここで宣言されました"
 
-#: cp/class.c:6760 cp/parser.c:23239
+#: cp/class.c:6777 cp/parser.c:23236
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "%q#T が再定義されています"
 
-#: cp/class.c:6897
+#: cp/class.c:6914
 #, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "%q#T は仮想関数を持っており非仮想デストラクタからアクセス可能です"
 
-#: cp/class.c:6925
+#: cp/class.c:6942
 #, fuzzy, gcc-internal-format
 #| msgid "prototype for %q#D does not match any in class %qT"
 msgid "type transparent %q#T does not have any fields"
 msgstr "%q#D 用のプロトタイプがクラス %qT 内のどれとも一致しません"
 
-#: cp/class.c:6931
+#: cp/class.c:6948
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr ""
 
-#: cp/class.c:6935
+#: cp/class.c:6952
 #, fuzzy, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr "メンバ関数の名前を欠いています"
 
-#: cp/class.c:6941
+#: cp/class.c:6958
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:7071
+#: cp/class.c:7088
 #, fuzzy, gcc-internal-format
 msgid "definition of %qD does not match %<#include <initializer_list>%>"
 msgstr "初期化された変数 `%s' は dllimport マークされています"
 
-#: cp/class.c:7082
+#: cp/class.c:7099
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr ""
 
-#: cp/class.c:7582
+#: cp/class.c:7599
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "言語文字列 %<\"%E\"%> は認識できません"
 
-#: cp/class.c:7672
+#: cp/class.c:7689
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr ""
 
-#: cp/class.c:7817
+#: cp/class.c:7834
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr "関数 %qD から型 %q#T への変換が適合しません"
 
-#: cp/class.c:7844
+#: cp/class.c:7861
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "オーバーロードされた関数 %qD から型 %q#T への変換は曖昧です"
 
-#: cp/class.c:7870
+#: cp/class.c:7887
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "メンバ %qD へのポインタと見なしています"
 
-#: cp/class.c:7873
+#: cp/class.c:7890
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr ""
 
-#: cp/class.c:7948 cp/class.c:7990
+#: cp/class.c:7965 cp/class.c:8007
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "型情報が不十分です"
 
-#: cp/class.c:7968
+#: cp/class.c:7985
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "%qE を型 %qT から型 %qT へ変換できません"
@@ -43635,12 +43679,12 @@
 #. A name N used in a class S shall refer to the same declaration
 #. in its context and when re-evaluated in the completed scope of
 #. S.
-#: cp/class.c:8235
+#: cp/class.c:8252
 #, gcc-internal-format
 msgid "declaration of %q#D"
 msgstr "%q#D が宣言されています"
 
-#: cp/class.c:8237
+#: cp/class.c:8254
 #, fuzzy, gcc-internal-format
 #| msgid "changes meaning of %qD from %q+#D"
 msgid "changes meaning of %qD from %q#D"
@@ -44050,17 +44094,17 @@
 msgid "unexpected AST of kind %s"
 msgstr "ファイル \"%s\" に戻るはずでした"
 
-#: cp/cp-gimplify.c:1415
+#: cp/cp-gimplify.c:1416
 #, gcc-internal-format
 msgid "throw will always call terminate()"
 msgstr ""
 
-#: cp/cp-gimplify.c:1418
+#: cp/cp-gimplify.c:1419
 #, gcc-internal-format
 msgid "in C++11 destructors default to noexcept"
 msgstr ""
 
-#: cp/cp-gimplify.c:1429
+#: cp/cp-gimplify.c:1430
 #, gcc-internal-format
 msgid "in C++11 this throw will terminate because destructors default to noexcept"
 msgstr ""
@@ -44485,7 +44529,7 @@
 msgid "redeclaration %qD differs in %<constexpr%> from previous declaration"
 msgstr "使用している宣言 %q+D は前に使用している宣言と競合しています"
 
-#: cp/decl.c:1304 cp/decl.c:13843
+#: cp/decl.c:1304 cp/decl.c:13867
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr "前方での `%s' の宣言"
@@ -44827,7 +44871,7 @@
 msgid "  enters OpenMP structured block"
 msgstr "  try ブロックに入ります"
 
-#: cp/decl.c:3434 cp/parser.c:12366 cp/parser.c:12387
+#: cp/decl.c:3434 cp/parser.c:12363 cp/parser.c:12384
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr ""
@@ -44837,7 +44881,7 @@
 msgid "%qD is not a type"
 msgstr "%s は型 %s ではありません (引数 %d)"
 
-#: cp/decl.c:3838 cp/parser.c:6366
+#: cp/decl.c:3838 cp/parser.c:6369
 #, gcc-internal-format
 msgid "%qD used without template parameters"
 msgstr ""
@@ -45222,8 +45266,8 @@
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.c:6011 cp/decl.c:6234 cp/typeck2.c:1310 cp/typeck2.c:1590
-#: cp/typeck2.c:1638 cp/typeck2.c:1685
+#: cp/decl.c:6011 cp/decl.c:6234 cp/typeck2.c:1310 cp/typeck2.c:1593
+#: cp/typeck2.c:1641 cp/typeck2.c:1688
 #, fuzzy, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "入力ファイルが多すぎます"
@@ -45299,12 +45343,12 @@
 msgid "assignment (not initialization) in declaration"
 msgstr "宣言の中に代入(初期化ではなく)があります"
 
-#: cp/decl.c:6873 cp/decl.c:12605
+#: cp/decl.c:6873 cp/decl.c:12629
 #, fuzzy, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C++ は名前つき戻り値を許可しません"
 
-#: cp/decl.c:6877 cp/decl.c:12609
+#: cp/decl.c:6877 cp/decl.c:12633
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for %qs"
 msgid "%<register%> storage class specifier used"
@@ -45331,44 +45375,44 @@
 msgid "function %q#D is initialized like a variable"
 msgstr "関数 `%s' が変数であるかのように初期化されました"
 
-#: cp/decl.c:7329
+#: cp/decl.c:7350
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr ""
 
-#: cp/decl.c:7332
+#: cp/decl.c:7353
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.c:7339
+#: cp/decl.c:7360
 #, gcc-internal-format
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr ""
 
-#: cp/decl.c:7365
+#: cp/decl.c:7386
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:7374
+#: cp/decl.c:7395
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:7592
+#: cp/decl.c:7613
 #, fuzzy, gcc-internal-format
 #| msgid "source is a pointer to incomplete type"
 msgid "structured binding refers to incomplete type %qT"
 msgstr "ソースは不完全型へのポインタです"
 
-#: cp/decl.c:7608
+#: cp/decl.c:7629
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable length array %qE"
 msgid "cannot decompose variable length array %qT"
 msgstr "ISO C90 は可変長の配列 %qE を禁止しています"
 
-#: cp/decl.c:7617 cp/decl.c:7702
+#: cp/decl.c:7638 cp/decl.c:7723
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qs specified for structure field"
 msgid "%u name provided for structured binding"
@@ -45375,915 +45419,915 @@
 msgid_plural "%u names provided for structured binding"
 msgstr[0] "%qs が構造体フィールド用に指定されています"
 
-#: cp/decl.c:7621
+#: cp/decl.c:7642
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
 msgstr[0] ""
 
-#: cp/decl.c:7624
+#: cp/decl.c:7645
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] ""
 
-#: cp/decl.c:7669
+#: cp/decl.c:7690
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr "ポインタを参照として宣言できません"
 
-#: cp/decl.c:7695
+#: cp/decl.c:7716
 #, fuzzy, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "定数式が欠けているか無効です"
 
-#: cp/decl.c:7704
+#: cp/decl.c:7725
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.c:7725
+#: cp/decl.c:7746
 #, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr ""
 
-#: cp/decl.c:7751
+#: cp/decl.c:7772
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr "ポインタを参照として宣言できません"
 
-#: cp/decl.c:7756
+#: cp/decl.c:7777
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "   ポインタからメンバへの変換で"
 
-#: cp/decl.c:7761
+#: cp/decl.c:7782
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose lambda closure type %qT"
 msgstr "不完全型のポインタへの間接参照"
 
-#: cp/decl.c:7765
+#: cp/decl.c:7786
 #, fuzzy, gcc-internal-format
 #| msgid "source is a pointer to incomplete type"
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "ソースは不完全型へのポインタです"
 
-#: cp/decl.c:7774
+#: cp/decl.c:7795
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply %<offsetof%> to static data member %qD"
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "%<offsetof%> を静的データメンバ %qD へ適用できません"
 
-#: cp/decl.c:8213
+#: cp/decl.c:8234
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:8216
+#: cp/decl.c:8237
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:8222
+#: cp/decl.c:8243
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:8450
+#: cp/decl.c:8471
 #, fuzzy, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "初期化子は `%s' のサイズの特定に失敗しました"
 
-#: cp/decl.c:8454
+#: cp/decl.c:8475
 #, fuzzy, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "`%s' での配列サイズを欠いています"
 
-#: cp/decl.c:8457
+#: cp/decl.c:8478
 #, fuzzy, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "ISO C は サイズ 0 の配列 `%s' を禁じます"
 
-#: cp/decl.c:8473
+#: cp/decl.c:8494
 #, fuzzy, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "他のクラス `%s' のデストラクタを、メンバにはできません"
 
-#: cp/decl.c:8475
+#: cp/decl.c:8496
 #, fuzzy, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "他のクラス `%s' のデストラクタを、メンバにはできません"
 
-#: cp/decl.c:8499
+#: cp/decl.c:8520
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr ""
 
-#: cp/decl.c:8501
+#: cp/decl.c:8522
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr ""
 
-#: cp/decl.c:8506
+#: cp/decl.c:8527
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr ""
 
-#: cp/decl.c:8508
+#: cp/decl.c:8529
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr ""
 
-#: cp/decl.c:8510
+#: cp/decl.c:8531
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:8515
+#: cp/decl.c:8536
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr ""
 
-#: cp/decl.c:8517
+#: cp/decl.c:8538
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr ""
 
-#: cp/decl.c:8519
+#: cp/decl.c:8540
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr ""
 
-#: cp/decl.c:8524
+#: cp/decl.c:8545
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr ""
 
-#: cp/decl.c:8526
+#: cp/decl.c:8547
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr ""
 
-#: cp/decl.c:8528
+#: cp/decl.c:8549
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr ""
 
-#: cp/decl.c:8535
+#: cp/decl.c:8556
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "領域 `%s' は関数として宣言されています"
 
-#: cp/decl.c:8542
+#: cp/decl.c:8563
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "例外仕様の検査をするコードを生成しない"
 
-#: cp/decl.c:8574
+#: cp/decl.c:8595
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr ""
 
-#: cp/decl.c:8614
+#: cp/decl.c:8635
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr ""
 
-#: cp/decl.c:8624
+#: cp/decl.c:8645
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a non-parameter"
 msgid "concept %q#D declared with function parameters"
 msgstr "%qD は非仮引数として宣言されています"
 
-#: cp/decl.c:8630
+#: cp/decl.c:8651
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD declared with void type"
 msgid "concept %q#D declared with a deduced return type"
 msgstr "仮引数 %qD が void 型で宣言されています"
 
-#: cp/decl.c:8632
+#: cp/decl.c:8653
 #, fuzzy, gcc-internal-format
 #| msgid "Java method %qD has non-Java return type %qT"
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "Java メソッド %qD が非 Java 戻り型 %qT を持ちます"
 
-#: cp/decl.c:8703
+#: cp/decl.c:8724
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%> after union definition"
 msgid "concept %qD has no definition"
 msgstr "共用体定義の後には %<;%> が予期されます"
 
-#: cp/decl.c:8772
+#: cp/decl.c:8793
 #, fuzzy, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "宣言の中に代入(初期化ではなく)があります"
 
 #. Something like `template <class T> friend void f<T>()'.
-#: cp/decl.c:8782
+#: cp/decl.c:8803
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr ""
 
-#: cp/decl.c:8800
+#: cp/decl.c:8821
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:8808
+#: cp/decl.c:8829
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:8857
+#: cp/decl.c:8878
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "`::main' を template としては宣言できません"
 
-#: cp/decl.c:8859
+#: cp/decl.c:8880
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "`::main' を inline としては宣言できません"
 
-#: cp/decl.c:8861
+#: cp/decl.c:8882
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be %<constexpr%>"
 msgstr "`::main' を inline としては宣言できません"
 
-#: cp/decl.c:8863
+#: cp/decl.c:8884
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "`::main' を static としては宣言できません"
 
-#: cp/decl.c:8920
+#: cp/decl.c:8941
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.c:8921
+#: cp/decl.c:8942
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.c:8929
+#: cp/decl.c:8950
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD cannot be a bit-field"
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "静的メンバ %qD はビットフィールドに出来ません"
 
-#: cp/decl.c:8930
+#: cp/decl.c:8951
 #, fuzzy, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "`::main' を static としては宣言できません"
 
-#: cp/decl.c:8940
+#: cp/decl.c:8961
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared at namespace scope"
 msgstr ""
 
-#: cp/decl.c:8946
+#: cp/decl.c:8967
 #, fuzzy, gcc-internal-format
 msgid "deduction guide %qD must not have a function body"
 msgstr "`%s' の宣言は関数の配列"
 
-#: cp/decl.c:8959
+#: cp/decl.c:8980
 #, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr ""
 
-#: cp/decl.c:8969
+#: cp/decl.c:8990
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is an invalid argument to -mcpu="
 msgid "%qD has invalid argument list"
 msgstr "%qs は -mcpu= への引数としては無効です"
 
-#: cp/decl.c:8977
+#: cp/decl.c:8998
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:8983
+#: cp/decl.c:9004
 #, gcc-internal-format
 msgid "floating point suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:8991
+#: cp/decl.c:9012
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/decl.c:8996
+#: cp/decl.c:9017
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/decl.c:9076
+#: cp/decl.c:9097
 #, fuzzy, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "`main' は `int' を返さなければなりません"
 
-#: cp/decl.c:9116
+#: cp/decl.c:9137
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr ""
 
-#: cp/decl.c:9121
+#: cp/decl.c:9142
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of typedef %q+D"
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "typedef %q+D が再定義されました"
 
-#: cp/decl.c:9123
+#: cp/decl.c:9144
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared here"
 msgid "%q#D explicitly defaulted here"
 msgstr "%qD はここで宣言されています"
 
-#: cp/decl.c:9140
+#: cp/decl.c:9161
 #, fuzzy, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "メンバ関数へのポインタが呼ばれましたが、クラススコープ内ではありません"
 
-#: cp/decl.c:9329
+#: cp/decl.c:9350
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "`::main' を template としては宣言できません"
 
-#: cp/decl.c:9337
+#: cp/decl.c:9358
 #, fuzzy, gcc-internal-format
 #| msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "自動変数 %qE は %<threadprivate%> になることは出来ません"
 
-#: cp/decl.c:9344
+#: cp/decl.c:9365
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.c:9464
+#: cp/decl.c:9485
 #, fuzzy, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "ISO C++ は new 式の初期化での `=' を禁じます"
 
-#: cp/decl.c:9468
+#: cp/decl.c:9489
 #, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr ""
 
-#: cp/decl.c:9472
+#: cp/decl.c:9493
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr ""
 
-#: cp/decl.c:9486
+#: cp/decl.c:9507
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:9493
+#: cp/decl.c:9514
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ISO C++ は new 式の初期化での `=' を禁じます"
 
-#: cp/decl.c:9498
+#: cp/decl.c:9519
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO C++ は new 式の初期化での `=' を禁じます"
 
-#: cp/decl.c:9598
+#: cp/decl.c:9619
 #, fuzzy, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "配列 `%s' の大きさは非整数型"
 
-#: cp/decl.c:9600
+#: cp/decl.c:9621
 #, fuzzy, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "配列 `%s' の大きさは非整数型"
 
-#: cp/decl.c:9630 cp/decl.c:9680
+#: cp/decl.c:9651 cp/decl.c:9701
 #, fuzzy, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "定数式が欠けているか無効です"
 
-#: cp/decl.c:9646
+#: cp/decl.c:9667
 #, fuzzy, gcc-internal-format
 msgid "size of array %qD is negative"
 msgstr "配列 `%s' の大きさが負です"
 
-#: cp/decl.c:9648 cp/init.c:3651
+#: cp/decl.c:9669 cp/init.c:3667
 #, fuzzy, gcc-internal-format
 msgid "size of array is negative"
 msgstr "配列 `%s' の大きさが負です"
 
-#: cp/decl.c:9662
+#: cp/decl.c:9683
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C は サイズ 0 の配列 `%s' を禁じます"
 
-#: cp/decl.c:9664
+#: cp/decl.c:9685
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C は サイズ 0 の配列 `%s' を禁じます"
 
-#: cp/decl.c:9677
+#: cp/decl.c:9698
 #, fuzzy, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "配列 `%s' の大きさは非整数型"
 
-#: cp/decl.c:9686
+#: cp/decl.c:9707
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C89 は可変長サイズの配列 `%s' を禁じます"
 
-#: cp/decl.c:9688
+#: cp/decl.c:9709
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C89 は可変長サイズの配列 `%s' を禁じます"
 
-#: cp/decl.c:9694
+#: cp/decl.c:9715
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr ""
 
-#: cp/decl.c:9697
+#: cp/decl.c:9718
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr "可変長配列が使用されています"
 
-#: cp/decl.c:9746
+#: cp/decl.c:9767
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "配列の次元がオーバーフローしました"
 
-#: cp/decl.c:9799
+#: cp/decl.c:9820
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as array of %qT"
 msgstr "領域 `%s' は関数として宣言されています"
 
-#: cp/decl.c:9809
+#: cp/decl.c:9830
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "`%s' の宣言は void の配列"
 
-#: cp/decl.c:9811
+#: cp/decl.c:9832
 #, fuzzy, gcc-internal-format
 msgid "creating array of void"
 msgstr "`%s' の宣言は void の配列"
 
-#: cp/decl.c:9816
+#: cp/decl.c:9837
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "`%s' の宣言は関数の配列"
 
-#: cp/decl.c:9818
+#: cp/decl.c:9839
 #, fuzzy, gcc-internal-format
 msgid "creating array of functions"
 msgstr "`%s' の宣言は関数の配列"
 
-#: cp/decl.c:9823
+#: cp/decl.c:9844
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "`%s' の宣言は関数の配列"
 
-#: cp/decl.c:9825
+#: cp/decl.c:9846
 #, fuzzy, gcc-internal-format
 msgid "creating array of references"
 msgstr "配列参照での添字を欠いています"
 
-#: cp/decl.c:9830
+#: cp/decl.c:9851
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "`%s' の宣言は関数の配列"
 
-#: cp/decl.c:9832
+#: cp/decl.c:9853
 #, fuzzy, gcc-internal-format
 msgid "creating array of function members"
 msgstr "`%s' の宣言は関数の配列"
 
-#: cp/decl.c:9846
+#: cp/decl.c:9867
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.c:9850
+#: cp/decl.c:9871
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.c:9909
+#: cp/decl.c:9930
 #, fuzzy, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "コンストラクタに対する戻り値の型指定は無視されました"
 
-#: cp/decl.c:9912
+#: cp/decl.c:9933
 #, fuzzy, gcc-internal-format
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "大域 register 変数が関数定義の後ろにあります"
 
-#: cp/decl.c:9922
+#: cp/decl.c:9943
 #, fuzzy, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "コンストラクタに対する戻り値の型指定は無視されました"
 
-#: cp/decl.c:9925
+#: cp/decl.c:9946
 #, fuzzy, gcc-internal-format
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "大域 register 変数が関数定義の後ろにあります"
 
-#: cp/decl.c:9937
+#: cp/decl.c:9958
 #, fuzzy, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "コンストラクタに対する戻り値の型指定は無視されました"
 
-#: cp/decl.c:9940
+#: cp/decl.c:9961
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr ""
 
-#: cp/decl.c:9948
+#: cp/decl.c:9969
 #, fuzzy, gcc-internal-format
 msgid "return type specified for deduction guide"
 msgstr "コンストラクタに対する戻り値の型指定は無視されました"
 
-#: cp/decl.c:9951
+#: cp/decl.c:9972
 #, fuzzy, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "大域 register 変数が関数定義の後ろにあります"
 
-#: cp/decl.c:9955
+#: cp/decl.c:9976
 #, fuzzy, gcc-internal-format
 #| msgid "too many template parameter lists in declaration of %qD"
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "%qD の宣言内でテンプレート仮引数リストが多すぎます"
 
-#: cp/decl.c:9964
+#: cp/decl.c:9985
 #, fuzzy, gcc-internal-format
 msgid "decl-specifier in declaration of deduction guide"
 msgstr "`%s' の宣言が矛盾しています"
 
-#: cp/decl.c:9985
+#: cp/decl.c:10006
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "無名変数やフィールドが void と宣言されました"
 
-#: cp/decl.c:9992
+#: cp/decl.c:10013
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "変数またはフィールドが void と宣言されました"
 
-#: cp/decl.c:10007
+#: cp/decl.c:10028
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "大域スコープ外の関数 `%s' に対する記憶クラス `inline' は無効です"
 
-#: cp/decl.c:10013
+#: cp/decl.c:10034
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "inline variables are only available with -std=c++17 or -std=gnu++17"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/decl.c:10268
+#: cp/decl.c:10292
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "未定義の型 `%s %s' の使用は不適切です"
 
-#: cp/decl.c:10271 cp/decl.c:10291
+#: cp/decl.c:10295 cp/decl.c:10315
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "未定義の型 `%s %s' の使用は不適切です"
 
-#: cp/decl.c:10274
+#: cp/decl.c:10298
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "未定義の型 `%s %s' の使用は不適切です"
 
-#: cp/decl.c:10283
+#: cp/decl.c:10307
 #, gcc-internal-format
 msgid "%q#T is not a class or a namespace"
 msgstr ""
 
-#: cp/decl.c:10305 cp/decl.c:10398 cp/decl.c:10407 cp/decl.c:11970
+#: cp/decl.c:10329 cp/decl.c:10422 cp/decl.c:10431 cp/decl.c:11994
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "`%s' の宣言は関数の配列"
 
-#: cp/decl.c:10311
+#: cp/decl.c:10335
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as non-member"
 msgstr "`%s' の宣言は仮引数を覆い隠します"
 
-#: cp/decl.c:10339
+#: cp/decl.c:10363
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr ""
 
-#: cp/decl.c:10390
+#: cp/decl.c:10414
 #, fuzzy, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "関数の定義が `register' と宣言されました"
 
-#: cp/decl.c:10415
+#: cp/decl.c:10439
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "`%s' の extern 宣言がネストしています"
 
-#: cp/decl.c:10420
+#: cp/decl.c:10444
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of %qD as parameter"
 msgstr "%q+D の再宣言は仮引数を隠します"
 
-#: cp/decl.c:10454
+#: cp/decl.c:10478
 #, fuzzy, gcc-internal-format
 #| msgid "%<[*]%> not in a declaration"
 msgid "%<concept%> cannot appear in a typedef declaration"
 msgstr "宣言内にない %<[*]%> です"
 
-#: cp/decl.c:10460
+#: cp/decl.c:10484
 #, gcc-internal-format
 msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgstr ""
 
-#: cp/decl.c:10468
+#: cp/decl.c:10492
 #, fuzzy, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "`%s' の宣言に二つ以上のデータ型が指定されました"
 
-#: cp/decl.c:10474
+#: cp/decl.c:10498
 #, fuzzy, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr "`%s' の宣言が矛盾しています"
 
-#: cp/decl.c:10515
+#: cp/decl.c:10539
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C は単なる %<complex%> を %<double complex%> を意味するものとしてはサポートしません"
 
-#: cp/decl.c:10564 cp/decl.c:10567 cp/decl.c:10570
+#: cp/decl.c:10588 cp/decl.c:10591 cp/decl.c:10594
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ では型の無い %qs の宣言を禁止しています"
 
-#: cp/decl.c:10586
+#: cp/decl.c:10610
 #, fuzzy, gcc-internal-format
 #| msgid "%<__int128%> is not supported by this target"
 msgid "%<__int%d%> is not supported by this target"
 msgstr "このターゲットでは %<__int128%> はサポートされていません"
 
-#: cp/decl.c:10592
+#: cp/decl.c:10616
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not support %<__int128%> for %qs"
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ は %<__int128%> を %qs に対してはサポートしていません"
 
-#: cp/decl.c:10614 cp/decl.c:10634
+#: cp/decl.c:10638 cp/decl.c:10658
 #, gcc-internal-format
 msgid "%<signed%> or %<unsigned%> invalid for %qs"
 msgstr "%<signed%> または %<unsigned%> は %qs に対しては無効です"
 
-#: cp/decl.c:10616
+#: cp/decl.c:10640
 #, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgstr "%<signed%> と %<unsigned%> が %qs に対して両方指定されています"
 
-#: cp/decl.c:10618
+#: cp/decl.c:10642
 #, gcc-internal-format
 msgid "%<long long%> invalid for %qs"
 msgstr "%<long long%> は %qs に対しては無効です"
 
-#: cp/decl.c:10620
+#: cp/decl.c:10644
 #, gcc-internal-format
 msgid "%<long%> invalid for %qs"
 msgstr "%<long%> は %qs に対しては無効です"
 
-#: cp/decl.c:10622
+#: cp/decl.c:10646
 #, gcc-internal-format
 msgid "%<short%> invalid for %qs"
 msgstr "%<short%> は %qs に対しては無効です"
 
-#: cp/decl.c:10624
+#: cp/decl.c:10648
 #, gcc-internal-format
 msgid "%<long%> or %<short%> invalid for %qs"
 msgstr "%<long%> または %<short%> は %qs に対しては無効です"
 
-#: cp/decl.c:10626
+#: cp/decl.c:10650
 #, gcc-internal-format
 msgid "%<long%>, %<int%>, %<short%>, or %<char%> invalid for %qs"
 msgstr "%<long%>、%<int%>、%<short%>、または %<char%> は %qs に対しては無効です"
 
-#: cp/decl.c:10628
+#: cp/decl.c:10652
 #, gcc-internal-format
 msgid "%<long%> or %<short%> specified with char for %qs"
 msgstr "%<long%> または %<short%> が char と共に %qs に対して指定されています"
 
-#: cp/decl.c:10630
+#: cp/decl.c:10654
 #, gcc-internal-format
 msgid "%<long%> and %<short%> specified together for %qs"
 msgstr "%<long%> および %<short%> が %qs に対して両方指定されています"
 
-#: cp/decl.c:10636
+#: cp/decl.c:10660
 #, gcc-internal-format
 msgid "%<short%> or %<long%> invalid for %qs"
 msgstr "%<short%> または %<long%> は %qs に対しては無効です"
 
-#: cp/decl.c:10644
+#: cp/decl.c:10668
 #, gcc-internal-format
 msgid "long, short, signed or unsigned used invalidly for %qs"
 msgstr "long, short, signed または unsigned の使用は %qs に対しては無効です"
 
-#: cp/decl.c:10712
+#: cp/decl.c:10736
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "complex は %qs に対しては無効です"
 
-#: cp/decl.c:10751
+#: cp/decl.c:10775
 #, gcc-internal-format
 msgid "template placeholder type %qT must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.c:10769
+#: cp/decl.c:10793
 #, fuzzy, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "非メンバ `%s' を `mutable' とは宣言できません"
 
-#: cp/decl.c:10775
+#: cp/decl.c:10799
 #, fuzzy, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<constexpr%>"
 msgstr "非メンバ `%s' を `mutable' とは宣言できません"
 
-#: cp/decl.c:10785
+#: cp/decl.c:10809
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "仮引数宣言の中の typedef 宣言は無効です"
 
-#: cp/decl.c:10790
+#: cp/decl.c:10814
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "仮引数 `%s' で指定された記憶クラス"
 
-#: cp/decl.c:10796
+#: cp/decl.c:10820
 #, gcc-internal-format
 msgid "storage class specifiers invalid in parameter declarations"
 msgstr "仮引数宣言の中の記憶域クラス指定は無効です"
 
-#: cp/decl.c:10800
+#: cp/decl.c:10824
 #, fuzzy, gcc-internal-format
 #| msgid "a parameter cannot be declared %<constexpr%>"
 msgid "a parameter cannot be declared %<concept%>"
 msgstr "仮引数は %<constexpr%> として宣言してはいけません"
 
-#: cp/decl.c:10805
+#: cp/decl.c:10829
 #, gcc-internal-format
 msgid "a parameter cannot be declared %<constexpr%>"
 msgstr "仮引数は %<constexpr%> として宣言してはいけません"
 
-#: cp/decl.c:10815
+#: cp/decl.c:10839
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "%<virtual%> がクラス宣言外で使用されています"
 
-#: cp/decl.c:10825
+#: cp/decl.c:10849
 #, fuzzy, gcc-internal-format
 #| msgid "Warn when an inlined function cannot be inlined"
 msgid "structured binding declaration cannot be %<inline%>"
 msgstr "インライン関数をインライン化できない場合に警告する"
 
-#: cp/decl.c:10828
+#: cp/decl.c:10852
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %<typedef%>"
 msgstr "`%s' の extern 宣言がネストしています"
 
-#: cp/decl.c:10830
+#: cp/decl.c:10854
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %<constexpr%>"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/decl.c:10834
+#: cp/decl.c:10858
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr "`%s' の宣言に二つ以上のデータ型が指定されました"
 
-#: cp/decl.c:10839
+#: cp/decl.c:10863
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %<concept%>"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/decl.c:10845
+#: cp/decl.c:10869
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %<register%>"
 msgstr "`register' と宣言された配列に添字をつけようとしています"
 
-#: cp/decl.c:10849
+#: cp/decl.c:10873
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<static%>"
 msgstr ""
 
-#: cp/decl.c:10853
+#: cp/decl.c:10877
 #, fuzzy, gcc-internal-format
 #| msgid "nested function %qE declared %<extern%>"
 msgid "structured binding declaration cannot be %<extern%>"
 msgstr "入れ子になった関数 %qE が %<extern%> と宣言されています"
 
-#: cp/decl.c:10857
+#: cp/decl.c:10881
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %<mutable%>"
 msgstr "関数 `%s' を `mutable' としては宣言できません"
 
-#: cp/decl.c:10861
+#: cp/decl.c:10885
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10872
+#: cp/decl.c:10896
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr "`%s' の宣言に二つ以上のデータ型が指定されました"
 
-#: cp/decl.c:10875
+#: cp/decl.c:10899
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10906
+#: cp/decl.c:10930
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "%qs の宣言内に複数の記憶域クラスがあります"
 
-#: cp/decl.c:10929
+#: cp/decl.c:10953
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "%qs に対して記憶域クラスが指定されています"
 
-#: cp/decl.c:10933
+#: cp/decl.c:10957
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "仮引数 %qs に対して記憶域クラスタ指定されています"
 
-#: cp/decl.c:10946
+#: cp/decl.c:10970
 #, fuzzy, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "ネストした関数 `%s' は `extern' に宣言されました"
 
-#: cp/decl.c:10950
+#: cp/decl.c:10974
 #, fuzzy, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "`%s' のトップレベルの宣言が `auto' を指定します"
 
-#: cp/decl.c:10957
+#: cp/decl.c:10981
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr ""
 
-#: cp/decl.c:10969
+#: cp/decl.c:10993
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "friend 関数宣言内の記憶クラス指定子は無効です"
 
-#: cp/decl.c:11050
+#: cp/decl.c:11074
 #, fuzzy, gcc-internal-format
 #| msgid "multiple storage classes in declaration of %qs"
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "%qs の宣言内に複数の記憶域クラスがあります"
 
-#: cp/decl.c:11098
+#: cp/decl.c:11122
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.c:11118
+#: cp/decl.c:11142
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.c:11121
+#: cp/decl.c:11145
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/decl.c:11127
+#: cp/decl.c:11151
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual function cannot have deduced return type"
 msgstr "仮想関数は friend にできません"
 
-#: cp/decl.c:11134
+#: cp/decl.c:11158
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:11147
+#: cp/decl.c:11171
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "deduced class type %qD in function return type"
 msgstr "関数戻り値の型修飾子は無視されました"
 
-#: cp/decl.c:11156
+#: cp/decl.c:11180
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr ""
 
-#: cp/decl.c:11169
+#: cp/decl.c:11193
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
@@ -46290,59 +46334,59 @@
 
 #. Not using maybe_warn_cpp0x because this should
 #. always be an error.
-#: cp/decl.c:11180
+#: cp/decl.c:11204
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/decl.c:11183
+#: cp/decl.c:11207
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.c:11212
+#: cp/decl.c:11236
 #, fuzzy, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "`%s' は関数を返す関数として宣言されています"
 
-#: cp/decl.c:11218
+#: cp/decl.c:11242
 #, fuzzy, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "`%s' は配列を返す関数として宣言されています"
 
-#: cp/decl.c:11247
+#: cp/decl.c:11271
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/decl.c:11248
+#: cp/decl.c:11272
 #, fuzzy, gcc-internal-format
 #| msgid "destructor cannot be static member function"
 msgid "constructor cannot be static member function"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/decl.c:11252
+#: cp/decl.c:11276
 #, fuzzy, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "コンストラクタは virtual 宣言できません"
 
-#: cp/decl.c:11253
+#: cp/decl.c:11277
 #, fuzzy, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "コンストラクタは virtual 宣言できません"
 
-#: cp/decl.c:11261
+#: cp/decl.c:11285
 #, fuzzy, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr "コンストラクタは virtual 宣言できません"
 
-#: cp/decl.c:11262
+#: cp/decl.c:11286
 #, fuzzy, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr "コンストラクタは virtual 宣言できません"
 
-#: cp/decl.c:11280
+#: cp/decl.c:11304
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructors cannot be declared %<virtual%>"
@@ -46349,410 +46393,410 @@
 msgstr "コンストラクタは virtual 宣言できません"
 
 #. Cannot be both friend and virtual.
-#: cp/decl.c:11295
+#: cp/decl.c:11319
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "仮想関数は friend にできません"
 
-#: cp/decl.c:11299
+#: cp/decl.c:11323
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "friend 宣言がクラス定義の中にありません"
 
-#: cp/decl.c:11301
+#: cp/decl.c:11325
 #, gcc-internal-format
 msgid "can%'t define friend function %qs in a local class definition"
 msgstr ""
 
-#: cp/decl.c:11313
+#: cp/decl.c:11337
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr ""
 
-#: cp/decl.c:11339
+#: cp/decl.c:11363
 #, fuzzy, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "デストラクタは仮引数を取りません"
 
-#: cp/decl.c:11379
+#: cp/decl.c:11403
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "ポインタを参照として宣言できません"
 
-#: cp/decl.c:11392 cp/decl.c:11399
+#: cp/decl.c:11416 cp/decl.c:11423
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "参照を参照として宣言できません"
 
-#: cp/decl.c:11401
+#: cp/decl.c:11425
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "ポインタを参照として宣言できません"
 
-#: cp/decl.c:11430
+#: cp/decl.c:11454
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "参照を参照として宣言できません"
 
-#: cp/decl.c:11431
+#: cp/decl.c:11455
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "ポインタを参照として宣言できません"
 
-#: cp/decl.c:11504
+#: cp/decl.c:11528
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.c:11574
+#: cp/decl.c:11598
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr ""
 
-#: cp/decl.c:11599
+#: cp/decl.c:11623
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "メンバ関数は暗黙的にそのクラスの friend です"
 
-#: cp/decl.c:11605
+#: cp/decl.c:11629
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr ""
 
-#: cp/decl.c:11635
+#: cp/decl.c:11659
 #, fuzzy, gcc-internal-format
 #| msgid "cannot call member function %qD without object"
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "オブジェクト以外がメンバ関数 %qD を呼び出すことは出来ません"
 
-#: cp/decl.c:11637
+#: cp/decl.c:11661
 #, fuzzy, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "`::main' を static としては宣言できません"
 
-#: cp/decl.c:11645
+#: cp/decl.c:11669
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.c:11685
+#: cp/decl.c:11709
 #, fuzzy, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "非メンバ `%s' を `mutable' とは宣言できません"
 
-#: cp/decl.c:11693
+#: cp/decl.c:11717
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.c:11695
+#: cp/decl.c:11719
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.c:11706
+#: cp/decl.c:11730
 #, fuzzy, gcc-internal-format
 #| msgid "%<virtual%> outside class declaration"
 msgid "%<explicit%> outside class declaration"
 msgstr "%<virtual%> がクラス宣言外で使用されています"
 
-#: cp/decl.c:11709
+#: cp/decl.c:11733
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<explicit%> in friend declaration"
 msgstr "空の宣言内に %<inline%> があります"
 
-#: cp/decl.c:11712
+#: cp/decl.c:11736
 #, fuzzy, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "`explicit' にできるのは、コンストラクタだけです"
 
-#: cp/decl.c:11721
+#: cp/decl.c:11745
 #, fuzzy, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "非メンバ `%s' を `mutable' とは宣言できません"
 
-#: cp/decl.c:11726
+#: cp/decl.c:11750
 #, fuzzy, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "非オブジェクトメンバ `%s' を `mutable' とは宣言できません"
 
-#: cp/decl.c:11732
+#: cp/decl.c:11756
 #, fuzzy, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "関数 `%s' を `mutable' としては宣言できません"
 
-#: cp/decl.c:11737
+#: cp/decl.c:11761
 #, fuzzy, gcc-internal-format
 msgid "static %qs cannot be declared %<mutable%>"
 msgstr "static `%s' を mutable として宣言できません"
 
-#: cp/decl.c:11742
+#: cp/decl.c:11766
 #, fuzzy, gcc-internal-format
 msgid "const %qs cannot be declared %<mutable%>"
 msgstr "const `%s' を `mutable' として宣言できません"
 
-#: cp/decl.c:11747
+#: cp/decl.c:11771
 #, fuzzy, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "関数 `%s' を `mutable' としては宣言できません"
 
-#: cp/decl.c:11778
+#: cp/decl.c:11802
 #, fuzzy, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "仮引数 `%s' が void と宣言されています"
 
-#: cp/decl.c:11783
+#: cp/decl.c:11807
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.c:11787
+#: cp/decl.c:11811
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr ""
 
-#: cp/decl.c:11813
+#: cp/decl.c:11837
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr ""
 
-#: cp/decl.c:11900
+#: cp/decl.c:11924
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "クラス宣言の外側で virtual 指定しています"
 
-#: cp/decl.c:11908
+#: cp/decl.c:11932
 #, fuzzy, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "複雑なパラメタをもつ関数は inline にできません"
 
-#: cp/decl.c:11910
+#: cp/decl.c:11934
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr ""
 
-#: cp/decl.c:11914
+#: cp/decl.c:11938
 #, fuzzy, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "friend 宣言がクラス定義の中にありません"
 
-#: cp/decl.c:11927
+#: cp/decl.c:11951
 #, fuzzy, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "クラス `%s' を大域スコープの friend にしようとしています"
 
-#: cp/decl.c:11947
+#: cp/decl.c:11971
 #, fuzzy, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "非メンバ関数での `this' の使用は無効です"
 
-#: cp/decl.c:11951
+#: cp/decl.c:11975
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.c:11961
+#: cp/decl.c:11985
 #, fuzzy, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "`%s' の宣言はグローバル宣言を覆い隠します"
 
-#: cp/decl.c:11976
+#: cp/decl.c:12000
 #, fuzzy, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "`enum %s' の再宣言"
 
-#: cp/decl.c:11995
+#: cp/decl.c:12019
 #, fuzzy, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "仮引数宣言の中で `::' を使えません"
 
-#: cp/decl.c:12001
+#: cp/decl.c:12025
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "マクロ引数内でディレクトリを使うことはできません"
 
-#: cp/decl.c:12003
+#: cp/decl.c:12027
 #, fuzzy, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "仮引数 `%s' が void と宣言されています"
 
-#: cp/decl.c:12052 cp/parser.c:3270
+#: cp/decl.c:12076 cp/parser.c:3270
 #, fuzzy, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "無効なデフォルトテンプレート引数"
 
-#: cp/decl.c:12056
+#: cp/decl.c:12080
 #, fuzzy, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr "%s に `%s' という名前のメンバはありません"
 
-#: cp/decl.c:12080
+#: cp/decl.c:12104
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C は サイズ 0 の配列 `%s' を禁じます"
 
-#: cp/decl.c:12083
+#: cp/decl.c:12107
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids flexible array members"
 msgstr "ISO C は サイズ 0 の配列 `%s' を禁じます"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:12099
+#: cp/decl.c:12123
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "無効な用法の of %%d, %%x, 又は %%X"
 
-#: cp/decl.c:12121
+#: cp/decl.c:12145
 #, fuzzy, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "%s: 関数 `%s' の宣言が変換されていません\n"
 
-#: cp/decl.c:12130
+#: cp/decl.c:12154
 #, fuzzy, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "領域 `%s' は関数として宣言されています"
 
-#: cp/decl.c:12139
+#: cp/decl.c:12163
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "`::main' を static としては宣言できません"
 
-#: cp/decl.c:12153
+#: cp/decl.c:12177
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr ""
 
-#: cp/decl.c:12160
+#: cp/decl.c:12184
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "`%s' の宣言により `this' のメンバが覆い隠されます"
 
-#: cp/decl.c:12166
+#: cp/decl.c:12190
 #, fuzzy, gcc-internal-format
 msgid "a destructor cannot be %<concept%>"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/decl.c:12171
+#: cp/decl.c:12195
 #, fuzzy, gcc-internal-format
 msgid "a destructor cannot be %<constexpr%>"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/decl.c:12177
+#: cp/decl.c:12201
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr ""
 
-#: cp/decl.c:12185
+#: cp/decl.c:12209
 #, fuzzy, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/decl.c:12190
+#: cp/decl.c:12214
 #, fuzzy, gcc-internal-format
 #| msgid "destructor cannot be static member function"
 msgid "a concept cannot be a member function"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/decl.c:12199
+#: cp/decl.c:12223
 #, fuzzy, gcc-internal-format
 #| msgid "variable %qD redeclared as function"
 msgid "specialization of variable template %qD declared as function"
 msgstr "変数 %qD が関数として再宣言されました"
 
-#: cp/decl.c:12202
+#: cp/decl.c:12226
 #, fuzzy, gcc-internal-format
 #| msgid "original type declared here"
 msgid "variable template declared here"
 msgstr "元の型はここで宣言されました"
 
-#: cp/decl.c:12257
+#: cp/decl.c:12281
 #, fuzzy, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr "領域 `%s' は不完全な型です"
 
-#: cp/decl.c:12262
+#: cp/decl.c:12286
 #, fuzzy, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "仮引数が不完全型です"
 
-#: cp/decl.c:12272
+#: cp/decl.c:12296
 #, fuzzy, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "`%s' は関数でもメンバ関数でもありません -- friend とは宣言できません"
 
-#: cp/decl.c:12318
+#: cp/decl.c:12342
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared %<inline%>"
 msgid "static data member %qE declared %<concept%>"
 msgstr "仮引数 %q+D が %<inline%> と宣言されています"
 
-#: cp/decl.c:12322
+#: cp/decl.c:12346
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "関数を inline にできません"
 
-#: cp/decl.c:12350
+#: cp/decl.c:12374
 #, fuzzy, gcc-internal-format
 msgid "non-static data member %qE declared %<concept%>"
 msgstr "非オブジェクトメンバ `%s' を `mutable' とは宣言できません"
 
-#: cp/decl.c:12354
+#: cp/decl.c:12378
 #, gcc-internal-format
 msgid "non-static data member %qE declared %<constexpr%>"
 msgstr ""
 
-#: cp/decl.c:12409
+#: cp/decl.c:12433
 #, fuzzy, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "関数 `%s' に対する記憶クラス `auto' は無効です"
 
-#: cp/decl.c:12411
+#: cp/decl.c:12435
 #, fuzzy, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "関数 `%s' に対する記憶クラス `register' は無効です"
 
-#: cp/decl.c:12415
+#: cp/decl.c:12439
 #, fuzzy, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "関数 `%s' に対する記憶クラス `auto' は無効です"
 
-#: cp/decl.c:12418
+#: cp/decl.c:12442
 #, fuzzy, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "関数 `%s' に対する記憶クラス `auto' は無効です"
 
-#: cp/decl.c:12423
+#: cp/decl.c:12447
 #, fuzzy, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "初期化子リストは非メンバ関数では使えません"
 
-#: cp/decl.c:12434
+#: cp/decl.c:12458
 #, fuzzy, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "大域スコープ外の関数 `%s' に対する記憶クラス `inline' は無効です"
 
-#: cp/decl.c:12438
+#: cp/decl.c:12462
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "大域スコープ外の関数 `%s' に対する記憶クラス `inline' は無効です"
 
-#: cp/decl.c:12446
+#: cp/decl.c:12470
 #, fuzzy, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "virtual な非クラス関数 `%s'"
 
-#: cp/decl.c:12453
+#: cp/decl.c:12477
 #, fuzzy, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "メソッド定義がクラスコンテキスト内ではありません"
 
-#: cp/decl.c:12454
+#: cp/decl.c:12478
 #, fuzzy, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "メソッド定義がクラスコンテキスト内ではありません"
 
-#: cp/decl.c:12489
+#: cp/decl.c:12513
 #, fuzzy, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "`::main' を static としては宣言できません"
@@ -46759,78 +46803,78 @@
 
 #. 7.1.1: There can be no static function declarations within a
 #. block.
-#: cp/decl.c:12497
+#: cp/decl.c:12521
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "他の関数内で static 関数を宣言できません"
 
-#: cp/decl.c:12533
+#: cp/decl.c:12557
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr ""
 
-#: cp/decl.c:12540
+#: cp/decl.c:12564
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr ""
 
-#: cp/decl.c:12546
+#: cp/decl.c:12570
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr ""
 
-#: cp/decl.c:12553
+#: cp/decl.c:12577
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "%<extern%> 変数 %qD の宣言が %<for%> ループ初期化宣言内にあります"
 
-#: cp/decl.c:12574
+#: cp/decl.c:12598
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "`%s' の宣言に `extern' がついており、初期化もされています"
 
-#: cp/decl.c:12585
+#: cp/decl.c:12609
 #, fuzzy, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "`%s' が初期化されるところで、`extern' 宣言されました"
 
-#: cp/decl.c:12589
+#: cp/decl.c:12613
 #, fuzzy, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "`%s' に `extern' と初期化子の両方があります"
 
-#: cp/decl.c:12754
+#: cp/decl.c:12778
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "関数がローカル変数のアドレスを返しています"
 
-#: cp/decl.c:12757
+#: cp/decl.c:12781
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "関数がローカル変数のアドレスを返しています"
 
-#: cp/decl.c:12841
+#: cp/decl.c:12865
 #, fuzzy, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "不完全な typedef `%s' の使用は不適切です"
 
-#: cp/decl.c:12845
+#: cp/decl.c:12869
 #, fuzzy, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "仮引数宣言の中で `::' を使えません"
 
-#: cp/decl.c:12868
+#: cp/decl.c:12892
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "パラメタはメソッドの型を不正に宣言しました"
 
-#: cp/decl.c:12895
+#: cp/decl.c:12919
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.c:12897
+#: cp/decl.c:12921
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr ""
@@ -46850,170 +46894,170 @@
 #. or implicitly defined), there's no need to worry about their
 #. existence.  Theoretically, they should never even be
 #. instantiated, but that's hard to forestall.
-#: cp/decl.c:13150
+#: cp/decl.c:13174
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr ""
 
-#: cp/decl.c:13228
+#: cp/decl.c:13252
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr ""
 
-#: cp/decl.c:13234
+#: cp/decl.c:13258
 #, fuzzy, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "`::main' を static としては宣言できません"
 
-#: cp/decl.c:13261
+#: cp/decl.c:13285
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/decl.c:13267
+#: cp/decl.c:13291
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr ""
 
-#: cp/decl.c:13277
+#: cp/decl.c:13301
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr ""
 
 #. 13.4.0.3
-#: cp/decl.c:13303
+#: cp/decl.c:13327
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ prohibits overloading operator ?:"
 msgstr "ISO C++ は無名構造体を禁止しています"
 
 #. Variadic.
-#: cp/decl.c:13314
+#: cp/decl.c:13338
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr ""
 
-#: cp/decl.c:13338
+#: cp/decl.c:13362
 #, fuzzy, gcc-internal-format
 msgid "%qD must have either zero or one argument"
 msgstr "`%s' は 0 か 2 個の引数しかとりません"
 
-#: cp/decl.c:13339
+#: cp/decl.c:13363
 #, fuzzy, gcc-internal-format
 msgid "%qD must have either one or two arguments"
 msgstr "`%s' は 0 か 2 個の引数しかとりません"
 
-#: cp/decl.c:13350
+#: cp/decl.c:13374
 #, fuzzy, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "`%s' は 0 か 2 個の引数しかとりません"
 
-#: cp/decl.c:13351
+#: cp/decl.c:13375
 #, fuzzy, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "`%s' は 0 か 2 個の引数しかとりません"
 
-#: cp/decl.c:13361
+#: cp/decl.c:13385
 #, fuzzy, gcc-internal-format
 msgid "%qD must have no arguments"
 msgstr "`%s' は 0 か 2 個の引数しかとりません"
 
-#: cp/decl.c:13362 cp/decl.c:13371
+#: cp/decl.c:13386 cp/decl.c:13395
 #, fuzzy, gcc-internal-format
 msgid "%qD must have exactly one argument"
 msgstr "`%s' は 0 か 2 個の引数しかとりません"
 
-#: cp/decl.c:13372
+#: cp/decl.c:13396
 #, fuzzy, gcc-internal-format
 msgid "%qD must have exactly two arguments"
 msgstr "`%s' は 0 か 2 個の引数しかとりません"
 
-#: cp/decl.c:13389 cp/decl.c:13392
+#: cp/decl.c:13413 cp/decl.c:13416
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr ""
 
-#: cp/decl.c:13419
+#: cp/decl.c:13443
 #, fuzzy, gcc-internal-format
 msgid "conversion to a reference to void will never use a type conversion operator"
 msgstr "%s%s への変換で型変換演算子が利用されることは決してありません"
 
-#: cp/decl.c:13421
+#: cp/decl.c:13445
 #, fuzzy, gcc-internal-format
 msgid "conversion to void will never use a type conversion operator"
 msgstr "%s%s への変換で型変換演算子が利用されることは決してありません"
 
-#: cp/decl.c:13428
+#: cp/decl.c:13452
 #, fuzzy, gcc-internal-format
 msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgstr "%s%s への変換で型変換演算子が利用されることは決してありません"
 
-#: cp/decl.c:13430
+#: cp/decl.c:13454
 #, fuzzy, gcc-internal-format
 msgid "conversion to the same type will never use a type conversion operator"
 msgstr "%s%s への変換で型変換演算子が利用されることは決してありません"
 
-#: cp/decl.c:13438
+#: cp/decl.c:13462
 #, fuzzy, gcc-internal-format
 msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgstr "%s%s への変換で型変換演算子が利用されることは決してありません"
 
-#: cp/decl.c:13440
+#: cp/decl.c:13464
 #, fuzzy, gcc-internal-format
 msgid "conversion to a base class will never use a type conversion operator"
 msgstr "%s%s への変換で型変換演算子が利用されることは決してありません"
 
-#: cp/decl.c:13455
+#: cp/decl.c:13479
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr ""
 
-#: cp/decl.c:13474
+#: cp/decl.c:13498
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.c:13480
+#: cp/decl.c:13504
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.c:13492
+#: cp/decl.c:13516
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr ""
 
-#: cp/decl.c:13547
+#: cp/decl.c:13571
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr ""
 
-#: cp/decl.c:13570
+#: cp/decl.c:13594
 #, fuzzy, gcc-internal-format
 #| msgid "invalid template declaration of %qD"
 msgid "using alias template specialization %qT after %qs"
 msgstr "%qD の無効なテンプレート宣言です"
 
-#: cp/decl.c:13573
+#: cp/decl.c:13597
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr ""
 
-#: cp/decl.c:13575
+#: cp/decl.c:13599
 #, fuzzy, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "前方での `%s' の宣言"
 
-#: cp/decl.c:13583
+#: cp/decl.c:13607
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr ""
 
-#: cp/decl.c:13584 cp/decl.c:13591
+#: cp/decl.c:13608 cp/decl.c:13615
 #, fuzzy, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr "前方での `%s' の宣言"
 
-#: cp/decl.c:13590
+#: cp/decl.c:13614
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr ""
@@ -47025,94 +47069,94 @@
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:13605
+#: cp/decl.c:13629
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr ""
 
-#: cp/decl.c:13659 cp/name-lookup.c:4652
+#: cp/decl.c:13683 cp/name-lookup.c:4652
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr ""
 
-#: cp/decl.c:13689 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6425
-#: cp/pt.c:9209
+#: cp/decl.c:13713 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6428
+#: cp/pt.c:9223
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr ""
 
-#: cp/decl.c:13694
+#: cp/decl.c:13718
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:13703 cp/name-lookup.c:4079 cp/name-lookup.c:4086
-#: cp/name-lookup.c:4939 cp/parser.c:6376 cp/parser.c:26300
+#: cp/decl.c:13727 cp/name-lookup.c:4079 cp/name-lookup.c:4086
+#: cp/name-lookup.c:4939 cp/parser.c:6379 cp/parser.c:26297
 #, fuzzy, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "%s: オプション `%s' はあいまいです\n"
 
-#: cp/decl.c:13806
+#: cp/decl.c:13830
 #, fuzzy, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "事前の宣言なしの大域関数に関して警告する"
 
-#: cp/decl.c:13842
+#: cp/decl.c:13866
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "`%s' の宣言は仮引数を覆い隠します"
 
-#: cp/decl.c:13982
+#: cp/decl.c:14006
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr ""
 
-#: cp/decl.c:13989
+#: cp/decl.c:14013
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr ""
 
-#: cp/decl.c:14000
+#: cp/decl.c:14024
 #, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr ""
 
-#: cp/decl.c:14025
+#: cp/decl.c:14049
 #, fuzzy, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "型修飾子 `%s' は struct や class の後には使えません"
 
-#: cp/decl.c:14055
+#: cp/decl.c:14079
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr ""
 
-#: cp/decl.c:14057
+#: cp/decl.c:14081
 #, fuzzy, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "重複した case の値"
 
-#: cp/decl.c:14202
+#: cp/decl.c:14226
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14205 cp/decl.c:14213 cp/decl.c:14225 cp/parser.c:18284
+#: cp/decl.c:14229 cp/decl.c:14237 cp/decl.c:14249 cp/parser.c:18281
 #, fuzzy, gcc-internal-format
 msgid "previous definition here"
 msgstr "`%s' は前にここで定義されました"
 
-#: cp/decl.c:14210
+#: cp/decl.c:14234
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14222
+#: cp/decl.c:14246
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14300
+#: cp/decl.c:14324
 #, fuzzy, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr "述語は識別子でなければなりません"
@@ -47121,82 +47165,82 @@
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:14447
+#: cp/decl.c:14471
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr ""
 
-#: cp/decl.c:14619
+#: cp/decl.c:14643
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "`%s' の列挙値が整数定数ではありません"
 
-#: cp/decl.c:14629
+#: cp/decl.c:14653
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "`%s' の列挙値が整数定数ではありません"
 
-#: cp/decl.c:14678
+#: cp/decl.c:14702
 #, fuzzy, gcc-internal-format
 #| msgid "integer constant is too large for %<unsigned long%> type"
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "整数定数が %<unsigned long%> 型に対して大きすぎます"
 
-#: cp/decl.c:14679
+#: cp/decl.c:14703
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C restricts enumerator values to range of %<int%>"
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "ISO C は列挙値を %<int%> の範囲に制限しています"
 
-#: cp/decl.c:14690
+#: cp/decl.c:14714
 #, fuzzy, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "列挙値がオーバーフロー"
 
-#: cp/decl.c:14710
+#: cp/decl.c:14734
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qE is not an integer constant"
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "%qE 用の列挙値が整数定数ではありません"
 
-#: cp/decl.c:14821
+#: cp/decl.c:14845
 #, fuzzy, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "戻り値の型が不完全型です"
 
-#: cp/decl.c:14999 cp/typeck.c:9286
+#: cp/decl.c:15023 cp/typeck.c:9286
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr ""
 
-#: cp/decl.c:15344
+#: cp/decl.c:15368
 #, fuzzy, gcc-internal-format
 msgid "invalid function declaration"
 msgstr "無効な宣言です"
 
-#: cp/decl.c:15786
+#: cp/decl.c:15810
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statements in function returning %qT"
 msgstr "非 void を戻す関数内に return 文がありません"
 
-#: cp/decl.c:15788 cp/typeck.c:9166
+#: cp/decl.c:15812 cp/typeck.c:9166
 #, fuzzy, gcc-internal-format
 #| msgid "function return types not compatible due to %<volatile%>"
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "関数の戻り型は %<volatile%> と互換性がありません"
 
-#: cp/decl.c:15996
+#: cp/decl.c:16020
 #, fuzzy, gcc-internal-format
 msgid "invalid member function declaration"
 msgstr "無効な宣言です"
 
-#: cp/decl.c:16010
+#: cp/decl.c:16034
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr ""
 
-#: cp/decl.c:16386
+#: cp/decl.c:16410
 #, fuzzy, gcc-internal-format
 #| msgid "type of %qD defaults to %<int%>"
 msgid "use of %qD before deduction of %<auto%>"
@@ -47238,7 +47282,7 @@
 msgid "deleting %qT is undefined"
 msgstr "%qT の削除は定義されていません"
 
-#: cp/decl2.c:585 cp/pt.c:5552
+#: cp/decl2.c:585 cp/pt.c:5566
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "%q#D のテンプレート宣言です"
@@ -47251,7 +47295,7 @@
 #. [temp.mem]
 #.
 #. A destructor shall not be a member template.
-#: cp/decl2.c:640 cp/pt.c:5511
+#: cp/decl2.c:640 cp/pt.c:5525
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "デストラクタ %qD がメンバテンプレートとして宣言されています"
@@ -47434,47 +47478,47 @@
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "`operator delete' は第一引数として `void *' 型をとります"
 
-#: cp/decl2.c:2660
+#: cp/decl2.c:2650
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2664
+#: cp/decl2.c:2654
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2669
+#: cp/decl2.c:2659
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2677
+#: cp/decl2.c:2667
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr ""
 
-#: cp/decl2.c:2695
+#: cp/decl2.c:2685
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2699
+#: cp/decl2.c:2689
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2704
+#: cp/decl2.c:2694
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2711
+#: cp/decl2.c:2701
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr ""
 
-#: cp/decl2.c:4309
+#: cp/decl2.c:4299
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using unnamed type, is used but never defined"
 msgstr "`%s' が `static' と宣言されましたが未定義です"
@@ -47483,63 +47527,63 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4318
+#: cp/decl2.c:4308
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4322
+#: cp/decl2.c:4312
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4326
+#: cp/decl2.c:4316
 #, gcc-internal-format
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr ""
 
-#: cp/decl2.c:4334
+#: cp/decl2.c:4324
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "`%s' が `static' と宣言されましたが未定義です"
 
-#: cp/decl2.c:4338
+#: cp/decl2.c:4328
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4341
+#: cp/decl2.c:4331
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4529
+#: cp/decl2.c:4519
 #, fuzzy, gcc-internal-format
 #| msgid "section of %q+D conflicts with previous declaration"
 msgid "mangling of %q#D as %qE conflicts with a previous mangle"
 msgstr "%q+D のセクションが前の宣言と競合しています"
 
-#: cp/decl2.c:4532
+#: cp/decl2.c:4522
 #, fuzzy, gcc-internal-format
 msgid "previous mangling %q#D"
 msgstr "前方での `%s' の宣言"
 
-#: cp/decl2.c:4534
+#: cp/decl2.c:4524
 #, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr ""
 
-#: cp/decl2.c:4606 cp/decl2.c:4609
+#: cp/decl2.c:4596 cp/decl2.c:4599
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.c:4956
+#: cp/decl2.c:4946
 #, fuzzy, gcc-internal-format
 msgid "inline function %qD used but never defined"
 msgstr "`%s' が使われましたが未定義です"
 
-#: cp/decl2.c:5143
+#: cp/decl2.c:5133
 #, fuzzy, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr "仮引数リストからの仮引数名を欠いています"
@@ -47546,17 +47590,17 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5251
+#: cp/decl2.c:5241
 #, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.c:5254
+#: cp/decl2.c:5244
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr ""
 
-#: cp/decl2.c:5307
+#: cp/decl2.c:5297
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr ""
@@ -47860,45 +47904,45 @@
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr "%q#D 用のデフォルト引数の再定義です"
 
-#: cp/init.c:613
+#: cp/init.c:629
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr ""
 
-#: cp/init.c:615
+#: cp/init.c:631
 #, fuzzy, gcc-internal-format
 #| msgid "union defined here"
 msgid "defined here"
 msgstr "共用体がここで定義されています"
 
-#: cp/init.c:673
+#: cp/init.c:689
 #, fuzzy, gcc-internal-format
 #| msgid "initialization of a flexible array member"
 msgid "initializer for flexible array member %q#D"
 msgstr "可変配列メンバを初期化しています"
 
-#: cp/init.c:699
+#: cp/init.c:715
 #, gcc-internal-format
 msgid "%qD should be initialized in the member initialization list"
 msgstr ""
 
-#: cp/init.c:720
+#: cp/init.c:736
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is used uninitialized in this function"
 msgid "%qD is initialized with itself"
 msgstr "%qD はこの関数内で初期化されずに使用されています"
 
-#: cp/init.c:831
+#: cp/init.c:847
 #, gcc-internal-format
 msgid "invalid initializer for array member %q#D"
 msgstr ""
 
-#: cp/init.c:845 cp/init.c:869 cp/init.c:2410 cp/method.c:1368
+#: cp/init.c:861 cp/init.c:885 cp/init.c:2427 cp/method.c:1368
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr ""
 
-#: cp/init.c:847 cp/init.c:864 cp/init.c:871 cp/init.c:2395 cp/init.c:2423
+#: cp/init.c:863 cp/init.c:880 cp/init.c:887 cp/init.c:2412 cp/init.c:2440
 #: cp/method.c:1371 cp/method.c:1382
 #, fuzzy, gcc-internal-format
 #| msgid "%qD should be initialized"
@@ -47905,296 +47949,296 @@
 msgid "%q#D should be initialized"
 msgstr "%qD は初期化されるべきです"
 
-#: cp/init.c:862 cp/init.c:2382 cp/method.c:1379
+#: cp/init.c:878 cp/init.c:2399 cp/method.c:1379
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr ""
 
-#: cp/init.c:1041
+#: cp/init.c:1057
 #, fuzzy, gcc-internal-format
 #| msgid "%qD should be initialized"
 msgid "%qD will be initialized after"
 msgstr "%qD は初期化されるべきです"
 
-#: cp/init.c:1044
+#: cp/init.c:1060
 #, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr ""
 
-#: cp/init.c:1048
+#: cp/init.c:1064
 #, gcc-internal-format
 msgid "  %q#D"
 msgstr ""
 
-#: cp/init.c:1050
+#: cp/init.c:1066
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr ""
 
-#: cp/init.c:1052
+#: cp/init.c:1068
 #, fuzzy, gcc-internal-format
 msgid "  when initialized here"
 msgstr "無効な初期化子"
 
-#: cp/init.c:1069
+#: cp/init.c:1085
 #, fuzzy, gcc-internal-format
 msgid "multiple initializations given for %qD"
 msgstr "(`%s' の初期化は不完全です)"
 
-#: cp/init.c:1073
+#: cp/init.c:1089
 #, fuzzy, gcc-internal-format
 msgid "multiple initializations given for base %qT"
 msgstr "(`%s' の初期化は不完全です)"
 
-#: cp/init.c:1158
+#: cp/init.c:1174
 #, fuzzy, gcc-internal-format
 msgid "initializations for multiple members of %qT"
 msgstr "可変配列メンバを初期化しています"
 
-#: cp/init.c:1255
+#: cp/init.c:1271
 #, gcc-internal-format
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr ""
 
-#: cp/init.c:1482 cp/init.c:1501
+#: cp/init.c:1498 cp/init.c:1517
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr ""
 
-#: cp/init.c:1488
+#: cp/init.c:1504
 #, fuzzy, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr "`com_interface' 属性はクラス定義にのみ用いる事ができます"
 
-#: cp/init.c:1495
+#: cp/init.c:1511
 #, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr ""
 
-#: cp/init.c:1534
+#: cp/init.c:1550
 #, fuzzy, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr "基底クラスを持つクラスのオブジェクト用の初期化子リストです"
 
-#: cp/init.c:1542
+#: cp/init.c:1558
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr ""
 
-#: cp/init.c:1589
+#: cp/init.c:1605
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr ""
 
-#: cp/init.c:1597
+#: cp/init.c:1613
 #, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr ""
 
-#: cp/init.c:1600
+#: cp/init.c:1616
 #, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr ""
 
-#: cp/init.c:1710 cp/init.c:4386 cp/typeck2.c:1175
+#: cp/init.c:1727 cp/init.c:4402 cp/typeck2.c:1175
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
 
-#: cp/init.c:2019 cp/semantics.c:3268
+#: cp/init.c:2036 cp/semantics.c:3271
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "クラスタイプ項を欠いています"
 
-#: cp/init.c:2075
+#: cp/init.c:2092
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr ""
 
-#: cp/init.c:2089
+#: cp/init.c:2106
 #, fuzzy, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr "二項演算子 %s が不適切です"
 
-#: cp/init.c:2175 cp/typeck.c:1893
+#: cp/init.c:2192 cp/typeck.c:1893
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "非メンバ関数での `this' の使用は無効です"
 
-#: cp/init.c:2182 cp/semantics.c:1835
+#: cp/init.c:2199 cp/semantics.c:1835
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "メンバへのポインタでの無効な `%s' の使用"
 
-#: cp/init.c:2379
+#: cp/init.c:2396
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2387
+#: cp/init.c:2404
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2391
+#: cp/init.c:2408
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr "無効な参照型です"
 
-#: cp/init.c:2407
+#: cp/init.c:2424
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2415
+#: cp/init.c:2432
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const member in %qT is invalid in C++"
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "%qT 内の初期化されない定数メンバは C++ では無効です"
 
-#: cp/init.c:2419
+#: cp/init.c:2436
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr "未初期化定数を ROM に置かない"
 
-#: cp/init.c:2710
+#: cp/init.c:2727
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2721
+#: cp/init.c:2738
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2732
+#: cp/init.c:2749
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2880
+#: cp/init.c:2896
 #, fuzzy, gcc-internal-format
 #| msgid "integer overflow in expression"
 msgid "integer overflow in array size"
 msgstr "式内で整数がオーバーフローしました"
 
-#: cp/init.c:2890
+#: cp/init.c:2906
 #, gcc-internal-format
 msgid "array size in new-expression must be constant"
 msgstr ""
 
-#: cp/init.c:2904
+#: cp/init.c:2920
 #, fuzzy, gcc-internal-format
 #| msgid "variably modified field at file scope"
 msgid "variably modified type not allowed in new-expression"
 msgstr "ファイルスコープの可変フィールドです"
 
-#: cp/init.c:2920
+#: cp/init.c:2936
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by typedef"
 msgstr ""
 
-#: cp/init.c:2922
+#: cp/init.c:2938
 #, gcc-internal-format
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr ""
 
-#: cp/init.c:2932
+#: cp/init.c:2948
 #, fuzzy, gcc-internal-format
 msgid "invalid type %<void%> for new"
 msgstr "new に対して無効な型である `void'"
 
-#: cp/init.c:2975
+#: cp/init.c:2991
 #, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr ""
 
-#: cp/init.c:3101
+#: cp/init.c:3117
 #, fuzzy, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr "フィールド '%s' がクラス内に見つかりません"
 
-#: cp/init.c:3108 cp/search.c:1023
+#: cp/init.c:3124 cp/search.c:1026
 #, fuzzy, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "要求されたメンバ `%s' は多重継承グラフの中で曖昧です"
 
-#: cp/init.c:3181
+#: cp/init.c:3197
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr ""
 
-#: cp/init.c:3184
+#: cp/init.c:3200
 #, gcc-internal-format
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr ""
 
-#: cp/init.c:3187
+#: cp/init.c:3203
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr ""
 
-#: cp/init.c:3370
+#: cp/init.c:3386
 #, fuzzy, gcc-internal-format
 msgid "parenthesized initializer in array new"
 msgstr "ISO C++ は new 式の初期化での `=' を禁じます"
 
-#: cp/init.c:3633
+#: cp/init.c:3649
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr "配列 new でのサイズは完全な型を持たねばなりません"
 
-#: cp/init.c:3665
+#: cp/init.c:3681
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr "参照型に対して new を適用できません"
 
-#: cp/init.c:3674
+#: cp/init.c:3690
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr "関数型に対して new を適用できません"
 
-#: cp/init.c:3743
+#: cp/init.c:3759
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete [] operator:"
 msgstr ""
 
-#: cp/init.c:3747
+#: cp/init.c:3763
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete [] will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4295
+#: cp/init.c:4311
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "初期設定子の末尾が本来より早く出現しました"
 
-#: cp/init.c:4599
+#: cp/init.c:4615
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr "delete での配列サイズが不明です"
 
-#: cp/init.c:4623
+#: cp/init.c:4639
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete operator:"
 msgstr ""
 
-#: cp/init.c:4628
+#: cp/init.c:4644
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4642
+#: cp/init.c:4658
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4647
+#: cp/init.c:4663
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4954
+#: cp/init.c:4970
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "ベクトル型の delete ですが、ポインタでも配列型でもありません"
@@ -48672,7 +48716,7 @@
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "非インライン (noinline) 属性が与えられたインライン関数 %qD です"
 
-#: cp/name-lookup.c:5111 cp/name-lookup.c:7065
+#: cp/name-lookup.c:5111 cp/name-lookup.c:7073
 #, fuzzy, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "`%s' 属性の疑似命令が無視されました"
@@ -48720,56 +48764,56 @@
 msgid "it was later defined here"
 msgstr "構造体がここで定義されています"
 
-#: cp/name-lookup.c:6687
+#: cp/name-lookup.c:6695
 #, gcc-internal-format
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn't a template"
 msgstr ""
 
-#: cp/name-lookup.c:7059
+#: cp/name-lookup.c:7067
 #, fuzzy, gcc-internal-format
 #| msgid "switch %qs is no longer supported"
 msgid "strong using directive no longer supported"
 msgstr "%qs スイッチは既にサポートされていません"
 
-#: cp/name-lookup.c:7062
+#: cp/name-lookup.c:7070
 #, gcc-internal-format
 msgid "you may use an inline namespace instead"
 msgstr ""
 
-#: cp/name-lookup.c:7079
+#: cp/name-lookup.c:7087
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on local using directive"
 msgstr "インスタンス化されない型に対する無効な操作です"
 
-#: cp/name-lookup.c:7163
+#: cp/name-lookup.c:7171
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr ""
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:7183
+#: cp/name-lookup.c:7191
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot nest more than %d namespaces"
 msgstr ""
 
-#: cp/name-lookup.c:7218
+#: cp/name-lookup.c:7226
 #, fuzzy, gcc-internal-format
 #| msgid "method attributes must be specified at the end only"
 msgid "inline namespace must be specified at initial definition"
 msgstr "メソッド属性を指定するのは最後のみでなければいけません"
 
-#: cp/name-lookup.c:7219
+#: cp/name-lookup.c:7227
 #, fuzzy, gcc-internal-format
 #| msgid "label %qD defined here"
 msgid "%qD defined here"
 msgstr "ラベル %qD はここで定義されています"
 
-#: cp/name-lookup.c:7292
+#: cp/name-lookup.c:7300
 #, gcc-internal-format
 msgid "XXX entering pop_everything ()\n"
 msgstr ""
 
-#: cp/name-lookup.c:7301
+#: cp/name-lookup.c:7309
 #, gcc-internal-format
 msgid "XXX leaving pop_everything ()\n"
 msgstr ""
@@ -48790,7 +48834,7 @@
 msgid "LEXER_DEBUGGING_ENABLED_P is not set to true"
 msgstr ""
 
-#: cp/parser.c:1352 cp/parser.c:37254
+#: cp/parser.c:1352 cp/parser.c:37251
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -48815,7 +48859,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr ""
 
-#: cp/parser.c:2949 cp/parser.c:18221
+#: cp/parser.c:2949 cp/parser.c:18218
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr ""
@@ -48896,7 +48940,7 @@
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "ISO C++ は減算に関数へのポインタを使うことを禁じます"
 
-#: cp/parser.c:3143 cp/pt.c:17853
+#: cp/parser.c:3143 cp/pt.c:17890
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr ""
@@ -49125,7 +49169,7 @@
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr ""
 
-#: cp/parser.c:4587 cp/parser.c:12940
+#: cp/parser.c:4587 cp/parser.c:12937
 #, gcc-internal-format
 msgid "expected declaration"
 msgstr ""
@@ -49179,7 +49223,7 @@
 msgid "fold-expressions only available with -std=c++17 or -std=gnu++17"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:5275 cp/parser.c:5452 cp/parser.c:5630 cp/semantics.c:3612
+#: cp/parser.c:5275 cp/parser.c:5452 cp/parser.c:5633 cp/semantics.c:3615
 #, gcc-internal-format
 msgid "expected primary-expression"
 msgstr ""
@@ -49199,95 +49243,95 @@
 msgid "local variable %qD may not appear in this context"
 msgstr ""
 
-#: cp/parser.c:5787
+#: cp/parser.c:5790
 #, gcc-internal-format
 msgid "expected id-expression"
 msgstr ""
 
-#: cp/parser.c:5919
+#: cp/parser.c:5922
 #, gcc-internal-format
 msgid "scope %qT before %<~%> is not a class-name"
 msgstr ""
 
-#: cp/parser.c:5948 cp/parser.c:7860
+#: cp/parser.c:5951 cp/parser.c:7860
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:6059
+#: cp/parser.c:6062
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<~%T%> as member of %qT"
 msgstr "`%s' の宣言により `this' のメンバが覆い隠されます"
 
-#: cp/parser.c:6074
+#: cp/parser.c:6077
 #, gcc-internal-format
 msgid "typedef-name %qD used as destructor declarator"
 msgstr ""
 
-#: cp/parser.c:6111 cp/parser.c:20249
+#: cp/parser.c:6114 cp/parser.c:20246
 #, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr ""
 
-#: cp/parser.c:6220
+#: cp/parser.c:6223
 #, gcc-internal-format
 msgid "found %<:%> in nested-name-specifier, expected %<::%>"
 msgstr ""
 
-#: cp/parser.c:6288
+#: cp/parser.c:6291
 #, gcc-internal-format
 msgid "decltype evaluates to %qT, which is not a class or enumeration type"
 msgstr ""
 
-#: cp/parser.c:6314
+#: cp/parser.c:6317
 #, gcc-internal-format
 msgid "function template-id %qD in nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:6322
+#: cp/parser.c:6325
 #, gcc-internal-format
 msgid "variable template-id %qD in nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:6426 cp/typeck.c:2684 cp/typeck.c:2687 cp/typeck.c:2704
+#: cp/parser.c:6429 cp/typeck.c:2684 cp/typeck.c:2687 cp/typeck.c:2704
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr ""
 
-#: cp/parser.c:6504
+#: cp/parser.c:6507
 #, gcc-internal-format
 msgid "expected nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:6711 cp/parser.c:8950
+#: cp/parser.c:6714 cp/parser.c:8950
 #, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr ""
 
-#: cp/parser.c:6797
+#: cp/parser.c:6800
 #, gcc-internal-format
 msgid "types may not be defined in a %<typeid%> expression"
 msgstr ""
 
-#: cp/parser.c:6889
+#: cp/parser.c:6892
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "関数 %<__builtin_next_arg%> への引数の数が間違っています"
 
-#: cp/parser.c:6901 cp/pt.c:18416
+#: cp/parser.c:6904 cp/pt.c:18453
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "関数 %<__builtin_next_arg%> への引数の数が間違っています"
 
-#: cp/parser.c:6995
+#: cp/parser.c:6998
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids compound-literals"
 msgstr "ISO C++ は複合リテラルを禁じます"
 
-#: cp/parser.c:7054
+#: cp/parser.c:7057
 #, gcc-internal-format
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
@@ -49424,7 +49468,7 @@
 msgid "capture of non-variable %qE"
 msgstr "読み取り専用変数 %qD の増分です"
 
-#: cp/parser.c:10391 cp/parser.c:10401 cp/semantics.c:3453 cp/semantics.c:3465
+#: cp/parser.c:10391 cp/parser.c:10401 cp/semantics.c:3456 cp/semantics.c:3468
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared here"
 msgid "%q#D declared here"
@@ -49517,7 +49561,7 @@
 msgid "init-statement in selection statements only available with -std=c++17 or -std=gnu++17"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:11546 cp/parser.c:28490
+#: cp/parser.c:11546 cp/parser.c:28487
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr ""
@@ -49538,579 +49582,579 @@
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:12250 cp/parser.c:28493
+#: cp/parser.c:12250 cp/parser.c:28490
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr ""
 
-#: cp/parser.c:12298
+#: cp/parser.c:12297
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:12426
+#: cp/parser.c:12423
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr ""
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:12434
+#: cp/parser.c:12431
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ は計算型 goto を禁じます"
 
-#: cp/parser.c:12447 cp/parser.c:28496
+#: cp/parser.c:12444 cp/parser.c:28493
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr ""
 
-#: cp/parser.c:12620 cp/parser.c:23584
+#: cp/parser.c:12617 cp/parser.c:23581
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr ""
 
-#: cp/parser.c:12863
+#: cp/parser.c:12860
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr ""
 
-#: cp/parser.c:13083
+#: cp/parser.c:13080
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:13103
+#: cp/parser.c:13100
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr ""
 
-#: cp/parser.c:13124
+#: cp/parser.c:13121
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr ""
 
-#: cp/parser.c:13148
+#: cp/parser.c:13145
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr "一つの空の宣言中に、二つの型が指定されています"
 
-#: cp/parser.c:13203
+#: cp/parser.c:13200
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13206
+#: cp/parser.c:13203
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13257
+#: cp/parser.c:13254
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "structured bindings only available with -std=c++17 or -std=gnu++17"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:13306
+#: cp/parser.c:13303
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "empty structured binding declaration"
 msgstr "空の宣言です"
 
-#: cp/parser.c:13324
+#: cp/parser.c:13321
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer for member function %qD"
 msgid "invalid initializer for structured binding declaration"
 msgstr "メンバ関数 %qD 用の無効な初期化子です"
 
-#: cp/parser.c:13491
+#: cp/parser.c:13488
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr "%<friend%> がクラスの外側で使用されています"
 
-#: cp/parser.c:13558
+#: cp/parser.c:13555
 #, fuzzy, gcc-internal-format
 #| msgid "%<auto%> will change meaning in C++0x; please remove it"
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr "%<auto%> は C++0x で意味が変更になります。削除してください"
 
-#: cp/parser.c:13594
+#: cp/parser.c:13591
 #, gcc-internal-format
 msgid "decl-specifier invalid in condition"
 msgstr ""
 
-#: cp/parser.c:13600
+#: cp/parser.c:13597
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D invalid in %q#T"
 msgid "%qD invalid in lambda"
 msgstr "%q+D は %q#T 内では無効です"
 
-#: cp/parser.c:13693
+#: cp/parser.c:13690
 #, fuzzy, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "`%s' は関数でもメンバ関数でもありません -- friend とは宣言できません"
 
-#: cp/parser.c:13763 cp/parser.c:24064
+#: cp/parser.c:13760 cp/parser.c:24061
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:13805
+#: cp/parser.c:13802
 #, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr "無効なリンク指定です"
 
-#: cp/parser.c:13909
+#: cp/parser.c:13906
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "static_assert without a message only available with -std=c++17 or -std=gnu++17"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:14111
+#: cp/parser.c:14108
 #, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr ""
 
-#: cp/parser.c:14264
+#: cp/parser.c:14261
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr "参照型に対して new を適用できません"
 
-#: cp/parser.c:14291
+#: cp/parser.c:14288
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "void 式の不適切な使用"
 
-#: cp/parser.c:14295
+#: cp/parser.c:14292
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr "void 式の不適切な使用"
 
-#: cp/parser.c:14379
+#: cp/parser.c:14376
 #, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr ""
 
-#: cp/parser.c:14406
+#: cp/parser.c:14403
 #, fuzzy, gcc-internal-format
 msgid "cannot expand initializer for member %qD"
 msgstr "メンバ `%s' に対する無効な初期値"
 
-#: cp/parser.c:14418 cp/pt.c:24255
+#: cp/parser.c:14415 cp/pt.c:24333
 #, fuzzy, gcc-internal-format
 #| msgid "static declaration of %q+D follows non-static declaration"
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "%q+D は静的宣言の後に非静的宣言が続いています"
 
-#: cp/parser.c:14430 cp/pt.c:24267
+#: cp/parser.c:14427 cp/pt.c:24345
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
 
-#: cp/parser.c:14482
+#: cp/parser.c:14479
 #, fuzzy, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr "前時代的な古いスタイルの基底クラス初期化子です"
 
-#: cp/parser.c:14552
+#: cp/parser.c:14549
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:14927
+#: cp/parser.c:14924
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr ""
 
-#: cp/parser.c:14933
+#: cp/parser.c:14930
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier"
 msgid "expected suffix identifier"
 msgstr "識別子が予期されます"
 
-#: cp/parser.c:14942
+#: cp/parser.c:14939
 #, fuzzy, gcc-internal-format
 #| msgid "expected a string after %<#pragma message%>"
 msgid "expected empty string after %<operator%> keyword"
 msgstr "%<#pragma message%> の後に文字列が予期されます"
 
-#: cp/parser.c:14948
+#: cp/parser.c:14945
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands in binary operation"
 msgid "invalid encoding prefix in literal operator"
 msgstr "二進演算内で無効な被演算子です"
 
-#: cp/parser.c:14975
+#: cp/parser.c:14972
 #, gcc-internal-format
 msgid "expected operator"
 msgstr "演算子が予期されます"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:15020
+#: cp/parser.c:15017
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr ""
 
-#: cp/parser.c:15190
+#: cp/parser.c:15187
 #, fuzzy, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr "不完全な typedef `%s' の使用は不適切です"
 
-#: cp/parser.c:15198
+#: cp/parser.c:15195
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter %qs"
 msgid "cv-qualified type parameter"
 msgstr "無効なパラメータ %qs です"
 
-#: cp/parser.c:15283
+#: cp/parser.c:15280
 #, gcc-internal-format
 msgid "variadic constraint introduced without %<...%>"
 msgstr ""
 
-#: cp/parser.c:15347
+#: cp/parser.c:15344
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "無効なデフォルトテンプレート引数"
 
-#: cp/parser.c:15582 cp/parser.c:15668 cp/parser.c:21694
+#: cp/parser.c:15579 cp/parser.c:15665 cp/parser.c:21691
 #, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:15586 cp/parser.c:15672
+#: cp/parser.c:15583 cp/parser.c:15669
 #, fuzzy, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr "strftime フォーマットは引数をフォーマットできません"
 
-#: cp/parser.c:15738
+#: cp/parser.c:15735
 #, gcc-internal-format
 msgid "expected template-id"
 msgstr ""
 
-#: cp/parser.c:15798
+#: cp/parser.c:15795
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr ""
 
-#: cp/parser.c:15802
+#: cp/parser.c:15799
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr ""
 
-#: cp/parser.c:15806
+#: cp/parser.c:15803
 #, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr ""
 
-#: cp/parser.c:15924
+#: cp/parser.c:15921
 #, fuzzy, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "マクロ引数リストにあり得ないトークン"
 
 #. The name does not name a template.
-#: cp/parser.c:15992 cp/parser.c:16122 cp/parser.c:16337
+#: cp/parser.c:15989 cp/parser.c:16119 cp/parser.c:16334
 #, gcc-internal-format
 msgid "expected template-name"
 msgstr "テンプレート名が予期されます"
 
 #. Explain what went wrong.
-#: cp/parser.c:16038
+#: cp/parser.c:16035
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr "非テンプレート %qD がテンプレートとして使用されています"
 
-#: cp/parser.c:16040
+#: cp/parser.c:16037
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr ""
 
-#: cp/parser.c:16189
+#: cp/parser.c:16186
 #, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr ""
 
-#: cp/parser.c:16298 cp/parser.c:16316 cp/parser.c:16483
+#: cp/parser.c:16295 cp/parser.c:16313 cp/parser.c:16480
 #, gcc-internal-format
 msgid "expected template-argument"
 msgstr "テンプレート引数が予期されます"
 
-#: cp/parser.c:16458
+#: cp/parser.c:16455
 #, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr ""
 
-#: cp/parser.c:16585
+#: cp/parser.c:16582
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr ""
 
-#: cp/parser.c:16589
+#: cp/parser.c:16586
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr ""
 
-#: cp/parser.c:16648
+#: cp/parser.c:16645
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr ""
 
-#: cp/parser.c:16869
+#: cp/parser.c:16866
 #, gcc-internal-format
 msgid "expected type specifier"
 msgstr "型指定が予期されます"
 
-#: cp/parser.c:17053
+#: cp/parser.c:17050
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:17059
+#: cp/parser.c:17056
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:17064
+#: cp/parser.c:17061
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -fconcepts"
 msgstr ""
 
-#: cp/parser.c:17209
+#: cp/parser.c:17206
 #, gcc-internal-format
 msgid "expected template-id for type"
 msgstr ""
 
-#: cp/parser.c:17278
+#: cp/parser.c:17275
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr "型名が予期されます"
 
-#: cp/parser.c:17631
+#: cp/parser.c:17628
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr ""
 
-#: cp/parser.c:17854
+#: cp/parser.c:17851
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "宣言 %qD が何も宣言していません"
 
-#: cp/parser.c:17942
+#: cp/parser.c:17939
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "インスタンス化されない型に対する無効な操作です"
 
-#: cp/parser.c:17946
+#: cp/parser.c:17943
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "自動テンプレート実体化を有効にする"
 
-#: cp/parser.c:17951
+#: cp/parser.c:17948
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr ""
 
-#: cp/parser.c:18085
+#: cp/parser.c:18082
 #, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr ""
 
-#: cp/parser.c:18096
+#: cp/parser.c:18093
 #, fuzzy, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr "%s に `%s' という名前のメンバはありません"
 
-#: cp/parser.c:18111
+#: cp/parser.c:18108
 #, fuzzy, gcc-internal-format
 #| msgid "%<namespace%> definition is not allowed here"
 msgid "unnamed scoped enum is not allowed"
 msgstr "ここでは %<namespace%> 定義は許可されていません"
 
-#: cp/parser.c:18166
+#: cp/parser.c:18163
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "%<;%> または %<{%> が予期されます"
 
-#: cp/parser.c:18215
+#: cp/parser.c:18212
 #, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr ""
 
-#: cp/parser.c:18229
+#: cp/parser.c:18226
 #, gcc-internal-format
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr ""
 
-#: cp/parser.c:18241 cp/parser.c:23070
+#: cp/parser.c:18238 cp/parser.c:23067
 #, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr ""
 
-#: cp/parser.c:18246 cp/parser.c:23075
+#: cp/parser.c:18243 cp/parser.c:23072
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr ""
 
-#: cp/parser.c:18258 cp/parser.c:23089
+#: cp/parser.c:18255 cp/parser.c:23086
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr ""
 
-#: cp/parser.c:18282
+#: cp/parser.c:18279
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "%q#T が複数定義されています"
 
-#: cp/parser.c:18295
+#: cp/parser.c:18292
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO C++ は enum の %s を禁じます"
 
-#: cp/parser.c:18315
+#: cp/parser.c:18312
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:18318
+#: cp/parser.c:18315
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:18497
+#: cp/parser.c:18494
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD は名前空間名ではありません"
 
-#: cp/parser.c:18503
+#: cp/parser.c:18500
 #, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "名前空間名が予期されます"
 
-#: cp/parser.c:18570
+#: cp/parser.c:18567
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "nested namespace definitions only available with -std=c++17 or -std=gnu++17"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:18578
+#: cp/parser.c:18575
 #, fuzzy, gcc-internal-format
 #| msgid "expected namespace-name"
 msgid "nested namespace name required"
 msgstr "名前空間名が予期されます"
 
-#: cp/parser.c:18583
+#: cp/parser.c:18580
 #, gcc-internal-format
 msgid "namespace name required"
 msgstr ""
 
-#: cp/parser.c:18587
+#: cp/parser.c:18584
 #, fuzzy, gcc-internal-format
 #| msgid "%<namespace%> definition is not allowed here"
 msgid "a nested namespace definition cannot have attributes"
 msgstr "ここでは %<namespace%> 定義は許可されていません"
 
-#: cp/parser.c:18590
+#: cp/parser.c:18587
 #, fuzzy, gcc-internal-format
 #| msgid "Warn when an inlined function cannot be inlined"
 msgid "a nested namespace definition cannot be inline"
 msgstr "インライン関数をインライン化できない場合に警告する"
 
-#: cp/parser.c:18597
+#: cp/parser.c:18594
 #, gcc-internal-format
 msgid "namespace %qD entered"
 msgstr ""
 
-#: cp/parser.c:18652
+#: cp/parser.c:18649
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "ここでは %<namespace%> 定義は許可されていません"
 
-#: cp/parser.c:18803
+#: cp/parser.c:18800
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "pack expansion in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:18818
+#: cp/parser.c:18815
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr ""
 
-#: cp/parser.c:18865
+#: cp/parser.c:18862
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "comma-separated list in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:18875
+#: cp/parser.c:18872
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:18940
+#: cp/parser.c:18937
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "一つの空の宣言中に、二つの型が指定されています"
 
-#: cp/parser.c:19106
+#: cp/parser.c:19103
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:19493
+#: cp/parser.c:19490
 #, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "ここでは関数定義は許可されていません"
 
-#: cp/parser.c:19504
+#: cp/parser.c:19501
 #, fuzzy, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr "初期化子リストは非メンバ関数では使えません"
 
-#: cp/parser.c:19508
+#: cp/parser.c:19505
 #, fuzzy, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "大域 register 変数が関数定義の後ろにあります"
 
-#: cp/parser.c:19559
+#: cp/parser.c:19556
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
 #. Anything else is an error.
-#: cp/parser.c:19598 cp/parser.c:21906
+#: cp/parser.c:19595 cp/parser.c:21903
 #, gcc-internal-format
 msgid "expected initializer"
 msgstr ""
 
-#: cp/parser.c:19679
+#: cp/parser.c:19676
 #, fuzzy, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "friend 関数 `%s' を初期化できません"
 
-#: cp/parser.c:19713
+#: cp/parser.c:19710
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr ""
 
-#: cp/parser.c:19727
+#: cp/parser.c:19724
 #, fuzzy, gcc-internal-format
 #| msgid "function template %qD redeclared as a class template"
 msgid "non-function %qD declared as implicit template"
 msgstr "関数テンプレート %qD がクラステンプレートとして再定義されました"
 
-#: cp/parser.c:20169
+#: cp/parser.c:20166
 #, fuzzy, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "配列の添字が整数型ではありません"
 
-#: cp/parser.c:20295
+#: cp/parser.c:20292
 #, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr ""
 
-#: cp/parser.c:20299
+#: cp/parser.c:20296
 #, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr ""
@@ -50119,17 +50163,17 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:20328
+#: cp/parser.c:20325
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr "無効な宣言子です"
 
-#: cp/parser.c:20336
+#: cp/parser.c:20333
 #, fuzzy, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "トップレベルでの `this' の使用は無効です"
 
-#: cp/parser.c:20338
+#: cp/parser.c:20335
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr ""
@@ -50136,392 +50180,392 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:20410
+#: cp/parser.c:20407
 #, fuzzy, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr "無効な宣言です"
 
-#: cp/parser.c:20435
+#: cp/parser.c:20432
 #, gcc-internal-format
 msgid "expected declarator"
 msgstr "宣言子が予期されます"
 
-#: cp/parser.c:20554
+#: cp/parser.c:20551
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD は名前空間です"
 
-#: cp/parser.c:20556
+#: cp/parser.c:20553
 #, fuzzy, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "   ポインタからメンバへの変換で"
 
-#: cp/parser.c:20577
+#: cp/parser.c:20574
 #, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "ポインタ演算子が予期されます"
 
-#: cp/parser.c:20638
+#: cp/parser.c:20635
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr ""
 
-#: cp/parser.c:20692
+#: cp/parser.c:20689
 #, fuzzy, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr "重複する `virtual' 指定子"
 
-#: cp/parser.c:20729
+#: cp/parser.c:20726
 #, gcc-internal-format
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr ""
 
-#: cp/parser.c:20787
+#: cp/parser.c:20784
 #, fuzzy, gcc-internal-format
 #| msgid "expected type-specifier"
 msgid "duplicate virt-specifier"
 msgstr "型指定子が予期されます"
 
-#: cp/parser.c:21025
+#: cp/parser.c:21022
 #, fuzzy, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr "`%s' の引数として無効な型"
 
-#: cp/parser.c:21031 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2090
+#: cp/parser.c:21028 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2093
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr "`restrict' の用法が不適切です"
 
-#: cp/parser.c:21052
+#: cp/parser.c:21049
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "\"%s\" はマクロ仮引数リストに現れてはなりません"
 
-#: cp/parser.c:21057
+#: cp/parser.c:21054
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "void 式の不適切な使用"
 
-#: cp/parser.c:21145
+#: cp/parser.c:21142
 #, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "型指定子が予期されます"
 
-#: cp/parser.c:21429
+#: cp/parser.c:21426
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "%<,%> または %<...%> が予期されます"
 
-#: cp/parser.c:21504
+#: cp/parser.c:21501
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr "\"%s\" はマクロ仮引数リストに現れてはなりません"
 
-#: cp/parser.c:21678
+#: cp/parser.c:21675
 #, fuzzy, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "メソッドは関数ポインタに変換できません"
 
-#: cp/parser.c:21696
+#: cp/parser.c:21693
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "strftime フォーマットは引数をフォーマットできません"
 
-#: cp/parser.c:21702
+#: cp/parser.c:21699
 #, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:21704
+#: cp/parser.c:21701
 #, fuzzy, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr "strftime フォーマットは引数をフォーマットできません"
 
-#: cp/parser.c:22131
+#: cp/parser.c:22128
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "C++ designated initializers only available with -std=c++2a or -std=gnu++2a"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:22151
+#: cp/parser.c:22148
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr "ISO C++ は名前つき戻り値を許可しません"
 
-#: cp/parser.c:22189
+#: cp/parser.c:22186
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C++ は名前つき戻り値を許可しません"
 
-#: cp/parser.c:22203
+#: cp/parser.c:22200
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr ""
 
-#: cp/parser.c:22228
+#: cp/parser.c:22225
 #, fuzzy, gcc-internal-format
 msgid "%<...%> not allowed in designated initializer list"
 msgstr "ISO C++ は名前つき戻り値を許可しません"
 
-#: cp/parser.c:22266
+#: cp/parser.c:22263
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr ""
 
-#: cp/parser.c:22322 cp/parser.c:22448
+#: cp/parser.c:22319 cp/parser.c:22445
 #, gcc-internal-format
 msgid "expected class-name"
 msgstr ""
 
-#: cp/parser.c:22650
+#: cp/parser.c:22647
 #, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "クラス定義の後には %<;%> が予期されます"
 
-#: cp/parser.c:22653
+#: cp/parser.c:22650
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "構造体定義の後には %<;%> が予期されます"
 
-#: cp/parser.c:22656
+#: cp/parser.c:22653
 #, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "共用体定義の後には %<;%> が予期されます"
 
-#: cp/parser.c:23012
+#: cp/parser.c:23009
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "%<{%> または %<:%> が予期されます"
 
-#: cp/parser.c:23023
+#: cp/parser.c:23020
 #, fuzzy, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "クラス %s 用のファイルを見つけられません。"
 
-#: cp/parser.c:23031
+#: cp/parser.c:23028
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:23038
+#: cp/parser.c:23035
 #, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr ""
 
-#: cp/parser.c:23050
+#: cp/parser.c:23047
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr ""
 
-#: cp/parser.c:23056
+#: cp/parser.c:23053
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "%qD の宣言内に無効なクラス名です"
 
-#: cp/parser.c:23114
+#: cp/parser.c:23111
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr ""
 
-#: cp/parser.c:23146
+#: cp/parser.c:23143
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "関数テンプレート %qD がクラステンプレートとして再定義されました"
 
-#: cp/parser.c:23182
+#: cp/parser.c:23179
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr ""
 
-#: cp/parser.c:23241
+#: cp/parser.c:23238
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+#T"
 msgid "previous definition of %q#T"
 msgstr "%q+#T の前の定義"
 
-#: cp/parser.c:23331 cp/parser.c:28499
+#: cp/parser.c:23328 cp/parser.c:28496
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr ""
 
-#: cp/parser.c:23355
+#: cp/parser.c:23352
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:23359
+#: cp/parser.c:23356
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<class%> or %<typename%>"
 msgstr "%<class%>、%<typename%>、または %<template%> が予期されます"
 
-#: cp/parser.c:23605
+#: cp/parser.c:23602
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr ""
 
-#: cp/parser.c:23623
+#: cp/parser.c:23620
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr ""
 
-#: cp/parser.c:23641
+#: cp/parser.c:23638
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:23738
+#: cp/parser.c:23735
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "default member initializers for bit-fields only available with -std=c++2a or -std=gnu++2a"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:23745
+#: cp/parser.c:23742
 #, gcc-internal-format
 msgid "default member initializer for unnamed bit-field"
 msgstr ""
 
-#: cp/parser.c:23758
+#: cp/parser.c:23755
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr ""
 
-#: cp/parser.c:23903
+#: cp/parser.c:23900
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr ""
 
-#: cp/parser.c:23923
+#: cp/parser.c:23920
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%> after class definition"
 msgid "extra %<;%> after in-class function definition"
 msgstr "クラス定義の後には %<;%> が予期されます"
 
-#: cp/parser.c:23970
+#: cp/parser.c:23967
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%> at end of member declaration"
 msgid "stray %<,%> at end of member declaration"
 msgstr "メンバ宣言の最後には %<;%> が予期されます"
 
-#: cp/parser.c:23984
+#: cp/parser.c:23981
 #, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "メンバ宣言の最後には %<;%> が予期されます"
 
-#: cp/parser.c:24058
+#: cp/parser.c:24055
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr ""
 
-#: cp/parser.c:24093
+#: cp/parser.c:24090
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr ""
 
-#: cp/parser.c:24223
+#: cp/parser.c:24220
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr ""
 
-#: cp/parser.c:24243
+#: cp/parser.c:24240
 #, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr ""
 
-#: cp/parser.c:24267
+#: cp/parser.c:24264
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr ""
 
-#: cp/parser.c:24270
+#: cp/parser.c:24267
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:24364 cp/parser.c:24442
+#: cp/parser.c:24361 cp/parser.c:24439
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "例外仕様の検査をするコードを生成しない"
 
-#: cp/parser.c:24450
+#: cp/parser.c:24447
 #, fuzzy, gcc-internal-format
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "例外仕様の検査をするコードを生成しない"
 
-#: cp/parser.c:24456
+#: cp/parser.c:24453
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr ""
 
-#: cp/parser.c:24500
+#: cp/parser.c:24497
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "void 式の不適切な使用"
 
-#: cp/parser.c:24539
+#: cp/parser.c:24536
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:24650
+#: cp/parser.c:24647
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr "一つの空の宣言中に、二つの型が指定されています"
 
-#: cp/parser.c:25203
+#: cp/parser.c:25200
 #, gcc-internal-format
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr ""
 
-#: cp/parser.c:25217
+#: cp/parser.c:25214
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier or %<(%>"
 msgid "expected an identifier for the attribute name"
 msgstr "識別子または %<(%> が予期されます"
 
-#: cp/parser.c:25301
+#: cp/parser.c:25298
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:25305
+#: cp/parser.c:25302
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:25342
+#: cp/parser.c:25339
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<...%>"
 msgid "expected attribute before %<...%>"
 msgstr "%<:%> または %<...%> が予期されます"
 
-#: cp/parser.c:25403
+#: cp/parser.c:25400
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "attribute using prefix only available with -std=c++17 or -std=gnu++17"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:25721
+#: cp/parser.c:25718
 #, gcc-internal-format
 msgid "%<requires%> only available with -fconcepts"
 msgstr ""
 
-#: cp/parser.c:25753
+#: cp/parser.c:25750
 #, gcc-internal-format
 msgid "a requires expression cannot appear outside a template"
 msgstr ""
 
-#: cp/parser.c:26467
+#: cp/parser.c:26464
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:26472
+#: cp/parser.c:26469
 #, fuzzy, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "無効な宣言です"
 
-#: cp/parser.c:26476
+#: cp/parser.c:26473
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr ""
@@ -50530,466 +50574,466 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:26483
+#: cp/parser.c:26480
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr ""
 
-#: cp/parser.c:26832
+#: cp/parser.c:26829
 #, fuzzy, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "--driver は最早サポートされません"
 
-#: cp/parser.c:26991
+#: cp/parser.c:26988
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr ""
 
-#: cp/parser.c:26996
+#: cp/parser.c:26993
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr ""
 
-#: cp/parser.c:27066
+#: cp/parser.c:27063
 #, fuzzy, gcc-internal-format
 #| msgid "Enable multiply instructions"
 msgid "empty introduction-list"
 msgstr "乗算命令を有効にする"
 
-#: cp/parser.c:27090
+#: cp/parser.c:27087
 #, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr ""
 
-#: cp/parser.c:27112
+#: cp/parser.c:27109
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr ""
 
-#: cp/parser.c:27121
+#: cp/parser.c:27118
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr ""
 
-#: cp/parser.c:27141
+#: cp/parser.c:27138
 #, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr ""
 
-#: cp/parser.c:27245
+#: cp/parser.c:27242
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "`%s' の extern 宣言がネストしています"
 
-#: cp/parser.c:27296
+#: cp/parser.c:27293
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "a class template declaration must not declare anything else"
 msgstr "宣言が何も宣言していません"
 
-#: cp/parser.c:27342
+#: cp/parser.c:27339
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr ""
 
-#: cp/parser.c:27650
+#: cp/parser.c:27647
 #, fuzzy, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "`>>' はテンプレートクラス名は `> >' とすべきです"
 
-#: cp/parser.c:27663
+#: cp/parser.c:27660
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr ""
 
-#: cp/parser.c:27958
+#: cp/parser.c:27955
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:28118
+#: cp/parser.c:28115
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "テンプレート型統一中 `%s' が使用されました"
 
-#: cp/parser.c:28133
+#: cp/parser.c:28130
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> が %qD の前にあります"
 
-#: cp/parser.c:28267
+#: cp/parser.c:28264
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ は `long long' を受け入れません"
 
-#: cp/parser.c:28275
+#: cp/parser.c:28272
 #, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr ""
 
-#: cp/parser.c:28280
+#: cp/parser.c:28277
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %qE"
 msgid "duplicate %qD"
 msgstr "%qE が重複しています"
 
-#: cp/parser.c:28304
+#: cp/parser.c:28301
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "`%s' が重複しています"
 
-#: cp/parser.c:28356
+#: cp/parser.c:28353
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "%<new%> が予期されます"
 
-#: cp/parser.c:28359
+#: cp/parser.c:28356
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "%<delete%> が予期されます"
 
-#: cp/parser.c:28362
+#: cp/parser.c:28359
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "%<return%> が予期されます"
 
-#: cp/parser.c:28368
+#: cp/parser.c:28365
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "%<extern%> が予期されます"
 
-#: cp/parser.c:28371
+#: cp/parser.c:28368
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "%<static_assert%> が予期されます"
 
-#: cp/parser.c:28374
+#: cp/parser.c:28371
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "%<decltype%> が予期されます"
 
-#: cp/parser.c:28377
+#: cp/parser.c:28374
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "%<operator%> が予期されます"
 
-#: cp/parser.c:28380
+#: cp/parser.c:28377
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "%<class%> が予期されます"
 
-#: cp/parser.c:28383
+#: cp/parser.c:28380
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "%<template%> が予期されます"
 
-#: cp/parser.c:28386
+#: cp/parser.c:28383
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "%<namespace%> が予期されます"
 
-#: cp/parser.c:28389
+#: cp/parser.c:28386
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "%<using%> が予期されます"
 
-#: cp/parser.c:28392
+#: cp/parser.c:28389
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "%<asm%> が予期されます"
 
-#: cp/parser.c:28395
+#: cp/parser.c:28392
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "%<try%> が予期されます"
 
-#: cp/parser.c:28398
+#: cp/parser.c:28395
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "%<catch%> が予期されます"
 
-#: cp/parser.c:28401
+#: cp/parser.c:28398
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "%<throw%> が予期されます"
 
-#: cp/parser.c:28404
+#: cp/parser.c:28401
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "%<__label__%> が予期されます"
 
-#: cp/parser.c:28407
+#: cp/parser.c:28404
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "%<@try%> が予期されます"
 
-#: cp/parser.c:28410
+#: cp/parser.c:28407
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "%<@synchronized%> が予期されます"
 
-#: cp/parser.c:28413
+#: cp/parser.c:28410
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "%<@throw%> が予期されます"
 
-#: cp/parser.c:28416
+#: cp/parser.c:28413
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<static_assert%>"
 msgid "expected %<__transaction_atomic%>"
 msgstr "%<static_assert%> が予期されます"
 
-#: cp/parser.c:28419
+#: cp/parser.c:28416
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<static_assert%>"
 msgid "expected %<__transaction_relaxed%>"
 msgstr "%<static_assert%> が予期されます"
 
-#: cp/parser.c:28451
+#: cp/parser.c:28448
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "%<::%> が予期されます"
 
-#: cp/parser.c:28463
+#: cp/parser.c:28460
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "%<...%> が予期されます"
 
-#: cp/parser.c:28466
+#: cp/parser.c:28463
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "%<*%> が予期されます"
 
-#: cp/parser.c:28469
+#: cp/parser.c:28466
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "%<~%> が予期されます"
 
-#: cp/parser.c:28475
+#: cp/parser.c:28472
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "%<:%> または %<::%> が予期されます"
 
-#: cp/parser.c:28502
+#: cp/parser.c:28499
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "%<class%>、%<typename%>、または %<template%> が予期されます"
 
-#: cp/parser.c:28772
+#: cp/parser.c:28769
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr ""
 
-#: cp/parser.c:28777
+#: cp/parser.c:28774
 #, fuzzy, gcc-internal-format
 #| msgid "previously declared here"
 msgid "%q#T was previously declared here"
 msgstr "前はここで宣言されました"
 
-#: cp/parser.c:28798
+#: cp/parser.c:28795
 #, fuzzy, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "`%s' が別のシンボル種として再宣言されました"
 
-#: cp/parser.c:28819
+#: cp/parser.c:28816
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr ""
 
-#: cp/parser.c:29062
+#: cp/parser.c:29059
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "デフォルト引数内でファイルが終了しています"
 
-#: cp/parser.c:29303 cp/parser.c:30620 cp/parser.c:30808
+#: cp/parser.c:29300 cp/parser.c:30617 cp/parser.c:30805
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr ""
 
-#: cp/parser.c:29372
+#: cp/parser.c:29369
 #, fuzzy, gcc-internal-format
 #| msgid "objective-c method declaration is expected"
 msgid "objective-c++ message receiver expected"
 msgstr "objective-c メソッド定義が予期されます"
 
-#: cp/parser.c:29442
+#: cp/parser.c:29439
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:29473
+#: cp/parser.c:29470
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr ""
 
-#: cp/parser.c:29883
+#: cp/parser.c:29880
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr ""
 
-#: cp/parser.c:29958 cp/parser.c:29976
+#: cp/parser.c:29955 cp/parser.c:29973
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr ""
 
-#: cp/parser.c:29970 cp/parser.c:30035
+#: cp/parser.c:29967 cp/parser.c:30032
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr ""
 
-#: cp/parser.c:30078
+#: cp/parser.c:30075
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:30284 cp/parser.c:30291 cp/parser.c:30298
+#: cp/parser.c:30281 cp/parser.c:30288 cp/parser.c:30295
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr ""
 
-#: cp/parser.c:30413
+#: cp/parser.c:30410
 #, fuzzy, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "識別子が必要です"
 
-#: cp/parser.c:30585
+#: cp/parser.c:30582
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:30592
+#: cp/parser.c:30589
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr ""
 
-#: cp/parser.c:30867 cp/parser.c:30874 cp/parser.c:30881
+#: cp/parser.c:30864 cp/parser.c:30871 cp/parser.c:30878
 #, gcc-internal-format
 msgid "invalid type for property"
 msgstr ""
 
-#: cp/parser.c:32011
+#: cp/parser.c:32008
 #, fuzzy, gcc-internal-format
 #| msgid "index must be integer"
 msgid "%<wait%> expression must be integral"
 msgstr "添え字は整数でなければいけません"
 
-#: cp/parser.c:32724
+#: cp/parser.c:32721
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid reduction-identifier"
 msgstr "無効な初期化子です"
 
-#: cp/parser.c:34911
+#: cp/parser.c:34908
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:35231 cp/pt.c:16392
+#: cp/parser.c:35228 cp/pt.c:16414
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "レジスタ変数 `%s' が入れ子関数の中で使われました"
 
-#: cp/parser.c:35316
+#: cp/parser.c:35313
 #, fuzzy, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr "不十分な型情報"
 
-#: cp/parser.c:37521
+#: cp/parser.c:37518
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer clause"
 msgstr "無効な初期化子です"
 
-#: cp/parser.c:37549
+#: cp/parser.c:37546
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "expected id-expression (arguments)"
 msgstr "式が予期されます"
 
-#: cp/parser.c:37561
+#: cp/parser.c:37558
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:37662
+#: cp/parser.c:37659
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr "参照型に対して new を適用できません"
 
-#: cp/parser.c:37682 cp/semantics.c:5405
+#: cp/parser.c:37679 cp/semantics.c:5408
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37687 cp/semantics.c:5414
+#: cp/parser.c:37684 cp/semantics.c:5417
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37690 cp/pt.c:12944 cp/semantics.c:5420
+#: cp/parser.c:37687 cp/pt.c:12966 cp/semantics.c:5423
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37693 cp/semantics.c:5426
+#: cp/parser.c:37690 cp/semantics.c:5429
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:38047
+#: cp/parser.c:38044
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:38057
+#: cp/parser.c:38054
 #, fuzzy, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr "メンバ関数の名前を欠いています"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:38392
+#: cp/parser.c:38389
 #, gcc-internal-format
 msgid "atomic_cancel"
 msgstr ""
 
-#: cp/parser.c:38435 cp/semantics.c:8575
+#: cp/parser.c:38432 cp/semantics.c:8578
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:38437 cp/semantics.c:8577
+#: cp/parser.c:38434 cp/semantics.c:8580
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:38631
+#: cp/parser.c:38628
 #, fuzzy, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "#pragma GCC java_exceptions の末尾にゴミ"
 
-#: cp/parser.c:38927
+#: cp/parser.c:38924
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "#pragma GCC optimize は関数内では許可されていません"
 
-#: cp/parser.c:38959
+#: cp/parser.c:38956
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC option is not allowed inside functions"
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr "#pragma GCC option は関数内では許可されていません"
 
-#: cp/parser.c:39039
+#: cp/parser.c:39036
 #, fuzzy, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "ret 命令は実装されていません"
 
-#: cp/parser.c:39295
+#: cp/parser.c:39292
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:39351
+#: cp/parser.c:39348
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
@@ -51076,7 +51120,7 @@
 msgid "specialization of %qD after instantiation"
 msgstr ""
 
-#: cp/pt.c:1954 cp/semantics.c:5274
+#: cp/pt.c:1954 cp/semantics.c:5277
 #, fuzzy, gcc-internal-format
 #| msgid "%s %+#D"
 msgid "%s %#qD"
@@ -51249,127 +51293,127 @@
 msgid "argument to __integer_pack must be between 0 and %d"
 msgstr "%K %D の最後の引数が 0 から 3 の間の整数定数ではありません"
 
-#: cp/pt.c:3942
+#: cp/pt.c:3955
 #, gcc-internal-format
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr ""
 
-#: cp/pt.c:4010
+#: cp/pt.c:4023
 #, fuzzy, gcc-internal-format
 msgid "expansion pattern %qT contains no argument packs"
 msgstr "非メンバ `%s' を `mutable' とは宣言できません"
 
-#: cp/pt.c:4012
+#: cp/pt.c:4025
 #, fuzzy, gcc-internal-format
 msgid "expansion pattern %qE contains no argument packs"
 msgstr "非メンバ `%s' を `mutable' とは宣言できません"
 
-#: cp/pt.c:4063
+#: cp/pt.c:4077
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr ""
 
-#: cp/pt.c:4080 cp/pt.c:4835
+#: cp/pt.c:4094 cp/pt.c:4849
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
 
-#: cp/pt.c:4082
+#: cp/pt.c:4096
 #, gcc-internal-format
 msgid "        <anonymous>"
 msgstr "        <無名>"
 
-#: cp/pt.c:4208
+#: cp/pt.c:4222
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr "%q+D の再宣言は仮引数を隠します"
 
-#: cp/pt.c:4211
+#: cp/pt.c:4225
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of %q+#D shadows template parameter"
 msgstr "%q+D の再宣言は仮引数を隠します"
 
-#: cp/pt.c:4213
+#: cp/pt.c:4227
 #, fuzzy, gcc-internal-format
 msgid "template parameter %qD declared here"
 msgstr "仮引数 `%s' が void と宣言されています"
 
-#: cp/pt.c:4771
+#: cp/pt.c:4785
 #, fuzzy, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.c:4830
+#: cp/pt.c:4844
 #, fuzzy, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr "#define 中の仮引数リストが終端されていません"
 
-#: cp/pt.c:4854
+#: cp/pt.c:4868
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:4858
+#: cp/pt.c:4872
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:4862 cp/pt.c:4873
+#: cp/pt.c:4876 cp/pt.c:4887
 #, fuzzy, gcc-internal-format
 #| msgid "previously declared here"
 msgid "primary template here"
 msgstr "前はここで宣言されました"
 
-#: cp/pt.c:4870
+#: cp/pt.c:4884
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:4885
+#: cp/pt.c:4899
 #, gcc-internal-format
 msgid "partial specialization %qD is not more specialized than"
 msgstr ""
 
-#: cp/pt.c:4887
+#: cp/pt.c:4901
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate label %qD"
 msgid "primary template %qD"
 msgstr "重複したラベル %qD です"
 
-#: cp/pt.c:4934
+#: cp/pt.c:4948
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:4937
+#: cp/pt.c:4951
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:4958
+#: cp/pt.c:4972
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr ""
 
-#: cp/pt.c:5004
+#: cp/pt.c:5018
 #, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
 msgstr[0] ""
 
-#: cp/pt.c:5066
+#: cp/pt.c:5080
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "自動テンプレート実体化を有効にする"
 
-#: cp/pt.c:5070
+#: cp/pt.c:5084
 #, fuzzy, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.c:5247
+#: cp/pt.c:5261
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "%qD 用のデフォルト引数がありません"
@@ -51377,47 +51421,47 @@
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5269
+#: cp/pt.c:5283
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "仮引数リスト中の `void' はリスト全体を占めなければなりません"
 
-#: cp/pt.c:5305
+#: cp/pt.c:5319
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr ""
 
-#: cp/pt.c:5308
+#: cp/pt.c:5322
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "一つの空の宣言中に、二つの型が指定されています"
 
-#: cp/pt.c:5311
+#: cp/pt.c:5325
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/pt.c:5314
+#: cp/pt.c:5328
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr ""
 
-#: cp/pt.c:5317 cp/pt.c:5375
+#: cp/pt.c:5331 cp/pt.c:5389
 #, fuzzy, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "クロスコンパイル時の実数値テンプレート仮引数"
 
-#: cp/pt.c:5489
+#: cp/pt.c:5503
 #, fuzzy, gcc-internal-format
 msgid "template %qD declared"
 msgstr "仮引数 `%s' が void と宣言されています"
 
-#: cp/pt.c:5496
+#: cp/pt.c:5510
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "名前無しテンプレートクラスです"
 
-#: cp/pt.c:5504
+#: cp/pt.c:5518
 #, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr ""
@@ -51427,74 +51471,74 @@
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5526
+#: cp/pt.c:5540
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "%qD の無効なテンプレート宣言です"
 
-#: cp/pt.c:5669
+#: cp/pt.c:5683
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "非テンプレート %q#D のテンプレート定義です"
 
-#: cp/pt.c:5712
+#: cp/pt.c:5726
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr ""
 
-#: cp/pt.c:5726
+#: cp/pt.c:5740
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr ""
 
-#: cp/pt.c:5729
+#: cp/pt.c:5743
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr ""
 
-#: cp/pt.c:5731
+#: cp/pt.c:5745
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr ""
 
-#: cp/pt.c:5752
+#: cp/pt.c:5766
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr ""
 
-#: cp/pt.c:5755
+#: cp/pt.c:5769
 #, gcc-internal-format
 msgid "use %<template<>%> for an explicit specialization"
 msgstr ""
 
-#: cp/pt.c:5882
+#: cp/pt.c:5896
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT はテンプレート型ではありません"
 
-#: cp/pt.c:5895
+#: cp/pt.c:5909
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr ""
 
-#: cp/pt.c:5906
+#: cp/pt.c:5920
 #, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
 msgstr[0] ""
 
-#: cp/pt.c:5910
+#: cp/pt.c:5924
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
 msgstr[0] "`%s' の宣言は仮引数を覆い隠します"
 
-#: cp/pt.c:5947
+#: cp/pt.c:5961
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "テンプレート仮引数 %q+#D です"
 
-#: cp/pt.c:5948
+#: cp/pt.c:5962
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "ここで %q#D として再宣言されています"
@@ -51503,122 +51547,122 @@
 #.
 #. A template-parameter may not be given default arguments
 #. by two different declarations in the same scope.
-#: cp/pt.c:5958
+#: cp/pt.c:5972
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "%q#D 用のデフォルト引数の再定義です"
 
-#: cp/pt.c:5960
+#: cp/pt.c:5974
 #, gcc-internal-format
 msgid "original definition appeared here"
 msgstr "元の定義はここに出現しています"
 
-#: cp/pt.c:5988
+#: cp/pt.c:6002
 #, fuzzy, gcc-internal-format
 msgid "redeclaration %q#D with different constraints"
 msgstr "`%s' が別のシンボル種として再宣言されました"
 
-#: cp/pt.c:5991
+#: cp/pt.c:6005
 #, fuzzy, gcc-internal-format
 #| msgid "original definition appeared here"
 msgid "original declaration appeared here"
 msgstr "元の定義はここに出現しています"
 
-#: cp/pt.c:6250 cp/pt.c:6318
+#: cp/pt.c:6264 cp/pt.c:6332
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr ""
 
-#: cp/pt.c:6253
+#: cp/pt.c:6267
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6256
+#: cp/pt.c:6270
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6268
+#: cp/pt.c:6282
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "`%s' の引数として無効な型"
 
-#: cp/pt.c:6272
+#: cp/pt.c:6286
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr ""
 
-#: cp/pt.c:6321
+#: cp/pt.c:6335
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr ""
 
-#: cp/pt.c:6323
+#: cp/pt.c:6337
 #, fuzzy, gcc-internal-format
 msgid "because it is a member of %qT"
 msgstr "%s に `%s' という名前のメンバはありません"
 
-#: cp/pt.c:6383
+#: cp/pt.c:6397
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter %q+#D"
 msgid "  couldn't deduce template parameter %qD"
 msgstr "テンプレート仮引数 %q+#D です"
 
-#: cp/pt.c:6392
+#: cp/pt.c:6406
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.c:6401
+#: cp/pt.c:6415
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between types %qT and %qT"
 msgid "  mismatched types %qT and %qT"
 msgstr "型 %qT と %qT の間での比較です"
 
-#: cp/pt.c:6410
+#: cp/pt.c:6424
 #, fuzzy, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr "strftime フォーマットは引数をフォーマットできません"
 
-#: cp/pt.c:6421
+#: cp/pt.c:6435
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute argument not an integer constant"
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "%qE 属性の引数が整数定数ではありません"
 
-#: cp/pt.c:6431
+#: cp/pt.c:6445
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "  %qE is not equivalent to %qE"
 msgstr "%qs は %qs 用には有効ではありません"
 
-#: cp/pt.c:6440
+#: cp/pt.c:6454
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:6452
+#: cp/pt.c:6466
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.c:6456
+#: cp/pt.c:6470
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.c:6467
+#: cp/pt.c:6481
 #, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6478
+#: cp/pt.c:6492
 #, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6490
+#: cp/pt.c:6504
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "  candidate expects %d argument, %d provided"
 #| msgid_plural "  candidate expects %d arguments, %d provided"
@@ -51626,300 +51670,300 @@
 msgid_plural "  candidate expects at least %d arguments, %d provided"
 msgstr[0] "  候補では %d 個の引数が予期されますが、%d 個の引数が与えられています"
 
-#: cp/pt.c:6521
+#: cp/pt.c:6535
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert type %qT to type %qT"
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "型 %qT から型 %qT へ変換できません"
 
-#: cp/pt.c:6534
+#: cp/pt.c:6548
 #, fuzzy, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "%s に `%s' という名前のメンバはありません"
 
-#: cp/pt.c:6538
+#: cp/pt.c:6552
 #, fuzzy, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "%s に `%s' という名前のメンバはありません"
 
-#: cp/pt.c:6549
+#: cp/pt.c:6563
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.c:6559
+#: cp/pt.c:6573
 #, fuzzy, gcc-internal-format
 msgid "  can't deduce a template for %qT from non-template type %qT"
 msgstr "不完全型のポインタへの間接参照"
 
-#: cp/pt.c:6569
+#: cp/pt.c:6583
 #, fuzzy, gcc-internal-format
 #| msgid "argument of type %qT does not match %qT"
 msgid "  template argument %qE does not match %qE"
 msgstr "型 %qT の引数が %qT と一致しません"
 
-#: cp/pt.c:6609
+#: cp/pt.c:6623
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr ""
 
-#: cp/pt.c:6758
+#: cp/pt.c:6772
 #, fuzzy, gcc-internal-format
 msgid "in template argument for type %qT"
 msgstr "`%s' の引数として無効な型"
 
-#: cp/pt.c:6772
+#: cp/pt.c:6786
 #, fuzzy, gcc-internal-format
 msgid "template argument %qE for type %qT not a constant integer"
 msgstr "`%s' の引数として無効な型"
 
-#: cp/pt.c:6833
+#: cp/pt.c:6847
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr ""
 
-#: cp/pt.c:6841
+#: cp/pt.c:6855
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr ""
 
-#: cp/pt.c:6857
+#: cp/pt.c:6871
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr ""
 
-#: cp/pt.c:6864
+#: cp/pt.c:6878
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr ""
 
-#: cp/pt.c:6873
+#: cp/pt.c:6887
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr ""
 
-#: cp/pt.c:6888
+#: cp/pt.c:6902
 #, fuzzy, gcc-internal-format
 #| msgid "the address of %qD will always evaluate as %<true%>"
 msgid "the address of %qD is not a valid template argument"
 msgstr "%qD のアドレスは常に %<true%> と評価されます"
 
-#: cp/pt.c:6897
+#: cp/pt.c:6911
 #, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6904
+#: cp/pt.c:6918
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr ""
 
-#: cp/pt.c:6933
+#: cp/pt.c:6947
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr ""
 
-#: cp/pt.c:6941
+#: cp/pt.c:6955
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr ""
 
-#: cp/pt.c:6959
+#: cp/pt.c:6973
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr ""
 
-#: cp/pt.c:6975
+#: cp/pt.c:6989
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an object with linkage"
 msgstr ""
 
-#: cp/pt.c:6986
+#: cp/pt.c:7000
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because object %qD does not have linkage"
 msgstr ""
 
-#: cp/pt.c:7036
+#: cp/pt.c:7050
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr ""
 
-#: cp/pt.c:7038
+#: cp/pt.c:7052
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr ""
 
-#: cp/pt.c:7092
+#: cp/pt.c:7106
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr ""
 
-#: cp/pt.c:7654
+#: cp/pt.c:7668
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "不完全な typedef `%s' の使用は不適切です"
 
-#: cp/pt.c:7670
+#: cp/pt.c:7684
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes applied to %qT after definition"
 msgid "ignoring attributes in template argument %qE"
 msgstr "定義した後に %qT に適用される属性を無視しています"
 
-#: cp/pt.c:7805
+#: cp/pt.c:7819
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr ""
 
-#: cp/pt.c:7834
+#: cp/pt.c:7848
 #, fuzzy, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "`restrict' の用法が不適切です"
 
-#: cp/pt.c:7839
+#: cp/pt.c:7853
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr ""
 
-#: cp/pt.c:7855 cp/pt.c:7877 cp/pt.c:7931
+#: cp/pt.c:7869 cp/pt.c:7891 cp/pt.c:7945
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.c:7860
+#: cp/pt.c:7874
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr ""
 
-#: cp/pt.c:7865
+#: cp/pt.c:7879
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr ""
 
-#: cp/pt.c:7868
+#: cp/pt.c:7882
 #, fuzzy, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "予期しない型が `id' (%s) に指定されました"
 
-#: cp/pt.c:7882
+#: cp/pt.c:7896
 #, fuzzy, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "予期しない型が `id' (%s) に指定されました"
 
-#: cp/pt.c:7885
+#: cp/pt.c:7899
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr ""
 
-#: cp/pt.c:7935
+#: cp/pt.c:7949
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr ""
 
-#: cp/pt.c:7949
+#: cp/pt.c:7963
 #, fuzzy, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "クロスコンパイル時の実数値テンプレート仮引数"
 
-#: cp/pt.c:7952
+#: cp/pt.c:7966
 #, fuzzy, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr "予期しない型が `id' (%s) に指定されました"
 
-#: cp/pt.c:8012
+#: cp/pt.c:8026
 #, fuzzy, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "%qE から %qT へ変換できません"
 
-#: cp/pt.c:8149 cp/pt.c:8465
+#: cp/pt.c:8163 cp/pt.c:8479
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "マクロ引数 \"%s\" は文字列化されます"
 
-#: cp/pt.c:8164 cp/pt.c:8298
+#: cp/pt.c:8178 cp/pt.c:8312
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr ""
 
-#: cp/pt.c:8294
+#: cp/pt.c:8308
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of arguments to function %<va_start%>"
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "関数 %<va_start%> への引数の数が間違っています"
 
-#: cp/pt.c:8303
+#: cp/pt.c:8317
 #, gcc-internal-format
 msgid "provided for %qD"
 msgstr ""
 
-#: cp/pt.c:8328
+#: cp/pt.c:8342
 #, fuzzy, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr "クロスコンパイル時の実数値テンプレート仮引数"
 
-#: cp/pt.c:8332
+#: cp/pt.c:8346
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr ""
 
-#: cp/pt.c:8431
+#: cp/pt.c:8445
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:9054
+#: cp/pt.c:9068
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%q#D is not a function template"
 msgstr "%qD は関数テンプレートではありません"
 
-#: cp/pt.c:9221
+#: cp/pt.c:9235
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr ""
 
-#: cp/pt.c:9223
+#: cp/pt.c:9237
 #, fuzzy, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "空の宣言です"
 
-#: cp/pt.c:9346
+#: cp/pt.c:9360
 #, fuzzy, gcc-internal-format
 #| msgid "internal consistency failure"
 msgid "template constraint failure"
 msgstr "内部一貫性がありません"
 
-#: cp/pt.c:9697
+#: cp/pt.c:9718
 #, fuzzy, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr "テンプレート内で `%s' を使用しています"
 
-#: cp/pt.c:10125
+#: cp/pt.c:10148
 #, gcc-internal-format, gfc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:11202
+#: cp/pt.c:11225
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member in union"
 msgid "flexible array member %qD in union"
 msgstr "共用体に可変配列メンバがあります"
 
-#: cp/pt.c:11691
+#: cp/pt.c:11713
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:12160
+#: cp/pt.c:12182
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr ""
 
-#: cp/pt.c:12163
+#: cp/pt.c:12185
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr ""
 
-#: cp/pt.c:12747
+#: cp/pt.c:12769
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for %q#D"
 msgid "  when instantiating default argument for call to %qD"
@@ -51938,279 +51982,279 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:13708
+#: cp/pt.c:13730
 #, fuzzy, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "sizeof が関数型に適用されました"
 
-#: cp/pt.c:13881
+#: cp/pt.c:13903
 #, fuzzy, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "仮引数 `%s' は無効です"
 
-#: cp/pt.c:13883
+#: cp/pt.c:13905
 #, fuzzy, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "無効な宣言です"
 
-#: cp/pt.c:14001
+#: cp/pt.c:14023
 #, fuzzy, gcc-internal-format
 msgid "function returning an array"
 msgstr "関数が集合体を返しています"
 
-#: cp/pt.c:14003
+#: cp/pt.c:14025
 #, fuzzy, gcc-internal-format
 msgid "function returning a function"
 msgstr "`%s' は関数を返す関数として宣言されています"
 
-#: cp/pt.c:14043
+#: cp/pt.c:14065
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "メンバ関数へのポインタが呼ばれましたが、クラススコープ内ではありません"
 
-#: cp/pt.c:14637
+#: cp/pt.c:14659
 #, fuzzy, gcc-internal-format
 msgid "forming reference to void"
 msgstr "一時オブジェクトへの参照を返そうとしています"
 
-#: cp/pt.c:14639
+#: cp/pt.c:14661
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "不完全型のポインタへの間接参照"
 
-#: cp/pt.c:14641
+#: cp/pt.c:14663
 #, fuzzy, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "参照を参照として宣言できません"
 
-#: cp/pt.c:14654
+#: cp/pt.c:14676
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "ポインタを参照として宣言できません"
 
-#: cp/pt.c:14657
+#: cp/pt.c:14679
 #, fuzzy, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "参照を参照として宣言できません"
 
-#: cp/pt.c:14705
+#: cp/pt.c:14727
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "   ポインタからメンバへの変換で"
 
-#: cp/pt.c:14711
+#: cp/pt.c:14733
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "   ポインタからメンバへの変換で"
 
-#: cp/pt.c:14717
+#: cp/pt.c:14739
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "   ポインタからメンバへの変換で"
 
-#: cp/pt.c:14783
+#: cp/pt.c:14805
 #, fuzzy, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "大きさゼロの配列を作ろうとしています"
 
-#: cp/pt.c:14816
+#: cp/pt.c:14838
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr ""
 
-#: cp/pt.c:14853
+#: cp/pt.c:14875
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr ""
 
-#: cp/pt.c:14861
+#: cp/pt.c:14883
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr ""
 
-#: cp/pt.c:14925
+#: cp/pt.c:14947
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.c:15000
+#: cp/pt.c:15022
 #, fuzzy, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "テンプレート内で `%s' を使用しています"
 
-#: cp/pt.c:15178
+#: cp/pt.c:15200
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/pt.c:15193
+#: cp/pt.c:15215
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr ""
 
-#: cp/pt.c:15195
+#: cp/pt.c:15217
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr ""
 
-#: cp/pt.c:15394
+#: cp/pt.c:15416
 #, fuzzy, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "static フィールド `%s' を欠いています"
 
-#: cp/pt.c:15883 cp/pt.c:17386
+#: cp/pt.c:15905 cp/pt.c:17408
 #, fuzzy, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "void 式の不適切な使用"
 
-#: cp/pt.c:15887 cp/pt.c:17390
+#: cp/pt.c:15909 cp/pt.c:17412
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr ""
 
-#: cp/pt.c:18334
+#: cp/pt.c:18371
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:18362
+#: cp/pt.c:18399
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:18367
+#: cp/pt.c:18404
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.c:18370
+#: cp/pt.c:18407
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr ""
 
-#: cp/pt.c:18375
+#: cp/pt.c:18412
 #, fuzzy, gcc-internal-format
 #| msgid "%qE undeclared here (not in a function)"
 msgid "%qD declared here, later in the translation unit"
 msgstr "%qE がここでは宣言されていません (関数内ではない)"
 
-#: cp/pt.c:18712
+#: cp/pt.c:18752
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr ""
 
-#: cp/pt.c:18715
+#: cp/pt.c:18755
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr ""
 
-#: cp/pt.c:19026
+#: cp/pt.c:19066
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a template type"
 msgid "%qT is/uses unnamed type"
 msgstr "%qT はテンプレート型ではありません"
 
-#: cp/pt.c:19028
+#: cp/pt.c:19068
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr ""
 
-#: cp/pt.c:19038
+#: cp/pt.c:19078
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr ""
 
-#: cp/pt.c:19053
+#: cp/pt.c:19093
 #, fuzzy, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "初期化子の要素が定数ではありません"
 
-#: cp/pt.c:19071
+#: cp/pt.c:19111
 #, fuzzy, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "不正な文字列定数です"
 
-#: cp/pt.c:22972
+#: cp/pt.c:23050
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "自動テンプレート実体化を有効にする"
 
-#: cp/pt.c:22974
+#: cp/pt.c:23052
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "自動テンプレート実体化を有効にする"
 
-#: cp/pt.c:22980
+#: cp/pt.c:23058
 #, fuzzy
 msgid "%s %#qS"
 msgstr "%s: %s"
 
-#: cp/pt.c:23004 cp/pt.c:23091
+#: cp/pt.c:23082 cp/pt.c:23169
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.c:23023
+#: cp/pt.c:23101
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr ""
 
-#: cp/pt.c:23029 cp/pt.c:23086
+#: cp/pt.c:23107 cp/pt.c:23164
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr ""
 
-#: cp/pt.c:23034
+#: cp/pt.c:23112
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr ""
 
-#: cp/pt.c:23042
+#: cp/pt.c:23120
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "%s: `%s' の初期化:\n"
 
-#: cp/pt.c:23078
+#: cp/pt.c:23156
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.c:23101 cp/pt.c:23187
+#: cp/pt.c:23179 cp/pt.c:23265
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ は減算にメソッドへのポインタを使うことを禁じます"
 
-#: cp/pt.c:23106 cp/pt.c:23204
+#: cp/pt.c:23184 cp/pt.c:23282
 #, fuzzy, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "自動テンプレート実体化を有効にする"
 
-#: cp/pt.c:23163
+#: cp/pt.c:23241
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.c:23165
+#: cp/pt.c:23243
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.c:23174
+#: cp/pt.c:23252
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.c:23192
+#: cp/pt.c:23270
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ は減算に関数へのポインタを使うことを禁じます"
 
-#: cp/pt.c:23238
+#: cp/pt.c:23316
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.c:23536
+#: cp/pt.c:23614
 #, gcc-internal-format
 msgid "exception specification of %qD depends on itself"
 msgstr ""
@@ -52222,112 +52266,112 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:23842
+#: cp/pt.c:23920
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.c:24043
+#: cp/pt.c:24121
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:24418
+#: cp/pt.c:24496
 #, fuzzy, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "不完全な typedef `%s' の使用は不適切です"
 
-#: cp/pt.c:24420
+#: cp/pt.c:24498
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "'#' にマクロ仮引数名が続いていません"
 
-#: cp/pt.c:25723
+#: cp/pt.c:25802
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr ""
 
-#: cp/pt.c:25961
+#: cp/pt.c:26040
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/pt.c:26440
+#: cp/pt.c:26519
 #, fuzzy, gcc-internal-format
 #| msgid "non-template %qD used as template"
 msgid "non-class template %qT used without template arguments"
 msgstr "非テンプレート %qD がテンプレートとして使用されています"
 
-#: cp/pt.c:26586
+#: cp/pt.c:26665
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:26593
+#: cp/pt.c:26672
 #, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr ""
 
-#: cp/pt.c:26607
+#: cp/pt.c:26686
 #, fuzzy, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "マクロ引数 \"%s\" は文字列化されます"
 
-#: cp/pt.c:26614
+#: cp/pt.c:26693
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "inline に出来ると見なされていない関数です"
 
-#: cp/pt.c:26676
+#: cp/pt.c:26755
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:26679
+#: cp/pt.c:26758
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:26711
+#: cp/pt.c:26790
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/pt.c:26746
+#: cp/pt.c:26825
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "無効なメソッド宣言です。メソッド名が必要です"
 
-#: cp/pt.c:26748
+#: cp/pt.c:26827
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr ""
 
-#: cp/pt.c:26781
+#: cp/pt.c:26860
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:26785
+#: cp/pt.c:26864
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "命令が制約を満たしません:"
 
-#: cp/pt.c:26789
+#: cp/pt.c:26868
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "命令が制約を満たしません:"
 
-#: cp/pt.c:26793
+#: cp/pt.c:26872
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "命令が制約を満たしません:"
 
-#: cp/pt.c:26912
+#: cp/pt.c:26991
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr "不完全な typedef `%s' の使用は不適切です"
@@ -52384,83 +52428,83 @@
 msgid "cannot dynamic_cast %qE (of type %q#T) to type %q#T (%s)"
 msgstr ""
 
-#: cp/search.c:240
+#: cp/search.c:243
 #, gcc-internal-format
 msgid "%qT is an ambiguous base of %qT"
 msgstr ""
 
-#: cp/search.c:256
+#: cp/search.c:259
 #, gcc-internal-format
 msgid "%qT is an inaccessible base of %qT"
 msgstr ""
 
-#: cp/search.c:1905
+#: cp/search.c:1908
 #, fuzzy, gcc-internal-format
 msgid "invalid covariant return type for %q#D"
 msgstr "無効なメソッド宣言です。メソッド名が必要です"
 
-#: cp/search.c:1907 cp/search.c:1922 cp/search.c:1928 cp/search.c:1957
+#: cp/search.c:1910 cp/search.c:1925 cp/search.c:1931 cp/search.c:1960
 #, fuzzy, gcc-internal-format
 #| msgid "decrement of function %qD"
 msgid "overridden function is %q#D"
 msgstr "関数 %qD の減分です"
 
-#: cp/search.c:1920
+#: cp/search.c:1923
 #, fuzzy, gcc-internal-format
 msgid "invalid covariant return type for %q+#D"
 msgstr "無効なメソッド宣言です。メソッド名が必要です"
 
-#: cp/search.c:1926
+#: cp/search.c:1929
 #, fuzzy, gcc-internal-format
 msgid "conflicting return type specified for %q+#D"
 msgstr "`%s' と型が矛盾します"
 
-#: cp/search.c:1942
+#: cp/search.c:1945
 #, fuzzy, gcc-internal-format
 msgid "looser throw specifier for %q+#F"
 msgstr "`%s' に対して char とともに long または short が指定されています"
 
-#: cp/search.c:1944
+#: cp/search.c:1947
 #, fuzzy, gcc-internal-format
 #| msgid "In function %qs"
 msgid "overridden function is %q#F"
 msgstr "関数 %qs 内"
 
-#: cp/search.c:1955
+#: cp/search.c:1958
 #, fuzzy, gcc-internal-format
 msgid "conflicting type attributes specified for %q+#D"
 msgstr "`%s' と型が矛盾します"
 
-#: cp/search.c:1972
+#: cp/search.c:1975
 #, gcc-internal-format
 msgid "%qD declared %<transaction_safe_dynamic%>"
 msgstr ""
 
-#: cp/search.c:1974
+#: cp/search.c:1977
 #, fuzzy, gcc-internal-format
 #| msgid "variable %q+D declared %<inline%>"
 msgid "overriding %qD declared %<transaction_safe%>"
 msgstr "変数 %q+D が %<inline%> と宣言されています"
 
-#: cp/search.c:1981
+#: cp/search.c:1984
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "deleted function %q+D overriding non-deleted function"
 msgstr "組み込み関数 %q+D が非関数として宣言されました"
 
-#: cp/search.c:1984 cp/search.c:1992 cp/search.c:2000
+#: cp/search.c:1987 cp/search.c:1995 cp/search.c:2003
 #, fuzzy, gcc-internal-format
 #| msgid "decrement of function %qD"
 msgid "overridden function is %qD"
 msgstr "関数 %qD の減分です"
 
-#: cp/search.c:1989
+#: cp/search.c:1992
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "non-deleted function %q+D overriding deleted function"
 msgstr "組み込み関数 %q+D が非関数として宣言されました"
 
-#: cp/search.c:1998
+#: cp/search.c:2001
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "virtual function %q+D overriding final function"
@@ -52468,12 +52512,12 @@
 
 #. A static member function cannot match an inherited
 #. virtual member function.
-#: cp/search.c:2082
+#: cp/search.c:2085
 #, fuzzy, gcc-internal-format
 msgid "%q+#D cannot be declared"
 msgstr "const `%s' を `mutable' として宣言できません"
 
-#: cp/search.c:2083
+#: cp/search.c:2086
 #, gcc-internal-format
 msgid "  since %q+#D declared in base class"
 msgstr ""
@@ -52513,156 +52557,156 @@
 msgid "invalid use of member %qD in static member function"
 msgstr "非メンバ関数での `this' の使用は無効です"
 
-#: cp/semantics.c:2153
+#: cp/semantics.c:2156
 #, gcc-internal-format
 msgid "a statement expression is an insufficient context for overload resolution"
 msgstr ""
 
-#: cp/semantics.c:2540
+#: cp/semantics.c:2543
 #, fuzzy, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr "引数が構造体です"
 
-#: cp/semantics.c:2622
+#: cp/semantics.c:2625
 #, fuzzy, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr "`this' は静的メンバ関数から使用できません"
 
-#: cp/semantics.c:2624
+#: cp/semantics.c:2627
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr "非メンバ関数での `this' の使用は無効です"
 
-#: cp/semantics.c:2626
+#: cp/semantics.c:2629
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr "トップレベルでの `this' の使用は無効です"
 
-#: cp/semantics.c:2648
+#: cp/semantics.c:2651
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr ""
 
-#: cp/semantics.c:2656 cp/typeck.c:2604
+#: cp/semantics.c:2659 cp/typeck.c:2604
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/semantics.c:2678
+#: cp/semantics.c:2681
 #, fuzzy, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr "%s は型 %s ではありません (引数 %d)"
 
-#: cp/semantics.c:2751
+#: cp/semantics.c:2754
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr ""
 
-#: cp/semantics.c:2892
+#: cp/semantics.c:2895
 #, fuzzy, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr "テンプレート型仮引数には `class' や `typename' 予約語を使わねばなりません"
 
-#: cp/semantics.c:2942
+#: cp/semantics.c:2945
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr ""
 
-#: cp/semantics.c:2945
+#: cp/semantics.c:2948
 #, fuzzy, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr "無効なデフォルトテンプレート引数"
 
-#: cp/semantics.c:2962
+#: cp/semantics.c:2965
 #, fuzzy, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr "`%s' の宣言は仮引数リストのシンボルを覆い隠します"
 
-#: cp/semantics.c:2993
+#: cp/semantics.c:2996
 #, fuzzy, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr "インスタンス化されない型に対する無効な操作です"
 
-#: cp/semantics.c:3263
+#: cp/semantics.c:3266
 #, fuzzy, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "無効な宣言です"
 
-#: cp/semantics.c:3423
+#: cp/semantics.c:3426
 #, fuzzy, gcc-internal-format
 #| msgid "protected member %q+#D in anonymous union"
 msgid "cannot capture member %qD of anonymous union"
 msgstr "無名共用体内に保護されたメンバ %q+#D があります"
 
-#: cp/semantics.c:3443 cp/semantics.c:9269
+#: cp/semantics.c:3446 cp/semantics.c:9272
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr ""
 
-#: cp/semantics.c:3448
+#: cp/semantics.c:3451
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.c:3450
+#: cp/semantics.c:3453
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.c:3462
+#: cp/semantics.c:3465
 #, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr ""
 
-#: cp/semantics.c:3464
+#: cp/semantics.c:3467
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr ""
 
-#: cp/semantics.c:3596
+#: cp/semantics.c:3599
 #, fuzzy, gcc-internal-format
 #| msgid "alloc_size parameter outside range"
 msgid "use of parameter outside function body"
 msgstr "alloc_size パラメータが範囲外です"
 
-#: cp/semantics.c:3606
+#: cp/semantics.c:3609
 #, fuzzy, gcc-internal-format
 #| msgid "mismatched arguments"
 msgid "missing template arguments"
 msgstr "合っていない引数です"
 
-#: cp/semantics.c:3633
+#: cp/semantics.c:3636
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr ""
 
-#: cp/semantics.c:3664
+#: cp/semantics.c:3667
 #, gcc-internal-format
 msgid "use of namespace %qD as expression"
 msgstr ""
 
-#: cp/semantics.c:3669
+#: cp/semantics.c:3672
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr ""
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:3675
+#: cp/semantics.c:3678
 #, fuzzy, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "要求されたメンバ `%s' は多重継承グラフの中で曖昧です"
 
-#: cp/semantics.c:3702
+#: cp/semantics.c:3705
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "定数式がオーバーフローしました"
 
-#: cp/semantics.c:3841
+#: cp/semantics.c:3844
 #, fuzzy, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "レジスタ '%c' が不明です"
 
-#: cp/semantics.c:3870
+#: cp/semantics.c:3873
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a template type"
 msgid "%qT is not an enumeration type"
@@ -52669,455 +52713,471 @@
 msgstr "%qT はテンプレート型ではありません"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4009
+#: cp/semantics.c:4012
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specifiers invalid in parameter declarations"
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr "仮引数宣言の中の記憶域クラス指定は無効です"
 
-#: cp/semantics.c:4038
+#: cp/semantics.c:4041
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr ""
 
-#: cp/semantics.c:4052
+#: cp/semantics.c:4055
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "ISO C++ はメンバ関数への `sizeof' の適用を禁じます"
 
-#: cp/semantics.c:4056
+#: cp/semantics.c:4059
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function"
 msgstr "ISO C++ はメンバ関数への `sizeof' の適用を禁じます"
 
-#: cp/semantics.c:4061
+#: cp/semantics.c:4064
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr "ISO C++ はメンバ関数への `sizeof' の適用を禁じます"
 
-#: cp/semantics.c:4072
+#: cp/semantics.c:4075
 #, gcc-internal-format
 msgid "offsetof within non-standard-layout type %qT is conditionally-supported"
 msgstr ""
 
-#: cp/semantics.c:4583 cp/semantics.c:6069 cp/semantics.c:6140
-#: cp/semantics.c:6183 cp/semantics.c:6533 cp/semantics.c:6632
-#: cp/semantics.c:6775
+#: cp/semantics.c:4586 cp/semantics.c:6072 cp/semantics.c:6143
+#: cp/semantics.c:6186 cp/semantics.c:6536 cp/semantics.c:6635
+#: cp/semantics.c:6778
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5271
+#: cp/semantics.c:5274
 #, fuzzy, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr "%s: オプション `%s' はあいまいです\n"
 
-#: cp/semantics.c:5544
+#: cp/semantics.c:5547
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: cp/semantics.c:5592
+#: cp/semantics.c:5595
 #, fuzzy, gcc-internal-format
 #| msgid "%qE has invalid type for %<reduction%>"
 msgid "%qE has const type for %<reduction%>"
 msgstr "%qE は %<reduction%> 用の無効な型を持っています"
 
-#: cp/semantics.c:5707
+#: cp/semantics.c:5710
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:5941
+#: cp/semantics.c:5944
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5955
+#: cp/semantics.c:5958
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5977
+#: cp/semantics.c:5980
 #, fuzzy, gcc-internal-format
 #| msgid "index must be integer"
 msgid "linear step expression must be integral"
 msgstr "添え字は整数でなければいけません"
 
-#: cp/semantics.c:6080
+#: cp/semantics.c:6083
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "インスタンス変数 `%s' は %s と宣言されています"
 
-#: cp/semantics.c:6152
+#: cp/semantics.c:6155
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "インスタンス変数 `%s' は private と宣言されています"
 
-#: cp/semantics.c:6195
+#: cp/semantics.c:6198
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "インスタンス変数 `%s' は private と宣言されています"
 
-#: cp/semantics.c:6240
+#: cp/semantics.c:6243
 #, gcc-internal-format
 msgid "%<gang%> static expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6254
+#: cp/semantics.c:6257
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<gang%> static value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: cp/semantics.c:6288
+#: cp/semantics.c:6291
 #, gcc-internal-format
 msgid "%<gang%> num expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6291
+#: cp/semantics.c:6294
 #, gcc-internal-format
 msgid "%<vector%> length expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6295
+#: cp/semantics.c:6298
 #, gcc-internal-format
 msgid "%<worker%> num expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6317
+#: cp/semantics.c:6320
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<gang%> num value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: cp/semantics.c:6321
+#: cp/semantics.c:6324
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<vector%> length value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: cp/semantics.c:6326
+#: cp/semantics.c:6329
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<worker%> num value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: cp/semantics.c:6376
+#: cp/semantics.c:6379
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6406
+#: cp/semantics.c:6409
 #, fuzzy, gcc-internal-format
 #| msgid "index must be integer"
 msgid "%qs length expression must be integral"
 msgstr "添え字は整数でなければいけません"
 
-#: cp/semantics.c:6419
+#: cp/semantics.c:6422
 #, fuzzy, gcc-internal-format
 #| msgid "expression in static assertion is not an integer constant expression"
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "静的アサーション内の式が整数定数式ではありません"
 
-#: cp/semantics.c:6438
+#: cp/semantics.c:6441
 #, fuzzy, gcc-internal-format
 #| msgid "index must be integer"
 msgid "%<async%> expression must be integral"
 msgstr "添え字は整数でなければいけません"
 
-#: cp/semantics.c:6466
+#: cp/semantics.c:6469
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6495
+#: cp/semantics.c:6498
 #, fuzzy, gcc-internal-format
 #| msgid "index must be integer"
 msgid "%<device%> id must be integral"
 msgstr "添え字は整数でなければいけません"
 
-#: cp/semantics.c:6516
+#: cp/semantics.c:6519
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6543
+#: cp/semantics.c:6546
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "インスタンス変数 `%s' は %s と宣言されています"
 
-#: cp/semantics.c:6557
+#: cp/semantics.c:6560
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:6563
+#: cp/semantics.c:6566
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
-#: cp/semantics.c:6576
+#: cp/semantics.c:6579
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6625
+#: cp/semantics.c:6628
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr "インスタンス変数 `%s' は %s と宣言されています"
 
-#: cp/semantics.c:6910
+#: cp/semantics.c:6913
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "template %qE in clause %qs"
 msgstr "%qs 句が多すぎます"
 
-#: cp/semantics.c:6914
+#: cp/semantics.c:6917
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6979
+#: cp/semantics.c:6982
 #, fuzzy, gcc-internal-format
 #| msgid "index must be integer"
 msgid "%<grainsize%> expression must be integral"
 msgstr "添え字は整数でなければいけません"
 
-#: cp/semantics.c:7008
+#: cp/semantics.c:7011
 #, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7037
+#: cp/semantics.c:7040
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<num_tasks%> expression must be integral"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: cp/semantics.c:7066
+#: cp/semantics.c:7069
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:7105
+#: cp/semantics.c:7108
 #, fuzzy, gcc-internal-format
 #| msgid "%<tree%> is not defined as a pointer type"
 msgid "%<tile%> argument needs integral type"
 msgstr "%<tree%> がポインタ型として定義されていません"
 
-#: cp/semantics.c:7524
+#: cp/semantics.c:7527
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.c:7538
+#: cp/semantics.c:7541
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr ""
 
-#: cp/semantics.c:7743
+#: cp/semantics.c:7746
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.c:8171
+#: cp/semantics.c:8174
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.c:8398 cp/semantics.c:8408
+#: cp/semantics.c:8401 cp/semantics.c:8411
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.c:8702
+#: cp/semantics.c:8705
 #, fuzzy, gcc-internal-format
 #| msgid "static assertion failed: %E"
 msgid "static assertion failed"
 msgstr "静的アサーションに失敗しました: %E"
 
-#: cp/semantics.c:8704
+#: cp/semantics.c:8707
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "static assertion failed: %E"
 msgid "static assertion failed: %s"
 msgstr "静的アサーションに失敗しました: %E"
 
-#: cp/semantics.c:8709
+#: cp/semantics.c:8712
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr ""
 
-#: cp/semantics.c:8739
+#: cp/semantics.c:8742
 #, gcc-internal-format
 msgid "argument to decltype must be an expression"
 msgstr ""
 
-#: cp/semantics.c:8767
+#: cp/semantics.c:8770
 #, fuzzy, gcc-internal-format
 #| msgid "<unresolved overloaded function type>"
 msgid "decltype cannot resolve address of overloaded function"
 msgstr "<未解決オーバーロードされた関数型>"
 
-#: cp/semantics.c:9308
+#: cp/semantics.c:9311
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "カンマ演算子の左側の式に効力がありません"
 
-#: cp/semantics.c:9361
+#: cp/semantics.c:9364
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.c:9363
+#: cp/semantics.c:9366
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:9381
+#: cp/semantics.c:9384
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %<__builtin_return_address%>"
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "%<__builtin_return_address%> へのサポートされていない引数です"
 
-#: cp/tree.c:1276
+#: cp/tree.c:1295
 #, gcc-internal-format
 msgid "%qV qualifiers cannot be applied to %qT"
 msgstr ""
 
-#: cp/tree.c:1788
+#: cp/tree.c:1807
 #, fuzzy, gcc-internal-format
 msgid "lambda-expression in a constant expression"
 msgstr "定数式がオーバーフローしました"
 
-#: cp/tree.c:1792
+#: cp/tree.c:1811
 #, fuzzy, gcc-internal-format
 msgid "statement-expression in a constant expression"
 msgstr "定数式がオーバーフローしました"
 
-#: cp/tree.c:4050
+#: cp/tree.c:4083
 #, gcc-internal-format
-msgid "the calling convention for %qT changes in -fabi-version=12 (GCC 8)"
+msgid "-fabi-version=13 (GCC 8.2) fixes the calling convention for %qT, which was accidentally changed in 8.1"
 msgstr ""
 
-#: cp/tree.c:4055
+#: cp/tree.c:4087
 #, gcc-internal-format
+msgid "-fabi-version=12 (GCC 8.1) accidentally changes the calling convention for %qT"
+msgstr ""
+
+#: cp/tree.c:4090
+#, fuzzy, gcc-internal-format
+#| msgid "declared here"
+msgid " declared here"
+msgstr "ここで宣言されています"
+
+#: cp/tree.c:4094
+#, gcc-internal-format
+msgid "the calling convention for %qT changes in -fabi-version=13 (GCC 8.2)"
+msgstr ""
+
+#: cp/tree.c:4096
+#, gcc-internal-format
 msgid " because all of its copy and move constructors are deleted"
 msgstr ""
 
-#: cp/tree.c:4416
+#: cp/tree.c:4464
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to function types"
 msgid "%qE attribute applied to %qD with void return type"
 msgstr "%qE 属性は関数型にのみ適用できます"
 
-#: cp/tree.c:4423
+#: cp/tree.c:4471
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr "`com_interface' 属性はクラス定義にのみ用いる事ができます"
 
-#: cp/tree.c:4475
+#: cp/tree.c:4523
 #, gcc-internal-format
 msgid "requested init_priority is not an integer constant"
 msgstr "要求された init_priority は整数型の定数ではありません"
 
-#: cp/tree.c:4497
+#: cp/tree.c:4545
 #, fuzzy, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr "init_priority 属性はクラス型オブジェクトのファイルスコープ定義でのみ使えます"
 
-#: cp/tree.c:4505
+#: cp/tree.c:4553
 #, gcc-internal-format
 msgid "requested init_priority is out of range"
 msgstr "要求された init_priority が範囲外です"
 
-#: cp/tree.c:4515
+#: cp/tree.c:4563
 #, gcc-internal-format
 msgid "requested init_priority is reserved for internal use"
 msgstr "要求された init_priority は内部で使用するために予約されています"
 
-#: cp/tree.c:4526
+#: cp/tree.c:4574
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr "init_priority 属性はこのプラットフォームではサポートされていません"
 
-#: cp/tree.c:4553
+#: cp/tree.c:4601
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %qE"
 msgstr "`%s' の宣言により `this' のメンバが覆い隠されます"
 
-#: cp/tree.c:4573
+#: cp/tree.c:4621
 #, fuzzy, gcc-internal-format
 msgid "the %qE attribute requires arguments"
 msgstr "%s: オプション `%s' には引数が必要です\n"
 
-#: cp/tree.c:4584
+#: cp/tree.c:4632
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qE attribute is not a string constant"
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "%qE 属性の引数が文字列定数ではありません"
 
-#: cp/tree.c:4597 cp/tree.c:4610
+#: cp/tree.c:4645 cp/tree.c:4658
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qE attribute is not a string constant"
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "%qE 属性の引数が文字列定数ではありません"
 
-#: cp/tree.c:4599
+#: cp/tree.c:4647
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a valid declarator"
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "%<%T::%D%> は有効な宣言子ではありません"
 
-#: cp/tree.c:4612
+#: cp/tree.c:4660
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a valid declarator"
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "%<%T::%D%> は有効な宣言子ではありません"
 
-#: cp/tree.c:4636
+#: cp/tree.c:4684
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "%qE 属性は非クラス型に関しては無視されます"
 
-#: cp/tree.c:4642
+#: cp/tree.c:4690
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes applied to %qT after definition"
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "定義した後に %qT に適用される属性を無視しています"
 
-#: cp/tree.c:4649
+#: cp/tree.c:4697
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes applied to %qT after definition"
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "定義した後に %qT に適用される属性を無視しています"
 
-#: cp/tree.c:4656
+#: cp/tree.c:4704
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes applied to %qT after definition"
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "定義した後に %qT に適用される属性を無視しています"
 
-#: cp/tree.c:4678
+#: cp/tree.c:4726
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to functions, not %s"
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "%qE 属性は関数へのみ適用出来ます。%s へは適用できません"
 
-#: cp/tree.c:4684
+#: cp/tree.c:4732
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "`%s' 属性は関数に対してのみ適用されます"
 
-#: cp/tree.c:5440
+#: cp/tree.c:5488
 #, fuzzy, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "配列の添字が整数型ではありません"
 
-#: cp/tree.c:5453
+#: cp/tree.c:5501
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr "Tree 検査: %s があるべき所に %s があります(%s 内, %s:%d)"
@@ -54238,110 +54298,110 @@
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr ""
 
-#: cp/typeck2.c:1496 cp/typeck2.c:1523
+#: cp/typeck2.c:1499 cp/typeck2.c:1526
 #, fuzzy, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "初期化子を欠いています"
 
-#: cp/typeck2.c:1504
+#: cp/typeck2.c:1507
 #, fuzzy, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "仮引数 `%s' が初期化されました"
 
-#: cp/typeck2.c:1511
+#: cp/typeck2.c:1514
 #, fuzzy, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr "仮引数 `%s' が初期化されました"
 
-#: cp/typeck2.c:1587
+#: cp/typeck2.c:1590
 #, fuzzy, gcc-internal-format
 #| msgid "type of %qD does not match original declaration"
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "%qD の型は元の宣言と一致しません"
 
-#: cp/typeck2.c:1660
+#: cp/typeck2.c:1663
 #, fuzzy, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "レコードや共用体にフィールド名がない初期化子です"
 
-#: cp/typeck2.c:1671
+#: cp/typeck2.c:1674
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "union 初期化子がフィールド名ではなくインデックス値になっています"
 
-#: cp/typeck2.c:1858
+#: cp/typeck2.c:1861
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "循環ポインタの代表を検出しました"
 
-#: cp/typeck2.c:1872
+#: cp/typeck2.c:1875
 #, fuzzy, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "`->' のベースオペランドがポインタではありません"
 
-#: cp/typeck2.c:1898
+#: cp/typeck2.c:1901
 #, fuzzy, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "`operator->()'の結果が非ポインタの結果をもたらします"
 
-#: cp/typeck2.c:1900
+#: cp/typeck2.c:1903
 #, fuzzy, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "`->' のベースオペランドがポインタではありません"
 
-#: cp/typeck2.c:1927
+#: cp/typeck2.c:1930
 #, fuzzy, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "\"%s\" は C++ の演算子であり、マクロ名として使用することはできません"
 
-#: cp/typeck2.c:1936
+#: cp/typeck2.c:1939
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr ""
 
-#: cp/typeck2.c:1958
+#: cp/typeck2.c:1961
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2018
+#: cp/typeck2.c:2021
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "メンバ関数へのポインタが計算内で使用されています"
 
-#: cp/typeck2.c:2029
+#: cp/typeck2.c:2032
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "メンバ関数へのポインタが計算内で使用されています"
 
-#: cp/typeck2.c:2037
+#: cp/typeck2.c:2040
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++2a"
 msgstr ""
 
-#: cp/typeck2.c:2080
+#: cp/typeck2.c:2083
 #, fuzzy, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "関数 `%s' に対して不適切な保存クラス"
 
-#: cp/typeck2.c:2096
+#: cp/typeck2.c:2099
 #, fuzzy, gcc-internal-format
 msgid "cannot deduce template arguments for %qT from ()"
 msgstr "`%s' の引数として無効な型"
 
-#: cp/typeck2.c:2114
+#: cp/typeck2.c:2117
 #, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr ""
 
-#: cp/typeck2.c:2341
+#: cp/typeck2.c:2344
 #, fuzzy, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "不完全型への変換です"
 
-#: cp/typeck2.c:2344
+#: cp/typeck2.c:2347
 #, fuzzy, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "不完全型への変換です"
@@ -54557,11 +54617,11 @@
 msgstr ""
 
 #: fortran/array.c:221 fortran/array.c:661 fortran/check.c:2849
-#: fortran/check.c:5222 fortran/check.c:5260 fortran/check.c:5302
-#: fortran/check.c:5329 fortran/check.c:5529 fortran/match.c:1821
+#: fortran/check.c:5225 fortran/check.c:5263 fortran/check.c:5305
+#: fortran/check.c:5332 fortran/check.c:5532 fortran/match.c:1821
 #: fortran/match.c:3174 fortran/match.c:3516 fortran/match.c:3712
-#: fortran/simplify.c:2909 fortran/simplify.c:2939 fortran/simplify.c:5764
-#: fortran/simplify.c:7658
+#: fortran/simplify.c:2909 fortran/simplify.c:2939 fortran/simplify.c:5769
+#: fortran/simplify.c:7663
 #, gcc-internal-format
 msgid "Coarrays disabled at %C, use %<-fcoarray=%> to enable"
 msgstr ""
@@ -54698,121 +54758,126 @@
 msgid "DO-iterator %qs at %L is inside iterator of the same name"
 msgstr ""
 
-#: fortran/array.c:1073 fortran/array.c:1255
+#: fortran/array.c:1073 fortran/array.c:1264
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in array constructor at %C"
 msgstr ""
 
-#: fortran/array.c:1129
+#: fortran/array.c:1105
+#, fuzzy, gcc-internal-format, gfc-internal-format
+msgid "NULL() at %C cannot appear in an array constructor"
+msgstr "定数式がオーバーフローしました"
+
+#: fortran/array.c:1138
 #, gcc-internal-format, gfc-internal-format
 msgid "[...] style array constructors at %C"
 msgstr ""
 
-#: fortran/array.c:1149
+#: fortran/array.c:1158
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array constructor including type specification at %C"
 msgstr "メソッド仕様内での構文解析エラー"
 
-#: fortran/array.c:1155 fortran/match.c:4148
+#: fortran/array.c:1164 fortran/match.c:4148
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-spec at %L cannot contain a deferred type parameter"
 msgstr ""
 
-#: fortran/array.c:1163
+#: fortran/array.c:1172
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-spec at %L cannot contain an asterisk for a type parameter"
 msgstr ""
 
-#: fortran/array.c:1181
+#: fortran/array.c:1190
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty array constructor at %C is not allowed"
 msgstr ""
 
-#: fortran/array.c:1218 fortran/array.c:1228
+#: fortran/array.c:1227 fortran/array.c:1237
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "incompatible type for argument %d of %qE"
 msgid "Incompatible typespec for array element at %L"
 msgstr "%d 番目の %qE の引数用の互換性がない型です"
 
-#: fortran/array.c:1302
+#: fortran/array.c:1311
 #, gcc-internal-format, gfc-internal-format
 msgid "Element in %s array constructor at %L is %s"
 msgstr ""
 
-#: fortran/array.c:1633
+#: fortran/array.c:1642
 #, gcc-internal-format, gfc-internal-format
 msgid "Iterator step at %L cannot be zero"
 msgstr ""
 
-#: fortran/array.c:1770
+#: fortran/array.c:1779
 #, gcc-internal-format
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit.   See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/array.c:1940
+#: fortran/array.c:1949
 #, gcc-internal-format, gfc-internal-format
 msgid "AC-IMPLIED-DO initial expression references control variable at %L"
 msgstr ""
 
-#: fortran/array.c:1947
+#: fortran/array.c:1956
 #, gcc-internal-format, gfc-internal-format
 msgid "AC-IMPLIED-DO final expression references control variable at %L"
 msgstr ""
 
-#: fortran/array.c:1954
+#: fortran/array.c:1963
 #, gcc-internal-format, gfc-internal-format
 msgid "AC-IMPLIED-DO step expression references control variable at %L"
 msgstr ""
 
-#: fortran/array.c:1966
+#: fortran/array.c:1975
 #, gcc-internal-format, gfc-internal-format
 msgid "Array constructor value at %L shall not be unlimited polymorphic [F2008: C4106]"
 msgstr ""
 
-#: fortran/array.c:2055
+#: fortran/array.c:2067
 #, gcc-internal-format, gfc-internal-format
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor at %L"
 msgstr ""
 
-#: fortran/array.c:2174
+#: fortran/array.c:2186
 #, gcc-internal-format
 msgid "spec_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2233
+#: fortran/array.c:2245
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2237
+#: fortran/array.c:2249
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "overflow in array dimension"
 msgid "Bad array dimension at %L"
 msgstr "配列の次元がオーバーフローしました"
 
-#: fortran/array.c:2264 fortran/data.c:552 fortran/data.c:571
-#: fortran/data.c:585 fortran/data.c:714
+#: fortran/array.c:2276 fortran/data.c:563 fortran/data.c:582
+#: fortran/data.c:596 fortran/data.c:725
 #, fuzzy, gcc-internal-format
 #| msgid "gimplification failed"
 msgid "Simplification error"
 msgstr "gimplification に失敗しました"
 
-#: fortran/array.c:2376
+#: fortran/array.c:2388
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimen_type"
 msgstr ""
 
-#: fortran/array.c:2427
+#: fortran/array.c:2439
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2472
+#: fortran/array.c:2484
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad EXPR_ARRAY expr"
 msgstr ""
 
-#: fortran/array.c:2620
+#: fortran/array.c:2632
 #, gcc-internal-format
 msgid "gfc_find_array_ref(): No ref found"
 msgstr ""
@@ -54863,7 +54928,7 @@
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or PROCEDURE"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:205 fortran/check.c:6658
+#: fortran/check.c:205 fortran/check.c:6661
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a constant"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
@@ -54979,7 +55044,7 @@
 msgid "Unequal character lengths (%ld/%ld) in %s at %L"
 msgstr ""
 
-#: fortran/check.c:946 fortran/check.c:6602
+#: fortran/check.c:946 fortran/check.c:6605
 #, fuzzy, gcc-internal-format
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have the same type"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
@@ -55216,9 +55281,9 @@
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
 #: fortran/check.c:1939 fortran/check.c:2525 fortran/check.c:2628
-#: fortran/check.c:2835 fortran/check.c:2880 fortran/check.c:4256
-#: fortran/check.c:4390 fortran/check.c:4445 fortran/check.c:5515
-#: fortran/check.c:5644
+#: fortran/check.c:2835 fortran/check.c:2880 fortran/check.c:4259
+#: fortran/check.c:4393 fortran/check.c:4448 fortran/check.c:5518
+#: fortran/check.c:5647
 #, gcc-internal-format
 msgid "%qs intrinsic with KIND argument at %L"
 msgstr ""
@@ -55413,7 +55478,7 @@
 msgid "NULL intrinsic with allocatable MOLD at %L"
 msgstr ""
 
-#: fortran/check.c:3768 fortran/check.c:5591
+#: fortran/check.c:3768 fortran/check.c:5594
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must provide at least as many elements as there are .TRUE. values in %qs (%ld/%d)"
 msgstr ""
@@ -55433,373 +55498,373 @@
 msgid "%qs argument of %qs intrinsic at %L must not be a subobject of %qs"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:3901
+#: fortran/check.c:3904
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The argument of the RANK intrinsic at %L must be a data object"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:4005
+#: fortran/check.c:4008
 #, fuzzy, gcc-internal-format
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L must be an array of constant size"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:4015
+#: fortran/check.c:4018
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L is empty"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:4022
+#: fortran/check.c:4025
 #, fuzzy, gcc-internal-format
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L has more than %d elements"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:4039
+#: fortran/check.c:4042
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has negative element (%d)"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:4071
+#: fortran/check.c:4074
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Element %d of actual argument of RESHAPE at %L cannot be negative"
 msgstr "`%s' の第二引数は `char **' とすべきです"
 
-#: fortran/check.c:4109
+#: fortran/check.c:4112
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has wrong number of elements (%d/%d)"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:4127
+#: fortran/check.c:4130
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has out-of-range dimension (%d)"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:4136
+#: fortran/check.c:4139
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has invalid permutation of dimensions (dimension %qd duplicated)"
 msgstr ""
 
-#: fortran/check.c:4172
+#: fortran/check.c:4175
 #, gcc-internal-format, gfc-internal-format
 msgid "Without padding, there are not enough elements in the intrinsic RESHAPE source at %L to match the shape"
 msgstr ""
 
-#: fortran/check.c:4189 fortran/check.c:4208
+#: fortran/check.c:4192 fortran/check.c:4211
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L cannot be of type %s"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:4199 fortran/check.c:4218
+#: fortran/check.c:4202 fortran/check.c:4221
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of an extensible type"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:4317
+#: fortran/check.c:4320
 #, gcc-internal-format
 msgid "SELECTED_REAL_KIND with neither %<P%> nor %<R%> argument at %L"
 msgstr ""
 
-#: fortran/check.c:4348
+#: fortran/check.c:4351
 #, gcc-internal-format
 msgid "%qs intrinsic with RADIX argument at %L"
 msgstr ""
 
-#: fortran/check.c:4383
+#: fortran/check.c:4386
 #, fuzzy, gcc-internal-format
 msgid "%<source%> argument of %<shape%> intrinsic at %L must not be an assumed size array"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:4460 fortran/check.c:6641
+#: fortran/check.c:4463 fortran/check.c:6644
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be a procedure"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:4473 fortran/check.c:4612 fortran/check.c:6633
+#: fortran/check.c:4476 fortran/check.c:4615 fortran/check.c:6636
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be TYPE(*)"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:4484 fortran/check.c:4624
+#: fortran/check.c:4487 fortran/check.c:4627
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be an assumed-size array"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:4554
+#: fortran/check.c:4557
 #, gcc-internal-format
 msgid "is_c_interoperable(): gfc_simplify_expr failed"
 msgstr ""
 
-#: fortran/check.c:4603
+#: fortran/check.c:4606
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be an interoperable data entity: %s"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:4642
+#: fortran/check.c:4645
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_1 at %L to C_ASSOCIATED shall have the type TYPE(C_PTR) or TYPE(C_FUNPTR)"
 msgstr ""
 
-#: fortran/check.c:4656
+#: fortran/check.c:4659
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_2 at %L to C_ASSOCIATED shall have the same type as C_PTR_1: %s instead of %s"
 msgstr ""
 
-#: fortran/check.c:4680
+#: fortran/check.c:4683
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_POINTER shall have the type TYPE(C_PTR)"
 msgstr ""
 
-#: fortran/check.c:4692
+#: fortran/check.c:4695
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER must be a pointer"
 msgstr ""
 
-#: fortran/check.c:4699
+#: fortran/check.c:4702
 #, gcc-internal-format, gfc-internal-format
 msgid "FPTR argument at %L to C_F_POINTER shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:4706
+#: fortran/check.c:4709
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:4713
+#: fortran/check.c:4716
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected SHAPE argument at %L to C_F_POINTER with scalar FPTR"
 msgstr ""
 
-#: fortran/check.c:4719
+#: fortran/check.c:4722
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected SHAPE argument to C_F_POINTER with array FPTR at %L"
 msgstr ""
 
-#: fortran/check.c:4738
+#: fortran/check.c:4741
 #, gcc-internal-format, gfc-internal-format
 msgid "SHAPE argument at %L to C_F_POINTER must have the same size as the RANK of FPTR"
 msgstr ""
 
-#: fortran/check.c:4748
+#: fortran/check.c:4751
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic FPTR at %L to C_F_POINTER"
 msgstr ""
 
-#: fortran/check.c:4753
+#: fortran/check.c:4756
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array FPTR at %L to C_F_POINTER: %s"
 msgstr ""
 
-#: fortran/check.c:4769
+#: fortran/check.c:4772
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_PROCPOINTER shall have the type TYPE(C_FUNPTR)"
 msgstr ""
 
-#: fortran/check.c:4781
+#: fortran/check.c:4784
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall be a procedure pointer"
 msgstr ""
 
-#: fortran/check.c:4788
+#: fortran/check.c:4791
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:4794
+#: fortran/check.c:4797
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure pointer at %L to C_F_PROCPOINTER"
 msgstr ""
 
-#: fortran/check.c:4808
+#: fortran/check.c:4811
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:4823
+#: fortran/check.c:4826
 #, gcc-internal-format
 msgid "Function result %qs at %L is invalid as X argument to C_FUNLOC"
 msgstr ""
 
-#: fortran/check.c:4831
+#: fortran/check.c:4834
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall be a procedure or a procedure pointer"
 msgstr ""
 
-#: fortran/check.c:4837
+#: fortran/check.c:4840
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure at %L to C_FUNLOC"
 msgstr ""
 
-#: fortran/check.c:4851
+#: fortran/check.c:4854
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:4857
+#: fortran/check.c:4860
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "X argument at %L to C_LOC shall not be polymorphic"
 msgstr "`%s' の第二引数は `char **' とすべきです"
 
-#: fortran/check.c:4868
+#: fortran/check.c:4871
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall have either the POINTER or the TARGET attribute"
 msgstr ""
 
-#: fortran/check.c:4876
+#: fortran/check.c:4879
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall be not be a zero-sized string"
 msgstr ""
 
-#: fortran/check.c:4885
+#: fortran/check.c:4888
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument at %L to C_LOC shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:4892
+#: fortran/check.c:4895
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array at %L as argument to C_LOC: %s"
 msgstr ""
 
-#: fortran/check.c:4903
+#: fortran/check.c:4906
 #, gcc-internal-format, gfc-internal-format
 msgid "Array of interoperable type at %L to C_LOC which is nonallocatable and neither assumed size nor explicit size"
 msgstr ""
 
-#: fortran/check.c:4908
+#: fortran/check.c:4911
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array section at %L to C_LOC"
 msgstr "セクション属性は `%s' には使えません"
 
-#: fortran/check.c:4936
+#: fortran/check.c:4939
 #, gcc-internal-format, gfc-internal-format
 msgid "non double precision REAL argument to %s intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:4949
+#: fortran/check.c:4952
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be less than rank %d"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:4968
+#: fortran/check.c:4971
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L is not a valid dimension index"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:5231
+#: fortran/check.c:5234
 #, gcc-internal-format, gfc-internal-format
 msgid "%s argument to IMAGE_INDEX must be a rank one array at %L"
 msgstr ""
 
-#: fortran/check.c:5242
+#: fortran/check.c:5245
 #, gcc-internal-format, gfc-internal-format
 msgid "The number of array elements of the SUB argument to IMAGE_INDEX at %L shall be %d (corank) not %d"
 msgstr ""
 
-#: fortran/check.c:5275
+#: fortran/check.c:5278
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to NUM_IMAGES at %L"
 msgstr ""
 
-#: fortran/check.c:5288
+#: fortran/check.c:5291
 #, gcc-internal-format, gfc-internal-format
 msgid "FAILED= argument to NUM_IMAGES at %L"
 msgstr ""
 
-#: fortran/check.c:5312
+#: fortran/check.c:5315
 #, gcc-internal-format, gfc-internal-format
 msgid "TEAM argument at %L to the intrinsic TEAM_NUMBER shall be of type TEAM_TYPE"
 msgstr ""
 
-#: fortran/check.c:5338
+#: fortran/check.c:5341
 #, gcc-internal-format, gfc-internal-format
 msgid "DIM argument without COARRAY argument not allowed for THIS_IMAGE intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:5345
+#: fortran/check.c:5348
 #, gcc-internal-format, gfc-internal-format
 msgid "The DISTANCE argument may not be specified together with the COARRAY or DIM argument in intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:5356
+#: fortran/check.c:5359
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected element '%c' in format string at %L"
 msgid "Unexpected DIM argument with noncoarray argument at %L"
 msgstr "予期しない要素 '%c' が書式文字列内 (位置 %L) にあります"
 
-#: fortran/check.c:5374
+#: fortran/check.c:5377
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to THIS_IMAGE at %L"
 msgstr ""
 
-#: fortran/check.c:5454
+#: fortran/check.c:5457
 #, fuzzy, gcc-internal-format
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L must not be %s"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:5483
+#: fortran/check.c:5486
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic TRANSFER at %L has partly undefined result: source size %ld < result size %ld"
 msgstr ""
 
-#: fortran/check.c:5605
+#: fortran/check.c:5608
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must have the same rank as %qs or be a scalar"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:5618
+#: fortran/check.c:5621
 #, fuzzy, gcc-internal-format
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have identical shape."
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:5861 fortran/check.c:5893
+#: fortran/check.c:5864 fortran/check.c:5896
 #, fuzzy, gcc-internal-format
 msgid "Size of %qs argument of %qs intrinsic at %L too small (%i/%i)"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:5901
+#: fortran/check.c:5904
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Too many arguments to %s at %L"
 msgstr "フォーマットへの引数が多すぎます"
 
-#: fortran/check.c:5919
+#: fortran/check.c:5922
 #, gcc-internal-format
 msgid "fe_runtime_error string must be null terminated"
 msgstr ""
 
-#: fortran/check.c:5931
+#: fortran/check.c:5934
 #, gcc-internal-format, gfc-internal-format
 msgid "fe_runtime_error: Wrong number of arguments (%d instead of %d)"
 msgstr ""
 
-#: fortran/check.c:5971
+#: fortran/check.c:5974
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:5990
+#: fortran/check.c:5993
 #, gcc-internal-format, gfc-internal-format
 msgid "Real COUNT_RATE argument to SYSTEM_CLOCK at %L"
 msgstr ""
 
-#: fortran/check.c:6000
+#: fortran/check.c:6003
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT_RATE argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:6017
+#: fortran/check.c:6020
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT_MAX argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:6234
+#: fortran/check.c:6237
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of a kind not wider than the default kind (%d)"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:6586 fortran/check.c:6594
+#: fortran/check.c:6589 fortran/check.c:6597
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or LOGICAL"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/check.c:6625
+#: fortran/check.c:6628
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic function NULL at %L cannot be an actual argument to STORAGE_SIZE, because it returns a disassociated pointer"
 msgstr ""
@@ -55811,7 +55876,7 @@
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:727 fortran/decl.c:3636 fortran/decl.c:10066
+#: fortran/class.c:727 fortran/decl.c:3655 fortran/decl.c:10091
 #, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr ""
@@ -55836,43 +55901,48 @@
 msgid "non-constant array in DATA statement %L"
 msgstr "初期化子内に非定数の配列インデックスがあります"
 
-#: fortran/data.c:137
+#: fortran/data.c:140
 #, gcc-internal-format, gfc-internal-format
 msgid "failure to simplify substring reference in DATA statement at %L"
 msgstr ""
 
-#: fortran/data.c:170
+#: fortran/data.c:173
 #, gcc-internal-format, gfc-internal-format
 msgid "Unused initialization string at %L because variable has zero length"
 msgstr ""
 
-#: fortran/data.c:176
+#: fortran/data.c:179
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization string at %L was truncated to fit the variable (%ld/%ld)"
 msgstr ""
 
-#: fortran/data.c:265
+#: fortran/data.c:268
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L already is initialized at %L"
 msgstr "配列を仮引数リストによって初期化しようとしています"
 
-#: fortran/data.c:289
+#: fortran/data.c:292
 #, gcc-internal-format, gfc-internal-format
 msgid "Data element below array lower bound at %L"
 msgstr ""
 
-#: fortran/data.c:306 fortran/data.c:395
+#: fortran/data.c:309 fortran/data.c:398
 #, gcc-internal-format, gfc-internal-format
 msgid "Data element above array upper bound at %L"
 msgstr ""
 
-#: fortran/data.c:336 fortran/data.c:505
+#: fortran/data.c:339 fortran/data.c:496
 #, fuzzy, gcc-internal-format
 msgid "re-initialization of %qs at %L"
 msgstr "(`%s' の初期化は不完全です)"
 
-#: fortran/data.c:727
+#: fortran/data.c:515
 #, gcc-internal-format
+msgid "Nonpointer object %qs with default initialization shall not appear in a DATA statement at %L"
+msgstr ""
+
+#: fortran/data.c:738
+#, gcc-internal-format
 msgid "TODO: Vector sections in data statements"
 msgstr ""
 
@@ -55896,796 +55966,795 @@
 msgid "Invalid initializer %s in Data statement at %C"
 msgstr "無効なビット列初期化子です"
 
-#: fortran/decl.c:536
+#: fortran/decl.c:537
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:573
+#: fortran/decl.c:574
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %C cannot appear within an INTERFACE"
 msgstr ""
 
-#: fortran/decl.c:597
+#: fortran/decl.c:598
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid substring in data-implied-do at %L in DATA statement"
 msgstr "無効なビット列初期化子です"
 
-#: fortran/decl.c:619
+#: fortran/decl.c:620
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:664
+#: fortran/decl.c:662
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "empty scalar initializer"
 msgid "Empty old style initializer list at %C"
 msgstr "空のスカラー初期化子です"
 
-#: fortran/decl.c:684
+#: fortran/decl.c:671
 #, fuzzy, gcc-internal-format, gfc-internal-format
+msgid "Array in initializer list at %L must have an explicit shape"
+msgstr "組み込み関数 `%s' は非関数として宣言されました"
+
+#: fortran/decl.c:694
+#, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "extra elements in scalar initializer"
 msgid "Repeat spec invalid in scalar initializer at %C"
 msgstr "スカラー初期化子内に余分な要素があります"
 
-#: fortran/decl.c:689
+#: fortran/decl.c:699
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Repeat spec must be an integer at %C"
 msgstr "述語は識別子でなければなりません"
 
-#: fortran/decl.c:698
+#: fortran/decl.c:710
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected data constant after repeat spec at %C"
 msgstr "ファイル \"%s\" に戻るはずでした"
 
-#: fortran/decl.c:729
+#: fortran/decl.c:742
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "End of scalar initializer expected at %C"
 msgstr "長さ 0 の初期化は推奨されません"
 
-#: fortran/decl.c:758
+#: fortran/decl.c:773
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "nonconstant array index in initializer"
-msgid "Expected constant array-spec in initializer list at %L"
-msgstr "初期化子内に非定数の配列インデックスがあります"
-
-#: fortran/decl.c:767
-#, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "excess elements in array initializer"
 msgid "Not enough elements in array initializer at %C"
 msgstr "配列初期化子内の要素が多すぎます"
 
-#: fortran/decl.c:769
+#: fortran/decl.c:775
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "excess elements in array initializer"
 msgid "Too many elements in array initializer at %C"
 msgstr "配列初期化子内の要素が多すぎます"
 
-#: fortran/decl.c:790
+#: fortran/decl.c:795
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in old style initializer list at %C"
 msgstr "'%s' トークンの所で文法エラー"
 
-#: fortran/decl.c:812
+#: fortran/decl.c:821
 #, gcc-internal-format, gfc-internal-format
 msgid "The assumed-rank array at %C shall not have a codimension"
 msgstr ""
 
-#: fortran/decl.c:876
+#: fortran/decl.c:885
 #, gcc-internal-format, gfc-internal-format
 msgid "Sum of array rank %d and corank %d at %C exceeds maximum allowed dimensions of %d"
 msgstr ""
 
-#: fortran/decl.c:900
+#: fortran/decl.c:909
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad INTENT specification at %C"
 msgstr ""
 
-#: fortran/decl.c:921
+#: fortran/decl.c:930
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "different parameter types"
 msgid "deferred type parameter at %C"
 msgstr "引数の型が異なります"
 
-#: fortran/decl.c:1004 fortran/resolve.c:11705
+#: fortran/decl.c:1013 fortran/resolve.c:11725
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
 
-#: fortran/decl.c:1030
+#: fortran/decl.c:1039
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Old-style character length at %C"
 msgstr "無効な文字定数が #if にあります"
 
-#: fortran/decl.c:1061
+#: fortran/decl.c:1070
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in character length specification at %C"
 msgstr "メソッド仕様内での構文解析エラー"
 
-#: fortran/decl.c:1212 fortran/decl.c:1217 fortran/decl.c:1266
+#: fortran/decl.c:1221 fortran/decl.c:1226 fortran/decl.c:1275
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is already defined in %qT"
 msgid "Procedure %qs at %C is already defined at %L"
 msgstr "%qD は既に %qT 内で定義されています"
 
-#: fortran/decl.c:1222
+#: fortran/decl.c:1231
 #, gcc-internal-format
 msgid "Contained procedure %qs at %C clashes with procedure defined at %L"
 msgstr ""
 
-#: fortran/decl.c:1231
+#: fortran/decl.c:1240
 #, gcc-internal-format
 msgid "Name %qs at %C is already defined as a generic interface at %L"
 msgstr ""
 
-#: fortran/decl.c:1244
+#: fortran/decl.c:1253
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %C has an explicit interface from a previous declaration"
 msgstr "データ領域 '%s' は前の宣言と矛盾します"
 
-#: fortran/decl.c:1257
+#: fortran/decl.c:1266
 #, gcc-internal-format
 msgid "Procedure %qs defined in interface body at %L clashes with internal procedure defined at %C"
 msgstr ""
 
-#: fortran/decl.c:1335
+#: fortran/decl.c:1344
 #, gcc-internal-format
 msgid "Procedure %qs at %L must have the BIND(C) attribute to be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:1362
+#: fortran/decl.c:1371
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because derived type %qs is not C interoperable"
 msgstr ""
 
-#: fortran/decl.c:1369
+#: fortran/decl.c:1378
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because it is polymorphic"
 msgstr ""
 
-#: fortran/decl.c:1376
+#: fortran/decl.c:1385
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument of the BIND(C) procedure %qs but may not be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:1391
+#: fortran/decl.c:1400
 #, gcc-internal-format
 msgid "Character argument %qs at %L must be length 1 because procedure %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1404
+#: fortran/decl.c:1413
 #, gcc-internal-format
 msgid "Variable %qs at %L with ALLOCATABLE attribute in procedure %qs with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1412
+#: fortran/decl.c:1421
 #, gcc-internal-format
 msgid "Variable %qs at %L with POINTER attribute in procedure %qs with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1421
+#: fortran/decl.c:1430
 #, gcc-internal-format
 msgid "Scalar variable %qs at %L with POINTER or ALLOCATABLE in procedure %qs with BIND(C) is not yet supported"
 msgstr ""
 
-#: fortran/decl.c:1430
+#: fortran/decl.c:1439
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the OPTIONAL and the VALUE attribute because procedure %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1437
+#: fortran/decl.c:1446
 #, gcc-internal-format
 msgid "Variable %qs at %L with OPTIONAL attribute in procedure %qs which is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1448
+#: fortran/decl.c:1457
 #, gcc-internal-format
 msgid "Assumed-shape array %qs at %L as dummy argument to the BIND(C) procedure %qs at %L"
 msgstr ""
 
-#: fortran/decl.c:1516
+#: fortran/decl.c:1525
 #, gcc-internal-format
 msgid "Symbol %qs at %C also declared as a type at %L"
 msgstr ""
 
-#: fortran/decl.c:1575
+#: fortran/decl.c:1584
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %C must be declared with a C interoperable kind since common block %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1615
+#: fortran/decl.c:1624
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument must be a constant"
 msgid "CHARACTER length must be a constant at %L"
 msgstr "引数は定数でなければいけません"
 
-#: fortran/decl.c:1630
+#: fortran/decl.c:1639
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression at %L is being truncated (%ld/%ld)"
 msgstr ""
 
-#: fortran/decl.c:1638
+#: fortran/decl.c:1647
 #, gcc-internal-format, gfc-internal-format
 msgid "The CHARACTER elements of the array constructor at %L must have the same length (%ld/%ld)"
 msgstr ""
 
-#: fortran/decl.c:1729
+#: fortran/decl.c:1738
 #, gcc-internal-format
 msgid "Initializer not allowed for PARAMETER %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:1739
+#: fortran/decl.c:1748
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER at %L is missing an initializer"
 msgstr "初期化子を欠いています"
 
-#: fortran/decl.c:1749
+#: fortran/decl.c:1758
 #, gcc-internal-format
 msgid "Variable %qs at %C with an initializer already appears in a DATA statement"
 msgstr ""
 
-#: fortran/decl.c:1792
+#: fortran/decl.c:1801
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot initialize parameter array at %L with variable length elements"
 msgstr ""
 
-#: fortran/decl.c:1861
+#: fortran/decl.c:1870
 #, gcc-internal-format, gfc-internal-format
 msgid "Can't initialize implied-shape array at %L with scalar"
 msgstr ""
 
-#: fortran/decl.c:1896
+#: fortran/decl.c:1905
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-constant lower bound in implied-shape declaration at %L"
 msgstr ""
 
-#: fortran/decl.c:1982 fortran/decl.c:1989
+#: fortran/decl.c:1991 fortran/decl.c:1998
 #, gcc-internal-format, gfc-internal-format
 msgid "Component at %C must have the POINTER attribute"
 msgstr ""
 
-#: fortran/decl.c:1998
+#: fortran/decl.c:2007
 #, gcc-internal-format
 msgid "Component %qs with CLASS at %C must be allocatable or pointer"
 msgstr ""
 
-#: fortran/decl.c:2007
+#: fortran/decl.c:2016
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr ""
 
-#: fortran/decl.c:2031 fortran/symbol.c:2230
+#: fortran/decl.c:2040 fortran/symbol.c:2244
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %C already declared at %L"
 msgstr "シンボルの頭にアンダースコアをつける"
 
-#: fortran/decl.c:2079
+#: fortran/decl.c:2088
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer array component of structure at %C must have a deferred shape"
 msgstr ""
 
-#: fortran/decl.c:2088
+#: fortran/decl.c:2097
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component of structure at %C must have a deferred shape"
 msgstr ""
 
-#: fortran/decl.c:2097
+#: fortran/decl.c:2106
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have an explicit shape"
 msgstr ""
 
-#: fortran/decl.c:2114
+#: fortran/decl.c:2123
 #, gcc-internal-format
 msgid "Type parameter %qs at %C has no corresponding entry in the type parameter name list at %L"
 msgstr ""
 
-#: fortran/decl.c:2171
+#: fortran/decl.c:2180
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C is ambiguous"
 msgstr ""
 
-#: fortran/decl.c:2188
+#: fortran/decl.c:2197
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C may not have MOLD"
 msgstr ""
 
-#: fortran/decl.c:2205
+#: fortran/decl.c:2214
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of pointer at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:2226
+#: fortran/decl.c:2235
 #, gcc-internal-format, gfc-internal-format
 msgid "Error in pointer initialization at %C"
 msgstr ""
 
-#: fortran/decl.c:2233
+#: fortran/decl.c:2242
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "non-NULL pointer initialization at %C"
 msgstr "ANSI C++ は定数でない集合体の初期化子式を禁じます"
 
-#: fortran/decl.c:2256
+#: fortran/decl.c:2265
 #, gcc-internal-format
 msgid "RESULT variable %qs at %L prohibits FUNCTION name %qs at %C from appearing in a specification statement"
 msgstr ""
 
-#: fortran/decl.c:2318
+#: fortran/decl.c:2327
 #, gcc-internal-format
 msgid "%qs not allowed outside STRUCTURE at %C"
 msgstr ""
 
-#: fortran/decl.c:2320
+#: fortran/decl.c:2329
 #, gcc-internal-format
 msgid "%qs at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr ""
 
-#: fortran/decl.c:2327
+#: fortran/decl.c:2336
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "%qs entity cannot have attributes at %C"
 msgstr "%qE 属性は %s 属性と競合します"
 
-#: fortran/decl.c:2367
+#: fortran/decl.c:2376
 #, gcc-internal-format
 msgid "Non-PARAMETER symbol %qs at %L can't be implied-shape"
 msgstr ""
 
-#: fortran/decl.c:2377
+#: fortran/decl.c:2386
 #, gcc-internal-format, gfc-internal-format
 msgid "Implied-shape array at %L"
 msgstr ""
 
-#: fortran/decl.c:2422
+#: fortran/decl.c:2431
 #, gcc-internal-format, gfc-internal-format
 msgid "Explicit shaped array with nonconstant bounds at %C"
 msgstr ""
 
-#: fortran/decl.c:2501
+#: fortran/decl.c:2510
 #, gcc-internal-format
 msgid "%qs at %C is a redefinition of the declaration in the corresponding interface for MODULE PROCEDURE %qs"
 msgstr ""
 
-#: fortran/decl.c:2512
+#: fortran/decl.c:2521
 #, fuzzy, gcc-internal-format
 msgid "%qs entity cannot have an initializer at %C"
 msgstr "`%s' に `extern' と初期化子の両方があります"
 
-#: fortran/decl.c:2538 fortran/decl.c:8369
+#: fortran/decl.c:2547 fortran/decl.c:8388
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr ""
 
-#: fortran/decl.c:2546
+#: fortran/decl.c:2555
 #, gcc-internal-format
 msgid "Couldn't set pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:2609
+#: fortran/decl.c:2618
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Old-style initialization at %C"
 msgstr "重複した初期化子"
 
-#: fortran/decl.c:2617
+#: fortran/decl.c:2626
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr ""
 
-#: fortran/decl.c:2630
+#: fortran/decl.c:2639
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in old style initialization of %s at %C"
 msgstr "メソッド仕様内での構文解析エラー"
 
-#: fortran/decl.c:2650 fortran/decl.c:6661
+#: fortran/decl.c:2659 fortran/decl.c:6680
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr ""
 
-#: fortran/decl.c:2663
+#: fortran/decl.c:2672
 #, gcc-internal-format
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr ""
 
-#: fortran/decl.c:2672 fortran/decl.c:10240
+#: fortran/decl.c:2681 fortran/decl.c:10265
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr "長さ 0 の初期化は推奨されません"
 
-#: fortran/decl.c:2679
+#: fortran/decl.c:2688
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:2696
+#: fortran/decl.c:2705
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr ""
 
-#: fortran/decl.c:2710
+#: fortran/decl.c:2719
 #, gcc-internal-format, gfc-internal-format
 msgid "The component with KIND or LEN attribute at %C does not not appear in the type parameter list at %L"
 msgstr ""
 
-#: fortran/decl.c:2718
+#: fortran/decl.c:2727
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C that appears in the type parameter list at %L has neither the KIND nor LEN attribute"
 msgstr ""
 
-#: fortran/decl.c:2726
+#: fortran/decl.c:2735
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C which is a type parameter must be a scalar"
 msgstr ""
 
-#: fortran/decl.c:2789 fortran/decl.c:2825
+#: fortran/decl.c:2798 fortran/decl.c:2834
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr "-traditional は C++ では受け付けられません"
 
-#: fortran/decl.c:2831
+#: fortran/decl.c:2840
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr "`%s' の extern 宣言がネストしています"
 
-#: fortran/decl.c:2890 fortran/decl.c:2967
+#: fortran/decl.c:2899 fortran/decl.c:2976
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis at %C"
 msgstr "正式な仮引数項を欠いています"
 
-#: fortran/decl.c:2903 fortran/decl.c:3038
+#: fortran/decl.c:2912 fortran/decl.c:3047
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr "長さ 0 の初期化は推奨されません"
 
-#: fortran/decl.c:2911 fortran/decl.c:3044
+#: fortran/decl.c:2920 fortran/decl.c:3053
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr "長さ 0 の初期化は推奨されません"
 
-#: fortran/decl.c:2941 fortran/decl.c:3657
+#: fortran/decl.c:2950 fortran/decl.c:3676
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr "VAX 浮動小数では丸めモードを利用できません"
 
-#: fortran/decl.c:2954
+#: fortran/decl.c:2963
 #, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr ""
 
-#: fortran/decl.c:2965
+#: fortran/decl.c:2974
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr ""
 
-#: fortran/decl.c:3070
+#: fortran/decl.c:3079
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr "VAX 浮動小数では丸めモードを利用できません"
 
-#: fortran/decl.c:3202
+#: fortran/decl.c:3211
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:3291
+#: fortran/decl.c:3310
 #, gcc-internal-format, gfc-internal-format
 msgid "RECORD at %C is an extension, enable it with -fdec-structure"
 msgstr ""
 
-#: fortran/decl.c:3304
+#: fortran/decl.c:3323
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected after RECORD at %C"
 msgstr ""
 
-#: fortran/decl.c:3417
+#: fortran/decl.c:3436
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C cannot contain both ASSUMED and DEFERRED parameters"
 msgstr ""
 
-#: fortran/decl.c:3441
+#: fortran/decl.c:3460
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C does not contain enough parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3465
+#: fortran/decl.c:3484
 #, fuzzy, gcc-internal-format
 #| msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgid "The derived parameter %qs at %C does not have a default value"
 msgstr "%<operator new%> の第一引数はデフォルト引数を持っていてはいけません"
 
-#: fortran/decl.c:3497
+#: fortran/decl.c:3516
 #, gcc-internal-format, gfc-internal-format
 msgid "The parameter expression at %C must be of INTEGER type and not %s type"
 msgstr ""
 
-#: fortran/decl.c:3525
+#: fortran/decl.c:3544
 #, gcc-internal-format
 msgid "The KIND parameter %qs at %C cannot either be ASSUMED or DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:3532
+#: fortran/decl.c:3551
 #, fuzzy, gcc-internal-format
 msgid "The value for the KIND parameter %qs at %C does not reduce to a constant expression"
 msgstr "%qE の列挙値が整数定数式ではありません"
 
-#: fortran/decl.c:3547
+#: fortran/decl.c:3566
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C contains too many parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3556
+#: fortran/decl.c:3575
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Parameterized derived type at %C is ambiguous"
 msgstr "%s: オプション `%s' はあいまいです\n"
 
-#: fortran/decl.c:3819
+#: fortran/decl.c:3838
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type at %C"
 msgstr ""
 
-#: fortran/decl.c:3824
+#: fortran/decl.c:3843
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr ""
 
-#: fortran/decl.c:3846
+#: fortran/decl.c:3865
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C is not allowed for components"
 msgstr ""
 
-#: fortran/decl.c:3849
+#: fortran/decl.c:3868
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr ""
 
-#: fortran/decl.c:3872 fortran/decl.c:3903 fortran/decl.c:3932
-#: fortran/decl.c:4216
+#: fortran/decl.c:3891 fortran/decl.c:3922 fortran/decl.c:3951
+#: fortran/decl.c:4235
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr ""
 
-#: fortran/decl.c:3928
+#: fortran/decl.c:3947
 #, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr ""
 
-#: fortran/decl.c:3971 fortran/decl.c:4107 fortran/decl.c:4119
-#: fortran/decl.c:4133 fortran/decl.c:4611 fortran/decl.c:4619
+#: fortran/decl.c:3990 fortran/decl.c:4126 fortran/decl.c:4138
+#: fortran/decl.c:4152 fortran/decl.c:4630 fortran/decl.c:4638
 #, fuzzy, gcc-internal-format
 msgid "Type name %qs at %C is ambiguous"
 msgstr "%s: オプション `%s' はあいまいです\n"
 
-#: fortran/decl.c:4066
+#: fortran/decl.c:4085
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CLASS statement at %C"
 msgstr "'%s' トークンの所で文法エラー"
 
-#: fortran/decl.c:4148
+#: fortran/decl.c:4167
 #, gcc-internal-format
 msgid "Type name %qs at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr ""
 
-#: fortran/decl.c:4287
+#: fortran/decl.c:4306
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4296
+#: fortran/decl.c:4315
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr ""
 
-#: fortran/decl.c:4355
+#: fortran/decl.c:4374
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr ""
 
-#: fortran/decl.c:4401
+#: fortran/decl.c:4420
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4454
+#: fortran/decl.c:4473
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr ""
 
-#: fortran/decl.c:4464
+#: fortran/decl.c:4483
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4570
+#: fortran/decl.c:4589
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr ""
 
-#: fortran/decl.c:4577
+#: fortran/decl.c:4596
 #, gcc-internal-format, gfc-internal-format
 msgid "F2008: C1210 IMPORT statement at %C is not permitted in a module procedure interface body"
 msgstr ""
 
-#: fortran/decl.c:4582
+#: fortran/decl.c:4601
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4596
+#: fortran/decl.c:4615
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr ""
 
-#: fortran/decl.c:4625
+#: fortran/decl.c:4644
 #, gcc-internal-format
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr ""
 
-#: fortran/decl.c:4632
+#: fortran/decl.c:4651
 #, gcc-internal-format
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr ""
 
-#: fortran/decl.c:4673
+#: fortran/decl.c:4692
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IMPORT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5010
+#: fortran/decl.c:5029
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing codimension specification at %C"
 msgstr ""
 
-#: fortran/decl.c:5012
+#: fortran/decl.c:5031
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr ""
 
-#: fortran/decl.c:5107
+#: fortran/decl.c:5126
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr "定義の後で `%s' 属性をセットすることはできません"
 
-#: fortran/decl.c:5124
+#: fortran/decl.c:5143
 #, gcc-internal-format
 msgid "%s at %L is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:5141
+#: fortran/decl.c:5160
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5150
+#: fortran/decl.c:5169
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ignoring attributes applied to %qT after definition"
 msgid "KIND attribute at %C in a TYPE definition"
 msgstr "定義した後に %qT に適用される属性を無視しています"
 
-#: fortran/decl.c:5158
+#: fortran/decl.c:5177
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be INTEGER"
 msgstr ""
 
-#: fortran/decl.c:5165
+#: fortran/decl.c:5184
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5174
+#: fortran/decl.c:5193
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "can%'t set %qE attribute after definition"
 msgid "LEN attribute at %C in a TYPE definition"
 msgstr "定義の後に %qE 属性を設定できません"
 
-#: fortran/decl.c:5182
+#: fortran/decl.c:5201
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be INTEGER"
 msgstr ""
 
-#: fortran/decl.c:5189
+#: fortran/decl.c:5208
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5198
+#: fortran/decl.c:5217
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5216
+#: fortran/decl.c:5235
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr "大域 register 変数が関数定義の後ろにあります"
 
-#: fortran/decl.c:5226
+#: fortran/decl.c:5245
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:5236
+#: fortran/decl.c:5255
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed outside a TYPE definition"
 msgstr "大域 register 変数が関数定義の後ろにあります"
 
-#: fortran/decl.c:5249
+#: fortran/decl.c:5268
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5260
+#: fortran/decl.c:5279
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5315 fortran/decl.c:8673
+#: fortran/decl.c:5334 fortran/decl.c:8692
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:5321
+#: fortran/decl.c:5340
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute at %C"
 msgstr "定義の後で `%s' 属性をセットすることはできません"
 
-#: fortran/decl.c:5355
+#: fortran/decl.c:5374
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VALUE attribute at %C"
 msgstr "定義の後で `%s' 属性をセットすることはできません"
 
-#: fortran/decl.c:5362
+#: fortran/decl.c:5381
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5369
+#: fortran/decl.c:5388
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr ""
 
-#: fortran/decl.c:5410
+#: fortran/decl.c:5429
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:5508
+#: fortran/decl.c:5527
 #, gcc-internal-format
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:5530
+#: fortran/decl.c:5549
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5539
+#: fortran/decl.c:5558
 #, gcc-internal-format
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5543
+#: fortran/decl.c:5562
 #, gcc-internal-format
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5555
+#: fortran/decl.c:5574
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr ""
 
-#: fortran/decl.c:5569
+#: fortran/decl.c:5588
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr ""
 
-#: fortran/decl.c:5577
+#: fortran/decl.c:5596
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr ""
 
-#: fortran/decl.c:5589
+#: fortran/decl.c:5608
 #, fuzzy, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr "FPU レジスタ内の機能の値を返す"
 
-#: fortran/decl.c:5597
+#: fortran/decl.c:5616
 #, fuzzy, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be a character string"
 msgstr "FPU レジスタ内の機能の値を返す"
@@ -56692,964 +56761,969 @@
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:5608
+#: fortran/decl.c:5627
 #, gcc-internal-format
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr ""
 
-#: fortran/decl.c:5682
+#: fortran/decl.c:5701
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5727
+#: fortran/decl.c:5746
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5734
+#: fortran/decl.c:5753
 #, fuzzy, gcc-internal-format
 #| msgid "missing number"
 msgid "Missing symbol"
 msgstr "数値がありません"
 
-#: fortran/decl.c:5763
+#: fortran/decl.c:5782
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5850
+#: fortran/decl.c:5869
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr ""
 
-#: fortran/decl.c:5892
+#: fortran/decl.c:5911
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in anonymous structure declaration at %C"
 msgstr "`%s' の宣言に二つ以上のデータ型が指定されました"
 
-#: fortran/decl.c:5901
+#: fortran/decl.c:5920
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr "`%s' の宣言に二つ以上のデータ型が指定されました"
 
-#: fortran/decl.c:5951
+#: fortran/decl.c:5970
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C"
 msgstr ""
 
-#: fortran/decl.c:5996
+#: fortran/decl.c:6015
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IMPURE procedure at %C"
 msgstr "不明なレジスタ名です: %s"
 
-#: fortran/decl.c:6008
+#: fortran/decl.c:6027
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr ""
 
-#: fortran/decl.c:6054
+#: fortran/decl.c:6073
 #, gcc-internal-format, gfc-internal-format
 msgid "ELEMENTAL prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6061
+#: fortran/decl.c:6080
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6068
+#: fortran/decl.c:6087
 #, gcc-internal-format, gfc-internal-format
 msgid "RECURSIVE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6134 fortran/primary.c:1820
+#: fortran/decl.c:6153 fortran/primary.c:1820
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Alternate-return argument at %C"
 msgstr "ファイル \"%s\" に戻るはずでした"
 
-#: fortran/decl.c:6140 fortran/decl.c:6148
+#: fortran/decl.c:6159 fortran/decl.c:6167
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "parameter name omitted"
 msgid "A parameter name is required at %C"
 msgstr "仮引数名が省略されています"
 
-#: fortran/decl.c:6188
+#: fortran/decl.c:6207
 #, fuzzy, gcc-internal-format
 msgid "Name %qs at %C is the name of the procedure"
 msgstr "プロシージャ開始と終了のスケジュールを行なわない"
 
-#: fortran/decl.c:6201
+#: fortran/decl.c:6220
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected parameter list in type declaration at %C"
 msgstr "配列の次元を宣言で指定することはできません"
 
-#: fortran/decl.c:6204
+#: fortran/decl.c:6223
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr ""
 
-#: fortran/decl.c:6222
+#: fortran/decl.c:6241
 #, fuzzy, gcc-internal-format
 #| msgid "parameter name missing from parameter list"
 msgid "Duplicate name %qs in parameter list at %C"
 msgstr "仮引数リストに仮引数名がありません"
 
-#: fortran/decl.c:6225
+#: fortran/decl.c:6244
 #, fuzzy, gcc-internal-format
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr "%s: オプション `%s' には引数が必要です\n"
 
-#: fortran/decl.c:6264
+#: fortran/decl.c:6283
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in MODULE PROCEDURE formal argument names (%s/%s) at %C"
 msgstr ""
 
-#: fortran/decl.c:6270
+#: fortran/decl.c:6289
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in number of MODULE PROCEDURE formal arguments at %C"
 msgstr ""
 
-#: fortran/decl.c:6309
+#: fortran/decl.c:6328
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr ""
 
-#: fortran/decl.c:6386
+#: fortran/decl.c:6405
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr "`%s' の extern 宣言がネストしています"
 
-#: fortran/decl.c:6396 fortran/decl.c:7494
+#: fortran/decl.c:6415 fortran/decl.c:7513
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr "section 属性はローカル変数に対しては指定できません"
 
-#: fortran/decl.c:6600
+#: fortran/decl.c:6619
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:6607
+#: fortran/decl.c:6626
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:6613
+#: fortran/decl.c:6632
 #, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr ""
 
-#: fortran/decl.c:6636
+#: fortran/decl.c:6655
 #, gcc-internal-format
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr ""
 
-#: fortran/decl.c:6682 fortran/decl.c:6870 fortran/decl.c:10723
+#: fortran/decl.c:6701 fortran/decl.c:6889 fortran/decl.c:10748
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6731 fortran/decl.c:10623
+#: fortran/decl.c:6750 fortran/decl.c:10648
 #, fuzzy, gcc-internal-format
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr "行番号 %u に戻るはずでした"
 
-#: fortran/decl.c:6738
+#: fortran/decl.c:6757
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr ""
 
-#: fortran/decl.c:6742
+#: fortran/decl.c:6761
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component at %C"
 msgstr "代入として無効な左辺値です"
 
-#: fortran/decl.c:6814
+#: fortran/decl.c:6833
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:6832
+#: fortran/decl.c:6851
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr ""
 
-#: fortran/decl.c:6841 fortran/decl.c:9392
+#: fortran/decl.c:6860 fortran/decl.c:9411
 #, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr ""
 
-#: fortran/decl.c:6911
+#: fortran/decl.c:6930
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6983
+#: fortran/decl.c:7002
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr ""
 
-#: fortran/decl.c:7007 fortran/decl.c:7011 fortran/decl.c:7266
-#: fortran/decl.c:7270 fortran/decl.c:7462 fortran/decl.c:7466
-#: fortran/symbol.c:1875
+#: fortran/decl.c:7026 fortran/decl.c:7030 fortran/decl.c:7285
+#: fortran/decl.c:7289 fortran/decl.c:7481 fortran/decl.c:7485
+#: fortran/symbol.c:1889
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr ""
 
-#: fortran/decl.c:7164
+#: fortran/decl.c:7183
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "in statement"
 msgid "ENTRY statement at %C"
 msgstr "式内"
 
-#: fortran/decl.c:7173
+#: fortran/decl.c:7192
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr ""
 
-#: fortran/decl.c:7176
+#: fortran/decl.c:7195
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr ""
 
-#: fortran/decl.c:7179
+#: fortran/decl.c:7198
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SUBMODULE"
 msgstr ""
 
-#: fortran/decl.c:7182
+#: fortran/decl.c:7201
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr ""
 
-#: fortran/decl.c:7186 fortran/decl.c:7231
+#: fortran/decl.c:7205 fortran/decl.c:7250
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr ""
 
-#: fortran/decl.c:7190
+#: fortran/decl.c:7209
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a STRUCTURE block"
 msgstr ""
 
-#: fortran/decl.c:7194
+#: fortran/decl.c:7213
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr ""
 
-#: fortran/decl.c:7198
+#: fortran/decl.c:7217
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr ""
 
-#: fortran/decl.c:7203
+#: fortran/decl.c:7222
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr ""
 
-#: fortran/decl.c:7207
+#: fortran/decl.c:7226
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr ""
 
-#: fortran/decl.c:7211
+#: fortran/decl.c:7230
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr ""
 
-#: fortran/decl.c:7215
+#: fortran/decl.c:7234
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr ""
 
-#: fortran/decl.c:7219
+#: fortran/decl.c:7238
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr ""
 
-#: fortran/decl.c:7223
+#: fortran/decl.c:7242
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "expected statement"
 msgid "Unexpected ENTRY statement at %C"
 msgstr "文が予期されます"
 
-#: fortran/decl.c:7244
+#: fortran/decl.c:7263
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr ""
 
-#: fortran/decl.c:7295 fortran/decl.c:7501
+#: fortran/decl.c:7314 fortran/decl.c:7520
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7563 fortran/decl.c:7570
+#: fortran/decl.c:7582 fortran/decl.c:7589
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr "無効なビット列初期化子です"
 
-#: fortran/decl.c:7610
+#: fortran/decl.c:7629
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr ""
 
-#: fortran/decl.c:7626
+#: fortran/decl.c:7645
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: fortran/decl.c:7634
+#: fortran/decl.c:7653
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr ""
 
-#: fortran/decl.c:7653
+#: fortran/decl.c:7672
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing closing paren for binding label at %C"
 msgstr ""
 
-#: fortran/decl.c:7659
+#: fortran/decl.c:7678
 #, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7665
+#: fortran/decl.c:7684
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7694
+#: fortran/decl.c:7713
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr ""
 
-#: fortran/decl.c:7939
+#: fortran/decl.c:7958
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7948
+#: fortran/decl.c:7967
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "END statement instead of %s statement at %L"
 msgstr "'%s' トークンの所で文法エラー"
 
 #. We would have required END [something].
-#: fortran/decl.c:7957
+#: fortran/decl.c:7976
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr ""
 
-#: fortran/decl.c:7968
+#: fortran/decl.c:7987
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s statement at %L"
 msgstr "式文が無効です"
 
-#: fortran/decl.c:7988
+#: fortran/decl.c:8007
 #, fuzzy, gcc-internal-format
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr "switch 文の中でラベル `%s' が重複しています"
 
-#: fortran/decl.c:8005
+#: fortran/decl.c:8024
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr "行番号 %u に戻るはずでした"
 
-#: fortran/decl.c:8019 fortran/decl.c:8027
+#: fortran/decl.c:8038 fortran/decl.c:8046
 #, fuzzy, gcc-internal-format
 msgid "Expected label %qs for %s statement at %C"
 msgstr "switch 文の中でラベル `%s' が重複しています"
 
-#: fortran/decl.c:8126
+#: fortran/decl.c:8145
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr ""
 
-#: fortran/decl.c:8134
+#: fortran/decl.c:8153
 #, gcc-internal-format, gfc-internal-format
 msgid "Dimensions specified for %s at %L after its initialization"
 msgstr ""
 
-#: fortran/decl.c:8142
+#: fortran/decl.c:8161
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr ""
 
-#: fortran/decl.c:8151
+#: fortran/decl.c:8170
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr ""
 
-#: fortran/decl.c:8249
+#: fortran/decl.c:8268
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr ""
 
-#: fortran/decl.c:8286
+#: fortran/decl.c:8305
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<(%>"
 msgid "Expected %<(%> at %C"
 msgstr "%<(%> が予期されます"
 
-#: fortran/decl.c:8300 fortran/decl.c:8340
+#: fortran/decl.c:8319 fortran/decl.c:8359
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr ""
 
-#: fortran/decl.c:8316
+#: fortran/decl.c:8335
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C must be an integer"
 msgstr "述語は識別子でなければなりません"
 
-#: fortran/decl.c:8320
+#: fortran/decl.c:8339
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr ""
 
-#: fortran/decl.c:8326
+#: fortran/decl.c:8345
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr ""
 
-#: fortran/decl.c:8365
+#: fortran/decl.c:8384
 #, gcc-internal-format
 msgid "Couldn't set Cray pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:8389
+#: fortran/decl.c:8408
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr ""
 
-#: fortran/decl.c:8401
+#: fortran/decl.c:8420
 #, fuzzy, gcc-internal-format
 msgid "Expected %<,%> or end of statement at %C"
 msgstr "switch 文の中でラベル `%s' が重複しています"
 
-#: fortran/decl.c:8427
+#: fortran/decl.c:8446
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:8459
+#: fortran/decl.c:8478
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:8478
+#: fortran/decl.c:8497
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer declaration at %C requires -fcray-pointer flag"
 msgstr ""
 
-#: fortran/decl.c:8517
+#: fortran/decl.c:8536
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8623
+#: fortran/decl.c:8642
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:8640
+#: fortran/decl.c:8659
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:8679
+#: fortran/decl.c:8698
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8717
+#: fortran/decl.c:8736
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8741
+#: fortran/decl.c:8760
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:8778
+#: fortran/decl.c:8797
 #, gcc-internal-format, gfc-internal-format
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:8806
+#: fortran/decl.c:8825
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr ""
 
-#: fortran/decl.c:8813
+#: fortran/decl.c:8832
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8819
+#: fortran/decl.c:8838
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr ""
 
-#: fortran/decl.c:8839
+#: fortran/decl.c:8858
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Initializing already initialized variable at %C"
 msgstr "配列を仮引数リストによって初期化しようとしています"
 
 #. With legacy PARAMETER statements, don't expect a terminating ')'.
-#: fortran/decl.c:8864
+#: fortran/decl.c:8883
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER without '()' at %C"
 msgstr ""
 
-#: fortran/decl.c:8880
+#: fortran/decl.c:8899
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8899 fortran/decl.c:8955
+#: fortran/decl.c:8918 fortran/decl.c:8974
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:8934
+#: fortran/decl.c:8953
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in AUTOMATIC statement at %C"
 msgstr "式文が無効です"
 
-#: fortran/decl.c:8941
+#: fortran/decl.c:8960
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in AUTOMATIC statement at %C"
 msgstr "'%s' トークンの所で文法エラー"
 
-#: fortran/decl.c:8990
+#: fortran/decl.c:9009
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in STATIC statement at %C"
 msgstr "式文が無効です"
 
-#: fortran/decl.c:8997
+#: fortran/decl.c:9016
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in STATIC statement at %C"
 msgstr "'%s' トークンの所で文法エラー"
 
-#: fortran/decl.c:9016
+#: fortran/decl.c:9035
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:9027
+#: fortran/decl.c:9046
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:9073
+#: fortran/decl.c:9092
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9087
+#: fortran/decl.c:9106
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:9091
+#: fortran/decl.c:9110
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "in statement"
 msgid "VALUE statement at %C"
 msgstr "式内"
 
-#: fortran/decl.c:9129
+#: fortran/decl.c:9148
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VALUE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9141
+#: fortran/decl.c:9160
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9168
+#: fortran/decl.c:9187
 #, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr ""
 
-#: fortran/decl.c:9193
+#: fortran/decl.c:9212
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9205
+#: fortran/decl.c:9224
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9249
+#: fortran/decl.c:9268
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9274
+#: fortran/decl.c:9293
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:9367
+#: fortran/decl.c:9386
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr ""
 
-#: fortran/decl.c:9425
+#: fortran/decl.c:9444
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr ""
 
-#: fortran/decl.c:9474
+#: fortran/decl.c:9493
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr ""
 
-#: fortran/decl.c:9483
+#: fortran/decl.c:9502
 #, gcc-internal-format
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr ""
 
-#: fortran/decl.c:9489
+#: fortran/decl.c:9508
 #, gcc-internal-format
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr ""
 
-#: fortran/decl.c:9496
+#: fortran/decl.c:9515
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:9503
+#: fortran/decl.c:9522
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr ""
 
-#: fortran/decl.c:9526
+#: fortran/decl.c:9545
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:9538
+#: fortran/decl.c:9557
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:9559
+#: fortran/decl.c:9578
 #, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
 msgstr ""
 
-#: fortran/decl.c:9605
+#: fortran/decl.c:9624
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "failed to close read state file %s [%s]"
 msgid "Failed to create structure type '%s' at %C"
 msgstr "読み込んだ状態ファイル %s を閉じるのに失敗しました [%s]"
 
-#: fortran/decl.c:9611
+#: fortran/decl.c:9630
 #, gcc-internal-format
 msgid "Type definition of %qs at %C was already defined at %L"
 msgstr ""
 
-#: fortran/decl.c:9658
+#: fortran/decl.c:9677
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Junk after MAP statement at %C"
 msgstr "'%s' トークンの所で文法エラー"
 
-#: fortran/decl.c:9691
+#: fortran/decl.c:9710
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Junk after UNION statement at %C"
 msgstr "'%s' トークンの所で文法エラー"
 
-#: fortran/decl.c:9726
+#: fortran/decl.c:9745
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr ""
 
-#: fortran/decl.c:9740
+#: fortran/decl.c:9759
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected in non-nested structure declaration at %C"
 msgstr "`%s' の extern 宣言がネストしています"
 
-#: fortran/decl.c:9758
+#: fortran/decl.c:9777
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after non-nested STRUCTURE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9765
+#: fortran/decl.c:9784
 #, fuzzy, gcc-internal-format
 msgid "Structure name %qs at %C cannot be the same as an intrinsic type"
 msgstr "関数を inline にできません"
 
-#: fortran/decl.c:9926
+#: fortran/decl.c:9947
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr ""
 
-#: fortran/decl.c:9954
+#: fortran/decl.c:9975
 #, fuzzy, gcc-internal-format
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr "\"%s\" は C++ の演算子であり、マクロ名として使用することはできません"
 
-#: fortran/decl.c:9964
+#: fortran/decl.c:9986
 #, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr ""
 
-#: fortran/decl.c:9981
+#: fortran/decl.c:9989
 #, fuzzy, gcc-internal-format
+msgid "Derived type name %qs at %C already has a basic type"
+msgstr "\"%s\" は C++ の演算子であり、マクロ名として使用することはできません"
+
+#: fortran/decl.c:10006
+#, fuzzy, gcc-internal-format
 #| msgid "%qD has already been defined"
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr "%qD は既に定義されています"
 
-#: fortran/decl.c:10042
+#: fortran/decl.c:10067
 #, gcc-internal-format, gfc-internal-format
 msgid "Garbage after PARAMETERIZED TYPE declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:10126
+#: fortran/decl.c:10151
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr ""
 
-#: fortran/decl.c:10146
+#: fortran/decl.c:10171
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM and ENUMERATOR at %C"
 msgstr ""
 
-#: fortran/decl.c:10178
+#: fortran/decl.c:10203
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr "反復子 `%s' は非整数型です"
 
-#: fortran/decl.c:10257
+#: fortran/decl.c:10282
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr ""
 
-#: fortran/decl.c:10305
+#: fortran/decl.c:10330
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr "`*' の前に型の名前があるべきです"
 
-#: fortran/decl.c:10341
+#: fortran/decl.c:10366
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr ""
 
-#: fortran/decl.c:10388 fortran/decl.c:10403
+#: fortran/decl.c:10413 fortran/decl.c:10428
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate access-specifier at %C"
 msgstr "重複するアクセス指定子"
 
-#: fortran/decl.c:10423
+#: fortran/decl.c:10448
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10443
+#: fortran/decl.c:10468
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10470
+#: fortran/decl.c:10495
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:10488
+#: fortran/decl.c:10513
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr ""
 
-#: fortran/decl.c:10504
+#: fortran/decl.c:10529
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DEFERRED at %C"
 msgstr ""
 
-#: fortran/decl.c:10517
+#: fortran/decl.c:10542
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected access-specifier at %C"
 msgstr "重複するアクセス指定子"
 
-#: fortran/decl.c:10519
+#: fortran/decl.c:10544
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:10527
+#: fortran/decl.c:10552
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED can't both appear at %C"
 msgstr ""
 
-#: fortran/decl.c:10539
+#: fortran/decl.c:10564
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:10581
+#: fortran/decl.c:10606
 #, fuzzy, gcc-internal-format
 msgid "Interface-name expected after %<(%> at %C"
 msgstr "識別子が必要です"
 
-#: fortran/decl.c:10587
+#: fortran/decl.c:10612
 #, fuzzy, gcc-internal-format
 msgid "%<)%> expected at %C"
 msgstr "')' が必要です"
 
-#: fortran/decl.c:10607
+#: fortran/decl.c:10632
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:10612
+#: fortran/decl.c:10637
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:10635
+#: fortran/decl.c:10660
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr ""
 
-#: fortran/decl.c:10639
+#: fortran/decl.c:10664
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
 msgstr ""
 
-#: fortran/decl.c:10651
+#: fortran/decl.c:10676
 #, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:10657
+#: fortran/decl.c:10682
 #, gcc-internal-format
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr ""
 
-#: fortran/decl.c:10667
+#: fortran/decl.c:10692
 #, fuzzy, gcc-internal-format
 msgid "Expected binding target after %<=>%> at %C"
 msgstr "行番号 %u に戻るはずでした"
 
-#: fortran/decl.c:10684
+#: fortran/decl.c:10709
 #, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr ""
 
-#: fortran/decl.c:10695
+#: fortran/decl.c:10720
 #, gcc-internal-format
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:10746
+#: fortran/decl.c:10771
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr ""
 
-#: fortran/decl.c:10766
+#: fortran/decl.c:10791
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<::%>"
 msgid "Expected %<::%> at %C"
 msgstr "%<::%> が予期されます"
 
-#: fortran/decl.c:10778
+#: fortran/decl.c:10803
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected generic name or operator descriptor at %C"
 msgstr ""
 
-#: fortran/decl.c:10799
+#: fortran/decl.c:10824
 #, gcc-internal-format, gfc-internal-format
 msgid "Malformed GENERIC statement at %C"
 msgstr ""
 
-#: fortran/decl.c:10810
+#: fortran/decl.c:10835
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<=%>"
 msgid "Expected %<=>%> at %C"
 msgstr "%<=%> が予期されます"
 
-#: fortran/decl.c:10846
+#: fortran/decl.c:10871
 #, gcc-internal-format
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:10854
+#: fortran/decl.c:10879
 #, gcc-internal-format
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr ""
 
-#: fortran/decl.c:10902
+#: fortran/decl.c:10927
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr ""
 
-#: fortran/decl.c:10912
+#: fortran/decl.c:10937
 #, gcc-internal-format
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:10930
+#: fortran/decl.c:10955
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr ""
 
-#: fortran/decl.c:10965
+#: fortran/decl.c:10990
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr ""
 
-#: fortran/decl.c:10976
+#: fortran/decl.c:11001
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr ""
 
-#: fortran/decl.c:10998
+#: fortran/decl.c:11023
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr ""
 
-#: fortran/decl.c:11005
+#: fortran/decl.c:11030
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr ""
 
-#: fortran/decl.c:11015
+#: fortran/decl.c:11040
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>"
 msgid "Expected %<,%> at %C"
 msgstr "%<,%> が予期されます"
 
-#: fortran/decl.c:11021
+#: fortran/decl.c:11046
 #, fuzzy, gcc-internal-format
 msgid "Unknown procedure name %qs at %C"
 msgstr "不明なレジスタ名です: %s"
 
-#: fortran/decl.c:11034
+#: fortran/decl.c:11059
 #, fuzzy, gcc-internal-format
 msgid "%qs at %C is already defined as FINAL procedure"
 msgstr "プロシージャ開始と終了のスケジュールを行なわない"
 
-#: fortran/decl.c:11104
+#: fortran/decl.c:11129
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr ""
 
-#: fortran/decl.c:11150
+#: fortran/decl.c:11175
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr ""
 
-#: fortran/decl.c:11170
+#: fortran/decl.c:11195
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive requires a non-negative integral constant less than or equal to %u at %C"
 msgstr ""
 
-#: fortran/decl.c:11184
+#: fortran/decl.c:11209
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ UNROLL directive at %C"
 msgstr "`%s' の宣言に二つ以上のデータ型が指定されました"
@@ -57985,27 +58059,27 @@
 msgid "BOZ literal at %L used to initialize non-integer variable %qs"
 msgstr ""
 
-#: fortran/expr.c:3369 fortran/resolve.c:10197
+#: fortran/expr.c:3369 fortran/resolve.c:10210
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal at %L outside a DATA statement and outside INT/REAL/DBLE/CMPLX"
 msgstr ""
 
-#: fortran/expr.c:3380 fortran/resolve.c:10208
+#: fortran/expr.c:3380 fortran/resolve.c:10221
 #, gcc-internal-format
 msgid "BOZ literal at %L is bitwise transferred non-integer symbol %qs"
 msgstr ""
 
-#: fortran/expr.c:3388 fortran/resolve.c:10217
+#: fortran/expr.c:3388 fortran/resolve.c:10230
 #, gcc-internal-format
 msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3392 fortran/resolve.c:10221
+#: fortran/expr.c:3392 fortran/resolve.c:10234
 #, gcc-internal-format
 msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3396 fortran/resolve.c:10225
+#: fortran/expr.c:3396 fortran/resolve.c:10238
 #, gcc-internal-format
 msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
@@ -58015,147 +58089,147 @@
 msgid "The assignment to a KIND or LEN component of a parameterized type at %L is not allowed"
 msgstr ""
 
-#: fortran/expr.c:3426
+#: fortran/expr.c:3429
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible types in DATA statement at %L; attempted conversion of %s to %s"
 msgstr ""
 
-#: fortran/expr.c:3465
+#: fortran/expr.c:3468
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is not a POINTER at %L"
 msgstr ""
 
-#: fortran/expr.c:3473
+#: fortran/expr.c:3476
 #, gcc-internal-format
 msgid "%qs in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgstr ""
 
-#: fortran/expr.c:3496
+#: fortran/expr.c:3499
 #, fuzzy, gcc-internal-format
 msgid "Expected bounds specification for %qs at %L"
 msgstr "キャストは関数型を指定しています"
 
-#: fortran/expr.c:3501
+#: fortran/expr.c:3504
 #, fuzzy, gcc-internal-format
 msgid "Bounds specification for %qs in pointer assignment at %L"
 msgstr "代入として無効な左辺値です"
 
-#: fortran/expr.c:3514
+#: fortran/expr.c:3517
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower bound has to be present at %L"
 msgstr ""
 
-#: fortran/expr.c:3520
+#: fortran/expr.c:3523
 #, gcc-internal-format, gfc-internal-format
 msgid "Stride must not be present at %L"
 msgstr ""
 
-#: fortran/expr.c:3532
+#: fortran/expr.c:3535
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the upper bounds must be specified at %L"
 msgstr ""
 
-#: fortran/expr.c:3558
+#: fortran/expr.c:3561
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %L shall not have a coindex"
 msgstr ""
 
-#: fortran/expr.c:3579
+#: fortran/expr.c:3582
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure pointer assignment at %L"
 msgstr "代入として無効な左辺値です"
 
-#: fortran/expr.c:3603
+#: fortran/expr.c:3606
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs is invalid as proc-target in procedure pointer assignment at %L"
 msgstr "代入として無効な左辺値です"
 
-#: fortran/expr.c:3612
+#: fortran/expr.c:3615
 #, fuzzy, gcc-internal-format
 msgid "Abstract interface %qs is invalid in procedure pointer assignment at %L"
 msgstr "代入として無効な左辺値です"
 
-#: fortran/expr.c:3622
+#: fortran/expr.c:3625
 #, fuzzy, gcc-internal-format
 msgid "Statement function %qs is invalid in procedure pointer assignment at %L"
 msgstr "代入として無効な左辺値です"
 
-#: fortran/expr.c:3628
+#: fortran/expr.c:3631
 #, fuzzy, gcc-internal-format
 msgid "Internal procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "代入として無効な左辺値です"
 
-#: fortran/expr.c:3635
+#: fortran/expr.c:3638
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic %qs at %L is invalid in procedure pointer assignment"
 msgstr "代入として無効な左辺値です"
 
-#: fortran/expr.c:3643
+#: fortran/expr.c:3646
 #, fuzzy, gcc-internal-format
 msgid "Nonintrinsic elemental procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "代入として無効な左辺値です"
 
-#: fortran/expr.c:3666
+#: fortran/expr.c:3669
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in the procedure pointer assignment at %L: mismatch in the calling convention"
 msgstr ""
 
-#: fortran/expr.c:3719
+#: fortran/expr.c:3722
 #, fuzzy, gcc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %qs is not a subroutine"
 msgstr "代入として無効な左辺値です"
 
-#: fortran/expr.c:3729 fortran/expr.c:3744
+#: fortran/expr.c:3732 fortran/expr.c:3747
 #, gcc-internal-format
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr ""
 
-#: fortran/expr.c:3735 fortran/expr.c:3750 fortran/resolve.c:2566
+#: fortran/expr.c:3738 fortran/expr.c:3753 fortran/resolve.c:2566
 #, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr ""
 
-#: fortran/expr.c:3762
+#: fortran/expr.c:3765
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %s"
 msgstr ""
 
-#: fortran/expr.c:3771
+#: fortran/expr.c:3774
 #, gcc-internal-format
 msgid "Procedure pointer target %qs at %L must be either an intrinsic, host or use associated, referenced or have the EXTERNAL attribute"
 msgstr ""
 
-#: fortran/expr.c:3788
+#: fortran/expr.c:3791
 #, gcc-internal-format, gfc-internal-format
 msgid "Data-pointer-object at %L must be unlimited polymorphic, or of a type with the BIND or SEQUENCE attribute, to be compatible with an unlimited polymorphic target"
 msgstr ""
 
-#: fortran/expr.c:3793
+#: fortran/expr.c:3796
 #, gcc-internal-format, gfc-internal-format
 msgid "Different types in pointer assignment at %L; attempted assignment of %s to %s"
 msgstr ""
 
-#: fortran/expr.c:3802
+#: fortran/expr.c:3805
 #, gcc-internal-format, gfc-internal-format
 msgid "Different kind type parameters in pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3809
+#: fortran/expr.c:3812
 #, gcc-internal-format, gfc-internal-format
 msgid "Different ranks in pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3828
+#: fortran/expr.c:3831
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is smaller than size of the pointer (%ld < %ld) at %L"
 msgstr ""
 
-#: fortran/expr.c:3841
+#: fortran/expr.c:3844
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target must be rank 1 or simply contiguous at %L"
 msgstr ""
 
-#: fortran/expr.c:3845
+#: fortran/expr.c:3848
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is not rank 1 at %L"
 msgstr ""
@@ -58163,147 +58237,152 @@
 #. The test above might need to be extend when F08, Note 5.4 has to be
 #. interpreted in the way that target and pointer with the same coindex
 #. are allowed.
-#: fortran/expr.c:3877 fortran/expr.c:3925
+#: fortran/expr.c:3880 fortran/expr.c:3928
 #, gcc-internal-format, gfc-internal-format
 msgid "Data target at %L shall not have a coindex"
 msgstr ""
 
-#: fortran/expr.c:3880
+#: fortran/expr.c:3883
 #, gcc-internal-format, gfc-internal-format
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr ""
 
-#: fortran/expr.c:3888
+#: fortran/expr.c:3891
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr ""
 
-#: fortran/expr.c:3895
+#: fortran/expr.c:3898
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr ""
 
-#: fortran/expr.c:3904
+#: fortran/expr.c:3907
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr ""
 
-#: fortran/expr.c:3912
+#: fortran/expr.c:3915
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/expr.c:3936
+#: fortran/expr.c:3939
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to contiguous pointer from non-contiguous target at %L"
 msgstr ""
 
-#: fortran/expr.c:3975
+#: fortran/expr.c:3978
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr ""
 
-#: fortran/expr.c:4051 fortran/resolve.c:1452
+#: fortran/expr.c:4054 fortran/resolve.c:1452
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/expr.c:4057
+#: fortran/expr.c:4060
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr ""
 
-#: fortran/expr.c:4072 fortran/resolve.c:1458
+#: fortran/expr.c:4075 fortran/resolve.c:1458
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr ""
 
-#: fortran/expr.c:4084
+#: fortran/expr.c:4087
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr ""
 
-#: fortran/expr.c:5512
+#: fortran/expr.c:4557
+#, gcc-internal-format
+msgid "generate_isocbinding_initializer(): bad iso_c_binding type, expected %<c_ptr%> or %<c_funptr%>"
+msgstr ""
+
+#: fortran/expr.c:5568
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5520
+#: fortran/expr.c:5576
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5528
+#: fortran/expr.c:5584
 #, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5537
+#: fortran/expr.c:5593
 #, fuzzy, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr "`asm' の引数が定数文字列ではありません "
 
-#: fortran/expr.c:5548
+#: fortran/expr.c:5604
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5557
+#: fortran/expr.c:5613
 #, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5570
+#: fortran/expr.c:5626
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5583
+#: fortran/expr.c:5639
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5613
+#: fortran/expr.c:5669
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5621
+#: fortran/expr.c:5677
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5634
+#: fortran/expr.c:5690
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5642
+#: fortran/expr.c:5698
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5654
+#: fortran/expr.c:5710
 #, gcc-internal-format
 msgid "Variable %qs can not appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr ""
 
-#: fortran/expr.c:5713
+#: fortran/expr.c:5769
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:5717
+#: fortran/expr.c:5773
 #, gcc-internal-format
 msgid "%qs at %L associated to expression can not be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:5728
+#: fortran/expr.c:5784
 #, gcc-internal-format
 msgid "Associate-name %qs can not appear in a variable definition context (%s) at %L because its target at %L can not, either"
 msgstr ""
 
-#: fortran/expr.c:5770
+#: fortran/expr.c:5826
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr ""
@@ -58313,23 +58392,23 @@
 msgid "can't open input file: %s"
 msgstr "入力ファイル %s を close できません"
 
-#: fortran/frontend-passes.c:190
+#: fortran/frontend-passes.c:192
 #, fuzzy, gcc-internal-format
 #| msgid "in statement"
 msgid "No location in statement"
 msgstr "式内"
 
-#: fortran/frontend-passes.c:205
+#: fortran/frontend-passes.c:207
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "No location in expression near %L"
 msgstr "ANSI C++ は定数でない集合体の初期化子式を禁じます"
 
-#: fortran/frontend-passes.c:409
+#: fortran/frontend-passes.c:414
 #, gcc-internal-format
 msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
-#: fortran/frontend-passes.c:817 fortran/trans-array.c:1182
+#: fortran/frontend-passes.c:822 fortran/trans-array.c:1182
 #: fortran/trans-array.c:6440 fortran/trans-array.c:7864
 #: fortran/trans-intrinsic.c:7307
 #, fuzzy, gcc-internal-format, gfc-internal-format
@@ -58336,70 +58415,70 @@
 msgid "Creating array temporary at %L"
 msgstr "一時オブジェクトへの参照を返そうとしています"
 
-#: fortran/frontend-passes.c:842 fortran/frontend-passes.c:846
+#: fortran/frontend-passes.c:847 fortran/frontend-passes.c:851
 #, fuzzy, gcc-internal-format
 msgid "Removing call to function %qs at %L"
 msgstr "FPU レジスタ内の機能の値を返す"
 
-#: fortran/frontend-passes.c:1273 fortran/frontend-passes.c:1312
+#: fortran/frontend-passes.c:1278 fortran/frontend-passes.c:1317
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "bad expression"
 msgstr "式が予期されます"
 
-#: fortran/frontend-passes.c:1308
+#: fortran/frontend-passes.c:1313
 #, fuzzy, gcc-internal-format
 #| msgid "bad move"
 msgid "bad op"
 msgstr "誤った move です"
 
-#: fortran/frontend-passes.c:2161
+#: fortran/frontend-passes.c:2166
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands in gimple comparison"
 msgid "illegal OP in optimize_comparison"
 msgstr "gimple 比較内で無効な被演算子です"
 
-#: fortran/frontend-passes.c:2407
+#: fortran/frontend-passes.c:2412
 #, gcc-internal-format
 msgid "Variable %qs at %L set to undefined value inside loop  beginning at %L as INTENT(OUT) argument to subroutine %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:2414
+#: fortran/frontend-passes.c:2419
 #, gcc-internal-format
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to subroutine %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:2637 fortran/frontend-passes.c:2661
+#: fortran/frontend-passes.c:2642 fortran/frontend-passes.c:2666
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L out of bounds (%ld < %ld) in loop beginning at %L"
 msgstr ""
 
-#: fortran/frontend-passes.c:2646 fortran/frontend-passes.c:2670
+#: fortran/frontend-passes.c:2651 fortran/frontend-passes.c:2675
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L out of bounds (%ld > %ld) in loop beginning at %L"
 msgstr ""
 
-#: fortran/frontend-passes.c:2730
+#: fortran/frontend-passes.c:2735
 #, gcc-internal-format
 msgid "Variable %qs at %L set to undefined value inside loop beginning at %L as INTENT(OUT) argument to function %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:2736
+#: fortran/frontend-passes.c:2741
 #, gcc-internal-format
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:3128 fortran/trans-expr.c:1581
+#: fortran/frontend-passes.c:3133 fortran/trans-expr.c:1581
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr ""
 
-#: fortran/frontend-passes.c:3637
+#: fortran/frontend-passes.c:3642
 #, gcc-internal-format
 msgid "Scalarization using DIMEN_RANGE unimplemented"
 msgstr ""
 
-#: fortran/frontend-passes.c:4429
+#: fortran/frontend-passes.c:4434
 #, gcc-internal-format, gfc-internal-format
 msgid "Interchanging loops at %L"
 msgstr ""
@@ -58519,12 +58598,12 @@
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:970 fortran/resolve.c:16351
+#: fortran/interface.c:970 fortran/resolve.c:16378
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:977 fortran/resolve.c:16369
+#: fortran/interface.c:977 fortran/resolve.c:16396
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
@@ -59721,7 +59800,7 @@
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.c:3369 fortran/resolve.c:14263
+#: fortran/io.c:3369 fortran/resolve.c:14283
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -59887,7 +59966,7 @@
 msgid "Integer too large at %C"
 msgstr ""
 
-#: fortran/match.c:580 fortran/parse.c:1132
+#: fortran/match.c:580 fortran/parse.c:1136
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many digits in statement label at %C"
 msgstr ""
@@ -60651,57 +60730,57 @@
 msgid "Expected block name %qs of SELECT construct at %C"
 msgstr "switch 文の中でラベル `%s' が重複しています"
 
-#: fortran/match.c:6186
+#: fortran/match.c:6201
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "parse error in SELECT TYPE statement at %C"
 msgstr "'%s' トークンの所で文法エラー"
 
-#: fortran/match.c:6211
+#: fortran/match.c:6226
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr ""
 
-#: fortran/match.c:6249
+#: fortran/match.c:6264
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr ""
 
-#: fortran/match.c:6301
+#: fortran/match.c:6316
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CASE specification at %C"
 msgstr "メソッド仕様内での構文解析エラー"
 
-#: fortran/match.c:6319
+#: fortran/match.c:6334
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected TYPE IS statement at %C"
 msgstr ""
 
-#: fortran/match.c:6351
+#: fortran/match.c:6366
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr ""
 
-#: fortran/match.c:6362
+#: fortran/match.c:6377
 #, gcc-internal-format, gfc-internal-format
 msgid "All the LEN type parameters in the TYPE IS statement at %C must be ASSUMED"
 msgstr ""
 
-#: fortran/match.c:6373
+#: fortran/match.c:6388
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr "メソッド仕様内での構文解析エラー"
 
-#: fortran/match.c:6449
+#: fortran/match.c:6464
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr "メソッド仕様内での構文解析エラー"
 
-#: fortran/match.c:6572
+#: fortran/match.c:6587
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr ""
 
-#: fortran/match.c:6610
+#: fortran/match.c:6625
 #, gcc-internal-format
 msgid "Label %qs at %C doesn't match WHERE label %qs"
 msgstr ""
@@ -60852,188 +60931,188 @@
 msgid "mio_array_ref(): Unknown array ref"
 msgstr ""
 
-#: fortran/module.c:3716
+#: fortran/module.c:3718
 #, gcc-internal-format, gfc-internal-format
 msgid "Namelist %s cannot be renamed by USE association to %s"
 msgstr ""
 
-#: fortran/module.c:4832
+#: fortran/module.c:4834
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4835
+#: fortran/module.c:4837
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:5029
+#: fortran/module.c:5031
 #, gcc-internal-format
 msgid "%qs of module %qs, imported at %C, is also the name of the current program unit"
 msgstr ""
 
-#: fortran/module.c:5381
+#: fortran/module.c:5383
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in module %qs"
 msgstr "ラベル %s があらゆる関数の外側で参照されました"
 
-#: fortran/module.c:5388
+#: fortran/module.c:5390
 #, gcc-internal-format
 msgid "User operator %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5393
+#: fortran/module.c:5395
 #, gcc-internal-format
 msgid "Intrinsic operator %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5628
+#: fortran/module.c:5630
 #, gcc-internal-format
 msgid "write_symbol(): bad module symbol %qs"
 msgstr ""
 
-#: fortran/module.c:5961
+#: fortran/module.c:5963
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr ""
 
-#: fortran/module.c:6148
+#: fortran/module.c:6150
 #, fuzzy, gcc-internal-format
 msgid "Can't open module file %qs for writing at %C: %s"
 msgstr "%s: 読み込み用にファイル `%s' を開くことができません: %s\n"
 
-#: fortran/module.c:6169
+#: fortran/module.c:6171
 #, fuzzy, gcc-internal-format
 msgid "Error writing module file %qs for writing: %s"
 msgstr "%s: ファイル `%s' に書き込み中にエラー: %s\n"
 
-#: fortran/module.c:6180
+#: fortran/module.c:6182
 #, fuzzy, gcc-internal-format
 msgid "Can't delete module file %qs: %s"
 msgstr "%s: ファイル `%s' を削除できません: %s\n"
 
-#: fortran/module.c:6183
+#: fortran/module.c:6185
 #, fuzzy, gcc-internal-format
 msgid "Can't rename module file %qs to %qs: %s"
 msgstr "%s: 警告: ファイル `%s' を `%s' 名前変更できません: %s\n"
 
-#: fortran/module.c:6189
+#: fortran/module.c:6191
 #, fuzzy, gcc-internal-format
 msgid "Can't delete temporary module file %qs: %s"
 msgstr "%s: 副 info ファイル `%s' を削除できません: %s\n"
 
-#: fortran/module.c:6246
+#: fortran/module.c:6248
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C already declared"
 msgstr "シンボルの頭にアンダースコアをつける"
 
-#: fortran/module.c:6317
+#: fortran/module.c:6319
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr ""
 
-#: fortran/module.c:6425 fortran/module.c:6769
+#: fortran/module.c:6427 fortran/module.c:6771
 #, gcc-internal-format
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr ""
 
-#: fortran/module.c:6553
+#: fortran/module.c:6555
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr ""
 
-#: fortran/module.c:6574 fortran/module.c:6607 fortran/module.c:6649
+#: fortran/module.c:6576 fortran/module.c:6609 fortran/module.c:6651
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs already declared"
 msgstr "シンボルの頭にアンダースコアをつける"
 
-#: fortran/module.c:6754
+#: fortran/module.c:6756
 #, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:6776
+#: fortran/module.c:6778
 #, gcc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr ""
 
-#: fortran/module.c:6844
+#: fortran/module.c:6846
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr ""
 
-#: fortran/module.c:6898
+#: fortran/module.c:6900
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr ""
 
-#: fortran/module.c:6924
+#: fortran/module.c:6926
 #, gcc-internal-format, gfc-internal-format
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr ""
 
-#: fortran/module.c:6953
+#: fortran/module.c:6955
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr ""
 
-#: fortran/module.c:6965
+#: fortran/module.c:6967
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
 msgstr ""
 
-#: fortran/module.c:6978
+#: fortran/module.c:6980
 #, gcc-internal-format
 msgid "Can't find an intrinsic module named %qs at %C"
 msgstr ""
 
-#: fortran/module.c:6984
+#: fortran/module.c:6986
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr ""
 
-#: fortran/module.c:6990
+#: fortran/module.c:6992
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr ""
 
-#: fortran/module.c:6996
+#: fortran/module.c:6998
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr ""
 
-#: fortran/module.c:7006
+#: fortran/module.c:7008
 #, fuzzy, gcc-internal-format
 msgid "Can't open module file %qs for reading at %C: %s"
 msgstr "%s: 読み込み用にファイル `%s' を開くことができません: %s\n"
 
-#: fortran/module.c:7009
+#: fortran/module.c:7011
 #, gcc-internal-format
 msgid "Module file %qs has not been generated, either because the module does not contain a MODULE PROCEDURE or there is an error in the module."
 msgstr ""
 
-#: fortran/module.c:7020
+#: fortran/module.c:7022
 #, gcc-internal-format
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:7043
+#: fortran/module.c:7045
 #, gcc-internal-format
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr ""
 
-#: fortran/module.c:7051
+#: fortran/module.c:7053
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr ""
 
-#: fortran/module.c:7066
+#: fortran/module.c:7068
 #, gcc-internal-format, gfc-internal-format
 msgid "Can't USE the same %smodule we're building"
 msgstr ""
 
 #: fortran/openmp.c:296 fortran/openmp.c:397 fortran/openmp.c:692
-#: fortran/openmp.c:3167
+#: fortran/openmp.c:3166
 #, gcc-internal-format, gfc-internal-format
 msgid "COMMON block /%s/ not found at %C"
 msgstr ""
@@ -61111,862 +61190,862 @@
 
 #: fortran/openmp.c:2180
 #, fuzzy, gcc-internal-format, gfc-internal-format
-msgid "Invalid argument to !$ACC WAIT at %L"
+msgid "Invalid argument to !$ACC WAIT at %C"
 msgstr "`%s' の引数として無効な型"
 
-#: fortran/openmp.c:2188
+#: fortran/openmp.c:2187
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT clause at %L requires a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/openmp.c:2221
+#: fortran/openmp.c:2220
 #, gcc-internal-format, gfc-internal-format
 msgid "ACC CACHE directive must be inside of loop %C"
 msgstr ""
 
-#: fortran/openmp.c:2252
+#: fortran/openmp.c:2251
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for typename"
 msgid "Multiple loop axes specified for routine"
 msgstr "型名用に記憶域クラスが指定されました"
 
-#: fortran/openmp.c:2278
+#: fortran/openmp.c:2277
 #, gcc-internal-format, gfc-internal-format
 msgid "Only the !$ACC ROUTINE form without list is allowed in interface block at %C"
 msgstr ""
 
-#: fortran/openmp.c:2306
+#: fortran/openmp.c:2305
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$ACC ROUTINE ( NAME ) at %C, invalid function name %s"
 msgstr ""
 
-#: fortran/openmp.c:2315
+#: fortran/openmp.c:2314
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$ACC ROUTINE ( NAME ) at %C"
 msgstr "メソッド仕様内での構文解析エラー"
 
-#: fortran/openmp.c:2322
+#: fortran/openmp.c:2321
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$ACC ROUTINE ( NAME ) at %C, expecting ')' after NAME"
 msgstr ""
 
-#: fortran/openmp.c:2457 fortran/openmp.c:2481
+#: fortran/openmp.c:2456 fortran/openmp.c:2480
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP CRITICAL statement at %C"
 msgstr ""
 
-#: fortran/openmp.c:2548
+#: fortran/openmp.c:2547
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP FLUSH statement at %C"
 msgstr ""
 
-#: fortran/openmp.c:2942 fortran/openmp.c:6225
+#: fortran/openmp.c:2941 fortran/openmp.c:6230
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined %s !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2946 fortran/openmp.c:6229
+#: fortran/openmp.c:2945 fortran/openmp.c:6234
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2951
+#: fortran/openmp.c:2950
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2953
+#: fortran/openmp.c:2952
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2973
+#: fortran/openmp.c:2972
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after !$OMP DECLARE REDUCTION at %C"
 msgstr ""
 
-#: fortran/openmp.c:3010
+#: fortran/openmp.c:3009
 #, gcc-internal-format, gfc-internal-format
 msgid "Only the !$OMP DECLARE TARGET form without clauses is allowed in interface block at %C"
 msgstr ""
 
-#: fortran/openmp.c:3025
+#: fortran/openmp.c:3024
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after !$OMP DECLARE TARGET at %C"
 msgstr "`%s' の extern 宣言がネストしています"
 
-#: fortran/openmp.c:3048
+#: fortran/openmp.c:3047
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET variable at %L is an element of a COMMON block"
 msgstr ""
 
-#: fortran/openmp.c:3053
+#: fortran/openmp.c:3052
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET variable at %L previously mentioned in LINK clause and later in TO clause"
 msgstr ""
 
-#: fortran/openmp.c:3059
+#: fortran/openmp.c:3058
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET variable at %L previously mentioned in TO clause and later in LINK clause"
 msgstr ""
 
-#: fortran/openmp.c:3063
+#: fortran/openmp.c:3062
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable at %L mentioned multiple times in clauses of the same OMP DECLARE TARGET directive"
 msgstr ""
 
-#: fortran/openmp.c:3078
+#: fortran/openmp.c:3077
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET COMMON at %L previously mentioned in LINK clause and later in TO clause"
 msgstr ""
 
-#: fortran/openmp.c:3084
+#: fortran/openmp.c:3083
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET COMMON at %L previously mentioned in TO clause and later in LINK clause"
 msgstr ""
 
-#: fortran/openmp.c:3088
+#: fortran/openmp.c:3087
 #, gcc-internal-format, gfc-internal-format
 msgid "COMMON at %L mentioned multiple times in clauses of the same OMP DECLARE TARGET directive"
 msgstr ""
 
-#: fortran/openmp.c:3115
+#: fortran/openmp.c:3114
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$OMP DECLARE TARGET list at %C"
 msgstr "メソッド仕様内での構文解析エラー"
 
-#: fortran/openmp.c:3147
+#: fortran/openmp.c:3146
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate variable at %C is an element of a COMMON block"
 msgstr ""
 
-#: fortran/openmp.c:3184
+#: fortran/openmp.c:3183
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after OMP THREADPRIVATE at %C"
 msgstr "`%s' の extern 宣言がネストしています"
 
-#: fortran/openmp.c:3191
+#: fortran/openmp.c:3190
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$OMP THREADPRIVATE list at %C"
 msgstr ""
 
-#: fortran/openmp.c:3405
+#: fortran/openmp.c:3404
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after TASKWAIT clause at %C"
 msgstr ""
 
-#: fortran/openmp.c:3419
+#: fortran/openmp.c:3418
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after TASKYIELD clause at %C"
 msgstr "`%s' の extern 宣言がネストしています"
 
-#: fortran/openmp.c:3478
+#: fortran/openmp.c:3477
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP WORKSHARE statement at %C"
 msgstr ""
 
-#: fortran/openmp.c:3492
+#: fortran/openmp.c:3491
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP MASTER statement at %C"
 msgstr ""
 
-#: fortran/openmp.c:3551
+#: fortran/openmp.c:3550
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP ATOMIC statement at %C"
 msgstr ""
 
-#: fortran/openmp.c:3578
+#: fortran/openmp.c:3577
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP BARRIER statement at %C"
 msgstr ""
 
-#: fortran/openmp.c:3592
+#: fortran/openmp.c:3591
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP TASKGROUP statement at %C"
 msgstr "`%s' の extern 宣言がネストしています"
 
-#: fortran/openmp.c:3642
+#: fortran/openmp.c:3641
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP CANCELLATION POINT statement at %C"
 msgstr ""
 
-#: fortran/openmp.c:3662
+#: fortran/openmp.c:3661
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after NOWAIT clause at %C"
 msgstr ""
 
-#: fortran/openmp.c:3704
+#: fortran/openmp.c:3703
 #, gcc-internal-format, gfc-internal-format
 msgid "%s clause at %L requires a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/openmp.c:3715
+#: fortran/openmp.c:3714
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "INTEGER expression of %s clause at %L must be positive"
 msgstr "式の中の文に不完全型があります"
 
-#: fortran/openmp.c:3726
+#: fortran/openmp.c:3725
 #, gcc-internal-format, gfc-internal-format
 msgid "INTEGER expression of %s clause at %L must be non-negative"
 msgstr ""
 
-#: fortran/openmp.c:3737
+#: fortran/openmp.c:3736
 #, gcc-internal-format
 msgid "POINTER object %qs of derived type in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3740
+#: fortran/openmp.c:3739
 #, gcc-internal-format
 msgid "Cray pointer object %qs of derived type in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3743
+#: fortran/openmp.c:3742
 #, gcc-internal-format
 msgid "Cray pointee object %qs of derived type in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3749 fortran/openmp.c:4687
+#: fortran/openmp.c:3748 fortran/openmp.c:4686
 #, gcc-internal-format
 msgid "POINTER object %qs of polymorphic type in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3754
+#: fortran/openmp.c:3753
 #, gcc-internal-format
 msgid "Cray pointer object %qs of polymorphic type in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3759
+#: fortran/openmp.c:3758
 #, gcc-internal-format
 msgid "Cray pointee object %qs of polymorphic type in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3769 fortran/openmp.c:4385 fortran/openmp.c:4490
+#: fortran/openmp.c:3768 fortran/openmp.c:4384 fortran/openmp.c:4489
 #, fuzzy, gcc-internal-format
 msgid "Assumed size array %qs in %s clause at %L"
 msgstr "セクション属性は `%s' には使えません"
 
-#: fortran/openmp.c:3772
+#: fortran/openmp.c:3771
 #, fuzzy, gcc-internal-format
 msgid "Assumed rank array %qs in %s clause at %L"
 msgstr "セクション属性は `%s' には使えません"
 
-#: fortran/openmp.c:3776
+#: fortran/openmp.c:3775
 #, gcc-internal-format
 msgid "Noncontiguous deferred shape array %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3784
+#: fortran/openmp.c:3783
 #, gcc-internal-format
 msgid "ALLOCATABLE object %qs of derived type in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3789
+#: fortran/openmp.c:3788
 #, gcc-internal-format
 msgid "ALLOCATABLE object %qs of polymorphic type in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3801 fortran/openmp.c:4480
+#: fortran/openmp.c:3800 fortran/openmp.c:4479
 #, gcc-internal-format
 msgid "POINTER object %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3806 fortran/openmp.c:4691
+#: fortran/openmp.c:3805 fortran/openmp.c:4690
 #, fuzzy, gcc-internal-format
 msgid "Cray pointer object %qs in %s clause at %L"
 msgstr "値をベクトルには変換できません"
 
-#: fortran/openmp.c:3811 fortran/openmp.c:4694
+#: fortran/openmp.c:3810 fortran/openmp.c:4693
 #, fuzzy, gcc-internal-format
 msgid "Cray pointee object %qs in %s clause at %L"
 msgstr "値をベクトルには変換できません"
 
-#: fortran/openmp.c:3816 fortran/openmp.c:4682
+#: fortran/openmp.c:3815 fortran/openmp.c:4681
 #, gcc-internal-format
 msgid "ALLOCATABLE object %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3819
+#: fortran/openmp.c:3818
 #, gcc-internal-format
 msgid "VALUE object %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3862
+#: fortran/openmp.c:3861
 #, gcc-internal-format, gfc-internal-format
 msgid "Implicitly declared function %s used in !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:3911
+#: fortran/openmp.c:3910
 #, gcc-internal-format, gfc-internal-format
 msgid "Implicitly declared subroutine %s used in !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:3944
+#: fortran/openmp.c:3943
 #, gcc-internal-format, gfc-internal-format
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:3952 fortran/openmp.c:3963 fortran/resolve.c:10028
-#: fortran/resolve.c:11295
+#: fortran/openmp.c:3951 fortran/openmp.c:3962 fortran/resolve.c:10041
+#: fortran/resolve.c:11315
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/openmp.c:3967
+#: fortran/openmp.c:3966
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause without modifier at %L used together with IF clauses with modifiers"
 msgstr ""
 
-#: fortran/openmp.c:4044
+#: fortran/openmp.c:4043
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause modifier %s at %L not appropriate for the current OpenMP construct"
 msgstr ""
 
-#: fortran/openmp.c:4054
+#: fortran/openmp.c:4053
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/openmp.c:4064
+#: fortran/openmp.c:4063
 #, gcc-internal-format, gfc-internal-format
 msgid "SCHEDULE clause's chunk_size at %L requires a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/openmp.c:4069
+#: fortran/openmp.c:4068
 #, gcc-internal-format, gfc-internal-format
 msgid "INTEGER expression of SCHEDULE clause's chunk_size at %L must be positive"
 msgstr ""
 
-#: fortran/openmp.c:4084
+#: fortran/openmp.c:4083
 #, gcc-internal-format
 msgid "Variable %qs is not a dummy argument at %L"
 msgstr ""
 
-#: fortran/openmp.c:4116
+#: fortran/openmp.c:4115 fortran/openmp.c:5998
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "Object %qs is not a variable at %L"
 msgstr "%qD は変数ではありません"
 
-#: fortran/openmp.c:4132 fortran/openmp.c:4143 fortran/openmp.c:4151
-#: fortran/openmp.c:4162 fortran/openmp.c:4174 fortran/openmp.c:4189
-#: fortran/openmp.c:6023
+#: fortran/openmp.c:4131 fortran/openmp.c:4142 fortran/openmp.c:4150
+#: fortran/openmp.c:4161 fortran/openmp.c:4173 fortran/openmp.c:4188
+#: fortran/openmp.c:6028
 #, gcc-internal-format
 msgid "Symbol %qs present on multiple clauses at %L"
 msgstr ""
 
-#: fortran/openmp.c:4196
+#: fortran/openmp.c:4195
 #, gcc-internal-format
 msgid "Array %qs is not permitted in reduction at %L"
 msgstr ""
 
-#: fortran/openmp.c:4209
+#: fortran/openmp.c:4208
 #, gcc-internal-format
 msgid "Symbol %qs present on both FROM and TO clauses at %L"
 msgstr ""
 
-#: fortran/openmp.c:4231
+#: fortran/openmp.c:4230
 #, gcc-internal-format
 msgid "Non-THREADPRIVATE object %qs in COPYIN clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4239
+#: fortran/openmp.c:4238
 #, gcc-internal-format
 msgid "Assumed size array %qs in COPYPRIVATE clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4242
+#: fortran/openmp.c:4241
 #, gcc-internal-format
 msgid "INTENT(IN) POINTER %qs in COPYPRIVATE clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4250
+#: fortran/openmp.c:4249
 #, gcc-internal-format
 msgid "THREADPRIVATE object %qs in SHARED clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4253
+#: fortran/openmp.c:4252
 #, gcc-internal-format
 msgid "Cray pointee %qs in SHARED clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4256
+#: fortran/openmp.c:4255
 #, gcc-internal-format
 msgid "ASSOCIATE name %qs in SHARED clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4271
+#: fortran/openmp.c:4270
 #, gcc-internal-format
 msgid "%qs in ALIGNED clause must be POINTER, ALLOCATABLE, Cray pointer or C_PTR at %L"
 msgstr ""
 
-#: fortran/openmp.c:4283
+#: fortran/openmp.c:4282
 #, gcc-internal-format
 msgid "%qs in ALIGNED clause at %L requires a scalar positive constant integer alignment expression"
 msgstr ""
 
-#: fortran/openmp.c:4302
+#: fortran/openmp.c:4301
 #, gcc-internal-format, gfc-internal-format
 msgid "SINK dependence type only allowed on ORDERED directive at %L"
 msgstr ""
 
-#: fortran/openmp.c:4306
+#: fortran/openmp.c:4305
 #, gcc-internal-format, gfc-internal-format
 msgid "DEPEND SINK used together with DEPEND SOURCE on the same construct at %L"
 msgstr ""
 
-#: fortran/openmp.c:4316
+#: fortran/openmp.c:4315
 #, gcc-internal-format, gfc-internal-format
 msgid "SINK addend not a constant integer at %L"
 msgstr ""
 
-#: fortran/openmp.c:4322
+#: fortran/openmp.c:4321
 #, gcc-internal-format, gfc-internal-format
 msgid "Only SOURCE or SINK dependence types are allowed on ORDERED directive at %L"
 msgstr ""
 
-#: fortran/openmp.c:4333 fortran/openmp.c:4354
+#: fortran/openmp.c:4332 fortran/openmp.c:4353
 #, gcc-internal-format
 msgid "%qs in %s clause at %L is not a proper array section"
 msgstr ""
 
-#: fortran/openmp.c:4337
+#: fortran/openmp.c:4336
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coarrays not supported in %s clause at %L"
 msgstr "case の値としてポインタは許可されていません"
 
-#: fortran/openmp.c:4346
+#: fortran/openmp.c:4345
 #, gcc-internal-format, gfc-internal-format
 msgid "Stride should not be specified for array section in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4367
+#: fortran/openmp.c:4366
 #, gcc-internal-format
 msgid "%qs in DEPEND clause at %L is a zero size array section"
 msgstr ""
 
-#: fortran/openmp.c:4403
+#: fortran/openmp.c:4402
 #, gcc-internal-format, gfc-internal-format
 msgid "TARGET%s with map-type other than TO, FROM, TOFROM, or ALLOC on MAP clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4419
+#: fortran/openmp.c:4418
 #, gcc-internal-format, gfc-internal-format
 msgid "TARGET ENTER DATA with map-type other than TO, or ALLOC on MAP clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4434
+#: fortran/openmp.c:4433
 #, gcc-internal-format, gfc-internal-format
 msgid "TARGET EXIT DATA with map-type other than FROM, RELEASE, or DELETE on MAP clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4450 fortran/openmp.c:4466
+#: fortran/openmp.c:4449 fortran/openmp.c:4465
 #, gcc-internal-format
 msgid "THREADPRIVATE object %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4453 fortran/openmp.c:4469
+#: fortran/openmp.c:4452 fortran/openmp.c:4468
 #, fuzzy, gcc-internal-format
 msgid "Cray pointee %qs in %s clause at %L"
 msgstr "セクション属性は `%s' には使えません"
 
-#: fortran/openmp.c:4472
+#: fortran/openmp.c:4471
 #, gcc-internal-format
 msgid "ASSOCIATE name %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4477
+#: fortran/openmp.c:4476
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer %qs in %s clause at %L"
 msgstr "代入として無効な左辺値です"
 
-#: fortran/openmp.c:4483
+#: fortran/openmp.c:4482
 #, fuzzy, gcc-internal-format
 msgid "Cray pointer %qs in %s clause at %L"
 msgstr "値をベクトルには変換できません"
 
-#: fortran/openmp.c:4493
+#: fortran/openmp.c:4492
 #, gcc-internal-format
 msgid "Variable %qs in %s clause is used in NAMELIST statement at %L"
 msgstr ""
 
 #. case OMP_LIST_REDUCTION:
-#: fortran/openmp.c:4503
+#: fortran/openmp.c:4502
 #, gcc-internal-format
 msgid "INTENT(IN) POINTER %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4596
+#: fortran/openmp.c:4595
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP DECLARE REDUCTION %s not found for type %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:4622
+#: fortran/openmp.c:4621
 #, gcc-internal-format, gfc-internal-format
 msgid "LINEAR clause modifier used on DO or SIMD construct at %L"
 msgstr ""
 
-#: fortran/openmp.c:4627
+#: fortran/openmp.c:4626
 #, gcc-internal-format, gfc-internal-format
 msgid "LINEAR clause specified together with ORDERED clause with argument at %L"
 msgstr ""
 
-#: fortran/openmp.c:4632
+#: fortran/openmp.c:4631
 #, gcc-internal-format
 msgid "LINEAR variable %qs must be INTEGER at %L"
 msgstr ""
 
-#: fortran/openmp.c:4637
+#: fortran/openmp.c:4636
 #, gcc-internal-format
 msgid "LINEAR dummy argument %qs with VALUE attribute with %s modifier at %L"
 msgstr ""
 
-#: fortran/openmp.c:4648
+#: fortran/openmp.c:4647
 #, gcc-internal-format
 msgid "%qs in LINEAR clause at %L requires a scalar integer linear-step expression"
 msgstr ""
 
-#: fortran/openmp.c:4665
+#: fortran/openmp.c:4664
 #, gcc-internal-format
 msgid "%qs in LINEAR clause at %L requires a constant integer linear-step expression or dummy argument specified in UNIFORM clause"
 msgstr ""
 
-#: fortran/openmp.c:4699
+#: fortran/openmp.c:4698
 #, gcc-internal-format
 msgid "%s clause variable %qs at %L is neither a POINTER nor an array"
 msgstr ""
 
-#: fortran/openmp.c:4731
+#: fortran/openmp.c:4730
 #, gcc-internal-format, gfc-internal-format
 msgid "DIST_SCHEDULE clause's chunk_size at %L requires a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/openmp.c:4763
+#: fortran/openmp.c:4762
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible use of TILE and COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:4765
+#: fortran/openmp.c:4764
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE dependence type only allowed on ORDERED directive at %L"
 msgstr ""
 
-#: fortran/openmp.c:4778
+#: fortran/openmp.c:4777
 #, gcc-internal-format, gfc-internal-format
 msgid "%s must contain at least one MAP clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4875
+#: fortran/openmp.c:4874
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "expected expression"
 msgid "unexpected !$OMP ATOMIC expression at %L"
 msgstr "式が予期されます"
 
-#: fortran/openmp.c:4904
+#: fortran/openmp.c:4903
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC statement must set a scalar variable of intrinsic type at %L"
 msgstr ""
 
-#: fortran/openmp.c:4929
+#: fortran/openmp.c:4928
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC READ statement must read from a scalar variable of intrinsic type at %L"
 msgstr ""
 
-#: fortran/openmp.c:4934
+#: fortran/openmp.c:4933
 #, gcc-internal-format, gfc-internal-format
 msgid "expr in !$OMP ATOMIC WRITE assignment var = expr must be scalar and cannot reference var at %L"
 msgstr ""
 
-#: fortran/openmp.c:4956 fortran/openmp.c:5247
+#: fortran/openmp.c:4955 fortran/openmp.c:5246
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE capture statement must read from a scalar variable of intrinsic type at %L"
 msgstr ""
 
-#: fortran/openmp.c:4971
+#: fortran/openmp.c:4970
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE update statement must set a scalar variable of intrinsic type at %L"
 msgstr ""
 
-#: fortran/openmp.c:4978 fortran/openmp.c:5254
+#: fortran/openmp.c:4977 fortran/openmp.c:5253
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE capture statement reads from different variable than update statement writes into at %L"
 msgstr ""
 
-#: fortran/openmp.c:4994
+#: fortran/openmp.c:4993
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC with ALLOCATABLE variable at %L"
 msgstr ""
 
-#: fortran/openmp.c:5036
+#: fortran/openmp.c:5035
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment operator must be binary +, *, -, /, .AND., .OR., .EQV. or .NEQV. at %L"
 msgstr ""
 
-#: fortran/openmp.c:5084
+#: fortran/openmp.c:5083
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment must be var = var op expr or var = expr op var at %L"
 msgstr ""
 
-#: fortran/openmp.c:5098
+#: fortran/openmp.c:5097
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC var = var op expr not mathematically equivalent to var = var op (expr) at %L"
 msgstr ""
 
-#: fortran/openmp.c:5130
+#: fortran/openmp.c:5129
 #, gcc-internal-format, gfc-internal-format
 msgid "expr in !$OMP ATOMIC assignment var = var op expr must be scalar and cannot reference var at %L"
 msgstr ""
 
-#: fortran/openmp.c:5154
+#: fortran/openmp.c:5153
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment intrinsic IAND, IOR or IEOR must have two arguments at %L"
 msgstr ""
 
-#: fortran/openmp.c:5161
+#: fortran/openmp.c:5160
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment intrinsic must be MIN, MAX, IAND, IOR or IEOR at %L"
 msgstr ""
 
-#: fortran/openmp.c:5178
+#: fortran/openmp.c:5177
 #, gcc-internal-format
 msgid "!$OMP ATOMIC intrinsic arguments except one must not reference %qs at %L"
 msgstr ""
 
-#: fortran/openmp.c:5185
+#: fortran/openmp.c:5184
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC intrinsic arguments must be scalar at %L"
 msgstr ""
 
-#: fortran/openmp.c:5193
+#: fortran/openmp.c:5192
 #, gcc-internal-format
 msgid "First or last !$OMP ATOMIC intrinsic argument must be %qs at %L"
 msgstr ""
 
-#: fortran/openmp.c:5211
+#: fortran/openmp.c:5210
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment must have an operator or intrinsic on right hand side at %L"
 msgstr ""
 
-#: fortran/openmp.c:5225
+#: fortran/openmp.c:5224
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE capture statement must set a scalar variable of intrinsic type at %L"
 msgstr ""
 
-#: fortran/openmp.c:5544
+#: fortran/openmp.c:5543
 #, gcc-internal-format, gfc-internal-format
 msgid "%s cannot be a DO WHILE or DO without loop control at %L"
 msgstr ""
 
-#: fortran/openmp.c:5550
+#: fortran/openmp.c:5549
 #, gcc-internal-format, gfc-internal-format
 msgid "%s cannot be a DO CONCURRENT loop at %L"
 msgstr ""
 
-#: fortran/openmp.c:5556
+#: fortran/openmp.c:5555
 #, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable must be of type integer at %L"
 msgstr ""
 
-#: fortran/openmp.c:5560
+#: fortran/openmp.c:5559
 #, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable must not be THREADPRIVATE at %L"
 msgstr ""
 
-#: fortran/openmp.c:5573
+#: fortran/openmp.c:5572
 #, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable present on clause other than PRIVATE or LASTPRIVATE at %L"
 msgstr ""
 
-#: fortran/openmp.c:5577
+#: fortran/openmp.c:5576
 #, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable present on clause other than LASTPRIVATE at %L"
 msgstr ""
 
-#: fortran/openmp.c:5581
+#: fortran/openmp.c:5580
 #, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable present on clause other than LINEAR at %L"
 msgstr ""
 
-#: fortran/openmp.c:5599
+#: fortran/openmp.c:5598
 #, gcc-internal-format, gfc-internal-format
 msgid "%s collapsed loops don't form rectangular iteration space at %L"
 msgstr ""
 
-#: fortran/openmp.c:5611
+#: fortran/openmp.c:5610
 #, gcc-internal-format, gfc-internal-format
 msgid "collapsed %s loops not perfectly nested at %L"
 msgstr ""
 
-#: fortran/openmp.c:5620 fortran/openmp.c:5628
+#: fortran/openmp.c:5619 fortran/openmp.c:5627
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for collapsed %s at %L"
 msgstr "不十分な型情報"
 
-#: fortran/openmp.c:5712 fortran/openmp.c:5725
+#: fortran/openmp.c:5711 fortran/openmp.c:5724
 #, gcc-internal-format, gfc-internal-format
 msgid "The %s directive cannot be specified within a %s region at %L"
 msgstr ""
 
-#: fortran/openmp.c:5744
+#: fortran/openmp.c:5743
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP cannot be a DO WHILE or DO without loop control at %L"
 msgstr ""
 
-#: fortran/openmp.c:5750
+#: fortran/openmp.c:5749
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP iteration variable must be of type integer at %L"
 msgstr ""
 
-#: fortran/openmp.c:5766
+#: fortran/openmp.c:5765
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s loops don't form rectangular iteration space at %L"
 msgstr ""
 
-#: fortran/openmp.c:5778
+#: fortran/openmp.c:5777
 #, gcc-internal-format, gfc-internal-format
 msgid "%s !$ACC LOOP loops not perfectly nested at %L"
 msgstr ""
 
-#: fortran/openmp.c:5788 fortran/openmp.c:5797
+#: fortran/openmp.c:5787 fortran/openmp.c:5796
 #, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for %s !$ACC LOOP at %L"
 msgstr ""
 
-#: fortran/openmp.c:5812 fortran/openmp.c:5819
+#: fortran/openmp.c:5811 fortran/openmp.c:5818
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s in PARALLEL region doesn't allow %s arguments at %L"
 msgstr ""
 
-#: fortran/openmp.c:5841
+#: fortran/openmp.c:5840
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside another loop parallelized across gangs at %L"
 msgstr ""
 
-#: fortran/openmp.c:5845 fortran/openmp.c:5849
+#: fortran/openmp.c:5844 fortran/openmp.c:5848
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside loop parallelized across workers at %L"
 msgstr ""
 
-#: fortran/openmp.c:5856
+#: fortran/openmp.c:5855
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across workers at %L"
 msgstr ""
 
-#: fortran/openmp.c:5860
+#: fortran/openmp.c:5859
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across vectors at %L"
 msgstr ""
 
-#: fortran/openmp.c:5866
+#: fortran/openmp.c:5865
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across vectors is not allowed inside another loop parallelized across vectors at %L"
 msgstr ""
 
-#: fortran/openmp.c:5878
+#: fortran/openmp.c:5877
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with INDEPENDENT at %L"
 msgstr ""
 
-#: fortran/openmp.c:5880
+#: fortran/openmp.c:5879
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with GANG at %L"
 msgstr ""
 
-#: fortran/openmp.c:5882
+#: fortran/openmp.c:5881
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with WORKER at %L"
 msgstr ""
 
-#: fortran/openmp.c:5884
+#: fortran/openmp.c:5883
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with VECTOR at %L"
 msgstr ""
 
-#: fortran/openmp.c:5886
+#: fortran/openmp.c:5885
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with AUTO at %L"
 msgstr ""
 
-#: fortran/openmp.c:5891
+#: fortran/openmp.c:5890
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with GANG at %L"
 msgstr ""
 
-#: fortran/openmp.c:5893
+#: fortran/openmp.c:5892
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with WORKER at %L"
 msgstr ""
 
-#: fortran/openmp.c:5895
+#: fortran/openmp.c:5894
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with VECTOR at %L"
 msgstr ""
 
-#: fortran/openmp.c:5899
+#: fortran/openmp.c:5898
 #, gcc-internal-format, gfc-internal-format
 msgid "Tiled loop cannot be parallelized across gangs, workers and vectors at the same time at %L"
 msgstr ""
 
-#: fortran/openmp.c:5934
+#: fortran/openmp.c:5933
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "TILE requires constant expression at %L"
 msgstr "定数式がオーバーフローしました"
 
-#: fortran/openmp.c:5999
+#: fortran/openmp.c:6004
 #, gcc-internal-format
 msgid "PARAMETER object %qs is not allowed at %L"
 msgstr ""
 
-#: fortran/openmp.c:6006
+#: fortran/openmp.c:6011
 #, fuzzy, gcc-internal-format
 msgid "Array sections: %qs not allowed in !$ACC DECLARE at %L"
 msgstr "セクション属性は `%s' には使えません"
 
-#: fortran/openmp.c:6133
+#: fortran/openmp.c:6138
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP TARGET UPDATE at %L requires at least one TO or FROM clause"
 msgstr ""
 
-#: fortran/openmp.c:6155
+#: fortran/openmp.c:6160
 #, gcc-internal-format
 msgid "!$OMP DECLARE SIMD should refer to containing procedure %qs at %L"
 msgstr ""
 
-#: fortran/openmp.c:6179
+#: fortran/openmp.c:6184
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_PRIV or OMP_ORIG used in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6187
+#: fortran/openmp.c:6192
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_OUT or OMP_IN used in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6216
+#: fortran/openmp.c:6221
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid operator for !$OMP DECLARE REDUCTION %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:6238
+#: fortran/openmp.c:6243
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER length in !$OMP DECLARE REDUCTION %s not constant at %L"
 msgstr ""
 
-#: fortran/openmp.c:6254
+#: fortran/openmp.c:6259
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6269
+#: fortran/openmp.c:6274
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6279
+#: fortran/openmp.c:6284
 #, gcc-internal-format, gfc-internal-format
 msgid "One of actual subroutine arguments in INITIALIZER clause of !$OMP DECLARE REDUCTION must be OMP_PRIV at %L"
 msgstr ""
 
-#: fortran/openmp.c:6287
+#: fortran/openmp.c:6292
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing INITIALIZER clause for !$OMP DECLARE REDUCTION of derived type without default initializer at %L"
 msgstr ""
@@ -62078,496 +62157,496 @@
 msgid "Unclassifiable statement at %C"
 msgstr ""
 
-#: fortran/parse.c:629
+#: fortran/parse.c:631
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "OpenACC directives at %C may not appear in PURE procedures"
 msgstr "section 属性はローカル変数に対しては指定できません"
 
-#: fortran/parse.c:705
+#: fortran/parse.c:707
 #, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable OpenACC directive at %C"
 msgstr ""
 
-#: fortran/parse.c:831 fortran/parse.c:1040
+#: fortran/parse.c:835 fortran/parse.c:1044
 #, gcc-internal-format, gfc-internal-format
 msgid "OpenMP directives other than SIMD or DECLARE TARGET at %C may not appear in PURE or ELEMENTAL procedures"
 msgstr ""
 
-#: fortran/parse.c:1024
+#: fortran/parse.c:1028
 #, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable OpenMP directive at %C"
 msgstr ""
 
-#: fortran/parse.c:1076
+#: fortran/parse.c:1080
 #, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable GCC directive at %C"
 msgstr ""
 
-#: fortran/parse.c:1135 fortran/parse.c:1362
+#: fortran/parse.c:1139 fortran/parse.c:1366
 #, gcc-internal-format, gfc-internal-format
 msgid "Zero is not a valid statement label at %C"
 msgstr ""
 
-#: fortran/parse.c:1142 fortran/parse.c:1354
+#: fortran/parse.c:1146 fortran/parse.c:1358
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-numeric character in statement label at %C"
 msgstr ""
 
-#: fortran/parse.c:1154 fortran/parse.c:1403
+#: fortran/parse.c:1158 fortran/parse.c:1407
 #, gcc-internal-format, gfc-internal-format
 msgid "Semicolon at %C needs to be preceded by statement"
 msgstr ""
 
-#: fortran/parse.c:1161 fortran/parse.c:1418
+#: fortran/parse.c:1165 fortran/parse.c:1422
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Statement label without statement at %L"
 msgstr "switch 文の中でラベル `%s' が重複しています"
 
-#: fortran/parse.c:1224 fortran/parse.c:1405
+#: fortran/parse.c:1228 fortran/parse.c:1409
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Semicolon at %C without preceding statement"
 msgstr ""
 
-#: fortran/parse.c:1247 fortran/parse.c:1381
+#: fortran/parse.c:1251 fortran/parse.c:1385
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad continuation line at %C"
 msgstr ""
 
-#: fortran/parse.c:1679
+#: fortran/parse.c:1683
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT statement at %L does not have a statement label"
 msgstr ""
 
-#: fortran/parse.c:2435
+#: fortran/parse.c:2439
 #, gcc-internal-format
 msgid "gfc_ascii_statement(): Bad statement code"
 msgstr ""
 
-#: fortran/parse.c:2577
+#: fortran/parse.c:2581
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement at %C"
 msgstr ""
 
-#: fortran/parse.c:2732
+#: fortran/parse.c:2736
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot follow %s statement at %L"
 msgstr ""
 
-#: fortran/parse.c:2749
+#: fortran/parse.c:2753
 #, fuzzy, gcc-internal-format
 msgid "Unexpected end of file in %qs"
 msgstr "ファイル \"%s\" に戻るはずでした"
 
-#: fortran/parse.c:2784
+#: fortran/parse.c:2788
 #, gcc-internal-format
 msgid "Derived-type %qs with SEQUENCE must not have a CONTAINS section at %C"
 msgstr ""
 
-#: fortran/parse.c:2787
+#: fortran/parse.c:2791
 #, gcc-internal-format
 msgid "Derived-type %qs with BIND(C) must not have a CONTAINS section at %C"
 msgstr ""
 
-#: fortran/parse.c:2807
+#: fortran/parse.c:2811
 #, gcc-internal-format, gfc-internal-format
 msgid "Components in TYPE at %C must precede CONTAINS"
 msgstr ""
 
-#: fortran/parse.c:2811
+#: fortran/parse.c:2815
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type-bound procedure at %C"
 msgstr "不明なレジスタ名です: %s"
 
-#: fortran/parse.c:2819
+#: fortran/parse.c:2823
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC binding at %C"
 msgstr ""
 
-#: fortran/parse.c:2827
+#: fortran/parse.c:2831
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure declaration at %C"
 msgstr "前方での `%s' の宣言"
 
-#: fortran/parse.c:2839
+#: fortran/parse.c:2843
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type definition at %C with empty CONTAINS section"
 msgstr ""
 
-#: fortran/parse.c:2849 fortran/parse.c:3304
+#: fortran/parse.c:2853 fortran/parse.c:3308
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement in TYPE at %C must be inside a MODULE"
 msgstr ""
 
-#: fortran/parse.c:2856
+#: fortran/parse.c:2860
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede procedure bindings"
 msgstr ""
 
-#: fortran/parse.c:2863 fortran/parse.c:3317
+#: fortran/parse.c:2867 fortran/parse.c:3321
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PRIVATE statement at %C"
 msgstr ""
 
-#: fortran/parse.c:2873
+#: fortran/parse.c:2877
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede CONTAINS"
 msgstr ""
 
-#: fortran/parse.c:2877
+#: fortran/parse.c:2881
 #, gcc-internal-format, gfc-internal-format
 msgid "Already inside a CONTAINS block at %C"
 msgstr ""
 
-#: fortran/parse.c:2996
+#: fortran/parse.c:3000
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s at %L of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray, which is not possible as the component has the pointer attribute"
 msgstr ""
 
-#: fortran/parse.c:3002
+#: fortran/parse.c:3006
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer component %s at %L has a noncoarray subcomponent of type LOCK_TYPE, which must have a codimension or be a subcomponent of a coarray"
 msgstr ""
 
-#: fortran/parse.c:3007
+#: fortran/parse.c:3011
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L of type LOCK_TYPE must have a codimension"
 msgstr ""
 
-#: fortran/parse.c:3011
+#: fortran/parse.c:3015
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L must have a codimension as it has a noncoarray subcomponent of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/parse.c:3016
+#: fortran/parse.c:3020
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as already a coarray subcomponent exists)"
 msgstr ""
 
-#: fortran/parse.c:3023
+#: fortran/parse.c:3027
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as %s at %L has a codimension or a coarray subcomponent)"
 msgstr ""
 
-#: fortran/parse.c:3033
+#: fortran/parse.c:3037
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s at %L of type EVENT_TYPE must have a codimension or be a subcomponent of a coarray, which is not possible as the component has the pointer attribute"
 msgstr ""
 
-#: fortran/parse.c:3039
+#: fortran/parse.c:3043
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer component %s at %L has a noncoarray subcomponent of type EVENT_TYPE, which must have a codimension or be a subcomponent of a coarray"
 msgstr ""
 
-#: fortran/parse.c:3044
+#: fortran/parse.c:3048
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L of type EVENT_TYPE must have a codimension"
 msgstr ""
 
-#: fortran/parse.c:3048
+#: fortran/parse.c:3052
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L must have a codimension as it has a noncoarray subcomponent of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/parse.c:3053
+#: fortran/parse.c:3057
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as already a coarray subcomponent exists)"
 msgstr ""
 
-#: fortran/parse.c:3060
+#: fortran/parse.c:3064
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as %s at %L has a codimension or a coarray subcomponent)"
 msgstr ""
 
-#: fortran/parse.c:3112
+#: fortran/parse.c:3116
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "failed to open %s"
 msgid "failed to create map component '%s'"
 msgstr "%s を開くのに失敗しました"
 
-#: fortran/parse.c:3145
+#: fortran/parse.c:3149
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "failed to open %s"
 msgid "failed to create union component '%s'"
 msgstr "%s を開くのに失敗しました"
 
-#: fortran/parse.c:3200
+#: fortran/parse.c:3204
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in nested structure declaration at %C"
 msgstr "`%s' の宣言に二つ以上のデータ型が指定されました"
 
-#: fortran/parse.c:3287
+#: fortran/parse.c:3291
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside CONTAINS"
 msgstr ""
 
-#: fortran/parse.c:3295
+#: fortran/parse.c:3299
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type definition at %C without components"
 msgstr ""
 
-#: fortran/parse.c:3311
+#: fortran/parse.c:3315
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede structure components"
 msgstr ""
 
-#: fortran/parse.c:3328
+#: fortran/parse.c:3332
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede structure components"
 msgstr ""
 
-#: fortran/parse.c:3334
+#: fortran/parse.c:3338
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE attribute at %C already specified in TYPE statement"
 msgstr ""
 
-#: fortran/parse.c:3339
+#: fortran/parse.c:3343
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SEQUENCE statement at %C"
 msgstr ""
 
-#: fortran/parse.c:3349
+#: fortran/parse.c:3353
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS block in derived type definition at %C"
 msgstr ""
 
-#: fortran/parse.c:3407
+#: fortran/parse.c:3411
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM declaration at %C has no ENUMERATORS"
 msgstr ""
 
-#: fortran/parse.c:3494
+#: fortran/parse.c:3498
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in INTERFACE block at %C"
 msgstr ""
 
-#: fortran/parse.c:3518
+#: fortran/parse.c:3522
 #, gcc-internal-format
 msgid "Name %qs of ABSTRACT INTERFACE at %C cannot be the same as an intrinsic type"
 msgstr ""
 
-#: fortran/parse.c:3552
+#: fortran/parse.c:3556
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement at %C in INTERFACE body"
 msgstr ""
 
-#: fortran/parse.c:3570
+#: fortran/parse.c:3574
 #, fuzzy, gcc-internal-format
 msgid "INTERFACE procedure %qs at %L has the same name as the enclosing procedure"
 msgstr "プロシージャ開始と終了のスケジュールを行なわない"
 
-#: fortran/parse.c:3700
+#: fortran/parse.c:3704
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/parse.c:3732
+#: fortran/parse.c:3736
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement is not allowed inside of BLOCK DATA at %C"
 msgstr ""
 
-#: fortran/parse.c:3822
+#: fortran/parse.c:3826
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement must appear in a MODULE"
 msgstr ""
 
-#: fortran/parse.c:3830
+#: fortran/parse.c:3834
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C follows another accessibility specification"
 msgstr ""
 
-#: fortran/parse.c:3882
+#: fortran/parse.c:3886
 #, fuzzy, gcc-internal-format
 msgid "Bad kind expression for function %qs at %L"
 msgstr "関数 `%s' に対して不適切な保存クラス"
 
-#: fortran/parse.c:3886
+#: fortran/parse.c:3890
 #, fuzzy, gcc-internal-format
 msgid "The type for function %qs at %L is not accessible"
 msgstr "FPU レジスタ内の機能の値を返す"
 
-#: fortran/parse.c:3946
+#: fortran/parse.c:3950
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C follows previous unmasked ELSEWHERE"
 msgstr ""
 
-#: fortran/parse.c:3968
+#: fortran/parse.c:3972
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in WHERE block at %C"
 msgstr ""
 
-#: fortran/parse.c:4027
+#: fortran/parse.c:4031
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in FORALL block at %C"
 msgstr ""
 
-#: fortran/parse.c:4078
+#: fortran/parse.c:4082
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSE IF statement at %C cannot follow ELSE statement at %L"
 msgstr ""
 
-#: fortran/parse.c:4096
+#: fortran/parse.c:4100
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ELSE statements at %L and %C"
 msgstr ""
 
-#: fortran/parse.c:4157
+#: fortran/parse.c:4161
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected a CASE or END SELECT statement following SELECT CASE at %C"
 msgstr ""
 
-#: fortran/parse.c:4241
+#: fortran/parse.c:4245
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected TYPE IS, CLASS IS or END SELECT statement following SELECT TYPE at %C"
 msgstr ""
 
-#: fortran/parse.c:4303
+#: fortran/parse.c:4307
 #, gcc-internal-format
 msgid "Variable %qs at %C cannot be redefined inside loop beginning at %L"
 msgstr ""
 
-#: fortran/parse.c:4336
+#: fortran/parse.c:4340
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is within another block"
 msgstr ""
 
-#: fortran/parse.c:4346
+#: fortran/parse.c:4350
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is interwoven with another DO loop"
 msgstr ""
 
-#: fortran/parse.c:4372
+#: fortran/parse.c:4376
 #, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL block inside of OpenACC region at %C"
 msgstr ""
 
-#: fortran/parse.c:4373
+#: fortran/parse.c:4377
 #, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL block inside of OpenMP region at %C"
 msgstr ""
 
-#: fortran/parse.c:4399
+#: fortran/parse.c:4403
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label in END CRITICAL at %C does not match CRITICAL label"
 msgstr ""
 
-#: fortran/parse.c:4468
+#: fortran/parse.c:4472
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "In constructor %qs"
 msgid "BLOCK construct at %C"
 msgstr "コンストラクタ %qs 内"
 
-#: fortran/parse.c:4502
+#: fortran/parse.c:4506
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "In constructor %qs"
 msgid "ASSOCIATE construct at %C"
 msgstr "コンストラクタ %qs 内"
 
-#: fortran/parse.c:4690
+#: fortran/parse.c:4694
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label in ENDDO at %C doesn't match DO label"
 msgstr ""
 
-#: fortran/parse.c:4706
+#: fortran/parse.c:4710
 #, gcc-internal-format, gfc-internal-format
 msgid "Named block DO at %L requires matching ENDDO name"
 msgstr ""
 
-#: fortran/parse.c:4897
+#: fortran/parse.c:4901
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing !$OMP END ATOMIC after !$OMP ATOMIC CAPTURE at %C"
 msgstr ""
 
-#: fortran/parse.c:4913 fortran/parse.c:4972
+#: fortran/parse.c:4917 fortran/parse.c:4976
 #, gcc-internal-format, gfc-internal-format
 msgid "OpenACC directive inside of CRITICAL block at %C"
 msgstr ""
 
-#: fortran/parse.c:4947
+#: fortran/parse.c:4951
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s at %C"
 msgstr "行番号 %u に戻るはずでした"
 
-#: fortran/parse.c:4991
+#: fortran/parse.c:4995
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected DO loop at %C"
 msgstr "配列の添字が `char' 型です"
 
-#: fortran/parse.c:5011
+#: fortran/parse.c:5015
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant !$ACC END LOOP at %C"
 msgstr ""
 
-#: fortran/parse.c:5225
+#: fortran/parse.c:5229
 #, gcc-internal-format, gfc-internal-format
 msgid "Name after !$omp critical and !$omp end critical does not match at %C"
 msgstr ""
 
-#: fortran/parse.c:5283
+#: fortran/parse.c:5287
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot terminate a non-block DO loop"
 msgstr ""
 
-#: fortran/parse.c:5297
+#: fortran/parse.c:5301
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %C after the first executable statement"
 msgstr ""
 
-#: fortran/parse.c:5423
+#: fortran/parse.c:5427
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive does not commence a loop at %C"
 msgstr ""
 
-#: fortran/parse.c:5538
+#: fortran/parse.c:5542
 #, fuzzy, gcc-internal-format
 msgid "Contained procedure %qs at %C is already ambiguous"
 msgstr "%s: オプション `%s' はあいまいです\n"
 
-#: fortran/parse.c:5595
+#: fortran/parse.c:5599
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in CONTAINS section at %C"
 msgstr ""
 
-#: fortran/parse.c:5620
+#: fortran/parse.c:5624
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS statement without FUNCTION or SUBROUTINE statement at %L"
 msgstr ""
 
-#: fortran/parse.c:5732
+#: fortran/parse.c:5736
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS statement at %C is already in a contained program unit"
 msgstr ""
 
-#: fortran/parse.c:5784
+#: fortran/parse.c:5788
 #, gcc-internal-format
 msgid "Global binding name %qs at %L is already being used as a %s at %L"
 msgstr ""
 
-#: fortran/parse.c:5788
+#: fortran/parse.c:5792
 #, gcc-internal-format
 msgid "Global name %qs at %L is already being used as a %s at %L"
 msgstr ""
 
-#: fortran/parse.c:5794
+#: fortran/parse.c:5798
 #, gcc-internal-format
 msgid "Global binding name %qs at %L is already being used at %L"
 msgstr ""
 
-#: fortran/parse.c:5797
+#: fortran/parse.c:5801
 #, fuzzy, gcc-internal-format
 msgid "Global name %qs at %L is already being used at %L"
 msgstr "%s: オプション `%s' はあいまいです\n"
 
-#: fortran/parse.c:5819
+#: fortran/parse.c:5823
 #, gcc-internal-format, gfc-internal-format
 msgid "Blank BLOCK DATA at %C conflicts with prior BLOCK DATA at %L"
 msgstr ""
 
-#: fortran/parse.c:5845
+#: fortran/parse.c:5849
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in BLOCK DATA at %C"
 msgstr ""
 
-#: fortran/parse.c:5949
+#: fortran/parse.c:5953
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in MODULE at %C"
 msgstr ""
@@ -62575,7 +62654,7 @@
 #. If we see a duplicate main program, shut down.  If the second
 #. instance is an implied main program, i.e. data decls or executable
 #. statements, we're in for lots of errors.
-#: fortran/parse.c:6333
+#: fortran/parse.c:6337
 #, gcc-internal-format, gfc-internal-format
 msgid "Two main PROGRAMs at %L and %C"
 msgstr ""
@@ -63324,7 +63403,7 @@
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.c:1893 fortran/resolve.c:9560 fortran/resolve.c:11225
+#: fortran/resolve.c:1893 fortran/resolve.c:9573 fortran/resolve.c:11245
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "ラベル %s があらゆる関数の外側で参照されました"
@@ -63435,7 +63514,7 @@
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr ""
 
-#: fortran/resolve.c:2905 fortran/resolve.c:16283
+#: fortran/resolve.c:2905 fortran/resolve.c:16310
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr ""
@@ -63558,198 +63637,198 @@
 msgid "logical_to_bitwise(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:4059
+#: fortran/resolve.c:4065
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:4229 fortran/resolve.c:4252
+#: fortran/resolve.c:4235 fortran/resolve.c:4258
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:4347
+#: fortran/resolve.c:4353
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4352
+#: fortran/resolve.c:4358
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4362
+#: fortran/resolve.c:4368
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4367
+#: fortran/resolve.c:4373
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4387
+#: fortran/resolve.c:4393
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr ""
 
-#: fortran/resolve.c:4404
+#: fortran/resolve.c:4410
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4412
+#: fortran/resolve.c:4418
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4428
+#: fortran/resolve.c:4434
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4437
+#: fortran/resolve.c:4443
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4453
+#: fortran/resolve.c:4459
 #, fuzzy, gcc-internal-format
 #| msgid "subscript missing in array reference"
 msgid "check_dimension(): Bad array reference"
 msgstr "配列参照での添字を欠いています"
 
-#: fortran/resolve.c:4476
+#: fortran/resolve.c:4482
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:4486
+#: fortran/resolve.c:4492
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.c:4494
+#: fortran/resolve.c:4500
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.c:4510
+#: fortran/resolve.c:4516
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr ""
 
-#: fortran/resolve.c:4538
+#: fortran/resolve.c:4544
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4544
+#: fortran/resolve.c:4550
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr ""
 
-#: fortran/resolve.c:4550
+#: fortran/resolve.c:4556
 #, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr ""
 
-#: fortran/resolve.c:4589
+#: fortran/resolve.c:4595
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4596
+#: fortran/resolve.c:4602
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr ""
 
-#: fortran/resolve.c:4641
+#: fortran/resolve.c:4647
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr ""
 
-#: fortran/resolve.c:4652
+#: fortran/resolve.c:4658
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.c:4663
+#: fortran/resolve.c:4669
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.c:4706
+#: fortran/resolve.c:4712
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr ""
 
-#: fortran/resolve.c:4804
+#: fortran/resolve.c:4810
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:4811
+#: fortran/resolve.c:4817
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4820
+#: fortran/resolve.c:4826
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr ""
 
-#: fortran/resolve.c:4833
+#: fortran/resolve.c:4839
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:4840
+#: fortran/resolve.c:4846
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4850
+#: fortran/resolve.c:4856
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr ""
 
-#: fortran/resolve.c:4860
+#: fortran/resolve.c:4866
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr "要求されたアラインメントが大きすぎます"
 
-#: fortran/resolve.c:5013
+#: fortran/resolve.c:5019
 #, fuzzy, gcc-internal-format
 msgid "resolve_ref(): Bad array reference"
 msgstr "配列参照での添字を欠いています"
 
-#: fortran/resolve.c:5027
+#: fortran/resolve.c:5033
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:5037
+#: fortran/resolve.c:5043
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:5056
+#: fortran/resolve.c:5062
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:5154
+#: fortran/resolve.c:5160
 #, gcc-internal-format
 msgid "expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.c:5236
+#: fortran/resolve.c:5242
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr ""
 
-#: fortran/resolve.c:5246
+#: fortran/resolve.c:5252
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -63758,12 +63837,12 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5256
+#: fortran/resolve.c:5262
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5271
+#: fortran/resolve.c:5277
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -63772,269 +63851,269 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5281
+#: fortran/resolve.c:5287
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5292
+#: fortran/resolve.c:5298
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5301
+#: fortran/resolve.c:5307
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5316
+#: fortran/resolve.c:5322
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5478
+#: fortran/resolve.c:5484
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5483
+#: fortran/resolve.c:5489
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5553
+#: fortran/resolve.c:5559
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.c:5566
+#: fortran/resolve.c:5572
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.c:5919
+#: fortran/resolve.c:5925
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:5926
+#: fortran/resolve.c:5932
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5961
+#: fortran/resolve.c:5967
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5970
+#: fortran/resolve.c:5976
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr ""
 
 #. Nothing matching found!
-#: fortran/resolve.c:6158
+#: fortran/resolve.c:6164
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:6185
+#: fortran/resolve.c:6191
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:6236
+#: fortran/resolve.c:6242
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:6786
+#: fortran/resolve.c:6792
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr ""
 
-#: fortran/resolve.c:6812
+#: fortran/resolve.c:6818
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr ""
 
-#: fortran/resolve.c:6822
+#: fortran/resolve.c:6828
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "index must be integer"
 msgid "%s at %L must be integer"
 msgstr "添え字は整数でなければいけません"
 
-#: fortran/resolve.c:6826 fortran/resolve.c:6833
+#: fortran/resolve.c:6832 fortran/resolve.c:6839
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6875
+#: fortran/resolve.c:6881
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:6911
+#: fortran/resolve.c:6917
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.c:6928
+#: fortran/resolve.c:6934
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.c:6934
+#: fortran/resolve.c:6940
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.c:6995
+#: fortran/resolve.c:7001
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7000
+#: fortran/resolve.c:7006
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7007
+#: fortran/resolve.c:7013
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7015
+#: fortran/resolve.c:7021
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr ""
 
-#: fortran/resolve.c:7020
+#: fortran/resolve.c:7026
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:7033
+#: fortran/resolve.c:7039
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr ""
 
-#: fortran/resolve.c:7136 fortran/resolve.c:7428
+#: fortran/resolve.c:7142 fortran/resolve.c:7434
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:7144 fortran/resolve.c:7393
+#: fortran/resolve.c:7150 fortran/resolve.c:7399
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7250
+#: fortran/resolve.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7281
+#: fortran/resolve.c:7287
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.c:7439
+#: fortran/resolve.c:7445
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.c:7451
+#: fortran/resolve.c:7457
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.c:7465
+#: fortran/resolve.c:7471
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7480
+#: fortran/resolve.c:7486
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7493
+#: fortran/resolve.c:7499
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.c:7511
+#: fortran/resolve.c:7517
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.c:7592 fortran/resolve.c:7607
+#: fortran/resolve.c:7598 fortran/resolve.c:7613
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7599
+#: fortran/resolve.c:7605
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7622
+#: fortran/resolve.c:7628
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7649
+#: fortran/resolve.c:7655
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7668
+#: fortran/resolve.c:7674
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.c:7683
+#: fortran/resolve.c:7689
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7694
+#: fortran/resolve.c:7700
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7726
+#: fortran/resolve.c:7732
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:7749
+#: fortran/resolve.c:7755
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:7760
+#: fortran/resolve.c:7766
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.c:7771
+#: fortran/resolve.c:7782
 #, gcc-internal-format, gfc-internal-format
-msgid "Errmsg-variable at %L must be a scalar CHARACTER variable"
+msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:7794
+#: fortran/resolve.c:7805
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:7824
+#: fortran/resolve.c:7835
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.c:7830 fortran/resolve.c:7836
+#: fortran/resolve.c:7841 fortran/resolve.c:7847
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -64043,234 +64122,234 @@
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8064
+#: fortran/resolve.c:8075
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr ""
 
-#: fortran/resolve.c:8115
+#: fortran/resolve.c:8126
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "式の中の文に不完全型があります"
 
-#: fortran/resolve.c:8126
+#: fortran/resolve.c:8137
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr ""
 
-#: fortran/resolve.c:8139
+#: fortran/resolve.c:8150
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:8185
+#: fortran/resolve.c:8196
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr ""
 
-#: fortran/resolve.c:8204
+#: fortran/resolve.c:8215
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr ""
 
-#: fortran/resolve.c:8214
+#: fortran/resolve.c:8225
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr ""
 
-#: fortran/resolve.c:8232 fortran/resolve.c:8240
+#: fortran/resolve.c:8243 fortran/resolve.c:8251
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr ""
 
-#: fortran/resolve.c:8302 fortran/resolve.c:8873
+#: fortran/resolve.c:8313 fortran/resolve.c:8884
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr ""
 
-#: fortran/resolve.c:8328
+#: fortran/resolve.c:8339
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:8340
+#: fortran/resolve.c:8351
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:8355
+#: fortran/resolve.c:8366
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr ""
 
-#: fortran/resolve.c:8458
+#: fortran/resolve.c:8469
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr ""
 
-#: fortran/resolve.c:8518
+#: fortran/resolve.c:8529
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr ""
 
-#: fortran/resolve.c:8523
+#: fortran/resolve.c:8534
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "parameter %u has void type"
 msgid "Selector at %L has no type"
 msgstr "仮引数 %u が void 型を持っています"
 
-#: fortran/resolve.c:8545
+#: fortran/resolve.c:8556
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.c:8556
+#: fortran/resolve.c:8567
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:8763
+#: fortran/resolve.c:8774
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8783 fortran/resolve.c:8795
+#: fortran/resolve.c:8794 fortran/resolve.c:8806
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.c:8824
+#: fortran/resolve.c:8835
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr ""
 
-#: fortran/resolve.c:8836
+#: fortran/resolve.c:8847
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr ""
 
-#: fortran/resolve.c:8848
+#: fortran/resolve.c:8859
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr ""
 
-#: fortran/resolve.c:8851
+#: fortran/resolve.c:8862
 #, fuzzy, gcc-internal-format
 #| msgid "expected numeric type"
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "数値型が予期されます"
 
-#: fortran/resolve.c:8861
+#: fortran/resolve.c:8872
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.c:9108
+#: fortran/resolve.c:9119
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9204
+#: fortran/resolve.c:9215
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "無効なオプション %s"
 
-#: fortran/resolve.c:9257
+#: fortran/resolve.c:9268
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr ""
 
-#: fortran/resolve.c:9267
+#: fortran/resolve.c:9278
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9280
+#: fortran/resolve.c:9291
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9289
+#: fortran/resolve.c:9300
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr ""
 
-#: fortran/resolve.c:9296
+#: fortran/resolve.c:9307
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9307
+#: fortran/resolve.c:9318
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr ""
 
-#: fortran/resolve.c:9313
+#: fortran/resolve.c:9324
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9328
+#: fortran/resolve.c:9339
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:9388
+#: fortran/resolve.c:9399
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:9398
+#: fortran/resolve.c:9409
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:9402
+#: fortran/resolve.c:9413
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr ""
 
-#: fortran/resolve.c:9405
+#: fortran/resolve.c:9416
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr ""
 
-#: fortran/resolve.c:9412 fortran/resolve.c:9533
+#: fortran/resolve.c:9423 fortran/resolve.c:9545
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:9424 fortran/resolve.c:9540
+#: fortran/resolve.c:9435 fortran/resolve.c:9553
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:9436
+#: fortran/resolve.c:9447
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr ""
 
-#: fortran/resolve.c:9449
+#: fortran/resolve.c:9460
 #, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:9510
+#: fortran/resolve.c:9521
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:9514 fortran/resolve.c:9524
+#: fortran/resolve.c:9525 fortran/resolve.c:9535
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr ""
 
-#: fortran/resolve.c:9567
+#: fortran/resolve.c:9580
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9577
+#: fortran/resolve.c:9590
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr ""
@@ -64277,12 +64356,12 @@
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:9594 fortran/resolve.c:9617
+#: fortran/resolve.c:9607 fortran/resolve.c:9630
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.c:9598 fortran/resolve.c:9623
+#: fortran/resolve.c:9611 fortran/resolve.c:9636
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -64290,107 +64369,107 @@
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:9638
+#: fortran/resolve.c:9651
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9710
+#: fortran/resolve.c:9723
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:9726
+#: fortran/resolve.c:9739
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:9734 fortran/resolve.c:9821
+#: fortran/resolve.c:9747 fortran/resolve.c:9834
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:9744 fortran/resolve.c:9831
+#: fortran/resolve.c:9757 fortran/resolve.c:9844
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:9775
+#: fortran/resolve.c:9788
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:9784
+#: fortran/resolve.c:9797
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr ""
 
-#: fortran/resolve.c:9949
+#: fortran/resolve.c:9962
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr ""
 
-#: fortran/resolve.c:9959
+#: fortran/resolve.c:9972
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr ""
 
-#: fortran/resolve.c:10036
+#: fortran/resolve.c:10049
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr ""
 
-#: fortran/resolve.c:10138
+#: fortran/resolve.c:10151
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:10251
+#: fortran/resolve.c:10264
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr ""
 
-#: fortran/resolve.c:10283
+#: fortran/resolve.c:10296
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:10288
+#: fortran/resolve.c:10301
 #, gcc-internal-format, gfc-internal-format
 msgid "The impure variable at %L is assigned to a derived type variable with a POINTER component in a PURE procedure (12.6)"
 msgstr ""
 
-#: fortran/resolve.c:10298
+#: fortran/resolve.c:10311
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:10330
+#: fortran/resolve.c:10343
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:10334
+#: fortran/resolve.c:10347
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:10339
+#: fortran/resolve.c:10352
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.c:10346
+#: fortran/resolve.c:10359
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr ""
 
-#: fortran/resolve.c:10357
+#: fortran/resolve.c:10370
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:10663
+#: fortran/resolve.c:10683
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
@@ -64397,67 +64476,67 @@
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:10905
+#: fortran/resolve.c:10925
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr "代入として無効な左辺値です"
 
-#: fortran/resolve.c:10917
+#: fortran/resolve.c:10937
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr ""
 
-#: fortran/resolve.c:11157
+#: fortran/resolve.c:11177
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:11160
+#: fortran/resolve.c:11180
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr ""
 
-#: fortran/resolve.c:11171
+#: fortran/resolve.c:11191
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr ""
 
-#: fortran/resolve.c:11233
+#: fortran/resolve.c:11253
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:11278
+#: fortran/resolve.c:11298
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid NULL at %L"
 msgstr "無効なオプション %s"
 
-#: fortran/resolve.c:11282
+#: fortran/resolve.c:11302
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:11339
+#: fortran/resolve.c:11359
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:11344
+#: fortran/resolve.c:11364
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:11428
+#: fortran/resolve.c:11448
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:11507
+#: fortran/resolve.c:11527
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr ""
 
-#: fortran/resolve.c:11617
+#: fortran/resolve.c:11637
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
@@ -64464,7 +64543,7 @@
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:11630
+#: fortran/resolve.c:11650
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr ""
@@ -64472,57 +64551,57 @@
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:11647
+#: fortran/resolve.c:11667
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.c:11732
+#: fortran/resolve.c:11752
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "配列 `%s' の大きさが大きすぎます"
 
-#: fortran/resolve.c:11961
+#: fortran/resolve.c:11981
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:11965
+#: fortran/resolve.c:11985
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:11973
+#: fortran/resolve.c:11993
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:11983
+#: fortran/resolve.c:12003
 #, fuzzy, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "`%s' に `extern' と初期化子の両方があります"
 
-#: fortran/resolve.c:11998
+#: fortran/resolve.c:12018
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.c:12010
+#: fortran/resolve.c:12030
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.c:12041
+#: fortran/resolve.c:12061
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.c:12063
+#: fortran/resolve.c:12083
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
 
-#: fortran/resolve.c:12090
+#: fortran/resolve.c:12110
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
@@ -64529,893 +64608,898 @@
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12131
+#: fortran/resolve.c:12151
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr ""
 
-#: fortran/resolve.c:12150
+#: fortran/resolve.c:12170
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr ""
 
-#: fortran/resolve.c:12171
+#: fortran/resolve.c:12191
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr ""
 
-#: fortran/resolve.c:12178
+#: fortran/resolve.c:12198
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr ""
 
-#: fortran/resolve.c:12225
+#: fortran/resolve.c:12245
 #, fuzzy, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "関数を inline にできません"
 
-#: fortran/resolve.c:12228
+#: fortran/resolve.c:12248
 #, fuzzy, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr "可変長オブジェクトは初期化されないことになるでしょう"
 
-#: fortran/resolve.c:12232
+#: fortran/resolve.c:12252
 #, fuzzy, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "`%s' に `extern' と初期化子の両方があります"
 
-#: fortran/resolve.c:12235
+#: fortran/resolve.c:12255
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "関数を inline にできません"
 
-#: fortran/resolve.c:12238
+#: fortran/resolve.c:12258
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "関数を inline にできません"
 
-#: fortran/resolve.c:12241
+#: fortran/resolve.c:12261
 #, fuzzy, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "`%s' に `extern' と初期化子の両方があります"
 
-#: fortran/resolve.c:12283
+#: fortran/resolve.c:12303
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "in %s, at %s:%d"
 msgid "%s at %L"
 msgstr "%s 内、位置 %s:%d"
 
-#: fortran/resolve.c:12310
+#: fortran/resolve.c:12330
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:12332
+#: fortran/resolve.c:12352
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:12354
+#: fortran/resolve.c:12374
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.c:12372
+#: fortran/resolve.c:12392
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "関数を inline にできません"
 
-#: fortran/resolve.c:12381
+#: fortran/resolve.c:12401
 #, fuzzy, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr "可変長オブジェクトは初期化されないことになるでしょう"
 
-#: fortran/resolve.c:12389
+#: fortran/resolve.c:12409
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr ""
 
-#: fortran/resolve.c:12399
+#: fortran/resolve.c:12419
 #, fuzzy, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "組み込み関数 `%s' は非関数として宣言されました"
 
-#: fortran/resolve.c:12418
+#: fortran/resolve.c:12438
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "関数を inline にできません"
 
-#: fortran/resolve.c:12422
+#: fortran/resolve.c:12442
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "関数を inline にできません"
 
-#: fortran/resolve.c:12426
+#: fortran/resolve.c:12446
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr ""
 
-#: fortran/resolve.c:12430
+#: fortran/resolve.c:12450
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr ""
 
-#: fortran/resolve.c:12443
+#: fortran/resolve.c:12463
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12452
+#: fortran/resolve.c:12472
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:12458
+#: fortran/resolve.c:12478
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:12470
+#: fortran/resolve.c:12490
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:12527
+#: fortran/resolve.c:12547
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "%qE 属性は %s 属性と競合します"
 
-#: fortran/resolve.c:12533
+#: fortran/resolve.c:12553
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "%qE 属性は %s 属性と競合します"
 
-#: fortran/resolve.c:12539
+#: fortran/resolve.c:12559
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "%qE 属性は %s 属性と競合します"
 
-#: fortran/resolve.c:12547
+#: fortran/resolve.c:12567
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "%qE 属性は %s 属性と競合します"
 
-#: fortran/resolve.c:12553
+#: fortran/resolve.c:12573
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.c:12596
+#: fortran/resolve.c:12616
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12604
+#: fortran/resolve.c:12624
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12612
+#: fortran/resolve.c:12632
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12621
+#: fortran/resolve.c:12641
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.c:12705
+#: fortran/resolve.c:12725
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:12714
+#: fortran/resolve.c:12734
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr ""
 
-#: fortran/resolve.c:12723
+#: fortran/resolve.c:12743
 #, fuzzy, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "式の中の文に不完全型があります"
 
-#: fortran/resolve.c:12731
+#: fortran/resolve.c:12751
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:12737
+#: fortran/resolve.c:12757
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:12743
+#: fortran/resolve.c:12763
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr ""
 
-#: fortran/resolve.c:12751
+#: fortran/resolve.c:12771
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:12760
+#: fortran/resolve.c:12780
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr ""
 
-#: fortran/resolve.c:12782
+#: fortran/resolve.c:12802
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr ""
 
-#: fortran/resolve.c:12819
+#: fortran/resolve.c:12839
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr ""
 
-#: fortran/resolve.c:12859
+#: fortran/resolve.c:12879
 #, gcc-internal-format
 msgid "%qs and %qs can't be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12895
+#: fortran/resolve.c:12915
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.c:12954
+#: fortran/resolve.c:12974
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12966
+#: fortran/resolve.c:12986
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.c:12994
+#: fortran/resolve.c:13014
 #, gcc-internal-format
 msgid "GENERIC %qs at %L can't overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.c:13050
+#: fortran/resolve.c:13070
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L can't be NOPASS"
 msgstr ""
 
-#: fortran/resolve.c:13242
+#: fortran/resolve.c:13262
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr ""
 
-#: fortran/resolve.c:13284
+#: fortran/resolve.c:13304
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:13298
+#: fortran/resolve.c:13318
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:13312 fortran/resolve.c:13778
+#: fortran/resolve.c:13332 fortran/resolve.c:13798
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13320
+#: fortran/resolve.c:13340
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr ""
 
-#: fortran/resolve.c:13329
+#: fortran/resolve.c:13349
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:13335
+#: fortran/resolve.c:13355
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13341
+#: fortran/resolve.c:13361
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr ""
 
-#: fortran/resolve.c:13370
+#: fortran/resolve.c:13390
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:13380
+#: fortran/resolve.c:13400
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:13472
+#: fortran/resolve.c:13492
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.c:13574
+#: fortran/resolve.c:13594
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:13583
+#: fortran/resolve.c:13603
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13593
+#: fortran/resolve.c:13613
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.c:13602
+#: fortran/resolve.c:13622
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.c:13613
+#: fortran/resolve.c:13633
 #, gcc-internal-format
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.c:13711
+#: fortran/resolve.c:13731
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:13725
+#: fortran/resolve.c:13745
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:13741
+#: fortran/resolve.c:13761
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:13751
+#: fortran/resolve.c:13771
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/resolve.c:13760
+#: fortran/resolve.c:13780
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:13769
+#: fortran/resolve.c:13789
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13811
+#: fortran/resolve.c:13831
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr ""
 
-#: fortran/resolve.c:13824
+#: fortran/resolve.c:13844
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr ""
 
-#: fortran/resolve.c:13835
+#: fortran/resolve.c:13855
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13868
+#: fortran/resolve.c:13888
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:13876
+#: fortran/resolve.c:13896
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.c:13885
+#: fortran/resolve.c:13905
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr ""
 
-#: fortran/resolve.c:13903 fortran/resolve.c:13915
+#: fortran/resolve.c:13923 fortran/resolve.c:13935
 #, gcc-internal-format
 msgid "The pointer component %qs of %qs at %L is a type that has not been declared"
 msgstr ""
 
-#: fortran/resolve.c:13989
+#: fortran/resolve.c:14009
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "ANSI C++ は定数でない集合体の初期化子式を禁じます"
 
-#: fortran/resolve.c:14034
+#: fortran/resolve.c:14054
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.c:14047
+#: fortran/resolve.c:14067
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr ""
 
-#: fortran/resolve.c:14111
+#: fortran/resolve.c:14131
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14144
+#: fortran/resolve.c:14164
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.c:14216
+#: fortran/resolve.c:14236
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:14222
+#: fortran/resolve.c:14242
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14228
+#: fortran/resolve.c:14248
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14236
+#: fortran/resolve.c:14256
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14253
+#: fortran/resolve.c:14273
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14275
+#: fortran/resolve.c:14295
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14286
+#: fortran/resolve.c:14306
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14313
+#: fortran/resolve.c:14333
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "%qE 属性は %s 属性と競合します"
 
-#: fortran/resolve.c:14337
+#: fortran/resolve.c:14357
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:14353
+#: fortran/resolve.c:14373
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:14364
+#: fortran/resolve.c:14384
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "%s に互換性のない型"
 
-#: fortran/resolve.c:14372
+#: fortran/resolve.c:14392
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr ""
 
-#: fortran/resolve.c:14423
+#: fortran/resolve.c:14443
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr ""
 
-#: fortran/resolve.c:14434
+#: fortran/resolve.c:14454
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.c:14441
+#: fortran/resolve.c:14461
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.c:14480
+#: fortran/resolve.c:14500
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:14544
+#: fortran/resolve.c:14564
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:14547
+#: fortran/resolve.c:14567
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:14643
+#: fortran/resolve.c:14663
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:14664
+#: fortran/resolve.c:14684
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr ""
 
-#: fortran/resolve.c:14677
+#: fortran/resolve.c:14697
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14680
+#: fortran/resolve.c:14700
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14688
+#: fortran/resolve.c:14708
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14695
+#: fortran/resolve.c:14715
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:14708
+#: fortran/resolve.c:14728
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr ""
 
-#: fortran/resolve.c:14714
+#: fortran/resolve.c:14734
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14724
+#: fortran/resolve.c:14744
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:14733
+#: fortran/resolve.c:14753
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.c:14746 fortran/resolve.c:14923
+#: fortran/resolve.c:14766 fortran/resolve.c:14943
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.c:14760
+#: fortran/resolve.c:14780
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14769
+#: fortran/resolve.c:14789
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:14778
+#: fortran/resolve.c:14798
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14786
+#: fortran/resolve.c:14806
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:14793
+#: fortran/resolve.c:14813
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:14813
+#: fortran/resolve.c:14833
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.c:14820
+#: fortran/resolve.c:14840
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14827
+#: fortran/resolve.c:14847
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:14834
+#: fortran/resolve.c:14854
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:14860
+#: fortran/resolve.c:14880
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:14870
+#: fortran/resolve.c:14890
 #, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.c:14949
+#: fortran/resolve.c:14969
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:14964
+#: fortran/resolve.c:14984
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14977
+#: fortran/resolve.c:14997
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14995
+#: fortran/resolve.c:15015
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.c:15007
+#: fortran/resolve.c:15027
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:15016
+#: fortran/resolve.c:15036
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:15028
+#: fortran/resolve.c:15048
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr ""
 
-#: fortran/resolve.c:15037
+#: fortran/resolve.c:15057
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15049
+#: fortran/resolve.c:15069
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15065
+#: fortran/resolve.c:15085
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15073
+#: fortran/resolve.c:15093
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15080
+#: fortran/resolve.c:15100
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15092
+#: fortran/resolve.c:15112
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.c:15101
+#: fortran/resolve.c:15121
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15117
+#: fortran/resolve.c:15137
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15123
+#: fortran/resolve.c:15143
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15148
+#: fortran/resolve.c:15168
 #, fuzzy, gcc-internal-format
 msgid "Namelist %qs can not be an argument to subroutine or function at %L"
 msgstr "関数 `%s' への引数が少なすぎます"
 
-#: fortran/resolve.c:15218
+#: fortran/resolve.c:15238
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:15229
+#: fortran/resolve.c:15249
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:15333
+#: fortran/resolve.c:15353
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:15339
+#: fortran/resolve.c:15359
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:15345
+#: fortran/resolve.c:15365
 #, fuzzy, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "データ領域 '%s' は前の宣言と矛盾します"
 
-#: fortran/resolve.c:15354
+#: fortran/resolve.c:15374
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "`%s' に `extern' と初期化子の両方があります"
 
-#: fortran/resolve.c:15368
+#: fortran/resolve.c:15388
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:15414
+#: fortran/resolve.c:15434
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.c:15427
+#: fortran/resolve.c:15447
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.c:15526
+#: fortran/resolve.c:15546
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15534
+#: fortran/resolve.c:15554
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15542
+#: fortran/resolve.c:15562
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15667
+#: fortran/resolve.c:15687
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.c:15832
+#: fortran/resolve.c:15852
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "ラベル `%s' が定義されましたが使われていません"
 
-#: fortran/resolve.c:15838
+#: fortran/resolve.c:15858
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "ラベル `%s' が定義されましたが使われていません"
 
-#: fortran/resolve.c:15922
+#: fortran/resolve.c:15942
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15931
+#: fortran/resolve.c:15951
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15939
+#: fortran/resolve.c:15959
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:15955
+#: fortran/resolve.c:15975
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16058
+#: fortran/resolve.c:16078
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:16073
+#: fortran/resolve.c:16093
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:16098
+#: fortran/resolve.c:16118
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:16107
+#: fortran/resolve.c:16127
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16180
+#: fortran/resolve.c:16200
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16191
+#: fortran/resolve.c:16211
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16202
+#: fortran/resolve.c:16222
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr ""
 
-#: fortran/resolve.c:16293
+#: fortran/resolve.c:16253
+#, fuzzy, gcc-internal-format
+msgid "Self reference in character length expression for %qs at %L"
+msgstr "メソッド仕様内での構文解析エラー"
+
+#: fortran/resolve.c:16320
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.c:16306
+#: fortran/resolve.c:16333
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:16326
+#: fortran/resolve.c:16353
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:16336
+#: fortran/resolve.c:16363
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr ""
 
-#: fortran/resolve.c:16344
+#: fortran/resolve.c:16371
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:16358
+#: fortran/resolve.c:16385
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:16376
+#: fortran/resolve.c:16403
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:16383
+#: fortran/resolve.c:16410
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr ""
 
-#: fortran/resolve.c:16461
+#: fortran/resolve.c:16488
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -65743,19 +65827,12 @@
 msgid "simplify_min_max(): Bad type in arglist"
 msgstr ""
 
-#. Result is processor-dependent.
-#: fortran/simplify.c:5472
-#, gcc-internal-format, gfc-internal-format
-msgid "Second argument MOD at %L is zero"
-msgstr ""
-
-#. Result is processor-dependent.
-#: fortran/simplify.c:5483
-#, fuzzy, gcc-internal-format, gfc-internal-format
-msgid "Second argument of MOD at %L is zero"
+#: fortran/simplify.c:5470 fortran/simplify.c:5478
+#, fuzzy, gcc-internal-format
+msgid "Argument %qs of MOD at %L shall not be zero"
 msgstr "`%s' の第二引数は `char **' とすべきです"
 
-#: fortran/simplify.c:5494
+#: fortran/simplify.c:5484
 #, gcc-internal-format
 msgid "gfc_simplify_mod(): Bad arguments"
 msgstr ""
@@ -65763,98 +65840,98 @@
 #. Result is processor-dependent. This processor just opts
 #. to not handle it at all.
 #. Result is processor-dependent.
-#: fortran/simplify.c:5520 fortran/simplify.c:5532
+#: fortran/simplify.c:5525 fortran/simplify.c:5537
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of MODULO at %L is zero"
 msgstr ""
 
-#: fortran/simplify.c:5552
+#: fortran/simplify.c:5557
 #, gcc-internal-format
 msgid "gfc_simplify_modulo(): Bad arguments"
 msgstr ""
 
-#: fortran/simplify.c:5600
+#: fortran/simplify.c:5605
 #, gcc-internal-format, gfc-internal-format
 msgid "Result of NEAREST is NaN at %L"
 msgstr ""
 
-#: fortran/simplify.c:6081
+#: fortran/simplify.c:6086
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative at %L"
 msgstr ""
 
-#: fortran/simplify.c:6137
+#: fortran/simplify.c:6142
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument NCOPIES of REPEAT intrinsic is too large at %L"
 msgstr ""
 
-#: fortran/simplify.c:6174
+#: fortran/simplify.c:6179
 #, gcc-internal-format, gfc-internal-format
 msgid "Evaluation of string longer than 2**28 at %L deferred to runtime, expect bugs"
 msgstr ""
 
-#: fortran/simplify.c:6302
+#: fortran/simplify.c:6307
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "size of array is too large"
 msgid "Reshaped array too large at %C"
 msgstr "配列のサイズが大きすぎます"
 
-#: fortran/simplify.c:6416
+#: fortran/simplify.c:6421
 #, gcc-internal-format, gfc-internal-format
 msgid "Result of SCALE overflows its kind at %L"
 msgstr ""
 
-#: fortran/simplify.c:6995
+#: fortran/simplify.c:7000
 #, fuzzy, gcc-internal-format
 msgid "Bad type in gfc_simplify_sign"
 msgstr "定数式がオーバーフローしました"
 
-#: fortran/simplify.c:7024
+#: fortran/simplify.c:7029
 #, gcc-internal-format
 msgid "in gfc_simplify_sin(): Bad type"
 msgstr ""
 
-#: fortran/simplify.c:7151 fortran/simplify.c:7431
+#: fortran/simplify.c:7156 fortran/simplify.c:7436
 #, gcc-internal-format
 msgid "Failure getting length of a constant array."
 msgstr ""
 
-#: fortran/simplify.c:7161
+#: fortran/simplify.c:7166
 #, gcc-internal-format
 msgid "The number of elements (%d) in the array constructor at %L requires an increase of the allowed %d upper limit.  See %<-fmax-array-constructor%> option."
 msgstr ""
 
-#: fortran/simplify.c:7227
+#: fortran/simplify.c:7232
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Simplification of SPREAD at %C not yet implemented"
 msgstr "Trampoline は、まだ実装されていません"
 
-#: fortran/simplify.c:7251
+#: fortran/simplify.c:7256
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of SQRT at %L has a negative value"
 msgstr "関数呼び出しが集合体の値を持っています"
 
-#: fortran/simplify.c:7267
+#: fortran/simplify.c:7272
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid argument of SQRT at %L"
 msgstr "`%s' の引数として無効な型"
 
-#: fortran/simplify.c:7598
+#: fortran/simplify.c:7603
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY lower bound is %ld)"
 msgstr ""
 
-#: fortran/simplify.c:7621
+#: fortran/simplify.c:7626
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY upper bound is %ld)"
 msgstr ""
 
-#: fortran/simplify.c:7993
+#: fortran/simplify.c:7998
 #, gcc-internal-format
 msgid "gfc_convert_constant(): Unexpected type"
 msgstr ""
 
-#: fortran/simplify.c:8078
+#: fortran/simplify.c:8083
 #, gcc-internal-format
 msgid "Character %qs in string at %L cannot be converted into character kind %d"
 msgstr ""
@@ -65957,7 +66034,7 @@
 msgid "BIND(C) applied to %s %s at %L"
 msgstr ""
 
-#: fortran/symbol.c:901 fortran/symbol.c:912 fortran/symbol.c:1762
+#: fortran/symbol.c:901 fortran/symbol.c:912 fortran/symbol.c:1776
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute conflicts with %s attribute at %L"
 msgstr ""
@@ -66032,17 +66109,22 @@
 msgid "Duplicate VOLATILE attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1367
+#: fortran/symbol.c:1360
+#, fuzzy, gcc-internal-format, gfc-internal-format
+msgid "VOLATILE attribute at %L cannot be specified in a PURE procedure"
+msgstr "section 属性はローカル変数に対しては指定できません"
+
+#: fortran/symbol.c:1381
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ASYNCHRONOUS attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1758
+#: fortran/symbol.c:1772
 #, fuzzy, gcc-internal-format
 msgid "%s attribute of %qs conflicts with %s attribute at %L"
 msgstr "データ領域 '%s' は前の宣言と矛盾します"
 
-#: fortran/symbol.c:1794
+#: fortran/symbol.c:1808
 #, gcc-internal-format, gfc-internal-format
 msgid ""
 "%s procedure at %L is already declared as %s procedure. \n"
@@ -66049,208 +66131,208 @@
 "F2008: A pointer function assignment is ambiguous if it is the first executable statement after the specification block. Please add any other kind of executable statement before it. FIXME"
 msgstr ""
 
-#: fortran/symbol.c:1802
+#: fortran/symbol.c:1816
 #, gcc-internal-format, gfc-internal-format
 msgid "%s procedure at %L is already declared as %s procedure"
 msgstr ""
 
-#: fortran/symbol.c:1837
+#: fortran/symbol.c:1851
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgstr ""
 
-#: fortran/symbol.c:1861
+#: fortran/symbol.c:1875
 #, gcc-internal-format, gfc-internal-format
 msgid "ACCESS specification at %L was already specified"
 msgstr ""
 
-#: fortran/symbol.c:1878
+#: fortran/symbol.c:1892
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate BIND attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1885
+#: fortran/symbol.c:1899
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) at %L"
 msgstr ""
 
-#: fortran/symbol.c:1901
+#: fortran/symbol.c:1915
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate EXTENDS attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1905
+#: fortran/symbol.c:1919
 #, gcc-internal-format, gfc-internal-format
 msgid "EXTENDS at %L"
 msgstr ""
 
-#: fortran/symbol.c:1931
+#: fortran/symbol.c:1945
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L already has an explicit interface"
 msgstr "組み込み関数 `%s' は非関数として宣言されました"
 
-#: fortran/symbol.c:1938
+#: fortran/symbol.c:1952
 #, gcc-internal-format
 msgid "%qs at %L has attributes specified outside its INTERFACE body"
 msgstr ""
 
-#: fortran/symbol.c:1976
+#: fortran/symbol.c:1990
 #, gcc-internal-format
 msgid "Symbol %qs at %L conflicts with symbol from module %qs, use-associated at %L"
 msgstr ""
 
-#: fortran/symbol.c:1980
+#: fortran/symbol.c:1994
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr ""
 
-#: fortran/symbol.c:1987
+#: fortran/symbol.c:2001
 #, gcc-internal-format
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr ""
 
-#: fortran/symbol.c:1999
+#: fortran/symbol.c:2013
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L cannot have a type"
 msgstr "`%s' に `extern' と初期化子の両方があります"
 
-#: fortran/symbol.c:2242
+#: fortran/symbol.c:2256
 #, gcc-internal-format
 msgid "Component %qs at %C already in the parent type at %L"
 msgstr ""
 
-#: fortran/symbol.c:2327
+#: fortran/symbol.c:2341
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C is ambiguous"
 msgstr "%s: オプション `%s' はあいまいです\n"
 
-#: fortran/symbol.c:2359
+#: fortran/symbol.c:2373
 #, gcc-internal-format
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr ""
 
-#: fortran/symbol.c:2508
+#: fortran/symbol.c:2522
 #, gcc-internal-format
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr ""
 
-#: fortran/symbol.c:2529
+#: fortran/symbol.c:2543
 #, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure; did you mean %qs?"
 msgstr ""
 
-#: fortran/symbol.c:2533
+#: fortran/symbol.c:2547
 #, fuzzy, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr "%s に `%s' という名前のメンバはありません"
 
-#: fortran/symbol.c:2697
+#: fortran/symbol.c:2711
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr ""
 
-#: fortran/symbol.c:2708
+#: fortran/symbol.c:2722
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr ""
 
-#: fortran/symbol.c:2718
+#: fortran/symbol.c:2732
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr ""
 
-#: fortran/symbol.c:2724
+#: fortran/symbol.c:2738
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:2766
+#: fortran/symbol.c:2780
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr ""
 
-#: fortran/symbol.c:2775
+#: fortran/symbol.c:2789
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr ""
 
-#: fortran/symbol.c:2781
+#: fortran/symbol.c:2795
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Shared DO termination label %d at %C"
 msgstr "行番号 %u に戻るはずでした"
 
-#: fortran/symbol.c:3110
+#: fortran/symbol.c:3124
 #, gcc-internal-format
 msgid "new_symbol(): Symbol name too long"
 msgstr ""
 
-#: fortran/symbol.c:3135
+#: fortran/symbol.c:3149
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr ""
 
-#: fortran/symbol.c:3138
+#: fortran/symbol.c:3152
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
 msgstr ""
 
 #. Symbol is from another namespace.
-#: fortran/symbol.c:3381
+#: fortran/symbol.c:3395
 #, gcc-internal-format
 msgid "Symbol %qs at %C has already been host associated"
 msgstr ""
 
-#: fortran/symbol.c:4397
+#: fortran/symbol.c:4411
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr ""
 
-#: fortran/symbol.c:4410
+#: fortran/symbol.c:4424
 #, gcc-internal-format
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr ""
 
-#: fortran/symbol.c:4428
+#: fortran/symbol.c:4442
 #, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr ""
 
-#: fortran/symbol.c:4449
+#: fortran/symbol.c:4463
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:4459
+#: fortran/symbol.c:4473
 #, gcc-internal-format
 msgid "Procedure pointer component %qs at %L cannot be a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:4470
+#: fortran/symbol.c:4484
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:4509
+#: fortran/symbol.c:4523
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.c:4519
+#: fortran/symbol.c:4533
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/symbol.c:4533
+#: fortran/symbol.c:4547
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot be declared with both PRIVATE and BIND(C) attributes"
 msgstr ""
 
-#: fortran/symbol.c:4541
+#: fortran/symbol.c:4555
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.c:5018 fortran/symbol.c:5023
+#: fortran/symbol.c:5032 fortran/symbol.c:5037
 #, gcc-internal-format
 msgid "Symbol %qs is used before it is typed at %L"
 msgstr ""
@@ -66298,7 +66380,7 @@
 msgid "Creating array temporary at %L for argument %qs"
 msgstr "一時オブジェクトへの参照を返そうとしています"
 
-#: fortran/trans-array.c:10693
+#: fortran/trans-array.c:10724
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr ""
@@ -66501,12 +66583,12 @@
 msgid "%<dim%> argument of %s intrinsic at %L is not a valid dimension index"
 msgstr "`__builtin_args_info' の引数は定数でなければなりません"
 
-#: fortran/trans-intrinsic.c:10572 fortran/trans-stmt.c:1050
+#: fortran/trans-intrinsic.c:10574 fortran/trans-stmt.c:1050
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, the event component of derived type at %L is not yet supported"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:10579
+#: fortran/trans-intrinsic.c:10581
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "environment variable %qs not defined"
 msgid "The event variable at %L shall not be coindexed"
@@ -66547,7 +66629,7 @@
 msgid "Sorry, only support for integer kind %d implemented for image-set at %L"
 msgstr ""
 
-#: fortran/trans-stmt.c:3346
+#: fortran/trans-stmt.c:3343
 #, gcc-internal-format
 msgid "gfc_trans_select(): Bad type for case expr."
 msgstr ""
@@ -66676,7 +66758,7 @@
 msgid "two or more sections for %s"
 msgstr ""
 
-#: lto/lto-partition.c:516
+#: lto/lto-partition.c:570
 #, gcc-internal-format
 msgid "min partition size cannot be greater than max partition size"
 msgstr ""
@@ -66818,59 +66900,59 @@
 msgid "Cannot read %s"
 msgstr "%s を開けません"
 
-#: lto/lto.c:2369
+#: lto/lto.c:2337
 #, gcc-internal-format
 msgid "lto_obj_file_open() failed"
 msgstr ""
 
-#: lto/lto.c:2394
+#: lto/lto.c:2362
 #, fuzzy, gcc-internal-format
 #| msgid "atexit failed"
 msgid "waitpid failed"
 msgstr "atexit に失敗しました"
 
-#: lto/lto.c:2397
+#: lto/lto.c:2365
 #, fuzzy, gcc-internal-format
 #| msgid "renaming .rpo file"
 msgid "streaming subprocess failed"
 msgstr ".rpo ファイルの名前を変更しています"
 
-#: lto/lto.c:2400
+#: lto/lto.c:2368
 #, gcc-internal-format
 msgid "streaming subprocess was killed by signal"
 msgstr ""
 
-#: lto/lto.c:2476
+#: lto/lto.c:2445
 #, gcc-internal-format
 msgid "no LTRANS output list filename provided"
 msgstr ""
 
-#: lto/lto.c:2564
+#: lto/lto.c:2525
 #, gcc-internal-format
 msgid "opening LTRANS output list %s: %m"
 msgstr ""
 
-#: lto/lto.c:2570
+#: lto/lto.c:2532
 #, gcc-internal-format
 msgid "writing to LTRANS output list %s: %m"
 msgstr ""
 
-#: lto/lto.c:2581
+#: lto/lto.c:2542
 #, gcc-internal-format
 msgid "closing LTRANS output list %s: %m"
 msgstr ""
 
-#: lto/lto.c:2833
+#: lto/lto.c:2794
 #, gcc-internal-format
 msgid "could not open symbol resolution file: %m"
 msgstr ""
 
-#: lto/lto.c:2954
+#: lto/lto.c:2915
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing resolution data for %s"
 msgstr "初期化子のまわりのブレースを欠いています"
 
-#: lto/lto.c:2986
+#: lto/lto.c:2947
 #, gcc-internal-format
 msgid "errors during merging of translation units"
 msgstr ""
@@ -67813,6 +67895,15 @@
 msgid "creating selector for nonexistent method %qE"
 msgstr ""
 
+#, fuzzy
+#~| msgid "nonconstant array index in initializer"
+#~ msgid "Expected constant array-spec in initializer list at %L"
+#~ msgstr "初期化子内に非定数の配列インデックスがあります"
+
+#, fuzzy
+#~ msgid "Second argument of MOD at %L is zero"
+#~ msgstr "`%s' の第二引数は `char **' とすべきです"
+
 #~ msgid "pex_init failed"
 #~ msgstr "pex_init に失敗しました"
 
Index: gcc/po/zh_TW.po
===================================================================
--- gcc/po/zh_TW.po	(.../tags/gcc_8_2_0_release)
+++ gcc/po/zh_TW.po	(.../branches/gcc-8-branch)
@@ -8,7 +8,7 @@
 msgstr ""
 "Project-Id-Version: gcc 4.8.0\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2018-05-01 20:30+0000\n"
+"POT-Creation-Date: 2018-07-25 14:25+0000\n"
 "PO-Revision-Date: 2013-06-07 23:29+0800\n"
 "Last-Translator: Wei-Lun Chao <bluebat@member.fsf.org>\n"
 "Language-Team: Chinese (traditional) <zh-l10n@linux.org.tw>\n"
@@ -40,35 +40,35 @@
 msgid "[cannot find %s]"
 msgstr "[找不到 %s]"
 
-#: collect2.c:1557
+#: collect2.c:1585
 #, fuzzy, c-format
 msgid "collect2 version %s\n"
 msgstr "collect2 版本 %s\n"
 
-#: collect2.c:1664
+#: collect2.c:1692
 #, fuzzy, c-format
 msgid "%d constructor found\n"
 msgid_plural "%d constructors found\n"
 msgstr[0] "%d 建構子找到\n"
 
-#: collect2.c:1668
+#: collect2.c:1696
 #, fuzzy, c-format
 msgid "%d destructor found\n"
 msgid_plural "%d destructors found\n"
 msgstr[0] "%d 解構式找到\n"
 
-#: collect2.c:1672
+#: collect2.c:1700
 #, fuzzy, c-format
 msgid "%d frame table found\n"
 msgid_plural "%d frame tables found\n"
 msgstr[0] "%d 影格表格找到\n"
 
-#: collect2.c:1836
+#: collect2.c:1864
 #, c-format
 msgid "[Leaving %s]\n"
 msgstr "[離開 %s]\n"
 
-#: collect2.c:2068
+#: collect2.c:2094
 #, c-format
 msgid ""
 "\n"
@@ -77,7 +77,7 @@
 "\n"
 "write_c_file - 輸出名為 %s，字首為 %s\n"
 
-#: collect2.c:2584
+#: collect2.c:2610
 #, c-format
 msgid ""
 "\n"
@@ -101,7 +101,7 @@
 msgid "%s: some warnings being treated as errors"
 msgstr "%s：某些警告被視為錯誤"
 
-#: diagnostic.c:324 input.c:222 input.c:1834 c-family/c-opts.c:1377
+#: diagnostic.c:324 input.c:222 input.c:1834 c-family/c-opts.c:1392
 #: fortran/cpp.c:576 fortran/error.c:1008 fortran/error.c:1028
 msgid "<built-in>"
 msgstr "<built-in>"
@@ -194,13 +194,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:4164 config/arc/arc.c:5784 config/i386/i386.c:17302
+#: final.c:4164 config/arc/arc.c:5775 config/i386/i386.c:17305
 #: config/pdp11/pdp11.c:1715
 #, c-format
 msgid "floating constant misused"
 msgstr "錯誤地使用了浮點常數"
 
-#: final.c:4222 config/arc/arc.c:5881 config/i386/i386.c:17393
+#: final.c:4222 config/arc/arc.c:5872 config/i386/i386.c:17396
 #: config/pdp11/pdp11.c:1756
 #, c-format
 msgid "invalid expression as operand"
@@ -1194,7 +1194,7 @@
 msgid "GCSE disabled"
 msgstr "GCSE 被停用"
 
-#: gimple-ssa-isolate-paths.c:542 c/c-typeck.c:10240
+#: gimple-ssa-isolate-paths.c:542 c/c-typeck.c:10245
 #, gcc-internal-format
 msgid "function returns address of local variable"
 msgstr "函式回傳局部變數的位址"
@@ -1517,7 +1517,7 @@
 msgid "options enabled: "
 msgstr "啟用的選項："
 
-#: tree-diagnostic.c:299 c/c-decl.c:5419 c/c-typeck.c:7259 cp/error.c:1042
+#: tree-diagnostic.c:299 c/c-decl.c:5439 c/c-typeck.c:7264 cp/error.c:1042
 #: c-family/c-pretty-print.c:413
 #, gcc-internal-format
 msgid "<anonymous>"
@@ -3047,65 +3047,65 @@
 msgstr "strfmon 格式的長度修飾符"
 
 #. Handle deferred options from command-line.
-#: c-family/c-opts.c:1402 fortran/cpp.c:590
+#: c-family/c-opts.c:1417 fortran/cpp.c:590
 #, fuzzy
 msgid "<command-line>"
 msgstr "<command-line>"
 
-#: config/aarch64/aarch64.c:6613
+#: config/aarch64/aarch64.c:6629
 #, fuzzy, c-format
 msgid "unsupported operand for code '%c'"
 msgstr "不受支援的運算元用於編碼『%c』"
 
-#: config/aarch64/aarch64.c:6624 config/aarch64/aarch64.c:6640
-#: config/aarch64/aarch64.c:6652 config/aarch64/aarch64.c:6663
-#: config/aarch64/aarch64.c:6673 config/aarch64/aarch64.c:6694
-#: config/aarch64/aarch64.c:6764 config/aarch64/aarch64.c:6775
-#: config/aarch64/aarch64.c:6789 config/aarch64/aarch64.c:7011
-#: config/aarch64/aarch64.c:7029
+#: config/aarch64/aarch64.c:6640 config/aarch64/aarch64.c:6656
+#: config/aarch64/aarch64.c:6668 config/aarch64/aarch64.c:6679
+#: config/aarch64/aarch64.c:6689 config/aarch64/aarch64.c:6710
+#: config/aarch64/aarch64.c:6780 config/aarch64/aarch64.c:6791
+#: config/aarch64/aarch64.c:6805 config/aarch64/aarch64.c:7027
+#: config/aarch64/aarch64.c:7045
 #, fuzzy, c-format
 msgid "invalid operand for '%%%c'"
 msgstr "程式碼「%c」的運算元無效"
 
-#: config/aarch64/aarch64.c:6709 config/aarch64/aarch64.c:6720
-#: config/aarch64/aarch64.c:6871 config/aarch64/aarch64.c:6882
+#: config/aarch64/aarch64.c:6725 config/aarch64/aarch64.c:6736
+#: config/aarch64/aarch64.c:6887 config/aarch64/aarch64.c:6898
 #, fuzzy, c-format
 msgid "invalid vector constant"
 msgstr "無效指令："
 
-#: config/aarch64/aarch64.c:6732 config/aarch64/aarch64.c:6744
-#: config/aarch64/aarch64.c:6755
+#: config/aarch64/aarch64.c:6748 config/aarch64/aarch64.c:6760
+#: config/aarch64/aarch64.c:6771
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6823 config/arm/arm.c:22704
+#: config/aarch64/aarch64.c:6839 config/arm/arm.c:22704
 #, c-format
 msgid "missing operand"
 msgstr "缺少運算元"
 
-#: config/aarch64/aarch64.c:6908
+#: config/aarch64/aarch64.c:6924
 #, fuzzy, c-format
 msgid "invalid constant"
 msgstr "無效指令："
 
-#: config/aarch64/aarch64.c:6911
+#: config/aarch64/aarch64.c:6927
 #, fuzzy, c-format
 msgid "invalid operand"
 msgstr "無效的 %%d 運算元"
 
-#: config/aarch64/aarch64.c:7040 config/aarch64/aarch64.c:7045
+#: config/aarch64/aarch64.c:7056 config/aarch64/aarch64.c:7061
 #, fuzzy, c-format
 msgid "invalid operand prefix '%%%c'"
 msgstr "無效的運算元程式碼「%c」"
 
-#: config/aarch64/aarch64.c:7062
+#: config/aarch64/aarch64.c:7078
 #, fuzzy, c-format
 msgid "invalid address mode"
 msgstr "無效的定址模式"
 
-#: config/alpha/alpha.c:5125 config/i386/i386.c:18558
-#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21798
+#: config/alpha/alpha.c:5125 config/i386/i386.c:18561
+#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21875
 #: config/sparc/sparc.c:9290
 #, fuzzy, c-format
 msgid "'%%&' used without any local dynamic TLS references"
@@ -3122,7 +3122,7 @@
 msgstr "無效 %%r 值"
 
 #: config/alpha/alpha.c:5223 config/ia64/ia64.c:5534
-#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21506
+#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21583
 #: config/xtensa/xtensa.c:2429
 #, c-format
 msgid "invalid %%R value"
@@ -3129,13 +3129,13 @@
 msgstr "無效 %%R 值"
 
 #: config/alpha/alpha.c:5229 config/powerpcspe/powerpcspe.c:23933
-#: config/rs6000/rs6000.c:21426 config/xtensa/xtensa.c:2396
+#: config/rs6000/rs6000.c:21503 config/xtensa/xtensa.c:2396
 #, c-format
 msgid "invalid %%N value"
 msgstr "無效 %%N 值"
 
 #: config/alpha/alpha.c:5237 config/powerpcspe/powerpcspe.c:23961
-#: config/rs6000/rs6000.c:21454
+#: config/rs6000/rs6000.c:21531
 #, c-format
 msgid "invalid %%P value"
 msgstr "無效 %%P 值"
@@ -3166,7 +3166,7 @@
 msgstr "無效 %%U 值"
 
 #: config/alpha/alpha.c:5323 config/powerpcspe/powerpcspe.c:24021
-#: config/rs6000/rs6000.c:21514
+#: config/rs6000/rs6000.c:21591
 #, c-format
 msgid "invalid %%s value"
 msgstr "無效 %%s 值"
@@ -3177,7 +3177,7 @@
 msgstr "無效 %%C 值"
 
 #: config/alpha/alpha.c:5371 config/powerpcspe/powerpcspe.c:23797
-#: config/rs6000/rs6000.c:21290
+#: config/rs6000/rs6000.c:21367
 #, c-format
 msgid "invalid %%E value"
 msgstr "無效 %%E 值"
@@ -3188,7 +3188,7 @@
 msgstr "不明的不可預期重定位"
 
 #: config/alpha/alpha.c:5405 config/cr16/cr16.c:1569
-#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21803
+#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21880
 #: config/spu/spu.c:1458
 #, c-format
 msgid "invalid %%xn code"
@@ -3199,61 +3199,61 @@
 msgid "invalid operand address"
 msgstr "無效的 %%d 運算元"
 
-#: config/arc/arc.c:3810
+#: config/arc/arc.c:3808
 #, fuzzy, c-format
 #| msgid "invalid operand to %%s code"
 msgid "invalid operand to %%Z code"
 msgstr "%%s 程式碼的運算元無效"
 
-#: config/arc/arc.c:3818
+#: config/arc/arc.c:3816
 #, fuzzy, c-format
 #| msgid "invalid operand to %%s code"
 msgid "invalid operand to %%z code"
 msgstr "%%s 程式碼的運算元無效"
 
-#: config/arc/arc.c:3826
+#: config/arc/arc.c:3824
 #, fuzzy, c-format
 #| msgid "invalid operand to %%s code"
 msgid "invalid operands to %%c code"
 msgstr "%%s 程式碼的運算元無效"
 
-#: config/arc/arc.c:3834
+#: config/arc/arc.c:3832
 #, fuzzy, c-format
 #| msgid "invalid operand to %%s code"
 msgid "invalid operand to %%M code"
 msgstr "%%s 程式碼的運算元無效"
 
-#: config/arc/arc.c:3842 config/m32r/m32r.c:2100
+#: config/arc/arc.c:3840 config/m32r/m32r.c:2100
 #, c-format
 msgid "invalid operand to %%p code"
 msgstr "%%p 程式碼的運算元無效"
 
-#: config/arc/arc.c:3853 config/m32r/m32r.c:2093
+#: config/arc/arc.c:3851 config/m32r/m32r.c:2093
 #, c-format
 msgid "invalid operand to %%s code"
 msgstr "%%s 程式碼的運算元無效"
 
-#: config/arc/arc.c:4001 config/m32r/m32r.c:2126
+#: config/arc/arc.c:3999 config/m32r/m32r.c:2126
 #, c-format
 msgid "invalid operand to %%R code"
 msgstr "%%R 程式碼的運算元無效"
 
-#: config/arc/arc.c:4077 config/m32r/m32r.c:2149
+#: config/arc/arc.c:4075 config/m32r/m32r.c:2149
 #, c-format
 msgid "invalid operand to %%H/%%L code"
 msgstr "%%H/%%L 程式碼的運算元無效"
 
-#: config/arc/arc.c:4145 config/m32r/m32r.c:2220
+#: config/arc/arc.c:4143 config/m32r/m32r.c:2220
 #, c-format
 msgid "invalid operand to %%U code"
 msgstr "%%U 程式碼的運算元無效"
 
-#: config/arc/arc.c:4157
+#: config/arc/arc.c:4155
 #, c-format
 msgid "invalid operand to %%V code"
 msgstr "%%V 程式碼的運算元無效"
 
-#: config/arc/arc.c:4214
+#: config/arc/arc.c:4212
 #, fuzzy, c-format
 #| msgid "invalid operand to %%s code"
 msgid "invalid operand to %%O code"
@@ -3261,19 +3261,19 @@
 
 #. Unknown flag.
 #. Undocumented flag.
-#: config/arc/arc.c:4240 config/epiphany/epiphany.c:1305
-#: config/m32r/m32r.c:2247 config/nds32/nds32.c:3079 config/sparc/sparc.c:9569
+#: config/arc/arc.c:4238 config/epiphany/epiphany.c:1305
+#: config/m32r/m32r.c:2247 config/nds32/nds32.c:3080 config/sparc/sparc.c:9569
 #, c-format
 msgid "invalid operand output code"
 msgstr "無效的運算元輸出程式碼"
 
-#: config/arc/arc.c:5869
+#: config/arc/arc.c:5860
 #, fuzzy, c-format
 #| msgid "invalid UNSPEC as operand"
 msgid "invalid UNSPEC as operand: %d"
 msgstr "無效的 UNSPEC 做為運算元"
 
-#: config/arc/arc.c:6158 config/cris/cris.c:2568
+#: config/arc/arc.c:6149 config/cris/cris.c:2568
 msgid "unrecognized supposed constant"
 msgstr "預期的常數無法識別"
 
@@ -3308,7 +3308,7 @@
 #: config/arm/arm.c:22685 config/arm/arm.c:22692 config/bfin/bfin.c:1441
 #: config/bfin/bfin.c:1448 config/bfin/bfin.c:1455 config/bfin/bfin.c:1462
 #: config/bfin/bfin.c:1471 config/bfin/bfin.c:1478 config/bfin/bfin.c:1485
-#: config/bfin/bfin.c:1492 config/nds32/nds32.c:3098
+#: config/bfin/bfin.c:1492 config/nds32/nds32.c:3099
 #, c-format
 msgid "invalid operand for code '%c'"
 msgstr "程式碼「%c」的運算元無效"
@@ -3658,99 +3658,99 @@
 msgid "bad output_condmove_single operand"
 msgstr "錯誤的 output_condmove_single 運算元"
 
-#: config/i386/i386.c:17387
+#: config/i386/i386.c:17390
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "無效的 UNSPEC 做為運算元"
 
-#: config/i386/i386.c:17925
+#: config/i386/i386.c:17928
 #, fuzzy, c-format
 #| msgid "invalid use of %<restrict%>"
 msgid "invalid use of register '%s'"
 msgstr "錯誤地使用了 %<restrict%>"
 
-#: config/i386/i386.c:17930
+#: config/i386/i386.c:17933
 #, fuzzy, c-format
 #| msgid "invalid lvalue in asm output %d"
 msgid "invalid use of asm flag output"
 msgstr "組譯輸出 %d 中左值無效"
 
-#: config/i386/i386.c:18160
+#: config/i386/i386.c:18163
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr "無效的運算元大小用於運算元編碼『%c』"
 
-#: config/i386/i386.c:18195
+#: config/i386/i386.c:18198
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr "無效的運算元大小用於運算元編碼『%c』"
 
-#: config/i386/i386.c:18264
+#: config/i386/i386.c:18267
 #, fuzzy, c-format
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "無效的運算元類型使用的與運算元編碼『%c』"
 
-#: config/i386/i386.c:18269
+#: config/i386/i386.c:18272
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'Z'"
 msgstr "無效的運算元大小用於運算元編碼『%c』"
 
-#: config/i386/i386.c:18346
+#: config/i386/i386.c:18349
 #, fuzzy, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "運算元並非條件編碼，無效的運算元編碼『Y』"
 
-#: config/i386/i386.c:18425
+#: config/i386/i386.c:18428
 #, fuzzy, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "運算元並非條件編碼，無效的運算元編碼『D』"
 
-#: config/i386/i386.c:18443
+#: config/i386/i386.c:18446
 #, fuzzy, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "運算元並非條件編碼，無效的運算元編碼『D』"
 
-#: config/i386/i386.c:18456
+#: config/i386/i386.c:18459
 #, fuzzy, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "運算元不是 offsettable 記憶體參考，無效的運算元編碼『H』"
 
-#: config/i386/i386.c:18471
+#: config/i386/i386.c:18474
 #, fuzzy, c-format
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr "運算元並非條件編碼，無效的運算元編碼『Y』"
 
-#: config/i386/i386.c:18499
+#: config/i386/i386.c:18502
 #, fuzzy, c-format
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr "運算元並非條件編碼，無效的運算元編碼『Y』"
 
-#: config/i386/i386.c:18517
+#: config/i386/i386.c:18520
 #, fuzzy, c-format
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr "運算元並非條件編碼，無效的運算元編碼『Y』"
 
-#: config/i386/i386.c:18540
+#: config/i386/i386.c:18543
 #, fuzzy, c-format
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "運算元並非條件編碼，無效的運算元編碼『Y』"
 
-#: config/i386/i386.c:18626
+#: config/i386/i386.c:18629
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "無效的運算元程式碼「%c」"
 
-#: config/i386/i386.c:18688
+#: config/i386/i386.c:18691
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "運算元的約束無效"
 
-#: config/i386/i386.c:18738
+#: config/i386/i386.c:18741
 #, fuzzy, c-format
 msgid "invalid vector immediate"
 msgstr "無效的控制述詞"
 
-#: config/i386/i386.c:29572
+#: config/i386/i386.c:29575
 msgid "unknown insn mode"
 msgstr "不明的指令模式"
 
@@ -3789,7 +3789,7 @@
 msgstr "無效的 %%P 運算元"
 
 #: config/iq2000/iq2000.c:3185 config/powerpcspe/powerpcspe.c:23951
-#: config/rs6000/rs6000.c:21444
+#: config/rs6000/rs6000.c:21521
 #, c-format
 msgid "invalid %%p value"
 msgstr "無效的 %%p 值"
@@ -3846,7 +3846,7 @@
 msgstr "後自增位址不是一個暫存器"
 
 #: config/m32r/m32r.c:2350 config/m32r/m32r.c:2365
-#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33292
+#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33348
 msgid "bad address"
 msgstr "錯誤位址"
 
@@ -3966,202 +3966,202 @@
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr "嘗試在命令解譯器中執行「%s」以提升它的極值。\n"
 
-#: config/powerpcspe/powerpcspe.c:4411 config/rs6000/rs6000.c:4258
+#: config/powerpcspe/powerpcspe.c:4411 config/rs6000/rs6000.c:4278
 msgid "-maltivec=le not allowed for big-endian targets"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4423 config/rs6000/rs6000.c:4273
+#: config/powerpcspe/powerpcspe.c:4423 config/rs6000/rs6000.c:4293
 #, fuzzy
 msgid "-mvsx requires hardware floating point"
 msgstr "-mvsx 需求硬體浮點數"
 
-#: config/powerpcspe/powerpcspe.c:4431 config/rs6000/rs6000.c:4281
+#: config/powerpcspe/powerpcspe.c:4431 config/rs6000/rs6000.c:4301
 #, fuzzy
 msgid "-mvsx and -mpaired are incompatible"
 msgstr "-mvsx 和 -mpaired 是不相容的"
 
-#: config/powerpcspe/powerpcspe.c:4433 config/rs6000/rs6000.c:4283
+#: config/powerpcspe/powerpcspe.c:4433 config/rs6000/rs6000.c:4303
 #, fuzzy
 msgid "-mvsx needs indexed addressing"
 msgstr "-mvsx 需要索引的定址"
 
-#: config/powerpcspe/powerpcspe.c:4438 config/rs6000/rs6000.c:4288
+#: config/powerpcspe/powerpcspe.c:4438 config/rs6000/rs6000.c:4308
 #, fuzzy
 msgid "-mvsx and -mno-altivec are incompatible"
 msgstr "-mvsx 和 -mno-altivec 是不相容的"
 
-#: config/powerpcspe/powerpcspe.c:4440 config/rs6000/rs6000.c:4290
+#: config/powerpcspe/powerpcspe.c:4440 config/rs6000/rs6000.c:4310
 #, fuzzy
 msgid "-mno-altivec disables vsx"
 msgstr "-mno-altivec 停用 vsx"
 
-#: config/powerpcspe/powerpcspe.c:4648 config/rs6000/rs6000.c:4416
+#: config/powerpcspe/powerpcspe.c:4648 config/rs6000/rs6000.c:4436
 #, fuzzy
 #| msgid "--resource requires -o"
 msgid "-mquad-memory requires 64-bit mode"
 msgstr "--resource 需要 -o"
 
-#: config/powerpcspe/powerpcspe.c:4651 config/rs6000/rs6000.c:4419
+#: config/powerpcspe/powerpcspe.c:4651 config/rs6000/rs6000.c:4439
 msgid "-mquad-memory-atomic requires 64-bit mode"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4663 config/rs6000/rs6000.c:4431
+#: config/powerpcspe/powerpcspe.c:4663 config/rs6000/rs6000.c:4451
 #, fuzzy
 #| msgid "Generate code in little endian mode"
 msgid "-mquad-memory is not available in little endian mode"
 msgstr "產生低位位元組在前的程式碼"
 
-#: config/powerpcspe/powerpcspe.c:4735 config/rs6000/rs6000.c:4512
+#: config/powerpcspe/powerpcspe.c:4735 config/rs6000/rs6000.c:4532
 #, fuzzy
 #| msgid "--resource requires -o"
 msgid "-mtoc-fusion requires 64-bit"
 msgstr "--resource 需要 -o"
 
-#: config/powerpcspe/powerpcspe.c:4742 config/rs6000/rs6000.c:4519
+#: config/powerpcspe/powerpcspe.c:4742 config/rs6000/rs6000.c:4539
 msgid "-mtoc-fusion requires medium/large code model"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10915
+#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10947
 #, fuzzy
 msgid "bad move"
 msgstr "不當的移動"
 
-#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21087
+#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21164
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21278
+#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21355
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%e value"
 msgstr "無效 %%H 值"
 
-#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21299
+#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21376
 #, c-format
 msgid "invalid %%f value"
 msgstr "無效 %%f 值"
 
-#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21308
+#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21385
 #, c-format
 msgid "invalid %%F value"
 msgstr "無效 %%F 值"
 
-#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21317
+#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21394
 #, c-format
 msgid "invalid %%G value"
 msgstr "無效 %%G 值"
 
-#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21352
+#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21429
 #, c-format
 msgid "invalid %%j code"
 msgstr "無效 %%j 程式碼"
 
-#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21362
+#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21439
 #, c-format
 msgid "invalid %%J code"
 msgstr "無效 %%J 程式碼"
 
-#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21372
+#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21449
 #, c-format
 msgid "invalid %%k value"
 msgstr "無效 %%k 值"
 
-#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21387
+#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21464
 #: config/xtensa/xtensa.c:2415
 #, c-format
 msgid "invalid %%K value"
 msgstr "無效 %%K 值"
 
-#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21434
+#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21511
 #, c-format
 msgid "invalid %%O value"
 msgstr "無效 %%O 值"
 
-#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21481
+#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21558
 #, c-format
 msgid "invalid %%q value"
 msgstr "無效 %%q 值"
 
-#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21534
+#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21611
 #, c-format
 msgid "invalid %%T value"
 msgstr "無效 %%T 值"
 
-#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21546
+#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21623
 #, c-format
 msgid "invalid %%u value"
 msgstr "無效 %%u 值"
 
-#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21560
+#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21637
 #: config/xtensa/xtensa.c:2384
 #, c-format
 msgid "invalid %%v value"
 msgstr "無效 %%v 值"
 
-#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21627
+#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21704
 #: config/xtensa/xtensa.c:2436
 #, c-format
 msgid "invalid %%x value"
 msgstr "無效的 %%x 值"
 
-#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21747
+#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21824
 #, fuzzy, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "無效的 %%y 值，嘗試使用『Z』條件約束"
 
-#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22282
+#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22359
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22288
+#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22365
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22294
+#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22371
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36572
+#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36628
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "傳遞 AltiVec 引數給無原型的函式"
 
-#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38739
+#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38795
 #, fuzzy
 #| msgid "Do not generate a single exit point for each function"
 msgid "Could not generate addis value for fusion"
 msgstr "不為每個函式產生單一的離開點"
 
-#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38809
+#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38865
 #, fuzzy
 #| msgid "unable to generate reloads for:"
 msgid "Unable to generate load/store offset for fusion"
 msgstr "無法產生重新載入，為："
 
-#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38908
+#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38964
 msgid "Bad GPR fusion"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39126
+#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39182
 msgid "emit_fusion_p9_load, bad reg #1"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39172
+#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39228
 msgid "emit_fusion_p9_load, bad reg #2"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39175
+#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39231
 msgid "emit_fusion_p9_load not MEM"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39213
+#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39269
 msgid "emit_fusion_p9_store, bad reg #1"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39259
+#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39315
 msgid "emit_fusion_p9_store, bad reg #2"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39262
+#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39318
 msgid "emit_fusion_p9_store not MEM"
 msgstr ""
 
@@ -4550,14 +4550,14 @@
 #: c/gimple-parser.c:188 c/gimple-parser.c:197 c/gimple-parser.c:226
 #: c/gimple-parser.c:1375 c/gimple-parser.c:1404 c/gimple-parser.c:1484
 #: c/gimple-parser.c:1511 c/c-parser.c:3204 c/c-parser.c:9967
-#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27841
-#: cp/parser.c:28430
+#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27838
+#: cp/parser.c:28427
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "需要 %<;%>"
 
 #: c/c-parser.c:2431 c/c-parser.c:7573 c/c-parser.c:8015 c/c-parser.c:8058
-#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27839 cp/parser.c:28448
+#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27836 cp/parser.c:28445
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "預期 %<,%>"
@@ -4572,7 +4572,7 @@
 #: c/gimple-parser.c:821 c/gimple-parser.c:837 c/gimple-parser.c:853
 #: c/gimple-parser.c:880 c/gimple-parser.c:915 c/gimple-parser.c:1038
 #: c/gimple-parser.c:1209 c/gimple-parser.c:1220 c/gimple-parser.c:1342
-#: c/gimple-parser.c:1441 cp/parser.c:28478
+#: c/gimple-parser.c:1441 cp/parser.c:28475
 #, fuzzy, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "預期 %<)%>"
@@ -4580,7 +4580,7 @@
 #: c/c-parser.c:3824 c/c-parser.c:4733 c/c-parser.c:4769 c/c-parser.c:6441
 #: c/c-parser.c:8125 c/c-parser.c:8983 c/c-parser.c:9127 c/c-parser.c:11588
 #: c/c-parser.c:18220 c/c-parser.c:18222 c/gimple-parser.c:1015
-#: cp/parser.c:28442
+#: cp/parser.c:28439
 #, fuzzy, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "預期 %<]%>"
@@ -4595,7 +4595,7 @@
 #: c/c-parser.c:17792 c/gimple-parser.c:363 c/gimple-parser.c:811
 #: c/gimple-parser.c:873 c/gimple-parser.c:911 c/gimple-parser.c:1198
 #: c/gimple-parser.c:1339 c/gimple-parser.c:1438 c/c-parser.c:11911
-#: cp/parser.c:28433
+#: cp/parser.c:28430
 #, fuzzy, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "預期 %<(%>"
@@ -4602,7 +4602,7 @@
 
 #: c/c-parser.c:4903 c/c-parser.c:10310 c/c-parser.c:16212 c/c-parser.c:18449
 #: c/gimple-parser.c:141 c/gimple-parser.c:1444 c/c-parser.c:3018
-#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18155 cp/parser.c:28439
+#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18152 cp/parser.c:28436
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "需要 %<{%>"
@@ -4612,13 +4612,13 @@
 #: c/c-parser.c:12351 c/c-parser.c:12493 c/c-parser.c:12864 c/c-parser.c:12957
 #: c/c-parser.c:13566 c/c-parser.c:17636 c/c-parser.c:17695
 #: c/gimple-parser.c:431 c/gimple-parser.c:1492 c/gimple-parser.c:1519
-#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28472 cp/parser.c:29597
-#: cp/parser.c:32279
+#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28469 cp/parser.c:29594
+#: cp/parser.c:32276
 #, fuzzy, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "預期 %<:%>"
 
-#: c/c-parser.c:5974 cp/parser.c:28365
+#: c/c-parser.c:5974 cp/parser.c:28362
 #, fuzzy, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "預期 %<while%>"
@@ -4628,18 +4628,18 @@
 msgid "expected %<.%>"
 msgstr "預期 %<.%>"
 
-#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30172
-#: cp/parser.c:30246
+#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30169
+#: cp/parser.c:30243
 #, fuzzy, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "預期 %<@end%>"
 
-#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28457
+#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28454
 #, fuzzy, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "預期 %<>%>"
 
-#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28481
+#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28478
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "預期 %<,%>或 %<)%>"
@@ -4647,33 +4647,33 @@
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15190 c/c-parser.c:15234 c/c-parser.c:15466 c/c-parser.c:15701
 #: c/c-parser.c:17833 c/gimple-parser.c:286 c/c-parser.c:4792
-#: cp/parser.c:28460
+#: cp/parser.c:28457
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "需要 %<=%>"
 
-#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28436
-#: cp/parser.c:30389
+#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28433
+#: cp/parser.c:30386
 #, fuzzy, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "預期 %<}%>"
 
-#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35674
+#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35671
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "預期 %<# pragma omp section%>或 %<}%>"
 
-#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28445 cp/parser.c:31535
+#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28442 cp/parser.c:31532
 #, fuzzy, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "預期 %<[%>"
 
-#: c/c-typeck.c:7847
+#: c/c-typeck.c:7852
 #, fuzzy
 msgid "(anonymous)"
 msgstr "(匿名)"
 
-#: c/gimple-parser.c:795 cp/parser.c:15791 cp/parser.c:28454
+#: c/gimple-parser.c:795 cp/parser.c:15788 cp/parser.c:28451
 #, fuzzy, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "預期 %<<%>"
@@ -4969,11 +4969,11 @@
 msgid "%r%s:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr "%s:%d：  在中 constexpr 擴展的 %qs"
 
-#: cp/pt.c:1949 cp/semantics.c:5268
+#: cp/pt.c:1949 cp/semantics.c:5271
 msgid "candidates are:"
 msgstr "備選為："
 
-#: cp/pt.c:1951 cp/pt.c:22975
+#: cp/pt.c:1951 cp/pt.c:23053
 #, fuzzy
 msgid "candidate is:"
 msgid_plural "candidates are:"
@@ -5029,27 +5029,27 @@
 msgid "source type is not polymorphic"
 msgstr "來源型態不是 polymorphic"
 
-#: cp/typeck.c:6083 c/c-typeck.c:4261
+#: cp/typeck.c:6083 c/c-typeck.c:4266
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "單位元減的運算元類型錯誤"
 
-#: cp/typeck.c:6084 c/c-typeck.c:4248
+#: cp/typeck.c:6084 c/c-typeck.c:4253
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "單位元加的運算元類型錯誤"
 
-#: cp/typeck.c:6111 c/c-typeck.c:4302
+#: cp/typeck.c:6111 c/c-typeck.c:4307
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "按位取反的引數類型錯誤"
 
-#: cp/typeck.c:6128 c/c-typeck.c:4310
+#: cp/typeck.c:6128 c/c-typeck.c:4315
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "不能對該類型的引數求絕對值"
 
-#: cp/typeck.c:6140 c/c-typeck.c:4322
+#: cp/typeck.c:6140 c/c-typeck.c:4327
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "不能對該類型的引數求共軛"
@@ -5311,67 +5311,67 @@
 msgid "Expected attribute bit name"
 msgstr "需要屬性位名"
 
-#: fortran/module.c:3223
+#: fortran/module.c:3225
 msgid "Expected integer string"
 msgstr "需要整數字串"
 
-#: fortran/module.c:3227
+#: fortran/module.c:3229
 msgid "Error converting integer"
 msgstr "轉換整數時發生錯誤"
 
-#: fortran/module.c:3249
+#: fortran/module.c:3251
 msgid "Expected real string"
 msgstr "需要實數字串"
 
-#: fortran/module.c:3474
+#: fortran/module.c:3476
 msgid "Expected expression type"
 msgstr "需要運算式類型"
 
-#: fortran/module.c:3554
+#: fortran/module.c:3556
 msgid "Bad operator"
 msgstr "錯誤的運算子"
 
-#: fortran/module.c:3671
+#: fortran/module.c:3673
 msgid "Bad type in constant expression"
 msgstr "常數運算式中類型錯誤"
 
-#: fortran/module.c:7038
+#: fortran/module.c:7040
 msgid "Unexpected end of module"
 msgstr "非預期的模組結束"
 
-#: fortran/parse.c:1757
+#: fortran/parse.c:1761
 msgid "arithmetic IF"
 msgstr "算術 IF"
 
-#: fortran/parse.c:1766
+#: fortran/parse.c:1770
 msgid "attribute declaration"
 msgstr "屬性宣告"
 
-#: fortran/parse.c:1802
+#: fortran/parse.c:1806
 msgid "data declaration"
 msgstr "資料宣告"
 
-#: fortran/parse.c:1820
+#: fortran/parse.c:1824
 msgid "derived type declaration"
 msgstr "衍生的類型宣告"
 
-#: fortran/parse.c:1947
+#: fortran/parse.c:1951
 msgid "block IF"
 msgstr "區塊 IF"
 
-#: fortran/parse.c:1956
+#: fortran/parse.c:1960
 msgid "implied END DO"
 msgstr "暗示的 END DO"
 
-#: fortran/parse.c:2050 fortran/resolve.c:11199
+#: fortran/parse.c:2054 fortran/resolve.c:11219
 msgid "assignment"
 msgstr "賦值"
 
-#: fortran/parse.c:2053 fortran/resolve.c:11250 fortran/resolve.c:11253
+#: fortran/parse.c:2057 fortran/resolve.c:11270 fortran/resolve.c:11273
 msgid "pointer assignment"
 msgstr "指標賦值"
 
-#: fortran/parse.c:2071
+#: fortran/parse.c:2075
 msgid "simple IF"
 msgstr "簡單的 IF"
 
@@ -5484,121 +5484,126 @@
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr "單位元數值運算子「%s」(位於 %%L)的運算元為 %s"
 
-#: fortran/resolve.c:3878
+#: fortran/resolve.c:3879
+#, c-format
+msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
+msgstr ""
+
+#: fortran/resolve.c:3884
 #, fuzzy, c-format
 #| msgid "Operands of binary numeric operator '%s' at %%L are %s/%s"
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr "二元數值運算子「%s」(位於 %%L)的運算元為 %s/%s"
 
-#: fortran/resolve.c:3893
+#: fortran/resolve.c:3899
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr "字串粘貼運算子(位於 %%L)的運算元為 %s/%s"
 
-#: fortran/resolve.c:3926
+#: fortran/resolve.c:3932
 #, fuzzy, c-format
 #| msgid "Operands of logical operator '%s' at %%L are %s/%s"
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr "邏輯運算子「%s」(位於 %%L)的運算元為 %s/%s"
 
-#: fortran/resolve.c:3949
+#: fortran/resolve.c:3955
 #, fuzzy, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr "運算元的.not。運算子於 %%L 是 %s"
 
-#: fortran/resolve.c:3963
+#: fortran/resolve.c:3969
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "%L 處複數不能比較大小"
 
-#: fortran/resolve.c:4015
+#: fortran/resolve.c:4021
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr "%%L 處邏輯值必須與 %s 比較，而不是 %s"
 
-#: fortran/resolve.c:4021
+#: fortran/resolve.c:4027
 #, fuzzy, c-format
 #| msgid "Operands of comparison operator '%s' at %%L are %s/%s"
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr "比較運算子「%s」(位於 %%L)的運算元為 %s/%s"
 
-#: fortran/resolve.c:4034
+#: fortran/resolve.c:4040
 #, fuzzy, c-format
 msgid "Unknown operator %%<%s%%> at %%L; did you mean '%s'?"
 msgstr "不明運算子『%s』於 %%L"
 
-#: fortran/resolve.c:4037
+#: fortran/resolve.c:4043
 #, fuzzy, c-format
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr "不明運算子『%s』於 %%L"
 
-#: fortran/resolve.c:4040
+#: fortran/resolve.c:4046
 #, fuzzy, c-format
 #| msgid "Operand of user operator '%s' at %%L is %s"
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr "使用者運算子「%s」(位於 %%L)的運算元為 %s"
 
-#: fortran/resolve.c:4044
+#: fortran/resolve.c:4050
 #, fuzzy, c-format
 #| msgid "Operands of user operator '%s' at %%L are %s/%s"
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr "使用者運算子「%s」(位於 %%L)的運算元為 %s/%s"
 
-#: fortran/resolve.c:4132
+#: fortran/resolve.c:4138
 #, fuzzy, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "不一致分級用於運算子於 %%L 和 %%L"
 
-#: fortran/resolve.c:6849
+#: fortran/resolve.c:6855
 #, fuzzy
 msgid "Loop variable"
 msgstr "迴圈變數"
 
-#: fortran/resolve.c:6853
+#: fortran/resolve.c:6859
 #, fuzzy
 msgid "iterator variable"
 msgstr "迭代器變數"
 
-#: fortran/resolve.c:6857
+#: fortran/resolve.c:6863
 #, fuzzy
 msgid "Start expression in DO loop"
 msgstr "開始運算式在中做迴圈"
 
-#: fortran/resolve.c:6861
+#: fortran/resolve.c:6867
 #, fuzzy
 msgid "End expression in DO loop"
 msgstr "結束運算式在中做迴圈"
 
-#: fortran/resolve.c:6865
+#: fortran/resolve.c:6871
 #, fuzzy
 msgid "Step expression in DO loop"
 msgstr "步驟運算式在中做迴圈"
 
-#: fortran/resolve.c:7150 fortran/resolve.c:7153
+#: fortran/resolve.c:7156 fortran/resolve.c:7159
 #, fuzzy
 msgid "DEALLOCATE object"
 msgstr "取消配置物件"
 
-#: fortran/resolve.c:7525 fortran/resolve.c:7528
+#: fortran/resolve.c:7531 fortran/resolve.c:7534
 #, fuzzy
 msgid "ALLOCATE object"
 msgstr "配置物件"
 
-#: fortran/resolve.c:7720 fortran/resolve.c:9417
+#: fortran/resolve.c:7726 fortran/resolve.c:9428
 #, fuzzy
 msgid "STAT variable"
 msgstr "STAT 變數"
 
-#: fortran/resolve.c:7764 fortran/resolve.c:9429
+#: fortran/resolve.c:7770 fortran/resolve.c:9440
 #, fuzzy
 msgid "ERRMSG variable"
 msgstr "ERRMSG 變數"
 
-#: fortran/resolve.c:9219
+#: fortran/resolve.c:9230
 #, fuzzy
 msgid "item in READ"
 msgstr "項目在中讀取"
 
-#: fortran/resolve.c:9441
+#: fortran/resolve.c:9452
 #, fuzzy
 msgid "ACQUIRED_LOCK variable"
 msgstr "ACQUIRED_LOCK 變數"
@@ -5633,7 +5638,7 @@
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr "目標的分級重新映射太小 (%ld<%ld)"
 
-#: fortran/trans-expr.c:10154
+#: fortran/trans-expr.c:10157
 msgid "Assignment of scalar to unallocated array"
 msgstr ""
 
@@ -5642,12 +5647,12 @@
 msgid "Unequal character lengths (%ld/%ld) in %s"
 msgstr "Unequal 字元長度 (%ld/%ld) 在中 %s"
 
-#: fortran/trans-intrinsic.c:8088
+#: fortran/trans-intrinsic.c:8090
 #, fuzzy, c-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative (its value is %ld)"
 msgstr "引數 NCOPIES 的重複 intrinsic 是負 (它的值是 %ld)"
 
-#: fortran/trans-intrinsic.c:8120
+#: fortran/trans-intrinsic.c:8122
 #, fuzzy
 msgid "Argument NCOPIES of REPEAT intrinsic is too large"
 msgstr "引數 NCOPIES 的重複 intrinsic 太大"
@@ -5671,16 +5676,16 @@
 msgid "Invalid image number %d in SYNC IMAGES"
 msgstr "無效的影像號碼 %d 在中同步影像"
 
-#: fortran/trans-stmt.c:2180
+#: fortran/trans-stmt.c:2177
 msgid "Loop iterates infinitely"
 msgstr ""
 
-#: fortran/trans-stmt.c:2200 fortran/trans-stmt.c:2456
+#: fortran/trans-stmt.c:2197 fortran/trans-stmt.c:2453
 #, fuzzy
 msgid "Loop variable has been modified"
 msgstr "迴圈變數已被已修改"
 
-#: fortran/trans-stmt.c:2309
+#: fortran/trans-stmt.c:2306
 #, fuzzy
 msgid "DO step value is zero"
 msgstr "做步驟值是零"
@@ -6376,10 +6381,10 @@
 msgid "Allow dollar signs in entity names."
 msgstr "允許在實體名中使用美元符號"
 
-#: fortran/lang.opt:485 config/alpha/alpha.opt:31 common.opt:783
-#: common.opt:985 common.opt:989 common.opt:993 common.opt:997 common.opt:1532
-#: common.opt:1588 common.opt:1712 common.opt:1716 common.opt:1946
-#: common.opt:2116 common.opt:2792
+#: fortran/lang.opt:485 config/alpha/alpha.opt:31 common.opt:649
+#: common.opt:783 common.opt:989 common.opt:993 common.opt:997 common.opt:1001
+#: common.opt:1536 common.opt:1592 common.opt:1716 common.opt:1720
+#: common.opt:1950 common.opt:2120 common.opt:2796
 #, fuzzy
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr "沒做任何事。保留的用於回溯相容性。"
@@ -6657,12 +6662,12 @@
 msgstr "為外部可見的名稱加入底線"
 
 #: fortran/lang.opt:751 c-family/c.opt:1356 c-family/c.opt:1384
-#: c-family/c.opt:1634 config/pa/pa.opt:42 config/pa/pa.opt:70 common.opt:1154
-#: common.opt:1333 common.opt:1408 common.opt:1676 common.opt:1799
-#: common.opt:2169 common.opt:2205 common.opt:2298 common.opt:2302
-#: common.opt:2407 common.opt:2498 common.opt:2506 common.opt:2514
-#: common.opt:2522 common.opt:2623 common.opt:2675 common.opt:2755
-#: common.opt:2893 common.opt:2897 common.opt:2901 common.opt:2905
+#: c-family/c.opt:1634 config/pa/pa.opt:42 config/pa/pa.opt:70 common.opt:1158
+#: common.opt:1337 common.opt:1412 common.opt:1680 common.opt:1803
+#: common.opt:2173 common.opt:2209 common.opt:2302 common.opt:2306
+#: common.opt:2411 common.opt:2502 common.opt:2510 common.opt:2518
+#: common.opt:2526 common.opt:2627 common.opt:2679 common.opt:2759
+#: common.opt:2897 common.opt:2901 common.opt:2905 common.opt:2909
 #, fuzzy
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr "沒做任何事。 保留的用於回溯相容性。"
@@ -6724,7 +6729,7 @@
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:220 c-family/c.opt:224
 #: c-family/c.opt:236 c-family/c.opt:1855 c-family/c.opt:1863 brig/lang.opt:39
-#: config/darwin.opt:56 common.opt:338 common.opt:341 common.opt:3046
+#: config/darwin.opt:56 common.opt:338 common.opt:341 common.opt:3050
 #, c-format
 msgid "missing filename after %qs"
 msgstr "%qs 後缺少檔案名稱"
@@ -7464,7 +7469,7 @@
 #: c-family/c.opt:1525 c-family/c.opt:1528 c-family/c.opt:1569
 #: c-family/c.opt:1704 c-family/c.opt:1731 c-family/c.opt:1771
 #: c-family/c.opt:1802 c-family/c.opt:1806 c-family/c.opt:1822
-#: config/ia64/ia64.opt:167 config/ia64/ia64.opt:170 c-family/c-opts.c:434
+#: config/ia64/ia64.opt:167 config/ia64/ia64.opt:170 c-family/c-opts.c:432
 #, gcc-internal-format
 msgid "switch %qs is no longer supported"
 msgstr "開關 %qs 不再被支援"
@@ -16574,10 +16579,6 @@
 msgid "Warn if dereferencing a NULL pointer may lead to erroneous or undefined behavior."
 msgstr ""
 
-#: common.opt:649
-msgid "Warn if the loop cannot be optimized due to nontrivial assumptions."
-msgstr "當循環因為不平凡的假定而不能被最佳化時給出警告"
-
 #: common.opt:656
 msgid "Warn about some C++ One Definition Rule violations during link time optimization."
 msgstr ""
@@ -16802,2161 +16803,2161 @@
 msgid "-dumpdir <dir>\tSet the directory name to be used for dumps."
 msgstr "-dumpdir <dir>\t設定目錄名稱為用於傾印"
 
-#: common.opt:946
+#: common.opt:950
 msgid "The version of the C++ ABI in use."
 msgstr ""
 
-#: common.opt:950
+#: common.opt:954
 msgid "Aggressively optimize loops using language constraints."
 msgstr ""
 
-#: common.opt:954
+#: common.opt:958
 #, fuzzy
 #| msgid "Align the start of functions"
 msgid "Align the start of functions."
 msgstr "對齊函式入口"
 
-#: common.opt:964
+#: common.opt:968
 #, fuzzy
 #| msgid "Align labels which are only reached by jumping"
 msgid "Align labels which are only reached by jumping."
 msgstr "對齊只能為跳轉所到達的標籤"
 
-#: common.opt:971
+#: common.opt:975
 #, fuzzy
 #| msgid "Align all labels"
 msgid "Align all labels."
 msgstr "對齊所有的標籤"
 
-#: common.opt:978
+#: common.opt:982
 #, fuzzy
 #| msgid "Align the start of loops"
 msgid "Align the start of loops."
 msgstr "對齊循環入口"
 
-#: common.opt:1001
+#: common.opt:1005
 #, fuzzy
 msgid "Select what to sanitize."
 msgstr "選取執行階段"
 
-#: common.opt:1005
+#: common.opt:1009
 msgid "Select type of coverage sanitization."
 msgstr ""
 
-#: common.opt:1009
+#: common.opt:1013
 msgid "-fasan-shadow-offset=<number>\tUse custom shadow memory offset."
 msgstr ""
 
-#: common.opt:1013
+#: common.opt:1017
 msgid "-fsanitize-sections=<sec1,sec2,...>\tSanitize global variables in user-defined sections."
 msgstr ""
 
-#: common.opt:1018
+#: common.opt:1022
 msgid "After diagnosing undefined behavior attempt to continue execution."
 msgstr ""
 
-#: common.opt:1022
+#: common.opt:1026
 #, fuzzy
 #| msgid "This switch is deprecated; use -Wextra instead"
 msgid "This switch is deprecated; use -fsanitize-recover= instead."
 msgstr "此開關已過時；請改用 -Wextra"
 
-#: common.opt:1029
+#: common.opt:1033
 msgid "Use trap instead of a library function for undefined behavior sanitization."
 msgstr ""
 
-#: common.opt:1033
+#: common.opt:1037
 #, fuzzy
 #| msgid "Generate unwind tables that are exact at each instruction boundary"
 msgid "Generate unwind tables that are exact at each instruction boundary."
 msgstr "產生精確到每條指令邊界的堆疊展開表"
 
-#: common.opt:1037
+#: common.opt:1041
 #, fuzzy
 msgid "Generate auto-inc/dec instructions."
 msgstr "產生 auto-inc/十二月指令"
 
-#: common.opt:1041
+#: common.opt:1045
 msgid "Use sample profile information for call graph node weights. The default profile file is fbdata.afdo in 'pwd'."
 msgstr ""
 
-#: common.opt:1046
+#: common.opt:1050
 msgid "Use sample profile information for call graph node weights. The profile file is specified in the argument."
 msgstr ""
 
-#: common.opt:1055
+#: common.opt:1059
 #, fuzzy
 #| msgid "Generate code to check bounds before indexing arrays"
 msgid "Generate code to check bounds before indexing arrays."
 msgstr "產生檢查陣列存取是否越界的程式碼"
 
-#: common.opt:1059
+#: common.opt:1063
 #, fuzzy
 #| msgid "Replace add, compare, branch with branch on count register"
 msgid "Replace add, compare, branch with branch on count register."
 msgstr "將加/減法、比較、跳轉指令序列替換為根據計數暫存器跳轉指令"
 
-#: common.opt:1063
+#: common.opt:1067
 #, fuzzy
 #| msgid "Use profiling information for branch probabilities"
 msgid "Use profiling information for branch probabilities."
 msgstr "為分支概率使用取樣資訊"
 
-#: common.opt:1067
+#: common.opt:1071
 #, fuzzy
 #| msgid "Perform branch target load optimization before prologue / epilogue threading"
 msgid "Perform branch target load optimization before prologue / epilogue threading."
 msgstr "在開始/結末執行緒前進行分支目的載入最佳化"
 
-#: common.opt:1071
+#: common.opt:1075
 #, fuzzy
 #| msgid "Perform branch target load optimization after prologue / epilogue threading"
 msgid "Perform branch target load optimization after prologue / epilogue threading."
 msgstr "在開始/結末執行緒後進行分支目的載入最佳化"
 
-#: common.opt:1075
+#: common.opt:1079
 #, fuzzy
 msgid "Restrict target load migration not to re-use registers in any basic block."
 msgstr "限制目標載入遷移無法到重新使用暫存器在中任何基本區塊"
 
-#: common.opt:1079
+#: common.opt:1083
 #, fuzzy
 msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions."
 msgstr "-fcall-saved-<register>\t標記<暫存器>做為被保留跨越函式"
 
-#: common.opt:1083
+#: common.opt:1087
 #, fuzzy
 msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls."
 msgstr "-fcall-used-<register>\t標記<暫存器>做為被已損壞由函式呼叫"
 
-#: common.opt:1090
+#: common.opt:1094
 #, fuzzy
 #| msgid "Save registers around function calls"
 msgid "Save registers around function calls."
 msgstr "函式呼叫前後儲存/恢復暫存器值"
 
-#: common.opt:1094
+#: common.opt:1098
 #, fuzzy
 #| msgid "This switch is deprecated; use -Wextra instead"
 msgid "This switch is deprecated; do not use."
 msgstr "此開關已過時；請改用 -Wextra"
 
-#: common.opt:1098
+#: common.opt:1102
 #, fuzzy
 #| msgid "Check the return value of new"
 msgid "Check the return value of new in C++."
 msgstr "檢查 new 的回傳值"
 
-#: common.opt:1102 common.opt:1106
+#: common.opt:1106 common.opt:1110
 #, fuzzy
 #| msgid "internal consistency failure"
 msgid "Perform internal consistency checkings."
 msgstr "內部一致性錯誤"
 
-#: common.opt:1110
+#: common.opt:1114
 #, fuzzy
 #| msgid "Enable function profiling"
 msgid "Enable code hoisting."
 msgstr "啟用函式取樣"
 
-#: common.opt:1114
+#: common.opt:1118
 #, fuzzy
 msgid "Looks for opportunities to reduce stack adjustments and stack references."
 msgstr "找尋機會到縮小堆疊調整和堆疊參考。"
 
-#: common.opt:1118
+#: common.opt:1122
 #, fuzzy
 #| msgid "Do not put uninitialized globals in the common section"
 msgid "Do not put uninitialized globals in the common section."
 msgstr "不將未初始化的全域資料放在公共區段中"
 
-#: common.opt:1126
+#: common.opt:1130
 #, fuzzy
 msgid "-fcompare-debug[=<opts>]\tCompile with and without e.g. -gtoggle, and compare the final-insns dump."
 msgstr "-fcompare-debug [=<opts>]\t編譯與和而無需例如： -gtoggle，而比較 final-insns 傾印"
 
-#: common.opt:1130
+#: common.opt:1134
 #, fuzzy
 msgid "Run only the second compilation of -fcompare-debug."
 msgstr "運行只有第二編譯的 -fcompare-debug"
 
-#: common.opt:1134
+#: common.opt:1138
 #, fuzzy
 msgid "Perform comparison elimination after register allocation has finished."
 msgstr "施行比較 elimination 之後暫存器配額已完成"
 
-#: common.opt:1138
+#: common.opt:1142
 #, fuzzy
 msgid "Do not perform optimizations increasing noticeably stack usage."
 msgstr "不施行最佳化增加 noticeably 堆疊用法"
 
-#: common.opt:1142
+#: common.opt:1146
 #, fuzzy
 #| msgid "Perform a register copy-propagation optimization pass"
 msgid "Perform a register copy-propagation optimization pass."
 msgstr "進行一趟暫存器副本傳遞最佳化"
 
-#: common.opt:1146
+#: common.opt:1150
 #, fuzzy
 #| msgid "Perform cross-jumping optimization"
 msgid "Perform cross-jumping optimization."
 msgstr "進行跨跳轉最佳化"
 
-#: common.opt:1150
+#: common.opt:1154
 #, fuzzy
 #| msgid "When running CSE, follow jumps to their targets"
 msgid "When running CSE, follow jumps to their targets."
 msgstr "進行 CSE 時，跟隨跳轉至目的"
 
-#: common.opt:1158
+#: common.opt:1162
 #, fuzzy
 #| msgid "Omit range reduction step when performing complex division"
 msgid "Omit range reduction step when performing complex division."
 msgstr "當進行複數除法時省略縮減範圍的步驟"
 
-#: common.opt:1162
+#: common.opt:1166
 #, fuzzy
 msgid "Complex multiplication and division follow Fortran rules."
 msgstr "複雜乘法和除法追隨 Fortran 規則"
 
-#: common.opt:1166
+#: common.opt:1170
 #, fuzzy
 #| msgid "Place data items into their own section"
 msgid "Place data items into their own section."
 msgstr "將每個資料項分別放在它們各自的區段中"
 
-#: common.opt:1170
+#: common.opt:1174
 #, fuzzy
 msgid "List all available debugging counters with their limits and counts."
 msgstr "列出所有可用偵錯計數器與它們的限度和計數。"
 
-#: common.opt:1174
+#: common.opt:1178
 #, fuzzy
 msgid "-fdbg-cnt=<counter>:<limit>[,<counter>:<limit>,...]\tSet the debug counter limit."
 msgstr "-fdbg-cnt=<counter>:<限制>[,<計數器>:<限制>,...]\t設定除錯計數器限制。  "
 
-#: common.opt:1178
+#: common.opt:1182
 #, fuzzy
 msgid "-fdebug-prefix-map=<old>=<new> Map one directory name to another in debug information."
 msgstr "映射一個目錄名稱到另外的在中除錯資訊"
 
-#: common.opt:1182
+#: common.opt:1186
 #, fuzzy
 msgid "-ffile-prefix-map=<old>=<new> Map one directory name to another in compilation result."
 msgstr "映射一個目錄名稱到另外的在中除錯資訊"
 
-#: common.opt:1186
+#: common.opt:1190
 #, fuzzy
 msgid "Output .debug_types section when using DWARF v4 debuginfo."
 msgstr "輸出.debugtypes 區段時使用 DWARF v4 debuginfo(_T)。"
 
-#: common.opt:1192
+#: common.opt:1196
 #, fuzzy
 #| msgid "Defer popping functions args from stack until later"
 msgid "Defer popping functions args from stack until later."
 msgstr "延遲將函式引數彈堆疊"
 
-#: common.opt:1196
+#: common.opt:1200
 #, fuzzy
 #| msgid "Attempt to fill delay slots of branch instructions"
 msgid "Attempt to fill delay slots of branch instructions."
 msgstr "試圖利用延遲轉移指令後"
 
-#: common.opt:1200
+#: common.opt:1204
 msgid "Delete dead instructions that may throw exceptions."
 msgstr ""
 
-#: common.opt:1204
+#: common.opt:1208
 #, fuzzy
 #| msgid "Delete useless null pointer checks"
 msgid "Delete useless null pointer checks."
 msgstr "刪除無用的空指標檢查"
 
-#: common.opt:1208
+#: common.opt:1212
 msgid "Stream extra data to support more aggressive devirtualization in LTO local transformation mode."
 msgstr ""
 
-#: common.opt:1212
+#: common.opt:1216
 #, fuzzy
 msgid "Perform speculative devirtualization."
 msgstr "施行超區塊格式透過尾端複印法"
 
-#: common.opt:1216
+#: common.opt:1220
 #, fuzzy
 msgid "Try to convert virtual calls to direct ones."
 msgstr "試著轉換虛擬呼叫到直接的一個。"
 
-#: common.opt:1220
+#: common.opt:1224
 #, fuzzy
 msgid "-fdiagnostics-show-location=[once|every-line]\tHow often to emit source location at the beginning of line-wrapped diagnostics."
 msgstr "-fdiagnostics-show-location=[一旦|every-line]\t多久會到 emit 來源位置於起始部分的 line-wrapped 診斷"
 
-#: common.opt:1237
+#: common.opt:1241
 msgid "Show the source line with a caret indicating the column."
 msgstr ""
 
-#: common.opt:1245
+#: common.opt:1249
 msgid "-fdiagnostics-color=[never|always|auto]\tColorize diagnostics."
 msgstr ""
 
-#: common.opt:1265
+#: common.opt:1269
 msgid "Print fix-it hints in machine-readable form."
 msgstr ""
 
-#: common.opt:1269
+#: common.opt:1273
 msgid "Print fix-it hints to stderr in unified diff format."
 msgstr ""
 
-#: common.opt:1273
+#: common.opt:1277
 #, fuzzy
 msgid "Amend appropriate diagnostic messages with the command line option that controls them."
 msgstr "修正適當診斷訊息與命令列選項該控制項它們"
 
-#: common.opt:1277
+#: common.opt:1281
 #, fuzzy
 msgid "-fdisable-[tree|rtl|ipa]-<pass>=range1+range2 disables an optimization pass."
 msgstr "-fdisable-[ 樹|rtl|ipa ]-<pass>=range1+range2 停用最佳化回合"
 
-#: common.opt:1281
+#: common.opt:1285
 #, fuzzy
 msgid "-fenable-[tree|rtl|ipa]-<pass>=range1+range2 enables an optimization pass."
 msgstr "-fenable-[ 樹|rtl|ipa ]-<pass>=range1+range2 啟用最佳化回合"
 
-#: common.opt:1285
+#: common.opt:1289
 #, fuzzy
 msgid "-fdump-<type>\tDump various compiler internals to a file."
 msgstr "-fdump-<type>\t傾印各種編譯器內部到檔案"
 
-#: common.opt:1292
+#: common.opt:1296
 #, fuzzy
 msgid "-fdump-final-insns=filename\tDump to filename the insns at the end of translation."
 msgstr "-fdump-final-insns=檔名\t傾印到檔名 insns 於結束的翻譯"
 
-#: common.opt:1296
+#: common.opt:1300
 #, fuzzy
 msgid "-fdump-go-spec=filename\tWrite all declarations to file as Go code."
 msgstr "-fdump-go-spec=檔名\t寫入所有宣告到檔案做為前往編碼"
 
-#: common.opt:1300
+#: common.opt:1304
 #, fuzzy
 msgid "Suppress output of addresses in debugging dumps."
 msgstr "不列印輸出的位址在中偵錯傾印"
 
-#: common.opt:1304
+#: common.opt:1308
 msgid "Collect and dump debug information into temporary file if ICE in C/C++ compiler occurred."
 msgstr ""
 
-#: common.opt:1309
+#: common.opt:1313
 msgid "Dump detailed information on GCC's internal representation of source code locations."
 msgstr ""
 
-#: common.opt:1313
+#: common.opt:1317
 #, fuzzy
 msgid "Dump optimization passes."
 msgstr "傾印最佳化次數"
 
-#: common.opt:1317
+#: common.opt:1321
 #, fuzzy
 msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps."
 msgstr "不列印輸出的指令數量，列號記事和位址在中偵錯傾印"
 
-#: common.opt:1321
+#: common.opt:1325
 #, fuzzy
 msgid "Suppress output of previous and next insn numbers in debugging dumps."
 msgstr "不列印輸出的前一個和下一個 insn 數量在中偵錯傾印"
 
-#: common.opt:1325
+#: common.opt:1329
 #, fuzzy
 msgid "Enable CFI tables via GAS assembler directives."
 msgstr "啟用 CFI 表格透過氣體組譯器指令。"
 
-#: common.opt:1329
+#: common.opt:1333
 #, fuzzy
 #| msgid "Perform early inlining"
 msgid "Perform early inlining."
 msgstr "進行早內聯"
 
-#: common.opt:1337
+#: common.opt:1341
 #, fuzzy
 msgid "Perform interprocedural reduction of aggregates."
 msgstr "施行 interprocedural 消除的彙總"
 
-#: common.opt:1341
+#: common.opt:1345
 #, fuzzy
 #| msgid "Perform unused type elimination in debug info"
 msgid "Perform unused symbol elimination in debug info."
 msgstr "在除錯資訊中進行無用類型消除"
 
-#: common.opt:1345
+#: common.opt:1349
 #, fuzzy
 #| msgid "Perform unused type elimination in debug info"
 msgid "Perform unused type elimination in debug info."
 msgstr "在除錯資訊中進行無用類型消除"
 
-#: common.opt:1349
+#: common.opt:1353
 #, fuzzy
 msgid "Do not suppress C++ class debug information."
 msgstr "不抑制 C++類別除錯資訊。"
 
-#: common.opt:1353
+#: common.opt:1357
 #, fuzzy
 #| msgid "Enable exception handling"
 msgid "Enable exception handling."
 msgstr "啟用異常處理"
 
-#: common.opt:1357
+#: common.opt:1361
 #, fuzzy
 #| msgid "Perform a number of minor, expensive optimizations"
 msgid "Perform a number of minor, expensive optimizations."
 msgstr "進行一些細微的、代價高昂的最佳化"
 
-#: common.opt:1361
+#: common.opt:1365
 #, fuzzy
 msgid "-fexcess-precision=[fast|standard]\tSpecify handling of excess floating-point precision."
 msgstr "-fexcess-precision=[快速|標準]\t指定處理的過剩浮點精確度"
 
-#: common.opt:1364
+#: common.opt:1368
 #, fuzzy, c-format
 msgid "unknown excess precision style %qs"
 msgstr "不明過剩精確度樣式 %qs"
 
-#: common.opt:1376
+#: common.opt:1380
 msgid "-fpermitted-flt-eval-methods=[c11|ts-18661]\tSpecify which values of FLT_EVAL_METHOD are permitted."
 msgstr ""
 
-#: common.opt:1379
+#: common.opt:1383
 #, c-format
 msgid "unknown specification for the set of FLT_EVAL_METHOD values to permit %qs"
 msgstr ""
 
-#: common.opt:1392
+#: common.opt:1396
 #, fuzzy
 msgid "Output lto objects containing both the intermediate language and binary output."
 msgstr "輸出 lto 物件包含兩者中介語言和二進位輸出。"
 
-#: common.opt:1396
+#: common.opt:1400
 #, fuzzy
 #| msgid "Assume no NaNs or infinities are generated"
 msgid "Assume no NaNs or infinities are generated."
 msgstr "假定結果不會是 NaN 或無限大浮點數"
 
-#: common.opt:1400
+#: common.opt:1404
 #, fuzzy
 msgid "-ffixed-<register>\tMark <register> as being unavailable to the compiler."
 msgstr "-ffixed-<register>\t標記<暫存器>做為是不得使用到編譯器"
 
-#: common.opt:1404
+#: common.opt:1408
 #, fuzzy
 #| msgid "Don't allocate floats and doubles in extended-precision registers"
 msgid "Don't allocate floats and doubles in extended-precision registers."
 msgstr "不將單精度和雙精度浮點數指派到擴充精度的暫存器中"
 
-#: common.opt:1412
+#: common.opt:1416
 #, fuzzy
 msgid "Perform a forward propagation pass on RTL."
 msgstr "施行轉寄傳播傳送 RTL"
 
-#: common.opt:1416
+#: common.opt:1420
 #, fuzzy
 msgid "-ffp-contract=[off|on|fast]\tPerform floating-point expression contraction."
 msgstr "-ffp-contract=[關閉|於|快速] 施行浮點運算式合約。"
 
-#: common.opt:1419
+#: common.opt:1423
 #, fuzzy, c-format
 msgid "unknown floating point contraction style %qs"
 msgstr "不明浮點數合約樣式 %qs"
 
-#: common.opt:1433
+#: common.opt:1437
 msgid "Allow built-in functions ceil, floor, round, trunc to raise \"inexact\" exceptions."
 msgstr ""
 
-#: common.opt:1440
+#: common.opt:1444
 #, fuzzy
 #| msgid "Allow function addresses to be held in registers"
 msgid "Allow function addresses to be held in registers."
 msgstr "允許將函式位址儲存在暫存器中"
 
-#: common.opt:1444
+#: common.opt:1448
 #, fuzzy
 #| msgid "Place each function into its own section"
 msgid "Place each function into its own section."
 msgstr "將每個函式分別放在它們各自的區段中"
 
-#: common.opt:1448
+#: common.opt:1452
 #, fuzzy
 #| msgid "Perform global common subexpression elimination"
 msgid "Perform global common subexpression elimination."
 msgstr "進行全域公因式消去"
 
-#: common.opt:1452
+#: common.opt:1456
 #, fuzzy
 #| msgid "Perform enhanced load motion during global common subexpression elimination"
 msgid "Perform enhanced load motion during global common subexpression elimination."
 msgstr "在全域公因式消去中進行增強的讀轉移最佳化"
 
-#: common.opt:1456
+#: common.opt:1460
 #, fuzzy
 #| msgid "Perform store motion after global common subexpression elimination"
 msgid "Perform store motion after global common subexpression elimination."
 msgstr "在全域公因式消去後進行存儲轉移"
 
-#: common.opt:1460
+#: common.opt:1464
 #, fuzzy
 #| msgid "Perform redundant load after store elimination in global common subexpression"
 msgid "Perform redundant load after store elimination in global common subexpression elimination."
 msgstr "在全域公因式消去中進行冗餘的寫後讀消除"
 
-#: common.opt:1465
+#: common.opt:1469
 #, fuzzy
 #| msgid "Perform global common subexpression elimination after register allocation"
 msgid "Perform global common subexpression elimination after register allocation has finished."
 msgstr "在指派暫存器後進行全域公因式消去"
 
-#: common.opt:1482
+#: common.opt:1486
 msgid "-fgnat-encodings=[all|gdb|minimal]\tSelect the balance between GNAT encodings and standard DWARF emitted in the debug information"
 msgstr ""
 
-#: common.opt:1487
+#: common.opt:1491
 #, fuzzy
 msgid "Enable in and out of Graphite representation."
 msgstr "啟用在中和超出石墨表示"
 
-#: common.opt:1491
+#: common.opt:1495
 #, fuzzy
 msgid "Enable Graphite Identity transformation."
 msgstr "啟用石墨身分變換"
 
-#: common.opt:1495
+#: common.opt:1499
 #, fuzzy
 msgid "Enable hoisting adjacent loads to encourage generating conditional move instructions."
 msgstr "啟用 hoisting 載入從條件指標。"
 
-#: common.opt:1504
+#: common.opt:1508
 #, fuzzy
 msgid "Mark all loops as parallel."
 msgstr "標記所有迴圈做為平行"
 
-#: common.opt:1508 common.opt:1516 common.opt:2587
+#: common.opt:1512 common.opt:1520 common.opt:2591
 #, fuzzy
 msgid "Enable loop nest transforms.  Same as -floop-nest-optimize."
 msgstr "啟用迴圈交換變換。 如同 -floop-interchange"
 
-#: common.opt:1512
+#: common.opt:1516
 #, fuzzy
 #| msgid "Enable loop header copying on trees"
 msgid "Enable loop interchange on trees."
 msgstr "啟用樹上的循環不變量轉移"
 
-#: common.opt:1520
+#: common.opt:1524
 #, fuzzy
 #| msgid "Perform loop unrolling for all loops"
 msgid "Perform unroll-and-jam on loops."
 msgstr "展開所有循環"
 
-#: common.opt:1524
+#: common.opt:1528
 #, fuzzy
 msgid "Enable support for GNU transactional memory."
 msgstr "啟用支援用於 GNU transactional 記憶體"
 
-#: common.opt:1528
+#: common.opt:1532
 msgid "Use STB_GNU_UNIQUE if supported by the assembler."
 msgstr ""
 
-#: common.opt:1536
+#: common.opt:1540
 #, fuzzy
 #| msgid "Run the loop optimizer twice"
 msgid "Enable the loop nest optimizer."
 msgstr "執行循環最佳化引擎兩次"
 
-#: common.opt:1540
+#: common.opt:1544
 #, fuzzy
 msgid "Force bitfield accesses to match their type width."
 msgstr "強制 bitfield 存取到匹配它們的型態寬度"
 
-#: common.opt:1544
+#: common.opt:1548
 msgid "Merge adjacent stores."
 msgstr ""
 
-#: common.opt:1548
+#: common.opt:1552
 #, fuzzy
 #| msgid "Enable guessing of branch probabilities"
 msgid "Enable guessing of branch probabilities."
 msgstr "啟用分支概率猜測"
 
-#: common.opt:1556
+#: common.opt:1560
 #, fuzzy
 #| msgid "Process #ident directives"
 msgid "Process #ident directives."
 msgstr "處理 #ident 指令"
 
-#: common.opt:1560
+#: common.opt:1564
 #, fuzzy
 #| msgid "Perform conversion of conditional jumps to branchless equivalents"
 msgid "Perform conversion of conditional jumps to branchless equivalents."
 msgstr "將條件跳轉替換為沒有跳轉的等值表示"
 
-#: common.opt:1564
+#: common.opt:1568
 #, fuzzy
 #| msgid "Perform conversion of conditional jumps to conditional execution"
 msgid "Perform conversion of conditional jumps to conditional execution."
 msgstr "將條件跳轉替換為條件執行"
 
-#: common.opt:1568
+#: common.opt:1572
 msgid "-fstack-reuse=[all|named_vars|none]\tSet stack reuse level for local variables."
 msgstr ""
 
-#: common.opt:1571
+#: common.opt:1575
 #, fuzzy, c-format
 msgid "unknown Stack Reuse Level %qs"
 msgstr "不明 TLS 式樣 %qs"
 
-#: common.opt:1584
+#: common.opt:1588
 #, fuzzy
 msgid "Convert conditional jumps in innermost loops to branchless equivalents."
 msgstr "轉換條件式跳位在中 innermost 迴圈到 branchless equivalents"
 
-#: common.opt:1596
+#: common.opt:1600
 #, fuzzy
 #| msgid "Do not generate .size directives"
 msgid "Do not generate .size directives."
 msgstr "不產生 .size 指令"
 
-#: common.opt:1600
+#: common.opt:1604
 #, fuzzy
 msgid "Perform indirect inlining."
 msgstr "施行間接內聯"
 
-#: common.opt:1606
+#: common.opt:1610
 #, fuzzy
 msgid "Enable inlining of function declared \"inline\", disabling disables all inlining."
 msgstr "啟用內聯的函式宣告「內聯」，停用全部停用內聯"
 
-#: common.opt:1610
+#: common.opt:1614
 #, fuzzy
 msgid "Integrate functions into their callers when code size is known not to grow."
 msgstr "整合函式進入它們的呼叫者時編碼大小是已知無法到 grow"
 
-#: common.opt:1614
+#: common.opt:1618
 #, fuzzy
 msgid "Integrate functions not declared \"inline\" into their callers when profitable."
 msgstr "整合函式無法宣告「內聯」進入它們的呼叫者時 profitable"
 
-#: common.opt:1618
+#: common.opt:1622
 #, fuzzy
 msgid "Integrate functions only required by their single caller."
 msgstr "整合函式只有必要項由它們的單一呼叫者"
 
-#: common.opt:1625
+#: common.opt:1629
 #, fuzzy
 msgid "-finline-limit=<number>\tLimit the size of inlined functions to <number>."
 msgstr "-finline-limit=<number>\t限制大小的內聯的函式到<數字>"
 
-#: common.opt:1629
+#: common.opt:1633
 #, fuzzy
 msgid "Inline __atomic operations when a lock free instruction sequence is available."
 msgstr "內聯 __atomic 計算時鎖定自由指令序列是可用。"
 
-#: common.opt:1636
+#: common.opt:1640
 msgid "-fcf-protection=[full|branch|return|none]\tInstrument functions with checks to verify jump/call/return control-flow transfer instructions have valid targets."
 msgstr ""
 
-#: common.opt:1640
+#: common.opt:1644
 #, fuzzy, c-format
 msgid "unknown Control-Flow Protection Level %qs"
 msgstr "不明 TLS 式樣 %qs"
 
-#: common.opt:1656
+#: common.opt:1660
 #, fuzzy
 msgid "Instrument function entry and exit with profiling calls."
 msgstr "器具函式條目然後離開與側寫檔呼叫"
 
-#: common.opt:1660
+#: common.opt:1664
 #, fuzzy
 msgid "-finstrument-functions-exclude-function-list=name,...  Do not instrument listed functions."
 msgstr "-finstrument-functions-exclude-function-list=名稱 ,... 不器具清單的函式"
 
-#: common.opt:1664
+#: common.opt:1668
 #, fuzzy
 msgid "-finstrument-functions-exclude-file-list=filename,...  Do not instrument functions listed in files."
 msgstr "-finstrument-functions-exclude-file-list=檔名 ,... 不器具函式清單的在中檔案"
 
-#: common.opt:1668
+#: common.opt:1672
 #, fuzzy
 #| msgid "Perform Interprocedural constant propagation"
 msgid "Perform interprocedural constant propagation."
 msgstr "進行處理序間的複寫傳遞"
 
-#: common.opt:1672
+#: common.opt:1676
 #, fuzzy
 msgid "Perform cloning to make Interprocedural constant propagation stronger."
 msgstr "施行仿本要讓 Interprocedural 常數傳用 stronger"
 
-#: common.opt:1680
+#: common.opt:1684
 #, fuzzy
 #| msgid "Perform Interprocedural constant propagation"
 msgid "Perform interprocedural bitwise constant propagation."
 msgstr "進行處理序間的複寫傳遞"
 
-#: common.opt:1684
+#: common.opt:1688
 #, fuzzy
 msgid "Perform interprocedural profile propagation."
 msgstr "施行 interprocedural 側寫檔傳播"
 
-#: common.opt:1688
+#: common.opt:1692
 #, fuzzy
 msgid "Perform interprocedural points-to analysis."
 msgstr "施行 interprocedural points-to 分析"
 
-#: common.opt:1692
+#: common.opt:1696
 #, fuzzy
 #| msgid "Discover pure and const functions"
 msgid "Discover pure and const functions."
 msgstr "發現純函式和常函式"
 
-#: common.opt:1696
+#: common.opt:1700
 msgid "Perform Identical Code Folding for functions and read-only variables."
 msgstr ""
 
-#: common.opt:1700
+#: common.opt:1704
 msgid "Perform Identical Code Folding for functions."
 msgstr ""
 
-#: common.opt:1704
+#: common.opt:1708
 msgid "Perform Identical Code Folding for variables."
 msgstr ""
 
-#: common.opt:1708
+#: common.opt:1712
 #, fuzzy
 #| msgid "Discover readonly and non addressable static variables"
 msgid "Discover readonly and non addressable static variables."
 msgstr "發現唯讀和不可定址靜態變數"
 
-#: common.opt:1720
+#: common.opt:1724
 #, fuzzy
 #| msgid "Perform Value Range Propagation on trees"
 msgid "Perform IPA Value Range Propagation."
 msgstr "進行樹上的值欄位傳遞"
 
-#: common.opt:1724
+#: common.opt:1728
 #, fuzzy
 msgid "-fira-algorithm=[CB|priority]\tSet the used IRA algorithm."
 msgstr "-fira-algorithm=[CB|優先權] 設定使用的 IRA 演算法"
 
-#: common.opt:1727
+#: common.opt:1731
 #, fuzzy, c-format
 msgid "unknown IRA algorithm %qs"
 msgstr "不明 IRA 演算法 %qs"
 
-#: common.opt:1737
+#: common.opt:1741
 #, fuzzy
 msgid "-fira-region=[one|all|mixed]\tSet regions for IRA."
 msgstr "-fira-region=[一個|所有|混合] 設定區域用於 IRA"
 
-#: common.opt:1740
+#: common.opt:1744
 #, fuzzy, c-format
 msgid "unknown IRA region %qs"
 msgstr "不明 IRA 區域 %qs"
 
-#: common.opt:1753
+#: common.opt:1757
 #, fuzzy
 msgid "Use IRA based register pressure calculation in RTL hoist optimizations."
 msgstr "使用 IRA 基底的暫存器壓力 calculation"
 
-#: common.opt:1758
+#: common.opt:1762
 #, fuzzy
 msgid "Use IRA based register pressure calculation in RTL loop optimizations."
 msgstr "使用 IRA 基底的暫存器壓力 calculation"
 
-#: common.opt:1763
+#: common.opt:1767
 #, fuzzy
 msgid "Share slots for saving different hard registers."
 msgstr "共享插槽用於儲存不同的硬暫存器。"
 
-#: common.opt:1767
+#: common.opt:1771
 #, fuzzy
 msgid "Share stack slots for spilled pseudo-registers."
 msgstr "共享堆疊插槽用於 spilled pseudo-registers。"
 
-#: common.opt:1771
+#: common.opt:1775
 #, fuzzy
 msgid "-fira-verbose=<number>\tControl IRA's level of diagnostic messages."
 msgstr "-fira-verbose=<number>\t控制 IRA's 等級的診斷訊息。"
 
-#: common.opt:1775
+#: common.opt:1779
 #, fuzzy
 #| msgid "Optimize induction variables on trees"
 msgid "Optimize induction variables on trees."
 msgstr "在樹上最佳化歸納變數"
 
-#: common.opt:1779
+#: common.opt:1783
 #, fuzzy
 #| msgid "Use jump tables for sufficiently large switch statements"
 msgid "Use jump tables for sufficiently large switch statements."
 msgstr "為足夠大的 switch 敘述使用跳轉表"
 
-#: common.opt:1783
+#: common.opt:1787
 #, fuzzy
 #| msgid "Generate code for functions even if they are fully inlined"
 msgid "Generate code for functions even if they are fully inlined."
 msgstr "為完全內聯的函式產生程式碼"
 
-#: common.opt:1787
+#: common.opt:1791
 #, fuzzy
 #| msgid "Generate code for functions even if they are fully inlined"
 msgid "Generate code for static functions even if they are never called."
 msgstr "為完全內聯的函式產生程式碼"
 
-#: common.opt:1791
+#: common.opt:1795
 #, fuzzy
 #| msgid "Emit static const variables even if they are not used"
 msgid "Emit static const variables even if they are not used."
 msgstr "保留未用到的靜態常數"
 
-#: common.opt:1795
+#: common.opt:1799
 #, fuzzy
 #| msgid "Give external symbols a leading underscore"
 msgid "Give external symbols a leading underscore."
 msgstr "給外部符號加入起始的底線"
 
-#: common.opt:1803
+#: common.opt:1807
 msgid "Do CFG-sensitive rematerialization in LRA."
 msgstr ""
 
-#: common.opt:1807
+#: common.opt:1811
 #, fuzzy
 msgid "Enable link-time optimization."
 msgstr "啟用 link-time 最佳化。"
 
-#: common.opt:1811
+#: common.opt:1815
 #, fuzzy
 msgid "Link-time optimization with number of parallel jobs or jobserver."
 msgstr "Link-time 最佳化與平行工作編號的或 jobserver。"
 
-#: common.opt:1814
+#: common.opt:1818
 #, fuzzy, c-format
 msgid "unknown LTO partitioning model %qs"
 msgstr "不明 TLS 式樣 %qs"
 
-#: common.opt:1833
+#: common.opt:1837
 msgid "Specify the algorithm to partition symbols and vars at linktime."
 msgstr ""
 
-#: common.opt:1838
+#: common.opt:1842
 #, fuzzy
 msgid "-flto-compression-level=<number>\tUse zlib compression level <number> for IL."
 msgstr "-flto-compression-level=<number>\t使用 zlib 壓縮等級<數字>用於 IL"
 
-#: common.opt:1842
+#: common.opt:1846
 msgid "Merge C++ types using One Definition Rule."
 msgstr ""
 
-#: common.opt:1846
+#: common.opt:1850
 #, fuzzy
 msgid "Report various link-time optimization statistics."
 msgstr "報告各種 link-time 最佳化統計"
 
-#: common.opt:1850
+#: common.opt:1854
 #, fuzzy
 msgid "Report various link-time optimization statistics for WPA only."
 msgstr "報告各種 link-time 最佳化統計"
 
-#: common.opt:1854
+#: common.opt:1858
 #, fuzzy
 #| msgid "Set errno after built-in math functions"
 msgid "Set errno after built-in math functions."
 msgstr "執行內建數學函式後設定 errno"
 
-#: common.opt:1858
+#: common.opt:1862
 #, fuzzy
 msgid "-fmax-errors=<number>\tMaximum number of errors to report."
 msgstr "-fmax-errors=<number>\t最大值錯誤代號的到報告"
 
-#: common.opt:1862
+#: common.opt:1866
 #, fuzzy
 #| msgid "Report on permanent memory allocation"
 msgid "Report on permanent memory allocation."
 msgstr "報告永久性記憶體指派"
 
-#: common.opt:1866
+#: common.opt:1870
 #, fuzzy
 msgid "Report on permanent memory allocation in WPA only."
 msgstr "報告永久性記憶體指派"
 
-#: common.opt:1873
+#: common.opt:1877
 #, fuzzy
 #| msgid "Attempt to merge identical constants and constant variables"
 msgid "Attempt to merge identical constants and constant variables."
 msgstr "試圖合併相同的常數和常變數"
 
-#: common.opt:1877
+#: common.opt:1881
 #, fuzzy
 #| msgid "Attempt to merge identical constants across compilation units"
 msgid "Attempt to merge identical constants across compilation units."
 msgstr "試圖合併不同編譯單元中的相同常數"
 
-#: common.opt:1881
+#: common.opt:1885
 #, fuzzy
 msgid "Attempt to merge identical debug strings across compilation units."
 msgstr "試圖到合併相等的除錯字串跨越編譯單元"
 
-#: common.opt:1885
+#: common.opt:1889
 #, fuzzy
 msgid "-fmessage-length=<number>\tLimit diagnostics to <number> characters per line.  0 suppresses line-wrapping."
 msgstr "-fmessage-length=<number>\t限制診斷到<數字>字元各列。 0 抑制換列"
 
-#: common.opt:1889
+#: common.opt:1893
 #, fuzzy
 #| msgid "Perform SMS based modulo scheduling before the first scheduling pass"
 msgid "Perform SMS based modulo scheduling before the first scheduling pass."
 msgstr "在首趟調度前進行基於 SMS 的模調度"
 
-#: common.opt:1893
+#: common.opt:1897
 #, fuzzy
 msgid "Perform SMS based modulo scheduling with register moves allowed."
 msgstr "施行 SMS 基底的 modulo 排程與暫存器移動允許"
 
-#: common.opt:1897
+#: common.opt:1901
 #, fuzzy
 #| msgid "Move loop invariant computations out of loops"
 msgid "Move loop invariant computations out of loops."
 msgstr "將每次循環中不變的計算外提"
 
-#: common.opt:1901
+#: common.opt:1905
 #, fuzzy
 msgid "Use the RTL dead code elimination pass."
 msgstr "使用 RTL 無作用程式碼 elimination 回合"
 
-#: common.opt:1905
+#: common.opt:1909
 #, fuzzy
 msgid "Use the RTL dead store elimination pass."
 msgstr "使用 RTL 無作用儲存體 elimination 回合"
 
-#: common.opt:1909
+#: common.opt:1913
 #, fuzzy
 #| msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling"
 msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling."
 msgstr "啟用/停用已經透過模調度的循環中的傳統調度"
 
-#: common.opt:1913
+#: common.opt:1917
 #, fuzzy
 #| msgid "Support synchronous non-call exceptions"
 msgid "Support synchronous non-call exceptions."
 msgstr "支援同步非呼叫異常"
 
-#: common.opt:1916
+#: common.opt:1920
 #, fuzzy, c-format
 #| msgid "assertion missing after %qs"
 msgid "options or targets missing after %qs"
 msgstr "%qs 後判定語"
 
-#: common.opt:1917
+#: common.opt:1921
 msgid "-foffload=<targets>=<options>  Specify offloading targets and options for them."
 msgstr ""
 
-#: common.opt:1921
+#: common.opt:1925
 msgid "-foffload-abi=[lp64|ilp32]     Set the ABI to use in an offload compiler."
 msgstr ""
 
-#: common.opt:1924
+#: common.opt:1928
 #, fuzzy, c-format
 msgid "unknown offload ABI %qs"
 msgstr "不明 TLS 式樣 %qs"
 
-#: common.opt:1934
+#: common.opt:1938
 #, fuzzy
 #| msgid "When possible do not generate stack frames"
 msgid "When possible do not generate stack frames."
 msgstr "盡可能不產生堆疊框架"
 
-#: common.opt:1938
+#: common.opt:1942
 #, fuzzy
 msgid "Enable all optimization info dumps on stderr."
 msgstr "在樹層級進行循環最佳化"
 
-#: common.opt:1942
+#: common.opt:1946
 msgid "-fopt-info[-<type>=filename]\tDump compiler optimization details."
 msgstr ""
 
-#: common.opt:1950
+#: common.opt:1954
 #, fuzzy
 #| msgid "Optimize sibling and tail recursive calls"
 msgid "Optimize sibling and tail recursive calls."
 msgstr "最佳化同級遞迴和尾遞迴"
 
-#: common.opt:1954
+#: common.opt:1958
 #, fuzzy
 msgid "Perform partial inlining."
 msgstr "施行部分內聯"
 
-#: common.opt:1958 common.opt:1962
+#: common.opt:1962 common.opt:1966
 #, fuzzy
 msgid "Report on memory allocation before interprocedural optimization."
 msgstr "報告於記憶體配置之前 interprocedural 最佳化"
 
-#: common.opt:1966
+#: common.opt:1970
 #, fuzzy
 #| msgid "Pack structure members together without holes"
 msgid "Pack structure members together without holes."
 msgstr "將結構成員不帶間隔地緊實存放"
 
-#: common.opt:1970
+#: common.opt:1974
 #, fuzzy
 msgid "-fpack-struct=<number>\tSet initial maximum structure member alignment."
 msgstr "-fpack-struct=<number>\t設定初始最大值結構成員對齊"
 
-#: common.opt:1974
+#: common.opt:1978
 #, fuzzy
 #| msgid "Return small aggregates in memory, not registers"
 msgid "Return small aggregates in memory, not registers."
 msgstr "在記憶體而不是暫存器中回傳小聚合"
 
-#: common.opt:1978
+#: common.opt:1982
 #, fuzzy
 #| msgid "Perform loop peeling"
 msgid "Perform loop peeling."
 msgstr "進行循環剝離"
 
-#: common.opt:1982
+#: common.opt:1986
 #, fuzzy
 #| msgid "Enable machine specific peephole optimizations"
 msgid "Enable machine specific peephole optimizations."
 msgstr "啟用機器相關的窺孔最佳化"
 
-#: common.opt:1986
+#: common.opt:1990
 #, fuzzy
 #| msgid "Enable an RTL peephole pass before sched2"
 msgid "Enable an RTL peephole pass before sched2."
 msgstr "在 sched2 前進行一趟 RTL 窺孔最佳化"
 
-#: common.opt:1990
+#: common.opt:1994
 #, fuzzy
 #| msgid "Generate position-independent code if possible (large mode)"
 msgid "Generate position-independent code if possible (large mode)."
 msgstr "盡可能產生與位置無關的程式碼(大模式)"
 
-#: common.opt:1994
+#: common.opt:1998
 #, fuzzy
 #| msgid "Generate position-independent code for executables if possible (large mode)"
 msgid "Generate position-independent code for executables if possible (large mode)."
 msgstr "為可執行檔案盡可能產生與位置無關的程式碼(大模式)"
 
-#: common.opt:1998
+#: common.opt:2002
 #, fuzzy
 #| msgid "Generate position-independent code if possible (small mode)"
 msgid "Generate position-independent code if possible (small mode)."
 msgstr "盡可能產生與位置無關的程式碼(小模式)"
 
-#: common.opt:2002
+#: common.opt:2006
 #, fuzzy
 #| msgid "Generate position-independent code for executables if possible (small mode)"
 msgid "Generate position-independent code for executables if possible (small mode)."
 msgstr "為可執行檔案盡可能產生與位置無關的程式碼(小模式)"
 
-#: common.opt:2006
+#: common.opt:2010
 msgid "Use PLT for PIC calls (-fno-plt: load the address from GOT at call site)."
 msgstr ""
 
-#: common.opt:2010
+#: common.opt:2014
 #, fuzzy
 msgid "Specify a plugin to load."
 msgstr "指定外掛程式到載入"
 
-#: common.opt:2014
+#: common.opt:2018
 #, fuzzy
 msgid "-fplugin-arg-<name>-<key>[=<value>]\tSpecify argument <key>=<value> for plugin <name>."
 msgstr "-fplugin-arg-<name>-< 鍵>[=<值>]\t指定引數<鍵>=<值>用於外掛程式<名稱>"
 
-#: common.opt:2018
+#: common.opt:2022
 #, fuzzy
 msgid "Run predictive commoning optimization."
 msgstr "運行 predictive 共同最佳化。"
 
-#: common.opt:2022
+#: common.opt:2026
 #, fuzzy
 #| msgid "Generate prefetch instructions, if available, for arrays in loops"
 msgid "Generate prefetch instructions, if available, for arrays in loops."
 msgstr "如果可用，為循環中的陣列產生預取指令"
 
-#: common.opt:2026
+#: common.opt:2030
 #, fuzzy
 #| msgid "Enable basic program profiling code"
 msgid "Enable basic program profiling code."
 msgstr "啟用基本程式取樣程式碼"
 
-#: common.opt:2030
+#: common.opt:2034
 msgid "Generate absolute source path names for gcov."
 msgstr ""
 
-#: common.opt:2034
+#: common.opt:2038
 #, fuzzy
 msgid "Insert arc-based program profiling code."
 msgstr "插入 arc-based 程式側寫檔編碼"
 
-#: common.opt:2038
+#: common.opt:2042
 #, fuzzy
 msgid "Set the top-level directory for storing the profile data. The default is 'pwd'."
 msgstr "設定最上層目錄用於存入側寫檔資料。"
 
-#: common.opt:2043
+#: common.opt:2047
 #, fuzzy
 msgid "Enable correction of flow inconsistent profile data input."
 msgstr "啟用校正的流程不一致側寫檔資料輸入"
 
-#: common.opt:2047
+#: common.opt:2051
 msgid "-fprofile-update=[single|atomic|prefer-atomic]\tSet the profile update method."
 msgstr ""
 
-#: common.opt:2050
+#: common.opt:2054
 #, fuzzy, c-format
 msgid "unknown profile update method %qs"
 msgstr "不明 TLS 式樣 %qs"
 
-#: common.opt:2063
+#: common.opt:2067
 #, fuzzy
 #| msgid "Enable common options for generating profile info for profile feedback directed optimizations"
 msgid "Enable common options for generating profile info for profile feedback directed optimizations."
 msgstr "啟用一些公共選項來產生樣本檔案，以便進行基於取樣的最佳化"
 
-#: common.opt:2067
+#: common.opt:2071
 #, fuzzy
 msgid "Enable common options for generating profile info for profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr "啟用共同選項用於產生側寫檔資訊用於側寫檔反饋導最佳化，而設定 -fprofile-dir="
 
-#: common.opt:2071
+#: common.opt:2075
 #, fuzzy
 #| msgid "Enable common options for performing profile feedback directed optimizations"
 msgid "Enable common options for performing profile feedback directed optimizations."
 msgstr "啟用一些公共選項以進行基於取樣的最佳化"
 
-#: common.opt:2075
+#: common.opt:2079
 #, fuzzy
 msgid "Enable common options for performing profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr "啟用共同選項用於履行側寫檔反饋導最佳化，而設定 -fprofile-dir="
 
-#: common.opt:2079
+#: common.opt:2083
 #, fuzzy
 #| msgid "Insert code to profile values of expressions"
 msgid "Insert code to profile values of expressions."
 msgstr "為取樣運算式的值插入相關程式碼"
 
-#: common.opt:2083
+#: common.opt:2087
 #, fuzzy
 msgid "Report on consistency of profile."
 msgstr "內部一致性錯誤"
 
-#: common.opt:2087
+#: common.opt:2091
 #, fuzzy
 #| msgid "Reorder functions to improve code placement"
 msgid "Enable function reordering that improves code placement."
 msgstr "函式重新排序以改善程式碼版面設置"
 
-#: common.opt:2091
+#: common.opt:2095
 #, fuzzy
 msgid "Insert NOP instructions at each function entry."
 msgstr "產生 cld 指令在中函式 prologue。"
 
-#: common.opt:2098
+#: common.opt:2102
 #, fuzzy
 msgid "-frandom-seed=<string>\tMake compile reproducible using <string>."
 msgstr "-frandom-seed=<string>\t製作編譯可再生使用<字串>"
 
-#: common.opt:2108
+#: common.opt:2112
 #, fuzzy
 msgid "Record gcc command line switches in the object file."
 msgstr "記錄 gcc 命令列切換在中目的檔案。"
 
-#: common.opt:2112
+#: common.opt:2116
 #, fuzzy
 #| msgid "Return small aggregates in registers"
 msgid "Return small aggregates in registers."
 msgstr "在暫存器中回傳小聚合"
 
-#: common.opt:2120
+#: common.opt:2124
 msgid "Tell DSE that the storage for a C++ object is dead when the constructor starts and when the destructor finishes."
 msgstr ""
 
-#: common.opt:2128
+#: common.opt:2132
 #, fuzzy
 msgid "Relief of register pressure through live range shrinkage."
 msgstr "啟用暫存器壓力敏感的 insn 排程"
 
-#: common.opt:2132
+#: common.opt:2136
 #, fuzzy
 #| msgid "Perform a register renaming optimization pass"
 msgid "Perform a register renaming optimization pass."
 msgstr "進行暫存器重新命名最佳化"
 
-#: common.opt:2136
+#: common.opt:2140
 #, fuzzy
 #| msgid "Perform a register renaming optimization pass"
 msgid "Perform a target dependent instruction fusion optimization pass."
 msgstr "進行暫存器重新命名最佳化"
 
-#: common.opt:2140
+#: common.opt:2144
 #, fuzzy
 #| msgid "Reorder basic blocks to improve code placement"
 msgid "Reorder basic blocks to improve code placement."
 msgstr "基本區塊重新排序以改善程式碼版面設置"
 
-#: common.opt:2144
+#: common.opt:2148
 msgid "-freorder-blocks-algorithm=[simple|stc]\tSet the used basic block reordering algorithm."
 msgstr ""
 
-#: common.opt:2147
+#: common.opt:2151
 #, fuzzy, c-format
 msgid "unknown basic block reordering algorithm %qs"
 msgstr "不明 IRA 演算法 %qs"
 
-#: common.opt:2157
+#: common.opt:2161
 #, fuzzy
 msgid "Reorder basic blocks and partition into hot and cold sections."
 msgstr "重新排序基本區塊和分割進入熱門和 cold 區段"
 
-#: common.opt:2161
+#: common.opt:2165
 #, fuzzy
 #| msgid "Reorder functions to improve code placement"
 msgid "Reorder functions to improve code placement."
 msgstr "函式重新排序以改善程式碼版面設置"
 
-#: common.opt:2165
+#: common.opt:2169
 #, fuzzy
 #| msgid "Add a common subexpression elimination pass after loop optimizations"
 msgid "Add a common subexpression elimination pass after loop optimizations."
 msgstr "在循環最佳化結束後增加一趟公因式消去"
 
-#: common.opt:2173
+#: common.opt:2177
 #, fuzzy
 #| msgid "Disable optimizations that assume default FP rounding behavior"
 msgid "Disable optimizations that assume default FP rounding behavior."
 msgstr "停用假定預設浮點捨入行為的最佳化"
 
-#: common.opt:2177
+#: common.opt:2181
 #, fuzzy
 #| msgid "Enable scheduling across basic blocks"
 msgid "Enable scheduling across basic blocks."
 msgstr "啟用基本區塊間的調度"
 
-#: common.opt:2181
+#: common.opt:2185
 #, fuzzy
 msgid "Enable register pressure sensitive insn scheduling."
 msgstr "啟用暫存器壓力敏感的 insn 排程"
 
-#: common.opt:2185
+#: common.opt:2189
 #, fuzzy
 #| msgid "Allow speculative motion of non-loads"
 msgid "Allow speculative motion of non-loads."
 msgstr "允許非載入的預測移動"
 
-#: common.opt:2189
+#: common.opt:2193
 #, fuzzy
 #| msgid "Allow speculative motion of some loads"
 msgid "Allow speculative motion of some loads."
 msgstr "允許一些載入的預測移動"
 
-#: common.opt:2193
+#: common.opt:2197
 #, fuzzy
 #| msgid "Allow speculative motion of more loads"
 msgid "Allow speculative motion of more loads."
 msgstr "允許更多載入的預測移動"
 
-#: common.opt:2197
+#: common.opt:2201
 #, fuzzy
 msgid "-fsched-verbose=<number>\tSet the verbosity level of the scheduler."
 msgstr "-fsched-verbose=<number>\t設定詳細度等級的排程程式"
 
-#: common.opt:2201
+#: common.opt:2205
 #, fuzzy
 msgid "If scheduling post reload, do superblock scheduling."
 msgstr "如果排程貼文重新載入，做超區塊排程"
 
-#: common.opt:2209
+#: common.opt:2213
 #, fuzzy
 #| msgid "Reschedule instructions before register allocation"
 msgid "Reschedule instructions before register allocation."
 msgstr "指派暫存器前重新調度指令"
 
-#: common.opt:2213
+#: common.opt:2217
 #, fuzzy
 #| msgid "Reschedule instructions after register allocation"
 msgid "Reschedule instructions after register allocation."
 msgstr "指派暫存器後重新調度指令"
 
-#: common.opt:2220
+#: common.opt:2224
 #, fuzzy
 msgid "Schedule instructions using selective scheduling algorithm."
 msgstr "排程指令使用選擇性排程演算法"
 
-#: common.opt:2224
+#: common.opt:2228
 #, fuzzy
 msgid "Run selective scheduling after reload."
 msgstr "運行選擇性排程之後重新載入"
 
-#: common.opt:2228
+#: common.opt:2232
 msgid "Run self-tests, using the given path to locate test files."
 msgstr ""
 
-#: common.opt:2232
+#: common.opt:2236
 #, fuzzy
 msgid "Perform software pipelining of inner loops during selective scheduling."
 msgstr "施行軟體管線操作的內迴圈在的期間選擇性排程"
 
-#: common.opt:2236
+#: common.opt:2240
 #, fuzzy
 msgid "Perform software pipelining of outer loops during selective scheduling."
 msgstr "施行軟體管線操作的外迴圈在的期間選擇性排程"
 
-#: common.opt:2240
+#: common.opt:2244
 #, fuzzy
 msgid "Reschedule pipelined regions without pipelining."
 msgstr "重新排程管線的區域而無需管線操作"
 
-#: common.opt:2244
+#: common.opt:2248
 msgid "Allow interposing function (or variables) by ones with different semantics (or initializer) respectively by dynamic linker."
 msgstr ""
 
-#: common.opt:2250
+#: common.opt:2254
 #, fuzzy
 msgid "Allow premature scheduling of queued insns."
 msgstr "允許過早排程的已佇列 insns"
 
-#: common.opt:2254
+#: common.opt:2258
 #, fuzzy
 msgid "-fsched-stalled-insns=<number>\tSet number of queued insns that can be prematurely scheduled."
 msgstr "-fsched-stalled-insns=<number>\t設定已佇列 insns 數量該可以是過早已排程"
 
-#: common.opt:2262
+#: common.opt:2266
 #, fuzzy
 msgid "Set dependence distance checking in premature scheduling of queued insns."
 msgstr "設定 dependence 距離簽入過早排程的已佇列 insns"
 
-#: common.opt:2266
+#: common.opt:2270
 #, fuzzy
 msgid "-fsched-stalled-insns-dep=<number>\tSet dependence distance checking in premature scheduling of queued insns."
 msgstr "-fsched-stalled-insns-dep=<number>\t設定 dependence 距離簽入過早排程的已佇列 insns"
 
-#: common.opt:2270
+#: common.opt:2274
 #, fuzzy
 msgid "Enable the group heuristic in the scheduler."
 msgstr "啟用群組試探在中排程程式"
 
-#: common.opt:2274
+#: common.opt:2278
 #, fuzzy
 msgid "Enable the critical path heuristic in the scheduler."
 msgstr "啟用關鍵路徑試探在中排程程式"
 
-#: common.opt:2278
+#: common.opt:2282
 #, fuzzy
 msgid "Enable the speculative instruction heuristic in the scheduler."
 msgstr "啟用 speculative 指令試探在中排程程式"
 
-#: common.opt:2282
+#: common.opt:2286
 #, fuzzy
 msgid "Enable the rank heuristic in the scheduler."
 msgstr "啟用分級試探在中排程程式"
 
-#: common.opt:2286
+#: common.opt:2290
 #, fuzzy
 msgid "Enable the last instruction heuristic in the scheduler."
 msgstr "啟用最後一筆指令試探在中排程程式"
 
-#: common.opt:2290
+#: common.opt:2294
 #, fuzzy
 msgid "Enable the dependent count heuristic in the scheduler."
 msgstr "啟用附屬計數試探在中排程程式"
 
-#: common.opt:2294
+#: common.opt:2298
 #, fuzzy
 msgid "Access data in the same section from shared anchor points."
 msgstr "存取資料在中相同區段從共享的錨點"
 
-#: common.opt:2306
+#: common.opt:2310
 #, fuzzy
 msgid "Turn on Redundant Extensions Elimination pass."
 msgstr "打開冗餘延伸 Elimination 回合。"
 
-#: common.opt:2310
+#: common.opt:2314
 #, fuzzy
 msgid "Show column numbers in diagnostics, when available.  Default on."
 msgstr "顯示欄數量在中診斷，若是可用。 預設開"
 
-#: common.opt:2314
+#: common.opt:2318
 #, fuzzy
 msgid "Emit function prologues only before parts of the function that need it, rather than at the top of the function."
 msgstr "Emit 函式 prologues 只有之前零件的函式該需要它，"
 
-#: common.opt:2319
+#: common.opt:2323
 msgid "Shrink-wrap parts of the prologue and epilogue separately."
 msgstr ""
 
-#: common.opt:2323
+#: common.opt:2327
 #, fuzzy
 #| msgid "Disable optimizations observable by IEEE signaling NaNs"
 msgid "Disable optimizations observable by IEEE signaling NaNs."
 msgstr "停用為 IEEE 訊息 NaN 可見的最佳化"
 
-#: common.opt:2327
+#: common.opt:2331
 #, fuzzy
 msgid "Disable floating point optimizations that ignore the IEEE signedness of zero."
 msgstr "停用浮點數最佳化該忽略我 signedness 的零"
 
-#: common.opt:2331
+#: common.opt:2335
 #, fuzzy
 #| msgid "Convert floating point constants to single precision constants"
 msgid "Convert floating point constants to single precision constants."
 msgstr "將浮點常數轉換為單精度常數"
 
-#: common.opt:2335
+#: common.opt:2339
 #, fuzzy
 #| msgid "Split lifetimes of induction variables when loops are unrolled"
 msgid "Split lifetimes of induction variables when loops are unrolled."
 msgstr "展開循環時分離歸納變數的生存期"
 
-#: common.opt:2339
+#: common.opt:2343
 #, fuzzy
 msgid "Generate discontiguous stack frames."
 msgstr "產生 discontiguous 堆疊框架"
 
-#: common.opt:2343
+#: common.opt:2347
 #, fuzzy
 msgid "Split wide types into independent registers."
 msgstr "分割 wide 類型進入獨立暫存器"
 
-#: common.opt:2347
+#: common.opt:2351
 #, fuzzy
 msgid "Enable backward propagation of use properties at the SSA level."
 msgstr "啟用轉寄傳播於樹"
 
-#: common.opt:2351
+#: common.opt:2355
 msgid "Optimize conditional patterns using SSA PHI nodes."
 msgstr ""
 
-#: common.opt:2355
+#: common.opt:2359
 msgid "Optimize amount of stdarg registers saved to stack at start of function."
 msgstr ""
 
-#: common.opt:2359
+#: common.opt:2363
 #, fuzzy
 #| msgid "Apply variable expansion when loops are unrolled"
 msgid "Apply variable expansion when loops are unrolled."
 msgstr "展開循環時也展開變數"
 
-#: common.opt:2363
+#: common.opt:2367
 #, fuzzy
 msgid "-fstack-check=[no|generic|specific]\tInsert stack checking code into the program."
 msgstr "-fstack-check=[沒有|通用|特定的]\t插入堆疊檢查編碼進入程式"
 
-#: common.opt:2367
+#: common.opt:2371
 #, fuzzy
 msgid "Insert stack checking code into the program.  Same as -fstack-check=specific."
 msgstr "插入堆疊檢查編碼進入程式。 如同 -fstack-check=特定的"
 
-#: common.opt:2371
+#: common.opt:2375
 msgid "Insert code to probe each page of stack space as it is allocated to protect from stack-clash style attacks."
 msgstr ""
 
-#: common.opt:2379
+#: common.opt:2383
 #, fuzzy
 msgid "-fstack-limit-register=<register>\tTrap if the stack goes past <register>."
 msgstr "-fstack-limit-register=<register>\t陷阱如果堆疊前往過去<暫存器>"
 
-#: common.opt:2383
+#: common.opt:2387
 #, fuzzy
 msgid "-fstack-limit-symbol=<name>\tTrap if the stack goes past symbol <name>."
 msgstr "-fstack-limit-symbol=<name>\t陷阱如果堆疊前往過去符號<名稱>"
 
-#: common.opt:2387
+#: common.opt:2391
 #, fuzzy
 msgid "Use propolice as a stack protection method."
 msgstr "使用 propolice 做為堆疊保護方法"
 
-#: common.opt:2391
+#: common.opt:2395
 #, fuzzy
 msgid "Use a stack protection method for every function."
 msgstr "使用堆疊保護方法用於每函式"
 
-#: common.opt:2395
+#: common.opt:2399
 #, fuzzy
 msgid "Use a smart stack protection method for certain functions."
 msgstr "使用堆疊保護方法用於每函式"
 
-#: common.opt:2399
+#: common.opt:2403
 #, fuzzy
 msgid "Use stack protection method only for functions with the stack_protect attribute."
 msgstr "使用堆疊保護方法用於每函式"
 
-#: common.opt:2403
+#: common.opt:2407
 #, fuzzy
 msgid "Output stack usage information on a per-function basis."
 msgstr "輸出堆疊用法資訊於 per-function 基礎"
 
-#: common.opt:2415
+#: common.opt:2419
 #, fuzzy
 #| msgid "Assume strict aliasing rules apply"
 msgid "Assume strict aliasing rules apply."
 msgstr "假定套用強重疊規則"
 
-#: common.opt:2419
+#: common.opt:2423
 #, fuzzy
 msgid "Treat signed overflow as undefined.  Negated as -fwrapv -fwrapv-pointer."
 msgstr "對待帶正負號溢位做為未定義"
 
-#: common.opt:2423
+#: common.opt:2427
 msgid "Implement __atomic operations via libcalls to legacy __sync functions."
 msgstr ""
 
-#: common.opt:2427
+#: common.opt:2431
 #, fuzzy
 #| msgid "Check for syntax errors, then stop"
 msgid "Check for syntax errors, then stop."
 msgstr "檢查語法錯誤，然後停止"
 
-#: common.opt:2431
+#: common.opt:2435
 #, fuzzy
 #| msgid "Create data files needed by \"gcov\""
 msgid "Create data files needed by \"gcov\"."
 msgstr "產生「gcov」需要的資料檔案"
 
-#: common.opt:2435
+#: common.opt:2439
 #, fuzzy
 #| msgid "Perform jump threading optimizations"
 msgid "Perform jump threading optimizations."
 msgstr "進行跳轉執行緒最佳化"
 
-#: common.opt:2439
+#: common.opt:2443
 #, fuzzy
 #| msgid "Report the time taken by each compiler pass"
 msgid "Report the time taken by each compiler pass."
 msgstr "報告每趟組譯的耗時"
 
-#: common.opt:2443
+#: common.opt:2447
 msgid "Record times taken by sub-phases separately."
 msgstr ""
 
-#: common.opt:2447
+#: common.opt:2451
 #, fuzzy
 msgid "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tSet the default thread-local storage code generation model."
 msgstr "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\t設定預設 thread-local 貯藏體編碼產生式樣"
 
-#: common.opt:2450
+#: common.opt:2454
 #, fuzzy, c-format
 msgid "unknown TLS model %qs"
 msgstr "不明 TLS 式樣 %qs"
 
-#: common.opt:2466
+#: common.opt:2470
 #, fuzzy
 msgid "Reorder top level functions, variables, and asms."
 msgstr "重新排序頂層函式、變數，而asms"
 
-#: common.opt:2470
+#: common.opt:2474
 #, fuzzy
 msgid "Perform superblock formation via tail duplication."
 msgstr "施行超區塊格式透過尾端複印法"
 
-#: common.opt:2474
+#: common.opt:2478
 msgid "For targets that normally need trampolines for nested functions, always generate them instead of using descriptors."
 msgstr ""
 
-#: common.opt:2482
+#: common.opt:2486
 #, fuzzy
 #| msgid "Assume floating-point operations can trap"
 msgid "Assume floating-point operations can trap."
 msgstr "假定浮點運算可能引發陷阱"
 
-#: common.opt:2486
+#: common.opt:2490
 #, fuzzy
 msgid "Trap for signed overflow in addition, subtraction and multiplication."
 msgstr "陷阱用於帶正負號溢位另外、減去和乘法"
 
-#: common.opt:2490
+#: common.opt:2494
 #, fuzzy
 #| msgid "Enable SSA-CCP optimization on trees"
 msgid "Enable SSA-CCP optimization on trees."
 msgstr "啟用樹上的 SSA-CCP 最佳化"
 
-#: common.opt:2494
+#: common.opt:2498
 #, fuzzy
 msgid "Enable SSA-BIT-CCP optimization on trees."
 msgstr "啟用 SSA-BIT-CCP 最佳化於樹"
 
-#: common.opt:2502
+#: common.opt:2506
 #, fuzzy
 #| msgid "Enable loop header copying on trees"
 msgid "Enable loop header copying on trees."
 msgstr "啟用樹上的循環不變量轉移"
 
-#: common.opt:2510
+#: common.opt:2514
 #, fuzzy
 msgid "Enable SSA coalescing of user variables."
 msgstr "施行變數追蹤並且標籤變數所 uninitialized"
 
-#: common.opt:2518
+#: common.opt:2522
 #, fuzzy
 #| msgid "Enable copy propagation on trees"
 msgid "Enable copy propagation on trees."
 msgstr "在樹層級進行複寫傳遞"
 
-#: common.opt:2526
+#: common.opt:2530
 #, fuzzy
 msgid "Transform condition stores into unconditional ones."
 msgstr "變換條件儲存進入 unconditional 一個"
 
-#: common.opt:2530
+#: common.opt:2534
 #, fuzzy
 msgid "Perform conversions of switch initializations."
 msgstr "施行轉換的切換初始化。"
 
-#: common.opt:2534
+#: common.opt:2538
 #, fuzzy
 #| msgid "Enable SSA dead code elimination optimization on trees"
 msgid "Enable SSA dead code elimination optimization on trees."
 msgstr "啟用樹上的 SSA 死程式碼消除最佳化"
 
-#: common.opt:2538
+#: common.opt:2542
 #, fuzzy
 #| msgid "Enable dominator optimizations"
 msgid "Enable dominator optimizations."
 msgstr "啟用主導最佳化"
 
-#: common.opt:2542
+#: common.opt:2546
 #, fuzzy
 msgid "Enable tail merging on trees."
 msgstr "啟用尾端合併於樹"
 
-#: common.opt:2546
+#: common.opt:2550
 #, fuzzy
 #| msgid "Enable dead store elimination"
 msgid "Enable dead store elimination."
 msgstr "刪除死存儲"
 
-#: common.opt:2550
+#: common.opt:2554
 #, fuzzy
 msgid "Enable forward propagation on trees."
 msgstr "啟用轉寄傳播於樹"
 
-#: common.opt:2554
+#: common.opt:2558
 #, fuzzy
 #| msgid "Enable Full Redundancy Elimination (FRE) on trees"
 msgid "Enable Full Redundancy Elimination (FRE) on trees."
 msgstr "啟用樹上的完全冗餘消除(FRE)"
 
-#: common.opt:2558
+#: common.opt:2562
 #, fuzzy
 msgid "Enable string length optimizations on trees."
 msgstr "啟用字串長度最佳化於樹"
 
-#: common.opt:2562
+#: common.opt:2566
 msgid "Detect paths that trigger erroneous or undefined behavior due to dereferencing a null pointer.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
-#: common.opt:2568
+#: common.opt:2572
 msgid "Detect paths that trigger erroneous or undefined behavior due to a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
-#: common.opt:2575
+#: common.opt:2579
 #, fuzzy
 msgid "Enable loop distribution on trees."
 msgstr "啟用迴圈發布於樹"
 
-#: common.opt:2579
+#: common.opt:2583
 #, fuzzy
 msgid "Enable loop distribution for patterns transformed into a library call."
 msgstr "啟用迴圈發布用於胚騰變換的進入函式庫呼叫"
 
-#: common.opt:2583
+#: common.opt:2587
 #, fuzzy
 #| msgid "Enable loop invariant motion on trees"
 msgid "Enable loop invariant motion on trees."
 msgstr "啟用樹上的循環不變量轉移"
 
-#: common.opt:2591
+#: common.opt:2595
 #, fuzzy
 #| msgid "Create canonical induction variables in loops"
 msgid "Create canonical induction variables in loops."
 msgstr "在循環中產生正規的歸納變數"
 
-#: common.opt:2595
+#: common.opt:2599
 #, fuzzy
 #| msgid "Enable loop optimizations on tree level"
 msgid "Enable loop optimizations on tree level."
 msgstr "在樹層級進行循環最佳化"
 
-#: common.opt:2599
+#: common.opt:2603
 #, fuzzy
 msgid "-ftree-parallelize-loops=<number>\tEnable automatic parallelization of loops."
 msgstr "啟用自動 parallelization 的迴圈"
 
-#: common.opt:2603
+#: common.opt:2607
 #, fuzzy
 msgid "Enable hoisting loads from conditional pointers."
 msgstr "啟用 hoisting 載入從條件指標。"
 
-#: common.opt:2607
+#: common.opt:2611
 #, fuzzy
 #| msgid "Enable SSA-PRE optimization on trees"
 msgid "Enable SSA-PRE optimization on trees."
 msgstr "啟用樹上的 SSA-PRE 最佳化"
 
-#: common.opt:2611
+#: common.opt:2615
 msgid "In SSA-PRE optimization on trees, enable partial-partial redundancy elimination."
 msgstr ""
 
-#: common.opt:2615
+#: common.opt:2619
 #, fuzzy
 msgid "Perform function-local points-to analysis on trees."
 msgstr "施行 function-local points-to 分析於樹。"
 
-#: common.opt:2619
+#: common.opt:2623
 #, fuzzy
 msgid "Enable reassociation on tree level."
 msgstr "啟用 reassociation 於樹等級"
 
-#: common.opt:2627
+#: common.opt:2631
 #, fuzzy
 #| msgid "Enable SSA code sinking on trees"
 msgid "Enable SSA code sinking on trees."
 msgstr "啟用樹上的 SSA 程式碼下沉最佳化"
 
-#: common.opt:2631
+#: common.opt:2635
 #, fuzzy
 msgid "Perform straight-line strength reduction."
 msgstr "進行強度削減最佳化"
 
-#: common.opt:2635
+#: common.opt:2639
 #, fuzzy
 #| msgid "Perform scalar replacement of aggregates"
 msgid "Perform scalar replacement of aggregates."
 msgstr "為聚合類型進行標量替換"
 
-#: common.opt:2639
+#: common.opt:2643
 #, fuzzy
 msgid "Replace temporary expressions in the SSA->normal pass."
 msgstr "置換暫時的運算式在中 SSA-> 一般回合"
 
-#: common.opt:2643
+#: common.opt:2647
 #, fuzzy
 msgid "Perform live range splitting during the SSA->normal pass."
 msgstr "施行即時範圍分裂在的期間 SSA-> 一般回合"
 
-#: common.opt:2647
+#: common.opt:2651
 #, fuzzy
 #| msgid "Perform Value Range Propagation on trees"
 msgid "Perform Value Range Propagation on trees."
 msgstr "進行樹上的值欄位傳遞"
 
-#: common.opt:2651
+#: common.opt:2655
 msgid "Split paths leading to loop backedges."
 msgstr ""
 
-#: common.opt:2655
+#: common.opt:2659
 msgid "Assume common declarations may be overridden with ones with a larger trailing array."
 msgstr ""
 
-#: common.opt:2660
+#: common.opt:2664
 #, fuzzy
 #| msgid "Compile whole compilation unit at a time"
 msgid "Compile whole compilation unit at a time."
 msgstr "一次編譯一整個編譯單元"
 
-#: common.opt:2664
+#: common.opt:2668
 #, fuzzy
 #| msgid "Perform loop unrolling when iteration count is known"
 msgid "Perform loop unrolling when iteration count is known."
 msgstr "展開所有迭代次數已知的循環"
 
-#: common.opt:2668
+#: common.opt:2672
 #, fuzzy
 #| msgid "Perform loop unrolling for all loops"
 msgid "Perform loop unrolling for all loops."
 msgstr "展開所有循環"
 
-#: common.opt:2679
+#: common.opt:2683
 #, fuzzy
 msgid "Allow optimization for floating-point arithmetic which may change the result of the operation due to rounding."
 msgstr "允許最佳化用於浮點算術該項也許會變更"
 
-#: common.opt:2684
+#: common.opt:2688
 #, fuzzy
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr "如同 -fassociative-math 用於運算式該項包含除法。"
 
-#: common.opt:2692
+#: common.opt:2696
 #, fuzzy
 #| msgid "Allow math optimizations that may violate IEEE or ISO standards"
 msgid "Allow math optimizations that may violate IEEE or ISO standards."
 msgstr "允許可能違反 IEEE 或 ISO 標準的最佳化"
 
-#: common.opt:2696
+#: common.opt:2700
 #, fuzzy
 #| msgid "Perform loop unswitching"
 msgid "Perform loop unswitching."
 msgstr "外提循環內的測試敘述"
 
-#: common.opt:2700
+#: common.opt:2704
 #, fuzzy
 #| msgid "Perform loop peeling"
 msgid "Perform loop splitting."
 msgstr "進行循環剝離"
 
-#: common.opt:2704
+#: common.opt:2708
 #, fuzzy
 #| msgid "Just generate unwind tables for exception handling"
 msgid "Just generate unwind tables for exception handling."
 msgstr "僅為異常處理產生堆疊展開表"
 
-#: common.opt:2708
+#: common.opt:2712
 #, fuzzy
 msgid "Use the bfd linker instead of the default linker."
 msgstr "使用硬體大桶 shifter 以代替模擬"
 
-#: common.opt:2712
+#: common.opt:2716
 #, fuzzy
 msgid "Use the gold linker instead of the default linker."
 msgstr "使用硬體大桶 shifter 以代替模擬"
 
-#: common.opt:2724
+#: common.opt:2728
 #, fuzzy
 #| msgid "Perform variable tracking"
 msgid "Perform variable tracking."
 msgstr "進行變數追蹤"
 
-#: common.opt:2732
+#: common.opt:2736
 #, fuzzy
 msgid "Perform variable tracking by annotating assignments."
 msgstr "施行變數追蹤由 notating 指派"
 
-#: common.opt:2738
+#: common.opt:2742
 #, fuzzy
 msgid "Toggle -fvar-tracking-assignments."
 msgstr "切換 -fvar-tracking-assignments"
 
-#: common.opt:2746
+#: common.opt:2750
 #, fuzzy
 msgid "Perform variable tracking and also tag variables that are uninitialized."
 msgstr "施行變數追蹤並且標籤變數所 uninitialized"
 
-#: common.opt:2751
+#: common.opt:2755
 #, fuzzy
 #| msgid "Enable loop vectorization on trees"
 msgid "Enable vectorization on trees."
 msgstr "在樹上進行循環向量化"
 
-#: common.opt:2759
+#: common.opt:2763
 #, fuzzy
 #| msgid "Enable loop vectorization on trees"
 msgid "Enable loop vectorization on trees."
 msgstr "在樹上進行循環向量化"
 
-#: common.opt:2763
+#: common.opt:2767
 #, fuzzy
 msgid "Enable basic block vectorization (SLP) on trees."
 msgstr "啟用基本區塊 vectorization (SLP) 於樹"
 
-#: common.opt:2767
+#: common.opt:2771
 msgid "Specifies the cost model for vectorization. -fvect-cost-model=[unlimited|dynamic|cheap]\tSpecifies the cost model for vectorization."
 msgstr ""
 
-#: common.opt:2772
+#: common.opt:2776
 msgid "-fsimd-cost-model=[unlimited|dynamic|cheap]\tSpecifies the vectorization cost model for code marked with a simd directive."
 msgstr ""
 
-#: common.opt:2775
+#: common.opt:2779
 #, fuzzy, c-format
 msgid "unknown vectorizer cost model %qs"
 msgstr "不明 TLS 式樣 %qs"
 
-#: common.opt:2788
+#: common.opt:2792
 #, fuzzy
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr "沒做任何事。 保留的用於回溯相容性。"
 
-#: common.opt:2796
+#: common.opt:2800
 #, fuzzy
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr "啟用複製傳用的 scalar-evolution 資訊。"
 
-#: common.opt:2806
+#: common.opt:2810
 #, fuzzy
 #| msgid "Add extra commentary to assembler output"
 msgid "Add extra commentary to assembler output."
 msgstr "為組譯輸出加入額外註釋"
 
-#: common.opt:2810
+#: common.opt:2814
 #, fuzzy
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility."
 msgstr "-fvisibility=[預設|內部|隱藏|保護的]\t設定預設符號可視性"
 
-#: common.opt:2813
+#: common.opt:2817
 #, fuzzy, c-format
 msgid "unrecognized visibility value %qs"
 msgstr "無法辨識的可視性值 %qs"
 
-#: common.opt:2829
+#: common.opt:2833
 msgid "Validate vtable pointers before using them."
 msgstr ""
 
-#: common.opt:2832
+#: common.opt:2836
 #, fuzzy, c-format
 #| msgid "(near initialization for %qs)"
 msgid "unknown vtable verify initialization priority %qs"
 msgstr "(在 %qs 的初始化附近)"
 
-#: common.opt:2845
+#: common.opt:2849
 msgid "Output vtable verification counters."
 msgstr ""
 
-#: common.opt:2849
+#: common.opt:2853
 msgid "Output vtable verification pointer sets information."
 msgstr ""
 
-#: common.opt:2853
+#: common.opt:2857
 #, fuzzy
 #| msgid "Use expression value profiles in optimizations"
 msgid "Use expression value profiles in optimizations."
 msgstr "在最佳化中使用運算式值樣本提供的資訊"
 
-#: common.opt:2857
+#: common.opt:2861
 #, fuzzy
 msgid "Construct webs and split unrelated uses of single variable."
 msgstr "建構網頁和分割 unrelated 使用的單一變數"
 
-#: common.opt:2861
+#: common.opt:2865
 #, fuzzy
 msgid "Enable conditional dead code elimination for builtin calls."
 msgstr "啟用條件無作用程式碼 elimination 用於內建呼叫"
 
-#: common.opt:2865
+#: common.opt:2869
 #, fuzzy
 #| msgid "Perform whole program optimizations"
 msgid "Perform whole program optimizations."
 msgstr "進行全程式最佳化"
 
-#: common.opt:2869
+#: common.opt:2873
 #, fuzzy
 #| msgid "Assume signed arithmetic overflow wraps around"
 msgid "Assume pointer overflow wraps around."
 msgstr "假定有號運算溢出時回繞"
 
-#: common.opt:2873
+#: common.opt:2877
 #, fuzzy
 #| msgid "Assume signed arithmetic overflow wraps around"
 msgid "Assume signed arithmetic overflow wraps around."
 msgstr "假定有號運算溢出時回繞"
 
-#: common.opt:2877
+#: common.opt:2881
 #, fuzzy
 #| msgid "Put zero initialized data in the bss section"
 msgid "Put zero initialized data in the bss section."
 msgstr "將初始化為零的資料存放在 bss 區段中"
 
-#: common.opt:2881
+#: common.opt:2885
 #, fuzzy
 #| msgid "Generate debug information in default format"
 msgid "Generate debug information in default format."
 msgstr "產生預設格式的除錯資訊"
 
-#: common.opt:2885
+#: common.opt:2889
 #, fuzzy
 msgid "Assume assembler support for (DWARF2+) .loc directives"
 msgstr "%<-fsplit-stack%> 需求組譯器支援用於 CFI 指令"
 
-#: common.opt:2889
+#: common.opt:2893
 #, fuzzy
 msgid "Assume assembler support for view in (DWARF2+) .loc directives"
 msgstr "%<-fsplit-stack%> 需求組譯器支援用於 CFI 指令"
 
-#: common.opt:2892 common.opt:2896 common.opt:2900 common.opt:2904
+#: common.opt:2896 common.opt:2900 common.opt:2904 common.opt:2908
 #, fuzzy, c-format
 #| msgid "switch %qs is no longer supported"
 msgid "switch %qs no longer supported"
 msgstr "開關 %qs 不再被支援"
 
-#: common.opt:2909
+#: common.opt:2913
 msgid "Record DW_AT_decl_column and DW_AT_call_column in DWARF."
 msgstr ""
 
-#: common.opt:2913
+#: common.opt:2917
 #, fuzzy
 #| msgid "Generate debug information in default format"
 msgid "Generate debug information in default version of DWARF format."
 msgstr "產生預設格式的除錯資訊"
 
-#: common.opt:2917
+#: common.opt:2921
 #, fuzzy
 msgid "Generate debug information in DWARF v2 (or later) format."
 msgstr "產生除錯資訊在中 DWARF v2 (或稍後) 格式"
 
-#: common.opt:2921
+#: common.opt:2925
 #, fuzzy
 #| msgid "Generate debug information in default extended format"
 msgid "Generate debug information in default extended format."
 msgstr "產生預設擴充格式的除錯資訊"
 
-#: common.opt:2925
+#: common.opt:2929
 #, fuzzy
 #| msgid "Generate a single exit point for each function"
 msgid "Generate extended entry point information for inlined functions"
 msgstr "為每個函式產生單一的離開點"
 
-#: common.opt:2929
+#: common.opt:2933
 msgid "Compute locview reset points based on insn length estimates"
 msgstr ""
 
-#: common.opt:2937
+#: common.opt:2941
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:2941
+#: common.opt:2945
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:2945
+#: common.opt:2949
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr ""
 
-#: common.opt:2949
+#: common.opt:2953
 #, fuzzy
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr "記錄 gcc 命令列切換在中 DWARF DW_AT_producer。"
 
-#: common.opt:2953
+#: common.opt:2957
 #, fuzzy
 msgid "Generate debug information in separate .dwo files."
 msgstr "產生預設格式的除錯資訊"
 
-#: common.opt:2957
+#: common.opt:2961
 #, fuzzy
 #| msgid "Generate debug information in STABS format"
 msgid "Generate debug information in STABS format."
 msgstr "產生 STABS 格式的除錯資訊"
 
-#: common.opt:2961
+#: common.opt:2965
 #, fuzzy
 #| msgid "Generate debug information in extended STABS format"
 msgid "Generate debug information in extended STABS format."
 msgstr "產生擴充 STABS 格式的除錯資訊"
 
-#: common.opt:2965
+#: common.opt:2969
 msgid "Emit progressive recommended breakpoint locations."
 msgstr ""
 
-#: common.opt:2969
+#: common.opt:2973
 #, fuzzy
 msgid "Don't emit DWARF additions beyond selected version."
 msgstr "不 emit DWARF 增加位於之後已選版本"
 
-#: common.opt:2973
+#: common.opt:2977
 #, fuzzy
 msgid "Toggle debug information generation."
 msgstr "切換除錯資訊產生"
 
-#: common.opt:2977
+#: common.opt:2981
 msgid "Augment variable location lists with progressive views."
 msgstr ""
 
-#: common.opt:2984
+#: common.opt:2988
 #, fuzzy
 #| msgid "Generate debug information in VMS format"
 msgid "Generate debug information in VMS format."
 msgstr "產生 VMS 格式的除錯資訊"
 
-#: common.opt:2988
+#: common.opt:2992
 #, fuzzy
 #| msgid "Generate debug information in XCOFF format"
 msgid "Generate debug information in XCOFF format."
 msgstr "產生 XCOFF 格式的除錯資訊"
 
-#: common.opt:2992
+#: common.opt:2996
 #, fuzzy
 #| msgid "Generate debug information in extended XCOFF format"
 msgid "Generate debug information in extended XCOFF format."
 msgstr "產生 XCOFF 擴充格式的除錯資訊"
 
-#: common.opt:3010
+#: common.opt:3014
 #, fuzzy
 #| msgid "Generate isel instructions"
 msgid "Generate compressed debug sections."
 msgstr "產生 isel 指令"
 
-#: common.opt:3014
+#: common.opt:3018
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>."
 msgstr ""
 
-#: common.opt:3021
+#: common.opt:3025
 #, fuzzy
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory."
 msgstr "-iplugindir=<dir>\t設定<dir>為預設外掛程式目錄"
 
-#: common.opt:3025
+#: common.opt:3029
 #, fuzzy
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory."
 msgstr "-imultilib <dir>\t設定<dir>為 multilib 包含子目錄"
 
-#: common.opt:3047
+#: common.opt:3051
 #, fuzzy
 msgid "-o <file>\tPlace output into <file>."
 msgstr "-o <file>\t置放輸出進入<檔案>"
 
-#: common.opt:3051
+#: common.opt:3055
 #, fuzzy
 #| msgid "Enable function profiling"
 msgid "Enable function profiling."
 msgstr "啟用函式取樣"
 
-#: common.opt:3061
+#: common.opt:3065
 #, fuzzy
 #| msgid "Like -pedantic but issue them as errors"
 msgid "Like -pedantic but issue them as errors."
 msgstr "與 -pedantic 類似，但將它們視作錯誤"
 
-#: common.opt:3101
+#: common.opt:3105
 #, fuzzy
 #| msgid "Do not display functions compiled or elapsed time"
 msgid "Do not display functions compiled or elapsed time."
 msgstr "不顯示編譯的函式或逝去的時間"
 
-#: common.opt:3133
+#: common.opt:3137
 #, fuzzy
 #| msgid "Enable verbose output"
 msgid "Enable verbose output."
 msgstr "啟用詳細輸出"
 
-#: common.opt:3137
+#: common.opt:3141
 #, fuzzy
 #| msgid "Display the compiler's version"
 msgid "Display the compiler's version."
 msgstr "顯示編譯器版本"
 
-#: common.opt:3141
+#: common.opt:3145
 #, fuzzy
 #| msgid "Suppress warnings"
 msgid "Suppress warnings."
 msgstr "不顯示警告"
 
-#: common.opt:3151
+#: common.opt:3155
 #, fuzzy
 msgid "Create a shared library."
 msgstr "建立共用函式庫"
 
-#: common.opt:3196
+#: common.opt:3200
 #, fuzzy
 msgid "Don't create a dynamically linked position independent executable."
 msgstr "建立位置獨立可執行檔案"
 
-#: common.opt:3200
+#: common.opt:3204
 #, fuzzy
 msgid "Create a dynamically linked position independent executable."
 msgstr "建立位置獨立可執行檔案"
 
-#: common.opt:3204
+#: common.opt:3208
 #, fuzzy
 msgid "Create a static position independent executable."
 msgstr "建立位置獨立可執行檔案"
 
-#: common.opt:3211
+#: common.opt:3215
 msgid "Use caller save register across calls if possible."
 msgstr ""
 
-#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:598 cp/cvt.c:1308
+#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:599 cp/cvt.c:1308
 #: cp/cvt.c:1561
 #, gcc-internal-format
 msgid "value computed is not used"
@@ -18988,7 +18989,7 @@
 msgstr "預期的布林值型態"
 
 #: go/gofrontend/expressions.cc:4331 c/c-parser.c:13477 c/c-parser.c:13484
-#: cp/parser.c:33264 cp/parser.c:33271
+#: cp/parser.c:33261 cp/parser.c:33268
 #, fuzzy, gcc-internal-format
 #| msgid "Expected integer"
 msgid "expected integer"
@@ -19488,14 +19489,14 @@
 msgid "ignoring attribute %qE because it conflicts with attribute %qs"
 msgstr "%qE 屬性衝突與屬性 %s"
 
-#: attribs.c:449 c-family/c-attribs.c:1894 cp/decl.c:13690 cp/friend.c:302
-#: cp/tree.c:4559
+#: attribs.c:449 c-family/c-attribs.c:1905 cp/decl.c:13714 cp/friend.c:302
+#: cp/tree.c:4607
 #, fuzzy, gcc-internal-format
 msgid "previous declaration here"
 msgstr "與此處早先的宣告 %q+#D 衝突"
 
 #. Warn about and ignore all others for now, but store them.
-#: attribs.c:564 c-family/c-attribs.c:2717 objc/objc-act.c:4963
+#: attribs.c:564 c-family/c-attribs.c:2728 objc/objc-act.c:4963
 #: objc/objc-act.c:6932 objc/objc-act.c:8119 objc/objc-act.c:8170
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute directive ignored"
@@ -19514,17 +19515,17 @@
 #. This is a c++11 attribute that appertains to a
 #. type-specifier, outside of the definition of, a class
 #. type.  Ignore it.
-#: attribs.c:590 cp/decl.c:10999
+#: attribs.c:590 cp/decl.c:11023
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored"
 msgstr "%qE 屬性被忽略"
 
-#: attribs.c:592 cp/decl.c:11000
+#: attribs.c:592 cp/decl.c:11024
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
 
-#: attribs.c:610 c-family/c-attribs.c:3219
+#: attribs.c:610 c-family/c-attribs.c:3230
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute does not apply to types"
 msgstr "%qE 屬性不套用輸入"
@@ -19540,40 +19541,40 @@
 msgstr "型態屬性忽略的之後型態已經定義"
 
 #: attribs.c:691 attribs.c:1622 attribs.c:1632 attribs.c:1642
-#: c-family/c-attribs.c:540 c-family/c-attribs.c:559 c-family/c-attribs.c:577
-#: c-family/c-attribs.c:607 c-family/c-attribs.c:628 c-family/c-attribs.c:649
-#: c-family/c-attribs.c:690 c-family/c-attribs.c:717 c-family/c-attribs.c:733
-#: c-family/c-attribs.c:750 c-family/c-attribs.c:766 c-family/c-attribs.c:792
-#: c-family/c-attribs.c:807 c-family/c-attribs.c:835 c-family/c-attribs.c:852
-#: c-family/c-attribs.c:870 c-family/c-attribs.c:893 c-family/c-attribs.c:931
-#: c-family/c-attribs.c:954 c-family/c-attribs.c:971 c-family/c-attribs.c:1000
-#: c-family/c-attribs.c:1021 c-family/c-attribs.c:1042
-#: c-family/c-attribs.c:1069 c-family/c-attribs.c:1099
-#: c-family/c-attribs.c:1136 c-family/c-attribs.c:1189
-#: c-family/c-attribs.c:1255 c-family/c-attribs.c:1313
-#: c-family/c-attribs.c:1402 c-family/c-attribs.c:1432
-#: c-family/c-attribs.c:1483 c-family/c-attribs.c:1998
-#: c-family/c-attribs.c:2035 c-family/c-attribs.c:2096
-#: c-family/c-attribs.c:2152 c-family/c-attribs.c:2230
-#: c-family/c-attribs.c:2312 c-family/c-attribs.c:2371
-#: c-family/c-attribs.c:2390 c-family/c-attribs.c:2498
-#: c-family/c-attribs.c:2514 c-family/c-attribs.c:2530
-#: c-family/c-attribs.c:2551 c-family/c-attribs.c:2608
-#: c-family/c-attribs.c:2635 c-family/c-attribs.c:2690
-#: c-family/c-attribs.c:2870 c-family/c-attribs.c:2891
-#: c-family/c-attribs.c:3004 c-family/c-attribs.c:3031
-#: c-family/c-attribs.c:3221 c-family/c-attribs.c:3239
-#: c-family/c-attribs.c:3262 c-family/c-attribs.c:3301
-#: c-family/c-attribs.c:3383 c-family/c-attribs.c:3439
-#: c-family/c-attribs.c:3455 c-family/c-attribs.c:3549
-#: c-family/c-common.c:5600 config/darwin.c:2072 config/arm/arm.c:6868
+#: c-family/c-attribs.c:547 c-family/c-attribs.c:566 c-family/c-attribs.c:584
+#: c-family/c-attribs.c:614 c-family/c-attribs.c:635 c-family/c-attribs.c:656
+#: c-family/c-attribs.c:697 c-family/c-attribs.c:728 c-family/c-attribs.c:744
+#: c-family/c-attribs.c:761 c-family/c-attribs.c:777 c-family/c-attribs.c:803
+#: c-family/c-attribs.c:818 c-family/c-attribs.c:846 c-family/c-attribs.c:863
+#: c-family/c-attribs.c:881 c-family/c-attribs.c:904 c-family/c-attribs.c:942
+#: c-family/c-attribs.c:965 c-family/c-attribs.c:982 c-family/c-attribs.c:1011
+#: c-family/c-attribs.c:1032 c-family/c-attribs.c:1053
+#: c-family/c-attribs.c:1080 c-family/c-attribs.c:1110
+#: c-family/c-attribs.c:1147 c-family/c-attribs.c:1200
+#: c-family/c-attribs.c:1266 c-family/c-attribs.c:1324
+#: c-family/c-attribs.c:1413 c-family/c-attribs.c:1443
+#: c-family/c-attribs.c:1494 c-family/c-attribs.c:2009
+#: c-family/c-attribs.c:2046 c-family/c-attribs.c:2107
+#: c-family/c-attribs.c:2163 c-family/c-attribs.c:2241
+#: c-family/c-attribs.c:2323 c-family/c-attribs.c:2382
+#: c-family/c-attribs.c:2401 c-family/c-attribs.c:2509
+#: c-family/c-attribs.c:2525 c-family/c-attribs.c:2541
+#: c-family/c-attribs.c:2562 c-family/c-attribs.c:2619
+#: c-family/c-attribs.c:2646 c-family/c-attribs.c:2701
+#: c-family/c-attribs.c:2881 c-family/c-attribs.c:2902
+#: c-family/c-attribs.c:3015 c-family/c-attribs.c:3042
+#: c-family/c-attribs.c:3232 c-family/c-attribs.c:3250
+#: c-family/c-attribs.c:3273 c-family/c-attribs.c:3312
+#: c-family/c-attribs.c:3394 c-family/c-attribs.c:3450
+#: c-family/c-attribs.c:3466 c-family/c-attribs.c:3560
+#: c-family/c-common.c:5598 config/darwin.c:2072 config/arm/arm.c:6868
 #: config/arm/arm.c:6896 config/arm/arm.c:6913 config/avr/avr.c:9698
-#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6497
-#: config/i386/i386.c:41520 config/ia64/ia64.c:788
-#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33056
-#: config/spu/spu.c:3743 ada/gcc-interface/utils.c:6244
-#: ada/gcc-interface/utils.c:6261 ada/gcc-interface/utils.c:6277
-#: ada/gcc-interface/utils.c:6303 brig/brig-lang.c:476 lto/lto-lang.c:283
+#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6500
+#: config/i386/i386.c:41514 config/ia64/ia64.c:788
+#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33112
+#: config/spu/spu.c:3743 ada/gcc-interface/utils.c:6249
+#: ada/gcc-interface/utils.c:6266 ada/gcc-interface/utils.c:6282
+#: ada/gcc-interface/utils.c:6308 brig/brig-lang.c:476 lto/lto-lang.c:283
 #, gcc-internal-format
 msgid "%qE attribute ignored"
 msgstr "%qE 屬性被忽略"
@@ -19943,91 +19944,106 @@
 msgid "%Kattempt to free a non-heap object"
 msgstr "%Kattempt 以釋放 non-heap 物件"
 
-#: calls.c:1434
+#: calls.c:1291 file-prefix-map.c:50
 #, fuzzy, gcc-internal-format
+msgid "invalid argument %qs to %qs"
+msgstr "有效引數到 %qs 是：%s"
+
+#: calls.c:1452
+#, fuzzy, gcc-internal-format
 msgid "%Kargument %i value %qE is negative"
 msgstr "引數的 %s 函式於 %L 是負"
 
-#: calls.c:1452
+#: calls.c:1470
 #, fuzzy, gcc-internal-format
 #| msgid "Second argument MOD at %L is zero"
 msgid "%Kargument %i value is zero"
 msgstr "%L 處 MOD 的第二個參數為 0"
 
-#: calls.c:1469
+#: calls.c:1487
 #, gcc-internal-format
 msgid "%Kargument %i value %qE exceeds maximum object size %E"
 msgstr ""
 
-#: calls.c:1483
+#: calls.c:1501
 #, fuzzy, gcc-internal-format
 msgid "%Kargument %i range [%E, %E] is negative"
 msgstr "引數的 %s 函式於 %L 是負"
 
-#: calls.c:1490
+#: calls.c:1508
 #, gcc-internal-format
 msgid "%Kargument %i range [%E, %E] exceeds maximum object size %E"
 msgstr ""
 
-#: calls.c:1520
+#: calls.c:1538
 #, gcc-internal-format
 msgid "%Kproduct %<%E * %E%> of arguments %i and %i exceeds %<SIZE_MAX%>"
 msgstr ""
 
-#: calls.c:1526
+#: calls.c:1544
 #, gcc-internal-format
 msgid "%Kproduct %<%E * %E%> of arguments %i and %i exceeds maximum object size %E"
 msgstr ""
 
-#: calls.c:1537 calls.c:1540
+#: calls.c:1555 calls.c:1558
 #, fuzzy, gcc-internal-format
 msgid "argument %i in the range [%E, %E]"
 msgstr "引數 %d 的 %qE 必須是在中範圍 %d...%d"
 
-#: calls.c:1551
+#: calls.c:1569
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "in a call to built-in allocation function %qD"
 msgstr "呼叫非函式的 %qD"
 
-#: calls.c:1554
+#: calls.c:1572
 #, fuzzy, gcc-internal-format
 msgid "in a call to allocation function %qD declared here"
 msgstr "內聯函式 %q+D 宣告的 weak"
 
-#: calls.c:1711
+#: calls.c:1835
 #, gcc-internal-format
-msgid "%qD argument %i declared attribute %<nonstring%> is smaller than the specified bound %E"
+msgid "%qD argument %i declared attribute %<nonstring%> is smaller than the specified bound %wu"
 msgstr ""
 
-#: calls.c:1716
+#: calls.c:1841
+#, gcc-internal-format
+msgid "%qD argument %i declared attribute %<nonstring%> is smaller than the specified bound [%E, %E]"
+msgstr ""
+
+#: calls.c:1847
+#, gcc-internal-format
+msgid "%qD argument %i declared attribute %<nonstring%> may be smaller than the specified bound [%E, %E]"
+msgstr ""
+
+#: calls.c:1857
 #, fuzzy, gcc-internal-format
 msgid "%qD argument %i declared attribute %<nonstring%>"
 msgstr "%qD 未被宣告 %<constexpr%>"
 
-#: calls.c:1721
+#: calls.c:1862
 #, fuzzy, gcc-internal-format
 msgid "argument %qD declared here"
 msgstr "%qD 宣告的在此"
 
-#: calls.c:1735
+#: calls.c:1876
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "[cannot find %s]"
 msgid "cannot tail-call: %s"
 msgstr "[找不到 %s]"
 
-#: calls.c:3365
+#: calls.c:3506
 #, gcc-internal-format
 msgid "function call has aggregate value"
 msgstr "函式呼叫有聚合類型"
 
-#: calls.c:4059
+#: calls.c:4200
 #, fuzzy, gcc-internal-format
 #| msgid "passing %qT for argument %P to %qD"
 msgid "passing too large argument on stack"
 msgstr "將 %qT 做為引數 %P 傳遞給 %qD"
 
-#: cfgexpand.c:1665 function.c:1002 varasm.c:2231
+#: cfgexpand.c:1665 function.c:1002 varasm.c:2242
 #, gcc-internal-format
 msgid "size of variable %q+D is too large"
 msgstr "變數 %q+D 的大小太大"
@@ -20606,240 +20622,240 @@
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr "bb 記事數量在中 insn 鏈接 (%d) !=n_basic_blocks (%d)"
 
-#: cgraph.c:3051
+#: cgraph.c:3056
 #, fuzzy, gcc-internal-format
 #| msgid "caller edge count is negative"
 msgid "caller edge count invalid"
 msgstr "呼叫邊計數為負"
 
-#: cgraph.c:3135
+#: cgraph.c:3140
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr "為邊 %s->%s 設定 AUX 欄位"
 
-#: cgraph.c:3142
+#: cgraph.c:3147
 #, gcc-internal-format
 msgid "cgraph count invalid"
 msgstr ""
 
-#: cgraph.c:3147
+#: cgraph.c:3152
 #, fuzzy, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr "節點是單獨在中 comdat 群組"
 
-#: cgraph.c:3152
+#: cgraph.c:3157
 #, fuzzy, gcc-internal-format
 #| msgid "Assume symbols might be invalid"
 msgid "local symbols must be defined"
 msgstr "假定符號可能無效"
 
-#: cgraph.c:3157
+#: cgraph.c:3162
 #, fuzzy, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr "外部可見的內聯仿本"
 
-#: cgraph.c:3162
+#: cgraph.c:3167
 #, fuzzy, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr "內聯仿本與位址佔用"
 
-#: cgraph.c:3167
+#: cgraph.c:3172
 #, fuzzy, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr "內聯仿本被所需的"
 
-#: cgraph.c:3174
+#: cgraph.c:3179
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "aux field set for indirect edge from %s"
 msgstr "aux 欄位設定用於間接邊緣從 %s"
 
-#: cgraph.c:3181
+#: cgraph.c:3186
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr "間接邊緣從 %s 未被標記為間接或已關聯的 indirectinfo(_I)，相應敘述是："
 
-#: cgraph.c:3196
+#: cgraph.c:3201
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr ""
 
-#: cgraph.c:3206
+#: cgraph.c:3211
 #, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr "inlined_to pointer 錯誤"
 
-#: cgraph.c:3211
+#: cgraph.c:3216
 #, gcc-internal-format
 msgid "multiple inline callers"
 msgstr "多個內聯呼叫者"
 
-#: cgraph.c:3218
+#: cgraph.c:3223
 #, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr "為非內聯的呼叫者設定了 inlined_to pointer"
 
-#: cgraph.c:3239
+#: cgraph.c:3244
 #, fuzzy, gcc-internal-format
 msgid "caller edge count does not match BB count"
 msgstr "呼叫者邊緣頻率 %i 不匹配 BB 頻率 %i"
 
-#: cgraph.c:3261
+#: cgraph.c:3266
 #, fuzzy, gcc-internal-format
 msgid "indirect call count does not match BB count"
 msgstr "收到的郵件邊緣計數不匹配 PHI 引數數量"
 
-#: cgraph.c:3272
+#: cgraph.c:3277
 #, fuzzy, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr "inlinedto 指標是設定並不是找到任何 predecessors(_T)"
 
-#: cgraph.c:3277
+#: cgraph.c:3282
 #, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr "inlined_to pointer 參照自身"
 
-#: cgraph.c:3289
+#: cgraph.c:3294
 #, fuzzy, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr "節點有錯誤的 cloneof(_O)"
 
-#: cgraph.c:3301
+#: cgraph.c:3306
 #, fuzzy, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr "節點有錯誤的仿本清單"
 
-#: cgraph.c:3307
+#: cgraph.c:3312
 #, fuzzy, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr "節點是在中仿本清單但是它不是仿本"
 
-#: cgraph.c:3312
+#: cgraph.c:3317
 #, fuzzy, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr "節點有錯誤的 prevclone 指標(_C)"
 
-#: cgraph.c:3317
+#: cgraph.c:3322
 #, fuzzy, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr "雙倍鏈結的仿本清單的已損壞"
 
-#: cgraph.c:3329
+#: cgraph.c:3334
 #, fuzzy, gcc-internal-format
 msgid "Alias has call edges"
 msgstr "別名有呼叫邊緣"
 
-#: cgraph.c:3337
+#: cgraph.c:3342
 #, fuzzy, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr "別名有 non-alias 參考"
 
-#: cgraph.c:3342
+#: cgraph.c:3347
 #, fuzzy, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr "別名有超過一個別名參考"
 
-#: cgraph.c:3349
+#: cgraph.c:3354
 #, fuzzy, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr "分析的別名沒有任何參考"
 
-#: cgraph.c:3358
+#: cgraph.c:3363
 #, gcc-internal-format
 msgid "Instrumentation clone does not reference original node"
 msgstr ""
 
-#: cgraph.c:3365
+#: cgraph.c:3370
 #, fuzzy, gcc-internal-format
 msgid "Not instrumented node has non-NULL original declaration"
 msgstr "對齊的 %qD 是大於原來的宣告"
 
-#: cgraph.c:3375
+#: cgraph.c:3380
 #, fuzzy, gcc-internal-format
 msgid "Instrumented node has wrong original declaration"
 msgstr "對齊的 %qD 是大於原來的宣告"
 
-#: cgraph.c:3393
+#: cgraph.c:3398
 #, fuzzy, gcc-internal-format
 msgid "Node has more than one chkp reference"
 msgstr "別名有超過一個別名參考"
 
-#: cgraph.c:3398
+#: cgraph.c:3403
 #, fuzzy, gcc-internal-format
 msgid "Wrong node is referenced with chkp reference"
 msgstr "表單參考到參考類型 %qT"
 
-#: cgraph.c:3406
+#: cgraph.c:3411
 #, fuzzy, gcc-internal-format
 msgid "Analyzed node has no reference to instrumented version"
 msgstr "分析的別名沒有任何參考"
 
-#: cgraph.c:3420
+#: cgraph.c:3425
 #, gcc-internal-format
 msgid "Alias chain for instrumented node is broken"
 msgstr ""
 
-#: cgraph.c:3429
+#: cgraph.c:3434
 #, fuzzy, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr "沒有邊緣超出 thunk 節點"
 
-#: cgraph.c:3434
+#: cgraph.c:3439
 #, fuzzy, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr "超過一個邊緣超出 thunk 節點"
 
-#: cgraph.c:3439
+#: cgraph.c:3444
 #, fuzzy, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr "Thunk 未被猜想到有內文"
 
-#: cgraph.c:3445
+#: cgraph.c:3450
 #, gcc-internal-format
 msgid "Instrumentation thunk has wrong edge callee"
 msgstr ""
 
-#: cgraph.c:3481
+#: cgraph.c:3486
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr "共享的 call_stmt："
 
-#: cgraph.c:3489
+#: cgraph.c:3494
 #, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr "邊緣指到不對的宣告："
 
-#: cgraph.c:3498
+#: cgraph.c:3503
 #, fuzzy, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr "間接邊緣與不明被呼叫端相應到 callstmt 與已知宣告(_S)："
 
-#: cgraph.c:3508
+#: cgraph.c:3513
 #, fuzzy, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr "缺少callgraph 邊緣用於呼叫 stmt："
 
-#: cgraph.c:3518
+#: cgraph.c:3523
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "reference to dead statement"
 msgstr "需要敘述"
 
-#: cgraph.c:3531
+#: cgraph.c:3536
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr "邊緣 %s->%s 沒有任何相應 callstmt(_S)"
 
-#: cgraph.c:3543
+#: cgraph.c:3548
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr "間接邊緣從 %s 沒有任何相應 callstmt(_S)"
 
-#: cgraph.c:3554
+#: cgraph.c:3559
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr "verify_cgraph_node 失敗"
 
-#: cgraph.c:3661 varpool.c:306
+#: cgraph.c:3666 varpool.c:306
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s: section %s is missing"
 msgstr "%s：區段 %s 缺少"
@@ -20870,12 +20886,12 @@
 msgstr "%<weakref%> 屬性忽略的因為變數被初始化的"
 
 #. include_self=
-#: cgraphunit.c:981 c/c-decl.c:11282
+#: cgraphunit.c:981 c/c-decl.c:11302
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F 使用過但從未定義"
 
-#: cgraphunit.c:983 c/c-decl.c:11291
+#: cgraphunit.c:983 c/c-decl.c:11311
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "%q+F 宣告為 %<static%> 卻從未定義過"
@@ -20995,12 +21011,12 @@
 msgid "cannot find '%s'"
 msgstr "找不到「%s」"
 
-#: collect-utils.c:183 collect2.c:2361 collect2.c:2560 gcc.c:3080 gcc.c:6856
+#: collect-utils.c:183 collect2.c:2387 collect2.c:2586 gcc.c:3080 gcc.c:6856
 #, fuzzy, gcc-internal-format
 msgid "pex_init failed: %m"
 msgstr "pexinit 失敗(_I)：%m"
 
-#: collect-utils.c:192 collect2.c:2370 collect2.c:2568 gcc.c:8498
+#: collect-utils.c:192 collect2.c:2396 collect2.c:2594 gcc.c:8498
 #, fuzzy, gcc-internal-format
 msgid "%s: %m"
 msgstr "%s：%m"
@@ -21010,93 +21026,93 @@
 msgid "COLLECT_LTO_WRAPPER must be set"
 msgstr "COLLECT_LTO_WRAPPER 必須是設定"
 
-#: collect2.c:966 gcc.c:7382 lto-wrapper.c:1666
+#: collect2.c:969 gcc.c:7382 lto-wrapper.c:1692
 #: config/i386/intelmic-mkoffload.c:556 config/nvptx/mkoffload.c:405
 #, fuzzy, gcc-internal-format
 msgid "atexit failed"
 msgstr "atexit 失敗"
 
-#: collect2.c:1064
+#: collect2.c:1067
 #, gcc-internal-format
 msgid "no arguments"
 msgstr "沒有參數"
 
-#: collect2.c:1303 opts.c:904
+#: collect2.c:1311 opts.c:904
 #, fuzzy, gcc-internal-format
 msgid "LTO support has not been enabled in this configuration"
 msgstr "LTO 支援未被已啟用在中這個組態"
 
-#: collect2.c:1344
+#: collect2.c:1352
 #, gcc-internal-format
 msgid "can't open %s: %m"
 msgstr "無法開啟 %s：%m"
 
-#: collect2.c:1450
+#: collect2.c:1472
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown demangling style '%s'"
 msgstr "不明的解修飾風格「%s」"
 
-#: collect2.c:1546 collect2.c:1729 collect2.c:1769
+#: collect2.c:1574 collect2.c:1757 collect2.c:1797
 #, fuzzy, gcc-internal-format
 msgid "fopen %s: %m"
 msgstr "fopen %s：%m"
 
-#: collect2.c:1549 collect2.c:1734 collect2.c:1772
+#: collect2.c:1577 collect2.c:1762 collect2.c:1800
 #, fuzzy, gcc-internal-format
 msgid "fclose %s: %m"
 msgstr "fclose %s：%m"
 
-#: collect2.c:2335
+#: collect2.c:2361
 #, gcc-internal-format
 msgid "cannot find 'nm'"
 msgstr "找不到 「nm」"
 
-#: collect2.c:2383
+#: collect2.c:2409
 #, fuzzy, gcc-internal-format
 msgid "can't open nm output: %m"
 msgstr "無法開啟 nm 輸出：%m"
 
-#: collect2.c:2467
+#: collect2.c:2493
 #, gcc-internal-format, gfc-internal-format
 msgid "init function found in object %s"
 msgstr "在物件 %s 中發現 init 函式"
 
-#: collect2.c:2478
+#: collect2.c:2504
 #, gcc-internal-format, gfc-internal-format
 msgid "fini function found in object %s"
 msgstr "在物件 %s 中發現 fini 函式"
 
-#: collect2.c:2535
+#: collect2.c:2561
 #, gcc-internal-format
 msgid "cannot find 'ldd'"
 msgstr "找不到「ldd」"
 
-#: collect2.c:2581
+#: collect2.c:2607
 #, fuzzy, gcc-internal-format
 msgid "can't open ldd output: %m"
 msgstr "無法開啟 ldd 輸出：%m"
 
-#: collect2.c:2599
+#: collect2.c:2625
 #, gcc-internal-format, gfc-internal-format
 msgid "dynamic dependency %s not found"
 msgstr "找不到動態依賴項 %s"
 
-#: collect2.c:2611
+#: collect2.c:2637
 #, gcc-internal-format, gfc-internal-format
 msgid "unable to open dynamic dependency '%s'"
 msgstr "無法開啟動態依賴項「%s」"
 
-#: collect2.c:2765
+#: collect2.c:2791
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: not a COFF file"
 msgstr "%s：不是一個 COFF 檔案"
 
-#: collect2.c:2930
+#: collect2.c:2961
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: cannot open as COFF file"
 msgstr "%s：無法開啟 COFF 檔案"
 
-#: collect2.c:2989
+#: collect2.c:3020
 #, gcc-internal-format, gfc-internal-format
 msgid "library lib%s not found"
 msgstr "找不到函式庫 lib%s"
@@ -21306,12 +21322,12 @@
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr "多重 EH 身分被支援只有與組譯器支援.cfipersonality 指令(_P)"
 
-#: dwarf2out.c:10901
+#: dwarf2out.c:10909
 #, gcc-internal-format
 msgid "-gdwarf-6 is output as version 5 with incompatibilities"
 msgstr ""
 
-#: dwarf2out.c:14415
+#: dwarf2out.c:14423
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr "non-delegitimized UNSPEC %s (%d) 找到在中變數位置"
@@ -21431,11 +21447,6 @@
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr "%Kcall 到 %qs 宣告的與屬性警告：%s"
 
-#: file-prefix-map.c:50
-#, fuzzy, gcc-internal-format
-msgid "invalid argument %qs to %qs"
-msgstr "有效引數到 %qs 是：%s"
-
 #: final.c:1868
 #, fuzzy, gcc-internal-format
 msgid "the frame size of %wd bytes is larger than %wd bytes"
@@ -21456,42 +21467,42 @@
 msgid "large fixed-point constant implicitly truncated to fixed-point type"
 msgstr "大定點常數隱含地截短至定點型態"
 
-#: fold-const.c:4151 fold-const.c:4161
+#: fold-const.c:4157 fold-const.c:4167
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d due to width of bit-field"
 msgstr "由於位元段寬度所限，比較結果永遠為 %d"
 
-#: fold-const.c:5478 tree-ssa-reassoc.c:2374 tree-ssa-reassoc.c:3214
+#: fold-const.c:5484 tree-ssa-reassoc.c:2379 tree-ssa-reassoc.c:3219
 #, fuzzy, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr "假設帶正負號溢位不發生時簡化範圍測試"
 
-#: fold-const.c:5928 fold-const.c:5942
+#: fold-const.c:5934 fold-const.c:5948
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr "比較結果始終為 %d"
 
-#: fold-const.c:6085
+#: fold-const.c:6091
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr "對兩個不匹配的不等比較取 %<or%> 的結果總為 1"
 
-#: fold-const.c:6090
+#: fold-const.c:6096
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr "對兩個互斥的相等比較取 %<and%> 的結果永遠是 0"
 
-#: fold-const.c:8310
+#: fold-const.c:8316
 #, fuzzy, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr "假設帶正負號溢位不發生時縮小常數在中比較"
 
-#: fold-const.c:8710
+#: fold-const.c:8716
 #, fuzzy, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr "假設帶正負號溢位不發生時合併常數周圍比較"
 
-#: fold-const.c:12063
+#: fold-const.c:12069
 #, fuzzy, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr "折疊檢查：原來的樹變更的由折疊"
@@ -21501,7 +21512,7 @@
 msgid "total size of local objects too large"
 msgstr "總計大小的區域物件太大"
 
-#: function.c:1776 gimplify.c:6270
+#: function.c:1776 gimplify.c:6273
 #, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr "%<asm%> 中不可能的約束"
@@ -21809,7 +21820,7 @@
 msgid "%s: linker input file unused because linking not done"
 msgstr "%s：未使用連結器輸入檔案，因為連結尚未完成"
 
-#: gcc.c:8420 c-family/c-opts.c:770
+#: gcc.c:8420 c-family/c-opts.c:768
 #, gcc-internal-format
 msgid "cannot use %<-%> as input filename for a precompiled header"
 msgstr ""
@@ -22048,7 +22059,7 @@
 msgid "%G%qD destination unchanged after copying no bytes"
 msgstr ""
 
-#: gimple-fold.c:2052 tree-ssa-strlen.c:2050
+#: gimple-fold.c:2052 tree-ssa-strlen.c:2074
 msgid "%G%qD specified bound %E equals destination size"
 msgstr ""
 
@@ -22070,12 +22081,12 @@
 msgid "null pointer dereference"
 msgstr "空指標"
 
-#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12451
-#: tree.c:12488 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10147
-#: c/c-typeck.c:10164 c/gimple-parser.c:1616 c/gimple-parser.c:1624
+#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12455
+#: tree.c:12492 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10152
+#: c/c-typeck.c:10169 c/gimple-parser.c:1616 c/gimple-parser.c:1624
 #: cp/call.c:6493 cp/call.c:8098 cp/constexpr.c:820 cp/constexpr.c:2309
-#: cp/cvt.c:1015 cp/cvt.c:1042 cp/decl.c:7334 cp/decl2.c:5256 cp/pt.c:8334
-#: cp/semantics.c:1836 cp/semantics.c:4053 cp/typeck.c:1700 cp/typeck.c:1895
+#: cp/cvt.c:1015 cp/cvt.c:1042 cp/decl.c:7355 cp/decl2.c:5246 cp/pt.c:8348
+#: cp/semantics.c:1836 cp/semantics.c:4056 cp/typeck.c:1700 cp/typeck.c:1895
 #: cp/typeck.c:3837
 #, fuzzy, gcc-internal-format
 msgid "declared here"
@@ -22086,294 +22097,294 @@
 msgid "nonnull argument %qD compared to NULL"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2517 gimple-ssa-sprintf.c:2637
+#: gimple-ssa-sprintf.c:2555 gimple-ssa-sprintf.c:2675
 #, gcc-internal-format
 msgid "%qE output may be truncated before the last format character"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2519 gimple-ssa-sprintf.c:2639
+#: gimple-ssa-sprintf.c:2557 gimple-ssa-sprintf.c:2677
 #, gcc-internal-format
 msgid "%qE output truncated before the last format character"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2522 gimple-ssa-sprintf.c:2642
+#: gimple-ssa-sprintf.c:2560 gimple-ssa-sprintf.c:2680
 #, gcc-internal-format
 msgid "%qE may write a terminating nul past the end of the destination"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2524 gimple-ssa-sprintf.c:2644
+#: gimple-ssa-sprintf.c:2562 gimple-ssa-sprintf.c:2682
 #, gcc-internal-format
 msgid "%qE writing a terminating nul past the end of the destination"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2534
+#: gimple-ssa-sprintf.c:2572
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size %wu"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.c:2541
+#: gimple-ssa-sprintf.c:2579
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size %wu"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.c:2548
+#: gimple-ssa-sprintf.c:2586
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size %wu"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.c:2559
+#: gimple-ssa-sprintf.c:2597
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2562
+#: gimple-ssa-sprintf.c:2600
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2564
+#: gimple-ssa-sprintf.c:2602
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2576
+#: gimple-ssa-sprintf.c:2614
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2579
+#: gimple-ssa-sprintf.c:2617
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2582
+#: gimple-ssa-sprintf.c:2620
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2591
+#: gimple-ssa-sprintf.c:2629
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2594
+#: gimple-ssa-sprintf.c:2632
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2597
+#: gimple-ssa-sprintf.c:2635
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2606
+#: gimple-ssa-sprintf.c:2644
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2609
+#: gimple-ssa-sprintf.c:2647
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2611
+#: gimple-ssa-sprintf.c:2649
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2653
+#: gimple-ssa-sprintf.c:2691
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size between %wu and %wu"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.c:2660
+#: gimple-ssa-sprintf.c:2698
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size between %wu and %wu"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.c:2668
+#: gimple-ssa-sprintf.c:2706
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size between %wu and %wu"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.c:2680
+#: gimple-ssa-sprintf.c:2718
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2683
+#: gimple-ssa-sprintf.c:2721
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2686
+#: gimple-ssa-sprintf.c:2724
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2699
+#: gimple-ssa-sprintf.c:2737
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2702
+#: gimple-ssa-sprintf.c:2740
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2705
+#: gimple-ssa-sprintf.c:2743
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2715
+#: gimple-ssa-sprintf.c:2753
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2718
+#: gimple-ssa-sprintf.c:2756
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2721
+#: gimple-ssa-sprintf.c:2759
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2730
+#: gimple-ssa-sprintf.c:2768
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2733
+#: gimple-ssa-sprintf.c:2771
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2736
+#: gimple-ssa-sprintf.c:2774
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2825
+#: gimple-ssa-sprintf.c:2863
 #, gcc-internal-format
 msgid "%<%.*s%> directive argument is null"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2890
+#: gimple-ssa-sprintf.c:2928
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes exceeds minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2897
+#: gimple-ssa-sprintf.c:2935
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may exceed minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2900
+#: gimple-ssa-sprintf.c:2938
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes exceeds minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2929
+#: gimple-ssa-sprintf.c:2967
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2936
+#: gimple-ssa-sprintf.c:2974
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2939
+#: gimple-ssa-sprintf.c:2977
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may cause result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2949
+#: gimple-ssa-sprintf.c:2987
 #, gcc-internal-format
 msgid "assuming directive output of %wu byte"
 msgid_plural "assuming directive output of %wu bytes"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.c:2956
+#: gimple-ssa-sprintf.c:2994
 #, fuzzy, gcc-internal-format
 msgid "directive argument %qE"
 msgstr "延伸：負引數 N 於 %L"
 
-#: gimple-ssa-sprintf.c:2958
+#: gimple-ssa-sprintf.c:2996
 #, fuzzy, gcc-internal-format
 msgid "directive argument in the range [%E, %E]"
 msgstr "停用回合 %s 用於函式在中範圍的 [%u，%u]"
 
-#: gimple-ssa-sprintf.c:2962
+#: gimple-ssa-sprintf.c:3000
 #, gcc-internal-format
 msgid "using the range [%E, %E] for directive argument"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2982
+#: gimple-ssa-sprintf.c:3020
 #, gcc-internal-format
 msgid "%qE output %wu byte into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2983
+#: gimple-ssa-sprintf.c:3021
 #, gcc-internal-format
 msgid "%qE output %wu bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2987
+#: gimple-ssa-sprintf.c:3025
 #, gcc-internal-format
 msgid "%qE output between %wu and %wu bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2992
+#: gimple-ssa-sprintf.c:3030
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes (assuming %wu) into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2997
+#: gimple-ssa-sprintf.c:3035
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3368
+#: gimple-ssa-sprintf.c:3406
 #, gcc-internal-format
 msgid "%<%.*s%> directive width out of range"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3402
+#: gimple-ssa-sprintf.c:3440
 #, gcc-internal-format
 msgid "%<%.*s%> directive precision out of range"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3893
+#: gimple-ssa-sprintf.c:3931
 #, gcc-internal-format
 msgid "specified bound %wu exceeds maximum object size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3899
+#: gimple-ssa-sprintf.c:3937
 #, gcc-internal-format
 msgid "specified bound %wu exceeds %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3949
+#: gimple-ssa-sprintf.c:3987
 #, fuzzy, gcc-internal-format
 msgid "null destination pointer"
 msgstr "空指標"
 
-#: gimple-ssa-sprintf.c:3966
+#: gimple-ssa-sprintf.c:4004
 #, gcc-internal-format
 msgid "specified bound %wu exceeds the size %wu of the destination object"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3978
+#: gimple-ssa-sprintf.c:4016
 #, fuzzy, gcc-internal-format
 msgid "null format string"
 msgstr "%s 在中格式字串於 %L"
@@ -22576,10 +22587,10 @@
 msgstr ""
 
 #: gimple-ssa-warn-restrict.c:1678 c/c-decl.c:3603 c/c-decl.c:3874
-#: c/c-typeck.c:8345 cp/class.c:1346 cp/class.c:3098 cp/decl.c:3979
-#: cp/decl.c:10753 cp/decl.c:11151 cp/decl.c:11160 cp/friend.c:384
+#: c/c-typeck.c:8350 cp/class.c:1346 cp/class.c:3102 cp/decl.c:3979
+#: cp/decl.c:10777 cp/decl.c:11175 cp/decl.c:11184 cp/friend.c:384
 #: cp/friend.c:393 cp/parser.c:3275 cp/parser.c:3372 cp/parser.c:3422
-#: cp/parser.c:6327 cp/parser.c:21027
+#: cp/parser.c:6330 cp/parser.c:21024
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD 宣告的在此"
@@ -22652,219 +22663,219 @@
 msgid "using result of function returning %<void%>"
 msgstr "使用結果的函式回傳 %<void%>"
 
-#: gimplify.c:6128
+#: gimplify.c:6131
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid lvalue in asm output %d"
 msgstr "組譯輸出 %d 中左值無效"
 
-#: gimplify.c:6271
+#: gimplify.c:6274
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr "non-memory 輸入 %d 必須保持在中記憶體"
 
-#: gimplify.c:6311 gimplify.c:6320
+#: gimplify.c:6314 gimplify.c:6323
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr "記憶體輸入 %d 不可直接定址"
 
-#: gimplify.c:6928
+#: gimplify.c:6931
 #, fuzzy, gcc-internal-format
 msgid "threadprivate variable %qE used in target region"
 msgstr "threadprivate 變數 %qE 已用於 untied 任務"
 
-#: gimplify.c:6930
+#: gimplify.c:6933
 #, fuzzy, gcc-internal-format
 msgid "enclosing target region"
 msgstr "封閉任務"
 
-#: gimplify.c:6942
+#: gimplify.c:6945
 #, fuzzy, gcc-internal-format
 msgid "threadprivate variable %qE used in untied task"
 msgstr "threadprivate 變數 %qE 已用於 untied 任務"
 
-#: gimplify.c:6944
+#: gimplify.c:6947
 #, fuzzy, gcc-internal-format
 msgid "enclosing task"
 msgstr "封閉任務"
 
-#: gimplify.c:7016
+#: gimplify.c:7019
 #, fuzzy, gcc-internal-format
 msgid "%qE not specified in enclosing %qs"
 msgstr "%qE 尚未指定在中封閉平行"
 
-#: gimplify.c:7018
+#: gimplify.c:7021
 #, fuzzy, gcc-internal-format
 msgid "enclosing %qs"
 msgstr "封閉任務"
 
-#: gimplify.c:7143
+#: gimplify.c:7146
 #, fuzzy, gcc-internal-format
 msgid "%qE not specified in enclosing OpenACC %qs construct"
 msgstr "%qE 尚未指定在中封閉平行"
 
-#: gimplify.c:7145
+#: gimplify.c:7148
 #, gcc-internal-format
 msgid "enclosing OpenACC %qs construct"
 msgstr ""
 
-#: gimplify.c:7198
+#: gimplify.c:7201
 #, gcc-internal-format
 msgid "%qE with %<link%> clause used in %<routine%> function"
 msgstr ""
 
-#: gimplify.c:7206
+#: gimplify.c:7209
 #, fuzzy, gcc-internal-format
 msgid "%qE requires a %<declare%> directive for use in a %<routine%> function"
 msgstr "%qE undeclared (先使用在中這個函式)"
 
-#: gimplify.c:7272 gimplify.c:7872
+#: gimplify.c:7275 gimplify.c:7875
 #, fuzzy, gcc-internal-format
 #| msgid "variable %q+D declared %<inline%>"
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr "變數 %q+D 宣告為 %<inline%>"
 
-#: gimplify.c:7293
+#: gimplify.c:7296
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr ""
 
-#: gimplify.c:7411 gimplify.c:7443
+#: gimplify.c:7414 gimplify.c:7446
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE is predetermined linear"
 msgstr "迭代變數 %qE 不應為消除"
 
-#: gimplify.c:7414
+#: gimplify.c:7417
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should be private"
 msgstr "迭代變數 %qE 應該是私人的"
 
-#: gimplify.c:7428
+#: gimplify.c:7431
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be firstprivate"
 msgstr "迭代變數 %qE 不應為 firstprivate"
 
-#: gimplify.c:7431
+#: gimplify.c:7434
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be reduction"
 msgstr "迭代變數 %qE 不應為消除"
 
-#: gimplify.c:7434
+#: gimplify.c:7437
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be linear"
 msgstr "迭代變數 %qE 不應為消除"
 
-#: gimplify.c:7437
+#: gimplify.c:7440
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be lastprivate"
 msgstr "迭代變數 %qE 不應為 firstprivate"
 
-#: gimplify.c:7440
+#: gimplify.c:7443
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be private"
 msgstr "迭代變數 %qE 應該是私人的"
 
-#: gimplify.c:7742
+#: gimplify.c:7745
 #, gcc-internal-format
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr ""
 
-#: gimplify.c:7949
+#: gimplify.c:7952
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr ""
 
-#: gimplify.c:8160
+#: gimplify.c:8163
 #, fuzzy, gcc-internal-format
 msgid "%qE appears more than once in map clauses"
 msgstr "%qE 出現一次以上在中資料子句"
 
-#: gimplify.c:8464
+#: gimplify.c:8467
 #, fuzzy, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr "%s 變數 %qE 是私人的在中外語境"
 
-#: gimplify.c:8484
+#: gimplify.c:8487
 #, fuzzy, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr "%s 變數 %qE 是私人的在中外語境"
 
-#: gimplify.c:8510
+#: gimplify.c:8513
 #, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr ""
 
-#: gimplify.c:8775
+#: gimplify.c:8778
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr ""
 
-#: gimplify.c:8808
+#: gimplify.c:8811
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:9000
+#: gimplify.c:9003
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:9051
+#: gimplify.c:9054
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr ""
 
-#: gimplify.c:9133
+#: gimplify.c:9136
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to present_or_copy"
 msgstr ""
 
-#: gimplify.c:9278
+#: gimplify.c:9281
 #, fuzzy, gcc-internal-format
 #| msgid "invalid template declaration of %qD"
 msgid "invalid private reduction on %qE"
 msgstr "%qD 範本宣告無效"
 
-#: gimplify.c:11103 omp-low.c:2791
+#: gimplify.c:11106 omp-low.c:2791
 #, fuzzy, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr "已排序的區域必須是接近巢狀的內部迴圈區域與已排序的子句"
 
-#: gimplify.c:11121
+#: gimplify.c:11124
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr ""
 
-#: gimplify.c:11134
+#: gimplify.c:11137
 #, fuzzy, gcc-internal-format
 msgid "number of variables in %<depend(sink)%> clause does not match number of iteration variables"
 msgstr "結果數量不匹配值數量"
 
-#: gimplify.c:11147
+#: gimplify.c:11150
 #, gcc-internal-format
 msgid "more than one %<depend(source)%> clause on an %<ordered%> construct"
 msgstr ""
 
-#: gimplify.c:11158
+#: gimplify.c:11161
 #, gcc-internal-format
 msgid "%<depend(source)%> clause specified together with %<depend(sink:)%> clauses on the same construct"
 msgstr ""
 
-#: gimplify.c:12393
+#: gimplify.c:12396
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr "gimplification 失敗"
 
-#: gimplify.c:12936
+#: gimplify.c:12939
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr "透過 %<...%> 傳遞時 %qT 被提升為 %qT"
 
-#: gimplify.c:12941
+#: gimplify.c:12944
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr "(因此您應該向 %<va_arg%> 傳遞 %qT 而不是 %qT)"
 
-#: gimplify.c:12948
+#: gimplify.c:12951
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr "如果執行到這段程式碼，程式將中止"
@@ -23342,47 +23353,47 @@
 msgid "Max. number of generated reload insns per insn is achieved (%d)\n"
 msgstr ""
 
-#: lto-cgraph.c:1294
+#: lto-cgraph.c:1296
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "bytecode stream: found multiple instances of cgraph node with uid %d"
 msgstr "位元碼串流：找到多重實體的 cgraph 節點 %d"
 
-#: lto-cgraph.c:1472
+#: lto-cgraph.c:1474
 #, fuzzy, gcc-internal-format
 msgid "bytecode stream: no caller found while reading edge"
 msgstr "位元碼串流：找不到任何呼叫者當讀取邊緣"
 
-#: lto-cgraph.c:1478
+#: lto-cgraph.c:1480
 #, fuzzy, gcc-internal-format
 msgid "bytecode stream: no callee found while reading edge"
 msgstr "位元碼串流：找不到任何被呼叫端當讀取邊緣"
 
-#: lto-cgraph.c:1552
+#: lto-cgraph.c:1554
 #, fuzzy, gcc-internal-format
 msgid "bytecode stream: found empty cgraph node"
 msgstr "位元碼串流：找到清空 cgraph 節點"
 
-#: lto-cgraph.c:1730
+#: lto-cgraph.c:1732
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "At most %i profile runs is supported. Perhaps corrupted profile?"
 msgstr "最多 %i 側寫檔運行被支援。也許已損壞側寫檔？"
 
-#: lto-cgraph.c:1817
+#: lto-cgraph.c:1819
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Profile information in %s corrupted"
 msgstr "側寫檔資訊在中 %s 已損壞"
 
-#: lto-cgraph.c:1855
+#: lto-cgraph.c:1857
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO cgraph in %s"
 msgstr "找不到 LTO cgraph 在中 %s"
 
-#: lto-cgraph.c:1865
+#: lto-cgraph.c:1867
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO section refs in %s"
 msgstr "找不到 LTO 區段 refs 在中 %s"
 
-#: lto-cgraph.c:1946
+#: lto-cgraph.c:1948
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid rotate insn"
 msgid "invalid offload table in %s"
@@ -23456,86 +23467,91 @@
 msgid "bytecode stream in file %qs generated with LTO version %d.%d instead of the expected %d.%d"
 msgstr "位元碼串流產生的與 LTO 版本 %d.%d 以代替預期 %d.%d"
 
-#: lto-wrapper.c:117
+#: lto-wrapper.c:118
 #, fuzzy, gcc-internal-format
 msgid "deleting LTRANS file %s: %m"
 msgstr "刪除 LTRANS 檔案 %s"
 
-#: lto-wrapper.c:154
+#: lto-wrapper.c:155
 #, fuzzy, gcc-internal-format
 msgid "malformed COLLECT_GCC_OPTIONS"
 msgstr "異常的 COLLECT_GCC_OPTIONS"
 
-#: lto-wrapper.c:308
+#: lto-wrapper.c:309
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "created and used with different endianness"
 msgid "Option %s with different values"
 msgstr "建立和使用時使用了不同的高/低位位元組在前設定"
 
-#: lto-wrapper.c:392
+#: lto-wrapper.c:393
 #, gcc-internal-format, gfc-internal-format
 msgid "Option %s not used consistently in all LTO input files"
 msgstr ""
 
-#: lto-wrapper.c:832
+#: lto-wrapper.c:833
 #, gcc-internal-format, gfc-internal-format
 msgid "problem with building target image for %s\n"
 msgstr ""
 
-#: lto-wrapper.c:852
+#: lto-wrapper.c:853
 #, fuzzy, gcc-internal-format
 #| msgid "no input files"
 msgid "reading input file"
 msgstr "沒有輸入檔案"
 
-#: lto-wrapper.c:857
+#: lto-wrapper.c:858
 #, fuzzy, gcc-internal-format
 msgid "writing output file"
 msgstr "寫入輸出檔案『%s 時發生錯誤』\n"
 
-#: lto-wrapper.c:889
+#: lto-wrapper.c:890
 #, gcc-internal-format
 msgid "installation error, can't find crtoffloadtable.o"
 msgstr ""
 
-#: lto-wrapper.c:1000 lto-wrapper.c:1012
+#: lto-wrapper.c:1001 lto-wrapper.c:1013
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s: %s"
 msgid "%s: %s\n"
 msgstr "%s：%s"
 
-#: lto-wrapper.c:1056
+#: lto-wrapper.c:1064
 #, fuzzy, gcc-internal-format
 msgid "environment variable COLLECT_GCC must be set"
 msgstr "環境變數 COLLECT_GCC 必須是設定"
 
-#: lto-wrapper.c:1060 config/nvptx/mkoffload.c:363
+#: lto-wrapper.c:1068 config/nvptx/mkoffload.c:363
 #, fuzzy, gcc-internal-format
 msgid "environment variable COLLECT_GCC_OPTIONS must be set"
 msgstr "環境變數 COLLECT_GCC_OPTIONS 必須是設定"
 
-#: lto-wrapper.c:1229 lto-wrapper.c:1285
+#: lto-wrapper.c:1237 lto-wrapper.c:1293
 #, fuzzy, gcc-internal-format
 #| msgid "can't open %s: %m"
 msgid "cannot open %s: %m"
 msgstr "無法開啟 %s：%m"
 
-#: lto-wrapper.c:1232 lto-wrapper.c:1291
+#: lto-wrapper.c:1240 lto-wrapper.c:1299
 #, fuzzy, gcc-internal-format
 #| msgid "can%'t read %s: %m"
 msgid "cannot read %s: %m"
 msgstr "無法讀取 %s：%m"
 
-#: lto-wrapper.c:1259
+#: lto-wrapper.c:1267
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid format of %s"
 msgstr "無效的作業 (%s)"
 
-#: lto-wrapper.c:1482
+#: lto-wrapper.c:1491
 #, fuzzy, gcc-internal-format
 msgid "fopen: %s: %m"
 msgstr "fopen %s：%m"
 
+#: lto-wrapper.c:1508
+#, fuzzy, gcc-internal-format, gfc-internal-format
+msgid "Corrupted ltrans output file %s"
+msgstr "無法開啟輸出檔案『%s』\n"
+
 #: multiple_target.c:76
 #, fuzzy, gcc-internal-format
 msgid "the call requires ifunc, which is not supported by this target"
@@ -23890,12 +23906,12 @@
 msgid "unrecognized argument in option %qs"
 msgstr "無法辨識的引數在中選項 %qs"
 
-#: opts-common.c:1198 config/i386/i386.c:3206
+#: opts-common.c:1198 config/i386/i386.c:3209
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "有效引數到 %qs 是：%s"
 
-#: opts-common.c:1201 config/i386/i386.c:3209
+#: opts-common.c:1201 config/i386/i386.c:3212
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "有效引數到 %qs 是：%s"
@@ -24503,22 +24519,22 @@
 msgid "output operand %d must use %<&%> constraint"
 msgstr "輸出運算元 %d 必須使用 %<&%> 約束"
 
-#: regcprop.c:1187
+#: regcprop.c:1193
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad next_regno for empty chain (%u)"
 msgstr "validate_value_data：[%u] 不當的 next_regno 用於清空鏈接 (%u)"
 
-#: regcprop.c:1199
+#: regcprop.c:1205
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: Loop in regno chain (%u)"
 msgstr "validate_value_data：迴圈在中 regno 鏈接 (%u)"
 
-#: regcprop.c:1202
+#: regcprop.c:1208
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad oldest_regno (%u)"
 msgstr "validate_value_data：[%u] 不當的 oldest_regno (%u)"
 
-#: regcprop.c:1214
+#: regcprop.c:1220
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Non-empty reg in chain (%s %u %i)"
 msgstr "validate_value_data：[%u] 非空 reg 在中鏈接 (%s %u %i)"
@@ -24562,7 +24578,7 @@
 msgstr "暫存器的 %qD 用於多重全域暫存器變數"
 
 #: reginfo.c:789 config/powerpcspe/powerpcspe.c:32259
-#: config/rs6000/rs6000.c:29453
+#: config/rs6000/rs6000.c:29530
 #, fuzzy, gcc-internal-format
 msgid "conflicts with %qD"
 msgstr "衝突與 %qD"
@@ -24807,152 +24823,157 @@
 msgid "function symbol is not function"
 msgstr "函式回傳了一個函式"
 
-#: symtab.c:1006
+#: symtab.c:1005
+#, gcc-internal-format
+msgid "inconsistent `ifunc' attribute"
+msgstr ""
+
+#: symtab.c:1013
 #, fuzzy, gcc-internal-format
 msgid "variable symbol is not variable"
 msgstr "%qE 屬性只有套用到變數"
 
-#: symtab.c:1012
+#: symtab.c:1019
 #, fuzzy, gcc-internal-format
 msgid "node has unknown type"
 msgstr "節點有錯誤的仿本清單"
 
-#: symtab.c:1021
+#: symtab.c:1028
 #, gcc-internal-format
 msgid "node not found node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.c:1029
+#: symtab.c:1036
 #, gcc-internal-format
 msgid "node differs from node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.c:1038
+#: symtab.c:1045
 #, gcc-internal-format
 msgid "assembler name hash list corrupted"
 msgstr ""
 
-#: symtab.c:1051
+#: symtab.c:1058
 #, fuzzy, gcc-internal-format
 msgid "node not found in symtab assembler name hash"
 msgstr "節點找不到在中 cgraphhash(_H)"
 
-#: symtab.c:1058
+#: symtab.c:1065
 #, fuzzy, gcc-internal-format
 msgid "double linked list of assembler names corrupted"
 msgstr "雙倍鏈結的仿本清單的已損壞"
 
-#: symtab.c:1063
+#: symtab.c:1070
 #, fuzzy, gcc-internal-format
 msgid "node has body_removed but is definition"
 msgstr "%qD 使用的之前它的定義"
 
-#: symtab.c:1068
+#: symtab.c:1075
 #, fuzzy, gcc-internal-format
 msgid "node is analyzed but it is not a definition"
 msgstr "節點是在中仿本清單但是它不是仿本"
 
-#: symtab.c:1073
+#: symtab.c:1080
 #, gcc-internal-format
 msgid "node is alias but not implicit alias"
 msgstr ""
 
-#: symtab.c:1078
+#: symtab.c:1085
 #, fuzzy, gcc-internal-format
 msgid "node is alias but not definition"
 msgstr "節點是在中仿本清單但是它不是仿本"
 
-#: symtab.c:1083
+#: symtab.c:1090
 #, gcc-internal-format
 msgid "node is weakref but not an transparent_alias"
 msgstr ""
 
-#: symtab.c:1088
+#: symtab.c:1095
 #, gcc-internal-format
 msgid "node is transparent_alias but not an alias"
 msgstr ""
 
-#: symtab.c:1097
+#: symtab.c:1104
 #, fuzzy, gcc-internal-format
 msgid "node is in same_comdat_group list but has no comdat_group"
 msgstr "節點是在中仿本清單但是它不是仿本"
 
-#: symtab.c:1102
+#: symtab.c:1109
 #, fuzzy, gcc-internal-format
 msgid "same_comdat_group list across different groups"
 msgstr "same_comdat_group 並非環狀清單"
 
-#: symtab.c:1107
+#: symtab.c:1114
 #, gcc-internal-format
 msgid "mixing different types of symbol in same comdat groups is not supported"
 msgstr ""
 
-#: symtab.c:1112
+#: symtab.c:1119
 #, fuzzy, gcc-internal-format
 msgid "node is alone in a comdat group"
 msgstr "節點是單獨在中 comdat 群組"
 
-#: symtab.c:1119
+#: symtab.c:1126
 #, fuzzy, gcc-internal-format
 msgid "same_comdat_group is not a circular list"
 msgstr "same_comdat_group 並非環狀清單"
 
-#: symtab.c:1134
+#: symtab.c:1141
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local symbol referred to by %s outside its comdat"
 msgstr ""
 
-#: symtab.c:1144
+#: symtab.c:1151
 #, gcc-internal-format
 msgid "implicit_section flag is set but section isn't"
 msgstr ""
 
-#: symtab.c:1151
+#: symtab.c:1158
 #, fuzzy, gcc-internal-format
 msgid "Both section and comdat group is set"
 msgstr "節點是單獨在中 comdat 群組"
 
-#: symtab.c:1163
+#: symtab.c:1170
 #, gcc-internal-format
 msgid "Alias and target's section differs"
 msgstr ""
 
-#: symtab.c:1170
+#: symtab.c:1177
 #, gcc-internal-format
 msgid "Alias and target's comdat groups differs"
 msgstr ""
 
-#: symtab.c:1185
+#: symtab.c:1192
 #, gcc-internal-format
 msgid "Transparent alias and target's assembler names differs"
 msgstr ""
 
-#: symtab.c:1193
+#: symtab.c:1200
 #, gcc-internal-format
 msgid "Chained transparent aliases"
 msgstr ""
 
-#: symtab.c:1216 symtab.c:1253
+#: symtab.c:1223 symtab.c:1260
 #, fuzzy, gcc-internal-format
 msgid "symtab_node::verify failed"
 msgstr "verify_cgraph_node 失敗"
 
-#: symtab.c:1249
+#: symtab.c:1256
 #, gcc-internal-format
 msgid "Two symbols with same comdat_group are not linked by the same_comdat_group list."
 msgstr ""
 
-#: symtab.c:1658
+#: symtab.c:1665
 #, fuzzy, gcc-internal-format
 msgid "function %q+D part of alias cycle"
 msgstr "函式 %q+D 部分的別名週期"
 
-#: symtab.c:1660
+#: symtab.c:1667
 #, fuzzy, gcc-internal-format
 msgid "variable %q+D part of alias cycle"
 msgstr "變數 %q+D 部分的別名週期"
 
-#: symtab.c:1688
+#: symtab.c:1695
 #, gcc-internal-format
 msgid "section of alias %q+D must match section of its target"
 msgstr ""
@@ -25761,7 +25782,7 @@
 msgid "the first argument of a VEC_COND_EXPR must be of a boolean vector type of the same number of elements as the result"
 msgstr ""
 
-#: tree-cfg.c:4395 c/c-typeck.c:5212
+#: tree-cfg.c:4395 c/c-typeck.c:5217
 #, gcc-internal-format
 msgid "type mismatch in conditional expression"
 msgstr "條件運算式中類型不匹配"
@@ -26111,22 +26132,22 @@
 msgid "missing edge %i->%i"
 msgstr "缺少邊 %i->%i"
 
-#: tree-cfg.c:9379
+#: tree-cfg.c:9388
 #, fuzzy, gcc-internal-format
 msgid "%<noreturn%> function does return"
 msgstr "%<noreturn%> 函式做回傳"
 
-#: tree-cfg.c:9400 tree-cfg.c:9432
+#: tree-cfg.c:9409 tree-cfg.c:9441
 #, fuzzy, gcc-internal-format
 msgid "control reaches end of non-void function"
 msgstr "控制達到結束的 non-void 函式"
 
-#: tree-cfg.c:9498 cp/cvt.c:1039
+#: tree-cfg.c:9507 cp/cvt.c:1039
 #, fuzzy, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgstr "忽略傳回值的 %qD，宣告的與屬性 warn_unused_result"
 
-#: tree-cfg.c:9503 cp/cvt.c:1046
+#: tree-cfg.c:9512 cp/cvt.c:1046
 #, fuzzy, gcc-internal-format
 msgid "ignoring return value of function declared with attribute warn_unused_result"
 msgstr "忽略傳回值的函式宣告的與屬性 warn_unused_result"
@@ -26393,44 +26414,44 @@
 msgid "stmt volatile flag not up-to-date"
 msgstr "stmt 易變的旗標無法 up-to-date"
 
-#: tree-ssa-strlen.c:1975
+#: tree-ssa-strlen.c:1999
 msgid "%G%qD output truncated before terminating nul copying %E byte from a string of the same length"
 msgid_plural "%G%qD output truncated before terminating nul copying %E bytes from a string of the same length"
 msgstr[0] ""
 
-#: tree-ssa-strlen.c:1989
+#: tree-ssa-strlen.c:2013
 msgid "%G%qD output truncated copying %E byte from a string of length %wu"
 msgid_plural "%G%qD output truncated copying %E bytes from a string of length %wu"
 msgstr[0] ""
 
-#: tree-ssa-strlen.c:1996
+#: tree-ssa-strlen.c:2020
 msgid "%G%qD output truncated copying between %wu and %wu bytes from a string of length %wu"
 msgstr ""
 
-#: tree-ssa-strlen.c:2008
+#: tree-ssa-strlen.c:2032
 msgid "%G%qD output may be truncated copying %E byte from a string of length %wu"
 msgid_plural "%G%qD output may be truncated copying %E bytes from a string of length %wu"
 msgstr[0] ""
 
-#: tree-ssa-strlen.c:2015 tree-ssa-strlen.c:2029
+#: tree-ssa-strlen.c:2039 tree-ssa-strlen.c:2053
 msgid "%G%qD output may be truncated copying between %wu and %wu bytes from a string of length %wu"
 msgstr ""
 
-#: tree-ssa-strlen.c:2150
+#: tree-ssa-strlen.c:2174
 msgid "%G%qD output truncated before terminating nul copying as many bytes from a string as its length"
 msgstr ""
 
-#: tree-ssa-strlen.c:2156
+#: tree-ssa-strlen.c:2180
 msgid "%G%qD specified bound depends on the length of the source argument"
 msgstr ""
 
-#: tree-ssa-strlen.c:2163
+#: tree-ssa-strlen.c:2187
 #, fuzzy, gcc-internal-format
 #| msgid "length modifier"
 msgid "length computed here"
 msgstr "長度修飾符"
 
-#: tree-ssa-uninit.c:191 varasm.c:331
+#: tree-ssa-uninit.c:191 varasm.c:342
 #, fuzzy, gcc-internal-format
 msgid "%qD was declared here"
 msgstr "%qD 被宣告在此"
@@ -26605,27 +26626,27 @@
 msgid "target specific builtin not available"
 msgstr "目標特定的內建無法使用"
 
-#: tree-vect-generic.c:287
+#: tree-vect-generic.c:283
 #, fuzzy, gcc-internal-format
 msgid "vector operation will be expanded piecewise"
 msgstr "向量作業將被展開 piecewise"
 
-#: tree-vect-generic.c:290
+#: tree-vect-generic.c:286
 #, fuzzy, gcc-internal-format
 msgid "vector operation will be expanded in parallel"
 msgstr "向量作業將被展開在中平行"
 
-#: tree-vect-generic.c:341
+#: tree-vect-generic.c:337
 #, fuzzy, gcc-internal-format
 msgid "vector operation will be expanded with a single scalar operation"
 msgstr "向量作業將被展開與單一純量作業"
 
-#: tree-vect-generic.c:941
+#: tree-vect-generic.c:937
 #, fuzzy, gcc-internal-format
 msgid "vector condition will be expanded piecewise"
 msgstr "向量作業將被展開 piecewise"
 
-#: tree-vect-generic.c:1373
+#: tree-vect-generic.c:1369
 #, fuzzy, gcc-internal-format
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr "向量隨機播放作業將被展開 piecewise"
@@ -26635,27 +26656,27 @@
 msgid "vectorization did not happen for a simd loop"
 msgstr ""
 
-#: tree-vrp.c:4930 tree-vrp.c:4974
+#: tree-vrp.c:4931 tree-vrp.c:4975
 #, fuzzy, gcc-internal-format
 msgid "array subscript %E is above array bounds of %qT"
 msgstr "陣列下標是以上的陣列邊界"
 
-#: tree-vrp.c:4956
+#: tree-vrp.c:4957
 #, fuzzy, gcc-internal-format
 msgid "array subscript [%E, %E] is outside array bounds of %qT"
 msgstr "陣列下標超出陣列邊界"
 
-#: tree-vrp.c:4988
+#: tree-vrp.c:4989
 #, fuzzy, gcc-internal-format
 msgid "array subscript %E is below array bounds of %qT"
 msgstr "陣列下標是下列的陣列邊界"
 
-#: tree-vrp.c:5046
+#: tree-vrp.c:5047
 #, fuzzy, gcc-internal-format
 msgid "array subscript %wi is below array bounds of %qT"
 msgstr "陣列下標是下列的陣列邊界"
 
-#: tree-vrp.c:5060
+#: tree-vrp.c:5061
 #, fuzzy, gcc-internal-format
 msgid "array subscript %wu is above array bounds of %qT"
 msgstr "陣列下標是以上的陣列邊界"
@@ -26670,92 +26691,92 @@
 msgid "side-effects element in no-side-effects CONSTRUCTOR"
 msgstr ""
 
-#: tree.c:7852
+#: tree.c:7856
 #, gcc-internal-format
 msgid "arrays of functions are not meaningful"
 msgstr "函式陣列是沒有意義的"
 
-#: tree.c:8019
+#: tree.c:8023
 #, gcc-internal-format
 msgid "function return type cannot be function"
 msgstr "函式不能回傳函式"
 
-#: tree.c:9327 tree.c:9412 tree.c:9473
+#: tree.c:9331 tree.c:9416 tree.c:9477
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: %s, have %s in %s, at %s:%d"
 msgstr "樹檢查：%s，得到 %s 在 %s，於 %s:%d"
 
-#: tree.c:9364
+#: tree.c:9368
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected none of %s, have %s in %s, at %s:%d"
 msgstr "樹檢查：不需要 %s，得到 %s 在 %s，於 %s:%d"
 
-#: tree.c:9377
+#: tree.c:9381
 #, gcc-internal-format
 msgid "tree check: expected class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "樹檢查：需要類別 %qs，得到 %qs(%s) 在 %s，於 %s:%d"
 
-#: tree.c:9426
+#: tree.c:9430
 #, fuzzy, gcc-internal-format
 msgid "tree check: did not expect class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "樹檢查：並未預期類別 %qs，有 %qs (%s) 在中 %s，於 %s:%d"
 
-#: tree.c:9439
+#: tree.c:9443
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected omp_clause %s, have %s in %s, at %s:%d"
 msgstr "樹檢查：預期的 ompclause %s(_C)，有 %s 在中 %s，於 %s:%d"
 
-#: tree.c:9499
+#: tree.c:9503
 #, fuzzy, gcc-internal-format
 msgid "tree check: expected tree that contains %qs structure, have %qs in %s, at %s:%d"
 msgstr "樹檢查：預期的樹該含有 %qs 結構，有 %qs 在中 %s，於 %s:%d"
 
-#: tree.c:9513
+#: tree.c:9517
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_int_cst with %d elts in %s, at %s:%d"
 msgstr "樹檢查：存取的 elt %d 的 treevec 與 %d elts 在中 %s(_V)，於 %s:%d"
 
-#: tree.c:9525
+#: tree.c:9529
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_vec with %d elts in %s, at %s:%d"
 msgstr "樹檢查：存取的 elt %d 的 treevec 與 %d elts 在中 %s(_V)，於 %s:%d"
 
-#: tree.c:9538
+#: tree.c:9542
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of %s with %d operands in %s, at %s:%d"
 msgstr "樹檢查：存取的運算元 %d 的 %s 與 %d 運算元在中 %s，於 %s:%d"
 
-#: tree.c:9551
+#: tree.c:9555
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of omp_clause %s with %d operands in %s, at %s:%d"
 msgstr "樹檢查：存取的運算元 %d 的 ompclause %s 與 %d 運算元在中 %s(_C)，於 %s:%d"
 
-#: tree.c:12446
+#: tree.c:12450
 #, fuzzy, gcc-internal-format
 msgid "%qD is deprecated: %s"
 msgstr "%qE 被不宜用：%s"
 
-#: tree.c:12449
+#: tree.c:12453
 #, fuzzy, gcc-internal-format
 msgid "%qD is deprecated"
 msgstr "%qE 被不宜用"
 
-#: tree.c:12473 tree.c:12495
+#: tree.c:12477 tree.c:12499
 #, fuzzy, gcc-internal-format
 msgid "%qE is deprecated: %s"
 msgstr "%qE 被不宜用：%s"
 
-#: tree.c:12476 tree.c:12498
+#: tree.c:12480 tree.c:12502
 #, fuzzy, gcc-internal-format
 msgid "%qE is deprecated"
 msgstr "%qE 被不宜用"
 
-#: tree.c:12482 tree.c:12503
+#: tree.c:12486 tree.c:12507
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "type is deprecated: %s"
 msgstr "型態被不宜用：%s"
 
-#: tree.c:12485 tree.c:12506
+#: tree.c:12489 tree.c:12510
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr "類型已過時"
@@ -26780,242 +26801,242 @@
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.c:13043
+#: tree.c:13047
 #, gcc-internal-format, gfc-internal-format
 msgid "type variant differs by %s"
 msgstr ""
 
-#: tree.c:13084
+#: tree.c:13088
 #, gcc-internal-format
 msgid "type variant has different TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13086
+#: tree.c:13090
 #, gcc-internal-format
 msgid "type variant's TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13088
+#: tree.c:13092
 #, gcc-internal-format
 msgid "type's TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13108
+#: tree.c:13112
 #, gcc-internal-format
 msgid "type variant with TYPE_ALIAS_SET_KNOWN_P"
 msgstr ""
 
-#: tree.c:13121
+#: tree.c:13125
 #, gcc-internal-format
 msgid "type variant has different TYPE_VFIELD"
 msgstr ""
 
-#: tree.c:13157
+#: tree.c:13161
 #, gcc-internal-format
 msgid "type variant has different TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13159
+#: tree.c:13163
 #, gcc-internal-format
 msgid "type variant's TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13161
+#: tree.c:13165
 #, gcc-internal-format
 msgid "type's TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13199
+#: tree.c:13203
 #, gcc-internal-format
 msgid "type variant has different TYPE_FIELDS"
 msgstr ""
 
-#: tree.c:13201
+#: tree.c:13205
 #, fuzzy, gcc-internal-format
 msgid "first mismatch is field"
 msgstr "%s：時間戳記與圖檔案不匹配\n"
 
-#: tree.c:13203
+#: tree.c:13207
 #, gcc-internal-format
 msgid "and field"
 msgstr ""
 
-#: tree.c:13220
+#: tree.c:13224
 #, gcc-internal-format
 msgid "type variant has different TREE_TYPE"
 msgstr ""
 
-#: tree.c:13222 tree.c:13233
+#: tree.c:13226 tree.c:13237
 #, gcc-internal-format
 msgid "type variant's TREE_TYPE"
 msgstr ""
 
-#: tree.c:13224 tree.c:13235
+#: tree.c:13228 tree.c:13239
 #, gcc-internal-format
 msgid "type's TREE_TYPE"
 msgstr ""
 
-#: tree.c:13231
+#: tree.c:13235
 #, fuzzy, gcc-internal-format
 msgid "type is not compatible with its variant"
 msgstr "%qD 不是相容與 %qD"
 
-#: tree.c:13534
+#: tree.c:13538
 #, fuzzy, gcc-internal-format
 msgid "Main variant is not defined"
 msgstr "環境變數 %qs 無法定義"
 
-#: tree.c:13539
+#: tree.c:13543
 #, gcc-internal-format
 msgid "TYPE_MAIN_VARIANT has different TYPE_MAIN_VARIANT"
 msgstr ""
 
-#: tree.c:13551
+#: tree.c:13555
 #, gcc-internal-format
 msgid "TYPE_CANONICAL has different TYPE_CANONICAL"
 msgstr ""
 
-#: tree.c:13569
+#: tree.c:13573
 #, gcc-internal-format
 msgid "TYPE_CANONICAL is not compatible"
 msgstr ""
 
-#: tree.c:13577
+#: tree.c:13581
 #, gcc-internal-format
 msgid "TYPE_MODE of TYPE_CANONICAL is not compatible"
 msgstr ""
 
-#: tree.c:13583
+#: tree.c:13587
 #, gcc-internal-format
 msgid "TYPE_CANONICAL of main variant is not main variant"
 msgstr ""
 
-#: tree.c:13599
+#: tree.c:13603
 #, gcc-internal-format
 msgid "TYPE_VFIELD is not FIELD_DECL nor TREE_LIST"
 msgstr ""
 
-#: tree.c:13609
+#: tree.c:13613
 #, gcc-internal-format
 msgid "TYPE_NEXT_PTR_TO is not POINTER_TYPE"
 msgstr ""
 
-#: tree.c:13619
+#: tree.c:13623
 #, gcc-internal-format
 msgid "TYPE_NEXT_REF_TO is not REFERENCE_TYPE"
 msgstr ""
 
-#: tree.c:13640
+#: tree.c:13644
 #, gcc-internal-format
 msgid "TYPE_BINFO is not TREE_BINFO"
 msgstr ""
 
-#: tree.c:13646
+#: tree.c:13650
 #, gcc-internal-format
 msgid "TYPE_BINFO type is not TYPE_MAIN_VARIANT"
 msgstr ""
 
-#: tree.c:13657
+#: tree.c:13661
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not record nor union"
 msgstr ""
 
-#: tree.c:13668
+#: tree.c:13672
 #, gcc-internal-format
 msgid "TYPE_OFFSET_BASETYPE is not record nor union"
 msgstr ""
 
-#: tree.c:13686
+#: tree.c:13690
 #, gcc-internal-format
 msgid "TYPE_ARRAY_MAX_SIZE not INTEGER_CST"
 msgstr ""
 
-#: tree.c:13693
+#: tree.c:13697
 #, gcc-internal-format
 msgid "TYPE_MAX_VALUE_RAW non-NULL"
 msgstr ""
 
-#: tree.c:13700
+#: tree.c:13704
 #, gcc-internal-format
 msgid "TYPE_LANG_SLOT_1 (binfo) field is non-NULL"
 msgstr ""
 
-#: tree.c:13716
+#: tree.c:13720
 #, gcc-internal-format
 msgid "Enum value is not CONST_DECL or INTEGER_CST"
 msgstr ""
 
-#: tree.c:13724
+#: tree.c:13728
 #, gcc-internal-format
 msgid "Enum value type is not INTEGER_TYPE nor convertible to the enum"
 msgstr ""
 
-#: tree.c:13731
+#: tree.c:13735
 #, gcc-internal-format
 msgid "Enum value name is not IDENTIFIER_NODE"
 msgstr ""
 
-#: tree.c:13741
+#: tree.c:13745
 #, fuzzy, gcc-internal-format
 msgid "Array TYPE_DOMAIN is not integer type"
 msgstr "大小的陣列 %qE 有 non-integer 型態"
 
-#: tree.c:13750
+#: tree.c:13754
 #, fuzzy, gcc-internal-format
 msgid "TYPE_FIELDS defined in incomplete type"
 msgstr "欄位 %qE 有不完整型態"
 
-#: tree.c:13772
+#: tree.c:13776
 #, gcc-internal-format
 msgid "Wrong tree in TYPE_FIELDS list"
 msgstr ""
 
-#: tree.c:13787
+#: tree.c:13791
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is %i while TYPE_CACHED_VALUES is %p"
 msgstr ""
 
-#: tree.c:13793
+#: tree.c:13797
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES is not TREE_VEC"
 msgstr ""
 
-#: tree.c:13806
+#: tree.c:13810
 #, gcc-internal-format
 msgid "wrong TYPE_CACHED_VALUES entry"
 msgstr ""
 
-#: tree.c:13819
+#: tree.c:13823
 #, gcc-internal-format
 msgid "TREE_PURPOSE is non-NULL in TYPE_ARG_TYPES list"
 msgstr ""
 
-#: tree.c:13825
+#: tree.c:13829
 #, gcc-internal-format
 msgid "Wrong entry in TYPE_ARG_TYPES list"
 msgstr ""
 
-#: tree.c:13832
+#: tree.c:13836
 #, gcc-internal-format
 msgid "TYPE_VALUES_RAW field is non-NULL"
 msgstr ""
 
-#: tree.c:13844
+#: tree.c:13848
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is set while it should not"
 msgstr ""
 
-#: tree.c:13850
+#: tree.c:13854
 #, gcc-internal-format
 msgid "TYPE_STRING_FLAG is set on wrong type code"
 msgstr ""
 
-#: tree.c:13860
+#: tree.c:13864
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not main variant"
 msgstr ""
 
-#: tree.c:13867
+#: tree.c:13871
 #, fuzzy, gcc-internal-format
 msgid "verify_type failed"
 msgstr "verifygimple 失敗(_G)"
@@ -27040,188 +27061,188 @@
 msgid "corrupted value profile: %s profile counter (%d out of %d) inconsistent with basic-block count (%d)"
 msgstr "已損壞值側寫檔：%s 側寫檔計數器 (%d 超出 %d) 不一致與 basic-block 計數 (%d)"
 
-#: var-tracking.c:7166
+#: var-tracking.c:7184
 #, fuzzy, gcc-internal-format
 msgid "variable tracking size limit exceeded with -fvar-tracking-assignments, retrying without"
 msgstr "變數追蹤大小限制超出的與 -fvar-tracking-assignments，重試而無需"
 
-#: var-tracking.c:7170
+#: var-tracking.c:7188
 #, fuzzy, gcc-internal-format
 msgid "variable tracking size limit exceeded"
 msgstr "變數追蹤大小限制超出"
 
-#: varasm.c:326
+#: varasm.c:337
 #, fuzzy, gcc-internal-format
 msgid "%+qD causes a section type conflict with %qD"
 msgstr "%+D 造成區段型態衝突與 %D"
 
-#: varasm.c:329
+#: varasm.c:340
 #, fuzzy, gcc-internal-format
 msgid "section type conflict with %qD"
 msgstr "%+D 造成區段型態衝突與 %D"
 
-#: varasm.c:334
+#: varasm.c:345
 #, fuzzy, gcc-internal-format
 #| msgid "%+D causes a section type conflict"
 msgid "%+qD causes a section type conflict"
 msgstr "%+D 導致一個區段類型衝突"
 
-#: varasm.c:336
+#: varasm.c:347
 #, fuzzy, gcc-internal-format
 #| msgid "%+D causes a section type conflict"
 msgid "section type conflict"
 msgstr "%+D 導致一個區段類型衝突"
 
-#: varasm.c:1019
+#: varasm.c:1030
 #, fuzzy, gcc-internal-format
 #| msgid "alignment of %q+D is greater than maximum object file alignment.  Using %d"
 msgid "alignment of %q+D is greater than maximum object file alignment %d"
 msgstr "%q+D 的對齊要求大於目的檔案的最大對齊邊界。使用 %d"
 
-#: varasm.c:1172
+#: varasm.c:1183
 #, fuzzy, gcc-internal-format
 #| msgid "Put zero initialized data in the bss section"
 msgid "only zero initializers are allowed in section %qs"
 msgstr "將初始化為零的資料存放在 bss 區段中"
 
-#: varasm.c:1378 varasm.c:1387
+#: varasm.c:1389 varasm.c:1398
 #, gcc-internal-format
 msgid "register name not specified for %q+D"
 msgstr "%q+D 的暫存器名無效"
 
-#: varasm.c:1389
+#: varasm.c:1400
 #, gcc-internal-format
 msgid "invalid register name for %q+D"
 msgstr "%q+D 的暫存器名無效"
 
-#: varasm.c:1391
+#: varasm.c:1402
 #, gcc-internal-format
 msgid "data type of %q+D isn%'t suitable for a register"
 msgstr "為 %q+D 指定的暫存器不適合此資料類型"
 
-#: varasm.c:1394
+#: varasm.c:1405
 #, fuzzy, gcc-internal-format
 msgid "the register specified for %q+D cannot be accessed by the current target"
 msgstr "暫存器指定的用於 %q+D 無法存取的由目前的目標"
 
-#: varasm.c:1397
+#: varasm.c:1408
 #, fuzzy, gcc-internal-format
 msgid "the register specified for %q+D is not general enough to be used as a register variable"
 msgstr "暫存器指定的用於 %q+D 不是一般足夠為使用的做為暫存器變數"
 
-#: varasm.c:1400
+#: varasm.c:1411
 #, gcc-internal-format
 msgid "register specified for %q+D isn%'t suitable for data type"
 msgstr "為 %q+D 指定的暫存器不適合此資料類型"
 
-#: varasm.c:1410
+#: varasm.c:1421
 #, gcc-internal-format
 msgid "global register variable has initial value"
 msgstr "全域暫存器變數有初始值"
 
-#: varasm.c:1414
+#: varasm.c:1425
 #, gcc-internal-format
 msgid "optimization may eliminate reads and/or writes to register variables"
 msgstr "最佳化可能會去除對暫存器變數的讀寫"
 
-#: varasm.c:1460
+#: varasm.c:1471
 #, gcc-internal-format
 msgid "register name given for non-register variable %q+D"
 msgstr "為非暫存器變數 %q+D 給定了暫存器名"
 
-#: varasm.c:1870
+#: varasm.c:1881
 #, gcc-internal-format
 msgid "Patchable function entry > size"
 msgstr ""
 
-#: varasm.c:2069
+#: varasm.c:2080
 #, gcc-internal-format
 msgid "thread-local COMMON data not implemented"
 msgstr "執行緒區域性的 COMMON 資料沒有實作"
 
-#: varasm.c:2102
+#: varasm.c:2113
 #, gcc-internal-format
 msgid "requested alignment for %q+D is greater than implemented alignment of %wu"
 msgstr "%q+D 需要的對齊邊界大於實作的對齊邊界 %wu"
 
-#: varasm.c:2205 c/c-decl.c:5027 c/c-parser.c:1534
+#: varasm.c:2216 c/c-decl.c:5027 c/c-parser.c:1534
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t known"
 msgstr "%q+D 的存儲大小不明"
 
-#: varasm.c:4910
+#: varasm.c:4921
 #, fuzzy, gcc-internal-format
 msgid "initializer for integer/fixed-point value is too complicated"
 msgstr "初始設定式用於整數/定點值太複雜"
 
-#: varasm.c:4915
+#: varasm.c:4926
 #, gcc-internal-format
 msgid "initializer for floating value is not a floating constant"
 msgstr "浮點值的初始值設定不是一個浮點常數"
 
-#: varasm.c:5227
+#: varasm.c:5238
 #, fuzzy, gcc-internal-format
 msgid "invalid initial value for member %qE"
 msgstr "無效的初始值用於成員 %qE"
 
-#: varasm.c:5487
+#: varasm.c:5498
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after being called"
 msgid "%+qD declared weak after being used"
 msgstr "%q+D 的內聯宣告出現在其被呼叫之後"
 
-#: varasm.c:5539
+#: varasm.c:5550
 #, fuzzy, gcc-internal-format
 #| msgid "weak declaration of %q+D must precede definition"
 msgid "weak declaration of %q+D being applied to a already existing, static definition"
 msgstr "%q+D 的弱宣告必須在定義之前"
 
-#: varasm.c:5575
+#: varasm.c:5586
 #, gcc-internal-format
 msgid "weak declaration of %q+D must be public"
 msgstr "%q+D 的弱宣告必須是公共的"
 
-#: varasm.c:5579
+#: varasm.c:5590
 #, gcc-internal-format
 msgid "weak declaration of %q+D not supported"
 msgstr "不支援 %q+D 的弱宣告"
 
-#: varasm.c:5608 varasm.c:5912
+#: varasm.c:5619 varasm.c:5926
 #, gcc-internal-format
 msgid "only weak aliases are supported in this configuration"
 msgstr "此配置下只支援弱別名"
 
-#: varasm.c:5802
+#: varasm.c:5813
 #, fuzzy, gcc-internal-format
 msgid "weakref is not supported in this configuration"
 msgstr "weakref 未被支援在中這個組態"
 
-#: varasm.c:5834
+#: varasm.c:5846
 #, fuzzy, gcc-internal-format
 msgid "ifunc is not supported on this target"
 msgstr "巢狀的函式不支援於這個目標"
 
-#: varasm.c:5892
+#: varasm.c:5904
 #, gcc-internal-format
 msgid "weakref %q+D ultimately targets itself"
 msgstr "weakref %q+D 最終參照其自身"
 
-#: varasm.c:5894
+#: varasm.c:5906
 #, fuzzy, gcc-internal-format
 msgid "weakref %q+D must have static linkage"
 msgstr "weakref %q+D 必須有靜態鏈結"
 
-#: varasm.c:5901
+#: varasm.c:5913
 #, fuzzy, gcc-internal-format
 msgid "alias definitions not supported in this configuration"
 msgstr "別名定義不支援在中這個組態"
 
-#: varasm.c:5909
+#: varasm.c:5923
 #, fuzzy, gcc-internal-format
 msgid "ifunc is not supported in this configuration"
 msgstr "ifunc 未被支援在中這個組態"
 
-#: varasm.c:6127 config/sol2.c:159 config/i386/winnt.c:265
+#: varasm.c:6141 config/sol2.c:159 config/i386/winnt.c:265
 #, gcc-internal-format
 msgid "visibility attribute not supported in this configuration; ignored"
 msgstr "可見性屬性在此配置下不受支援；已忽略"
@@ -27297,475 +27318,481 @@
 msgid "bytecode stream: tag %s is not in the expected range [%s, %s]"
 msgstr "位元碼串流：標籤 %s 不是在中預期的範圍 [%s，%s]"
 
-#: c-family/c-attribs.c:529
+#: c-family/c-attribs.c:524
+#, fuzzy, gcc-internal-format
+#| msgid "%qE attribute ignored for %qE"
+msgid "%qE attribute ignored for type %qT"
+msgstr "%qE 屬性為 %qE 所忽略"
+
+#: c-family/c-attribs.c:536
 #, gcc-internal-format
 msgid "%qE attribute ignored for field of type %qT"
 msgstr "%qE 屬性為 %qT 型態的欄位所忽略"
 
-#: c-family/c-attribs.c:696
+#: c-family/c-attribs.c:706
 #, fuzzy, gcc-internal-format
 #| msgid "visibility argument not a string"
 msgid "no_sanitize argument not a string"
 msgstr "visibility 的引數不是一個字串"
 
-#: c-family/c-attribs.c:826 ada/gcc-interface/utils.c:6235
+#: c-family/c-attribs.c:837 ada/gcc-interface/utils.c:6240
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute ignored due to conflict with attribute %qs"
 msgstr "%qE 屬性衝突與屬性 %s"
 
-#: c-family/c-attribs.c:875
+#: c-family/c-attribs.c:886
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute ignored. Use -fcf-protection option to enable it"
 msgstr "%qE 屬性在不是類別的類型上被忽略"
 
-#: c-family/c-attribs.c:914 c-family/c-attribs.c:920 c-family/c-attribs.c:3388
-#: c-family/c-attribs.c:3423 c-family/c-attribs.c:3429
+#: c-family/c-attribs.c:925 c-family/c-attribs.c:931 c-family/c-attribs.c:3399
+#: c-family/c-attribs.c:3434 c-family/c-attribs.c:3440
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute ignored due to conflict with %qs attribute"
 msgstr "%qE 屬性衝突與屬性 %s"
 
-#: c-family/c-attribs.c:976 brig/brig-lang.c:482 lto/lto-lang.c:288
+#: c-family/c-attribs.c:987 brig/brig-lang.c:482 lto/lto-lang.c:288
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute has no effect on unit local functions"
 msgstr "%qE 屬性沒有任何效果於單位本地函式"
 
-#: c-family/c-attribs.c:1130
+#: c-family/c-attribs.c:1141
 #, gcc-internal-format
 msgid "%qE attribute have effect only on public objects"
 msgstr "%qE 屬性只能套用到公共物件上"
 
-#: c-family/c-attribs.c:1159
+#: c-family/c-attribs.c:1170
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only affects top level objects"
 msgstr "%qE 屬性只有套用到變數"
 
-#: c-family/c-attribs.c:1198 c-family/c-attribs.c:2682
+#: c-family/c-attribs.c:1209 c-family/c-attribs.c:2693
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute on function returning %<void%>"
 msgstr "使用結果的函式回傳 %<void%>"
 
-#: c-family/c-attribs.c:1221 c-family/c-pragma.c:419
+#: c-family/c-attribs.c:1232 c-family/c-pragma.c:419
 #, gcc-internal-format
 msgid "scalar_storage_order is not supported because endianness is not uniform"
 msgstr ""
 
-#: c-family/c-attribs.c:1238
+#: c-family/c-attribs.c:1249
 #, gcc-internal-format
 msgid "scalar_storage_order argument must be one of \"big-endian\" or \"little-endian\""
 msgstr ""
 
-#: c-family/c-attribs.c:1334
+#: c-family/c-attribs.c:1345
 #, fuzzy, gcc-internal-format
 msgid "destructor priorities are not supported"
 msgstr "解構式優先等級未被支援"
 
-#: c-family/c-attribs.c:1336
+#: c-family/c-attribs.c:1347
 #, fuzzy, gcc-internal-format
 msgid "constructor priorities are not supported"
 msgstr "建構子優先等級未被支援"
 
-#: c-family/c-attribs.c:1358
+#: c-family/c-attribs.c:1369
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "destructor priorities from 0 to %d are reserved for the implementation"
 msgstr "解構式優先等級從 0 到 %d 被保留的用於實作"
 
-#: c-family/c-attribs.c:1363
+#: c-family/c-attribs.c:1374
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "constructor priorities from 0 to %d are reserved for the implementation"
 msgstr "建構子優先等級從 0 到 %d 被保留的用於實作"
 
-#: c-family/c-attribs.c:1371
+#: c-family/c-attribs.c:1382
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "destructor priorities must be integers from 0 to %d inclusive"
 msgstr "解構式優先等級必須是整數從 0 到 %d inclusive"
 
-#: c-family/c-attribs.c:1374
+#: c-family/c-attribs.c:1385
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "constructor priorities must be integers from 0 to %d inclusive"
 msgstr "建構子優先等級必須是整數從 0 到 %d inclusive"
 
-#: c-family/c-attribs.c:1527
+#: c-family/c-attribs.c:1538
 #, fuzzy, gcc-internal-format
 msgid "unknown machine mode %qE"
 msgstr "不明機器模式 %qE"
 
-#: c-family/c-attribs.c:1557
+#: c-family/c-attribs.c:1568
 #, gcc-internal-format
 msgid "specifying vector types with __attribute__ ((mode)) is deprecated"
 msgstr "指定向量類型時使用 __attribute__ ((mode)) 已過時"
 
-#: c-family/c-attribs.c:1560
+#: c-family/c-attribs.c:1571
 #, gcc-internal-format
 msgid "use __attribute__ ((vector_size)) instead"
 msgstr "改用 __attribute__ ((vector_size))"
 
-#: c-family/c-attribs.c:1569
+#: c-family/c-attribs.c:1580
 #, gcc-internal-format
 msgid "unable to emulate %qs"
 msgstr "無法列舉 %qs"
 
-#: c-family/c-attribs.c:1582
+#: c-family/c-attribs.c:1593
 #, gcc-internal-format
 msgid "invalid pointer mode %qs"
 msgstr "無效的指標模式 %qs"
 
-#: c-family/c-attribs.c:1599
+#: c-family/c-attribs.c:1610
 #, fuzzy, gcc-internal-format
 msgid "signedness of type and machine mode %qs don%'t match"
 msgstr "signedness 的型態和機器模式 %qs don%'t 匹配"
 
-#: c-family/c-attribs.c:1610
+#: c-family/c-attribs.c:1621
 #, gcc-internal-format
 msgid "no data type for mode %qs"
 msgstr "沒有模式為 %qs 的資料類型"
 
-#: c-family/c-attribs.c:1620
+#: c-family/c-attribs.c:1631
 #, gcc-internal-format
 msgid "cannot use mode %qs for enumeral types"
 msgstr "無法為列舉類型使用模式 %qs"
 
-#: c-family/c-attribs.c:1647
+#: c-family/c-attribs.c:1658
 #, gcc-internal-format
 msgid "mode %qs applied to inappropriate type"
 msgstr "對不合適的類型套用模式 %qs"
 
-#: c-family/c-attribs.c:1669
+#: c-family/c-attribs.c:1680
 #, fuzzy, gcc-internal-format
 msgid "section attributes are not supported for this target"
 msgstr "區段屬性未被支援用於這個目標"
 
-#: c-family/c-attribs.c:1675
+#: c-family/c-attribs.c:1686
 #, gcc-internal-format
 msgid "section attribute not allowed for %q+D"
 msgstr "%q+D 不能有 section 屬性"
 
-#: c-family/c-attribs.c:1681
+#: c-family/c-attribs.c:1692
 #, fuzzy, gcc-internal-format
 msgid "section attribute argument not a string constant"
 msgstr "%qE 屬性引數不是字串常數"
 
-#: c-family/c-attribs.c:1690
+#: c-family/c-attribs.c:1701
 #, fuzzy, gcc-internal-format
 msgid "section attribute cannot be specified for local variables"
 msgstr "區段屬性無法指定的用於區域變數"
 
-#: c-family/c-attribs.c:1700 config/bfin/bfin.c:4806 config/bfin/bfin.c:4857
+#: c-family/c-attribs.c:1711 config/bfin/bfin.c:4806 config/bfin/bfin.c:4857
 #: config/bfin/bfin.c:4883 config/bfin/bfin.c:4896
 #, gcc-internal-format
 msgid "section of %q+D conflicts with previous declaration"
 msgstr "%q+D 的區段與早先的宣告衝突"
 
-#: c-family/c-attribs.c:1708
+#: c-family/c-attribs.c:1719
 #, fuzzy, gcc-internal-format
 msgid "section of %q+D cannot be overridden"
 msgstr "區段的 %q+D 無法 overridden"
 
-#: c-family/c-attribs.c:1773
+#: c-family/c-attribs.c:1784
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "requested alignment %d is larger than %d"
 msgstr "要求的對齊邊界太大"
 
-#: c-family/c-attribs.c:1866
+#: c-family/c-attribs.c:1877
 #, gcc-internal-format
 msgid "alignment may not be specified for %q+D"
 msgstr "不能為 %q+D 指定對齊"
 
-#: c-family/c-attribs.c:1886
+#: c-family/c-attribs.c:1897
 #, fuzzy, gcc-internal-format
 msgid "ignoring attribute %<%E (%u)%> because it conflicts with attribute %<%E (%u)%>"
 msgstr "%s 屬性的『%s』衝突與 %s 屬性於 %L"
 
 #. Do not error out for attribute warn_if_not_aligned.
-#: c-family/c-attribs.c:1891 c-family/c-attribs.c:1920
+#: c-family/c-attribs.c:1902 c-family/c-attribs.c:1931
 #, fuzzy, gcc-internal-format
 msgid "alignment for %q+D must be at least %d"
 msgstr "對齊用於 %q+D 必須是至少 %d"
 
-#: c-family/c-attribs.c:1916
+#: c-family/c-attribs.c:1927
 #, fuzzy, gcc-internal-format
 msgid "alignment for %q+D was previously specified as %d and may not be decreased"
 msgstr "對齊用於 %q+D 是在之前指定的做為 %d 和可能無法被減少"
 
-#: c-family/c-attribs.c:1943
+#: c-family/c-attribs.c:1954
 #, fuzzy, gcc-internal-format
 #| msgid "alignment may not be specified for %q+D"
 msgid "%<warn_if_not_aligned%> may not be specified for %q+D"
 msgstr "不能為 %q+D 指定對齊"
 
-#: c-family/c-attribs.c:1986
+#: c-family/c-attribs.c:1997
 #, fuzzy, gcc-internal-format
 msgid "inline function %q+D declared weak"
 msgstr "內聯函式 %q+D 宣告的 weak"
 
-#: c-family/c-attribs.c:1991
+#: c-family/c-attribs.c:2002
 #, fuzzy, gcc-internal-format
 msgid "indirect function %q+D cannot be declared weak"
 msgstr "間接函式 %q+D 無法宣告的 weak"
 
-#: c-family/c-attribs.c:2015
+#: c-family/c-attribs.c:2026
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is only applicable on functions"
 msgstr "%qE 屬性只有套用到函式"
 
-#: c-family/c-attribs.c:2046
+#: c-family/c-attribs.c:2057
 #, fuzzy, gcc-internal-format
 msgid "%q+D defined both normally and as %qE attribute"
 msgstr "%q+D 定義的兩者正常和做為 %qE 屬性"
 
-#: c-family/c-attribs.c:2054
+#: c-family/c-attribs.c:2065
 #, fuzzy, gcc-internal-format
 msgid "weak %q+D cannot be defined %qE"
 msgstr "weak %q+D 無法定義 %qE"
 
-#: c-family/c-attribs.c:2071 c-family/c-attribs.c:2582
+#: c-family/c-attribs.c:2082 c-family/c-attribs.c:2593
 #, fuzzy, gcc-internal-format
 msgid "attribute %qE argument not a string"
 msgstr "屬性 %qE 引數不是字串"
 
-#: c-family/c-attribs.c:2106
+#: c-family/c-attribs.c:2117
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after being called"
 msgid "%+qD declared alias after being used"
 msgstr "%q+D 的內聯宣告出現在其被呼叫之後"
 
-#: c-family/c-attribs.c:2108
+#: c-family/c-attribs.c:2119
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after being called"
 msgid "%+qD declared ifunc after being used"
 msgstr "%q+D 的內聯宣告出現在其被呼叫之後"
 
-#: c-family/c-attribs.c:2159
+#: c-family/c-attribs.c:2170
 #, fuzzy, gcc-internal-format
 msgid "indirect function %q+D cannot be declared weakref"
 msgstr "間接函式 %q+D 無法宣告的 weakref"
 
-#: c-family/c-attribs.c:2181
+#: c-family/c-attribs.c:2192
 #, fuzzy, gcc-internal-format
 msgid "weakref attribute must appear before alias attribute"
 msgstr "weakref 屬性必須出現之前別名屬性"
 
-#: c-family/c-attribs.c:2193
+#: c-family/c-attribs.c:2204
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after being called"
 msgid "%+qD declared weakref after being used"
 msgstr "%q+D 的內聯宣告出現在其被呼叫之後"
 
-#: c-family/c-attribs.c:2217
+#: c-family/c-attribs.c:2228
 #, gcc-internal-format
 msgid "%qE attribute ignored on non-class types"
 msgstr "%qE 屬性在不是類別的類型上被忽略"
 
-#: c-family/c-attribs.c:2223
+#: c-family/c-attribs.c:2234
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute ignored because %qT is already defined"
 msgstr "%qE 屬性忽略的因為 %qT 已經定義"
 
-#: c-family/c-attribs.c:2236
+#: c-family/c-attribs.c:2247
 #, gcc-internal-format
 msgid "visibility argument not a string"
 msgstr "visibility 的引數不是一個字串"
 
-#: c-family/c-attribs.c:2248
+#: c-family/c-attribs.c:2259
 #, gcc-internal-format
 msgid "%qE attribute ignored on types"
 msgstr "%qE 屬性在類型上被忽略"
 
-#: c-family/c-attribs.c:2264
+#: c-family/c-attribs.c:2275
 #, gcc-internal-format
 msgid "visibility argument must be one of \"default\", \"hidden\", \"protected\" or \"internal\""
 msgstr "visibility  的引數必須是「default」、「hidden」、「protected」或「internal」其中之一"
 
-#: c-family/c-attribs.c:2275
+#: c-family/c-attribs.c:2286
 #, fuzzy, gcc-internal-format
 msgid "%qD redeclared with different visibility"
 msgstr "%qD redeclared 與不同的可視性"
 
-#: c-family/c-attribs.c:2278 c-family/c-attribs.c:2282
+#: c-family/c-attribs.c:2289 c-family/c-attribs.c:2293
 #, fuzzy, gcc-internal-format
 msgid "%qD was declared %qs which implies default visibility"
 msgstr "%qD 被宣告 %qs 該項意味著預設可視性"
 
-#: c-family/c-attribs.c:2320
+#: c-family/c-attribs.c:2331
 #, gcc-internal-format
 msgid "tls_model argument not a string"
 msgstr "tls_model 的引數不是一個字串"
 
-#: c-family/c-attribs.c:2333
+#: c-family/c-attribs.c:2344
 #, gcc-internal-format
 msgid "tls_model argument must be one of \"local-exec\", \"initial-exec\", \"local-dynamic\" or \"global-dynamic\""
 msgstr "tls_model 的引數必須是「local-exec」、「initial-exec」、「local-dynamic」或「global-dynamic」其中之一"
 
-#: c-family/c-attribs.c:2353 c-family/c-attribs.c:2656
-#: c-family/c-attribs.c:3497 config/m32c/m32c.c:2944
+#: c-family/c-attribs.c:2364 c-family/c-attribs.c:2667
+#: c-family/c-attribs.c:3508 config/m32c/m32c.c:2944
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applies only to functions"
 msgstr "%qE 屬性套用只有到函式"
 
-#: c-family/c-attribs.c:2417
+#: c-family/c-attribs.c:2428
 #, fuzzy, gcc-internal-format
 msgid "alloc_size parameter outside range"
 msgstr "allocsize 參數外側範圍(_S)"
 
-#: c-family/c-attribs.c:2443
+#: c-family/c-attribs.c:2454
 #, fuzzy, gcc-internal-format
 msgid "alloc_align parameter outside range"
 msgstr "allocsize 參數外側範圍(_S)"
 
-#: c-family/c-attribs.c:2467
+#: c-family/c-attribs.c:2478
 #, fuzzy, gcc-internal-format
 msgid "assume_aligned parameter not integer constant"
 msgstr "要求的對齊不是整數常數"
 
-#: c-family/c-attribs.c:2595
+#: c-family/c-attribs.c:2606
 #, gcc-internal-format
 msgid "only %<inbranch%> and %<notinbranch%> flags are allowed for %<__simd__%> attribute"
 msgstr ""
 
-#: c-family/c-attribs.c:2662 c-family/c-attribs.c:3503
+#: c-family/c-attribs.c:2673 c-family/c-attribs.c:3514
 #, fuzzy, gcc-internal-format
 msgid "can%'t set %qE attribute after definition"
 msgstr "can%'t 設定 %qE 屬性之後定義"
 
-#: c-family/c-attribs.c:2727
+#: c-family/c-attribs.c:2738
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute duplicated"
 msgstr "%qE 屬性重製"
 
-#: c-family/c-attribs.c:2729
+#: c-family/c-attribs.c:2740
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute follows %qE"
 msgstr "%qE 屬性追隨 %qE"
 
-#: c-family/c-attribs.c:2828
+#: c-family/c-attribs.c:2839
 #, fuzzy, gcc-internal-format
 msgid "type was previously declared %qE"
 msgstr "型態是在之前宣告 %qE"
 
-#: c-family/c-attribs.c:2841 cp/class.c:4397
+#: c-family/c-attribs.c:2852 cp/class.c:4401
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
 msgstr "只能為函式指定 %qs"
 
-#: c-family/c-attribs.c:2899
+#: c-family/c-attribs.c:2910
 #, fuzzy, gcc-internal-format
 msgid "%qE argument not an identifier"
 msgstr "%qE 引數不是識別碼"
 
-#: c-family/c-attribs.c:2910
+#: c-family/c-attribs.c:2921
 #, fuzzy, gcc-internal-format
 msgid "%qD is not compatible with %qD"
 msgstr "%qD 不是相容與 %qD"
 
-#: c-family/c-attribs.c:2913
+#: c-family/c-attribs.c:2924
 #, fuzzy, gcc-internal-format
 #| msgid "cleanup argument not a function"
 msgid "%qE argument is not a function"
 msgstr "cleanup 引數不是一個函式"
 
-#: c-family/c-attribs.c:2961
+#: c-family/c-attribs.c:2972
 #, fuzzy, gcc-internal-format
 msgid "deprecated message is not a string"
 msgstr "不宜用訊息並非字串"
 
-#: c-family/c-attribs.c:3002
+#: c-family/c-attribs.c:3013
 #, gcc-internal-format
 msgid "%qE attribute ignored for %qE"
 msgstr "%qE 屬性為 %qE 所忽略"
 
-#: c-family/c-attribs.c:3065
+#: c-family/c-attribs.c:3076
 #, gcc-internal-format
 msgid "invalid vector type for attribute %qE"
 msgstr "屬性 %qE 的向量類型無效"
 
-#: c-family/c-attribs.c:3071 ada/gcc-interface/utils.c:3896
+#: c-family/c-attribs.c:3082 ada/gcc-interface/utils.c:3899
 #, fuzzy, gcc-internal-format
 msgid "vector size not an integral multiple of component size"
 msgstr "向量大小不是積分多重的成分大小"
 
-#: c-family/c-attribs.c:3077 ada/gcc-interface/utils.c:3903
+#: c-family/c-attribs.c:3088 ada/gcc-interface/utils.c:3906
 #, fuzzy, gcc-internal-format
 msgid "zero vector size"
 msgstr "零向量大小"
 
-#: c-family/c-attribs.c:3085
+#: c-family/c-attribs.c:3096
 #, gcc-internal-format
 msgid "number of components of the vector not a power of two"
 msgstr "向量中分量數不是 2 的某次方"
 
-#: c-family/c-attribs.c:3118 ada/gcc-interface/utils.c:6092
+#: c-family/c-attribs.c:3129 ada/gcc-interface/utils.c:6098
 #, gcc-internal-format
 msgid "nonnull attribute without arguments on a non-prototype"
 msgstr "非空的屬性在非原型中沒有引數"
 
-#: c-family/c-attribs.c:3137 ada/gcc-interface/utils.c:6106
+#: c-family/c-attribs.c:3148 ada/gcc-interface/utils.c:6112
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument has invalid operand number (argument %lu)"
 msgstr "非空的引數 %lu 運算元號不正確"
 
-#: c-family/c-attribs.c:3159 ada/gcc-interface/utils.c:6128
+#: c-family/c-attribs.c:3170 ada/gcc-interface/utils.c:6134
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument with out-of-range operand number (argument %lu, operand %lu)"
 msgstr "非空的引數運算元號越界(引數 %lu，運算元 %lu)"
 
-#: c-family/c-attribs.c:3168 ada/gcc-interface/utils.c:6137
+#: c-family/c-attribs.c:3179 ada/gcc-interface/utils.c:6143
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument references non-pointer operand (argument %lu, operand %lu)"
 msgstr "非空的引數 %lu 參照了非指標運算元 %lu"
 
-#: c-family/c-attribs.c:3208
+#: c-family/c-attribs.c:3219
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored for field of type %qT"
 msgid "%qE attribute ignored on objects of type %qT"
 msgstr "%qE 屬性為 %qT 型態的欄位所忽略"
 
-#: c-family/c-attribs.c:3216
+#: c-family/c-attribs.c:3227
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute does not apply to functions"
 msgstr "%qE 屬性不套用輸入"
 
-#: c-family/c-attribs.c:3273
+#: c-family/c-attribs.c:3284
 #, gcc-internal-format
 msgid "cleanup argument not an identifier"
 msgstr "cleanup 引數不是一個識別碼"
 
-#: c-family/c-attribs.c:3280
+#: c-family/c-attribs.c:3291
 #, gcc-internal-format
 msgid "cleanup argument not a function"
 msgstr "cleanup 引數不是一個函式"
 
-#: c-family/c-attribs.c:3317
+#: c-family/c-attribs.c:3328
 #, gcc-internal-format
 msgid "%qE attribute requires prototypes with named arguments"
 msgstr "%qE 屬性需要帶具名引數的原型"
 
-#: c-family/c-attribs.c:3325
+#: c-family/c-attribs.c:3336
 #, gcc-internal-format
 msgid "%qE attribute only applies to variadic functions"
 msgstr "%qE 屬性只能用於帶可變參數函式"
 
-#: c-family/c-attribs.c:3341 ada/gcc-interface/utils.c:6179
+#: c-family/c-attribs.c:3352 ada/gcc-interface/utils.c:6185
 #, gcc-internal-format
 msgid "requested position is not an integer constant"
 msgstr "要求的位置不是一個整數常數"
 
-#: c-family/c-attribs.c:3349 ada/gcc-interface/utils.c:6186
+#: c-family/c-attribs.c:3360 ada/gcc-interface/utils.c:6192
 #, gcc-internal-format
 msgid "requested position is less than zero"
 msgstr "要求的位置小於 0"
 
-#: c-family/c-attribs.c:3404
+#: c-family/c-attribs.c:3415
 #, fuzzy, gcc-internal-format
 msgid "empty string in attribute %<target%>"
 msgstr "預期的繫結屬性於 %C"
 
-#: c-family/c-attribs.c:3520
+#: c-family/c-attribs.c:3531
 #, fuzzy, gcc-internal-format
 msgid "returns_nonnull attribute on a function not returning a pointer"
 msgstr "回傳與值在中函式不具任何傳回類型"
 
-#: c-family/c-attribs.c:3535
+#: c-family/c-attribs.c:3546
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is only valid on %<struct%> type"
 msgstr "%qE 屬性只有套用到函數型式"
@@ -27810,13 +27837,13 @@
 msgid "__builtin_shuffle argument vector(s) inner type must have the same size as inner type of the mask"
 msgstr "__builtin_shuffle 引數向量內型態必須有相同大小做為內型態的遮罩"
 
-#: c-family/c-common.c:1262 c-family/c-warn.c:1194
+#: c-family/c-common.c:1262 c-family/c-warn.c:1202
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT discards qualifiers"
 msgid "unsigned conversion from %qT to %qT changes value from %qE to %qE"
 msgstr "從 %qT 到 %qT 的轉換丟失了限定資訊"
 
-#: c-family/c-common.c:1267 c-family/c-warn.c:1202
+#: c-family/c-common.c:1267 c-family/c-warn.c:1210
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "unsigned conversion from %qT to %qT changes the value of %qE"
@@ -27949,7 +27976,7 @@
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "建議在做為真值的賦值敘述前後加上括號"
 
-#: c-family/c-common.c:3518 c/c-decl.c:4325 c/c-decl.c:6430 c/c-typeck.c:14177
+#: c-family/c-common.c:3518 c/c-decl.c:4325 c/c-decl.c:6450 c/c-typeck.c:14182
 #, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr "錯誤地使用了 %<restrict%>"
@@ -28029,7 +28056,7 @@
 msgid "duplicate case value"
 msgstr "重複的 case 常數"
 
-#: c-family/c-common.c:4867 c-family/c-warn.c:2216
+#: c-family/c-common.c:4867 c-family/c-warn.c:2225
 #, fuzzy, gcc-internal-format
 msgid "previously used here"
 msgstr "在之前使用的在此"
@@ -28075,195 +28102,195 @@
 msgid "missing sentinel in function call"
 msgstr "函式呼叫中缺少哨兵"
 
-#: c-family/c-common.c:5411
+#: c-family/c-common.c:5409
 #, gcc-internal-format, gfc-internal-format
 msgid "null argument where non-null required (argument %lu)"
 msgstr "引數為 NULL，需要非 NULL 值(引數 %lu)"
 
-#: c-family/c-common.c:5506 c-family/c-common.c:5553
+#: c-family/c-common.c:5504 c-family/c-common.c:5551
 #, fuzzy, gcc-internal-format
 msgid "bad option %qs to attribute %<optimize%>"
 msgstr "不當的選項 %s 到 pragma 屬性"
 
-#: c-family/c-common.c:5509 c-family/c-common.c:5557
+#: c-family/c-common.c:5507 c-family/c-common.c:5555
 #, fuzzy, gcc-internal-format
 msgid "bad option %qs to pragma %<optimize%>"
 msgstr "不當的選項 %s 到 pragma 屬性"
 
-#: c-family/c-common.c:5589
+#: c-family/c-common.c:5587
 #, gcc-internal-format
 msgid "%<fallthrough%> attribute specified multiple times"
 msgstr ""
 
-#: c-family/c-common.c:5593
+#: c-family/c-common.c:5591
 #, fuzzy, gcc-internal-format
 msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr "預設引數指定的用於 lambda 參數"
 
-#: c-family/c-common.c:5733 c-family/c-common.c:6485 c-family/c-common.c:6558
+#: c-family/c-common.c:5731 c-family/c-common.c:6477 c-family/c-common.c:6550
 #: c/c-typeck.c:3555
 #, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr "提供給函式 %qE 的引數太少"
 
-#: c-family/c-common.c:5738 c-family/c-common.c:6584 c/c-typeck.c:3284
+#: c-family/c-common.c:5736 c-family/c-common.c:6576 c/c-typeck.c:3284
 #, gcc-internal-format
 msgid "too many arguments to function %qE"
 msgstr "提供給函式 %qE 的引數太多"
 
-#: c-family/c-common.c:5769
+#: c-family/c-common.c:5767
 #, fuzzy, gcc-internal-format
 #| msgid "third argument to %<__builtin_prefetch%> must be a constant"
 msgid "third argument to function %qE must be a constant integer"
 msgstr "%<__builtin_prefetch%> 的第三個引數必須是一個常數"
 
-#: c-family/c-common.c:5794
+#: c-family/c-common.c:5792
 #, gcc-internal-format
 msgid "second argument to function %qE must be a constant integer power of 2 between %qi and %qu bits"
 msgstr ""
 
-#: c-family/c-common.c:5815 c-family/c-common.c:5859
+#: c-family/c-common.c:5813 c-family/c-common.c:5857
 #, fuzzy, gcc-internal-format
 msgid "non-floating-point argument in call to function %qE"
 msgstr "non-floating-point 引數在中呼叫到函式 %qE"
 
-#: c-family/c-common.c:5838
+#: c-family/c-common.c:5836
 #, fuzzy, gcc-internal-format
 msgid "non-floating-point arguments in call to function %qE"
 msgstr "non-floating-point 引數在中呼叫到函式 %qE"
 
-#: c-family/c-common.c:5852
+#: c-family/c-common.c:5850
 #, fuzzy, gcc-internal-format
 msgid "non-const integer argument %u in call to function %qE"
 msgstr "non-const 整數引數 %u 在中呼叫到函式 %qE"
 
-#: c-family/c-common.c:5872
+#: c-family/c-common.c:5870
 #, fuzzy, gcc-internal-format
 msgid "non-integer argument 3 in call to function %qE"
 msgstr "non-integer 引數 3 在中呼叫到函式 %qE"
 
-#: c-family/c-common.c:5889 c-family/c-common.c:5925
+#: c-family/c-common.c:5887 c-family/c-common.c:5923
 #, fuzzy, gcc-internal-format
 msgid "argument %u in call to function %qE does not have integral type"
 msgstr "引數 %d 的 %qE 必須是指標類型"
 
-#: c-family/c-common.c:5896
+#: c-family/c-common.c:5894
 #, fuzzy, gcc-internal-format
 msgid "argument 3 in call to function %qE does not have pointer to integral type"
 msgstr "引數 1 的 %qE 必須是指標到常數大小型態"
 
-#: c-family/c-common.c:5902
+#: c-family/c-common.c:5900
 #, fuzzy, gcc-internal-format
 msgid "argument 3 in call to function %qE has pointer to enumerated type"
 msgstr "引數 1 的 %qE 必須是指標到常數大小型態"
 
-#: c-family/c-common.c:5908
+#: c-family/c-common.c:5906
 #, fuzzy, gcc-internal-format
 msgid "argument 3 in call to function %qE has pointer to boolean type"
 msgstr "non-integer 引數 3 在中呼叫到函式 %qE"
 
-#: c-family/c-common.c:5931
+#: c-family/c-common.c:5929
 #, fuzzy, gcc-internal-format
 msgid "argument 3 in call to function %qE has enumerated type"
 msgstr "non-integer 引數 3 在中呼叫到函式 %qE"
 
-#: c-family/c-common.c:5937
+#: c-family/c-common.c:5935
 #, fuzzy, gcc-internal-format
 msgid "argument 3 in call to function %qE has boolean type"
 msgstr "non-integer 引數 3 在中呼叫到函式 %qE"
 
-#: c-family/c-common.c:6184
+#: c-family/c-common.c:6183
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to static data member %qD"
 msgstr "無法套用 %<offsetof%> 到靜態資料成員 %qD"
 
-#: c-family/c-common.c:6189
+#: c-family/c-common.c:6188
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> when %<operator[]%> is overloaded"
 msgstr "無法套用 %<offsetof%> 時 %<運算子 []%>被過載"
 
-#: c-family/c-common.c:6196
+#: c-family/c-common.c:6195
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to a non constant address"
 msgstr "無法套用 %<offsetof%> 到非常數位址"
 
-#: c-family/c-common.c:6209
+#: c-family/c-common.c:6208
 #, gcc-internal-format
 msgid "attempt to take address of bit-field structure member %qD"
 msgstr "試圖取位元段結構成員 %qD 的位址"
 
-#: c-family/c-common.c:6261
+#: c-family/c-common.c:6260
 #, fuzzy, gcc-internal-format
 msgid "index %E denotes an offset greater than size of %qT"
 msgstr "索引 %E 指出偏移大於大小的 %qT"
 
-#: c-family/c-common.c:6427 cp/init.c:3004 cp/init.c:3023
+#: c-family/c-common.c:6419 cp/init.c:3020 cp/init.c:3039
 #, fuzzy, gcc-internal-format
 msgid "size of array is too large"
 msgstr "大小的陣列太大"
 
-#: c-family/c-common.c:6517
+#: c-family/c-common.c:6509
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible type for argument %d of %qE"
 msgid "operand type %qT is incompatible with argument %d of %qE"
 msgstr "引數 %d(屬於 %qE)類型不相容"
 
-#: c-family/c-common.c:6651
+#: c-family/c-common.c:6643
 #, fuzzy, gcc-internal-format
 msgid "incorrect number of arguments to function %qE"
 msgstr "不正確引數數量到函式 %qE"
 
-#: c-family/c-common.c:6665
+#: c-family/c-common.c:6657
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qE must be a non-void pointer type"
 msgstr "引數 1 的 %qE 必須是 non-void 指標類型"
 
-#: c-family/c-common.c:6674
+#: c-family/c-common.c:6666
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a constant size type"
 msgstr "引數 1 的 %qE 必須是指標到常數大小型態"
 
-#: c-family/c-common.c:6685
+#: c-family/c-common.c:6677
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a nonzero size object"
 msgstr "引數 1 的 %qE 必須是指標到非零值大小物件"
 
-#: c-family/c-common.c:6706
+#: c-family/c-common.c:6698
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must be a pointer type"
 msgstr "引數 %d 的 %qE 必須是指標類型"
 
-#: c-family/c-common.c:6714
+#: c-family/c-common.c:6706
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must be a pointer to a constant size type"
 msgstr "引數 1 的 %qE 必須是指標到常數大小型態"
 
-#: c-family/c-common.c:6720
+#: c-family/c-common.c:6712
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a function"
 msgstr "引數 %d 的 %qE 必須是指標類型"
 
-#: c-family/c-common.c:6728
+#: c-family/c-common.c:6720
 #, fuzzy, gcc-internal-format
 msgid "size mismatch in argument %d of %qE"
 msgstr "大小不匹配在中引數 %d 的 %qE"
 
-#: c-family/c-common.c:6740
+#: c-family/c-common.c:6732
 #, fuzzy, gcc-internal-format
 msgid "non-integer memory model argument %d of %qE"
 msgstr "non-integer 記憶體式樣引數 %d 的 %qE"
 
-#: c-family/c-common.c:6753
+#: c-family/c-common.c:6745
 #, fuzzy, gcc-internal-format
 msgid "invalid memory model argument %d of %qE"
 msgstr "無效的記憶體式樣引數 %d 的 %qE"
 
-#: c-family/c-common.c:7672
+#: c-family/c-common.c:7664
 #, fuzzy, gcc-internal-format
 msgid "index value is out of bound"
 msgstr "索引值是超出約束"
 
-#: c-family/c-common.c:7714 c-family/c-common.c:7763 c-family/c-common.c:7779
+#: c-family/c-common.c:7706 c-family/c-common.c:7755 c-family/c-common.c:7771
 #, fuzzy, gcc-internal-format
 msgid "conversion of scalar %qT to vector %qT involves truncation"
 msgstr "轉換的純量到向量牽連出截斷"
@@ -28270,22 +28297,22 @@
 
 #. Reject arguments that are built-in functions with
 #. no library fallback.
-#: c-family/c-common.c:7867
+#: c-family/c-common.c:7859
 #, fuzzy, gcc-internal-format
 msgid "built-in function %qE must be directly called"
 msgstr "內建函式 %qD 需一個引數只有"
 
-#: c-family/c-common.c:7889 c/c-decl.c:6177
+#: c-family/c-common.c:7881 c/c-decl.c:6197
 #, fuzzy, gcc-internal-format
 msgid "size of array %qE is too large"
 msgstr "大小的陣列 %qE 太大"
 
-#: c-family/c-common.c:7891 c/c-decl.c:6180
+#: c-family/c-common.c:7883 c/c-decl.c:6200
 #, fuzzy, gcc-internal-format
 msgid "size of unnamed array is too large"
 msgstr "大小的未命名陣列太大"
 
-#: c-family/c-common.c:7921
+#: c-family/c-common.c:7913
 #, gcc-internal-format
 msgid "environment variable SOURCE_DATE_EPOCH must expand to a non-negative integer less than or equal to %wd"
 msgstr ""
@@ -28812,7 +28839,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr "%<# pragma omp 基元的 capture%>使用兩不同的變數用於記憶體"
 
-#: c-family/c-omp.c:557 cp/semantics.c:8186
+#: c-family/c-omp.c:557 cp/semantics.c:8189
 #, fuzzy, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "無效的型態用於迭代變數 %qE"
@@ -28827,22 +28854,22 @@
 msgid "%qE is not initialized"
 msgstr "%qE 未被初始化的"
 
-#: c-family/c-omp.c:599 cp/semantics.c:8076
+#: c-family/c-omp.c:599 cp/semantics.c:8079
 #, fuzzy, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "缺少控制述詞"
 
-#: c-family/c-omp.c:704 cp/semantics.c:7732
+#: c-family/c-omp.c:704 cp/semantics.c:7735
 #, fuzzy, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "無效的控制述詞"
 
-#: c-family/c-omp.c:711 cp/semantics.c:8082
+#: c-family/c-omp.c:711 cp/semantics.c:8085
 #, fuzzy, gcc-internal-format
 msgid "missing increment expression"
 msgstr "缺少遞增運算式"
 
-#: c-family/c-omp.c:775 cp/semantics.c:7847
+#: c-family/c-omp.c:775 cp/semantics.c:7850
 #, fuzzy, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "無效的遞增運算式"
@@ -28899,112 +28926,127 @@
 msgid "%<-Wabi=1%> is not supported, using =2"
 msgstr "-f%s 不受支援：已忽略"
 
-#: c-family/c-opts.c:612 fortran/cpp.c:350
+#: c-family/c-opts.c:610 fortran/cpp.c:350
 #, gcc-internal-format
 msgid "output filename specified twice"
 msgstr "輸出檔案名稱指定了兩次"
 
-#: c-family/c-opts.c:799
+#: c-family/c-opts.c:797
 #, fuzzy, gcc-internal-format
 msgid "-fexcess-precision=standard for C++"
 msgstr "-fexcess-precision=標準用於 C++"
 
-#: c-family/c-opts.c:834
+#: c-family/c-opts.c:832
 #, fuzzy, gcc-internal-format
 msgid "-fno-gnu89-inline is only supported in GNU99 or C99 mode"
 msgstr "-fno-gnu89-inline 是只有支援的在中 GNU99 或 C99 模式"
 
-#: c-family/c-opts.c:880
+#: c-family/c-opts.c:878
 #, gcc-internal-format
 msgid "-Wformat-y2k ignored without -Wformat"
 msgstr "-Wformat-y2k 未與 -Wformat 一起使用，已忽略"
 
-#: c-family/c-opts.c:882
+#: c-family/c-opts.c:880
 #, gcc-internal-format
 msgid "-Wformat-extra-args ignored without -Wformat"
 msgstr "-Wformat-extra-args 未與 -Wformat 一起使用，已忽略"
 
-#: c-family/c-opts.c:884
+#: c-family/c-opts.c:882
 #, gcc-internal-format
 msgid "-Wformat-zero-length ignored without -Wformat"
 msgstr "-Wformat-zero-length 未與 -Wformat 一起使用，已忽略"
 
-#: c-family/c-opts.c:886
+#: c-family/c-opts.c:884
 #, gcc-internal-format
 msgid "-Wformat-nonliteral ignored without -Wformat"
 msgstr "-Wformat-nonliteral 未與 -Wformat 一起使用，已忽略"
 
-#: c-family/c-opts.c:888
+#: c-family/c-opts.c:886
 #, fuzzy, gcc-internal-format
 msgid "-Wformat-contains-nul ignored without -Wformat"
 msgstr "-Wformat-contains-nul 忽略的而無需 -Wformat"
 
-#: c-family/c-opts.c:890
+#: c-family/c-opts.c:888
 #, gcc-internal-format
 msgid "-Wformat-security ignored without -Wformat"
 msgstr "-Wformat-security 未與 -Wformat 一起使用，已忽略"
 
-#: c-family/c-opts.c:928
+#: c-family/c-opts.c:918
 #, fuzzy, gcc-internal-format
 msgid "%<-fabi-compat-version=1%> is not supported, using =2"
 msgstr "-falign-loops=%d 未被支援"
 
-#: c-family/c-opts.c:988
+#: c-family/c-opts.c:944
+#, gcc-internal-format
+msgid "-Wabi won't warn about anything"
+msgstr ""
+
+#: c-family/c-opts.c:946
+#, gcc-internal-format
+msgid "-Wabi warns about differences from the most up-to-date ABI, which is also used by default"
+msgstr ""
+
+#: c-family/c-opts.c:949
+#, gcc-internal-format
+msgid "use e.g. -Wabi=11 to warn about changes from GCC 7"
+msgstr ""
+
+#: c-family/c-opts.c:1003
 #, fuzzy, gcc-internal-format
 msgid "external TLS initialization functions not supported on this target"
 msgstr "巢狀的函式不支援於這個目標"
 
-#: c-family/c-opts.c:1001
+#: c-family/c-opts.c:1016
 #, gcc-internal-format, gfc-internal-format
 msgid "too many filenames given.  Type %s --help for usage"
 msgstr "給定了太多檔案名稱。試用 %s --help 以了解用法"
 
-#: c-family/c-opts.c:1016
+#: c-family/c-opts.c:1031
 #, gcc-internal-format
 msgid "opening output file %s: %m"
 msgstr "開啟輸出檔案 %s：%m"
 
-#: c-family/c-opts.c:1036
+#: c-family/c-opts.c:1051
 #, gcc-internal-format, gfc-internal-format
 msgid "the \"%s\" debug format cannot be used with pre-compiled headers"
 msgstr ""
 
-#: c-family/c-opts.c:1190
+#: c-family/c-opts.c:1205
 #, gcc-internal-format
 msgid "opening dependency file %s: %m"
 msgstr "開啟依賴檔案 %s：%m"
 
-#: c-family/c-opts.c:1201
+#: c-family/c-opts.c:1216
 #, gcc-internal-format
 msgid "closing dependency file %s: %m"
 msgstr "關閉依賴檔案 %s：%m"
 
-#: c-family/c-opts.c:1204
+#: c-family/c-opts.c:1219
 #, gcc-internal-format
 msgid "when writing output to %s: %m"
 msgstr "當寫入輸出到 %s 時：%m"
 
-#: c-family/c-opts.c:1284
+#: c-family/c-opts.c:1299
 #, gcc-internal-format
 msgid "to generate dependencies you must specify either -M or -MM"
 msgstr "要產生依賴項，您必須指定 -M 或 -MM"
 
-#: c-family/c-opts.c:1307
+#: c-family/c-opts.c:1322
 #, fuzzy, gcc-internal-format
 msgid "-MG may only be used with -M or -MM"
 msgstr "-MG 也許會只有被使用與 -M 或 -MM"
 
-#: c-family/c-opts.c:1340
+#: c-family/c-opts.c:1355
 #, fuzzy, gcc-internal-format
 msgid "-fdirectives-only is incompatible with -Wunused_macros"
 msgstr "-fdirectives-only 是不相容的與 -Wunusedmacros(_M)"
 
-#: c-family/c-opts.c:1342
+#: c-family/c-opts.c:1357
 #, fuzzy, gcc-internal-format
 msgid "-fdirectives-only is incompatible with -traditional"
 msgstr "-fdirectives-only 是不相容的與 -traditional"
 
-#: c-family/c-opts.c:1534
+#: c-family/c-opts.c:1549
 #, gcc-internal-format
 msgid "too late for # directive to set debug directory"
 msgstr "使用 # 指示設定除錯目錄太遲"
@@ -29390,743 +29432,743 @@
 msgid "wrong type argument to %s"
 msgstr "錯誤的型態引數到 %s"
 
-#: c-family/c-warn.c:53 c-family/c-warn.c:66 cp/constexpr.c:1847
+#: c-family/c-warn.c:54 c-family/c-warn.c:67 cp/constexpr.c:1847
 #: cp/constexpr.c:4099
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "常數運算式溢出"
 
-#: c-family/c-warn.c:93
+#: c-family/c-warn.c:94
 #, fuzzy, gcc-internal-format
 #| msgid "integer overflow in expression"
 msgid "integer overflow in expression %qE of type %qT results in %qE"
 msgstr "整數溢出"
 
-#: c-family/c-warn.c:95
+#: c-family/c-warn.c:96
 #, fuzzy, gcc-internal-format
 #| msgid "integer overflow in expression"
 msgid "integer overflow in expression of type %qT results in %qE"
 msgstr "整數溢出"
 
-#: c-family/c-warn.c:101
+#: c-family/c-warn.c:102
 #, fuzzy, gcc-internal-format
 #| msgid "floating point overflow in expression"
 msgid "floating point overflow in expression %qE of type %qT results in %qE"
 msgstr "運算式中浮點溢出"
 
-#: c-family/c-warn.c:103
+#: c-family/c-warn.c:104
 #, fuzzy, gcc-internal-format
 #| msgid "floating point overflow in expression"
 msgid "floating point overflow in expression of type %qT results in %qE"
 msgstr "運算式中浮點溢出"
 
-#: c-family/c-warn.c:109
+#: c-family/c-warn.c:110
 #, fuzzy, gcc-internal-format
 msgid "fixed-point overflow in expression %qE of type %qT results in %qE"
 msgstr "定點溢位在中運算式"
 
-#: c-family/c-warn.c:111
+#: c-family/c-warn.c:112
 #, fuzzy, gcc-internal-format
 msgid "fixed-point overflow in expression of type %qT results in %qE"
 msgstr "定點溢位在中運算式"
 
-#: c-family/c-warn.c:117
+#: c-family/c-warn.c:118
 #, fuzzy, gcc-internal-format
 #| msgid "vector overflow in expression"
 msgid "vector overflow in expression %qE of type %qT results in %qE"
 msgstr "向量浮點溢出"
 
-#: c-family/c-warn.c:119
+#: c-family/c-warn.c:120
 #, fuzzy, gcc-internal-format
 #| msgid "vector overflow in expression"
 msgid "vector overflow in expression of type %qT results in %qE"
 msgstr "向量浮點溢出"
 
-#: c-family/c-warn.c:126
+#: c-family/c-warn.c:127
 #, fuzzy, gcc-internal-format
 msgid "complex integer overflow in expression %qE of type %qT results in %qE"
 msgstr "複雜整數溢位在中運算式"
 
-#: c-family/c-warn.c:128
+#: c-family/c-warn.c:129
 #, fuzzy, gcc-internal-format
 msgid "complex integer overflow in expression of type %qT results in %qE"
 msgstr "複雜整數溢位在中運算式"
 
-#: c-family/c-warn.c:132
+#: c-family/c-warn.c:133
 #, fuzzy, gcc-internal-format
 msgid "complex floating point overflow in expression %qE of type %qT results in %qE"
 msgstr "複雜浮點數溢位在中運算式"
 
-#: c-family/c-warn.c:134
+#: c-family/c-warn.c:135
 #, fuzzy, gcc-internal-format
 msgid "complex floating point overflow in expression of type %qT results in %qE"
 msgstr "複雜浮點數溢位在中運算式"
 
-#: c-family/c-warn.c:216
+#: c-family/c-warn.c:217
 #, fuzzy, gcc-internal-format
 msgid "logical %<or%> applied to non-boolean constant"
 msgstr "邏輯的 %<or%> 套用到 non-boolean 常數"
 
-#: c-family/c-warn.c:219
+#: c-family/c-warn.c:220
 #, fuzzy, gcc-internal-format
 msgid "logical %<and%> applied to non-boolean constant"
 msgstr "邏輯的 %<and%> 套用到 non-boolean 常數"
 
-#: c-family/c-warn.c:289
+#: c-family/c-warn.c:290
 #, fuzzy, gcc-internal-format
 msgid "logical %<or%> of collectively exhaustive tests is always true"
 msgstr "邏輯的 %<or%> 的 collectively exhaustive 測試是一律真"
 
-#: c-family/c-warn.c:293
+#: c-family/c-warn.c:294
 #, fuzzy, gcc-internal-format
 msgid "logical %<and%> of mutually exclusive tests is always false"
 msgstr "邏輯的 %<and%> 的互斥測試是一律假"
 
-#: c-family/c-warn.c:303
+#: c-family/c-warn.c:304
 #, fuzzy, gcc-internal-format
 msgid "logical %<or%> of equal expressions"
 msgstr "無效的運算元在中一元運算式"
 
-#: c-family/c-warn.c:306
+#: c-family/c-warn.c:307
 #, fuzzy, gcc-internal-format
 msgid "logical %<and%> of equal expressions"
 msgstr "邏輯的 %<and%> 的互斥測試是一律假"
 
-#: c-family/c-warn.c:384
+#: c-family/c-warn.c:385
 #, gcc-internal-format
 msgid "bitwise comparison always evaluates to false"
 msgstr ""
 
-#: c-family/c-warn.c:387
+#: c-family/c-warn.c:388
 #, fuzzy, gcc-internal-format
 msgid "bitwise comparison always evaluates to true"
 msgstr "位址的 %qD 將一律評估做為 %<true%>"
 
-#: c-family/c-warn.c:441
+#: c-family/c-warn.c:442
 #, fuzzy, gcc-internal-format
 #| msgid "user-defined %qD always evaluates both arguments"
 msgid "self-comparison always evaluates to true"
 msgstr "使用者定義的 %qD 總是計算所有兩個參數"
 
-#: c-family/c-warn.c:444
+#: c-family/c-warn.c:445
 #, fuzzy, gcc-internal-format
 #| msgid "user-defined %qD always evaluates both arguments"
 msgid "self-comparison always evaluates to false"
 msgstr "使用者定義的 %qD 總是計算所有兩個參數"
 
-#: c-family/c-warn.c:494
+#: c-family/c-warn.c:495
 #, gcc-internal-format
 msgid "logical not is only applied to the left hand side of comparison"
 msgstr ""
 
-#: c-family/c-warn.c:502
+#: c-family/c-warn.c:503
 #, gcc-internal-format
 msgid "add parentheses around left hand side expression to silence this warning"
 msgstr ""
 
-#: c-family/c-warn.c:636
+#: c-family/c-warn.c:637
 #, gcc-internal-format
 msgid "type-punning to incomplete type might break strict-aliasing rules"
 msgstr "類型雙關作用在不完全類型上可能破壞強重疊規則"
 
-#: c-family/c-warn.c:654
+#: c-family/c-warn.c:655
 #, gcc-internal-format
 msgid "dereferencing type-punned pointer will break strict-aliasing rules"
 msgstr "提領類型雙關的指標將破壞強重疊規則"
 
-#: c-family/c-warn.c:662 c-family/c-warn.c:680
+#: c-family/c-warn.c:663 c-family/c-warn.c:681
 #, gcc-internal-format
 msgid "dereferencing type-punned pointer might break strict-aliasing rules"
 msgstr "提領類型雙關的指標可能破壞強重疊規則"
 
-#: c-family/c-warn.c:803
+#: c-family/c-warn.c:811
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to use the size of the destination?"
 msgstr ""
 
-#: c-family/c-warn.c:834
+#: c-family/c-warn.c:842
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the destination; did you mean to remove the addressof?"
 msgstr ""
 
-#: c-family/c-warn.c:841
+#: c-family/c-warn.c:849
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the destination; did you mean to provide an explicit length?"
 msgstr ""
 
-#: c-family/c-warn.c:846
+#: c-family/c-warn.c:854
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the destination; did you mean to dereference it?"
 msgstr ""
 
-#: c-family/c-warn.c:858
+#: c-family/c-warn.c:866
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the destination; expected %qT or an explicit length"
 msgstr ""
 
-#: c-family/c-warn.c:874
+#: c-family/c-warn.c:882
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to remove the addressof?"
 msgstr ""
 
-#: c-family/c-warn.c:881
+#: c-family/c-warn.c:889
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to provide an explicit length?"
 msgstr ""
 
-#: c-family/c-warn.c:886
+#: c-family/c-warn.c:894
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to dereference it?"
 msgstr ""
 
-#: c-family/c-warn.c:898
+#: c-family/c-warn.c:906
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the source; expected %qT or an explicit length"
 msgstr ""
 
-#: c-family/c-warn.c:914
+#: c-family/c-warn.c:922
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the first source; did you mean to remove the addressof?"
 msgstr ""
 
-#: c-family/c-warn.c:921
+#: c-family/c-warn.c:929
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the first source; did you mean to provide an explicit length?"
 msgstr ""
 
-#: c-family/c-warn.c:926
+#: c-family/c-warn.c:934
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the first source; did you mean to dereference it?"
 msgstr ""
 
-#: c-family/c-warn.c:938
+#: c-family/c-warn.c:946
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the first source; expected %qT or an explicit length"
 msgstr ""
 
-#: c-family/c-warn.c:954
+#: c-family/c-warn.c:962
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the second source; did you mean to remove the addressof?"
 msgstr ""
 
-#: c-family/c-warn.c:961
+#: c-family/c-warn.c:969
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the second source; did you mean to provide an explicit length?"
 msgstr ""
 
-#: c-family/c-warn.c:966
+#: c-family/c-warn.c:974
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the second source; did you mean to dereference it?"
 msgstr ""
 
-#: c-family/c-warn.c:978
+#: c-family/c-warn.c:986
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the second source; expected %qT or an explicit length"
 msgstr ""
 
-#: c-family/c-warn.c:1007 c-family/c-warn.c:1014
+#: c-family/c-warn.c:1015 c-family/c-warn.c:1022
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter type %qT"
 msgid "%<_Atomic%>-qualified parameter type %qT of %q+D"
 msgstr "無效的參數類型 %qT"
 
-#: c-family/c-warn.c:1024
+#: c-family/c-warn.c:1032
 #, gcc-internal-format
 msgid "first argument of %q+D should be %<int%>"
 msgstr "%q+D 的第一個參數的類型應該是 %<int%>"
 
-#: c-family/c-warn.c:1033
+#: c-family/c-warn.c:1041
 #, gcc-internal-format
 msgid "second argument of %q+D should be %<char **%>"
 msgstr "%q+D 的第二個參數類型應該是 %<char **%>"
 
-#: c-family/c-warn.c:1042
+#: c-family/c-warn.c:1050
 #, gcc-internal-format
 msgid "third argument of %q+D should probably be %<char **%>"
 msgstr "%q+D 如果有第三個參數，類型應該是 %<char **%>"
 
-#: c-family/c-warn.c:1053
+#: c-family/c-warn.c:1061
 #, gcc-internal-format
 msgid "%q+D takes only zero or two arguments"
 msgstr "%q+D 只帶零或兩個參數"
 
-#: c-family/c-warn.c:1057
+#: c-family/c-warn.c:1065
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared as variadic function"
 msgstr "欄位 %qE 宣告的做為函式"
 
-#: c-family/c-warn.c:1099
+#: c-family/c-warn.c:1107
 #, fuzzy, gcc-internal-format
 msgid "conversion to %qT from boolean expression"
 msgstr "轉換到 %qT 從布林表示式"
 
-#: c-family/c-warn.c:1117 c-family/c-warn.c:1192
+#: c-family/c-warn.c:1125 c-family/c-warn.c:1200
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT discards qualifiers"
 msgid "conversion from %qT to %qT changes value from %qE to %qE"
 msgstr "從 %qT 到 %qT 的轉換丟失了限定資訊"
 
-#: c-family/c-warn.c:1121 c-family/c-warn.c:1200
+#: c-family/c-warn.c:1129 c-family/c-warn.c:1208
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "conversion from %qT to %qT changes the value of %qE"
 msgstr "從 %qT 到 %qT 的轉換有歧義"
 
-#: c-family/c-warn.c:1141
+#: c-family/c-warn.c:1149
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT discards qualifiers"
 msgid "conversion from %qT to %qT discards imaginary component"
 msgstr "從 %qT 到 %qT 的轉換丟失了限定資訊"
 
-#: c-family/c-warn.c:1153
+#: c-family/c-warn.c:1161
 #, fuzzy, gcc-internal-format
 msgid "conversion from %qT to %qT may change value"
 msgstr "轉換到 %qT 從 %qT 也許會改變它的值"
 
-#: c-family/c-warn.c:1213 c-family/c-warn.c:1230 c-family/c-warn.c:1247
+#: c-family/c-warn.c:1221 c-family/c-warn.c:1238 c-family/c-warn.c:1255
 #, fuzzy, gcc-internal-format
 msgid "overflow in conversion from %qT to %qT changes value from %qE to %qE"
 msgstr "隱含轉換從 %qT 到 %qT 時傳遞引數到函式"
 
-#: c-family/c-warn.c:1218 c-family/c-warn.c:1235 c-family/c-warn.c:1252
+#: c-family/c-warn.c:1226 c-family/c-warn.c:1243 c-family/c-warn.c:1260
 #, fuzzy, gcc-internal-format
 msgid "overflow in conversion from %qT to %qT changes the value of %qE"
 msgstr "narrowing 轉換的 %qE 從 %qT 到 %qT 內部 {}"
 
-#: c-family/c-warn.c:1282
+#: c-family/c-warn.c:1290
 #, fuzzy, gcc-internal-format
 msgid "case value %qs not in enumerated type"
 msgstr "大小寫值 %qs 無法在中列舉型式"
 
-#: c-family/c-warn.c:1287
+#: c-family/c-warn.c:1295
 #, fuzzy, gcc-internal-format
 msgid "case value %qs not in enumerated type %qT"
 msgstr "大小寫值 %qs 無法在中列舉型式 %qT"
 
-#: c-family/c-warn.c:1348
+#: c-family/c-warn.c:1356
 #, fuzzy, gcc-internal-format
 msgid "switch missing default case"
 msgstr "切換缺少的預設大小寫"
 
-#: c-family/c-warn.c:1393
+#: c-family/c-warn.c:1401
 #, gcc-internal-format
 msgid "switch condition has boolean value"
 msgstr ""
 
-#: c-family/c-warn.c:1466
+#: c-family/c-warn.c:1474
 #, fuzzy, gcc-internal-format
 msgid "enumeration value %qE not handled in switch"
 msgstr "列舉類型值 %qE 無法控柄的在中切換"
 
-#: c-family/c-warn.c:1494
+#: c-family/c-warn.c:1502
 #, fuzzy, gcc-internal-format
 msgid "the omitted middle operand in ?: will always be %<true%>, suggest explicit middle operand"
 msgstr "省略的中間運算元在中 ?:將一律是 %<true%>，建議明確的中間運算元"
 
-#: c-family/c-warn.c:1515
+#: c-family/c-warn.c:1523
 #, fuzzy, gcc-internal-format
 msgid "assignment of member %qD in read-only object"
 msgstr "指派的成員 %qD 在中唯讀物件"
 
-#: c-family/c-warn.c:1517
+#: c-family/c-warn.c:1525
 #, fuzzy, gcc-internal-format
 msgid "increment of member %qD in read-only object"
 msgstr "遞增的成員 %qD 在中唯讀物件"
 
-#: c-family/c-warn.c:1519
+#: c-family/c-warn.c:1527
 #, fuzzy, gcc-internal-format
 msgid "decrement of member %qD in read-only object"
 msgstr "遞減的成員 %qD 在中唯讀物件"
 
-#: c-family/c-warn.c:1521
+#: c-family/c-warn.c:1529
 #, fuzzy, gcc-internal-format
 msgid "member %qD in read-only object used as %<asm%> output"
 msgstr "成員 %qD 在中唯讀物件使用的做為 %<asm%> 輸出"
 
-#: c-family/c-warn.c:1525
+#: c-family/c-warn.c:1533
 #, gcc-internal-format
 msgid "assignment of read-only member %qD"
 msgstr "向唯讀成員 %qD 賦值"
 
-#: c-family/c-warn.c:1526
+#: c-family/c-warn.c:1534
 #, gcc-internal-format
 msgid "increment of read-only member %qD"
 msgstr "令唯讀成員 %qD 自增"
 
-#: c-family/c-warn.c:1527
+#: c-family/c-warn.c:1535
 #, gcc-internal-format
 msgid "decrement of read-only member %qD"
 msgstr "令唯讀成員 %qD 自減"
 
-#: c-family/c-warn.c:1528
+#: c-family/c-warn.c:1536
 #, gcc-internal-format
 msgid "read-only member %qD used as %<asm%> output"
 msgstr "唯讀成員 %qD 做為 %<asm%> 的輸出"
 
-#: c-family/c-warn.c:1532
+#: c-family/c-warn.c:1540
 #, gcc-internal-format
 msgid "assignment of read-only variable %qD"
 msgstr "向唯讀變數 %qD 賦值"
 
-#: c-family/c-warn.c:1533
+#: c-family/c-warn.c:1541
 #, gcc-internal-format
 msgid "increment of read-only variable %qD"
 msgstr "令唯讀變數 %qD 自增"
 
-#: c-family/c-warn.c:1534
+#: c-family/c-warn.c:1542
 #, gcc-internal-format
 msgid "decrement of read-only variable %qD"
 msgstr "令唯讀成員 %qD 自增"
 
-#: c-family/c-warn.c:1535
+#: c-family/c-warn.c:1543
 #, gcc-internal-format
 msgid "read-only variable %qD used as %<asm%> output"
 msgstr "唯讀變數 %qD 做為 %<asm%> 的輸出"
 
-#: c-family/c-warn.c:1538
+#: c-family/c-warn.c:1546
 #, fuzzy, gcc-internal-format
 msgid "assignment of read-only parameter %qD"
 msgstr "指派的唯讀參數 %qD"
 
-#: c-family/c-warn.c:1539
+#: c-family/c-warn.c:1547
 #, fuzzy, gcc-internal-format
 msgid "increment of read-only parameter %qD"
 msgstr "遞增的唯讀參數 %qD"
 
-#: c-family/c-warn.c:1540
+#: c-family/c-warn.c:1548
 #, fuzzy, gcc-internal-format
 msgid "decrement of read-only parameter %qD"
 msgstr "遞減的唯讀參數 %qD"
 
-#: c-family/c-warn.c:1541
+#: c-family/c-warn.c:1549
 #, fuzzy, gcc-internal-format
 msgid "read-only parameter %qD use as %<asm%> output"
 msgstr "唯讀參數 %qD 做為 %<asm%> 輸出"
 
-#: c-family/c-warn.c:1546
+#: c-family/c-warn.c:1554
 #, fuzzy, gcc-internal-format
 msgid "assignment of read-only named return value %qD"
 msgstr "指派的唯讀具名的傳回值 %qD"
 
-#: c-family/c-warn.c:1548
+#: c-family/c-warn.c:1556
 #, fuzzy, gcc-internal-format
 msgid "increment of read-only named return value %qD"
 msgstr "遞增的唯讀具名的傳回值 %qD"
 
-#: c-family/c-warn.c:1550
+#: c-family/c-warn.c:1558
 #, fuzzy, gcc-internal-format
 msgid "decrement of read-only named return value %qD"
 msgstr "遞減的唯讀具名的傳回值 %qD"
 
-#: c-family/c-warn.c:1552
+#: c-family/c-warn.c:1560
 #, fuzzy, gcc-internal-format
 msgid "read-only named return value %qD used as %<asm%>output"
 msgstr "唯讀具名的傳回值 %qD 使用的做為 %<asm%>輸出"
 
-#: c-family/c-warn.c:1557
+#: c-family/c-warn.c:1565
 #, fuzzy, gcc-internal-format
 msgid "assignment of function %qD"
 msgstr "指派的函式 %qD"
 
-#: c-family/c-warn.c:1558
+#: c-family/c-warn.c:1566
 #, fuzzy, gcc-internal-format
 msgid "increment of function %qD"
 msgstr "遞增的函式 %qD"
 
-#: c-family/c-warn.c:1559
+#: c-family/c-warn.c:1567
 #, fuzzy, gcc-internal-format
 msgid "decrement of function %qD"
 msgstr "遞減的函式 %qD"
 
-#: c-family/c-warn.c:1560
+#: c-family/c-warn.c:1568
 #, fuzzy, gcc-internal-format
 msgid "function %qD used as %<asm%> output"
 msgstr "函式 %qD 使用的做為 %<asm%> 輸出"
 
-#: c-family/c-warn.c:1563 c/c-typeck.c:4762
+#: c-family/c-warn.c:1571 c/c-typeck.c:4767
 #, fuzzy, gcc-internal-format
 msgid "assignment of read-only location %qE"
 msgstr "指派的唯讀位置 %qE"
 
-#: c-family/c-warn.c:1564 c/c-typeck.c:4765
+#: c-family/c-warn.c:1572 c/c-typeck.c:4770
 #, fuzzy, gcc-internal-format
 msgid "increment of read-only location %qE"
 msgstr "遞增的唯讀位置 %qE"
 
-#: c-family/c-warn.c:1565 c/c-typeck.c:4768
+#: c-family/c-warn.c:1573 c/c-typeck.c:4773
 #, fuzzy, gcc-internal-format
 msgid "decrement of read-only location %qE"
 msgstr "遞減的唯讀位置 %qE"
 
-#: c-family/c-warn.c:1566
+#: c-family/c-warn.c:1574
 #, fuzzy, gcc-internal-format
 msgid "read-only location %qE used as %<asm%> output"
 msgstr "唯讀位置 %qE 使用的做為 %<asm%> 輸出"
 
-#: c-family/c-warn.c:1580
+#: c-family/c-warn.c:1588
 #, fuzzy, gcc-internal-format
 msgid "lvalue required as left operand of assignment"
 msgstr "lvalue 必要項做為向左運算元的指派"
 
-#: c-family/c-warn.c:1583
+#: c-family/c-warn.c:1591
 #, fuzzy, gcc-internal-format
 msgid "lvalue required as increment operand"
 msgstr "lvalue 必要項做為遞增運算元"
 
-#: c-family/c-warn.c:1586
+#: c-family/c-warn.c:1594
 #, fuzzy, gcc-internal-format
 msgid "lvalue required as decrement operand"
 msgstr "lvalue 必要項做為遞減運算元"
 
-#: c-family/c-warn.c:1589
+#: c-family/c-warn.c:1597
 #, fuzzy, gcc-internal-format
 msgid "lvalue required as unary %<&%> operand"
 msgstr "lvalue 必要項做為一元 %<&%>運算元"
 
-#: c-family/c-warn.c:1592
+#: c-family/c-warn.c:1600
 #, fuzzy, gcc-internal-format
 msgid "lvalue required in asm statement"
 msgstr "lvalue 必要項在中 asm 敘述"
 
-#: c-family/c-warn.c:1609
+#: c-family/c-warn.c:1617
 #, fuzzy, gcc-internal-format
 msgid "invalid type argument (have %qT)"
 msgstr "無效的型態引數 (有 %qT)"
 
-#: c-family/c-warn.c:1613
+#: c-family/c-warn.c:1621
 #, fuzzy, gcc-internal-format
 msgid "invalid type argument of array indexing (have %qT)"
 msgstr "無效的型態引數的陣列索引 (有 %qT)"
 
-#: c-family/c-warn.c:1618
+#: c-family/c-warn.c:1626
 #, fuzzy, gcc-internal-format
 msgid "invalid type argument of unary %<*%> (have %qT)"
 msgstr "無效的型態引數的一元 %<*%>(有 %qT)"
 
-#: c-family/c-warn.c:1623
+#: c-family/c-warn.c:1631
 #, fuzzy, gcc-internal-format
 msgid "invalid type argument of %<->%> (have %qT)"
 msgstr "無效的型態引數的 %<->%> (有 %qT)"
 
-#: c-family/c-warn.c:1628
+#: c-family/c-warn.c:1636
 #, fuzzy, gcc-internal-format
 msgid "invalid type argument of %<->*%> (have %qT)"
 msgstr "無效的型態引數的 %<->%> (有 %qT)"
 
-#: c-family/c-warn.c:1633
+#: c-family/c-warn.c:1641
 #, fuzzy, gcc-internal-format
 msgid "invalid type argument of implicit conversion (have %qT)"
 msgstr "無效的型態引數的隱含轉換 (有 %qT)"
 
-#: c-family/c-warn.c:1654
+#: c-family/c-warn.c:1662
 #, gcc-internal-format
 msgid "array subscript has type %<char%>"
 msgstr "陣列下標類型為 %<char%>"
 
-#: c-family/c-warn.c:1689 c-family/c-warn.c:1692
+#: c-family/c-warn.c:1697 c-family/c-warn.c:1700
 #, fuzzy, gcc-internal-format
 msgid "suggest parentheses around %<+%> inside %<<<%>"
 msgstr "建議 parentheses 周圍 %<+%>內部 %<<<%>"
 
-#: c-family/c-warn.c:1695 c-family/c-warn.c:1698
+#: c-family/c-warn.c:1703 c-family/c-warn.c:1706
 #, fuzzy, gcc-internal-format
 msgid "suggest parentheses around %<-%> inside %<<<%>"
 msgstr "建議 parentheses 周圍 %<-%> 內部 %<<<%>"
 
-#: c-family/c-warn.c:1704 c-family/c-warn.c:1707
+#: c-family/c-warn.c:1712 c-family/c-warn.c:1715
 #, fuzzy, gcc-internal-format
 msgid "suggest parentheses around %<+%> inside %<>>%>"
 msgstr "建議 parentheses 周圍 %<+%>內部 %<>>%>"
 
-#: c-family/c-warn.c:1710 c-family/c-warn.c:1713
+#: c-family/c-warn.c:1718 c-family/c-warn.c:1721
 #, fuzzy, gcc-internal-format
 msgid "suggest parentheses around %<-%> inside %<>>%>"
 msgstr "建議 parentheses 周圍 %<-%> 內部 %<>>%>"
 
-#: c-family/c-warn.c:1719 c-family/c-warn.c:1722
+#: c-family/c-warn.c:1727 c-family/c-warn.c:1730
 #, fuzzy, gcc-internal-format
 msgid "suggest parentheses around %<&&%> within %<||%>"
 msgstr "建議 parentheses 周圍 %<&&%>在之內 %<||%>"
 
-#: c-family/c-warn.c:1729 c-family/c-warn.c:1733
+#: c-family/c-warn.c:1737 c-family/c-warn.c:1741
 #, fuzzy, gcc-internal-format
 msgid "suggest parentheses around arithmetic in operand of %<|%>"
 msgstr "建議 parentheses 周圍算術在中運算元的 %<|%>"
 
-#: c-family/c-warn.c:1737 c-family/c-warn.c:1740
+#: c-family/c-warn.c:1745 c-family/c-warn.c:1748
 #, fuzzy, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<|%>"
 msgstr "建議 parentheses 周圍比較在中運算元的 %<|%>"
 
-#: c-family/c-warn.c:1745
+#: c-family/c-warn.c:1753
 #, fuzzy, gcc-internal-format
 msgid "suggest parentheses around operand of %<!%> or change %<|%> to %<||%> or %<!%> to %<~%>"
 msgstr "建議 parentheses 周圍運算元的 %<!%>或變更 %<|%>到 %<||%>或 %<!%>到 %<~%>"
 
-#: c-family/c-warn.c:1753 c-family/c-warn.c:1757
+#: c-family/c-warn.c:1761 c-family/c-warn.c:1765
 #, fuzzy, gcc-internal-format
 msgid "suggest parentheses around arithmetic in operand of %<^%>"
 msgstr "建議 parentheses 周圍算術在中運算元的 %<^%>"
 
-#: c-family/c-warn.c:1761 c-family/c-warn.c:1764
+#: c-family/c-warn.c:1769 c-family/c-warn.c:1772
 #, fuzzy, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<^%>"
 msgstr "建議 parentheses 周圍比較在中運算元的 %<^%>"
 
-#: c-family/c-warn.c:1770 c-family/c-warn.c:1773
+#: c-family/c-warn.c:1778 c-family/c-warn.c:1781
 #, fuzzy, gcc-internal-format
 msgid "suggest parentheses around %<+%> in operand of %<&%>"
 msgstr "建議 parentheses 周圍 %<+%>在中運算元的 %<&%>"
 
-#: c-family/c-warn.c:1776 c-family/c-warn.c:1779
+#: c-family/c-warn.c:1784 c-family/c-warn.c:1787
 #, fuzzy, gcc-internal-format
 msgid "suggest parentheses around %<-%> in operand of %<&%>"
 msgstr "建議 parentheses 周圍 %<-%> 在中運算元的 %<&%>"
 
-#: c-family/c-warn.c:1783 c-family/c-warn.c:1786
+#: c-family/c-warn.c:1791 c-family/c-warn.c:1794
 #, fuzzy, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<&%>"
 msgstr "建議 parentheses 周圍比較在中運算元的 %<&%>"
 
-#: c-family/c-warn.c:1791
+#: c-family/c-warn.c:1799
 #, fuzzy, gcc-internal-format
 msgid "suggest parentheses around operand of %<!%> or change %<&%> to %<&&%> or %<!%> to %<~%>"
 msgstr "建議 parentheses 周圍運算元的 %<!%>或變更 %<&%>到 %<&&%>或 %<!%>到 %<~%>"
 
-#: c-family/c-warn.c:1798 c-family/c-warn.c:1801
+#: c-family/c-warn.c:1806 c-family/c-warn.c:1809
 #, fuzzy, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<==%>"
 msgstr "建議 parentheses 周圍比較在中運算元的 %<==%>"
 
-#: c-family/c-warn.c:1806 c-family/c-warn.c:1809
+#: c-family/c-warn.c:1814 c-family/c-warn.c:1817
 #, fuzzy, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<!=%>"
 msgstr "建議 parentheses 周圍比較在中運算元的 %<!=%>"
 
-#: c-family/c-warn.c:1819 c-family/c-warn.c:1825
+#: c-family/c-warn.c:1827 c-family/c-warn.c:1833
 #, fuzzy, gcc-internal-format
 msgid "comparisons like %<X<=Y<=Z%> do not have their mathematical meaning"
 msgstr "比較如同 %<X<=Y<=Z%> 沒有它們的數學的平均"
 
-#: c-family/c-warn.c:1841
+#: c-family/c-warn.c:1849
 #, gcc-internal-format
 msgid "label %q+D defined but not used"
 msgstr "標籤 %q+D 定義後未使用"
 
-#: c-family/c-warn.c:1843
+#: c-family/c-warn.c:1851
 #, gcc-internal-format
 msgid "label %q+D declared but not defined"
 msgstr "標籤 %q+D 宣告後未定義"
 
-#: c-family/c-warn.c:1866
+#: c-family/c-warn.c:1874
 #, gcc-internal-format
 msgid "division by zero"
 msgstr "被零除"
 
-#: c-family/c-warn.c:1886
+#: c-family/c-warn.c:1894
 #, gcc-internal-format
 msgid "%<memset%> used with constant zero length parameter; this could be due to transposed parameters"
 msgstr ""
 
-#: c-family/c-warn.c:1909
+#: c-family/c-warn.c:1918
 #, gcc-internal-format
 msgid "%<memset%> used with length equal to number of elements without multiplication by element size"
 msgstr ""
 
-#: c-family/c-warn.c:1948 c/c-typeck.c:11499 c/c-typeck.c:11667
+#: c-family/c-warn.c:1957 c/c-typeck.c:11504 c/c-typeck.c:11672
 #: cp/typeck.c:5048
 #, fuzzy, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr "比較介於類型 %qT 和 %qT"
 
-#: c-family/c-warn.c:1998
+#: c-family/c-warn.c:2007
 #, gcc-internal-format
 msgid "comparison of integer expressions of different signedness: %qT and %qT"
 msgstr ""
 
-#: c-family/c-warn.c:2051
+#: c-family/c-warn.c:2060
 #, fuzzy, gcc-internal-format
 msgid "promoted ~unsigned is always non-zero"
 msgstr "升級 ~ 無正負號是一律非零"
 
-#: c-family/c-warn.c:2054
+#: c-family/c-warn.c:2063
 #, gcc-internal-format
 msgid "comparison of promoted ~unsigned with constant"
 msgstr "比較常數和取反後又經提升的無號數"
 
-#: c-family/c-warn.c:2064
+#: c-family/c-warn.c:2073
 #, gcc-internal-format
 msgid "comparison of promoted ~unsigned with unsigned"
 msgstr "比較無號數和取反後又經提升的無號數"
 
-#: c-family/c-warn.c:2118
+#: c-family/c-warn.c:2127
 #, fuzzy, gcc-internal-format
 #| msgid "unused parameter %q+D"
 msgid "unused parameter %qD"
 msgstr "未使用的參數 %q+D"
 
-#: c-family/c-warn.c:2180
+#: c-family/c-warn.c:2189
 #, fuzzy, gcc-internal-format
 msgid "typedef %qD locally defined but not used"
 msgstr "typedef %qD 局部地定義的並不是使用"
 
-#: c-family/c-warn.c:2215
+#: c-family/c-warn.c:2224
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<const%>"
 msgid "duplicated %<if%> condition"
 msgstr "重複的 %<const%>"
 
-#: c-family/c-warn.c:2244
+#: c-family/c-warn.c:2253
 #, gcc-internal-format
 msgid "optimization attribute on %qD follows definition but the attribute doesn%'t match"
 msgstr ""
 
-#: c-family/c-warn.c:2254
+#: c-family/c-warn.c:2261
 #, fuzzy, gcc-internal-format
 #| msgid "inline declaration of %qD follows declaration with attribute noinline"
 msgid "inline declaration of %qD follows declaration with attribute %qs"
 msgstr "%q+D 帶有 noinline 屬性的宣告出現在其內聯宣告之後"
 
-#: c-family/c-warn.c:2259
+#: c-family/c-warn.c:2266
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D with attribute noinline follows inline declaration "
 msgid "declaration of %q+D with attribute %qs follows inline declaration"
 msgstr "%q+D 帶有 noinline 屬性的宣告出現在其內聯宣告之後"
 
-#: c-family/c-warn.c:2306
+#: c-family/c-warn.c:2313
 #, gcc-internal-format
 msgid "result of %qE requires %u bits to represent, but %qT only has %u bits"
 msgstr ""
 
-#: c-family/c-warn.c:2344 c-family/c-warn.c:2368
+#: c-family/c-warn.c:2351 c-family/c-warn.c:2375
 #, fuzzy, gcc-internal-format
 #| msgid "comparison of unsigned expression < 0 is always false"
 msgid "comparison of constant %qE with boolean expression is always false"
 msgstr "無號運算式永遠不小於 0"
 
-#: c-family/c-warn.c:2347 c-family/c-warn.c:2365
+#: c-family/c-warn.c:2354 c-family/c-warn.c:2372
 #, fuzzy, gcc-internal-format
 #| msgid "comparison of unsigned expression >= 0 is always true"
 msgid "comparison of constant %qE with boolean expression is always true"
 msgstr "無號運算式永遠大於或等於 0"
 
-#: c-family/c-warn.c:2415
+#: c-family/c-warn.c:2422
 #, fuzzy
 msgid "passing argument %i to restrict-qualified parameter aliases with argument %Z"
 msgid_plural "passing argument %i to restrict-qualified parameter aliases with arguments %Z"
 msgstr[0] "傳遞引數 %d 的 %qE 捨棄 %qv 限定元從指標目標類型"
 
-#: c-family/c-warn.c:2480 c/c-typeck.c:5288 cp/call.c:5365
+#: c-family/c-warn.c:2487 c/c-typeck.c:5293 cp/call.c:5365
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr ""
 
-#: c-family/c-warn.c:2586
+#: c-family/c-warn.c:2593
 #, gcc-internal-format
 msgid "macro expands to multiple statements"
 msgstr ""
 
-#: c-family/c-warn.c:2587
+#: c-family/c-warn.c:2594
 #, gcc-internal-format
 msgid "some parts of macro expansion are not guarded by this %qs clause"
 msgstr ""
@@ -30141,7 +30183,7 @@
 msgid "too many input files"
 msgstr "輸入檔案太多"
 
-#: common/config/aarch64/aarch64-common.c:319 config/aarch64/aarch64.c:10686
+#: common/config/aarch64/aarch64-common.c:319 config/aarch64/aarch64.c:10702
 #, fuzzy, gcc-internal-format
 msgid "unknown value %qs for -mcpu"
 msgstr "-mcpu 開關的值 %qs 錯誤"
@@ -30173,13 +30215,13 @@
 msgstr ""
 
 #: common/config/arm/arm-common.c:322 common/config/arm/arm-common.c:376
-#: common/config/arm/arm-common.c:423 config/aarch64/aarch64.c:10639
+#: common/config/arm/arm-common.c:423 config/aarch64/aarch64.c:10655
 #, fuzzy, gcc-internal-format
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr "有效引數到 %qs 是：%s"
 
 #: common/config/arm/arm-common.c:325 common/config/arm/arm-common.c:379
-#: common/config/arm/arm-common.c:426 config/aarch64/aarch64.c:10642
+#: common/config/arm/arm-common.c:426 config/aarch64/aarch64.c:10658
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s"
 msgstr "有效引數到 %qs 是：%s"
@@ -30657,12 +30699,12 @@
 msgid "profiler support for VxWorks"
 msgstr "對 VxWorks 的取樣支援"
 
-#: config/aarch64/aarch64-builtins.c:1109 config/arm/arm-builtins.c:2262
+#: config/aarch64/aarch64-builtins.c:1109 config/arm/arm-builtins.c:2272
 #, fuzzy, gcc-internal-format
 msgid "%Kargument %d must be a constant immediate"
 msgstr "引數必須是常數"
 
-#: config/aarch64/aarch64-builtins.c:1180 config/arm/arm-builtins.c:2492
+#: config/aarch64/aarch64-builtins.c:1180 config/arm/arm-builtins.c:2502
 #, fuzzy, gcc-internal-format
 #| msgid "mask must be an immediate"
 msgid "%Klane index must be a constant immediate"
@@ -30673,177 +30715,177 @@
 msgid "%Ktotal size and element size must be a non-zero constant immediate"
 msgstr ""
 
-#: config/aarch64/aarch64.c:1053
+#: config/aarch64/aarch64.c:1069
 #, fuzzy, gcc-internal-format
 msgid "%qs is incompatible with %s %s"
 msgstr "%qs 是不相容的與 %qs"
 
-#: config/aarch64/aarch64.c:1055
+#: config/aarch64/aarch64.c:1071
 #, fuzzy, gcc-internal-format
 msgid "%qs feature modifier is incompatible with %s %s"
 msgstr "%qs 是不相容的與 %qs"
 
-#: config/aarch64/aarch64.c:3772
+#: config/aarch64/aarch64.c:3788
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10287
+#: config/aarch64/aarch64.c:10303
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown flag passed in -moverride=%s (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10331
+#: config/aarch64/aarch64.c:10347
 #, gcc-internal-format, gfc-internal-format
 msgid "%s string ill-formed\n"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10388
+#: config/aarch64/aarch64.c:10404
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr "無效的範圍 %s 在中選項 %s"
 
-#: config/aarch64/aarch64.c:10406
+#: config/aarch64/aarch64.c:10422
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown tuning option (%s)"
 msgstr "不明 spec 函式 %qs"
 
-#: config/aarch64/aarch64.c:10683
+#: config/aarch64/aarch64.c:10699
 #, fuzzy, gcc-internal-format
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr "%qs 後缺少路徑"
 
-#: config/aarch64/aarch64.c:10690
+#: config/aarch64/aarch64.c:10706
 #, fuzzy, gcc-internal-format
 msgid "invalid feature modifier in %<-mcpu=%s%>"
 msgstr "%qs 後缺少檔案名稱"
 
-#: config/aarch64/aarch64.c:10717
+#: config/aarch64/aarch64.c:10733
 #, fuzzy, gcc-internal-format
 msgid "missing arch name in %<-march=%s%>"
 msgstr "%qs 後缺少路徑"
 
-#: config/aarch64/aarch64.c:10720
+#: config/aarch64/aarch64.c:10736
 #, fuzzy, gcc-internal-format
 msgid "unknown value %qs for -march"
 msgstr "不明值 %qs 的 -mmacosx-version-min"
 
-#: config/aarch64/aarch64.c:10724
+#: config/aarch64/aarch64.c:10740
 #, fuzzy, gcc-internal-format
 msgid "invalid feature modifier in %<-march=%s%>"
 msgstr "%qs 後缺少檔案名稱"
 
-#: config/aarch64/aarch64.c:10750
+#: config/aarch64/aarch64.c:10766
 #, fuzzy, gcc-internal-format
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr "%qs 後缺少路徑"
 
-#: config/aarch64/aarch64.c:10753
+#: config/aarch64/aarch64.c:10769
 #, fuzzy, gcc-internal-format
 msgid "unknown value %qs for -mtune"
 msgstr "不當的值 %qs 用於 -mtune 切換"
 
-#: config/aarch64/aarch64.c:10871 config/arm/arm.c:3173
+#: config/aarch64/aarch64.c:10887 config/arm/arm.c:3173
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "switch -mcpu=%s conflicts with -march=%s switch"
 msgstr "切換 -mcpu=%s 衝突與 -march=%s 切換"
 
-#: config/aarch64/aarch64.c:10906
+#: config/aarch64/aarch64.c:10922
 #, fuzzy, gcc-internal-format
 #| msgid "does not support multilib"
 msgid "assembler does not support -mabi=ilp32"
 msgstr "不支援 multilib"
 
-#: config/aarch64/aarch64.c:10913
+#: config/aarch64/aarch64.c:10929
 #, gcc-internal-format
 msgid "return address signing is only supported for -mabi=lp64"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10975
+#: config/aarch64/aarch64.c:10991
 #, gcc-internal-format
 msgid "code model %qs with -f%s"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11138
+#: config/aarch64/aarch64.c:11154
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11141
+#: config/aarch64/aarch64.c:11157
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11145 config/aarch64/aarch64.c:11184
-#: config/aarch64/aarch64.c:11257
+#: config/aarch64/aarch64.c:11161 config/aarch64/aarch64.c:11200
+#: config/aarch64/aarch64.c:11273
 #, gcc-internal-format
 msgid "invalid value (\"%s\") in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11177
+#: config/aarch64/aarch64.c:11193
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11180
+#: config/aarch64/aarch64.c:11196
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11213
+#: config/aarch64/aarch64.c:11229
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"tune=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11253
+#: config/aarch64/aarch64.c:11269
 #, fuzzy, gcc-internal-format
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr "缺少%<=%>(之後 %<getter%>屬性)missing %<=%> (after %<getter%> attribute)缺少%<=%>(之後 %<getter%>屬性)"
 
-#: config/aarch64/aarch64.c:11306 config/aarch64/aarch64.c:11483
+#: config/aarch64/aarch64.c:11322 config/aarch64/aarch64.c:11499
 #, fuzzy, gcc-internal-format
 #| msgid "malformed %<#pragma init%>"
 msgid "malformed %<target()%> pragma or attribute"
 msgstr "%<#pragma init%> 格式錯誤"
 
-#: config/aarch64/aarch64.c:11354
+#: config/aarch64/aarch64.c:11370
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11362
+#: config/aarch64/aarch64.c:11378
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11416
+#: config/aarch64/aarch64.c:11432
 #, fuzzy, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr "屬性 (目標 (「%s」)) 為未知"
 
-#: config/aarch64/aarch64.c:11473 config/arm/arm.c:30742
-#: config/i386/i386.c:5440 config/powerpcspe/powerpcspe.c:39760
-#: config/rs6000/rs6000.c:36904 config/s390/s390.c:15746
+#: config/aarch64/aarch64.c:11489 config/arm/arm.c:30742
+#: config/i386/i386.c:5443 config/powerpcspe/powerpcspe.c:39760
+#: config/rs6000/rs6000.c:36960 config/s390/s390.c:15746
 #, fuzzy, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "屬性 %qE 引數不是字串"
 
-#: config/aarch64/aarch64.c:11500
+#: config/aarch64/aarch64.c:11516
 #, fuzzy, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr "屬性 (目標 (「%s」)) 為未知"
 
-#: config/aarch64/aarch64.c:11509
+#: config/aarch64/aarch64.c:11525
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13571
+#: config/aarch64/aarch64.c:13587
 #, fuzzy, gcc-internal-format
 msgid "%Klane %wd out of range %wd - %wd"
 msgstr "運算元號超出範圍"
 
-#: config/aarch64/aarch64.c:13573
+#: config/aarch64/aarch64.c:13589
 #, fuzzy, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr "運算元號超出範圍"
@@ -30903,8 +30945,8 @@
 msgid "bad value %qs for -mmemory-latency"
 msgstr "-mmemory-latency 開關的值 %qs 錯誤"
 
-#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6526
-#: config/arc/arc.c:6800 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
+#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6517
+#: config/arc/arc.c:6791 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
 #: config/tilepro/tilepro.c:3108
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -31018,11 +31060,11 @@
 #: config/arm/arm.c:7029 config/avr/avr.c:9718 config/avr/avr.c:9734
 #: config/bfin/bfin.c:4705 config/bfin/bfin.c:4766 config/bfin/bfin.c:4795
 #: config/epiphany/epiphany.c:491 config/h8300/h8300.c:5459
-#: config/i386/i386.c:6452 config/i386/i386.c:12479 config/i386/i386.c:41424
-#: config/i386/i386.c:41474 config/i386/i386.c:41544 config/m68k/m68k.c:780
+#: config/i386/i386.c:6455 config/i386/i386.c:12482 config/i386/i386.c:41418
+#: config/i386/i386.c:41468 config/i386/i386.c:41538 config/m68k/m68k.c:780
 #: config/mcore/mcore.c:3070 config/nvptx/nvptx.c:4611
 #: config/powerpcspe/powerpcspe.c:35785 config/riscv/riscv.c:2698
-#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:32982
+#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:33038
 #: config/rx/rx.c:2719 config/rx/rx.c:2745 config/s390/s390.c:1056
 #: config/s390/s390.c:1143 config/sh/sh.c:8428 config/sh/sh.c:8446
 #: config/sh/sh.c:8470 config/sh/sh.c:8541 config/sh/sh.c:8564
@@ -31032,139 +31074,139 @@
 msgid "%qE attribute only applies to functions"
 msgstr "%qE 屬性只有套用到函式"
 
-#: config/arc/arc.c:6425
+#: config/arc/arc.c:6416
 #, fuzzy, gcc-internal-format
 #| msgid "%<__builtin_next_arg%> called without an argument"
 msgid "__builtin_arc_aligned with non-constant alignment"
 msgstr "呼叫 %<__builtin_next_arg%> 時沒有給定引數"
 
-#: config/arc/arc.c:6433
+#: config/arc/arc.c:6424
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to %<__builtin_frame_address%>"
 msgid "invalid alignment value for __builtin_arc_aligned"
 msgstr "%<__builtin_frame_address%> 的引數無效"
 
-#: config/arc/arc.c:6596
+#: config/arc/arc.c:6587
 #, fuzzy, gcc-internal-format
 msgid "operand 1 should be an unsigned 3-bit immediate"
 msgstr "-mcorea 應該被使用與 -mmulticore"
 
-#: config/arc/arc.c:6637 config/arc/arc.c:6734
+#: config/arc/arc.c:6628 config/arc/arc.c:6725
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6670 config/arc/arc.c:6702
+#: config/arc/arc.c:6661 config/arc/arc.c:6693
 #, gcc-internal-format
 msgid "operand 1 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6674 config/arc/arc.c:6706
+#: config/arc/arc.c:6665 config/arc/arc.c:6697
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 8-bit value"
 msgstr ""
 
-#: config/arc/arc.c:6738
+#: config/arc/arc.c:6729
 #, gcc-internal-format
 msgid "operand 3 should be an unsigned 8-bit value"
 msgstr ""
 
-#: config/arc/arc.c:6771
+#: config/arc/arc.c:6762
 #, gcc-internal-format
 msgid "operand 4 should be an unsigned 8-bit value (0-255)"
 msgstr ""
 
-#: config/arc/arc.c:6775
+#: config/arc/arc.c:6766
 #, gcc-internal-format
 msgid "operand 3 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6782
+#: config/arc/arc.c:6773
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (subreg 0-7)"
 msgstr ""
 
-#: config/arc/arc.c:6785
+#: config/arc/arc.c:6776
 #, gcc-internal-format
 msgid "operand 2 should be an even 3-bit value (subreg 0,2,4,6)"
 msgstr ""
 
-#: config/arc/arc.c:6832
+#: config/arc/arc.c:6823
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "builtin requires an immediate for operand %d"
 msgstr "符號使用的做為即時運算元"
 
-#: config/arc/arc.c:6837
+#: config/arc/arc.c:6828
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "operand %d should be a 6 bit unsigned immediate"
 msgstr "引數 2 必須是一個 5 位無號字面值"
 
-#: config/arc/arc.c:6841
+#: config/arc/arc.c:6832
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "operand %d should be a 8 bit unsigned immediate"
 msgstr "引數 2 必須是一個 5 位無號字面值"
 
-#: config/arc/arc.c:6845
+#: config/arc/arc.c:6836
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "operand %d should be a 3 bit unsigned immediate"
 msgstr "引數 2 必須是一個 5 位無號字面值"
 
-#: config/arc/arc.c:6848
+#: config/arc/arc.c:6839
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown builtin immediate operand type for operand %d"
 msgstr ""
 
-#: config/arc/arc.c:6899
+#: config/arc/arc.c:6890
 #, gcc-internal-format
 msgid "register number must be a compile-time constant. Try giving higher optimization levels"
 msgstr ""
 
-#: config/arc/arc.c:7685
+#: config/arc/arc.c:7747
 #, gcc-internal-format
 msgid "Insn addresses not set after shorten_branches"
 msgstr ""
 
-#: config/arc/arc.c:7894
+#: config/arc/arc.c:7956
 #, fuzzy, gcc-internal-format
 msgid "insn addresses not freed"
 msgstr "不當的位址，無法暫存器："
 
-#: config/arc/arc.c:10682
+#: config/arc/arc.c:10670
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only valid for ARCv2 architecture"
 msgstr "%qE 屬性只有可見於 32-bit"
 
-#: config/arc/arc.c:10690 config/arc/arc.c:10729
+#: config/arc/arc.c:10678 config/arc/arc.c:10717
 #, fuzzy, gcc-internal-format
 msgid "argument of %qE attribute is missing"
 msgstr "引數的 %qE 屬性並非字串常數"
 
-#: config/arc/arc.c:10701 config/arc/arc.c:10740 config/arc/arc.c:10842
+#: config/arc/arc.c:10689 config/arc/arc.c:10728 config/arc/arc.c:10830
 #: config/avr/avr.c:9790
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute allows only an integer constant argument"
 msgstr "%qE 屬性允許只有整數常數引數"
 
-#: config/arc/arc.c:10721
+#: config/arc/arc.c:10709
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only valid for ARC EM architecture"
 msgstr "%qE 屬性只有可見於 32-bit"
 
-#: config/arc/arc.c:10776
+#: config/arc/arc.c:10764
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only applies to types"
 msgstr "%qE 屬性只有套用到函數型式"
 
-#: config/arc/arc.c:10782
+#: config/arc/arc.c:10770
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored"
 msgid "argument of %qE attribute ignored"
 msgstr "%qE 屬性被忽略"
 
-#: config/arc/arc.c:10832 config/avr/avr.c:9777 config/bfin/bfin.c:4827
+#: config/arc/arc.c:10820 config/avr/avr.c:9777 config/bfin/bfin.c:4827
 #: config/i386/winnt.c:63 config/msp430/msp430.c:2018
 #: config/nvptx/nvptx.c:4634
 #, fuzzy, gcc-internal-format
@@ -31171,175 +31213,175 @@
 msgid "%qE attribute only applies to variables"
 msgstr "%qE 屬性只有套用到變數"
 
-#: config/arm/arm-builtins.c:2370
+#: config/arm/arm-builtins.c:2380
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "this builtin is not supported for this target"
 msgstr "-fdata-sections 在此目標平臺上不受支援"
 
-#: config/arm/arm-builtins.c:2475
+#: config/arm/arm-builtins.c:2485
 #, gcc-internal-format
 msgid "You must enable NEON instructions (e.g. -mfloat-abi=softfp -mfpu=neon) to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2513
+#: config/arm/arm-builtins.c:2523
 #, gcc-internal-format
 msgid "You must enable VFP instructions to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2573
+#: config/arm/arm-builtins.c:2583
 #, gcc-internal-format
 msgid "You must enable crypto instructions (e.g. include -mfloat-abi=softfp -mfpu=crypto-neon...) to use these intrinsics."
 msgstr ""
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:2633 config/arm/arm-builtins.c:2737
+#: config/arm/arm-builtins.c:2643 config/arm/arm-builtins.c:2747
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr "選擇子必須是立即數值"
 
-#: config/arm/arm-builtins.c:2641 config/arm/arm-builtins.c:2686
-#: config/arm/arm-builtins.c:2744 config/arm/arm-builtins.c:2753
+#: config/arm/arm-builtins.c:2651 config/arm/arm-builtins.c:2696
+#: config/arm/arm-builtins.c:2754 config/arm/arm-builtins.c:2763
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2646 config/arm/arm-builtins.c:2755
+#: config/arm/arm-builtins.c:2656 config/arm/arm-builtins.c:2765
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2651 config/arm/arm-builtins.c:2757
+#: config/arm/arm-builtins.c:2661 config/arm/arm-builtins.c:2767
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2823
+#: config/arm/arm-builtins.c:2833
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr "遮罩必須是一個立即數值"
 
-#: config/arm/arm-builtins.c:2828
+#: config/arm/arm-builtins.c:2838
 #, fuzzy, gcc-internal-format
 msgid "the range of mask should be in 0 to 255"
 msgstr "%qE 屬性引數應該被介於 0 到 255"
 
-#: config/arm/arm-builtins.c:3016
+#: config/arm/arm-builtins.c:3026
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3018
+#: config/arm/arm-builtins.c:3028
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3020
+#: config/arm/arm-builtins.c:3030
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3022
+#: config/arm/arm-builtins.c:3032
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3028
+#: config/arm/arm-builtins.c:3038
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3030
+#: config/arm/arm-builtins.c:3040
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3035
+#: config/arm/arm-builtins.c:3045
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3037
+#: config/arm/arm-builtins.c:3047
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3039
+#: config/arm/arm-builtins.c:3049
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3041
+#: config/arm/arm-builtins.c:3051
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3043
+#: config/arm/arm-builtins.c:3053
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3045
+#: config/arm/arm-builtins.c:3055
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3047
+#: config/arm/arm-builtins.c:3057
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3049
+#: config/arm/arm-builtins.c:3059
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3051
+#: config/arm/arm-builtins.c:3061
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3053
+#: config/arm/arm-builtins.c:3063
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3055
+#: config/arm/arm-builtins.c:3065
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3057
+#: config/arm/arm-builtins.c:3067
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3059
+#: config/arm/arm-builtins.c:3069
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3061
+#: config/arm/arm-builtins.c:3071
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3063
+#: config/arm/arm-builtins.c:3073
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3065
+#: config/arm/arm-builtins.c:3075
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3067
+#: config/arm/arm-builtins.c:3077
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3069
+#: config/arm/arm-builtins.c:3079
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr ""
@@ -32258,17 +32300,17 @@
 msgid "can%'t set position in PCH file: %m"
 msgstr "can%'t 設定位置在中 PCH 檔案：%m"
 
-#: config/i386/i386.c:3177
+#: config/i386/i386.c:3180
 #, fuzzy, gcc-internal-format
 msgid "wrong argument %qs to option %qs"
 msgstr "無法辨識的引數在中選項 %qs"
 
-#: config/i386/i386.c:3183
+#: config/i386/i386.c:3186
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr ""
 
-#: config/i386/i386.c:3193
+#: config/i386/i386.c:3196
 #, fuzzy, gcc-internal-format
 #| msgid "register name not specified for %q+D"
 msgid "wrong strategy name %qs specified for option %qs"
@@ -32275,547 +32317,547 @@
 msgstr "%q+D 的暫存器名無效"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3219
+#: config/i386/i386.c:3222
 #, fuzzy, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr "-mstringop-strategy=rep_8 位元組不支援用於 32-bit 編碼"
 
-#: config/i386/i386.c:3232
+#: config/i386/i386.c:3235
 #, fuzzy, gcc-internal-format
 msgid "unknown alignment %qs specified for option %qs"
 msgstr "對齊指定的用於函式 %qE"
 
-#: config/i386/i386.c:3242
+#: config/i386/i386.c:3245
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr ""
 
-#: config/i386/i386.c:3249
+#: config/i386/i386.c:3252
 #, fuzzy, gcc-internal-format
 #| msgid "no class name specified with %qs"
 msgid "too many size ranges specified in option %qs"
 msgstr "%qs 沒有指定類別名"
 
-#: config/i386/i386.c:3302
+#: config/i386/i386.c:3305
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unknown register name: %s"
 msgid "unknown parameter to option -mtune-ctrl: %s"
 msgstr "不明的暫存器名：%s"
 
-#: config/i386/i386.c:3726
+#: config/i386/i386.c:3729
 #, fuzzy, gcc-internal-format
 #| msgid "64-bit ABI not supported in ESA/390 mode"
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "64-bit ABI 在 ESA/390 模式下不受支援"
 
-#: config/i386/i386.c:3775
+#: config/i386/i386.c:3778
 #, fuzzy, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "%stune =x86-64%s 被不宜用；使用 %stune=k8%s 或 %stune=generic%s 做為替代做為適當"
 
-#: config/i386/i386.c:3777
+#: config/i386/i386.c:3780
 #, fuzzy, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr "%stune =x86-64%s 被不宜用；使用 %stune=k8%s 或 %stune=generic%s 做為替代做為適當"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3804
+#: config/i386/i386.c:3807
 #, fuzzy, gcc-internal-format
 msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgstr "-mstringop-strategy=rep_8 位元組不支援用於 32-bit 編碼"
 
-#: config/i386/i386.c:3821
+#: config/i386/i386.c:3824
 #, fuzzy, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "程式碼模式 %qs 在 %s 位模式下不受支援"
 
-#: config/i386/i386.c:3833
+#: config/i386/i386.c:3836
 #, fuzzy, gcc-internal-format
 msgid "-mabi=ms not supported with X32 ABI"
 msgstr "-f%s 不受支援：已忽略"
 
-#: config/i386/i386.c:3851 config/i386/i386.c:3860 config/i386/i386.c:3872
-#: config/i386/i386.c:3883 config/i386/i386.c:3894
+#: config/i386/i386.c:3854 config/i386/i386.c:3863 config/i386/i386.c:3875
+#: config/i386/i386.c:3886 config/i386/i386.c:3897
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "程式碼模式 %qs 在 %s 位模式下不受支援"
 
-#: config/i386/i386.c:3863 config/i386/i386.c:3875
+#: config/i386/i386.c:3866 config/i386/i386.c:3878
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "編碼式樣 %qs 不支援在中 x32 模式"
 
-#: config/i386/i386.c:3881 config/i386/i386.c:3890 config/i386/i386.c:5213
+#: config/i386/i386.c:3884 config/i386/i386.c:3893 config/i386/i386.c:5216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "編碼式樣 %s 不支援 PIC 模式"
 
-#: config/i386/i386.c:3918
+#: config/i386/i386.c:3921
 #, fuzzy, gcc-internal-format
 msgid "-masm=intel not supported in this configuration"
 msgstr "-masm=intel 不支援在中這個組態"
 
-#: config/i386/i386.c:3923
+#: config/i386/i386.c:3926
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "未編譯入對 %i 位模式的支援"
 
-#: config/i386/i386.c:3932
+#: config/i386/i386.c:3935
 #, fuzzy, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr "通用 CPU 可以被使用只有用於 %stune=%s %s"
 
-#: config/i386/i386.c:3934
+#: config/i386/i386.c:3937
 #, fuzzy, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "通用 CPU 可以被使用只有用於 %stune=%s %s"
 
-#: config/i386/i386.c:3941
+#: config/i386/i386.c:3944
 #, fuzzy, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr "通用 CPU 可以被使用只有用於 %stune=%s %s"
 
-#: config/i386/i386.c:3943
+#: config/i386/i386.c:3946
 #, fuzzy, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "通用 CPU 可以被使用只有用於 %stune=%s %s"
 
-#: config/i386/i386.c:3951 config/i386/i386.c:4265
+#: config/i386/i386.c:3954 config/i386/i386.c:4268
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "您選擇的 CPU 不支援 x86-64 指令集"
 
-#: config/i386/i386.c:4197 config/i386/i386.c:4200
+#: config/i386/i386.c:4200 config/i386/i386.c:4203
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "Intel MPX does not support x32"
 msgstr "%s 不支援 %s"
 
-#: config/i386/i386.c:4205
+#: config/i386/i386.c:4208
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "bad value (%qs) for %<-march=%> switch"
 msgstr "-march= 所帶參數(%s)不正確"
 
-#: config/i386/i386.c:4206
+#: config/i386/i386.c:4209
 #, fuzzy, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"arch=\")%> attribute"
 msgstr "不當的值 (%s) 用於 %sarch=%s %s"
 
-#: config/i386/i386.c:4228
+#: config/i386/i386.c:4231
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "有效引數到 %qs 是：%s"
 
-#: config/i386/i386.c:4230
+#: config/i386/i386.c:4233
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4235
+#: config/i386/i386.c:4238
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "有效引數到 %qs 是：%s"
 
-#: config/i386/i386.c:4236
+#: config/i386/i386.c:4239
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "有效引數到 %qs 是：%s"
 
-#: config/i386/i386.c:4284
+#: config/i386/i386.c:4287
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -mtune= switch"
 msgid "bad value (%qs) for %<-mtune=%> switch"
 msgstr "-mtune= 所帶參數(%s)不正確"
 
-#: config/i386/i386.c:4285
+#: config/i386/i386.c:4288
 #, fuzzy, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"tune=\")%> attribute"
 msgstr "不當的值 (%s) 用於 %stune=%s %s"
 
-#: config/i386/i386.c:4305
+#: config/i386/i386.c:4308
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "有效引數到 %qs 是：%s"
 
-#: config/i386/i386.c:4307
+#: config/i386/i386.c:4310
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4312
+#: config/i386/i386.c:4315
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "有效引數到 %qs 是：%s"
 
-#: config/i386/i386.c:4313
+#: config/i386/i386.c:4316
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "有效引數到 %qs 是：%s"
 
-#: config/i386/i386.c:4379
+#: config/i386/i386.c:4382
 #, fuzzy, gcc-internal-format
 msgid "-mregparm is ignored in 64-bit mode"
 msgstr "-mregparm 被忽略在中 64-bit 模式"
 
-#: config/i386/i386.c:4381
+#: config/i386/i386.c:4384
 #, fuzzy, gcc-internal-format
 msgid "-mregparm is ignored for Intel MCU psABI"
 msgstr "-mregparm 被忽略在中 64-bit 模式"
 
-#: config/i386/i386.c:4384
+#: config/i386/i386.c:4387
 #, gcc-internal-format, gfc-internal-format
 msgid "-mregparm=%d is not between 0 and %d"
 msgstr "-mregparm=%d 不在 0 和 %d 之間"
 
-#: config/i386/i386.c:4417
+#: config/i386/i386.c:4420
 #, fuzzy, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "%srtd%s 被忽略在中 64 位元模式"
 
-#: config/i386/i386.c:4418
+#: config/i386/i386.c:4421
 #, fuzzy, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "%srtd%s 被忽略在中 64 位元模式"
 
-#: config/i386/i386.c:4497
+#: config/i386/i386.c:4500
 #, fuzzy, gcc-internal-format
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "-mpreferred-stack-boundary 未被支援用於這個目標"
 
-#: config/i386/i386.c:4500
+#: config/i386/i386.c:4503
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d 未被介於 %d 和 %d"
 
-#: config/i386/i386.c:4523
+#: config/i386/i386.c:4526
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr "-mincoming-stack-boundary=%d 未被介於 %d 和 12"
 
-#: config/i386/i386.c:4536
+#: config/i386/i386.c:4539
 #, fuzzy, gcc-internal-format
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "-mno-fentry isn%'t 相容與 SEH"
 
-#: config/i386/i386.c:4539
+#: config/i386/i386.c:4542
 #, fuzzy, gcc-internal-format
 #| msgid "inter-module optimizations not implemented for C++"
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr "模組間最佳化淍未為 C++ 實作"
 
-#: config/i386/i386.c:4545
+#: config/i386/i386.c:4548
 #, fuzzy, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "%ssseregparm%s 使用的而無需 SSE 已啟用"
 
-#: config/i386/i386.c:4546
+#: config/i386/i386.c:4549
 #, fuzzy, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "%ssseregparm%s 使用的而無需 SSE 已啟用"
 
-#: config/i386/i386.c:4556
+#: config/i386/i386.c:4559
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "SSE 指令集已停用，使用 387 指令"
 
-#: config/i386/i386.c:4563
+#: config/i386/i386.c:4566
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "387 指令集已停用，使用 SSE 指令"
 
-#: config/i386/i386.c:4613
+#: config/i386/i386.c:4616
 #, fuzzy, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr "堆疊試探需求 %saccumulate-outgoing-args%s 用於 correctness"
 
-#: config/i386/i386.c:4615
+#: config/i386/i386.c:4618
 #, fuzzy, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr "堆疊試探需求 %saccumulate-outgoing-args%s 用於 correctness"
 
-#: config/i386/i386.c:4629
+#: config/i386/i386.c:4632
 #, fuzzy, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr "堆疊試探需求 %saccumulate-outgoing-args%s 用於 correctness"
 
-#: config/i386/i386.c:4631
+#: config/i386/i386.c:4634
 #, fuzzy, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr "堆疊試探需求 %saccumulate-outgoing-args%s 用於 correctness"
 
-#: config/i386/i386.c:4741
+#: config/i386/i386.c:4744
 #, fuzzy, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr "-mfentry isn%'t 支援的用於 32-bit 在中組合與 -fpic"
 
-#: config/i386/i386.c:4744
+#: config/i386/i386.c:4747
 #, fuzzy, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr "-mno-fentry isn%'t 相容與 SEH"
 
-#: config/i386/i386.c:4748
+#: config/i386/i386.c:4751
 #, gcc-internal-format
 msgid "-mcall-ms2sysv-xlogues isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386.c:4813 config/powerpcspe/powerpcspe.c:5663
+#: config/i386/i386.c:4816 config/powerpcspe/powerpcspe.c:5663
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown option for -mrecip=%s"
 msgstr "不明選項用於 -mrecip=%s"
 
-#: config/i386/i386.c:4870 config/powerpcspe/powerpcspe.c:5339
+#: config/i386/i386.c:4873 config/powerpcspe/powerpcspe.c:5339
 #, gcc-internal-format
 msgid "%qs is not a valid number in -mstack-protector-guard-offset="
 msgstr ""
 
-#: config/i386/i386.c:4875 config/powerpcspe/powerpcspe.c:5344
+#: config/i386/i386.c:4878 config/powerpcspe/powerpcspe.c:5344
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid offset in -mstack-protector-guard-offset="
 msgstr "%qs 並非有效選項到前置處理器"
 
-#: config/i386/i386.c:4907 config/powerpcspe/powerpcspe.c:5356
+#: config/i386/i386.c:4910 config/powerpcspe/powerpcspe.c:5356
 #, gcc-internal-format
 msgid "%qs is not a valid base register in -mstack-protector-guard-reg="
 msgstr ""
 
-#: config/i386/i386.c:5506 config/i386/i386.c:5553 config/s390/s390.c:15812
+#: config/i386/i386.c:5509 config/i386/i386.c:5556 config/s390/s390.c:15812
 #: config/s390/s390.c:15862 config/s390/s390.c:15879
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr "屬性 (目標 (「%s」)) 為未知"
 
-#: config/i386/i386.c:5534
+#: config/i386/i386.c:5537
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr "選項 (「%s」) 已經指定的"
 
-#: config/i386/i386.c:5837
+#: config/i386/i386.c:5840
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and cdecl attributes are not compatible"
 msgid "interrupt and naked attributes are not compatible"
 msgstr "stdcall 和 cdecl 屬性互不相容"
 
-#: config/i386/i386.c:5852
+#: config/i386/i386.c:5855
 #, gcc-internal-format
 msgid "Only DWARF debug format is supported for interrupt service routine."
 msgstr ""
 
-#: config/i386/i386.c:5901
+#: config/i386/i386.c:5904
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s 與 -mcall-%s 互不相容"
 
-#: config/i386/i386.c:5913
+#: config/i386/i386.c:5916
 #, gcc-internal-format
 msgid "%<-mindirect-branch=thunk-extern%>, %<-fcf-protection=branch%> and %<-fcheck-pointer-bounds%> are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5949
+#: config/i386/i386.c:5952
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s 與 -mcall-%s 互不相容"
 
-#: config/i386/i386.c:6047
+#: config/i386/i386.c:6050
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in %s service routine"
 msgstr "2 位元組 cop 指令未被允許在中 64-bit VLIW 模式"
 
-#: config/i386/i386.c:6051
+#: config/i386/i386.c:6054
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in function with no_caller_saved_registers attribute"
 msgstr ""
 
-#: config/i386/i386.c:6465 config/i386/i386.c:6516
+#: config/i386/i386.c:6468 config/i386/i386.c:6519
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "fastcall 和 regparm 屬性互不相容"
 
-#: config/i386/i386.c:6470
+#: config/i386/i386.c:6473
 #, fuzzy, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "regparam 和 thiscall 屬性不是相容"
 
-#: config/i386/i386.c:6477 config/i386/i386.c:41444
+#: config/i386/i386.c:6480 config/i386/i386.c:41438
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "%qE 屬性需求整數常數引數"
 
-#: config/i386/i386.c:6483
+#: config/i386/i386.c:6486
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "引數到 %qE 屬性大於 %d"
 
-#: config/i386/i386.c:6508 config/i386/i386.c:6551
+#: config/i386/i386.c:6511 config/i386/i386.c:6554
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "fastcall 和 cdecl 屬性互不相容"
 
-#: config/i386/i386.c:6512
+#: config/i386/i386.c:6515
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "fastcall 和 stdcall 屬性互不相容"
 
-#: config/i386/i386.c:6520 config/i386/i386.c:6569
+#: config/i386/i386.c:6523 config/i386/i386.c:6572
 #, fuzzy, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "fastcall 和 thiscall 屬性不是相容"
 
-#: config/i386/i386.c:6530 config/i386/i386.c:6547
+#: config/i386/i386.c:6533 config/i386/i386.c:6550
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "stdcall 和 cdecl 屬性互不相容"
 
-#: config/i386/i386.c:6534
+#: config/i386/i386.c:6537
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "stdcall 和 fastcall 屬性互不相容"
 
-#: config/i386/i386.c:6538 config/i386/i386.c:6565
+#: config/i386/i386.c:6541 config/i386/i386.c:6568
 #, fuzzy, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "stdcall 和 thiscall 屬性不是相容"
 
-#: config/i386/i386.c:6555 config/i386/i386.c:6573
+#: config/i386/i386.c:6558 config/i386/i386.c:6576
 #, fuzzy, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "cdecl 和 thiscall 屬性不是相容"
 
-#: config/i386/i386.c:6561
+#: config/i386/i386.c:6564
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "%qE 屬性被用於無 class-method"
 
-#: config/i386/i386.c:6805
+#: config/i386/i386.c:6808
 #, fuzzy, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "呼叫 %qD 與屬性 sseregparm 而無需 SSE/SSE2 已啟用"
 
-#: config/i386/i386.c:6808
+#: config/i386/i386.c:6811
 #, fuzzy, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "呼叫 %qT 與屬性 sseregparm 而無需 SSE/SSE2 已啟用"
 
-#: config/i386/i386.c:7126
+#: config/i386/i386.c:7129
 #, fuzzy, gcc-internal-format
 #| msgid "does not support multilib"
 msgid "X32 does not support ms_abi attribute"
 msgstr "不支援 multilib"
 
-#: config/i386/i386.c:7160
+#: config/i386/i386.c:7163
 #, fuzzy, gcc-internal-format
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr "ms_hook_prologue 不是相容與巢狀的函式"
 
-#: config/i386/i386.c:7502
+#: config/i386/i386.c:7505
 #, fuzzy, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr "AVX 向量引數而無需 AVX 已啟用變更 ABI"
 
-#: config/i386/i386.c:7508
+#: config/i386/i386.c:7511
 #, fuzzy, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr "AVX 向量引數而無需 AVX 已啟用變更 ABI"
 
-#: config/i386/i386.c:7522
+#: config/i386/i386.c:7525
 #, fuzzy, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr "AVX 向量引數而無需 AVX 已啟用變更 ABI"
 
-#: config/i386/i386.c:7528
+#: config/i386/i386.c:7531
 #, fuzzy, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr "AVX 向量引數而無需 AVX 已啟用變更 ABI"
 
-#: config/i386/i386.c:7544
+#: config/i386/i386.c:7547
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr "沒有啟用 SSE，卻出現了 SSE 向量引數，這變更了 ABI"
 
-#: config/i386/i386.c:7550
+#: config/i386/i386.c:7553
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr "沒有啟用 SSE，卻有 SSE 向量回傳值，這變更了 ABI"
 
-#: config/i386/i386.c:7566
+#: config/i386/i386.c:7569
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr "沒有啟用 MMX，卻出現了 MMX 向量引數，這變更了 ABI"
 
-#: config/i386/i386.c:7572
+#: config/i386/i386.c:7575
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr "沒有啟用 MMX卻回傳 MMX 向量，這變更了 ABI"
 
-#: config/i386/i386.c:7754
+#: config/i386/i386.c:7757
 #, fuzzy, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr "ABI 的傳遞結構與 flexible 陣列成員已變更在中 GCC 4.4"
 
-#: config/i386/i386.c:7871
+#: config/i386/i386.c:7874
 #, fuzzy, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr "ABI 的傳遞聯合與長雙倍已變更在中 GCC 4.4"
 
-#: config/i386/i386.c:7989
+#: config/i386/i386.c:7992
 #, fuzzy, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr "ABI 的傳遞結構與複雜浮點數成員已變更在中 GCC 4.4"
 
-#: config/i386/i386.c:8152
+#: config/i386/i386.c:8155
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr "已停用 SSE 卻在 SSE 暫存器中回傳"
 
-#: config/i386/i386.c:8158
+#: config/i386/i386.c:8161
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr "已停用 SSE 卻在 SSE 暫存器中傳遞參數"
 
-#: config/i386/i386.c:8174
+#: config/i386/i386.c:8177
 #, fuzzy, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr "x87 暫存器回傳與 x87 已停用"
 
-#: config/i386/i386.c:8471 config/i386/i386.c:8750 config/i386/i386.c:9276
+#: config/i386/i386.c:8474 config/i386/i386.c:8753 config/i386/i386.c:9279
 #, fuzzy, gcc-internal-format
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr "呼叫 %qD 與屬性 sseregparm 而無需 SSE/SSE2 已啟用"
 
-#: config/i386/i386.c:8473 config/i386/i386.c:8752 config/i386/i386.c:9278
+#: config/i386/i386.c:8476 config/i386/i386.c:8755 config/i386/i386.c:9281
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr ""
 
-#: config/i386/i386.c:9178
+#: config/i386/i386.c:9181
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr "ABI 用於傳遞參數與 %d-byte 對齊已變更在中 GCC 4.6"
 
-#: config/i386/i386.c:11601
+#: config/i386/i386.c:11604
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "assert: %s is assign compatible with %s"
 msgid "-mcall-ms2sysv-xlogues is not compatible with %s"
 msgstr "assert：%s 與 %s 賦值相容"
 
-#: config/i386/i386.c:13593
+#: config/i386/i386.c:13596
 #, fuzzy, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr "ms_hook_prologue 屬性 isn%'t 相容與 -mfentry 用於 32-bit"
 
-#: config/i386/i386.c:13683
+#: config/i386/i386.c:13686
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr ""
 
-#: config/i386/i386.c:14970
+#: config/i386/i386.c:14973
 #, fuzzy, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr "-fsplit-stack 不支援 fastcall 與巢狀的函式"
 
-#: config/i386/i386.c:14990
+#: config/i386/i386.c:14993
 #, fuzzy, gcc-internal-format
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
 msgstr "-fsplit-stack 不支援 2 暫存器  參數用於巢狀的函式"
@@ -32822,317 +32864,317 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:15001
+#: config/i386/i386.c:15004
 #, fuzzy, gcc-internal-format
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr "-fsplit-stack 不支援 3 暫存器參數"
 
-#: config/i386/i386.c:17939
+#: config/i386/i386.c:17942
 #, gcc-internal-format
 msgid "'V' modifier on non-integer register"
 msgstr ""
 
-#: config/i386/i386.c:17950 config/i386/i386.c:17964
+#: config/i386/i386.c:17953 config/i386/i386.c:17967
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported operand size for extended register"
 msgid "unsupported size for integer register"
 msgstr "擴充的暫存器不支援的運算元大小"
 
-#: config/i386/i386.c:17996
+#: config/i386/i386.c:17999
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr "擴充的暫存器沒有高半部分"
 
-#: config/i386/i386.c:18011
+#: config/i386/i386.c:18014
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr "擴充的暫存器不支援的運算元大小"
 
-#: config/i386/i386.c:18202
+#: config/i386/i386.c:18205
 #, fuzzy, gcc-internal-format
 msgid "non-integer operand used with operand code 'z'"
 msgstr "non-integer 運算元使用的與運算元編碼『%c』"
 
-#: config/i386/i386.c:28467
+#: config/i386/i386.c:28470
 #, fuzzy, gcc-internal-format
 msgid "interrupt service routine can't be called directly"
 msgstr "插斷服務常式無法編碼的在中姆指模式"
 
-#: config/i386/i386.c:29995
+#: config/i386/i386.c:29998
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in -fabi-version=12 (GCC 8)"
 msgstr ""
 
-#: config/i386/i386.c:32435
+#: config/i386/i386.c:32438
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr ""
 
-#: config/i386/i386.c:32485
+#: config/i386/i386.c:32488
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for %s"
 msgstr ""
 
-#: config/i386/i386.c:32495
+#: config/i386/i386.c:32498
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr ""
 
-#: config/i386/i386.c:32657
+#: config/i386/i386.c:32660
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386.c:32662 config/i386/i386.c:32938
-#: config/rs6000/rs6000.c:37850
+#: config/i386/i386.c:32665 config/i386/i386.c:32941
+#: config/rs6000/rs6000.c:37906
 #, fuzzy, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "不支援堆疊限制運算式"
 
-#: config/i386/i386.c:32795 config/rs6000/rs6000.c:37607
+#: config/i386/i386.c:32798 config/rs6000/rs6000.c:37663
 #, fuzzy, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "ifunc 未被支援在中這個組態"
 
-#: config/i386/i386.c:33207
+#: config/i386/i386.c:33210
 #, fuzzy, gcc-internal-format
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr "%qs 的引數必須是一個 2 位無號原文"
 
-#: config/i386/i386.c:33232 config/i386/i386.c:33282
+#: config/i386/i386.c:33235 config/i386/i386.c:33285
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Parameter to builtin not valid: %s"
 msgstr "-ffpe-trap 的參數無效：%s"
 
-#: config/i386/i386.c:33975 config/i386/i386.c:35415
+#: config/i386/i386.c:33978 config/i386/i386.c:35418
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "最後一筆引數必須是 2-bit 即時"
 
-#: config/i386/i386.c:34370
+#: config/i386/i386.c:34373
 #, fuzzy, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "fifth 引數必須是 8-bit 即時"
 
-#: config/i386/i386.c:34465
+#: config/i386/i386.c:34468
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "第三引數必須是 8-bit 即時"
 
-#: config/i386/i386.c:35346
+#: config/i386/i386.c:35349
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "最後一筆引數必須是 1-bit 即時"
 
-#: config/i386/i386.c:35361
+#: config/i386/i386.c:35364
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "最後一筆引數必須是 32-bit 即時"
 
-#: config/i386/i386.c:35394
+#: config/i386/i386.c:35397
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "最後一筆引數必須是 4-bit 即時"
 
-#: config/i386/i386.c:35434
+#: config/i386/i386.c:35437
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "最後一筆引數必須是 1-bit 即時"
 
-#: config/i386/i386.c:35447
+#: config/i386/i386.c:35450
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "最後一筆引數必須是 5-bit 即時"
 
-#: config/i386/i386.c:35457
+#: config/i386/i386.c:35460
 #, fuzzy, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "下一個到最後一筆引數必須是 8-bit 即時"
 
-#: config/i386/i386.c:35462 config/i386/i386.c:36249
+#: config/i386/i386.c:35465 config/i386/i386.c:36252
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "最後一筆引數必須是 8-bit 即時"
 
-#: config/i386/i386.c:35596
+#: config/i386/i386.c:35599
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr "引數必須是常數"
 
-#: config/i386/i386.c:35601
+#: config/i386/i386.c:35604
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect comparison mode"
 msgstr "錯誤指令："
 
-#: config/i386/i386.c:35607 config/i386/i386.c:35814
+#: config/i386/i386.c:35610 config/i386/i386.c:35817
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect sharing of tree nodes"
 msgid "incorrect rounding operand"
 msgstr "對樹結區段的共享不正確"
 
-#: config/i386/i386.c:35796
+#: config/i386/i386.c:35799
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "最後一筆引數必須是 4-bit 即時"
 
-#: config/i386/i386.c:35802
+#: config/i386/i386.c:35805
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "最後一筆引數必須是 5-bit 即時"
 
-#: config/i386/i386.c:35805
+#: config/i386/i386.c:35808
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "最後一筆引數必須是 8-bit 即時"
 
-#: config/i386/i386.c:36247
+#: config/i386/i386.c:36250
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "最後一筆引數必須是 32-bit 即時"
 
-#: config/i386/i386.c:36329 config/powerpcspe/powerpcspe.c:16219
-#: config/rs6000/rs6000.c:15304
+#: config/i386/i386.c:36332 config/powerpcspe/powerpcspe.c:16219
+#: config/rs6000/rs6000.c:15348
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr "選擇子必須是 0 到 %wi 間的整常數"
 
-#: config/i386/i386.c:36539
+#: config/i386/i386.c:36542
 #, fuzzy, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr "%qE 需要不明 isa 選項"
 
-#: config/i386/i386.c:36543
+#: config/i386/i386.c:36546
 #, fuzzy, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "%qE 需要 isa 選項 %s"
 
-#: config/i386/i386.c:37381
+#: config/i386/i386.c:37375
 #, fuzzy, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "最後一筆引數必須是即時"
 
-#: config/i386/i386.c:38108 config/i386/i386.c:38290
+#: config/i386/i386.c:38102 config/i386/i386.c:38284
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "最後一筆引數必須是尺度 1,- 2,- 4, 8"
 
-#: config/i386/i386.c:38343
+#: config/i386/i386.c:38337
 #, fuzzy, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "最後一筆引數必須是尺度 1,- 2,- 4, 8"
 
-#: config/i386/i386.c:38349
+#: config/i386/i386.c:38343
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect hint operand"
 msgstr "錯誤指令："
 
-#: config/i386/i386.c:38368
+#: config/i386/i386.c:38362
 #, fuzzy, gcc-internal-format
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr "最後一筆引數必須是 8-bit 即時"
 
-#: config/i386/i386.c:41431
+#: config/i386/i386.c:41425
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "%qE 屬性只有可見於 32-bit"
 
-#: config/i386/i386.c:41452
+#: config/i386/i386.c:41446
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "引數到 %qE 屬性是 neither 零，nor 一個"
 
-#: config/i386/i386.c:41485 config/i386/i386.c:41494
+#: config/i386/i386.c:41479 config/i386/i386.c:41488
 #, fuzzy, gcc-internal-format
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr "ms_abi 和 sysv_abi 屬性不是相容"
 
-#: config/i386/i386.c:41530 config/powerpcspe/powerpcspe.c:35868
-#: config/rs6000/rs6000.c:33065
+#: config/i386/i386.c:41524 config/powerpcspe/powerpcspe.c:35868
+#: config/rs6000/rs6000.c:33121
 #, fuzzy, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "%qE 不相容的屬性忽略"
 
-#: config/i386/i386.c:41555 config/i386/i386.c:41577 config/ia64/ia64.c:815
+#: config/i386/i386.c:41549 config/i386/i386.c:41571 config/ia64/ia64.c:815
 #: config/s390/s390.c:1153
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "%qE 屬性需要字串常數引數"
 
-#: config/i386/i386.c:41565 config/i386/i386.c:41587 config/s390/s390.c:1182
+#: config/i386/i386.c:41559 config/i386/i386.c:41581 config/s390/s390.c:1182
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "引數的 %qE 屬性並非字串常數"
 
-#: config/i386/i386.c:41619
+#: config/i386/i386.c:41613
 #, fuzzy, gcc-internal-format
 #| msgid "dereferenced pointers should have a name or a type tag"
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr "提領的指標應具有一個名稱或類型標記"
 
-#: config/i386/i386.c:41626
+#: config/i386/i386.c:41620
 #, gcc-internal-format, gfc-internal-format
 msgid "interrupt service routine should have unsigned %sint as the second argument"
 msgstr ""
 
-#: config/i386/i386.c:41636
+#: config/i386/i386.c:41630
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386.c:41639
+#: config/i386/i386.c:41633
 #, fuzzy, gcc-internal-format
 msgid "interrupt service routine can't have non-void return value"
 msgstr "插斷服務常式無法編碼的在中姆指模式"
 
-#: config/i386/i386.c:44676
+#: config/i386/i386.c:44670
 #, fuzzy, gcc-internal-format
 msgid "alternatives not allowed in asm flag output"
 msgstr "By-value 引數於 %L 未被允許在中這個語境"
 
-#: config/i386/i386.c:44740
+#: config/i386/i386.c:44734
 #, fuzzy, gcc-internal-format
 msgid "unknown asm flag output %qs"
 msgstr "不明 IRA 演算法 %qs"
 
-#: config/i386/i386.c:44769
+#: config/i386/i386.c:44763
 #, fuzzy, gcc-internal-format
 msgid "invalid type for asm flag output"
 msgstr "無效的型態用於製作函式"
 
-#: config/i386/i386.c:50634
+#: config/i386/i386.c:50628
 #, fuzzy, gcc-internal-format
 msgid "unknown architecture specific memory model"
 msgstr "不明 TLS 式樣 %qs"
 
-#: config/i386/i386.c:50641
+#: config/i386/i386.c:50635
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50647
+#: config/i386/i386.c:50641
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50671 config/i386/i386.c:50787
+#: config/i386/i386.c:50665 config/i386/i386.c:50781
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "unsupported simdlen %d"
 msgstr "不支援的組合：%s"
 
-#: config/i386/i386.c:50690
+#: config/i386/i386.c:50684
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd"
 msgstr ""
 
-#: config/i386/i386.c:50712
+#: config/i386/i386.c:50706
 #, fuzzy, gcc-internal-format
 msgid "unsupported argument type %qT for simd"
 msgstr "不受支援的引數類型到內建函式"
 
-#: config/i386/i386.c:51033
+#: config/i386/i386.c:51027
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr ""
@@ -33356,7 +33398,7 @@
 msgstr "interruptthread 是可用只有於 fido(_T)"
 
 #: config/m68k/m68k.c:1128 config/powerpcspe/powerpcspe.c:28512
-#: config/rs6000/rs6000.c:25791
+#: config/rs6000/rs6000.c:25868
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "不支援堆疊限制運算式"
@@ -33938,63 +33980,63 @@
 
 #. Trampoline is not supported on reduced-set registers yet.
 #: config/nds32/nds32.c:2327 config/nds32/nds32.c:2381
-#: config/nds32/nds32.c:3127 config/nds32/nds32.c:3201
-#: config/nds32/nds32.c:3216 config/nds32/nds32.c:3222
-#: config/nds32/nds32.c:3284 config/nds32/nds32.c:3290
-#: config/nds32/nds32.c:3322
+#: config/nds32/nds32.c:3128 config/nds32/nds32.c:3202
+#: config/nds32/nds32.c:3217 config/nds32/nds32.c:3223
+#: config/nds32/nds32.c:3285 config/nds32/nds32.c:3291
+#: config/nds32/nds32.c:3323
 #, fuzzy, gcc-internal-format
 msgid "a nested function is not supported for reduced registers"
 msgstr "巢狀的函式不支援於這個目標"
 
 #. The enum index value for array size is out of range.
-#: config/nds32/nds32.c:3025
+#: config/nds32/nds32.c:3026
 #, fuzzy, gcc-internal-format
 #| msgid "requested init_priority is out of range"
 msgid "intrinsic register index is out of range"
 msgstr "請求的 init_priority 越界"
 
-#: config/nds32/nds32.c:3041 config/nds32/nds32.c:3048
-#: config/nds32/nds32.c:3055 config/nds32/nds32.c:3062
-#: config/nds32/nds32.c:3069
+#: config/nds32/nds32.c:3042 config/nds32/nds32.c:3049
+#: config/nds32/nds32.c:3056 config/nds32/nds32.c:3063
+#: config/nds32/nds32.c:3070
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic function %s(%d) not recognized"
 msgid "CCTL intrinsic function subtype out of range!"
 msgstr "內部函式 %s(%d) 無法識別"
 
-#: config/nds32/nds32.c:3508
+#: config/nds32/nds32.c:3509
 #, fuzzy, gcc-internal-format
 msgid "invalid id value for interrupt/exception attribute"
 msgstr "無效的型態用於迭代變數 %qE"
 
-#: config/nds32/nds32.c:3536
+#: config/nds32/nds32.c:3537
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "invalid id value for reset attribute"
 msgstr "屬性 %qs 的參數無效"
 
-#: config/nds32/nds32.c:3552
+#: config/nds32/nds32.c:3553
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "invalid nmi function for reset attribute"
 msgstr "屬性 %qs 的參數無效"
 
-#: config/nds32/nds32.c:3565
+#: config/nds32/nds32.c:3566
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "invalid warm function for reset attribute"
 msgstr "屬性 %qs 的參數無效"
 
-#: config/nds32/nds32.c:3638
+#: config/nds32/nds32.c:3639
 #, gcc-internal-format
 msgid "Disable FPU ISA, the ABI option must be enable '-mfloat-abi=soft'"
 msgstr ""
 
-#: config/nds32/nds32.c:3641
+#: config/nds32/nds32.c:3642
 #, gcc-internal-format
 msgid "'-mabi=2fp+' option only support when FPU available, must be enable '-mext-fpu-sp' or '-mext-fpu-dp'"
 msgstr ""
 
-#: config/nds32/nds32.c:3647
+#: config/nds32/nds32.c:3648
 #, fuzzy, gcc-internal-format
 msgid "position-independent code not supported"
 msgstr "停用 position-independent 編碼 (PIC) 用於使用在中作業系統內核編碼"
@@ -34336,12 +34378,12 @@
 msgid "junk at end of #pragma longcall"
 msgstr "#pragma longcall 末尾有無用字元"
 
-#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6154
+#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6152
 #, gcc-internal-format
 msgid "vec_lvsl is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6158
+#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6156
 #, gcc-internal-format
 msgid "vec_lvsr is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
@@ -34391,7 +34433,7 @@
 msgid "vec_insert only accepts 3 arguments"
 msgstr "vecinsert 只有接受 3 引數(_I)"
 
-#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6868
+#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6866
 #, fuzzy, gcc-internal-format
 #| msgid "passing arg %d of %qE discards qualifiers frompointer target type"
 msgid "passing arg %d of %qE discards qualifiers from pointer target type"
@@ -34478,7 +34520,7 @@
 msgid "target attribute or pragma changes SPE ABI"
 msgstr "目標屬性或 pragma 變更 SPE ABI"
 
-#: config/powerpcspe/powerpcspe.c:4351 config/rs6000/rs6000.c:4223
+#: config/powerpcspe/powerpcspe.c:4351 config/rs6000/rs6000.c:4243
 #, fuzzy, gcc-internal-format
 msgid "AltiVec not supported in this target"
 msgstr "AltiVec 不支援在中這個目標"
@@ -34629,7 +34671,7 @@
 msgid "-mvsx-small-integer requires -mpower8-vector, -mupper-regs-di, and -mdirect-move"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4959 config/rs6000/rs6000.c:4601
+#: config/powerpcspe/powerpcspe.c:4959 config/rs6000/rs6000.c:4628
 #, fuzzy, gcc-internal-format
 msgid "target attribute or pragma changes long double size"
 msgstr "目標屬性或 pragma 變更長兩倍大小"
@@ -34670,22 +34712,22 @@
 msgstr "不明 vectorization 函式庫 ABI 型態 (%s) 用於 -mveclibabi=切換"
 
 #: config/powerpcspe/powerpcspe.c:5140 config/powerpcspe/powerpcspe.c:5155
-#: config/rs6000/rs6000.c:4766 config/rs6000/rs6000.c:4781
+#: config/rs6000/rs6000.c:4791 config/rs6000/rs6000.c:4806
 #, fuzzy, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr "目標屬性或 pragma 變更 AltiVec ABI"
 
-#: config/powerpcspe/powerpcspe.c:5168 config/rs6000/rs6000.c:4794
+#: config/powerpcspe/powerpcspe.c:5168 config/rs6000/rs6000.c:4819
 #, fuzzy, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr "目標屬性或 pragma 變更 darwin64 ABI"
 
-#: config/powerpcspe/powerpcspe.c:5234 config/rs6000/rs6000.c:4828
+#: config/powerpcspe/powerpcspe.c:5234 config/rs6000/rs6000.c:4853
 #, fuzzy, gcc-internal-format
 msgid "target attribute or pragma changes single precision floating point"
 msgstr "目標屬性或 pragma 變更單精確度浮點數"
 
-#: config/powerpcspe/powerpcspe.c:5237 config/rs6000/rs6000.c:4831
+#: config/powerpcspe/powerpcspe.c:5237 config/rs6000/rs6000.c:4856
 #, fuzzy, gcc-internal-format
 msgid "target attribute or pragma changes double precision floating point"
 msgstr "目標屬性或 pragma 變更雙倍精度浮點數"
@@ -34695,12 +34737,12 @@
 msgid "-mstack-protector-guard=tls needs a valid base register"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:8415 config/rs6000/rs6000.c:7925
+#: config/powerpcspe/powerpcspe.c:8415 config/rs6000/rs6000.c:7950
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr "ABI 用於傳遞參數與 %d-byte 對齊已變更在中 GCC 4.6"
 
-#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11237
+#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11269
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC 回傳向量參照：非標準的 ABI 擴充，不保證相容性"
@@ -34710,7 +34752,7 @@
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "不能在向量暫存器中回傳值，因為 altivec 指令集已被停用，使用 -maltivec 啟用"
 
-#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11595
+#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11633
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr "ABI 用於傳遞參數與 %d-byte 對齊已變更在中 GCC 4.6"
@@ -34720,12 +34762,12 @@
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "不能在向量暫存器中傳遞參數，因為 altivec 指令集已被停用，使用 -maltivec 啟用"
 
-#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12604
+#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12648
 #, fuzzy, gcc-internal-format
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr "ABI 的傳遞結構與複雜浮點數成員已變更在中 GCC 4.4"
 
-#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12779
+#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12823
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC 傳遞向量參照：非標準的 ABI 擴充，不保證相容性"
@@ -34735,30 +34777,30 @@
 msgid "internal error: builtin function %s already processed"
 msgstr "內部錯誤：內建函式 %s 已經處理"
 
-#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:13971
+#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:14015
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "argument 1 must be an 8-bit field value"
 msgstr "引數 1 必須是一個 5 位有號字面值"
 
-#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14015
+#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14059
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "引數 1 必須是一個 5 位有號字面值"
 
 #: config/powerpcspe/powerpcspe.c:14934 config/powerpcspe/powerpcspe.c:16803
-#: config/rs6000/rs6000.c:14101
+#: config/rs6000/rs6000.c:14145
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "引數 2 必須是一個 5 位無號字面值"
 
-#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14119
+#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14163
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "引數 2 必須是一個 5 位無號字面值"
 
-#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14135
+#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14179
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 7-bit unsigned literal"
@@ -34779,13 +34821,13 @@
 msgid "builtin %s is only valid in 64-bit mode"
 msgstr "%srtd%s 被忽略在中 64 位元模式"
 
-#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14791
+#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14835
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument %d must be an unsigned literal"
 msgstr "引數 2 必須是一個 5 位無號字面值"
 
-#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14793
+#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14837
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument %d is an unsigned literal that is out of range"
@@ -34808,55 +34850,55 @@
 msgid "hwcap %s is an invalid argument to builtin %s"
 msgstr "%qs 是無效的引數到 -mcpu="
 
-#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15065
+#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15109
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "引數 3 必須是一個 4 位無號字面值"
 
-#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15090
+#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15134
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "引數 3 必須是 2-bit 無正負號實字"
 
-#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15110
+#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15154
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "引數 3 必須是 1-bit 無正負號實字"
 
-#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15122
+#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15166
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be 0 or 2"
 msgstr "引數 1 必須是映射"
 
-#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15134
+#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15178
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "引數 3 必須是 1-bit 無正負號實字"
 
-#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15148
+#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15192
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "引數 2 必須是一個 5 位無號字面值"
 
-#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15160
+#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15204
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "argument 2 must be 0 or 1"
 msgstr "數字必須是 0 或 1"
 
-#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15168
+#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15212
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be in the range 0..15"
 msgstr "引數 %d 的 %qE 必須是在中範圍 %d...%d"
 
-#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15237
-#: config/rs6000/rs6000.c:15569
+#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15281
+#: config/rs6000/rs6000.c:15613
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "%qs 的引數必須是一個 2 位無號原文"
 
-#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15394
+#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15438
 #, fuzzy, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr "無法解析的過載用於 Altivec 內建 %qF"
@@ -34983,7 +35025,7 @@
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr "內部錯誤：內建函式 %s，引數 %d 已未預期的引數類型 %s"
 
-#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25758
+#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25835
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr "堆疊框架太大"
@@ -34993,12 +35035,12 @@
 msgid "-fsplit-stack uses register r29"
 msgstr "-fsplit-stack 不支援 3 暫存器參數"
 
-#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29459
+#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29536
 #, fuzzy, gcc-internal-format
 msgid "Stack frame larger than 2G is not supported for -fsplit-stack"
 msgstr "# pragma GCC 目標未被支援用於這個機器"
 
-#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30447
+#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30524
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "此 ABI 不支援取樣 64 位元程式碼"
@@ -35008,22 +35050,22 @@
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr "您無法需位址的巢狀的函式如果您使用 -mno-pointers-to-nested-functions 選項。"
 
-#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32830
+#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32907
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "在 AltiVec 類型中使用 %<long double%> 無效"
 
-#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32832
+#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32909
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "在 AltiVec 類型中使用布林類型無效"
 
-#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32834
+#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32911
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "在 AltiVec 類型中使用 %<complex%> 無效"
 
-#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32836
+#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32913
 #, fuzzy, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr "使用的十進位浮點數類型在中 AltiVec 類型無效"
@@ -35033,7 +35075,7 @@
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr "使用的 %<long%> 在中 AltiVec 類型無效用於 64-bit 編碼而無需 -mvsx"
 
-#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32845
+#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32922
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "在 AltiVec 類型中使用 %<long%> 已過時；請改用 %<int%>"
@@ -35575,75 +35617,75 @@
 "Please use an explicit cpu name.  Valid cpu names are: %s"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6168 config/rs6000/rs6000-c.c:6219
-#: config/rs6000/rs6000-c.c:6489 config/rs6000/rs6000-c.c:6555
-#: config/rs6000/rs6000-c.c:6916 config/rs6000/rs6000-c.c:6963
+#: config/rs6000/rs6000-c.c:6166 config/rs6000/rs6000-c.c:6217
+#: config/rs6000/rs6000-c.c:6487 config/rs6000/rs6000-c.c:6553
+#: config/rs6000/rs6000-c.c:6914 config/rs6000/rs6000-c.c:6961
 #, fuzzy, gcc-internal-format
 msgid "builtin %qs only accepts 2 arguments"
 msgstr "%s 只有接受 2 引數"
 
-#: config/rs6000/rs6000-c.c:6292 config/rs6000/rs6000-c.c:6375
-#: config/rs6000/rs6000-c.c:6736
+#: config/rs6000/rs6000-c.c:6290 config/rs6000/rs6000-c.c:6373
+#: config/rs6000/rs6000-c.c:6734
 #, fuzzy, gcc-internal-format
 msgid "builtin %qs only accepts 3 arguments"
 msgstr "%s 只有接受 2 引數"
 
-#: config/rs6000/rs6000-c.c:6484
+#: config/rs6000/rs6000-c.c:6482
 #, fuzzy, gcc-internal-format
 msgid "builtin %qs only accepts 1 argument"
 msgstr "%s 只有接受 1 引數"
 
-#: config/rs6000/rs6000-c.c:7054
+#: config/rs6000/rs6000-c.c:7052
 #, gcc-internal-format
 msgid "builtin %qs requires builtin %qs"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:7058
+#: config/rs6000/rs6000-c.c:7056
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs not supported in this compiler configuration"
 msgstr "ifunc 未被支援在中這個組態"
 
-#: config/rs6000/rs6000-c.c:7068
+#: config/rs6000/rs6000-c.c:7066
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter combination for AltiVec intrinsic"
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr "對 AltiVec 內建函式來說無效的參陣列合"
 
-#: config/rs6000/rs6000.c:3754 config/rs6000/rs6000.c:3757
-#: config/rs6000/rs6000.c:3760
+#: config/rs6000/rs6000.c:3772 config/rs6000/rs6000.c:3775
+#: config/rs6000/rs6000.c:3778
 #, fuzzy, gcc-internal-format
 msgid "%qs requires %qs or %qs"
 msgstr "%qE 被 predetermined %qs 用於 %qs"
 
-#: config/rs6000/rs6000.c:3861
+#: config/rs6000/rs6000.c:3879
 #, fuzzy, gcc-internal-format
 #| msgid "-m64 requires PowerPC64 architecture, enabling"
 msgid "%qs requires PowerPC64 architecture, enabling"
 msgstr "-m64 需要 PowerPC64 架構，正在啟用"
 
-#: config/rs6000/rs6000.c:4037
+#: config/rs6000/rs6000.c:4057
 #, gcc-internal-format
 msgid "%qs command-line option is deprecated"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4048
+#: config/rs6000/rs6000.c:4068
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-power is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgid "%qs is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr "-malign-power 在 64 位元 Darwin 下不受支援；它與已安裝的 C 和 C++ 函式庫不相容"
 
-#: config/rs6000/rs6000.c:4147
+#: config/rs6000/rs6000.c:4167
 #, gcc-internal-format
 msgid "will not generate %qs instructions because assembler lacks %qs support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4240
+#: config/rs6000/rs6000.c:4260
 #, fuzzy, gcc-internal-format
 #| msgid "-mstring is not supported on little endian systems"
 msgid "%qs is not supported on little endian systems"
 msgstr "-mstring 在低位位元組在前的系統上不受支援"
 
-#: config/rs6000/rs6000.c:4333
+#: config/rs6000/rs6000.c:4353
 #, gcc-internal-format
 msgid "power9 target option is incompatible with %<%s=<xxx>%> for <xxx> less than power9"
 msgstr ""
@@ -35650,7 +35692,7 @@
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:4341
+#: config/rs6000/rs6000.c:4361
 #, fuzzy, gcc-internal-format
 msgid "%qs incompatible with explicitly disabled options"
 msgstr "-mcmodel 不相容的與其他光碟內容表選項"
@@ -35659,248 +35701,249 @@
 #. error messages.  However, if users have managed to select
 #. power9-fusion without selecting power8-fusion, they
 #. already know about undocumented flags.
-#: config/rs6000/rs6000.c:4366 config/rs6000/rs6000.c:4373
-#: config/rs6000/rs6000.c:4380 config/rs6000/rs6000.c:4388
-#: config/rs6000/rs6000.c:4407 config/rs6000/rs6000.c:4464
-#: config/rs6000/rs6000.c:4468 config/rs6000/rs6000.c:4485
-#: config/rs6000/rs6000.c:4538 config/rs6000/rs6000.c:4565
-#: config/rs6000/rs6000.c:4580 config/rs6000/rs6000.c:4588
-#: config/rs6000/rs6000.c:4684
+#: config/rs6000/rs6000.c:4386 config/rs6000/rs6000.c:4393
+#: config/rs6000/rs6000.c:4400 config/rs6000/rs6000.c:4408
+#: config/rs6000/rs6000.c:4427 config/rs6000/rs6000.c:4484
+#: config/rs6000/rs6000.c:4488 config/rs6000/rs6000.c:4505
+#: config/rs6000/rs6000.c:4558 config/rs6000/rs6000.c:4585
+#: config/rs6000/rs6000.c:4600 config/rs6000/rs6000.c:4608
+#: config/rs6000/rs6000.c:4709
 #, fuzzy, gcc-internal-format
 #| msgid "%qT referred to as %qs"
 msgid "%qs requires %qs"
 msgstr "%qT 做為 %qs 被參照"
 
-#: config/rs6000/rs6000.c:4625
+#: config/rs6000/rs6000.c:4650
 #, fuzzy, gcc-internal-format
 msgid "Using IEEE extended precision long double"
 msgstr "使用我進階精確度長雙倍"
 
-#: config/rs6000/rs6000.c:4627
+#: config/rs6000/rs6000.c:4652
 #, fuzzy, gcc-internal-format
 msgid "Using IBM extended precision long double"
 msgstr "使用 IBM 進階精確度長雙倍"
 
-#: config/rs6000/rs6000.c:4644
+#: config/rs6000/rs6000.c:4669
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "%qs requires VSX support"
 msgstr "%s 不支援 %s"
 
-#: config/rs6000/rs6000.c:4653
+#: config/rs6000/rs6000.c:4678
 #, gcc-internal-format
 msgid "The -mfloat128 option may not be fully supported"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4676
+#: config/rs6000/rs6000.c:4701
 #, gcc-internal-format
 msgid "%qs requires full ISA 3.0 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4743
+#: config/rs6000/rs6000.c:4768
 #, fuzzy, gcc-internal-format
 msgid "unknown vectorization library ABI type (%qs) for %qs switch"
 msgstr "不明 vectorization 函式庫 ABI 型態 (%s) 用於 -mveclibabi=切換"
 
-#: config/rs6000/rs6000.c:4930
+#: config/rs6000/rs6000.c:4955
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr "%qs 無效用於 %qs"
 
-#: config/rs6000/rs6000.c:4935
+#: config/rs6000/rs6000.c:4960
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr "%qs 無效用於 %qs"
 
-#: config/rs6000/rs6000.c:4947
+#: config/rs6000/rs6000.c:4972
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid base register in %qs"
 msgstr "%qs 並非有效類別名稱"
 
-#: config/rs6000/rs6000.c:4955
+#: config/rs6000/rs6000.c:4980
 #, fuzzy, gcc-internal-format
 msgid "%qs needs a valid base register"
 msgstr "需要 call-clobbered 目標暫存器"
 
-#: config/rs6000/rs6000.c:5253
+#: config/rs6000/rs6000.c:5278
 #, fuzzy, gcc-internal-format
 msgid "unknown option for %<%s=%s%>"
 msgstr "不明選項用於 -mrecip=%s"
 
-#: config/rs6000/rs6000.c:5290
+#: config/rs6000/rs6000.c:5315
 #, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11401
+#: config/rs6000/rs6000.c:11439
 #, fuzzy, gcc-internal-format
 #| msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgid "cannot return value in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr "不能在向量暫存器中回傳值，因為 altivec 指令集已被停用，使用 -maltivec 啟用"
 
-#: config/rs6000/rs6000.c:11862
+#: config/rs6000/rs6000.c:11906
 #, fuzzy, gcc-internal-format
 #| msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr "不能在向量暫存器中傳遞參數，因為 altivec 指令集已被停用，使用 -maltivec 啟用"
 
-#: config/rs6000/rs6000.c:13572
+#: config/rs6000/rs6000.c:13616
 #, fuzzy, gcc-internal-format
 msgid "internal error: builtin function %qs already processed"
 msgstr "內部錯誤：內建函式 %s 已經處理"
 
-#: config/rs6000/rs6000.c:14150
+#: config/rs6000/rs6000.c:14194
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 1-bit unsigned literal"
 msgstr "引數 2 必須是一個 5 位無號字面值"
 
-#: config/rs6000/rs6000.c:14189
+#: config/rs6000/rs6000.c:14233
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qs must be a constant"
 msgstr "引數必須是常數"
 
-#: config/rs6000/rs6000.c:14247 config/rs6000/rs6000.c:15898
+#: config/rs6000/rs6000.c:14291 config/rs6000/rs6000.c:15942
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument 1 of %qs is out of range"
 msgstr "__builtin_spe_predicate 的第 1 個引數越界"
 
-#: config/rs6000/rs6000.c:14742
+#: config/rs6000/rs6000.c:14786
 #, fuzzy, gcc-internal-format
 msgid "builtin %qs is only valid in 64-bit mode"
 msgstr "%srtd%s 被忽略在中 64 位元模式"
 
-#: config/rs6000/rs6000.c:14939
+#: config/rs6000/rs6000.c:14983
 #, fuzzy, gcc-internal-format
 msgid "builtin %qs only accepts a string argument"
 msgstr "%s 只有接受 1 引數"
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000.c:14958
+#: config/rs6000/rs6000.c:15002
 #, fuzzy, gcc-internal-format
 msgid "cpu %qs is an invalid argument to builtin %qs"
 msgstr "%qs 是無效的引數到 -mcpu="
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000.c:14986
+#: config/rs6000/rs6000.c:15030
 #, fuzzy, gcc-internal-format
 msgid "%s %qs is an invalid argument to builtin %qs"
 msgstr "%qs 是無效的引數到 -mcpu="
 
-#: config/rs6000/rs6000.c:15012
+#: config/rs6000/rs6000.c:15056
 #, gcc-internal-format
 msgid "builtin %qs needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15616
+#: config/rs6000/rs6000.c:15660
 #, fuzzy, gcc-internal-format
 #| msgid "second argument of %q+D should be %<char **%>"
 msgid "second argument to %qs must be 0..12"
 msgstr "%q+D 的第二個參數類型應該是 %<char **%>"
 
-#: config/rs6000/rs6000.c:15631
+#: config/rs6000/rs6000.c:15675
 #, fuzzy, gcc-internal-format
 msgid "third argument to %qs must be 0..12"
 msgstr "有效引數到 %qs 是：%s"
 
-#: config/rs6000/rs6000.c:15850
+#: config/rs6000/rs6000.c:15894
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument 1 of %s must be a constant"
 msgstr "引數必須是常數"
 
-#: config/rs6000/rs6000.c:15932
+#: config/rs6000/rs6000.c:15976
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs is only valid for the cell processor"
 msgstr "內建函式 %s 是只有有效用於儲存格處理器"
 
-#: config/rs6000/rs6000.c:15934 config/rs6000/rs6000.c:15936
-#: config/rs6000/rs6000.c:15938 config/rs6000/rs6000.c:15940
-#: config/rs6000/rs6000.c:15946 config/rs6000/rs6000.c:15948
-#: config/rs6000/rs6000.c:15955 config/rs6000/rs6000.c:15962
-#: config/rs6000/rs6000.c:15969 config/rs6000/rs6000.c:15975
+#: config/rs6000/rs6000.c:15978 config/rs6000/rs6000.c:15980
+#: config/rs6000/rs6000.c:15982 config/rs6000/rs6000.c:15984
+#: config/rs6000/rs6000.c:15990 config/rs6000/rs6000.c:15992
+#: config/rs6000/rs6000.c:15999 config/rs6000/rs6000.c:16006
+#: config/rs6000/rs6000.c:16011 config/rs6000/rs6000.c:16014
+#: config/rs6000/rs6000.c:16018 config/rs6000/rs6000.c:16024
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs requires the %qs option"
 msgstr "內建函式 %s 需求 -mvsx 選項"
 
-#: config/rs6000/rs6000.c:15943 config/rs6000/rs6000.c:15952
-#: config/rs6000/rs6000.c:15959 config/rs6000/rs6000.c:15966
+#: config/rs6000/rs6000.c:15987 config/rs6000/rs6000.c:15996
+#: config/rs6000/rs6000.c:16003
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs requires the %qs and %qs options"
 msgstr "內建函式 %s 需求 -mvsx 選項"
 
-#: config/rs6000/rs6000.c:15972
+#: config/rs6000/rs6000.c:16021
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs requires ISA 3.0 IEEE 128-bit floating point"
 msgstr "內建函式 %s 需求 -mpaired 選項"
 
-#: config/rs6000/rs6000.c:15978
+#: config/rs6000/rs6000.c:16027
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs requires the %qs (or newer), and %qs or %qs options"
 msgstr "內建函式 %s 需求 -mspe 選項"
 
-#: config/rs6000/rs6000.c:15982
+#: config/rs6000/rs6000.c:16031
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs is not supported with the current options"
 msgstr "內建函式 %s 未被支援與目前的選項"
 
-#: config/rs6000/rs6000.c:18218
+#: config/rs6000/rs6000.c:18290
 #, fuzzy, gcc-internal-format
 msgid "internal error: builtin function %qs had an unexpected return type %qs"
 msgstr "內部錯誤：內建函式 %s 有未預期的傳回類型 %s"
 
-#: config/rs6000/rs6000.c:18235
+#: config/rs6000/rs6000.c:18307
 #, fuzzy, gcc-internal-format
 msgid "internal error: builtin function %qs, argument %d had unexpected argument type %qs"
 msgstr "內部錯誤：內建函式 %s，引數 %d 已未預期的引數類型 %s"
 
-#: config/rs6000/rs6000.c:29451
+#: config/rs6000/rs6000.c:29528
 #, fuzzy, gcc-internal-format
 #| msgid "Use registers r2 and r5"
 msgid "%qs uses register r29"
 msgstr "使用暫存器 r2 和 r5"
 
-#: config/rs6000/rs6000.c:32748
+#: config/rs6000/rs6000.c:32825
 #, fuzzy, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "您無法需位址的巢狀的函式如果您使用 -mno-pointers-to-nested-functions 選項。"
 
-#: config/rs6000/rs6000.c:32842
+#: config/rs6000/rs6000.c:32919
 #, fuzzy, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "使用的 %<long%> 在中 AltiVec 類型無效用於 64-bit 編碼而無需 -mvsx"
 
-#: config/rs6000/rs6000.c:32850
+#: config/rs6000/rs6000.c:32927
 #, fuzzy, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "使用的 %<long long%> 在中 AltiVec 類型無效而無需 -mvsx"
 
-#: config/rs6000/rs6000.c:32853
+#: config/rs6000/rs6000.c:32930
 #, fuzzy, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "使用的 %<double%> 在中 AltiVec 類型無效而無需 -mvsx"
 
-#: config/rs6000/rs6000.c:36876
+#: config/rs6000/rs6000.c:36932
 #, fuzzy, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "無效的 cpu「%s」用於 %s「%s」%s"
 
-#: config/rs6000/rs6000.c:36879
+#: config/rs6000/rs6000.c:36935
 #, fuzzy, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr "%s「%s」%s 未被允許"
 
-#: config/rs6000/rs6000.c:36881
+#: config/rs6000/rs6000.c:36937
 #, fuzzy, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr "%s「%s」%s 無效"
 
-#: config/rs6000/rs6000.c:37416
+#: config/rs6000/rs6000.c:37472
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:37575
+#: config/rs6000/rs6000.c:37631
 #, gcc-internal-format
 msgid "target_clones attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
@@ -36653,49 +36696,49 @@
 msgid "subprogram %q+F not marked Inline"
 msgstr ""
 
-#: ada/gcc-interface/trans.c:6404
+#: ada/gcc-interface/trans.c:6401
 #, gcc-internal-format
 msgid "out-of-bounds access may be optimized away"
 msgstr ""
 
-#: ada/gcc-interface/trans.c:6406
+#: ada/gcc-interface/trans.c:6403
 #, gcc-internal-format
 msgid "containing loop"
 msgstr ""
 
-#: ada/gcc-interface/utils.c:3887
+#: ada/gcc-interface/utils.c:3890
 #, fuzzy, gcc-internal-format
 msgid "invalid element type for attribute %qs"
 msgstr "無效的元件類型用於屬性 %qs"
 
-#: ada/gcc-interface/utils.c:3911
+#: ada/gcc-interface/utils.c:3914
 #, fuzzy, gcc-internal-format
 #| msgid "number of components of the vector not a power of two"
 msgid "number of components of vector not a power of two"
 msgstr "向量中分量數不是 2 的某次方"
 
-#: ada/gcc-interface/utils.c:6037 ada/gcc-interface/utils.c:6215
-#: ada/gcc-interface/utils.c:6322
+#: ada/gcc-interface/utils.c:6043 ada/gcc-interface/utils.c:6220
+#: ada/gcc-interface/utils.c:6327
 #, gcc-internal-format
 msgid "%qs attribute ignored"
 msgstr "忽略 %qs 屬性"
 
-#: ada/gcc-interface/utils.c:6158
+#: ada/gcc-interface/utils.c:6164
 #, fuzzy, gcc-internal-format
 msgid "%qs attribute requires prototypes with named arguments"
 msgstr "%qs 屬性需求原型與具名引數"
 
-#: ada/gcc-interface/utils.c:6167
+#: ada/gcc-interface/utils.c:6173
 #, fuzzy, gcc-internal-format
 msgid "%qs attribute only applies to variadic functions"
 msgstr "%qs 屬性只有套用到 variadic 函式"
 
-#: ada/gcc-interface/utils.c:6282
+#: ada/gcc-interface/utils.c:6287
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute has no effect"
 msgstr "%qE 屬性沒有任何效果"
 
-#: ada/gcc-interface/utils.c:6406
+#: ada/gcc-interface/utils.c:6411
 #, fuzzy, gcc-internal-format
 msgid "attribute %qs applies to array types only"
 msgstr "屬性 %qs 套用到陣列類型只有"
@@ -36710,7 +36753,7 @@
 #. an unprototyped function, it is compile-time undefined;
 #. making it a constraint in that case was rejected in
 #. DR#252.
-#: c/c-convert.c:101 c/c-typeck.c:2175 c/c-typeck.c:6507 c/c-typeck.c:12138
+#: c/c-convert.c:101 c/c-typeck.c:2175 c/c-typeck.c:6512 c/c-typeck.c:12143
 #: cp/typeck.c:2027 cp/typeck.c:7977 cp/typeck.c:8742
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
@@ -36771,7 +36814,7 @@
 msgid "type of array %q+D completed incompatibly with implicit initialization"
 msgstr "陣列 %q+D 類型與隱含初始化不相容"
 
-#: c/c-decl.c:1567 c/c-decl.c:6701 c/c-decl.c:7574 c/c-decl.c:8381
+#: c/c-decl.c:1567 c/c-decl.c:6721 c/c-decl.c:7594 c/c-decl.c:8401
 #, fuzzy, gcc-internal-format
 msgid "originally defined here"
 msgstr "原本地定義的在此"
@@ -37179,16 +37222,11 @@
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.c:4548 c/c-decl.c:7147
+#: c/c-decl.c:4548 c/c-decl.c:7167
 #, fuzzy, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr "%<[*]%>不允許在中不同於函式原型範圍"
 
-#: c/c-decl.c:4635 cp/decl2.c:1520
-#, gcc-internal-format
-msgid "%q+D in declare target directive does not have mappable type"
-msgstr ""
-
 #: c/c-decl.c:4693
 #, gcc-internal-format
 msgid "%q+D is usually a function"
@@ -37214,7 +37252,7 @@
 #. of VLAs themselves count as VLAs, it does not make
 #. sense to permit them to be initialized given that
 #. ordinary VLAs may not be initialized.
-#: c/c-decl.c:4732 c/c-decl.c:4747 c/c-typeck.c:7630
+#: c/c-decl.c:4732 c/c-decl.c:4747 c/c-typeck.c:7635
 #, gcc-internal-format
 msgid "variable-sized object may not be initialized"
 msgstr "可變大小的物件不能被初始化"
@@ -37274,205 +37312,210 @@
 msgid "uninitialized const %qD is invalid in C++"
 msgstr "uninitialized 常數 %qD 無效在中 C++"
 
-#: c/c-decl.c:5268
+#: c/c-decl.c:5224 cp/decl.c:7318
 #, gcc-internal-format
+msgid "%q+D in declare target directive does not have mappable type"
+msgstr ""
+
+#: c/c-decl.c:5288
+#, gcc-internal-format
 msgid "ISO C forbids forward parameter declarations"
 msgstr "ISO C 不允許前向參數宣告"
 
-#: c/c-decl.c:5371
+#: c/c-decl.c:5391
 #, fuzzy, gcc-internal-format
 msgid "defining a type in a compound literal is invalid in C++"
 msgstr "定義輸入複合實字無效在中 C++"
 
-#: c/c-decl.c:5425 c/c-decl.c:5440
+#: c/c-decl.c:5445 c/c-decl.c:5460
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant"
 msgstr "位元段 %qs 的寬度不是一個整數常數"
 
-#: c/c-decl.c:5435
+#: c/c-decl.c:5455
 #, fuzzy, gcc-internal-format
 msgid "bit-field %qs width not an integer constant expression"
 msgstr "bit-field %qs 寬度不是整數常數運算式"
 
-#: c/c-decl.c:5446
+#: c/c-decl.c:5466
 #, gcc-internal-format
 msgid "negative width in bit-field %qs"
 msgstr "位元段 %qs 寬度為負"
 
-#: c/c-decl.c:5451
+#: c/c-decl.c:5471
 #, gcc-internal-format
 msgid "zero width for bit-field %qs"
 msgstr "位元段 %qs 寬度為 0"
 
-#: c/c-decl.c:5461
+#: c/c-decl.c:5481
 #, gcc-internal-format
 msgid "bit-field %qs has invalid type"
 msgstr "位元段 %qs 類型無效"
 
-#: c/c-decl.c:5467
+#: c/c-decl.c:5487
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare bit-field %qD with function type"
 msgid "cannot declare bit-field %qs with %<warn_if_not_aligned%> type"
 msgstr "不能將位元段 %qD 宣告為函式類型"
 
-#: c/c-decl.c:5478
+#: c/c-decl.c:5498
 #, gcc-internal-format
 msgid "type of bit-field %qs is a GCC extension"
 msgstr "位元段類型 %qs 是一個 GCC 擴充"
 
-#: c/c-decl.c:5484
+#: c/c-decl.c:5504
 #, gcc-internal-format
 msgid "width of %qs exceeds its type"
 msgstr "%qs 的寬度超過它自身的類型"
 
-#: c/c-decl.c:5497
+#: c/c-decl.c:5517
 #, gcc-internal-format
 msgid "%qs is narrower than values of its type"
 msgstr "%qs 比其類型的值要窄"
 
-#: c/c-decl.c:5512
+#: c/c-decl.c:5532
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 forbids array %qE whose size can%'t be evaluated"
 msgstr "ISO C90 禁止陣列 %qE 其大小 can%'t 被評估"
 
-#: c/c-decl.c:5515
+#: c/c-decl.c:5535
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 forbids array whose size can%'t be evaluated"
 msgstr "ISO C90 禁止陣列其大小 can%'t 被評估"
 
-#: c/c-decl.c:5522
+#: c/c-decl.c:5542
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 forbids variable length array %qE"
 msgstr "ISO C90 禁止變數長度陣列 %qE"
 
-#: c/c-decl.c:5524
+#: c/c-decl.c:5544
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 forbids variable length array"
 msgstr "ISO C90 禁止變數長度陣列"
 
-#: c/c-decl.c:5733 c/c-decl.c:6107 c/c-decl.c:6117
+#: c/c-decl.c:5753 c/c-decl.c:6127 c/c-decl.c:6137
 #, fuzzy, gcc-internal-format
 msgid "variably modified %qE at file scope"
 msgstr "variably 已修改 %qE 於檔案範圍"
 
-#: c/c-decl.c:5735
+#: c/c-decl.c:5755
 #, fuzzy, gcc-internal-format
 msgid "variably modified field at file scope"
 msgstr "variably 已修改欄位於檔案範圍"
 
-#: c/c-decl.c:5755
+#: c/c-decl.c:5775
 #, fuzzy, gcc-internal-format
 msgid "type defaults to %<int%> in declaration of %qE"
 msgstr "型態預設值到 %<int%> 在中宣告的 %qE"
 
-#: c/c-decl.c:5759
+#: c/c-decl.c:5779
 #, fuzzy, gcc-internal-format
 msgid "type defaults to %<int%> in type name"
 msgstr "型態預設值到 %<int%> 在中型態名稱"
 
-#: c/c-decl.c:5791
+#: c/c-decl.c:5811
 #, gcc-internal-format
 msgid "duplicate %<const%>"
 msgstr "重複的 %<const%>"
 
-#: c/c-decl.c:5793
+#: c/c-decl.c:5813
 #, gcc-internal-format
 msgid "duplicate %<restrict%>"
 msgstr "重複的 %<restrict%>"
 
-#: c/c-decl.c:5795
+#: c/c-decl.c:5815
 #, gcc-internal-format
 msgid "duplicate %<volatile%>"
 msgstr "重複的 %<volatile%>"
 
-#: c/c-decl.c:5797
+#: c/c-decl.c:5817
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<restrict%>"
 msgid "duplicate %<_Atomic%>"
 msgstr "重複的 %<restrict%>"
 
-#: c/c-decl.c:5800
+#: c/c-decl.c:5820
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "conflicting named address spaces (%s vs %s)"
 msgstr "衝突具名的位址空間 (%s vs %s)"
 
-#: c/c-decl.c:5823 c/c-parser.c:2821
+#: c/c-decl.c:5843 c/c-parser.c:2821
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified array type"
 msgstr ""
 
-#: c/c-decl.c:5837
+#: c/c-decl.c:5857
 #, gcc-internal-format
 msgid "function definition declared %<auto%>"
 msgstr "函式宣告定義為 %<auto%>"
 
-#: c/c-decl.c:5839
+#: c/c-decl.c:5859
 #, gcc-internal-format
 msgid "function definition declared %<register%>"
 msgstr "函式宣告定義為 %<register%>"
 
-#: c/c-decl.c:5841
+#: c/c-decl.c:5861
 #, gcc-internal-format
 msgid "function definition declared %<typedef%>"
 msgstr "函式宣告定義為 %<typedef%>"
 
-#: c/c-decl.c:5843
+#: c/c-decl.c:5863
 #, fuzzy, gcc-internal-format
 #| msgid "function definition declared %<auto%>"
 msgid "function definition declared %qs"
 msgstr "函式宣告定義為 %<auto%>"
 
-#: c/c-decl.c:5861
+#: c/c-decl.c:5881
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for structure field %qE"
 msgstr "貯藏類別指定的用於結構欄位 %qE"
 
-#: c/c-decl.c:5864
+#: c/c-decl.c:5884
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for structure field"
 msgstr "貯藏類別指定的用於結構欄位"
 
-#: c/c-decl.c:5868
+#: c/c-decl.c:5888
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for parameter %qE"
 msgstr "貯藏類別指定的用於參數 %qE"
 
-#: c/c-decl.c:5871
+#: c/c-decl.c:5891
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for unnamed parameter"
 msgstr "貯藏類別指定的用於未命名參數"
 
-#: c/c-decl.c:5874 cp/decl.c:10935
+#: c/c-decl.c:5894 cp/decl.c:10959
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "為類型名指定了存儲類別"
 
-#: c/c-decl.c:5891
+#: c/c-decl.c:5911
 #, fuzzy, gcc-internal-format
 msgid "%qE initialized and declared %<extern%>"
 msgstr "%qE 初始化的和宣告 %<extern%>"
 
-#: c/c-decl.c:5895
+#: c/c-decl.c:5915
 #, fuzzy, gcc-internal-format
 msgid "%qE has both %<extern%> and initializer"
 msgstr "%qE 同時有 %<extern%> 和初始設定式"
 
-#: c/c-decl.c:5900
+#: c/c-decl.c:5920
 #, fuzzy, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<auto%>"
 msgstr "file-scope 宣告的 %qE 指定 %<auto%>"
 
-#: c/c-decl.c:5904
+#: c/c-decl.c:5924
 #, fuzzy, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<register%>"
 msgstr "file-scope 宣告的 %qE 指定 %<register%>"
 
-#: c/c-decl.c:5909
+#: c/c-decl.c:5929
 #, fuzzy, gcc-internal-format
 msgid "nested function %qE declared %<extern%>"
 msgstr "巢狀的函式 %qE 宣告 %<extern%>"
 
-#: c/c-decl.c:5912
+#: c/c-decl.c:5932
 #, fuzzy, gcc-internal-format
 msgid "function-scope %qE implicitly auto and declared %qs"
 msgstr "function-scope %qE 隱含地自動和宣告 %<__thread%>"
@@ -37480,708 +37523,708 @@
 #. Only the innermost declarator (making a parameter be of
 #. array type which is converted to pointer type)
 #. may have static or type qualifiers.
-#: c/c-decl.c:5959 c/c-decl.c:6328
+#: c/c-decl.c:5979 c/c-decl.c:6348
 #, gcc-internal-format
 msgid "static or type qualifiers in non-parameter array declarator"
 msgstr "static 或類型限定符出現在非參數陣列宣告中"
 
-#: c/c-decl.c:6007
+#: c/c-decl.c:6027
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qE as array of voids"
 msgstr "宣告的 %qE 做為陣列的虛值"
 
-#: c/c-decl.c:6009
+#: c/c-decl.c:6029
 #, fuzzy, gcc-internal-format
 msgid "declaration of type name as array of voids"
 msgstr "宣告的型態名稱做為陣列的虛值"
 
-#: c/c-decl.c:6016
+#: c/c-decl.c:6036
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qE as array of functions"
 msgstr "宣告的 %qE 做為陣列的函式"
 
-#: c/c-decl.c:6019
+#: c/c-decl.c:6039
 #, fuzzy, gcc-internal-format
 msgid "declaration of type name as array of functions"
 msgstr "宣告的型態名稱做為陣列的函式"
 
-#: c/c-decl.c:6027 c/c-decl.c:8085
+#: c/c-decl.c:6047 c/c-decl.c:8105
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr "對包含彈性陣列成員的結構的無效使用"
 
-#: c/c-decl.c:6053
+#: c/c-decl.c:6073
 #, fuzzy, gcc-internal-format
 msgid "size of array %qE has non-integer type"
 msgstr "大小的陣列 %qE 有 non-integer 型態"
 
-#: c/c-decl.c:6057
+#: c/c-decl.c:6077
 #, fuzzy, gcc-internal-format
 msgid "size of unnamed array has non-integer type"
 msgstr "大小的未命名陣列有 non-integer 型態"
 
-#: c/c-decl.c:6064
+#: c/c-decl.c:6084
 #, fuzzy, gcc-internal-format
 msgid "size of array %qE has incomplete type"
 msgstr "大小的陣列 %qE 有 non-integer 型態"
 
-#: c/c-decl.c:6067
+#: c/c-decl.c:6087
 #, fuzzy, gcc-internal-format
 msgid "size of unnamed array has incomplete type"
 msgstr "大小的未命名陣列有 non-integer 型態"
 
-#: c/c-decl.c:6078
+#: c/c-decl.c:6098
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids zero-size array %qE"
 msgstr "ISO C 禁止 zero-size 陣列 %qE"
 
-#: c/c-decl.c:6081
+#: c/c-decl.c:6101
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids zero-size array"
 msgstr "ISO C 禁止 zero-size 陣列"
 
-#: c/c-decl.c:6090
+#: c/c-decl.c:6110
 #, fuzzy, gcc-internal-format
 msgid "size of array %qE is negative"
 msgstr "大小的陣列 %qE 是負"
 
-#: c/c-decl.c:6092
+#: c/c-decl.c:6112
 #, fuzzy, gcc-internal-format
 msgid "size of unnamed array is negative"
 msgstr "大小的未命名陣列是負"
 
-#: c/c-decl.c:6216 c/c-decl.c:6871
+#: c/c-decl.c:6236 c/c-decl.c:6891
 #, gcc-internal-format
 msgid "ISO C90 does not support flexible array members"
 msgstr "ISO C90 不允許彈性陣列成員"
 
 #. C99 6.7.5.2p4
-#: c/c-decl.c:6238
+#: c/c-decl.c:6258
 #, fuzzy, gcc-internal-format
 msgid "%<[*]%> not in a declaration"
 msgstr "%<[*]%>無法在中宣告"
 
-#: c/c-decl.c:6251
+#: c/c-decl.c:6271
 #, fuzzy, gcc-internal-format
 #| msgid "array type has incomplete element type"
 msgid "array type has incomplete element type %qT"
 msgstr "陣列元素的類型不完全"
 
-#: c/c-decl.c:6257
+#: c/c-decl.c:6277
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgid "declaration of %qE as multidimensional array must have bounds for all dimensions except the first"
 msgstr "多維陣列 %qD 的宣告必須至少指定除第一維以外所有維的大小"
 
-#: c/c-decl.c:6261
+#: c/c-decl.c:6281
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgid "declaration of multidimensional array must have bounds for all dimensions except the first"
 msgstr "多維陣列 %qD 的宣告必須至少指定除第一維以外所有維的大小"
 
-#: c/c-decl.c:6364
+#: c/c-decl.c:6384
 #, fuzzy, gcc-internal-format
 msgid "%qE declared as function returning a function"
 msgstr "%qE 宣告的做為函式回傳函式"
 
-#: c/c-decl.c:6367
+#: c/c-decl.c:6387
 #, fuzzy, gcc-internal-format
 msgid "type name declared as function returning a function"
 msgstr "型態名稱宣告的做為函式回傳函式"
 
-#: c/c-decl.c:6374
+#: c/c-decl.c:6394
 #, fuzzy, gcc-internal-format
 msgid "%qE declared as function returning an array"
 msgstr "%qE 宣告的做為函式回傳陣列"
 
-#: c/c-decl.c:6377
+#: c/c-decl.c:6397
 #, fuzzy, gcc-internal-format
 msgid "type name declared as function returning an array"
 msgstr "型態名稱宣告的做為函式回傳陣列"
 
-#: c/c-decl.c:6418
+#: c/c-decl.c:6438
 #, gcc-internal-format
 msgid "function definition has qualified void return type"
 msgstr "函式定義有限定的 void 回傳類型"
 
-#: c/c-decl.c:6421 cp/decl.c:11201
+#: c/c-decl.c:6441 cp/decl.c:11225
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "忽略函式回傳類型的類型限定"
 
-#: c/c-decl.c:6459 c/c-decl.c:6668 c/c-decl.c:6721 c/c-decl.c:6805
-#: c/c-decl.c:6926 c/c-parser.c:2823
+#: c/c-decl.c:6479 c/c-decl.c:6688 c/c-decl.c:6741 c/c-decl.c:6825
+#: c/c-decl.c:6946 c/c-parser.c:2823
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids qualified function types"
 msgid "%<_Atomic%>-qualified function type"
 msgstr "ISO C 不允許使用 const 或 volatile 限定函式類型"
 
-#: c/c-decl.c:6465 c/c-decl.c:6674 c/c-decl.c:6810 c/c-decl.c:6931
+#: c/c-decl.c:6485 c/c-decl.c:6694 c/c-decl.c:6830 c/c-decl.c:6951
 #, gcc-internal-format
 msgid "ISO C forbids qualified function types"
 msgstr "ISO C 不允許使用 const 或 volatile 限定函式類型"
 
-#: c/c-decl.c:6559
+#: c/c-decl.c:6579
 #, fuzzy, gcc-internal-format
 msgid "%qs combined with %<auto%> qualifier for %qE"
 msgstr "%qs 合併的與 %<auto%> 限定元用於 %qE"
 
-#: c/c-decl.c:6563
+#: c/c-decl.c:6583
 #, fuzzy, gcc-internal-format
 msgid "%qs combined with %<register%> qualifier for %qE"
 msgstr "%qs 合併的與 %<register%> 限定元用於 %qE"
 
-#: c/c-decl.c:6569
+#: c/c-decl.c:6589
 #, fuzzy, gcc-internal-format
 msgid "%qs specified for auto variable %qE"
 msgstr "%qs 指定的用於自動變數 %qE"
 
-#: c/c-decl.c:6585
+#: c/c-decl.c:6605
 #, fuzzy, gcc-internal-format
 msgid "%qs specified for parameter %qE"
 msgstr "%qs 指定的用於參數 %qE"
 
-#: c/c-decl.c:6588
+#: c/c-decl.c:6608
 #, fuzzy, gcc-internal-format
 msgid "%qs specified for unnamed parameter"
 msgstr "%qs 指定的用於未命名參數"
 
-#: c/c-decl.c:6594
+#: c/c-decl.c:6614
 #, fuzzy, gcc-internal-format
 msgid "%qs specified for structure field %qE"
 msgstr "%qs 指定的用於結構欄位 %qE"
 
-#: c/c-decl.c:6597
+#: c/c-decl.c:6617
 #, fuzzy, gcc-internal-format
 msgid "%qs specified for structure field"
 msgstr "%qs 指定的用於結構欄位"
 
-#: c/c-decl.c:6612
+#: c/c-decl.c:6632
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qs has invalid type"
 msgid "bit-field %qE has atomic type"
 msgstr "位元段 %qs 類型無效"
 
-#: c/c-decl.c:6614
+#: c/c-decl.c:6634
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qs has invalid type"
 msgid "bit-field has atomic type"
 msgstr "位元段 %qs 類型無效"
 
-#: c/c-decl.c:6623
+#: c/c-decl.c:6643
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for typedef %qE"
 msgstr "對齊指定的用於 typedef %qE"
 
-#: c/c-decl.c:6625
+#: c/c-decl.c:6645
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for %<register%> object %qE"
 msgstr "對齊指定的用於 %<register%> 物件 %qE"
 
-#: c/c-decl.c:6630
+#: c/c-decl.c:6650
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for parameter %qE"
 msgstr "對齊指定的用於參數 %qE"
 
-#: c/c-decl.c:6632
+#: c/c-decl.c:6652
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for unnamed parameter"
 msgstr "對齊指定的用於未命名參數"
 
-#: c/c-decl.c:6637
+#: c/c-decl.c:6657
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for bit-field %qE"
 msgstr "對齊指定的用於 bit-field %qE"
 
-#: c/c-decl.c:6639
+#: c/c-decl.c:6659
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for unnamed bit-field"
 msgstr "對齊指定的用於未命名 bit-field"
 
-#: c/c-decl.c:6642
+#: c/c-decl.c:6662
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for function %qE"
 msgstr "對齊指定的用於函式 %qE"
 
-#: c/c-decl.c:6649
+#: c/c-decl.c:6669
 #, fuzzy, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of %qE"
 msgstr "%<Alignas%(_A)>說明符無法縮小對齊的 %qE"
 
-#: c/c-decl.c:6652
+#: c/c-decl.c:6672
 #, fuzzy, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of unnamed field"
 msgstr "%<Alignas%(_A)>說明符無法縮小對齊的未命名欄位"
 
-#: c/c-decl.c:6683
+#: c/c-decl.c:6703
 #, gcc-internal-format
 msgid "typedef %q+D declared %<inline%>"
 msgstr "typedef %q+D 宣告為 %<inline%>"
 
-#: c/c-decl.c:6685
+#: c/c-decl.c:6705
 #, fuzzy, gcc-internal-format
 msgid "typedef %q+D declared %<_Noreturn%>"
 msgstr "typedef %q+D 宣告 %<Noreturn%(_N)>"
 
-#: c/c-decl.c:6727
+#: c/c-decl.c:6747
 #, gcc-internal-format
 msgid "ISO C forbids const or volatile function types"
 msgstr "ISO C 不允許使用 const 或 volatile 限定函式類型"
 
 #. C99 6.7.2.1p8
-#: c/c-decl.c:6738
+#: c/c-decl.c:6758
 #, fuzzy, gcc-internal-format
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "成員的結構或聯合無法有 variably 已修改型態"
 
-#: c/c-decl.c:6755 cp/decl.c:9989
+#: c/c-decl.c:6775 cp/decl.c:10010
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "變數或欄位 %qE 宣告為 void"
 
-#: c/c-decl.c:6795
+#: c/c-decl.c:6815
 #, gcc-internal-format
 msgid "attributes in parameter array declarator ignored"
 msgstr "出現在參數陣列宣告中的屬性被忽略"
 
-#: c/c-decl.c:6837
+#: c/c-decl.c:6857
 #, gcc-internal-format
 msgid "parameter %q+D declared %<inline%>"
 msgstr "參數 %q+D 宣告為 %<inline%>"
 
-#: c/c-decl.c:6839
+#: c/c-decl.c:6859
 #, fuzzy, gcc-internal-format
 msgid "parameter %q+D declared %<_Noreturn%>"
 msgstr "參數 %q+D 宣告 %<Noreturn%(_N)>"
 
-#: c/c-decl.c:6852
+#: c/c-decl.c:6872
 #, fuzzy, gcc-internal-format
 msgid "field %qE declared as a function"
 msgstr "欄位 %qE 宣告的做為函式"
 
-#: c/c-decl.c:6859
+#: c/c-decl.c:6879
 #, fuzzy, gcc-internal-format
 msgid "field %qE has incomplete type"
 msgstr "欄位 %qE 有不完整型態"
 
-#: c/c-decl.c:6861
+#: c/c-decl.c:6881
 #, fuzzy, gcc-internal-format
 msgid "unnamed field has incomplete type"
 msgstr "未命名欄位有不完整型態"
 
-#: c/c-decl.c:6897 c/c-decl.c:6908 c/c-decl.c:6911
+#: c/c-decl.c:6917 c/c-decl.c:6928 c/c-decl.c:6931
 #, fuzzy, gcc-internal-format
 msgid "invalid storage class for function %qE"
 msgstr "無效的貯藏類別用於函式 %qE"
 
-#: c/c-decl.c:6968
+#: c/c-decl.c:6988
 #, gcc-internal-format
 msgid "cannot inline function %<main%>"
 msgstr "不能內聯 %<main%> 函式"
 
-#: c/c-decl.c:6970
+#: c/c-decl.c:6990
 #, fuzzy, gcc-internal-format
 msgid "%<main%> declared %<_Noreturn%>"
 msgstr "%<main%> 宣告 %<Noreturn%(_N)>"
 
-#: c/c-decl.c:6981
+#: c/c-decl.c:7001
 #, fuzzy, gcc-internal-format
 msgid "ISO C99 does not support %<_Noreturn%>"
 msgstr "ISO C99 不支援 %<Noreturn%(_N)>"
 
-#: c/c-decl.c:6984
+#: c/c-decl.c:7004
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support %<_Noreturn%>"
 msgstr "ISO C90 不支援 %<Noreturn%(_N)>"
 
-#: c/c-decl.c:7013
+#: c/c-decl.c:7033
 #, gcc-internal-format
 msgid "variable previously declared %<static%> redeclared %<extern%>"
 msgstr "先前被宣告為 %<static%> 的變數重宣告為 %<extern%>"
 
-#: c/c-decl.c:7023
+#: c/c-decl.c:7043
 #, gcc-internal-format
 msgid "variable %q+D declared %<inline%>"
 msgstr "變數 %q+D 宣告為 %<inline%>"
 
-#: c/c-decl.c:7025
+#: c/c-decl.c:7045
 #, fuzzy, gcc-internal-format
 msgid "variable %q+D declared %<_Noreturn%>"
 msgstr "變數 %q+D 宣告 %<Noreturn%(_N)>"
 
-#: c/c-decl.c:7060
+#: c/c-decl.c:7080
 #, fuzzy, gcc-internal-format
 msgid "non-nested function with variably modified type"
 msgstr "non-nested 函式與 variably 已修改型態"
 
-#: c/c-decl.c:7062
+#: c/c-decl.c:7082
 #, fuzzy, gcc-internal-format
 msgid "object with variably modified type must have no linkage"
 msgstr "物件與 variably 已修改型態必須沒有任何鏈結"
 
-#: c/c-decl.c:7153 c/c-decl.c:8821
+#: c/c-decl.c:7173 c/c-decl.c:8841
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr "函式宣告不是一個原型"
 
-#: c/c-decl.c:7163
+#: c/c-decl.c:7183
 #, gcc-internal-format
 msgid "parameter names (without types) in function declaration"
 msgstr "函式宣告中出現參數名卻未指定類型"
 
-#: c/c-decl.c:7201
+#: c/c-decl.c:7221
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has incomplete type"
 msgstr "參數 %u (%q+D) 的類型不完全"
 
-#: c/c-decl.c:7205
+#: c/c-decl.c:7225
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has incomplete type"
 msgstr "參數 %u 有不完整型態"
 
-#: c/c-decl.c:7216
+#: c/c-decl.c:7236
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has void type"
 msgstr "參數 %u (%q+D)類型為 void"
 
-#: c/c-decl.c:7220
+#: c/c-decl.c:7240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has void type"
 msgstr "參數 %u 有虛值型態"
 
-#: c/c-decl.c:7294
+#: c/c-decl.c:7314
 #, gcc-internal-format
 msgid "%<void%> as only parameter may not be qualified"
 msgstr "%<void%> 做為僅有的參數時不能被限定"
 
-#: c/c-decl.c:7298 c/c-decl.c:7334
+#: c/c-decl.c:7318 c/c-decl.c:7354
 #, gcc-internal-format
 msgid "%<void%> must be the only parameter"
 msgstr "%<void%> 必須是僅有的參數"
 
-#: c/c-decl.c:7328
+#: c/c-decl.c:7348
 #, gcc-internal-format
 msgid "parameter %q+D has just a forward declaration"
 msgstr "參數 %q+D 有一個前向宣告"
 
-#: c/c-decl.c:7374
+#: c/c-decl.c:7394
 #, gcc-internal-format
 msgid "%<%s %E%> declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr ""
 
-#: c/c-decl.c:7380
+#: c/c-decl.c:7400
 #, gcc-internal-format, gfc-internal-format
 msgid "anonymous %s declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr ""
 
-#: c/c-decl.c:7482
+#: c/c-decl.c:7502
 #, fuzzy, gcc-internal-format
 msgid "enum type defined here"
 msgstr "enum 型態定義的在此"
 
-#: c/c-decl.c:7488
+#: c/c-decl.c:7508
 #, fuzzy, gcc-internal-format
 msgid "struct defined here"
 msgstr "結構定義的在此"
 
-#: c/c-decl.c:7494
+#: c/c-decl.c:7514
 #, fuzzy, gcc-internal-format
 msgid "union defined here"
 msgstr "聯合定義的在此"
 
-#: c/c-decl.c:7570
+#: c/c-decl.c:7590
 #, gcc-internal-format
 msgid "redefinition of %<union %E%>"
 msgstr "%<union %E%> 重定義"
 
-#: c/c-decl.c:7572
+#: c/c-decl.c:7592
 #, gcc-internal-format
 msgid "redefinition of %<struct %E%>"
 msgstr "%<struct %E%> 重定義"
 
-#: c/c-decl.c:7581
+#: c/c-decl.c:7601
 #, gcc-internal-format
 msgid "nested redefinition of %<union %E%>"
 msgstr "巢狀的 %<union %E%> 重定義"
 
-#: c/c-decl.c:7583
+#: c/c-decl.c:7603
 #, gcc-internal-format
 msgid "nested redefinition of %<struct %E%>"
 msgstr "巢狀的 %<struct %E%> 重定義"
 
-#: c/c-decl.c:7613 c/c-decl.c:8400
+#: c/c-decl.c:7633 c/c-decl.c:8420
 #, fuzzy, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr "定義輸入 %qs 運算式無效在中 C++"
 
-#: c/c-decl.c:7680 cp/decl.c:4802
+#: c/c-decl.c:7700 cp/decl.c:4802
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "沒有宣告任何東西"
 
-#: c/c-decl.c:7685
+#: c/c-decl.c:7705
 #, fuzzy, gcc-internal-format
 msgid "ISO C99 doesn%'t support unnamed structs/unions"
 msgstr "ISO C99 doesn%'t 支援未命名結構/聯合"
 
-#: c/c-decl.c:7688
+#: c/c-decl.c:7708
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 doesn%'t support unnamed structs/unions"
 msgstr "ISO C90 doesn%'t 支援未命名結構/聯合"
 
-#: c/c-decl.c:7781 c/c-decl.c:7799 c/c-decl.c:7860
+#: c/c-decl.c:7801 c/c-decl.c:7819 c/c-decl.c:7880
 #, gcc-internal-format
 msgid "duplicate member %q+D"
 msgstr "重複的成員 %q+D"
 
-#: c/c-decl.c:7886
+#: c/c-decl.c:7906
 #, gcc-internal-format
 msgid "empty struct has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.c:7889
+#: c/c-decl.c:7909
 #, gcc-internal-format
 msgid "empty union has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.c:7994
+#: c/c-decl.c:8014
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr "聯合包含無名成員"
 
-#: c/c-decl.c:7996
+#: c/c-decl.c:8016
 #, gcc-internal-format
 msgid "union has no members"
 msgstr "聯合體沒有成員"
 
-#: c/c-decl.c:8001
+#: c/c-decl.c:8021
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr "結構不包含任何具名成員"
 
-#: c/c-decl.c:8003
+#: c/c-decl.c:8023
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr "結構體沒有成員"
 
-#: c/c-decl.c:8064 cp/decl.c:12069
+#: c/c-decl.c:8084 cp/decl.c:12093
 #, fuzzy, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "flexible 陣列成員在中聯合"
 
-#: c/c-decl.c:8070
+#: c/c-decl.c:8090
 #, fuzzy, gcc-internal-format
 msgid "flexible array member not at end of struct"
 msgstr "flexible 陣列成員無法於結束的結構"
 
-#: c/c-decl.c:8076
+#: c/c-decl.c:8096
 #, fuzzy, gcc-internal-format
 msgid "flexible array member in a struct with no named members"
 msgstr "flexible 陣列成員在中聯合"
 
-#: c/c-decl.c:8107
+#: c/c-decl.c:8127
 #, fuzzy, gcc-internal-format
 msgid "type %qT is too large"
 msgstr "值傳遞在中 %qs 太大"
 
-#: c/c-decl.c:8230
+#: c/c-decl.c:8250
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr "聯合不能成為透明的"
 
-#: c/c-decl.c:8372
+#: c/c-decl.c:8392
 #, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr "巢狀的 %<enum %E%> 重定義"
 
 #. This enum is a named one that has been declared already.
-#: c/c-decl.c:8379
+#: c/c-decl.c:8399
 #, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr "%<enum %E%> 重宣告"
 
-#: c/c-decl.c:8458 cp/decl.c:14423
+#: c/c-decl.c:8478 cp/decl.c:14447
 #, gcc-internal-format
 msgid "specified mode too small for enumeral values"
 msgstr "指定的模式對列舉值來說太小"
 
-#: c/c-decl.c:8473
+#: c/c-decl.c:8493
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr "列舉值超過了最大整數類型可表示的範圍"
 
-#: c/c-decl.c:8587 c/c-decl.c:8603
+#: c/c-decl.c:8607 c/c-decl.c:8623
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr "%qE 的列舉值不是一個整數常數"
 
-#: c/c-decl.c:8598
+#: c/c-decl.c:8618
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr "列舉值值用於 %qE 不是整數常數運算式"
 
-#: c/c-decl.c:8622
+#: c/c-decl.c:8642
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr "列舉值溢出"
 
-#: c/c-decl.c:8630
+#: c/c-decl.c:8650
 #, gcc-internal-format
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "ISO C 將列舉值限制在 %<int%> 範圍內"
 
-#: c/c-decl.c:8715 cp/decl.c:5104 cp/decl.c:14955
+#: c/c-decl.c:8735 cp/decl.c:5104 cp/decl.c:14979
 #, fuzzy, gcc-internal-format
 msgid "inline function %qD given attribute noinline"
 msgstr "內聯函式 %qD 給定的屬性 noinline"
 
-#: c/c-decl.c:8733
+#: c/c-decl.c:8753
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr "回傳不完全的類型"
 
-#: c/c-decl.c:8744
+#: c/c-decl.c:8764
 #, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr "回傳類型預設為 %<int%>"
 
-#: c/c-decl.c:8771
+#: c/c-decl.c:8791
 #, fuzzy, gcc-internal-format
 #| msgid "Warn about global functions without prototypes"
 msgid "%q+D defined as variadic function without prototype"
 msgstr "全域函式沒有原型時給出警告"
 
-#: c/c-decl.c:8830
+#: c/c-decl.c:8850
 #, fuzzy, gcc-internal-format
 msgid "no previous prototype for %qD"
 msgstr "沒有前一個原型用於 %qD"
 
-#: c/c-decl.c:8839
+#: c/c-decl.c:8859
 #, fuzzy, gcc-internal-format
 msgid "%qD was used with no prototype before its definition"
 msgstr "%qD 被使用不具任何原型之前它的定義"
 
-#: c/c-decl.c:8847 cp/decl.c:15090
+#: c/c-decl.c:8867 cp/decl.c:15114
 #, fuzzy, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "沒有前一個宣告用於 %qD"
 
-#: c/c-decl.c:8857
+#: c/c-decl.c:8877
 #, fuzzy, gcc-internal-format
 msgid "%qD was used with no declaration before its definition"
 msgstr "%qD 被使用不具任何宣告之前它的定義"
 
-#: c/c-decl.c:8876
+#: c/c-decl.c:8896
 #, fuzzy, gcc-internal-format
 msgid "return type of %qD is not %<int%>"
 msgstr "傳回類型的 %qD 不是 %<int%>"
 
-#: c/c-decl.c:8878
+#: c/c-decl.c:8898
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr ""
 
-#: c/c-decl.c:8885
+#: c/c-decl.c:8905
 #, fuzzy, gcc-internal-format
 msgid "%qD is normally a non-static function"
 msgstr "%qD 是正常非靜態函式"
 
-#: c/c-decl.c:8922
+#: c/c-decl.c:8942
 #, fuzzy, gcc-internal-format
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr "舊式參數宣告在中原型的函式定義"
 
-#: c/c-decl.c:8937
+#: c/c-decl.c:8957
 #, fuzzy, gcc-internal-format
 msgid "traditional C rejects ISO C style function definitions"
 msgstr "傳統 C 拒絕 ISO C 樣式函式定義"
 
-#: c/c-decl.c:8953
+#: c/c-decl.c:8973
 #, fuzzy, gcc-internal-format
 msgid "parameter name omitted"
 msgstr "參數名稱省略"
 
-#: c/c-decl.c:8990
+#: c/c-decl.c:9010
 #, fuzzy, gcc-internal-format
 msgid "old-style function definition"
 msgstr "舊式函式定義"
 
-#: c/c-decl.c:8999
+#: c/c-decl.c:9019
 #, fuzzy, gcc-internal-format
 msgid "parameter name missing from parameter list"
 msgstr "參數名稱缺少的從參數清單"
 
-#: c/c-decl.c:9015
+#: c/c-decl.c:9035
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a non-parameter"
 msgstr "%qD 宣告的做為 non-parameter"
 
-#: c/c-decl.c:9023
+#: c/c-decl.c:9043
 #, fuzzy, gcc-internal-format
 msgid "multiple parameters named %qD"
 msgstr "多重參數具名的 %qD"
 
-#: c/c-decl.c:9032
+#: c/c-decl.c:9052
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD declared with void type"
 msgstr "參數 %qD 宣告的與虛值型態"
 
-#: c/c-decl.c:9061 c/c-decl.c:9066
+#: c/c-decl.c:9081 c/c-decl.c:9086
 #, fuzzy, gcc-internal-format
 msgid "type of %qD defaults to %<int%>"
 msgstr "型態的 %qD 預設值到 %<int%>"
 
-#: c/c-decl.c:9086
+#: c/c-decl.c:9106
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD has incomplete type"
 msgstr "參數 %qD 有不完整型態"
 
-#: c/c-decl.c:9093
+#: c/c-decl.c:9113
 #, fuzzy, gcc-internal-format
 msgid "declaration for parameter %qD but no such parameter"
 msgstr "宣告用於參數 %qD 但是沒有此類參數"
 
-#: c/c-decl.c:9146
+#: c/c-decl.c:9166
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr "引數個數與內建原型不符"
 
-#: c/c-decl.c:9157
+#: c/c-decl.c:9177
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr "引數數目與原型不符"
 
-#: c/c-decl.c:9160 c/c-decl.c:9207 c/c-decl.c:9221
+#: c/c-decl.c:9180 c/c-decl.c:9227 c/c-decl.c:9241
 #, fuzzy, gcc-internal-format
 msgid "prototype declaration"
 msgstr "原型宣告"
 
-#: c/c-decl.c:9199
+#: c/c-decl.c:9219
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr "提升後的引數 %qD 與內建原型不符"
 
-#: c/c-decl.c:9204
+#: c/c-decl.c:9224
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr "提升後的引數 %qD 與原型不符"
 
-#: c/c-decl.c:9214
+#: c/c-decl.c:9234
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr "引數 %qD 與內建原型不符"
 
-#: c/c-decl.c:9219
+#: c/c-decl.c:9239
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr "引數 %qD 與原型不符"
 
-#: c/c-decl.c:9470 cp/decl.c:15873
+#: c/c-decl.c:9490 cp/decl.c:15897
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "在有回傳值的函式中未發現 return 敘述"
 
-#: c/c-decl.c:9490 cp/decl.c:15905
+#: c/c-decl.c:9510 cp/decl.c:15929
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "參數 %qD 設定並不是使用"
@@ -38189,254 +38232,254 @@
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:9586
+#: c/c-decl.c:9606
 #, fuzzy, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "%<for%> 迴圈初始宣告是只有允許的在中 C99 模式"
 
-#: c/c-decl.c:9591
+#: c/c-decl.c:9611
 #, fuzzy, gcc-internal-format
 msgid "use option -std=c99, -std=gnu99, -std=c11 or -std=gnu11 to compile your code"
 msgstr "使用選項 -std=c99 或 -std=gnu99 到編譯您的編碼"
 
-#: c/c-decl.c:9626
+#: c/c-decl.c:9646
 #, fuzzy, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "宣告的靜態變數 %qD 在中 %<for%> 迴圈初始宣告"
 
-#: c/c-decl.c:9630
+#: c/c-decl.c:9650
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "宣告的 %<extern%> 變數 %qD 在中 %<for%>迴圈初始宣告"
 
-#: c/c-decl.c:9637
+#: c/c-decl.c:9657
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "%<struct %E%> 宣告於 %<for%> 循環初始宣告中"
 
-#: c/c-decl.c:9642
+#: c/c-decl.c:9662
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "%<union %E%> 宣告於 %<for%> 循環初始宣告中"
 
-#: c/c-decl.c:9646
+#: c/c-decl.c:9666
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "%<enum %E%> 宣告於 %<for%> 循環初始宣告中"
 
-#: c/c-decl.c:9650
+#: c/c-decl.c:9670
 #, fuzzy, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "宣告的 non-variable %qD 在中 %<for%> 迴圈初始宣告"
 
-#: c/c-decl.c:9900
+#: c/c-decl.c:9920
 #, fuzzy, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr "不相容的位址空間限定元 %qs 和 %qs"
 
-#: c/c-decl.c:9958 c/c-decl.c:9965
+#: c/c-decl.c:9978 c/c-decl.c:9985
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "duplicate %qE declaration specifier"
 msgstr "需要指定宣告"
 
-#: c/c-decl.c:9992 c/c-decl.c:10376 c/c-decl.c:10766
+#: c/c-decl.c:10012 c/c-decl.c:10396 c/c-decl.c:10786
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr "宣告指定了兩個以上的資料類型"
 
-#: c/c-decl.c:10004 cp/parser.c:28261
+#: c/c-decl.c:10024 cp/parser.c:28258
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> 對 GCC 來說太長了"
 
-#: c/c-decl.c:10017
+#: c/c-decl.c:10037
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C90 不支援 %<long long%>"
 
-#: c/c-decl.c:10246 c/c-parser.c:8848
+#: c/c-decl.c:10266 c/c-parser.c:8848
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C90 不支援複數類型"
 
-#: c/c-decl.c:10292
+#: c/c-decl.c:10312
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr "ISO C 不支援飽和類型"
 
-#: c/c-decl.c:10363 c/c-decl.c:10923
+#: c/c-decl.c:10383 c/c-decl.c:10943
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "重複的 %qE"
 
-#: c/c-decl.c:10419
+#: c/c-decl.c:10439
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C 不支援 %<__int128%>型態"
 
-#: c/c-decl.c:10441
+#: c/c-decl.c:10461
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr "%<__int128%>未被支援用於這個目標"
 
-#: c/c-decl.c:10484
+#: c/c-decl.c:10504
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support complex types"
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C90 不支援複數類型"
 
-#: c/c-decl.c:10603
+#: c/c-decl.c:10623
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support the %<_Float%d%s%> type"
 msgstr "ISO C 不支援 %<__int128%>型態"
 
-#: c/c-decl.c:10653
+#: c/c-decl.c:10673
 #, fuzzy, gcc-internal-format
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "%<__int128%>未被支援用於這個目標"
 
-#: c/c-decl.c:10724
+#: c/c-decl.c:10744
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support decimal floating point"
 msgstr "ISO C 不支援十進位浮點數"
 
-#: c/c-decl.c:10747 c/c-decl.c:11013 c/c-parser.c:7842
+#: c/c-decl.c:10767 c/c-decl.c:11033 c/c-parser.c:7842
 #, fuzzy, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "定點類型不支援用於這個目標"
 
-#: c/c-decl.c:10749
+#: c/c-decl.c:10769
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C 不支援定點類型"
 
-#: c/c-decl.c:10784
+#: c/c-decl.c:10804
 #, fuzzy, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr "C++查找的 %qD 會回傳欄位，不是型態"
 
-#: c/c-decl.c:10797
+#: c/c-decl.c:10817
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr "%qE 不是一個 typedef 類型，也不是一個內建類型"
 
-#: c/c-decl.c:10845
+#: c/c-decl.c:10865
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qE 沒有出現在宣告的開頭"
 
-#: c/c-decl.c:10866
+#: c/c-decl.c:10886
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<auto%>"
 msgid "%qE used with %<auto%>"
 msgstr "%<__thread%> 與 %<auto%> 一起使用"
 
-#: c/c-decl.c:10868
+#: c/c-decl.c:10888
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<register%>"
 msgid "%qE used with %<register%>"
 msgstr "%<__thread%> 與 %<register%> 一起使用"
 
-#: c/c-decl.c:10870
+#: c/c-decl.c:10890
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<typedef%>"
 msgid "%qE used with %<typedef%>"
 msgstr "%<__thread%> 與 %<typedef%> 一起使用"
 
-#: c/c-decl.c:10884 c/c-parser.c:7360
+#: c/c-decl.c:10904 c/c-parser.c:7360
 #, fuzzy, gcc-internal-format
 msgid "ISO C99 does not support %qE"
 msgstr "ISO C99 不支援 %qE"
 
-#: c/c-decl.c:10887 c/c-parser.c:7363
+#: c/c-decl.c:10907 c/c-parser.c:7363
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support %qE"
 msgstr "ISO C90 不支援 %qE"
 
-#: c/c-decl.c:10899
+#: c/c-decl.c:10919
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<__thread%> 出現在 %<extern%> 之前"
 
-#: c/c-decl.c:10908
+#: c/c-decl.c:10928
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<__thread%> 出現在 %<static%> 之前"
 
-#: c/c-decl.c:10921
+#: c/c-decl.c:10941
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr ""
 
-#: c/c-decl.c:10929
+#: c/c-decl.c:10949
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr "宣告指定了多個存儲類別"
 
-#: c/c-decl.c:10937
+#: c/c-decl.c:10957
 #, fuzzy, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr "%qs 必須被使用與 %qs"
 
-#: c/c-decl.c:11010
+#: c/c-decl.c:11030
 #, fuzzy, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "%<_Sat%>被使用而無需 %<_Fract%>或 %<_Accum%>"
 
-#: c/c-decl.c:11025
+#: c/c-decl.c:11045
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C 不支援單獨用 %<complex%> 表示 %<double complex%>"
 
-#: c/c-decl.c:11076 c/c-decl.c:11092 c/c-decl.c:11118
+#: c/c-decl.c:11096 c/c-decl.c:11112 c/c-decl.c:11138
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C 不支援複整數"
 
-#: c/c-decl.c:11514 cp/semantics.c:5348
+#: c/c-decl.c:11534 cp/semantics.c:5351
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:11518 cp/semantics.c:5352
+#: c/c-decl.c:11538 cp/semantics.c:5355
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.c:385 c/c-typeck.c:11426 cp/typeck.c:4680
+#: c/c-fold.c:385 c/c-typeck.c:11431 cp/typeck.c:4680
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count is negative"
 msgid "left shift of negative value"
 msgstr "左移次數為負"
 
-#: c/c-fold.c:395 c/c-typeck.c:11435 cp/typeck.c:4688
+#: c/c-fold.c:395 c/c-typeck.c:11440 cp/typeck.c:4688
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "左移次數為負"
 
-#: c/c-fold.c:396 c/c-typeck.c:11365 cp/typeck.c:4633
+#: c/c-fold.c:396 c/c-typeck.c:11370 cp/typeck.c:4633
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "右移次數為負"
 
-#: c/c-fold.c:404 c/c-typeck.c:11454 cp/typeck.c:4696
+#: c/c-fold.c:404 c/c-typeck.c:11459 cp/typeck.c:4696
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "左移次數大於或等於類型寬度"
 
-#: c/c-fold.c:405 c/c-typeck.c:11389 cp/typeck.c:4641
+#: c/c-fold.c:405 c/c-typeck.c:11394 cp/typeck.c:4641
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "右移次數大於或等於類型寬度"
 
-#: c/c-fold.c:412 c/c-typeck.c:11446
+#: c/c-fold.c:412 c/c-typeck.c:11451
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count >= width of type"
 msgid "left shift count >= width of vector element"
 msgstr "左移次數大於或等於類型寬度"
 
-#: c/c-fold.c:413 c/c-typeck.c:11376
+#: c/c-fold.c:413 c/c-typeck.c:11381
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count >= width of type"
 msgid "right shift count >= width of vector element"
@@ -38457,7 +38500,7 @@
 msgid "to match this %qs"
 msgstr "沒有匹配用於 %qs 在中 %<%s %E%>"
 
-#: c/c-parser.c:1216 cp/parser.c:28484
+#: c/c-parser.c:1216 cp/parser.c:28481
 #, fuzzy, gcc-internal-format
 msgid "expected end of line"
 msgstr "預期的列尾"
@@ -38498,7 +38541,7 @@
 msgstr "不明型態名稱 %qE"
 
 #: c/c-parser.c:1848 c/c-parser.c:11129 c/c-parser.c:16147 c/c-parser.c:16585
-#: c/c-parser.c:17061 cp/parser.c:36007 cp/parser.c:38993
+#: c/c-parser.c:17061 cp/parser.c:36004 cp/parser.c:38990
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "需要指定宣告"
@@ -38513,7 +38556,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "預期 %<;%>，識別碼或 %<(%>"
 
-#: c/c-parser.c:1906 cp/parser.c:30161 cp/parser.c:30235
+#: c/c-parser.c:1906 cp/parser.c:30158 cp/parser.c:30232
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "前綴屬性被忽略用於方法"
@@ -38571,7 +38614,7 @@
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr "%<auto%> 只能被指定的用於變數或函式宣告"
 
-#: c/c-parser.c:2220 cp/parser.c:13002 cp/parser.c:13159
+#: c/c-parser.c:2220 cp/parser.c:12999 cp/parser.c:13156
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "需要 %<,%> 或 %<;%>"
@@ -38599,7 +38642,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C90 不支援 %<_Static_assert%>"
 
-#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38634
+#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38631
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr "需要字面字串"
@@ -38665,13 +38708,13 @@
 #: c/c-parser.c:10745 c/c-parser.c:10798 c/c-parser.c:10814 c/c-parser.c:10860
 #: c/c-parser.c:11496 c/c-parser.c:11537 c/c-parser.c:13445 c/c-parser.c:13681
 #: c/c-parser.c:15544 c/c-parser.c:18218 c/gimple-parser.c:1058
-#: c/gimple-parser.c:1096 cp/parser.c:28487 cp/parser.c:31013
-#: cp/parser.c:31043 cp/parser.c:31113 cp/parser.c:33230 cp/parser.c:38350
+#: c/gimple-parser.c:1096 cp/parser.c:28484 cp/parser.c:31010
+#: cp/parser.c:31040 cp/parser.c:31110 cp/parser.c:33227 cp/parser.c:38347
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "需要識別碼"
 
-#: c/c-parser.c:2995 cp/parser.c:18384
+#: c/c-parser.c:2995 cp/parser.c:18381
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "列舉表以逗號結尾"
@@ -38840,12 +38883,12 @@
 msgid "expected statement"
 msgstr "需要敘述"
 
-#: c/c-parser.c:5639 cp/parser.c:12516
+#: c/c-parser.c:5639 cp/parser.c:12513
 #, fuzzy, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "建議大括號周圍清空內文在中 %<if%> 敘述"
 
-#: c/c-parser.c:5681 cp/parser.c:12519
+#: c/c-parser.c:5681 cp/parser.c:12516
 #, fuzzy, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "建議大括號周圍清空內文在中 %<else%> 敘述"
@@ -39195,7 +39238,7 @@
 msgid "%<__builtin_complex%> operands of different types"
 msgstr "%<__builtin_complex%>運算元的不同的類型"
 
-#: c/c-parser.c:8891 cp/parser.c:6918
+#: c/c-parser.c:8891 cp/parser.c:6921
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_shuffle%>"
 msgstr "錯誤的引數數量到 %<__builtin_shuffle%>"
@@ -39255,76 +39298,76 @@
 msgid "no type or storage class may be specified here,"
 msgstr "沒有型態或貯藏類別也許會被指定的在此，"
 
-#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31073
+#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31070
 #, fuzzy, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "不明內容屬性"
 
-#: c/c-parser.c:10682 cp/parser.c:31033
+#: c/c-parser.c:10682 cp/parser.c:31030
 #, fuzzy, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "缺少%<=%>(之後 %<getter%>屬性)missing %<=%> (after %<getter%> attribute)缺少%<=%>(之後 %<getter%>屬性)"
 
-#: c/c-parser.c:10685 cp/parser.c:31036
+#: c/c-parser.c:10685 cp/parser.c:31033
 #, fuzzy, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "缺少%<=%>(之後 %<setter%>屬性)missing %<=%> (after %<setter%> attribute)缺少%<=%>(之後 %<setter%>屬性)"
 
-#: c/c-parser.c:10699 cp/parser.c:31051
+#: c/c-parser.c:10699 cp/parser.c:31048
 #, fuzzy, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "%<setter%> 屬性也許會只有被指定的一旦"
 
-#: c/c-parser.c:10704 cp/parser.c:31057
+#: c/c-parser.c:10704 cp/parser.c:31054
 #, fuzzy, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr "setter 名稱必須終止與 %<:%>"
 
-#: c/c-parser.c:10711 cp/parser.c:31065
+#: c/c-parser.c:10711 cp/parser.c:31062
 #, fuzzy, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "%<getter%> 屬性也許會只有被指定的一旦"
 
-#: c/c-parser.c:10905 cp/parser.c:38674
+#: c/c-parser.c:10905 cp/parser.c:38671
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
 #: c/c-parser.c:10949 c/c-parser.c:16582 c/c-parser.c:16840 c/c-parser.c:16899
-#: c/c-parser.c:16983 cp/parser.c:36004 cp/parser.c:36298 cp/parser.c:36386
-#: cp/parser.c:36457 cp/parser.c:38721 cp/parser.c:38736 cp/parser.c:38752
-#: cp/parser.c:38768 cp/parser.c:38784 cp/parser.c:38811 cp/parser.c:38824
-#: cp/parser.c:38847 cp/parser.c:38860
+#: c/c-parser.c:16983 cp/parser.c:36001 cp/parser.c:36295 cp/parser.c:36383
+#: cp/parser.c:36454 cp/parser.c:38718 cp/parser.c:38733 cp/parser.c:38749
+#: cp/parser.c:38765 cp/parser.c:38781 cp/parser.c:38808 cp/parser.c:38821
+#: cp/parser.c:38844 cp/parser.c:38857
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<# pragma omp flush%>也許會只有被已用於複合陳述"
 
-#: c/c-parser.c:10972 cp/parser.c:38837
+#: c/c-parser.c:10972 cp/parser.c:38834
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<# pragma GCC pchpreprocess%(_P)>必須是先"
 
-#: c/c-parser.c:11050 cp/parser.c:38918
+#: c/c-parser.c:11050 cp/parser.c:38915
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<# pragma omp section%>也許會只有被已用於 %<# pragma omp sections%>建構"
 
-#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38947 cp/parser.c:38980
+#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38944 cp/parser.c:38977
 #, fuzzy, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "用於敘述預期"
 
-#: c/c-parser.c:11111 cp/parser.c:38711
+#: c/c-parser.c:11111 cp/parser.c:38708
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<# pragma GCC pchpreprocess%(_P)>必須是先"
 
-#: c/c-parser.c:11421 cp/parser.c:31457
+#: c/c-parser.c:11421 cp/parser.c:31454
 #, fuzzy, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "太多 %qs 子句"
 
-#: c/c-parser.c:11443 cp/parser.c:31994
+#: c/c-parser.c:11443 cp/parser.c:31991
 #, fuzzy, gcc-internal-format
 msgid "expected integer expression before ')'"
 msgstr "預期的整數運算式"
@@ -39339,53 +39382,53 @@
 msgid "%qD is not a variable"
 msgstr "%qD 並非變數"
 
-#: c/c-parser.c:11746 cp/semantics.c:6808
+#: c/c-parser.c:11746 cp/semantics.c:6811
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "%qD 並非變數"
 
-#: c/c-parser.c:11788 cp/parser.c:32073
+#: c/c-parser.c:11788 cp/parser.c:32070
 #, fuzzy, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr "崩潰引數需要正面的常數整數運算式"
 
-#: c/c-parser.c:11865 cp/parser.c:32137
+#: c/c-parser.c:11865 cp/parser.c:32134
 #, fuzzy, gcc-internal-format
 msgid "expected %<none%> or %<present%>"
 msgstr "預期 %<none%> 或 %<shared%>"
 
-#: c/c-parser.c:11867 cp/parser.c:32139
+#: c/c-parser.c:11867 cp/parser.c:32136
 #, fuzzy, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "預期 %<none%> 或 %<shared%>"
 
-#: c/c-parser.c:11968 cp/parser.c:32242
+#: c/c-parser.c:11968 cp/parser.c:32239
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "預期 %<;%>，%<,%>或 %<)%>"
 
-#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32260
-#: cp/parser.c:36290 cp/parser.c:36378
+#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32257
+#: cp/parser.c:36287 cp/parser.c:36375
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%>"
 msgstr "預期 %<catch%>"
 
-#: c/c-parser.c:12035 cp/parser.c:32313
+#: c/c-parser.c:12035 cp/parser.c:32310
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:12042 cp/parser.c:32320
+#: c/c-parser.c:12042 cp/parser.c:32317
 #, fuzzy, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr "太多 %qs 子句"
 
-#: c/c-parser.c:12044 cp/parser.c:32322
+#: c/c-parser.c:12044 cp/parser.c:32319
 #, fuzzy, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr "太多 %qs 子句"
 
-#: c/c-parser.c:12050 cp/parser.c:32328
+#: c/c-parser.c:12050 cp/parser.c:32325
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -39407,83 +39450,83 @@
 msgid "%<num_tasks%> value must be positive"
 msgstr "%<num_threads%> 值必須是正值"
 
-#: c/c-parser.c:12229 cp/semantics.c:6992
+#: c/c-parser.c:12229 cp/semantics.c:6995
 #, fuzzy, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr "%<num_threads%> 值必須是正值"
 
-#: c/c-parser.c:12276 cp/semantics.c:7021
+#: c/c-parser.c:12276 cp/semantics.c:7024
 #, fuzzy, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr "『%s』於 %L 必須是 nonnegative"
 
-#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32545 cp/parser.c:32552
+#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32542 cp/parser.c:32549
 #, fuzzy, gcc-internal-format
 msgid "expected %<tofrom%>"
 msgstr "預期 %<throw%>"
 
-#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32561 cp/parser.c:32568
+#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32558 cp/parser.c:32565
 #, fuzzy, gcc-internal-format
 msgid "expected %<scalar%>"
 msgstr "預期 %<class%>"
 
-#: c/c-parser.c:12425 cp/semantics.c:6299
+#: c/c-parser.c:12425 cp/semantics.c:6302
 #, fuzzy, gcc-internal-format
 msgid "%qs expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6331
+#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6334
 #, fuzzy, gcc-internal-format
 msgid "%qs value must be positive"
 msgstr "%<num_threads%> 值必須是正值"
 
-#: c/c-parser.c:12499 cp/parser.c:31853
+#: c/c-parser.c:12499 cp/parser.c:31850
 #, fuzzy, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "太多引數"
 
-#: c/c-parser.c:12533 cp/parser.c:31886
+#: c/c-parser.c:12533 cp/parser.c:31883
 #, fuzzy, gcc-internal-format
 msgid "unexpected argument"
 msgstr "未預期的屬性"
 
-#: c/c-parser.c:12699 cp/semantics.c:7120
+#: c/c-parser.c:12699 cp/semantics.c:7123
 #, fuzzy, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "%qE 屬性引數不是整數常數"
 
-#: c/c-parser.c:12765 cp/parser.c:32626
+#: c/c-parser.c:12765 cp/parser.c:32623
 #, fuzzy, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr "崩潰引數需要正面的常數整數運算式"
 
-#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37643
+#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37640
 #, fuzzy, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "預期 %<+%>，%<*%>，%<-%>，%<&%>，%<^%>，%<|%>，%<&&%>，%<||%>，%<min%>或 %<max%>expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or %<max%>預期 %<+%>，%<*%>，%<-%>，%<&%>，%<^%>，%<|%>，%<&&%>，%<||%>，%<min%>或 %<max%>"
 
-#: c/c-parser.c:12967 cp/parser.c:32840
+#: c/c-parser.c:12967 cp/parser.c:32837
 #, fuzzy, gcc-internal-format
 #| msgid "both %<long%> and %<void%> in declaration specifiers"
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "宣告中同時使用了 %<long%> 和 %<void%>"
 
-#: c/c-parser.c:13021 cp/parser.c:32856
+#: c/c-parser.c:13021 cp/parser.c:32853
 #, fuzzy, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "排程 %<runtime%> 不需 %<chunksize%(_S)>參數"
 
-#: c/c-parser.c:13025 cp/parser.c:32859
+#: c/c-parser.c:13025 cp/parser.c:32856
 #, fuzzy, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "排程 %<auto%> 不需 %<chunksize%(_S)>參數"
 
-#: c/c-parser.c:13037 cp/semantics.c:6389
+#: c/c-parser.c:13037 cp/semantics.c:6392
 #, fuzzy, gcc-internal-format
 msgid "chunk size value must be positive"
 msgstr "%<num_threads%> 值必須是正值"
 
-#: c/c-parser.c:13060 cp/parser.c:32879
+#: c/c-parser.c:13060 cp/parser.c:32876
 #, fuzzy, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "無效的排程 kind"
@@ -39493,12 +39536,12 @@
 msgid "%<num_teams%> value must be positive"
 msgstr "%<num_threads%> 值必須是正值"
 
-#: c/c-parser.c:13226 cp/semantics.c:6479
+#: c/c-parser.c:13226 cp/semantics.c:6482
 #, fuzzy, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr "%<num_threads%> 值必須是正值"
 
-#: c/c-parser.c:13271 cp/semantics.c:6589
+#: c/c-parser.c:13271 cp/semantics.c:6592
 #, fuzzy, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr "崩潰引數需要正面的常數整數運算式"
@@ -39518,18 +39561,18 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr "崩潰引數需要正面的常數整數運算式"
 
-#: c/c-parser.c:13584 cp/parser.c:33374 cp/parser.c:33599
+#: c/c-parser.c:13584 cp/parser.c:33371 cp/parser.c:33596
 #, fuzzy, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "無效的排程 kind"
 
-#: c/c-parser.c:13669 cp/parser.c:33447
+#: c/c-parser.c:13669 cp/parser.c:33444
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mask"
 msgid "invalid map kind"
 msgstr "無效遮罩"
 
-#: c/c-parser.c:13767 cp/parser.c:33546
+#: c/c-parser.c:13767 cp/parser.c:33543
 #, fuzzy, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "無效的排程 kind"
@@ -39539,68 +39582,68 @@
 msgid "invalid proc_bind kind"
 msgstr "無效的排程 kind"
 
-#: c/c-parser.c:14059 cp/parser.c:33825
+#: c/c-parser.c:14059 cp/parser.c:33822
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr "預期 %<# pragma omp%>子句"
 
-#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33836 cp/parser.c:34143
+#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33833 cp/parser.c:34140
 #, fuzzy, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs 無效用於 %qs"
 
-#: c/c-parser.c:14214 cp/parser.c:34010
+#: c/c-parser.c:14214 cp/parser.c:34007
 #, fuzzy, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "%qs 必須被使用與 %qs"
 
-#: c/c-parser.c:14334 cp/parser.c:34132
+#: c/c-parser.c:14334 cp/parser.c:34129
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "預期 %<# pragma omp%>子句"
 
-#: c/c-parser.c:14472 cp/parser.c:36803
+#: c/c-parser.c:14472 cp/parser.c:36800
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14482 cp/parser.c:36813
+#: c/c-parser.c:14482 cp/parser.c:36810
 #, fuzzy, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr "陣列區段在中『%s』呼叫於 %L"
 
-#: c/c-parser.c:14502 cp/parser.c:36833
+#: c/c-parser.c:14502 cp/parser.c:36830
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr ""
 
-#: c/c-parser.c:14513 cp/parser.c:36844
+#: c/c-parser.c:14513 cp/parser.c:36841
 #, fuzzy, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr "無效的輸入宣告"
 
-#: c/c-parser.c:14520 cp/parser.c:36851
+#: c/c-parser.c:14520 cp/parser.c:36848
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "宣告的 %<extern%> 變數 %qD 在中 %<for%>迴圈初始宣告"
 
-#: c/c-parser.c:14528 cp/parser.c:36859
+#: c/c-parser.c:14528 cp/parser.c:36856
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<--%> on bool variable %qD"
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "對於 bool 變數 %qD 使用 %<--%> 無效"
 
-#: c/c-parser.c:14540 cp/parser.c:36871
+#: c/c-parser.c:14540 cp/parser.c:36868
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14632 cp/parser.c:36957
+#: c/c-parser.c:14632 cp/parser.c:36954
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "預期的字串之後 %<# pragma message%>"
 
-#: c/c-parser.c:14648 cp/parser.c:36974
+#: c/c-parser.c:14648 cp/parser.c:36971
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr ""
@@ -39615,7 +39658,7 @@
 msgid "expected function name"
 msgstr "預期的函式"
 
-#: c/c-parser.c:14893 cp/parser.c:38064
+#: c/c-parser.c:14893 cp/parser.c:38061
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qD does not refer to a function"
@@ -39626,42 +39669,42 @@
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14953 cp/parser.c:38118 cp/parser.c:38160
+#: c/c-parser.c:14953 cp/parser.c:38115 cp/parser.c:38157
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14970 cp/parser.c:38174
+#: c/c-parser.c:14970 cp/parser.c:38171
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> already applied to %qD"
 msgstr ""
 
-#: c/c-parser.c:14979 cp/parser.c:38183
+#: c/c-parser.c:14979 cp/parser.c:38180
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr ""
 
-#: c/c-parser.c:14980 cp/parser.c:38184
+#: c/c-parser.c:14980 cp/parser.c:38181
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<# pragma align%>必須出現之前宣告的 %D, 忽略"
 
-#: c/c-parser.c:15023 cp/parser.c:37152
+#: c/c-parser.c:15023 cp/parser.c:37149
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
 
-#: c/c-parser.c:15435 cp/parser.c:34511 cp/parser.c:34537
+#: c/c-parser.c:15435 cp/parser.c:34508 cp/parser.c:34534
 #, fuzzy, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "無效的表單的 %<# pragma omp atomic%>"
 
-#: c/c-parser.c:15439 cp/parser.c:34568 cp/parser.c:34584
+#: c/c-parser.c:15439 cp/parser.c:34565 cp/parser.c:34581
 #, fuzzy, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "無效的運算子用於 %<# pragma omp atomic%>"
 
-#: c/c-parser.c:15488 cp/semantics.c:8401 cp/semantics.c:8411
+#: c/c-parser.c:15488 cp/semantics.c:8404 cp/semantics.c:8414
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr "%<# pragma omp 基元的 capture%>使用兩不同的變數用於記憶體"
@@ -39671,22 +39714,22 @@
 msgid "expected %<(%> or end of line"
 msgstr "預期 %<(%>或列尾"
 
-#: c/c-parser.c:15619 cp/parser.c:35103
+#: c/c-parser.c:15619 cp/parser.c:35100
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:15630 cp/parser.c:35114
+#: c/c-parser.c:15630 cp/parser.c:35111
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:15648 cp/parser.c:35141
+#: c/c-parser.c:15648 cp/parser.c:35138
 #, fuzzy, gcc-internal-format
 msgid "for statement expected"
 msgstr "用於敘述預期"
 
-#: c/c-parser.c:15718 cp/semantics.c:8066 cp/semantics.c:8153
+#: c/c-parser.c:15718 cp/semantics.c:8069 cp/semantics.c:8156
 #, fuzzy, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "預期的迭代宣告或初始化"
@@ -39696,73 +39739,73 @@
 msgid "not enough perfectly nested loops"
 msgstr "不足 perfectly 巢狀的迴圈"
 
-#: c/c-parser.c:15862 cp/parser.c:35364
+#: c/c-parser.c:15862 cp/parser.c:35361
 #, fuzzy, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr "崩潰的迴圈無法 perfectly 巢狀"
 
-#: c/c-parser.c:15909 cp/parser.c:35184 cp/parser.c:35226 cp/pt.c:16385
+#: c/c-parser.c:15909 cp/parser.c:35181 cp/parser.c:35223 cp/pt.c:16407
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "迭代變數 %qD 不應為 firstprivate"
 
-#: c/c-parser.c:16000 cp/parser.c:35437
+#: c/c-parser.c:16000 cp/parser.c:35434
 #, fuzzy, gcc-internal-format
 #| msgid "%<void%> as only parameter may not be qualified"
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "%<void%> 做為僅有的參數時不能被限定"
 
-#: c/c-parser.c:16166 cp/parser.c:35600
+#: c/c-parser.c:16166 cp/parser.c:35597
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr "%<# pragma omp barrier%>也許會只有被已用於複合陳述"
 
-#: c/c-parser.c:16374 cp/parser.c:35799
+#: c/c-parser.c:16374 cp/parser.c:35796
 #, fuzzy, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "預期 %<operator%>"
 
-#: c/c-parser.c:16573 cp/parser.c:35995
+#: c/c-parser.c:16573 cp/parser.c:35992
 #, fuzzy, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "預期 %<using%>"
 
-#: c/c-parser.c:16793 cp/parser.c:36232
+#: c/c-parser.c:16793 cp/parser.c:36229
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16806 cp/parser.c:36245
+#: c/c-parser.c:16806 cp/parser.c:36242
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16853 cp/parser.c:36470
+#: c/c-parser.c:16853 cp/parser.c:36467
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:16925 cp/parser.c:36325
+#: c/c-parser.c:16925 cp/parser.c:36322
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16937 cp/parser.c:36337
+#: c/c-parser.c:16937 cp/parser.c:36334
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17011 cp/parser.c:36414
+#: c/c-parser.c:17011 cp/parser.c:36411
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17024 cp/parser.c:36427
+#: c/c-parser.c:17024 cp/parser.c:36424
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17238 cp/parser.c:36680
+#: c/c-parser.c:17238 cp/parser.c:36677
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -39782,32 +39825,32 @@
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17395 cp/parser.c:37273
+#: c/c-parser.c:17395 cp/parser.c:37270
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17474 cp/parser.c:37343
+#: c/c-parser.c:17474 cp/parser.c:37340
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> with clauses in between %<#pragma omp declare target%> without clauses and %<#pragma omp end declare target%>"
 msgstr ""
 
-#: c/c-parser.c:17493 cp/parser.c:37362
+#: c/c-parser.c:17493 cp/parser.c:37359
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17534 cp/parser.c:37409
+#: c/c-parser.c:17534 cp/parser.c:37406
 #, fuzzy, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "預期 %<try%>"
 
-#: c/c-parser.c:17541 cp/parser.c:37416
+#: c/c-parser.c:17541 cp/parser.c:37413
 #, fuzzy, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "預期 %<decltype%>"
 
-#: c/c-parser.c:17547 cp/parser.c:37423
+#: c/c-parser.c:17547 cp/parser.c:37420
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr "%<# pragma GCC pop_options%>而無需相應 %<# pragma GCC push_options%>"
@@ -39862,47 +39905,47 @@
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:17947 cp/parser.c:37868
+#: c/c-parser.c:17947 cp/parser.c:37865
 #, fuzzy, gcc-internal-format
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr "預期 %<# pragma omp section%>或 %<}%>"
 
-#: c/c-parser.c:18162 cp/semantics.c:7531
+#: c/c-parser.c:18162 cp/semantics.c:7534
 #, fuzzy, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE 宣告 %<threadprivate%> 之後先使用"
 
-#: c/c-parser.c:18164 cp/semantics.c:7533
+#: c/c-parser.c:18164 cp/semantics.c:7536
 #, fuzzy, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "自動變數 %qE 無法 %<threadprivate%>"
 
-#: c/c-parser.c:18168 cp/semantics.c:7535
+#: c/c-parser.c:18168 cp/semantics.c:7538
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%<threadprivate%> %qE 有不完整型態"
 
-#: c/c-parser.c:18368 cp/parser.c:38565
+#: c/c-parser.c:18368 cp/parser.c:38562
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr "%<__transaction_cancel%>而無需 transactional 記憶體支援已啟用"
 
-#: c/c-parser.c:18374 cp/parser.c:38571
+#: c/c-parser.c:18374 cp/parser.c:38568
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr "%<__transaction_cancel%>在之內 %<__transaction_relaxed%>"
 
-#: c/c-parser.c:18383 cp/parser.c:38580
+#: c/c-parser.c:18383 cp/parser.c:38577
 #, fuzzy, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr "外 %<__transaction_cancel%>無法在之內外 %<__transaction_atomic%>"
 
-#: c/c-parser.c:18385 cp/parser.c:38583
+#: c/c-parser.c:18385 cp/parser.c:38580
 #, fuzzy, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr "  或 %<transaction_may_cancel_outer%> 函式"
 
-#: c/c-parser.c:18391 cp/parser.c:38589
+#: c/c-parser.c:18391 cp/parser.c:38586
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr "%<__transaction_cancel%>無法在之內 %<__transaction_atomic%>"
@@ -39918,7 +39961,7 @@
 msgid "%qD has an incomplete type %qT"
 msgstr "%qD 類型不完全"
 
-#: c/c-typeck.c:237 c/c-typeck.c:9994 c/c-typeck.c:10036 cp/call.c:4147
+#: c/c-typeck.c:237 c/c-typeck.c:9999 c/c-typeck.c:10041 cp/call.c:4147
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "對 void 運算式的無效使用"
@@ -39996,13 +40039,13 @@
 msgid "converting an array compound literal to a pointer is ill-formed in C++"
 msgstr "轉換陣列複合實字到指標被不當形式的在中 C++"
 
-#: c/c-typeck.c:2417 c/c-typeck.c:8641
+#: c/c-typeck.c:2417 c/c-typeck.c:8646
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%qT has no member named %qE; did you mean %qE?"
 msgstr "%qT 沒具名為 %qE 的成員"
 
-#: c/c-typeck.c:2421 c/c-typeck.c:8645
+#: c/c-typeck.c:2421 c/c-typeck.c:8650
 #, gcc-internal-format
 msgid "%qT has no member named %qE"
 msgstr "%qT 沒具名為 %qE 的成員"
@@ -40203,478 +40246,478 @@
 msgid "pointer to a function used in subtraction"
 msgstr "函式指標不能相減"
 
-#: c/c-typeck.c:3847
+#: c/c-typeck.c:3852
 #, gcc-internal-format
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "在參照不完全類型的指標上執行算術運算"
 
-#: c/c-typeck.c:3852 cp/typeck.c:5562
+#: c/c-typeck.c:3857 cp/typeck.c:5562
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr "在參照不完全類型的指標上執行算術運算"
 
-#: c/c-typeck.c:4283
+#: c/c-typeck.c:4288
 #, fuzzy, gcc-internal-format
 msgid "%<~%> on a boolean expression"
 msgstr "預期的布林表示式"
 
-#: c/c-typeck.c:4287
+#: c/c-typeck.c:4292
 #, gcc-internal-format
 msgid "did you mean to use logical not?"
 msgstr ""
 
-#: c/c-typeck.c:4296
+#: c/c-typeck.c:4301
 #, gcc-internal-format
 msgid "ISO C does not support %<~%> for complex conjugation"
 msgstr "ISO C 不支援用 ~ 求共軛複數"
 
-#: c/c-typeck.c:4335
+#: c/c-typeck.c:4340
 #, gcc-internal-format
 msgid "wrong type argument to unary exclamation mark"
 msgstr "單位元 ! 的引數類型無效"
 
-#: c/c-typeck.c:4393
+#: c/c-typeck.c:4398
 #, fuzzy, gcc-internal-format
 msgid "increment of enumeration value is invalid in C++"
 msgstr "遞增的列舉類型值無效在中 C++"
 
-#: c/c-typeck.c:4396
+#: c/c-typeck.c:4401
 #, fuzzy, gcc-internal-format
 msgid "decrement of enumeration value is invalid in C++"
 msgstr "遞減的列舉類型值無效在中 C++"
 
-#: c/c-typeck.c:4403
+#: c/c-typeck.c:4408
 #, fuzzy, gcc-internal-format
 msgid "increment of a boolean expression"
 msgstr "預期的布林表示式"
 
-#: c/c-typeck.c:4406
+#: c/c-typeck.c:4411
 #, fuzzy, gcc-internal-format
 msgid "decrement of a boolean expression"
 msgstr "預期的布林表示式"
 
-#: c/c-typeck.c:4422
+#: c/c-typeck.c:4427
 #, gcc-internal-format
 msgid "ISO C does not support %<++%> and %<--%> on complex types"
 msgstr "ISO C 不支援對複數類型進行 %<++%> 或 %<--%> 作業"
 
-#: c/c-typeck.c:4447 c/c-typeck.c:4481
+#: c/c-typeck.c:4452 c/c-typeck.c:4486
 #, gcc-internal-format
 msgid "wrong type argument to increment"
 msgstr "該類型的引數不能自增"
 
-#: c/c-typeck.c:4449 c/c-typeck.c:4484
+#: c/c-typeck.c:4454 c/c-typeck.c:4489
 #, gcc-internal-format
 msgid "wrong type argument to decrement"
 msgstr "該類型的引數不能自減"
 
-#: c/c-typeck.c:4469
+#: c/c-typeck.c:4474
 #, fuzzy, gcc-internal-format
 msgid "increment of pointer to an incomplete type %qT"
 msgstr "無法遞增指標到不完整型態 %qT"
 
-#: c/c-typeck.c:4473
+#: c/c-typeck.c:4478
 #, fuzzy, gcc-internal-format
 msgid "decrement of pointer to an incomplete type %qT"
 msgstr "無法遞減指標到不完整型態 %qT"
 
-#: c/c-typeck.c:4577
+#: c/c-typeck.c:4582
 #, fuzzy, gcc-internal-format
 msgid "taking address of expression of type %<void%>"
 msgstr "需位址的運算式的型態 %<void%>"
 
-#: c/c-typeck.c:4636
+#: c/c-typeck.c:4641
 #, gcc-internal-format
 msgid "cannot take address of bit-field %qD"
 msgstr "無法取得位元段 %qD 的位址"
 
-#: c/c-typeck.c:4649
+#: c/c-typeck.c:4654
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgid "cannot take address of scalar with reverse storage order"
 msgstr "無法取右值運算式 %<this%> 的位址"
 
-#: c/c-typeck.c:4657
+#: c/c-typeck.c:4662
 #, fuzzy, gcc-internal-format
 #| msgid "address of register variable %qD requested"
 msgid "address of array with reverse scalar storage order requested"
 msgstr "要求暫存器變數 %qD 的位址。"
 
-#: c/c-typeck.c:4838
+#: c/c-typeck.c:4843
 #, gcc-internal-format
 msgid "global register variable %qD used in nested function"
 msgstr "巢狀函式中使用了全域暫存器變數 %qD"
 
-#: c/c-typeck.c:4841
+#: c/c-typeck.c:4846
 #, gcc-internal-format
 msgid "register variable %qD used in nested function"
 msgstr "巢狀函式中使用了暫存器變數 %qD"
 
-#: c/c-typeck.c:4846
+#: c/c-typeck.c:4851
 #, gcc-internal-format
 msgid "address of global register variable %qD requested"
 msgstr "要求全域暫存器變數 %qD 的位址"
 
-#: c/c-typeck.c:4848
+#: c/c-typeck.c:4853
 #, gcc-internal-format
 msgid "address of register variable %qD requested"
 msgstr "要求暫存器變數 %qD 的位址。"
 
-#: c/c-typeck.c:4951
+#: c/c-typeck.c:4956
 #, gcc-internal-format
 msgid "non-lvalue array in conditional expression"
 msgstr "非左值陣列出現在條件運算式中"
 
-#: c/c-typeck.c:5033
+#: c/c-typeck.c:5038
 #, fuzzy, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other result of conditional"
 msgstr "隱含轉換從 %qT 到 %qT 到匹配其他結果的條件"
 
-#: c/c-typeck.c:5092 c/c-typeck.c:5098
+#: c/c-typeck.c:5097 c/c-typeck.c:5103
 #, gcc-internal-format
 msgid "operand of ?: changes signedness from %qT to %qT due to unsignedness of other operand"
 msgstr ""
 
-#: c/c-typeck.c:5115
+#: c/c-typeck.c:5120
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr with only one void side"
 msgstr "ISO C 不允許條件運算式僅有一邊為空"
 
-#: c/c-typeck.c:5132
+#: c/c-typeck.c:5137
 #, fuzzy, gcc-internal-format
 msgid "pointers to disjoint address spaces used in conditional expression"
 msgstr "指標到 disjoint 位址空間已用於條件運算式"
 
-#: c/c-typeck.c:5143 c/c-typeck.c:5160
+#: c/c-typeck.c:5148 c/c-typeck.c:5165
 #, fuzzy, gcc-internal-format
 #| msgid "pointer type mismatch in conditional expression"
 msgid "pointer to array loses qualifier in conditional expression"
 msgstr "條件運算式指標類型不匹配"
 
-#: c/c-typeck.c:5148 c/c-typeck.c:5165
+#: c/c-typeck.c:5153 c/c-typeck.c:5170
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr between %<void *%> and function pointer"
 msgstr "ISO C 不允許在條件運算式中同時使用 %<void *%> 和函式指標"
 
-#: c/c-typeck.c:5178
+#: c/c-typeck.c:5183
 #, gcc-internal-format
 msgid "pointer type mismatch in conditional expression"
 msgstr "條件運算式指標類型不匹配"
 
-#: c/c-typeck.c:5187 c/c-typeck.c:5198
+#: c/c-typeck.c:5192 c/c-typeck.c:5203
 #, gcc-internal-format
 msgid "pointer/integer type mismatch in conditional expression"
 msgstr "條件運算式中指標/整數類型不匹配"
 
-#: c/c-typeck.c:5336
+#: c/c-typeck.c:5341
 #, gcc-internal-format
 msgid "left-hand operand of comma expression has no effect"
 msgstr "逗號運算式的左運算元不起作用"
 
-#: c/c-typeck.c:5354 c/c-typeck.c:10636
+#: c/c-typeck.c:5359 c/c-typeck.c:10641
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "right-hand operand of comma expression has no effect"
 msgstr "逗號運算式的左運算元不起作用"
 
-#: c/c-typeck.c:5423
+#: c/c-typeck.c:5428
 #, fuzzy
 msgid "cast adds %q#v qualifier to function type"
 msgstr "演員陣容加入 %q#v 限定元到函數型式"
 
-#: c/c-typeck.c:5429
+#: c/c-typeck.c:5434
 #, fuzzy
 msgid "cast discards %qv qualifier from pointer target type"
 msgstr "演員陣容捨棄 %q#v 限定元從指標目標類型"
 
-#: c/c-typeck.c:5464
+#: c/c-typeck.c:5469
 #, fuzzy, gcc-internal-format
 msgid "to be safe all intermediate pointers in cast from %qT to %qT must be %<const%> qualified"
 msgstr "要是安全所有中介指標在中演員陣容從 %qT 到 %qT 必須是 %<const%> 經資格修飾"
 
-#: c/c-typeck.c:5554
+#: c/c-typeck.c:5559
 #, gcc-internal-format
 msgid "cast specifies array type"
 msgstr "類型轉換指定了陣列類型"
 
-#: c/c-typeck.c:5560
+#: c/c-typeck.c:5565
 #, gcc-internal-format
 msgid "cast specifies function type"
 msgstr "類型轉換指定了函式類型"
 
-#: c/c-typeck.c:5575
+#: c/c-typeck.c:5580
 #, gcc-internal-format
 msgid "ISO C forbids casting nonscalar to the same type"
 msgstr "ISO C 不允許將非標量轉換為其自身類型"
 
-#: c/c-typeck.c:5595
+#: c/c-typeck.c:5600
 #, gcc-internal-format
 msgid "ISO C forbids casts to union type"
 msgstr "ISO C 不允許轉換為聯合類型"
 
-#: c/c-typeck.c:5605
+#: c/c-typeck.c:5610
 #, gcc-internal-format
 msgid "cast to union type from type not present in union"
 msgstr "類型轉換的來源類型未出現在聯合中"
 
-#: c/c-typeck.c:5640
+#: c/c-typeck.c:5645
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint generic address space pointer"
 msgstr "演員陣容到 %s 位址空間指標從 disjoint 通用位址空間指標"
 
-#: c/c-typeck.c:5645
+#: c/c-typeck.c:5650
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cast to generic address space pointer from disjoint %s address space pointer"
 msgstr "演員陣容到通用位址空間指標從 disjoint %s 位址空間指標"
 
-#: c/c-typeck.c:5650
+#: c/c-typeck.c:5655
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint %s address space pointer"
 msgstr "演員陣容到 %s 位址空間指標從 disjoint %s 位址空間指標"
 
-#: c/c-typeck.c:5670
+#: c/c-typeck.c:5675
 #, gcc-internal-format
 msgid "cast increases required alignment of target type"
 msgstr "類型轉換增大了目的類型的對齊需求"
 
-#: c/c-typeck.c:5681
+#: c/c-typeck.c:5686
 #, gcc-internal-format
 msgid "cast from pointer to integer of different size"
 msgstr "當將一個指標轉換為大小不同的整數時給出警告"
 
-#: c/c-typeck.c:5686
+#: c/c-typeck.c:5691
 #, gcc-internal-format
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "從類型為 %qT 的函式呼叫轉換到不匹配的類型 %qT"
 
-#: c/c-typeck.c:5695 cp/typeck.c:7811
+#: c/c-typeck.c:5700 cp/typeck.c:7811
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "當將一個指標轉換為大小不同的整數時給出警告"
 
-#: c/c-typeck.c:5709
+#: c/c-typeck.c:5714
 #, gcc-internal-format
 msgid "ISO C forbids conversion of function pointer to object pointer type"
 msgstr "ISO C 不允許將一個函式指標轉換為一個物件指標"
 
-#: c/c-typeck.c:5718
+#: c/c-typeck.c:5723
 #, gcc-internal-format
 msgid "ISO C forbids conversion of object pointer to function pointer type"
 msgstr "ISO C 不允許將一個物件指標轉換為一個函式指標"
 
-#: c/c-typeck.c:5728
+#: c/c-typeck.c:5733
 #, fuzzy, gcc-internal-format
 msgid "cast between incompatible function types from %qT to %qT"
 msgstr "can%'t 轉換從不完整型態 %qT 到 %qT"
 
-#: c/c-typeck.c:5815
+#: c/c-typeck.c:5820
 #, fuzzy, gcc-internal-format
 msgid "defining a type in a cast is invalid in C++"
 msgstr "定義輸入演員陣容無效在中 C++"
 
-#: c/c-typeck.c:5856
+#: c/c-typeck.c:5861
 #, fuzzy, gcc-internal-format
 #| msgid "assignment suppression"
 msgid "assignment to expression with array type"
 msgstr "取消賦值"
 
-#: c/c-typeck.c:5982
+#: c/c-typeck.c:5987
 #, fuzzy, gcc-internal-format
 msgid "enum conversion in assignment is invalid in C++"
 msgstr "enum 轉換在中指派無效在中 C++"
 
-#: c/c-typeck.c:6180 c/c-typeck.c:6202 c/c-typeck.c:6226
+#: c/c-typeck.c:6185 c/c-typeck.c:6207 c/c-typeck.c:6231
 #, gcc-internal-format
 msgid "(near initialization for %qs)"
 msgstr "(在 %qs 的初始化附近)"
 
-#: c/c-typeck.c:6241
+#: c/c-typeck.c:6246
 #, gcc-internal-format
 msgid "array initialized from parenthesized string constant"
 msgstr "用括號中的字串常數初始化陣列"
 
-#: c/c-typeck.c:6284 c/c-typeck.c:6476 c/c-typeck.c:6908
+#: c/c-typeck.c:6289 c/c-typeck.c:6481 c/c-typeck.c:6913
 #, fuzzy, gcc-internal-format
 msgid "expected %qT but argument is of type %qT"
 msgstr "預期 %qT 但是引數是的型態 %qT"
 
-#: c/c-typeck.c:6471
+#: c/c-typeck.c:6476
 #, fuzzy, gcc-internal-format
 msgid "enum conversion when passing argument %d of %qE is invalid in C++"
 msgstr "enum 轉換時傳遞引數 %d 的 %qE 無效在中 C++"
 
-#: c/c-typeck.c:6480
+#: c/c-typeck.c:6485
 #, fuzzy, gcc-internal-format
 msgid "enum conversion from %qT to %qT in assignment is invalid in C++"
 msgstr "enum 轉換在中指派無效在中 C++"
 
-#: c/c-typeck.c:6484
+#: c/c-typeck.c:6489
 #, fuzzy, gcc-internal-format
 msgid "enum conversion from %qT to %qT in initialization is invalid in C++"
 msgstr "enum 轉換在中初始化無效在中 C++"
 
-#: c/c-typeck.c:6489
+#: c/c-typeck.c:6494
 #, fuzzy, gcc-internal-format
 msgid "enum conversion from %qT to %qT in return is invalid in C++"
 msgstr "enum 轉換在中回傳無效在中 C++"
 
-#: c/c-typeck.c:6523
+#: c/c-typeck.c:6528
 #, gcc-internal-format
 msgid "cannot pass rvalue to reference parameter"
 msgstr "不能將右值傳遞給參照參數"
 
-#: c/c-typeck.c:6656 c/c-typeck.c:6942
+#: c/c-typeck.c:6661 c/c-typeck.c:6947
 #, fuzzy
 msgid "passing argument %d of %qE makes %q#v qualified function pointer from unqualified"
 msgstr "傳遞引數 %d 的 %qE 製作 %q#v 經資格修飾函式指標從資格不符的"
 
-#: c/c-typeck.c:6659 c/c-typeck.c:6945
+#: c/c-typeck.c:6664 c/c-typeck.c:6950
 #, fuzzy
 msgid "assignment makes %q#v qualified function pointer from unqualified"
 msgstr "指派製作 %q#v 經資格修飾函式指標從資格不符的"
 
-#: c/c-typeck.c:6662 c/c-typeck.c:6947
+#: c/c-typeck.c:6667 c/c-typeck.c:6952
 #, fuzzy
 msgid "initialization makes %q#v qualified function pointer from unqualified"
 msgstr "初始化製作 %q#v 經資格修飾函式指標從資格不符的"
 
-#: c/c-typeck.c:6665 c/c-typeck.c:6949
+#: c/c-typeck.c:6670 c/c-typeck.c:6954
 #, fuzzy
 msgid "return makes %q#v qualified function pointer from unqualified"
 msgstr "回傳製作 %q#v 經資格修飾函式指標從資格不符的"
 
-#: c/c-typeck.c:6673 c/c-typeck.c:6840 c/c-typeck.c:6883
+#: c/c-typeck.c:6678 c/c-typeck.c:6845 c/c-typeck.c:6888
 #, fuzzy
 msgid "passing argument %d of %qE discards %qv qualifier from pointer target type"
 msgstr "傳遞引數 %d 的 %qE 捨棄 %qv 限定元從指標目標類型"
 
-#: c/c-typeck.c:6675 c/c-typeck.c:6842 c/c-typeck.c:6885
+#: c/c-typeck.c:6680 c/c-typeck.c:6847 c/c-typeck.c:6890
 #, fuzzy
 msgid "assignment discards %qv qualifier from pointer target type"
 msgstr "指派捨棄 %qv 限定元從指標目標類型"
 
-#: c/c-typeck.c:6677 c/c-typeck.c:6844 c/c-typeck.c:6887
+#: c/c-typeck.c:6682 c/c-typeck.c:6849 c/c-typeck.c:6892
 #, fuzzy
 msgid "initialization discards %qv qualifier from pointer target type"
 msgstr "初始化捨棄 %qv 限定元從指標目標類型"
 
-#: c/c-typeck.c:6679 c/c-typeck.c:6846 c/c-typeck.c:6889
+#: c/c-typeck.c:6684 c/c-typeck.c:6851 c/c-typeck.c:6894
 #, fuzzy
 msgid "return discards %qv qualifier from pointer target type"
 msgstr "回傳捨棄 %qv 限定元從指標目標類型"
 
-#: c/c-typeck.c:6688
+#: c/c-typeck.c:6693
 #, gcc-internal-format
 msgid "ISO C prohibits argument conversion to union type"
 msgstr "ISO C 不允許將引數轉換為聯合"
 
-#: c/c-typeck.c:6750
+#: c/c-typeck.c:6755
 #, gcc-internal-format
 msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgstr "C++ 中不允許從 %qT 到 %qT 的隱含轉換"
 
-#: c/c-typeck.c:6762
+#: c/c-typeck.c:6767
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE from pointer to non-enclosed address space"
 msgstr "傳遞引數 %d 的 %qE 從指標到 non-enclosed 位址空間"
 
-#: c/c-typeck.c:6766
+#: c/c-typeck.c:6771
 #, fuzzy, gcc-internal-format
 msgid "assignment from pointer to non-enclosed address space"
 msgstr "指派從指標到 non-enclosed 位址空間"
 
-#: c/c-typeck.c:6770
+#: c/c-typeck.c:6775
 #, fuzzy, gcc-internal-format
 msgid "initialization from pointer to non-enclosed address space"
 msgstr "初始化從指標到 non-enclosed 位址空間"
 
-#: c/c-typeck.c:6774
+#: c/c-typeck.c:6779
 #, fuzzy, gcc-internal-format
 msgid "return from pointer to non-enclosed address space"
 msgstr "回傳從指標到 non-enclosed 位址空間"
 
-#: c/c-typeck.c:6792
+#: c/c-typeck.c:6797
 #, gcc-internal-format
 msgid "argument %d of %qE might be a candidate for a format attribute"
 msgstr "引數 %d(屬於 %qE)可能是 format 屬性的備選"
 
-#: c/c-typeck.c:6798
+#: c/c-typeck.c:6803
 #, gcc-internal-format
 msgid "assignment left-hand side might be a candidate for a format attribute"
 msgstr "賦值的左手邊可能是 format 屬性的備選時"
 
-#: c/c-typeck.c:6803
+#: c/c-typeck.c:6808
 #, gcc-internal-format
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "初始化的左手邊可能是 format 屬性的備選時"
 
-#: c/c-typeck.c:6808 cp/typeck.c:8891
+#: c/c-typeck.c:6813 cp/typeck.c:8891
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "回傳類型可能是 format 屬性的備選"
 
-#: c/c-typeck.c:6857
+#: c/c-typeck.c:6862
 #, gcc-internal-format
 msgid "ISO C forbids passing argument %d of %qE between function pointer and %<void *%>"
 msgstr "ISO C 不允許將引數 %d(屬於 %qE)在函式指標和 %<void *%> 間傳遞"
 
-#: c/c-typeck.c:6860
+#: c/c-typeck.c:6865
 #, gcc-internal-format
 msgid "ISO C forbids assignment between function pointer and %<void *%>"
 msgstr "ISO C 不允許在函式指標和 %<void *%> 間賦值"
 
-#: c/c-typeck.c:6862
+#: c/c-typeck.c:6867
 #, gcc-internal-format
 msgid "ISO C forbids initialization between function pointer and %<void *%>"
 msgstr "ISO C 不允許在函式指標和 %<void *%> 間初始化"
 
-#: c/c-typeck.c:6864
+#: c/c-typeck.c:6869
 #, gcc-internal-format
 msgid "ISO C forbids return between function pointer and %<void *%>"
 msgstr "ISO C 不允許在函式指標和 %<void *%> 間回傳"
 
-#: c/c-typeck.c:6904
+#: c/c-typeck.c:6909
 #, gcc-internal-format
 msgid "pointer targets in passing argument %d of %qE differ in signedness"
 msgstr "傳遞參數 %d (屬於 %qE) 給指標時目的與指標有/無號不一致"
 
-#: c/c-typeck.c:6913
+#: c/c-typeck.c:6918
 #, fuzzy, gcc-internal-format
 #| msgid "pointer targets in assignment differ in signedness"
 msgid "pointer targets in assignment from %qT to %qT differ in signedness"
 msgstr "對指標賦值時目的與指標有/無號不一致"
 
-#: c/c-typeck.c:6918
+#: c/c-typeck.c:6923
 #, fuzzy, gcc-internal-format
 #| msgid "pointer targets in initialization differ in signedness"
 msgid "pointer targets in initialization of %qT from %qT differ in signedness"
 msgstr "初始化指標時目的與指標有/無號不一致"
 
-#: c/c-typeck.c:6923
+#: c/c-typeck.c:6928
 #, fuzzy, gcc-internal-format
 #| msgid "pointer targets in passing argument %d of %qE differ in signedness"
 msgid "pointer targets in returning %qT from a function with return type %qT differ in signedness"
 msgstr "傳遞參數 %d (屬於 %qE) 給指標時目的與指標有/無號不一致"
 
-#: c/c-typeck.c:6961
+#: c/c-typeck.c:6966
 #, gcc-internal-format
 msgid "passing argument %d of %qE from incompatible pointer type"
 msgstr "傳遞參數 %d (屬於 %qE)時在不相容的指標類型間轉換"
 
-#: c/c-typeck.c:6967
+#: c/c-typeck.c:6972
 #, fuzzy, gcc-internal-format
 #| msgid "assignment from incompatible pointer type"
 msgid "assignment to %qT from incompatible pointer type %qT"
 msgstr "永遠不相容的指標類型賦值"
 
-#: c/c-typeck.c:6972
+#: c/c-typeck.c:6977
 #, fuzzy, gcc-internal-format
 #| msgid "initialization from incompatible pointer type"
 msgid "initialization of %qT from incompatible pointer type %qT"
 msgstr "永遠不相容的指標類型初始化"
 
-#: c/c-typeck.c:6977
+#: c/c-typeck.c:6982
 #, fuzzy, gcc-internal-format
 msgid "returning %qT from a function with incompatible return type %qT"
 msgstr "回傳與值在中函式不具任何傳回類型"
@@ -40681,797 +40724,797 @@
 
 #. ??? This should not be an error when inlining calls to
 #. unprototyped functions.
-#: c/c-typeck.c:6991 c/c-typeck.c:7514 cp/typeck.c:2063
+#: c/c-typeck.c:6996 c/c-typeck.c:7519 cp/typeck.c:2063
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "對非左值陣列的無效使用"
 
-#: c/c-typeck.c:7004
+#: c/c-typeck.c:7009
 #, gcc-internal-format
 msgid "passing argument %d of %qE makes pointer from integer without a cast"
 msgstr "傳遞參數 %d (屬於 %qE)時將整數賦給指標，未作類型轉換"
 
-#: c/c-typeck.c:7010
+#: c/c-typeck.c:7015
 #, fuzzy, gcc-internal-format
 #| msgid "assignment makes pointer from integer without a cast"
 msgid "assignment to %qT from %qT makes pointer from integer without a cast"
 msgstr "賦值時將整數賦給指標，未作類型轉換"
 
-#: c/c-typeck.c:7015
+#: c/c-typeck.c:7020
 #, fuzzy, gcc-internal-format
 #| msgid "initialization makes pointer from integer without a cast"
 msgid "initialization of %qT from %qT makes pointer from integer without a cast"
 msgstr "初始化時將整數賦給指標，未作類型轉換"
 
-#: c/c-typeck.c:7019
+#: c/c-typeck.c:7024
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE makes pointer from integer without a cast"
 msgid "returning %qT from a function with return type %qT makes pointer from integer without a cast"
 msgstr "傳遞參數 %d (屬於 %qE)時將整數賦給指標，未作類型轉換"
 
-#: c/c-typeck.c:7035
+#: c/c-typeck.c:7040
 #, gcc-internal-format
 msgid "passing argument %d of %qE makes integer from pointer without a cast"
 msgstr "傳遞參數 %d (屬於 %qE)時將指標賦給整數，未作類型轉換"
 
-#: c/c-typeck.c:7041
+#: c/c-typeck.c:7046
 #, fuzzy, gcc-internal-format
 #| msgid "assignment makes integer from pointer without a cast"
 msgid "assignment to %qT from %qT makes integer from pointer without a cast"
 msgstr "賦值時將指標賦給整數，未作類型轉換"
 
-#: c/c-typeck.c:7046
+#: c/c-typeck.c:7051
 #, fuzzy, gcc-internal-format
 #| msgid "initialization makes integer from pointer without a cast"
 msgid "initialization of %qT from %qT makes integer from pointer without a cast"
 msgstr "初始化將指標賦給整數，未作類型轉換"
 
-#: c/c-typeck.c:7050
+#: c/c-typeck.c:7055
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE makes integer from pointer without a cast"
 msgid "returning %qT from a function with return type %qT makes integer from pointer without a cast"
 msgstr "傳遞參數 %d (屬於 %qE)時將指標賦給整數，未作類型轉換"
 
-#: c/c-typeck.c:7073
+#: c/c-typeck.c:7078
 #, gcc-internal-format
 msgid "incompatible type for argument %d of %qE"
 msgstr "引數 %d(屬於 %qE)類型不相容"
 
-#: c/c-typeck.c:7078
+#: c/c-typeck.c:7083
 #, fuzzy, gcc-internal-format
 msgid "incompatible types when assigning to type %qT from type %qT"
 msgstr "不相容的類型時指派輸入 %qT 從型態 %qT"
 
-#: c/c-typeck.c:7083
+#: c/c-typeck.c:7088
 #, fuzzy, gcc-internal-format
 msgid "incompatible types when initializing type %qT using type %qT"
 msgstr "不相容的類型時初始化型態 %qT 使用型態 %qT"
 
-#: c/c-typeck.c:7088
+#: c/c-typeck.c:7093
 #, fuzzy, gcc-internal-format
 msgid "incompatible types when returning type %qT but %qT was expected"
 msgstr "不相容的類型時傳回類型 %qT 但是 %qT 被預期"
 
-#: c/c-typeck.c:7152
+#: c/c-typeck.c:7157
 #, gcc-internal-format
 msgid "traditional C rejects automatic aggregate initialization"
 msgstr "傳統 C 不接受自動的聚合初始化"
 
-#: c/c-typeck.c:7388 c/c-typeck.c:8284 cp/typeck2.c:1045
+#: c/c-typeck.c:7393 c/c-typeck.c:8289 cp/typeck2.c:1045
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "對彈性陣列成員的初始化"
 
-#: c/c-typeck.c:7398 cp/typeck2.c:1059
+#: c/c-typeck.c:7403 cp/typeck2.c:1059
 #, gcc-internal-format
 msgid "char-array initialized from wide string"
 msgstr "用寬字串初始化 char 陣列"
 
-#: c/c-typeck.c:7407
+#: c/c-typeck.c:7412
 #, fuzzy, gcc-internal-format
 msgid "wide character array initialized from non-wide string"
 msgstr "寬字元陣列初始化的從 non-wide 字串"
 
-#: c/c-typeck.c:7413
+#: c/c-typeck.c:7418
 #, fuzzy, gcc-internal-format
 msgid "wide character array initialized from incompatible wide string"
 msgstr "寬字元陣列初始化的從不相容的 wide 字串"
 
-#: c/c-typeck.c:7446
+#: c/c-typeck.c:7451
 #, gcc-internal-format
 msgid "array of inappropriate type initialized from string constant"
 msgstr "用字串常數初始化的陣列類型不合適"
 
-#: c/c-typeck.c:7533 c/c-typeck.c:7557 c/c-typeck.c:7560 c/c-typeck.c:7568
-#: c/c-typeck.c:7608 c/c-typeck.c:9131 c/c-typeck.c:9181
+#: c/c-typeck.c:7538 c/c-typeck.c:7562 c/c-typeck.c:7565 c/c-typeck.c:7573
+#: c/c-typeck.c:7613 c/c-typeck.c:9136 c/c-typeck.c:9186
 #, gcc-internal-format
 msgid "initializer element is not constant"
 msgstr "初始值設定元素不是常數"
 
-#: c/c-typeck.c:7542
+#: c/c-typeck.c:7547
 #, gcc-internal-format
 msgid "array initialized from non-constant array expression"
 msgstr "用非常數的陣列運算式初始化陣列"
 
-#: c/c-typeck.c:7573 c/c-typeck.c:7621 c/c-typeck.c:9191
+#: c/c-typeck.c:7578 c/c-typeck.c:7626 c/c-typeck.c:9196
 #, fuzzy, gcc-internal-format
 msgid "initializer element is not a constant expression"
 msgstr "初始設定式元件並非常數運算式"
 
-#: c/c-typeck.c:7615 c/c-typeck.c:9186
+#: c/c-typeck.c:7620 c/c-typeck.c:9191
 #, gcc-internal-format
 msgid "initializer element is not computable at load time"
 msgstr "初始值設定中的元素在載入時無法被計算出"
 
-#: c/c-typeck.c:7634
+#: c/c-typeck.c:7639
 #, gcc-internal-format
 msgid "invalid initializer"
 msgstr "無效的初始值設定"
 
-#: c/c-typeck.c:7912 cp/decl.c:6396
+#: c/c-typeck.c:7917 cp/decl.c:6396
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "不透明的向量類型不能被初始化"
 
-#: c/c-typeck.c:8132
+#: c/c-typeck.c:8137
 #, gcc-internal-format
 msgid "extra brace group at end of initializer"
 msgstr "初始值設定項末尾有多餘的大括號組"
 
-#: c/c-typeck.c:8215
+#: c/c-typeck.c:8220
 #, gcc-internal-format
 msgid "braces around scalar initializer"
 msgstr "標量初始化帶大括號"
 
-#: c/c-typeck.c:8281 c/c-typeck.c:9615 cp/typeck2.c:1084 cp/typeck2.c:1297
+#: c/c-typeck.c:8286 c/c-typeck.c:9620 cp/typeck2.c:1084 cp/typeck2.c:1297
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "在巢狀的上下文中初始化彈性陣列成員"
 
-#: c/c-typeck.c:8318
+#: c/c-typeck.c:8323
 #, gcc-internal-format
 msgid "missing braces around initializer"
 msgstr "初始值設定周圍缺少大括號"
 
-#: c/c-typeck.c:8341
+#: c/c-typeck.c:8346
 #, fuzzy, gcc-internal-format
 msgid "missing initializer for field %qD of %qT"
 msgstr "成員 %qD 缺少初始值設定"
 
-#: c/c-typeck.c:8365
+#: c/c-typeck.c:8370
 #, gcc-internal-format
 msgid "empty scalar initializer"
 msgstr "空的標量初始值設定項"
 
-#: c/c-typeck.c:8370
+#: c/c-typeck.c:8375
 #, gcc-internal-format
 msgid "extra elements in scalar initializer"
 msgstr "標量初始化設定中有多餘元素"
 
-#: c/c-typeck.c:8483 c/c-typeck.c:8565
+#: c/c-typeck.c:8488 c/c-typeck.c:8570
 #, gcc-internal-format
 msgid "array index in non-array initializer"
 msgstr "在非陣列初始值設定項中出現陣列索引"
 
-#: c/c-typeck.c:8488 c/c-typeck.c:8627
+#: c/c-typeck.c:8493 c/c-typeck.c:8632
 #, gcc-internal-format
 msgid "field name not in record or union initializer"
 msgstr "欄位名不在記錄或聯合初始化設定中"
 
-#: c/c-typeck.c:8538
+#: c/c-typeck.c:8543
 #, gcc-internal-format
 msgid "array index in initializer not of integer type"
 msgstr "初始值設定中陣列索引不是整型"
 
-#: c/c-typeck.c:8547 c/c-typeck.c:8556
+#: c/c-typeck.c:8552 c/c-typeck.c:8561
 #, fuzzy, gcc-internal-format
 msgid "array index in initializer is not an integer constant expression"
 msgstr "陣列索引在中初始設定式不是整數常數運算式"
 
-#: c/c-typeck.c:8561 c/c-typeck.c:8563
+#: c/c-typeck.c:8566 c/c-typeck.c:8568
 #, gcc-internal-format
 msgid "nonconstant array index in initializer"
 msgstr "初始值設定中陣列索引不是常數"
 
-#: c/c-typeck.c:8567 c/c-typeck.c:8570
+#: c/c-typeck.c:8572 c/c-typeck.c:8575
 #, gcc-internal-format
 msgid "array index in initializer exceeds array bounds"
 msgstr "初始化時陣列索引越界"
 
-#: c/c-typeck.c:8589
+#: c/c-typeck.c:8594
 #, gcc-internal-format
 msgid "empty index range in initializer"
 msgstr "初始值設定項中索引範圍為空"
 
-#: c/c-typeck.c:8598
+#: c/c-typeck.c:8603
 #, gcc-internal-format
 msgid "array index range in initializer exceeds array bounds"
 msgstr "初始值設定中資料索引範圍超出陣列邊界"
 
-#: c/c-typeck.c:8700 c/c-typeck.c:8730 c/c-typeck.c:9274
+#: c/c-typeck.c:8705 c/c-typeck.c:8735 c/c-typeck.c:9279
 #, gcc-internal-format
 msgid "initialized field with side-effects overwritten"
 msgstr "帶副作用的欄位初始化設定被覆寫"
 
-#: c/c-typeck.c:8704 c/c-typeck.c:8734 c/c-typeck.c:9277
+#: c/c-typeck.c:8709 c/c-typeck.c:8739 c/c-typeck.c:9282
 #, fuzzy, gcc-internal-format
 msgid "initialized field overwritten"
 msgstr "初始化的欄位覆寫"
 
-#: c/c-typeck.c:9208
+#: c/c-typeck.c:9213
 #, fuzzy, gcc-internal-format
 msgid "enum conversion in initialization is invalid in C++"
 msgstr "enum 轉換在中初始化無效在中 C++"
 
-#: c/c-typeck.c:9496
+#: c/c-typeck.c:9501
 #, gcc-internal-format
 msgid "excess elements in char array initializer"
 msgstr "字元陣列初始值設定項中有多餘元素"
 
-#: c/c-typeck.c:9503 c/c-typeck.c:9574
+#: c/c-typeck.c:9508 c/c-typeck.c:9579
 #, gcc-internal-format
 msgid "excess elements in struct initializer"
 msgstr "結構初始值設定項中有多餘元素"
 
-#: c/c-typeck.c:9518
+#: c/c-typeck.c:9523
 #, gcc-internal-format
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr ""
 
-#: c/c-typeck.c:9589
+#: c/c-typeck.c:9594
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr "對彈性陣列成員非靜態地初始化"
 
-#: c/c-typeck.c:9687
+#: c/c-typeck.c:9692
 #, gcc-internal-format
 msgid "excess elements in union initializer"
 msgstr "聯合初始值設定項中有多餘元素"
 
-#: c/c-typeck.c:9709
+#: c/c-typeck.c:9714
 #, gcc-internal-format
 msgid "traditional C rejects initialization of unions"
 msgstr "傳統 C 不接受對聯合的初始化"
 
-#: c/c-typeck.c:9777
+#: c/c-typeck.c:9782
 #, gcc-internal-format
 msgid "excess elements in array initializer"
 msgstr "陣列初始值設定項中有多餘的元素"
 
-#: c/c-typeck.c:9811
+#: c/c-typeck.c:9816
 #, gcc-internal-format
 msgid "excess elements in vector initializer"
 msgstr "向量初始值設定項中有多餘元素"
 
-#: c/c-typeck.c:9843
+#: c/c-typeck.c:9848
 #, gcc-internal-format
 msgid "excess elements in scalar initializer"
 msgstr "標量初始值設定項中有多餘元素"
 
-#: c/c-typeck.c:10086
+#: c/c-typeck.c:10091
 #, gcc-internal-format
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C++ 不允許 %<goto *expr;%>"
 
-#: c/c-typeck.c:10113 c/gimple-parser.c:1604 cp/typeck.c:9113
+#: c/c-typeck.c:10118 c/gimple-parser.c:1604 cp/typeck.c:9113
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "被宣告為 %<noreturn%> 的函式卻有 %<return%> 敘述"
 
-#: c/c-typeck.c:10139 c/c-typeck.c:10143
+#: c/c-typeck.c:10144 c/c-typeck.c:10148
 #, gcc-internal-format
 msgid "%<return%> with no value, in function returning non-void"
 msgstr "在有回傳值的的函式中，%<return%> 不帶回傳值"
 
-#: c/c-typeck.c:10157 c/gimple-parser.c:1614
+#: c/c-typeck.c:10162 c/gimple-parser.c:1614
 #, gcc-internal-format
 msgid "%<return%> with a value, in function returning void"
 msgstr "在無回傳值的函式中，%<return%> 帶回傳值"
 
-#: c/c-typeck.c:10160
+#: c/c-typeck.c:10165
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids %<return%> with expression, in function returning void"
 msgstr "ISO C 禁止 %<return%> 與運算式，在中函式回傳虛值"
 
-#: c/c-typeck.c:10236
+#: c/c-typeck.c:10241
 #, fuzzy, gcc-internal-format
 #| msgid "function returns address of local variable"
 msgid "function returns address of label"
 msgstr "函式回傳局部變數的位址"
 
-#: c/c-typeck.c:10327 cp/semantics.c:1171
+#: c/c-typeck.c:10332 cp/semantics.c:1171
 #, gcc-internal-format
 msgid "switch quantity not an integer"
 msgstr "switch 敘述中的值不是一個整數"
 
-#: c/c-typeck.c:10352
+#: c/c-typeck.c:10357
 #, gcc-internal-format
 msgid "%<long%> switch expression not converted to %<int%> in ISO C"
 msgstr "在 ISO C 中，%<long%> 開關運算式不被轉換為 %<int%>"
 
-#: c/c-typeck.c:10390 c/c-typeck.c:10398
+#: c/c-typeck.c:10395 c/c-typeck.c:10403
 #, fuzzy, gcc-internal-format
 msgid "case label is not an integer constant expression"
 msgstr "大小寫標貼不是整數常數運算式"
 
-#: c/c-typeck.c:10404 cp/parser.c:11067
+#: c/c-typeck.c:10409 cp/parser.c:11067
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "case 標籤出現在開關敘述外"
 
-#: c/c-typeck.c:10406
+#: c/c-typeck.c:10411
 #, gcc-internal-format
 msgid "%<default%> label not within a switch statement"
 msgstr "%<default%> 標籤未出現在 switch 敘述內"
 
-#: c/c-typeck.c:10578 cp/parser.c:12356
+#: c/c-typeck.c:10583 cp/parser.c:12353
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "break 敘述不在循環或開關敘述內"
 
-#: c/c-typeck.c:10580 cp/parser.c:12379
+#: c/c-typeck.c:10585 cp/parser.c:12376
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "continue 敘述出現在循環以外"
 
-#: c/c-typeck.c:10585 cp/parser.c:12369
+#: c/c-typeck.c:10590 cp/parser.c:12366
 #, fuzzy, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr "中斷敘述使用的與 OpenMP 用於迴圈"
 
-#: c/c-typeck.c:10590
+#: c/c-typeck.c:10595
 #, fuzzy, gcc-internal-format
 #| msgid "break statement not within loop or switch"
 msgid "break statement within %<#pragma simd%> loop body"
 msgstr "break 敘述不在循環或開關敘述內"
 
-#: c/c-typeck.c:10592
+#: c/c-typeck.c:10597
 #, fuzzy, gcc-internal-format
 #| msgid "continue statement not within a loop"
 msgid "continue statement within %<#pragma simd%> loop body"
 msgstr "continue 敘述出現在循環以外"
 
-#: c/c-typeck.c:10618 cp/cp-gimplify.c:432
+#: c/c-typeck.c:10623 cp/cp-gimplify.c:432
 #, gcc-internal-format
 msgid "statement with no effect"
 msgstr "敘述不起作用"
 
-#: c/c-typeck.c:10662
+#: c/c-typeck.c:10667
 #, gcc-internal-format
 msgid "expression statement has incomplete type"
 msgstr "運算式敘述類型不完全"
 
-#: c/c-typeck.c:11476 c/c-typeck.c:11644 cp/typeck.c:5017
+#: c/c-typeck.c:11481 c/c-typeck.c:11649 cp/typeck.c:5017
 #, fuzzy, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr "比較向量與不同的元件類型"
 
-#: c/c-typeck.c:11484 c/c-typeck.c:11652 cp/typeck.c:5030
+#: c/c-typeck.c:11489 c/c-typeck.c:11657 cp/typeck.c:5030
 #, fuzzy, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr "比較向量與不同的元件號碼的"
 
-#: c/c-typeck.c:11509 c/c-typeck.c:11677 cp/typeck.c:5058
+#: c/c-typeck.c:11514 c/c-typeck.c:11682 cp/typeck.c:5058
 #, fuzzy, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr "找不到介面用於類別 %qE"
 
-#: c/c-typeck.c:11523 cp/typeck.c:4743
+#: c/c-typeck.c:11528 cp/typeck.c:4743
 #, gcc-internal-format
 msgid "comparing floating point with == or != is unsafe"
 msgstr "使用 == 或 != 比較浮點數是不安全的"
 
-#: c/c-typeck.c:11541 c/c-typeck.c:11562
+#: c/c-typeck.c:11546 c/c-typeck.c:11567
 #, fuzzy, gcc-internal-format
 msgid "the comparison will always evaluate as %<false%> for the address of %qD will never be NULL"
 msgstr "比較將一律評估做為 %<false%> 用於位址的 %qD 將永不是空值"
 
-#: c/c-typeck.c:11547 c/c-typeck.c:11568
+#: c/c-typeck.c:11552 c/c-typeck.c:11573
 #, fuzzy, gcc-internal-format
 msgid "the comparison will always evaluate as %<true%> for the address of %qD will never be NULL"
 msgstr "比較將一律評估做為 %<true%> 用於位址的 %qD 將永不是空值"
 
-#: c/c-typeck.c:11589 c/c-typeck.c:11718
+#: c/c-typeck.c:11594 c/c-typeck.c:11723
 #, fuzzy, gcc-internal-format
 msgid "comparison of pointers to disjoint address spaces"
 msgstr "比較的指標到 disjoint 位址空間"
 
-#: c/c-typeck.c:11596 c/c-typeck.c:11602
+#: c/c-typeck.c:11601 c/c-typeck.c:11607
 #, gcc-internal-format
 msgid "ISO C forbids comparison of %<void *%> with function pointer"
 msgstr "ISO C 不允許在 %<void *%> 和函式指標間比較"
 
-#: c/c-typeck.c:11609 c/c-typeck.c:11728
+#: c/c-typeck.c:11614 c/c-typeck.c:11733
 #, gcc-internal-format
 msgid "comparison of distinct pointer types lacks a cast"
 msgstr "比較不相關的指標時缺少類型轉換"
 
-#: c/c-typeck.c:11621 c/c-typeck.c:11626 c/c-typeck.c:11754 c/c-typeck.c:11759
+#: c/c-typeck.c:11626 c/c-typeck.c:11631 c/c-typeck.c:11759 c/c-typeck.c:11764
 #, gcc-internal-format
 msgid "comparison between pointer and integer"
 msgstr "比較指標和整數"
 
-#: c/c-typeck.c:11706
+#: c/c-typeck.c:11711
 #, gcc-internal-format
 msgid "comparison of complete and incomplete pointers"
 msgstr "在完全和不完全指標間比較"
 
-#: c/c-typeck.c:11708
+#: c/c-typeck.c:11713
 #, gcc-internal-format
 msgid "ISO C forbids ordered comparisons of pointers to functions"
 msgstr "ISO C 不允許函式指標間比較大小"
 
-#: c/c-typeck.c:11713
+#: c/c-typeck.c:11718
 #, fuzzy, gcc-internal-format
 msgid "ordered comparison of pointer with null pointer"
 msgstr "已排序的比較的指標與空指標"
 
-#: c/c-typeck.c:11736 c/c-typeck.c:11739 c/c-typeck.c:11746 c/c-typeck.c:11749
+#: c/c-typeck.c:11741 c/c-typeck.c:11744 c/c-typeck.c:11751 c/c-typeck.c:11754
 #: cp/typeck.c:5081 cp/typeck.c:5088
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "指標與整數 0 比較大小"
 
-#: c/c-typeck.c:11811
+#: c/c-typeck.c:11816
 #, fuzzy, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
 msgstr "隱含轉換從 %qT 到 %qT 到匹配其他運算元的二進位運算式"
 
-#: c/c-typeck.c:12126
+#: c/c-typeck.c:12131
 #, gcc-internal-format
 msgid "used array that cannot be converted to pointer where scalar is required"
 msgstr "需要標量時使用了不能被轉換為指標的陣列"
 
-#: c/c-typeck.c:12130
+#: c/c-typeck.c:12135
 #, gcc-internal-format
 msgid "used struct type value where scalar is required"
 msgstr "需要標量時使用了結構類型"
 
-#: c/c-typeck.c:12134
+#: c/c-typeck.c:12139
 #, gcc-internal-format
 msgid "used union type value where scalar is required"
 msgstr "需要標量時使用了聯合類型"
 
-#: c/c-typeck.c:12150
+#: c/c-typeck.c:12155
 #, fuzzy, gcc-internal-format
 msgid "used vector type where scalar is required"
 msgstr "使用的向量型態位置純量被必要項"
 
-#: c/c-typeck.c:12340 cp/semantics.c:8508
+#: c/c-typeck.c:12345 cp/semantics.c:8511
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12379 cp/semantics.c:8545
+#: c/c-typeck.c:12384 cp/semantics.c:8548
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12423 c/c-typeck.c:13581 c/c-typeck.c:13642 c/c-typeck.c:13704
+#: c/c-typeck.c:12428 c/c-typeck.c:13586 c/c-typeck.c:13647 c/c-typeck.c:13709
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "太多 %qs 子句"
 
-#: c/c-typeck.c:12436 c/c-typeck.c:13628 cp/semantics.c:4546
-#: cp/semantics.c:6717
+#: c/c-typeck.c:12441 c/c-typeck.c:13633 cp/semantics.c:4549
+#: cp/semantics.c:6720
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12445 c/c-typeck.c:13652 cp/semantics.c:4556
-#: cp/semantics.c:6735
+#: c/c-typeck.c:12450 c/c-typeck.c:13657 cp/semantics.c:4559
+#: cp/semantics.c:6738
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qE is a member of a union"
 msgstr "%qD 不是一個成員範本函式"
 
-#: c/c-typeck.c:12455 cp/semantics.c:4570 cp/semantics.c:6760
+#: c/c-typeck.c:12460 cp/semantics.c:4573 cp/semantics.c:6763
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD 並非變數在中子句 %qs"
 
-#: c/c-typeck.c:12459 c/c-typeck.c:13669 cp/semantics.c:4574
-#: cp/semantics.c:6763
+#: c/c-typeck.c:12464 c/c-typeck.c:13674 cp/semantics.c:4577
+#: cp/semantics.c:6766
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qE 並非變數在中子句 %qs"
 
-#: c/c-typeck.c:12466
+#: c/c-typeck.c:12471
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%> %qD in %qs clause"
 msgstr "太多 %qs 子句"
 
-#: c/c-typeck.c:12475 c/c-typeck.c:13676 c/c-typeck.c:13778
-#: cp/semantics.c:4591 cp/semantics.c:6769 cp/semantics.c:6931
+#: c/c-typeck.c:12480 c/c-typeck.c:13681 c/c-typeck.c:13783
+#: cp/semantics.c:4594 cp/semantics.c:6772 cp/semantics.c:6934
 #, fuzzy, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD 並非變數在中子句 %qs"
 
-#: c/c-typeck.c:12511 cp/semantics.c:4623
+#: c/c-typeck.c:12516 cp/semantics.c:4626
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "low bound %qE of array section does not have integral type"
 msgstr "陣列 new 的大小必須有整數類型"
 
-#: c/c-typeck.c:12518 cp/semantics.c:4630
+#: c/c-typeck.c:12523 cp/semantics.c:4633
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "length %qE of array section does not have integral type"
 msgstr "陣列 new 的大小必須有整數類型"
 
-#: c/c-typeck.c:12545 c/c-typeck.c:12609 c/c-typeck.c:12867
-#: cp/semantics.c:4666 cp/semantics.c:4730
+#: c/c-typeck.c:12550 c/c-typeck.c:12614 c/c-typeck.c:12872
+#: cp/semantics.c:4669 cp/semantics.c:4733
 #, fuzzy, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr "陣列區段在中『%s』呼叫於 %L"
 
-#: c/c-typeck.c:12564 cp/semantics.c:4685
+#: c/c-typeck.c:12569 cp/semantics.c:4688
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12572 cp/semantics.c:4693
+#: c/c-typeck.c:12577 cp/semantics.c:4696
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12581 c/c-typeck.c:12691 cp/semantics.c:4702
-#: cp/semantics.c:4812
+#: c/c-typeck.c:12586 c/c-typeck.c:12696 cp/semantics.c:4705
+#: cp/semantics.c:4815
 #, fuzzy, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr "變數長度陣列被使用"
 
-#: c/c-typeck.c:12598 cp/semantics.c:4719
+#: c/c-typeck.c:12603 cp/semantics.c:4722
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12635 cp/semantics.c:4756
+#: c/c-typeck.c:12640 cp/semantics.c:4759
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12650 cp/semantics.c:4771
+#: c/c-typeck.c:12655 cp/semantics.c:4774
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12683 cp/semantics.c:4804
+#: c/c-typeck.c:12688 cp/semantics.c:4807
 #, fuzzy, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr "用於遞增運算式沒有任何效果"
 
-#: c/c-typeck.c:12701 c/c-typeck.c:12810 cp/semantics.c:4822
-#: cp/semantics.c:4934
+#: c/c-typeck.c:12706 c/c-typeck.c:12815 cp/semantics.c:4825
+#: cp/semantics.c:4937
 #, fuzzy, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr "複製陣列區段進入 contiguous 區塊於程序條目"
 
-#: c/c-typeck.c:12709 cp/semantics.c:4830
+#: c/c-typeck.c:12714 cp/semantics.c:4833
 #, fuzzy, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr "%qD 沒有積分或列舉類型型態"
 
-#: c/c-typeck.c:13103 c/c-typeck.c:13113
+#: c/c-typeck.c:13108 c/c-typeck.c:13118
 #, gcc-internal-format
 msgid "%qD in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: c/c-typeck.c:13130
+#: c/c-typeck.c:13135
 #, gcc-internal-format
 msgid "%<_Atomic%> %qE in %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13178
+#: c/c-typeck.c:13183
 #, fuzzy, gcc-internal-format
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "%qE 有無效的型態用於 %<reduction(%s)%>"
 
-#: c/c-typeck.c:13187 cp/semantics.c:5755
+#: c/c-typeck.c:13192 cp/semantics.c:5758
 #, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr ""
 
-#: c/c-typeck.c:13275
+#: c/c-typeck.c:13280
 #, fuzzy, gcc-internal-format
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "變數長度陣列被使用"
 
-#: c/c-typeck.c:13293 c/c-typeck.c:13836 cp/semantics.c:7249
+#: c/c-typeck.c:13298 c/c-typeck.c:13841 cp/semantics.c:7252
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13305 cp/semantics.c:7289
+#: c/c-typeck.c:13310 cp/semantics.c:7292
 #, fuzzy, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE 必須是 %<threadprivate%> 用於 %<copyin%>"
 
-#: c/c-typeck.c:13319 cp/semantics.c:5929
+#: c/c-typeck.c:13324 cp/semantics.c:5932
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr ""
 
-#: c/c-typeck.c:13327
+#: c/c-typeck.c:13332
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with type %qT"
 msgstr ""
 
-#: c/c-typeck.c:13335
+#: c/c-typeck.c:13340
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13354 cp/semantics.c:5999
+#: c/c-typeck.c:13359 cp/semantics.c:6002
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
-#: c/c-typeck.c:13384 c/c-typeck.c:13771 cp/semantics.c:6083
-#: cp/semantics.c:6924
+#: c/c-typeck.c:13389 c/c-typeck.c:13776 cp/semantics.c:6086
+#: cp/semantics.c:6927
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE 並非變數在中子句 %qs"
 
-#: c/c-typeck.c:13393 cp/semantics.c:6092
+#: c/c-typeck.c:13398 cp/semantics.c:6095
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr "%qD 出現一次以上在中資料子句"
 
-#: c/c-typeck.c:13404 c/c-typeck.c:13434 c/c-typeck.c:13463
+#: c/c-typeck.c:13409 c/c-typeck.c:13439 c/c-typeck.c:13468
 #, fuzzy, gcc-internal-format
 msgid "%qE appears more than once in data clauses"
 msgstr "%qE 出現一次以上在中資料子句"
 
-#: c/c-typeck.c:13411 c/c-typeck.c:13440 c/c-typeck.c:13600 c/c-typeck.c:13714
-#: c/c-typeck.c:13720 c/c-typeck.c:13733 c/c-typeck.c:13742
-#: cp/semantics.c:6102 cp/semantics.c:6109 cp/semantics.c:6160
-#: cp/semantics.c:6166 cp/semantics.c:6203 cp/semantics.c:6680
-#: cp/semantics.c:6817 cp/semantics.c:6823 cp/semantics.c:6836
-#: cp/semantics.c:6845
+#: c/c-typeck.c:13416 c/c-typeck.c:13445 c/c-typeck.c:13605 c/c-typeck.c:13719
+#: c/c-typeck.c:13725 c/c-typeck.c:13738 c/c-typeck.c:13747
+#: cp/semantics.c:6105 cp/semantics.c:6112 cp/semantics.c:6163
+#: cp/semantics.c:6169 cp/semantics.c:6206 cp/semantics.c:6683
+#: cp/semantics.c:6820 cp/semantics.c:6826 cp/semantics.c:6839
+#: cp/semantics.c:6848
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr "%qD 出現一次以上在中資料子句"
 
-#: c/c-typeck.c:13413 c/c-typeck.c:13442 c/c-typeck.c:13722 c/c-typeck.c:13744
-#: cp/semantics.c:6111 cp/semantics.c:6168 cp/semantics.c:6825
-#: cp/semantics.c:6847
+#: c/c-typeck.c:13418 c/c-typeck.c:13447 c/c-typeck.c:13727 c/c-typeck.c:13749
+#: cp/semantics.c:6114 cp/semantics.c:6171 cp/semantics.c:6828
+#: cp/semantics.c:6850
 #, fuzzy, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr "%qD 出現一次以上在中資料子句"
 
-#: c/c-typeck.c:13427 cp/semantics.c:6154
+#: c/c-typeck.c:13432 cp/semantics.c:6157
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "%qE 並非變數在中子句 %<firstprivate%>"
 
-#: c/c-typeck.c:13456 cp/semantics.c:6197
+#: c/c-typeck.c:13461 cp/semantics.c:6200
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "%qE 並非變數在中子句 %<lastprivate%>"
 
-#: c/c-typeck.c:13475 cp/semantics.c:6545
+#: c/c-typeck.c:13480 cp/semantics.c:6548
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "%qE 並非變數在中子句 %qs"
 
-#: c/c-typeck.c:13482
+#: c/c-typeck.c:13487
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array"
 msgstr "向量 delete 的引數類型既非指標也非陣列"
 
-#: c/c-typeck.c:13489
+#: c/c-typeck.c:13494
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<aligned%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13496
+#: c/c-typeck.c:13501
 #, fuzzy, gcc-internal-format
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr "%qE 出現一次以上在中資料子句"
 
-#: c/c-typeck.c:13551 cp/semantics.c:6627
+#: c/c-typeck.c:13556 cp/semantics.c:6630
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr "%qE 並非變數在中子句 %qs"
 
-#: c/c-typeck.c:13573 cp/semantics.c:6658
+#: c/c-typeck.c:13578 cp/semantics.c:6661
 #, fuzzy, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr "陣列區段無法允許的在中『%s』呼叫於 %L"
 
-#: c/c-typeck.c:13597 c/c-typeck.c:13731 cp/semantics.c:6677
-#: cp/semantics.c:6834
+#: c/c-typeck.c:13602 c/c-typeck.c:13736 cp/semantics.c:6680
+#: cp/semantics.c:6837
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD 出現一次以上在中資料子句"
 
-#: c/c-typeck.c:13603 c/c-typeck.c:13735 cp/semantics.c:6683
-#: cp/semantics.c:6838
+#: c/c-typeck.c:13608 c/c-typeck.c:13740 cp/semantics.c:6686
+#: cp/semantics.c:6841
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD 出現一次以上在中資料子句"
 
-#: c/c-typeck.c:13635 cp/semantics.c:6724
+#: c/c-typeck.c:13640 cp/semantics.c:6727
 #, fuzzy, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qE 並非變數在中子句 %qs"
 
-#: c/c-typeck.c:13695 c/c-typeck.c:13785 cp/semantics.c:6799
-#: cp/semantics.c:6938
+#: c/c-typeck.c:13700 c/c-typeck.c:13790 cp/semantics.c:6802
+#: cp/semantics.c:6941
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD 並非變數在中子句 %qs"
 
-#: c/c-typeck.c:13766 cp/semantics.c:6918
+#: c/c-typeck.c:13771 cp/semantics.c:6921
 #, fuzzy, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE 並非變數在中子句 %qs"
 
-#: c/c-typeck.c:13794 cp/semantics.c:6947
+#: c/c-typeck.c:13799 cp/semantics.c:6950
 #, fuzzy, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qE 出現一次以上在中資料子句"
 
-#: c/c-typeck.c:13808 cp/semantics.c:6962
+#: c/c-typeck.c:13813 cp/semantics.c:6965
 #, fuzzy, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD 並非變數在中子句 %qs"
 
-#: c/c-typeck.c:13811 cp/semantics.c:6964
+#: c/c-typeck.c:13816 cp/semantics.c:6967
 #, fuzzy, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qE 並非變數在中子句 %qs"
 
-#: c/c-typeck.c:13826
+#: c/c-typeck.c:13831
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "向量 delete 的引數類型既非指標也非陣列"
 
-#: c/c-typeck.c:13900 cp/semantics.c:6359
+#: c/c-typeck.c:13905 cp/semantics.c:6362
 #, gcc-internal-format
 msgid "%<nonmonotonic%> modifier specified for %qs schedule kind"
 msgstr ""
 
-#: c/c-typeck.c:13931 cp/semantics.c:7141
+#: c/c-typeck.c:13936 cp/semantics.c:7144
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:13981 cp/semantics.c:7332
+#: c/c-typeck.c:13986 cp/semantics.c:7335
 #, fuzzy, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE 被 predetermined %qs 用於 %qs"
 
-#: c/c-typeck.c:14001 cp/semantics.c:7223
+#: c/c-typeck.c:14006 cp/semantics.c:7226
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:14013 cp/semantics.c:7236
+#: c/c-typeck.c:14018 cp/semantics.c:7239
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14031 cp/semantics.c:7203
+#: c/c-typeck.c:14036 cp/semantics.c:7206
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14204
+#: c/c-typeck.c:14209
 #, gcc-internal-format
 msgid "cannot use %<va_arg%> with reverse storage order"
 msgstr ""
 
-#: c/c-typeck.c:14209
+#: c/c-typeck.c:14214
 #, fuzzy, gcc-internal-format
 #| msgid "first argument to %<va_arg%> not of type %<va_list%>"
 msgid "second argument to %<va_arg%> is of incomplete type %qT"
 msgstr "給 %<va_arg%> 的第一個參數的類型不是 %<va_list%>"
 
-#: c/c-typeck.c:14215
+#: c/c-typeck.c:14220
 #, fuzzy, gcc-internal-format
 msgid "C++ requires promoted type, not enum type, in %<va_arg%>"
 msgstr "C++需求升級的型態，無法 enum 型態，在中 %<va_arg%>"
@@ -41599,7 +41642,7 @@
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "  沒有已知轉換用於引數 %d 從 %qT 到 %qT"
 
-#: cp/call.c:3441 cp/pt.c:6495
+#: cp/call.c:3441 cp/pt.c:6509
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -41896,7 +41939,7 @@
 msgid "%q#D is private within this context"
 msgstr "在此上下文中"
 
-#: cp/call.c:6478 cp/decl.c:7343
+#: cp/call.c:6478 cp/decl.c:7364
 #, fuzzy, gcc-internal-format
 msgid "declared private here"
 msgstr "宣告的在此"
@@ -41907,7 +41950,7 @@
 msgid "%q#D is protected within this context"
 msgstr "在此上下文中"
 
-#: cp/call.c:6486 cp/decl.c:7344
+#: cp/call.c:6486 cp/decl.c:7365
 #, fuzzy, gcc-internal-format
 msgid "declared protected here"
 msgstr "宣告的在此"
@@ -42224,7 +42267,7 @@
 msgid "call to non-function %qD"
 msgstr "呼叫非函式的 %qD"
 
-#: cp/call.c:9119 cp/pt.c:15053 cp/typeck.c:2901
+#: cp/call.c:9119 cp/pt.c:15075 cp/typeck.c:2901
 #, fuzzy, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "無法呼叫建構子 %<%T::%D%>直接"
@@ -42452,274 +42495,274 @@
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr "無法衍生從 %<final%> 基底 %qT 在中衍生類型 %qT"
 
-#: cp/class.c:2098
+#: cp/class.c:2103
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr "類別 %qT 中所有成員函式都是私有的"
 
-#: cp/class.c:2110
+#: cp/class.c:2115
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr "%q#T 僅定義了一個私有解構函式且沒有夥伴"
 
-#: cp/class.c:2152
+#: cp/class.c:2156
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr "%q#T 僅定義了一個私有建構式且沒有夥伴"
 
-#: cp/class.c:2156
+#: cp/class.c:2160
 #, gcc-internal-format
 msgid "%q#D is public, but requires an existing %q#T object"
 msgstr ""
 
-#: cp/class.c:2430
+#: cp/class.c:2434
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr "%qD 的最終多載在 %qT 中不唯一"
 
-#: cp/class.c:2785
+#: cp/class.c:2789
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D cannot be overloaded"
 msgid "%qD can be marked override"
 msgstr "%q+#D 無法被多載"
 
-#: cp/class.c:2797
+#: cp/class.c:2801
 #, fuzzy, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr "%q+#D 標記的最後的，但是不是虛擬"
 
-#: cp/class.c:2799
+#: cp/class.c:2803
 #, fuzzy, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr "%q+#D 標記的強制變更，但是不強制變更"
 
-#: cp/class.c:2861
+#: cp/class.c:2865
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was hidden"
 msgid "%qD was hidden"
 msgstr "%q+D 被隱藏"
 
-#: cp/class.c:2863
+#: cp/class.c:2867
 #, fuzzy, gcc-internal-format
 #| msgid "  by %q+D"
 msgid "  by %qD"
 msgstr "  為 %q+D"
 
-#: cp/class.c:2896
+#: cp/class.c:2900
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D invalid; an anonymous union can only have non-static data members"
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "%q+#D 無效；匿名聯合只能有非靜態的資料成員"
 
-#: cp/class.c:2906 cp/name-lookup.c:3293 cp/parser.c:19720
+#: cp/class.c:2910 cp/name-lookup.c:3293 cp/parser.c:19717
 #, fuzzy, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr "%<mwords-little-endian%> 被不宜用而將被  移除的在中未來釋出"
 
-#: cp/class.c:3097
+#: cp/class.c:3101
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr ""
 
-#: cp/class.c:3213
+#: cp/class.c:3217
 #, gcc-internal-format
 msgid "bit-field %q+#D with non-integral type"
 msgstr "位元段 %q+#D 有非整數的類型"
 
-#: cp/class.c:3229
+#: cp/class.c:3233
 #, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr "位元段 %q+D 的寬度不是一個整數常數"
 
-#: cp/class.c:3234
+#: cp/class.c:3238
 #, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr "位元段 %q+D 寬度為負"
 
-#: cp/class.c:3239
+#: cp/class.c:3243
 #, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr "位元段 %q+D 寬度為 0"
 
-#: cp/class.c:3249
+#: cp/class.c:3253
 #, fuzzy, gcc-internal-format
 #| msgid "width of %q+D exceeds its type"
 msgid "width of %qD exceeds its type"
 msgstr "%q+D 的寬度超過了它的類型"
 
-#: cp/class.c:3255
+#: cp/class.c:3259
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is too small to hold all values of %q#T"
 msgid "%qD is too small to hold all values of %q#T"
 msgstr "%q+D 太小而不能存放 %q#T 的所有可能值"
 
-#: cp/class.c:3316
+#: cp/class.c:3320
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr "有建構式的成員 %q+#D 不能用在聯合中"
 
-#: cp/class.c:3319
+#: cp/class.c:3323
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr "有解構函式的成員 %q+#D 不能用在聯合中"
 
-#: cp/class.c:3321
+#: cp/class.c:3325
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr "有複製賦值運算子的成員 %q+#D 不能用在聯合中"
 
-#: cp/class.c:3325
+#: cp/class.c:3329
 #, fuzzy, gcc-internal-format
 msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgstr "無限制的聯合只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/class.c:3453
+#: cp/class.c:3457
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D may not be static because it is a member of a union"
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr "%q+D 不能是靜態的，因為它是聯合的成員"
 
-#: cp/class.c:3460
+#: cp/class.c:3464
 #, fuzzy, gcc-internal-format
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr "  非靜態資料成員 %q+D 有 non-literal 型態"
 
-#: cp/class.c:3470
+#: cp/class.c:3474
 #, gcc-internal-format
 msgid "field %q+D invalidly declared function type"
 msgstr "欄位 %q+D 無效地宣告為函式類型"
 
-#: cp/class.c:3476
+#: cp/class.c:3480
 #, gcc-internal-format
 msgid "field %q+D invalidly declared method type"
 msgstr "欄位 %q+D 無效地宣告為方法類型"
 
-#: cp/class.c:3536
+#: cp/class.c:3540
 #, fuzzy, gcc-internal-format
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr "忽略包裝的屬性因為解裝 non-POD 欄位 %q+#D"
 
-#: cp/class.c:3585
+#: cp/class.c:3589
 #, fuzzy, gcc-internal-format
 #| msgid "non-member %qs cannot be declared %<mutable%>"
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr "非成員 %qs 不能被宣告為 %<mutable%>"
 
-#: cp/class.c:3591
+#: cp/class.c:3595
 #, fuzzy, gcc-internal-format
 #| msgid "non-member %qs cannot be declared %<mutable%>"
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr "非成員 %qs 不能被宣告為 %<mutable%>"
 
-#: cp/class.c:3617
+#: cp/class.c:3621
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr "初始化了聯合 %qT 中的多個欄位"
 
-#: cp/class.c:3658
+#: cp/class.c:3662
 #, fuzzy, gcc-internal-format
 #| msgid "field %q+#D with same name as class"
 msgid "field %q#D with same name as class"
 msgstr "欄位 %q+#D 與類別同名"
 
-#: cp/class.c:3681
+#: cp/class.c:3685
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr "%q#T 有指標資料成員"
 
-#: cp/class.c:3686
+#: cp/class.c:3690
 #, gcc-internal-format
 msgid "  but does not override %<%T(const %T&)%>"
 msgstr "  但沒有多載 %<%T(const %T&)%>"
 
-#: cp/class.c:3688
+#: cp/class.c:3692
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr "  或 %<operator=(const %T&)%>"
 
-#: cp/class.c:3692
+#: cp/class.c:3696
 #, gcc-internal-format
 msgid "  but does not override %<operator=(const %T&)%>"
 msgstr "  也沒有多載 %<operator=(const %T&)%>"
 
-#: cp/class.c:4097
+#: cp/class.c:4101
 #, gcc-internal-format
 msgid "alignment of %qD increased in -fabi-version=9 (GCC 5.2)"
 msgstr ""
 
-#: cp/class.c:4100
+#: cp/class.c:4104
 #, fuzzy, gcc-internal-format
 msgid "alignment of %qD will increase in -fabi-version=9"
 msgstr "對齊的 %qD 是大於原來的宣告"
 
-#: cp/class.c:4378
+#: cp/class.c:4382
 #, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "為非虛方法 %q+D 指定了初始值設定項"
 
-#: cp/class.c:4813
+#: cp/class.c:4817
 #, fuzzy, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr "方法強制變更兩者 %<transaction_pure%> 和 %qE 方法"
 
-#: cp/class.c:4834
+#: cp/class.c:4838
 #, fuzzy, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr "方法宣告 %qE 強迫 %qE 方法"
 
-#: cp/class.c:5350 cp/constexpr.c:237
+#: cp/class.c:5367 cp/constexpr.c:237
 #, fuzzy, gcc-internal-format
 msgid "enclosing class of %<constexpr%> non-static member function %q+#D is not a literal type"
 msgstr "封入類別的 constexpr 非靜態成員函式 %q+#D 並非實字型態"
 
-#: cp/class.c:5374
+#: cp/class.c:5391
 #, fuzzy, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr "%q+T 不是實字因為："
 
-#: cp/class.c:5377
+#: cp/class.c:5394
 #, gcc-internal-format
 msgid "  %qT is a closure type, which is only literal in C++17 and later"
 msgstr ""
 
-#: cp/class.c:5380
+#: cp/class.c:5397
 #, fuzzy, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr "  %q+T 有 non-trivial 解構式"
 
-#: cp/class.c:5387
+#: cp/class.c:5404
 #, fuzzy, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no %<constexpr%> constructor that is not a copy or move constructor"
 msgstr "  %q+T 不是彙總，沒有 trivial 預設建構函式，而沒有任何 constexpr 建構子該並非複製或移動建構子"
 
-#: cp/class.c:5420
+#: cp/class.c:5437
 #, fuzzy, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "  基礎類別 %qT 的 %q+T 是 non-literal"
 
-#: cp/class.c:5435
+#: cp/class.c:5452
 #, fuzzy, gcc-internal-format
 msgid "  non-static data member %qD has non-literal type"
 msgstr "  非靜態資料成員 %q+D 有 non-literal 型態"
 
-#: cp/class.c:5442
+#: cp/class.c:5459
 #, fuzzy, gcc-internal-format
 msgid "  non-static data member %qD has volatile type"
 msgstr "  非靜態資料成員 %q+D 有 non-literal 型態"
 
-#: cp/class.c:5561
+#: cp/class.c:5578
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "基礎類別 %q#T 有一個非虛解構函式"
 
-#: cp/class.c:5590
+#: cp/class.c:5607
 #, fuzzy, gcc-internal-format
 #| msgid "non-static reference %q+#D in class without a constructor"
 msgid "non-static reference %q#D in class without a constructor"
 msgstr "類別中有非靜態參照 %q+#D，卻沒有提供建構式"
 
-#: cp/class.c:5596
+#: cp/class.c:5613
 #, fuzzy, gcc-internal-format
 #| msgid "non-static const member %q+#D in class without a constructor"
 msgid "non-static const member %q#D in class without a constructor"
@@ -42727,157 +42770,157 @@
 
 #. If the function is defaulted outside the class, we just
 #. give the synthesis error.
-#: cp/class.c:5624
+#: cp/class.c:5641
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared to take const reference, but implicit declaration would take non-const"
 msgstr "%q+D 宣告到需常數參考，但是蘊含宣告會需 non-const"
 
-#: cp/class.c:5898
+#: cp/class.c:5915
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr "由於存在歧義，直接基礎類別 %qT 在 %qT 中無法存取"
 
-#: cp/class.c:5910
+#: cp/class.c:5927
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr "由於存在歧義，虛基礎類別 %qT 在 %qT 中無法存取"
 
-#: cp/class.c:6133
+#: cp/class.c:6150
 #, fuzzy, gcc-internal-format
 #| msgid "offset of %q+D is not ABI-compliant and may change in a future version of GCC"
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr "%q+D 的偏移量與 ABI 不相容，並且在 GCC 的未來版本中可能會有變化"
 
-#: cp/class.c:6291
+#: cp/class.c:6308
 #, fuzzy, gcc-internal-format
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr "大小的陣列 %qE 太大"
 
-#: cp/class.c:6576
+#: cp/class.c:6593
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr "無效的使用的 %<...%>與 non-slice"
 
-#: cp/class.c:6578
+#: cp/class.c:6595
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of structure with flexible array member"
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr "對包含彈性陣列成員的結構的無效使用"
 
-#: cp/class.c:6583
+#: cp/class.c:6600
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "array member %q#D declared here"
 msgstr "  %q+#D 已在此宣告過"
 
-#: cp/class.c:6610
+#: cp/class.c:6627
 #, fuzzy, gcc-internal-format
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr "flexible 陣列成員無法於結束的結構"
 
-#: cp/class.c:6612
+#: cp/class.c:6629
 #, fuzzy, gcc-internal-format
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr "flexible 陣列成員在中否則清空結構"
 
-#: cp/class.c:6620 cp/class.c:6650
+#: cp/class.c:6637 cp/class.c:6667
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %q#T"
 msgid "in the definition of %q#T"
 msgstr "%q#T 重定義"
 
-#: cp/class.c:6628
+#: cp/class.c:6645
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD not at end of %q#T"
 msgstr "flexible 陣列成員無法於結束的結構"
 
-#: cp/class.c:6630
+#: cp/class.c:6647
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr "flexible 陣列成員在中否則清空結構"
 
-#: cp/class.c:6648
+#: cp/class.c:6665
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "next member %q#D declared here"
 msgstr "  %q+#D 已在此宣告過"
 
-#: cp/class.c:6760 cp/parser.c:23239
+#: cp/class.c:6777 cp/parser.c:23236
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "%q#T 重定義"
 
-#: cp/class.c:6897
+#: cp/class.c:6914
 #, fuzzy, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "%q#T 有虛擬函式和可存取 non-virtual 解構式"
 
-#: cp/class.c:6925
+#: cp/class.c:6942
 #, fuzzy, gcc-internal-format
 msgid "type transparent %q#T does not have any fields"
 msgstr "型態透明類別 %qT 沒有任何欄位"
 
-#: cp/class.c:6931
+#: cp/class.c:6948
 #, fuzzy, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr "型態透明類別 %qT 有基礎類別"
 
-#: cp/class.c:6935
+#: cp/class.c:6952
 #, fuzzy, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr "型態透明類別 %qT 有虛擬函式"
 
-#: cp/class.c:6941
+#: cp/class.c:6958
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:7071
+#: cp/class.c:7088
 #, fuzzy, gcc-internal-format
 msgid "definition of %qD does not match %<#include <initializer_list>%>"
 msgstr "定義的 %q#D 被標記 %<dllimport%>"
 
-#: cp/class.c:7082
+#: cp/class.c:7099
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr "試圖完成結構，但為先前的解析錯誤所插斷"
 
-#: cp/class.c:7582
+#: cp/class.c:7599
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "語言字串 %<\"%E\"%> 不可識別"
 
-#: cp/class.c:7672
+#: cp/class.c:7689
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr "無法解析多載函式 %qD，基於向類型 %qT 的轉換"
 
-#: cp/class.c:7817
+#: cp/class.c:7834
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr "沒有可將函式 %qD 轉換到類型 %q#T 的匹配項"
 
-#: cp/class.c:7844
+#: cp/class.c:7861
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "將多載函式 %qD 轉換為類型 %q#T 有歧義"
 
-#: cp/class.c:7870
+#: cp/class.c:7887
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "假定是成員指標 %qD"
 
-#: cp/class.c:7873
+#: cp/class.c:7890
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(成員指標只能用 %<&%E%> 構成)"
 
-#: cp/class.c:7948 cp/class.c:7990
+#: cp/class.c:7965 cp/class.c:8007
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "類型資訊不充分"
 
-#: cp/class.c:7968
+#: cp/class.c:7985
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "無法將 %qE 從類型 %qT 轉換到類型 %qT"
@@ -42887,12 +42930,12 @@
 #. A name N used in a class S shall refer to the same declaration
 #. in its context and when re-evaluated in the completed scope of
 #. S.
-#: cp/class.c:8235
+#: cp/class.c:8252
 #, gcc-internal-format
 msgid "declaration of %q#D"
 msgstr "%q#D 的宣告"
 
-#: cp/class.c:8237
+#: cp/class.c:8254
 #, fuzzy, gcc-internal-format
 #| msgid "changes meaning of %qD from %q+#D"
 msgid "changes meaning of %qD from %q#D"
@@ -43293,17 +43336,17 @@
 msgid "unexpected AST of kind %s"
 msgstr "未預期的 AST 的 kind %s"
 
-#: cp/cp-gimplify.c:1415
+#: cp/cp-gimplify.c:1416
 #, gcc-internal-format
 msgid "throw will always call terminate()"
 msgstr ""
 
-#: cp/cp-gimplify.c:1418
+#: cp/cp-gimplify.c:1419
 #, gcc-internal-format
 msgid "in C++11 destructors default to noexcept"
 msgstr ""
 
-#: cp/cp-gimplify.c:1429
+#: cp/cp-gimplify.c:1430
 #, gcc-internal-format
 msgid "in C++11 this throw will terminate because destructors default to noexcept"
 msgstr ""
@@ -43722,7 +43765,7 @@
 msgid "redeclaration %qD differs in %<constexpr%> from previous declaration"
 msgstr "重新宣告 %qD 不同在中 %<constexpr%>"
 
-#: cp/decl.c:1304 cp/decl.c:13843
+#: cp/decl.c:1304 cp/decl.c:13867
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D"
 msgid "previous declaration %qD"
@@ -44072,7 +44115,7 @@
 msgid "  enters OpenMP structured block"
 msgstr "  輸入 OpenMP 結構化訊息塊"
 
-#: cp/decl.c:3434 cp/parser.c:12366 cp/parser.c:12387
+#: cp/decl.c:3434 cp/parser.c:12363 cp/parser.c:12384
 #, fuzzy, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr "無效的離開從 OpenMP 結構化訊息塊"
@@ -44082,7 +44125,7 @@
 msgid "%qD is not a type"
 msgstr "%qD 並非型態"
 
-#: cp/decl.c:3838 cp/parser.c:6366
+#: cp/decl.c:3838 cp/parser.c:6369
 #, gcc-internal-format
 msgid "%qD used without template parameters"
 msgstr "%qD 使用時未帶範本參數"
@@ -44471,8 +44514,8 @@
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr "C99 指示項 %qE 外側彙總初始設定式"
 
-#: cp/decl.c:6011 cp/decl.c:6234 cp/typeck2.c:1310 cp/typeck2.c:1590
-#: cp/typeck2.c:1638 cp/typeck2.c:1685
+#: cp/decl.c:6011 cp/decl.c:6234 cp/typeck2.c:1310 cp/typeck2.c:1593
+#: cp/typeck2.c:1641 cp/typeck2.c:1688
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "%qT 的初始值設定項太多"
@@ -44547,13 +44590,13 @@
 msgid "assignment (not initialization) in declaration"
 msgstr "賦值(不是初始化)出現在宣告中"
 
-#: cp/decl.c:6873 cp/decl.c:12605
+#: cp/decl.c:6873 cp/decl.c:12629
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C++ 不允許指定元素初始值設定"
 
-#: cp/decl.c:6877 cp/decl.c:12609
+#: cp/decl.c:6877 cp/decl.c:12633
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for %qs"
 msgid "%<register%> storage class specifier used"
@@ -44580,957 +44623,957 @@
 msgid "function %q#D is initialized like a variable"
 msgstr "函式 %q#D 像變數一樣被初始化"
 
-#: cp/decl.c:7329
+#: cp/decl.c:7350
 #, fuzzy, gcc-internal-format
 #| msgid "  cannot use obsolete binding at %q+D because it has a destructor"
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "  不能在 %q+D 使用過時的繫結，因為它有解構函式"
 
-#: cp/decl.c:7332
+#: cp/decl.c:7353
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.c:7339
+#: cp/decl.c:7360
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is an inaccessible base of %qT"
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "%qT 是 %qT 不可存取的基礎類別"
 
-#: cp/decl.c:7365
+#: cp/decl.c:7386
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:7374
+#: cp/decl.c:7395
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:7592
+#: cp/decl.c:7613
 #, fuzzy, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr "來源是指標到不完整型態"
 
-#: cp/decl.c:7608
+#: cp/decl.c:7629
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr "ISO C90 禁止變數長度陣列 %qE"
 
-#: cp/decl.c:7617 cp/decl.c:7702
+#: cp/decl.c:7638 cp/decl.c:7723
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
 msgstr[0] "%qs 指定的用於結構欄位"
 
-#: cp/decl.c:7621
+#: cp/decl.c:7642
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
 msgstr[0] ""
 
-#: cp/decl.c:7624
+#: cp/decl.c:7645
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] ""
 
-#: cp/decl.c:7669
+#: cp/decl.c:7690
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to %q#T"
 msgid "cannot decompose variable length vector %qT"
 msgstr "無法宣告參照 %q#T 的指標"
 
-#: cp/decl.c:7695
+#: cp/decl.c:7716
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "陣列大小不是一個整數常運算式"
 
-#: cp/decl.c:7704
+#: cp/decl.c:7725
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.c:7725
+#: cp/decl.c:7746
 #, fuzzy, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr "value-initialization 的函數型式 %qT"
 
-#: cp/decl.c:7751
+#: cp/decl.c:7772
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr "無法宣告指標到經資格修飾函數型式 %qT"
 
-#: cp/decl.c:7756
+#: cp/decl.c:7777
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "產生非類別類型 %qT 的成員指標"
 
-#: cp/decl.c:7761
+#: cp/decl.c:7782
 #, fuzzy, gcc-internal-format
 #| msgid "cannot decompose address"
 msgid "cannot decompose lambda closure type %qT"
 msgstr "無法分解位址"
 
-#: cp/decl.c:7765
+#: cp/decl.c:7786
 #, fuzzy, gcc-internal-format
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "來源是的不完整類別型態"
 
-#: cp/decl.c:7774
+#: cp/decl.c:7795
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "無法套用 %<offsetof%> 到靜態資料成員 %qD"
 
-#: cp/decl.c:8213
+#: cp/decl.c:8234
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:8216
+#: cp/decl.c:8237
 #, fuzzy, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr "  %q+T 有 non-trivial 解構式"
 
-#: cp/decl.c:8222
+#: cp/decl.c:8243
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:8450
+#: cp/decl.c:8471
 #, fuzzy, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "初始設定式失敗到決定大小的 %qT"
 
-#: cp/decl.c:8454
+#: cp/decl.c:8475
 #, fuzzy, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "陣列大小缺少的在中 %qT"
 
-#: cp/decl.c:8457
+#: cp/decl.c:8478
 #, fuzzy, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "zero-size 陣列 %qT"
 
-#: cp/decl.c:8473
+#: cp/decl.c:8494
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "其它類別 %qT 的解構函式不能做為成員"
 
-#: cp/decl.c:8475
+#: cp/decl.c:8496
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "其它類別 %qT 的建構式不能做為成員"
 
-#: cp/decl.c:8499
+#: cp/decl.c:8520
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD 宣告的做為 %<virtual%> 變數"
 
-#: cp/decl.c:8501
+#: cp/decl.c:8522
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "%<const%> 和 %<volatile%>函式說明符於 %qD 無效的在中變數宣告"
 
-#: cp/decl.c:8506
+#: cp/decl.c:8527
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD 宣告的做為 %<virtual%> 參數"
 
-#: cp/decl.c:8508
+#: cp/decl.c:8529
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD 宣告的做為 %<inline%> 參數"
 
-#: cp/decl.c:8510
+#: cp/decl.c:8531
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "%<const%> 和 %<volatile%>函式說明符於 %qD 無效的在中參數宣告"
 
-#: cp/decl.c:8515
+#: cp/decl.c:8536
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD 宣告的做為 %<virtual%> 型態"
 
-#: cp/decl.c:8517
+#: cp/decl.c:8538
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD 宣告的做為 %<inline%> 型態"
 
-#: cp/decl.c:8519
+#: cp/decl.c:8540
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "%<const%> 和 %<volatile%>函式說明符於 %qD 無效的在中類型宣告"
 
-#: cp/decl.c:8524
+#: cp/decl.c:8545
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD 宣告的做為 %<virtual%> 欄位"
 
-#: cp/decl.c:8526
+#: cp/decl.c:8547
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD 宣告的做為 %<inline%> 欄位"
 
-#: cp/decl.c:8528
+#: cp/decl.c:8549
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "%<const%> 和 %<volatile%>函式說明符於 %qD 無效的在中欄位宣告"
 
-#: cp/decl.c:8535
+#: cp/decl.c:8556
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D 宣告為夥伴"
 
-#: cp/decl.c:8542
+#: cp/decl.c:8563
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D 宣告時有異常指定"
 
-#: cp/decl.c:8574
+#: cp/decl.c:8595
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "%qD 的定義不在包含 %qT 的命名空間中"
 
-#: cp/decl.c:8614
+#: cp/decl.c:8635
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "靜態成員函式 %q#D 的宣告帶有類型限定符"
 
-#: cp/decl.c:8624
+#: cp/decl.c:8645
 #, fuzzy, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr "%qD 宣告的做為 non-parameter"
 
-#: cp/decl.c:8630
+#: cp/decl.c:8651
 #, fuzzy, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr "使舊的宣告 %q+#D 出現歧義"
 
-#: cp/decl.c:8632
+#: cp/decl.c:8653
 #, fuzzy, gcc-internal-format
 #| msgid "Java method %qD has non-Java return type %qT"
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "Java 方法 %qD 回傳非 Java 類型 %qT"
 
-#: cp/decl.c:8703
+#: cp/decl.c:8724
 #, fuzzy, gcc-internal-format
 msgid "concept %qD has no definition"
 msgstr "預期 %<;%>之後聯合定義"
 
-#: cp/decl.c:8772
+#: cp/decl.c:8793
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "在夥伴宣告中定義明確特例化 %qD"
 
 #. Something like `template <class T> friend void f<T>()'.
-#: cp/decl.c:8782
+#: cp/decl.c:8803
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "在基本範本的宣告中對範本識別碼 %qD 的使用無效"
 
-#: cp/decl.c:8800
+#: cp/decl.c:8821
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "夥伴範本特例化 %qD 中不允許出現預設參數"
 
-#: cp/decl.c:8808
+#: cp/decl.c:8829
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "%<inline%> 不允許用於夥伴範本特例化 %qD 的宣告"
 
-#: cp/decl.c:8857
+#: cp/decl.c:8878
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "不能將 %<::main%> 宣告為一個範本"
 
-#: cp/decl.c:8859
+#: cp/decl.c:8880
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "不能將 %<::main%> 宣告為 inline"
 
-#: cp/decl.c:8861
+#: cp/decl.c:8882
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be inline"
 msgid "cannot declare %<::main%> to be %<constexpr%>"
 msgstr "不能將 %<::main%> 宣告為 inline"
 
-#: cp/decl.c:8863
+#: cp/decl.c:8884
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "不能將 %<::main%> 宣告為 static"
 
-#: cp/decl.c:8920
+#: cp/decl.c:8941
 #, fuzzy, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "靜態成員函式 %qD 無法有 cv-qualifier"
 
-#: cp/decl.c:8921
+#: cp/decl.c:8942
 #, fuzzy, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "non-member 函式 %qD 無法有 cv-qualifier"
 
-#: cp/decl.c:8929
+#: cp/decl.c:8950
 #, fuzzy, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "靜態成員函式 %qD 無法有 cv-qualifier"
 
-#: cp/decl.c:8930
+#: cp/decl.c:8951
 #, fuzzy, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "non-member 函式 %qD 無法有 cv-qualifier"
 
-#: cp/decl.c:8940
+#: cp/decl.c:8961
 #, fuzzy, gcc-internal-format
 msgid "deduction guide %qD must be declared at namespace scope"
 msgstr "特殊化的 %qD 必須出現於命名空間範圍"
 
-#: cp/decl.c:8946
+#: cp/decl.c:8967
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "deduction guide %qD must not have a function body"
 msgstr "%qD 沒有宣告為一個函式"
 
-#: cp/decl.c:8959
+#: cp/decl.c:8980
 #, fuzzy, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr "實字運算子與 C 鏈結"
 
-#: cp/decl.c:8969
+#: cp/decl.c:8990
 #, fuzzy, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "%qD 有無效的引數清單"
 
-#: cp/decl.c:8977
+#: cp/decl.c:8998
 #, fuzzy, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr "整數字尾 %<%s%>帶陰影由實作"
 
-#: cp/decl.c:8983
+#: cp/decl.c:9004
 #, fuzzy, gcc-internal-format
 msgid "floating point suffix %qs shadowed by implementation"
 msgstr "浮點數字尾 %<%s%>帶陰影由實作"
 
-#: cp/decl.c:8991
+#: cp/decl.c:9012
 #, fuzzy, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr "實字運算子字尾無法前繼的由 %<_%>被保留的用於未來標準化"
 
-#: cp/decl.c:8996
+#: cp/decl.c:9017
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "%qD 必須是 non-member 函式"
 
-#: cp/decl.c:9076
+#: cp/decl.c:9097
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> 必須回傳 %<int%>"
 
-#: cp/decl.c:9116
+#: cp/decl.c:9137
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "隱含宣告的 %qD 的定義"
 
-#: cp/decl.c:9121
+#: cp/decl.c:9142
 #, fuzzy, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "定義的 explicitly-defaulted %q+D"
 
-#: cp/decl.c:9123
+#: cp/decl.c:9144
 #, fuzzy, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr "%q+#D 明確的缺席在此"
 
-#: cp/decl.c:9140
+#: cp/decl.c:9161
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "成員函式 %q#D 未在類別 %qT 中宣告"
 
-#: cp/decl.c:9329
+#: cp/decl.c:9350
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be a template"
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "不能將 %<::main%> 宣告為一個範本"
 
-#: cp/decl.c:9337
+#: cp/decl.c:9358
 #, fuzzy, gcc-internal-format
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "自動變數 %qE 無法 %<threadprivate%>"
 
-#: cp/decl.c:9344
+#: cp/decl.c:9365
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.c:9464
+#: cp/decl.c:9485
 #, fuzzy, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "in-class 初始化的靜態資料成員 %q#D 的不完整型態"
 
-#: cp/decl.c:9468
+#: cp/decl.c:9489
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "%<constexpr%> 所需自 in-class 初始化的靜態資料成員 %q#D 的 non-integral 型態"
 
-#: cp/decl.c:9472
+#: cp/decl.c:9493
 #, fuzzy, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "in-class 初始化的靜態資料成員 %q#D 的 non-literal 型態"
 
-#: cp/decl.c:9486
+#: cp/decl.c:9507
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "類別中對具有非整數類型 %qT 的靜態資料成員的初始化無效"
 
-#: cp/decl.c:9493
+#: cp/decl.c:9514
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ISO C++ 不允許在類別內初始化非常數靜態成員 %qD"
 
-#: cp/decl.c:9498
+#: cp/decl.c:9519
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO C++ 不允許初始化成員常數 %qD，因為它有非整數的類型 %qT"
 
-#: cp/decl.c:9598
+#: cp/decl.c:9619
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "陣列 %qD 的大小具有非整數類型 %qT"
 
-#: cp/decl.c:9600
+#: cp/decl.c:9621
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "陣列 %qT 的大小的類型不是整數"
 
-#: cp/decl.c:9630 cp/decl.c:9680
+#: cp/decl.c:9651 cp/decl.c:9701
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "陣列大小不是一個整數常運算式"
 
-#: cp/decl.c:9646
+#: cp/decl.c:9667
 #, gcc-internal-format
 msgid "size of array %qD is negative"
 msgstr "陣列 %qD 的大小為負"
 
-#: cp/decl.c:9648 cp/init.c:3651
+#: cp/decl.c:9669 cp/init.c:3667
 #, gcc-internal-format
 msgid "size of array is negative"
 msgstr "陣列大小為負數"
 
-#: cp/decl.c:9662
+#: cp/decl.c:9683
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C 不允許大小為 0 的陣列 %qD"
 
-#: cp/decl.c:9664
+#: cp/decl.c:9685
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++ 不允許大小為 0 的陣列"
 
-#: cp/decl.c:9677
+#: cp/decl.c:9698
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "陣列 %qD 的大小不是一個整數常運算式"
 
-#: cp/decl.c:9686
+#: cp/decl.c:9707
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++禁止變數長度陣列 %qD"
 
-#: cp/decl.c:9688
+#: cp/decl.c:9709
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++禁止變數長度陣列"
 
-#: cp/decl.c:9694
+#: cp/decl.c:9715
 #, fuzzy, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr "變數長度陣列 %qD 被使用"
 
-#: cp/decl.c:9697
+#: cp/decl.c:9718
 #, fuzzy, gcc-internal-format
 msgid "variable length array is used"
 msgstr "變數長度陣列被使用"
 
-#: cp/decl.c:9746
+#: cp/decl.c:9767
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "陣列維數溢出"
 
-#: cp/decl.c:9799
+#: cp/decl.c:9820
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "%qD declared as array of %qT"
 msgstr "%q+D 宣告為夥伴"
 
-#: cp/decl.c:9809
+#: cp/decl.c:9830
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "宣告的 %qD 做為陣列的虛值"
 
-#: cp/decl.c:9811
+#: cp/decl.c:9832
 #, fuzzy, gcc-internal-format
 msgid "creating array of void"
 msgstr "建立陣列的虛值"
 
-#: cp/decl.c:9816
+#: cp/decl.c:9837
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "宣告的 %qD 做為陣列的函式"
 
-#: cp/decl.c:9818
+#: cp/decl.c:9839
 #, fuzzy, gcc-internal-format
 msgid "creating array of functions"
 msgstr "建立陣列的函式"
 
-#: cp/decl.c:9823
+#: cp/decl.c:9844
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "宣告的 %qD 做為陣列的參考"
 
-#: cp/decl.c:9825
+#: cp/decl.c:9846
 #, fuzzy, gcc-internal-format
 msgid "creating array of references"
 msgstr "建立陣列的參考"
 
-#: cp/decl.c:9830
+#: cp/decl.c:9851
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "宣告的 %qD 做為陣列的函式成員"
 
-#: cp/decl.c:9832
+#: cp/decl.c:9853
 #, fuzzy, gcc-internal-format
 msgid "creating array of function members"
 msgstr "建立陣列的函式成員"
 
-#: cp/decl.c:9846
+#: cp/decl.c:9867
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "多維陣列 %qD 的宣告必須至少指定除第一維以外所有維的大小"
 
-#: cp/decl.c:9850
+#: cp/decl.c:9871
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "宣告多維陣列必須至少指定除第一維以外所有維的大小"
 
-#: cp/decl.c:9909
+#: cp/decl.c:9930
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "為建構式指定回傳值無效"
 
-#: cp/decl.c:9912
+#: cp/decl.c:9933
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "%<operator %T%> 的宣告中不能使用限定符"
 
-#: cp/decl.c:9922
+#: cp/decl.c:9943
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "指定解構函式的回傳類型無效"
 
-#: cp/decl.c:9925
+#: cp/decl.c:9946
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "%<operator %T%> 的宣告中不能使用限定符"
 
-#: cp/decl.c:9937
+#: cp/decl.c:9958
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "為 %<operator %T%> 指定了回傳值"
 
-#: cp/decl.c:9940
+#: cp/decl.c:9961
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "%<operator %T%> 的宣告中不能使用限定符"
 
-#: cp/decl.c:9948
+#: cp/decl.c:9969
 #, fuzzy, gcc-internal-format
 #| msgid "return type specification for destructor invalid"
 msgid "return type specified for deduction guide"
 msgstr "指定解構函式的回傳類型無效"
 
-#: cp/decl.c:9951
+#: cp/decl.c:9972
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "%<operator %T%> 的宣告中不能使用限定符"
 
-#: cp/decl.c:9955
+#: cp/decl.c:9976
 #, fuzzy, gcc-internal-format
 #| msgid "too many template parameter lists in declaration of %qD"
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "%qD 宣告時範本參數表太多"
 
-#: cp/decl.c:9964
+#: cp/decl.c:9985
 #, fuzzy, gcc-internal-format
 msgid "decl-specifier in declaration of deduction guide"
 msgstr "衝突說明符在中宣告的 %qs"
 
-#: cp/decl.c:9985
+#: cp/decl.c:10006
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "無名變數或欄位宣告為 void"
 
-#: cp/decl.c:9992
+#: cp/decl.c:10013
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "變數或欄位宣告為 void"
 
-#: cp/decl.c:10007
+#: cp/decl.c:10028
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "在全域作用欄位外為函式 %qs 指定 %<inline%> 無效"
 
-#: cp/decl.c:10013
+#: cp/decl.c:10034
 #, fuzzy, gcc-internal-format
 msgid "inline variables are only available with -std=c++17 or -std=gnu++17"
 msgstr "內聯命名空間只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/decl.c:10268
+#: cp/decl.c:10292
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "無效的使用的限定名稱 %<::%D%>"
 
-#: cp/decl.c:10271 cp/decl.c:10291
+#: cp/decl.c:10295 cp/decl.c:10315
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "無效的使用的限定名稱 %<%T::%D%>"
 
-#: cp/decl.c:10274
+#: cp/decl.c:10298
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "無效的使用的限定名稱 %<%D::%D%>"
 
-#: cp/decl.c:10283
+#: cp/decl.c:10307
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a class or a namespace"
 msgstr "%q#T 並非類別或命名空間"
 
-#: cp/decl.c:10305 cp/decl.c:10398 cp/decl.c:10407 cp/decl.c:11970
+#: cp/decl.c:10329 cp/decl.c:10422 cp/decl.c:10431 cp/decl.c:11994
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "%qD 沒有宣告為一個函式"
 
-#: cp/decl.c:10311
+#: cp/decl.c:10335
 #, gcc-internal-format
 msgid "declaration of %qD as non-member"
 msgstr "%qD 未宣告為成員"
 
-#: cp/decl.c:10339
+#: cp/decl.c:10363
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "缺少宣告識別碼：使用了保留字 %qD"
 
-#: cp/decl.c:10390
+#: cp/decl.c:10414
 #, fuzzy, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "函式定義不宣告參數"
 
-#: cp/decl.c:10415
+#: cp/decl.c:10439
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "宣告的 %qD 做為 %<typedef%>"
 
-#: cp/decl.c:10420
+#: cp/decl.c:10444
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "宣告的 %qD 做為參數"
 
-#: cp/decl.c:10454
+#: cp/decl.c:10478
 #, fuzzy, gcc-internal-format
 msgid "%<concept%> cannot appear in a typedef declaration"
 msgstr "%<constexpr%> 無法出現在中 typedef 宣告"
 
-#: cp/decl.c:10460
+#: cp/decl.c:10484
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgstr "%<constexpr%> 無法出現在中 typedef 宣告"
 
-#: cp/decl.c:10468
+#: cp/decl.c:10492
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "%qs 的宣告指定了兩個以上的資料類型"
 
-#: cp/decl.c:10474
+#: cp/decl.c:10498
 #, fuzzy, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr "衝突說明符在中宣告的 %qs"
 
-#: cp/decl.c:10515
+#: cp/decl.c:10539
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C 不支援單獨用 %<complex%> 表示 %<double complex%>"
 
-#: cp/decl.c:10564 cp/decl.c:10567 cp/decl.c:10570
+#: cp/decl.c:10588 cp/decl.c:10591 cp/decl.c:10594
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ 不允許宣告無類型的 %qs"
 
-#: cp/decl.c:10586
+#: cp/decl.c:10610
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr "%<__int128%>未被支援由這個目標"
 
-#: cp/decl.c:10592
+#: cp/decl.c:10616
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++不支援 %<__int128%>用於 %qs"
 
-#: cp/decl.c:10614 cp/decl.c:10634
+#: cp/decl.c:10638 cp/decl.c:10658
 #, fuzzy, gcc-internal-format
 msgid "%<signed%> or %<unsigned%> invalid for %qs"
 msgstr "%<signed%> 或 %<unsigned%>無效的用於 %qs"
 
-#: cp/decl.c:10616
+#: cp/decl.c:10640
 #, fuzzy, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgstr "%<signed%> 和 %<unsigned%>指定的一起用於 %qs"
 
-#: cp/decl.c:10618
+#: cp/decl.c:10642
 #, fuzzy, gcc-internal-format
 msgid "%<long long%> invalid for %qs"
 msgstr "%<long long%> 無效的用於 %qs"
 
-#: cp/decl.c:10620
+#: cp/decl.c:10644
 #, fuzzy, gcc-internal-format
 msgid "%<long%> invalid for %qs"
 msgstr "%<long%> 無效的用於 %qs"
 
-#: cp/decl.c:10622
+#: cp/decl.c:10646
 #, fuzzy, gcc-internal-format
 msgid "%<short%> invalid for %qs"
 msgstr "%<short%> 無效的用於 %qs"
 
-#: cp/decl.c:10624
+#: cp/decl.c:10648
 #, fuzzy, gcc-internal-format
 msgid "%<long%> or %<short%> invalid for %qs"
 msgstr "%<long%> 或 %<short%>無效的用於 %qs"
 
-#: cp/decl.c:10626
+#: cp/decl.c:10650
 #, fuzzy, gcc-internal-format
 msgid "%<long%>, %<int%>, %<short%>, or %<char%> invalid for %qs"
 msgstr "%<long%>，%<int%>，%<short%>，或 %<char%>無效的用於 %qs"
 
-#: cp/decl.c:10628
+#: cp/decl.c:10652
 #, fuzzy, gcc-internal-format
 msgid "%<long%> or %<short%> specified with char for %qs"
 msgstr "%<long%> 或 %<short%>指定的與字元用於 %qs"
 
-#: cp/decl.c:10630
+#: cp/decl.c:10654
 #, fuzzy, gcc-internal-format
 msgid "%<long%> and %<short%> specified together for %qs"
 msgstr "%<long%> 和 %<short%>指定的一起用於 %qs"
 
-#: cp/decl.c:10636
+#: cp/decl.c:10660
 #, fuzzy, gcc-internal-format
 msgid "%<short%> or %<long%> invalid for %qs"
 msgstr "%<short%> 或 %<long%>無效的用於 %qs"
 
-#: cp/decl.c:10644
+#: cp/decl.c:10668
 #, gcc-internal-format
 msgid "long, short, signed or unsigned used invalidly for %qs"
 msgstr "為 %qs 使用 long、short、signed 或 unsigned 無效"
 
-#: cp/decl.c:10712
+#: cp/decl.c:10736
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "對 %qs 而言無效的複數"
 
-#: cp/decl.c:10751
+#: cp/decl.c:10775
 #, gcc-internal-format
 msgid "template placeholder type %qT must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.c:10769
+#: cp/decl.c:10793
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "成員 %qD 不能既被宣告為虛函式，又被宣告為靜態函式"
 
-#: cp/decl.c:10775
+#: cp/decl.c:10799
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD cannot be declared both %<virtual%> and %<constexpr%>"
 msgstr "成員 %qD 不能既被宣告為虛函式，又被宣告為靜態函式"
 
-#: cp/decl.c:10785
+#: cp/decl.c:10809
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "參數宣告中出現的 typedef 宣告無效"
 
-#: cp/decl.c:10790
+#: cp/decl.c:10814
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "貯藏類別指定的用於模板參數 %qs"
 
-#: cp/decl.c:10796
+#: cp/decl.c:10820
 #, gcc-internal-format
 msgid "storage class specifiers invalid in parameter declarations"
 msgstr "為參數宣告指定了無效的存儲類別"
 
-#: cp/decl.c:10800
+#: cp/decl.c:10824
 #, fuzzy, gcc-internal-format
 msgid "a parameter cannot be declared %<concept%>"
 msgstr "參數無法宣告 %<constexpr%>"
 
-#: cp/decl.c:10805
+#: cp/decl.c:10829
 #, fuzzy, gcc-internal-format
 msgid "a parameter cannot be declared %<constexpr%>"
 msgstr "參數無法宣告 %<constexpr%>"
 
-#: cp/decl.c:10815
+#: cp/decl.c:10839
 #, fuzzy, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "%<virtual%> 外側類別宣告"
 
-#: cp/decl.c:10825
+#: cp/decl.c:10849
 #, fuzzy, gcc-internal-format
 #| msgid "Warn when an inlined function cannot be inlined"
 msgid "structured binding declaration cannot be %<inline%>"
 msgstr "當內聯函式無法被內聯時給出警告"
 
-#: cp/decl.c:10828
+#: cp/decl.c:10852
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %<typedef%>"
 msgstr "模板宣告的 %<typedef%>"
 
-#: cp/decl.c:10830
+#: cp/decl.c:10854
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %<constexpr%>"
 msgstr "解構式無法 %<constexpr%>"
 
-#: cp/decl.c:10834
+#: cp/decl.c:10858
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr "屬性忽略的在中宣告的 %q#T"
 
-#: cp/decl.c:10839
+#: cp/decl.c:10863
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %<concept%>"
 msgstr "解構式無法 %<constexpr%>"
 
-#: cp/decl.c:10845
+#: cp/decl.c:10869
 #, fuzzy, gcc-internal-format
 #| msgid "subscripting array declared %<register%>"
 msgid "structured binding declaration cannot be %<register%>"
 msgstr "按下標存取宣告為 %<register%> 的陣列"
 
-#: cp/decl.c:10849
+#: cp/decl.c:10873
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<static%>"
 msgstr ""
 
-#: cp/decl.c:10853
+#: cp/decl.c:10877
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %<extern%>"
 msgstr "巢狀的函式 %qE 宣告 %<extern%>"
 
-#: cp/decl.c:10857
+#: cp/decl.c:10881
 #, fuzzy, gcc-internal-format
 #| msgid "function %qs cannot be declared %<mutable%>"
 msgid "structured binding declaration cannot be %<mutable%>"
 msgstr "函式 %qs 不能被宣告為 %<mutable%>"
 
-#: cp/decl.c:10861
+#: cp/decl.c:10885
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10872
+#: cp/decl.c:10896
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr "屬性忽略的在中宣告的 %q#T"
 
-#: cp/decl.c:10875
+#: cp/decl.c:10899
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10906
+#: cp/decl.c:10930
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "%qs 的宣告指定了多個存儲類別"
 
-#: cp/decl.c:10929
+#: cp/decl.c:10953
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "為 %qs 指定了存儲類別"
 
-#: cp/decl.c:10933
+#: cp/decl.c:10957
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "為參數 %qs 指定了存儲類別"
 
-#: cp/decl.c:10946
+#: cp/decl.c:10970
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "巢狀函式 %qs 被宣告為 %<extern%>"
 
-#: cp/decl.c:10950
+#: cp/decl.c:10974
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "在頂層將 %qs 宣告為 %<auto%>"
 
-#: cp/decl.c:10957
+#: cp/decl.c:10981
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "函式作用欄位的 %qs 隱含為 auto，卻被宣告為 %<__thread%>"
 
-#: cp/decl.c:10969
+#: cp/decl.c:10993
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "為夥伴函式宣告指定了無效的存儲類別"
 
-#: cp/decl.c:11050
+#: cp/decl.c:11074
 #, fuzzy, gcc-internal-format
 #| msgid "multiple storage classes in declaration of %qs"
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "%qs 的宣告指定了多個存儲類別"
 
-#: cp/decl.c:11098
+#: cp/decl.c:11122
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.c:11118
+#: cp/decl.c:11142
 #, fuzzy, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr "%qs 函式使用 %<auto%> 型態說明符而無需尾隨傳回類型"
 
-#: cp/decl.c:11121
+#: cp/decl.c:11145
 #, fuzzy, gcc-internal-format
 msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgstr "尾隨傳回類型只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/decl.c:11127
+#: cp/decl.c:11151
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual function cannot have deduced return type"
 msgstr "虛函式不能是夥伴"
 
-#: cp/decl.c:11134
+#: cp/decl.c:11158
 #, fuzzy, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr "%qs 函式與尾隨傳回類型有 %qT 做為它的型態而非普通 %<auto%>"
 
-#: cp/decl.c:11147
+#: cp/decl.c:11171
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "deduced class type %qD in function return type"
 msgstr "忽略函式回傳類型的類型限定"
 
-#: cp/decl.c:11156
+#: cp/decl.c:11180
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr ""
 
-#: cp/decl.c:11169
+#: cp/decl.c:11193
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
@@ -45537,59 +45580,59 @@
 
 #. Not using maybe_warn_cpp0x because this should
 #. always be an error.
-#: cp/decl.c:11180
+#: cp/decl.c:11204
 #, fuzzy, gcc-internal-format
 msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgstr "尾隨傳回類型只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/decl.c:11183
+#: cp/decl.c:11207
 #, fuzzy, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr "%qs 函式與尾隨傳回類型無法宣告的與 %<auto%> 型態說明符"
 
-#: cp/decl.c:11212
+#: cp/decl.c:11236
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs 宣告為回傳一個函式的函式"
 
-#: cp/decl.c:11218
+#: cp/decl.c:11242
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs 宣告為回傳一個陣列的函式"
 
-#: cp/decl.c:11247
+#: cp/decl.c:11271
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "解構函式不能是靜態成員函式"
 
-#: cp/decl.c:11248
+#: cp/decl.c:11272
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "建構式不能是靜態成員函式"
 
-#: cp/decl.c:11252
+#: cp/decl.c:11276
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "解構函式不能被 cv 限定"
 
-#: cp/decl.c:11253
+#: cp/decl.c:11277
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "建構式不能帶 cv 限定"
 
-#: cp/decl.c:11261
+#: cp/decl.c:11285
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "destructors may not be ref-qualified"
 msgstr "解構函式不能被 cv 限定"
 
-#: cp/decl.c:11262
+#: cp/decl.c:11286
 #, fuzzy, gcc-internal-format
 #| msgid "constructors may not be cv-qualified"
 msgid "constructors may not be ref-qualified"
 msgstr "建構式不能帶 cv 限定"
 
-#: cp/decl.c:11280
+#: cp/decl.c:11304
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructors cannot be declared %<virtual%>"
@@ -45596,253 +45639,253 @@
 msgstr "建構式不能被宣告為虛函式"
 
 #. Cannot be both friend and virtual.
-#: cp/decl.c:11295
+#: cp/decl.c:11319
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "虛函式不能是夥伴"
 
-#: cp/decl.c:11299
+#: cp/decl.c:11323
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "夥伴宣告不在類別定義內"
 
-#: cp/decl.c:11301
+#: cp/decl.c:11325
 #, fuzzy, gcc-internal-format
 msgid "can%'t define friend function %qs in a local class definition"
 msgstr "can%'t 定義朋友函式 %qs 在中區域類別定義"
 
-#: cp/decl.c:11313
+#: cp/decl.c:11337
 #, fuzzy, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr "%qs 函式無法有引數"
 
-#: cp/decl.c:11339
+#: cp/decl.c:11363
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "解構函式不能有參數"
 
-#: cp/decl.c:11379
+#: cp/decl.c:11403
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "無法宣告參照 %q#T 的指標"
 
-#: cp/decl.c:11392 cp/decl.c:11399
+#: cp/decl.c:11416 cp/decl.c:11423
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "無法宣告對 %q#T 的參照"
 
-#: cp/decl.c:11401
+#: cp/decl.c:11425
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "無法宣告參照 %q#T 成員的指標"
 
-#: cp/decl.c:11430
+#: cp/decl.c:11454
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "無法宣告參考到經資格修飾函數型式 %qT"
 
-#: cp/decl.c:11431
+#: cp/decl.c:11455
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "無法宣告指標到經資格修飾函數型式 %qT"
 
-#: cp/decl.c:11504
+#: cp/decl.c:11528
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr "無法宣告參考到 %q#T, 該項並非 typedef 或模板型態引數"
 
-#: cp/decl.c:11574
+#: cp/decl.c:11598
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "範本識別碼 %qD 做為宣告"
 
-#: cp/decl.c:11599
+#: cp/decl.c:11623
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "成員函式隱含地成為所屬類別的夥伴"
 
-#: cp/decl.c:11605
+#: cp/decl.c:11629
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "有多餘的限定 %<%T::%> 於成員 %qs 上"
 
-#: cp/decl.c:11635
+#: cp/decl.c:11659
 #, fuzzy, gcc-internal-format
 #| msgid "cannot define member function %<%T::%s%> within %<%T%>"
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "無法定義成員函式 %<%T::%s%> 於 %<%T%> 之內"
 
-#: cp/decl.c:11637
+#: cp/decl.c:11661
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member function %<%T::%s%> within %<%T%>"
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "無法宣告成員函式 %<%T::%s%> 於 %<%T%> 之內"
 
-#: cp/decl.c:11645
+#: cp/decl.c:11669
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "無法宣告成員 %<%T::%s%> 於 %qT 之內"
 
-#: cp/decl.c:11685
+#: cp/decl.c:11709
 #, fuzzy, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "non-parameter %qs 無法參數包裝"
 
-#: cp/decl.c:11693
+#: cp/decl.c:11717
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "資料成員不能具有可變類型 %qT"
 
-#: cp/decl.c:11695
+#: cp/decl.c:11719
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "參數不能具有可變類型 %qT"
 
-#: cp/decl.c:11706
+#: cp/decl.c:11730
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "%<virtual%> 外側類別宣告"
 
-#: cp/decl.c:11709
+#: cp/decl.c:11733
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<explicit%> in friend declaration"
 msgstr "%<inline%> 用於空宣告中"
 
-#: cp/decl.c:11712
+#: cp/decl.c:11736
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be %<explicit%>"
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "只有建構式才能被宣告為 %<explicit%>"
 
-#: cp/decl.c:11721
+#: cp/decl.c:11745
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "非成員 %qs 不能被宣告為 %<mutable%>"
 
-#: cp/decl.c:11726
+#: cp/decl.c:11750
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "非物件成員 %qs 不能被宣告為 %<mutable%>"
 
-#: cp/decl.c:11732
+#: cp/decl.c:11756
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "函式 %qs 不能被宣告為 %<mutable%>"
 
-#: cp/decl.c:11737
+#: cp/decl.c:11761
 #, gcc-internal-format
 msgid "static %qs cannot be declared %<mutable%>"
 msgstr "靜態 %qs 不能被宣告為 %<mutable%>"
 
-#: cp/decl.c:11742
+#: cp/decl.c:11766
 #, gcc-internal-format
 msgid "const %qs cannot be declared %<mutable%>"
 msgstr "常數 %qs 不能被宣告為 %<mutable%>"
 
-#: cp/decl.c:11747
+#: cp/decl.c:11771
 #, fuzzy, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "參考 %qs 無法宣告 %<mutable%>"
 
-#: cp/decl.c:11778
+#: cp/decl.c:11802
 #, fuzzy, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "typedef 宣告 %<auto%>"
 
-#: cp/decl.c:11783
+#: cp/decl.c:11807
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.c:11787
+#: cp/decl.c:11811
 #, fuzzy, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "typedef 名稱可能無法是 nested-name-specifier"
 
-#: cp/decl.c:11813
+#: cp/decl.c:11837
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ISO C++ 不允許嵌類別的類型 %qD 與其所屬的類別同名"
 
-#: cp/decl.c:11900
+#: cp/decl.c:11924
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "夥伴函式宣告中出現了 %<inline%>"
 
-#: cp/decl.c:11908
+#: cp/decl.c:11932
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "範本參數不能是夥伴"
 
-#: cp/decl.c:11910
+#: cp/decl.c:11934
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "夥伴宣告需要 class，即 %<friend class %T::%D%>"
 
-#: cp/decl.c:11914
+#: cp/decl.c:11938
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "夥伴宣告需要 class，即 %<friend %#T%>"
 
-#: cp/decl.c:11927
+#: cp/decl.c:11951
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "試圖讓 %qT 成為全域欄位的夥伴"
 
-#: cp/decl.c:11947
+#: cp/decl.c:11971
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "非成員函式類型上的限定符無效"
 
-#: cp/decl.c:11951
+#: cp/decl.c:11975
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.c:11961
+#: cp/decl.c:11985
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "抽象宣告 %qT 做為宣告"
 
-#: cp/decl.c:11976
+#: cp/decl.c:12000
 #, fuzzy, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "value-initialization 的函數型式 %qT"
 
-#: cp/decl.c:11995
+#: cp/decl.c:12019
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "不能在參數宣告中使用 %<::%>"
 
-#: cp/decl.c:12001
+#: cp/decl.c:12025
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "%<this%> 不能用在此上下文中"
 
-#: cp/decl.c:12003
+#: cp/decl.c:12027
 #, fuzzy, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "參數宣告 %<auto%>"
 
-#: cp/decl.c:12052 cp/parser.c:3270
+#: cp/decl.c:12076 cp/parser.c:3270
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "使用範本名 %qE 時不帶引數表無效"
 
-#: cp/decl.c:12056
+#: cp/decl.c:12080
 #, fuzzy, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr "非靜態資料成員宣告 %<auto%>"
 
-#: cp/decl.c:12080
+#: cp/decl.c:12104
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids zero-size array %qD"
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C 不允許大小為 0 的陣列 %qD"
 
-#: cp/decl.c:12083
+#: cp/decl.c:12107
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array members"
@@ -45849,162 +45892,162 @@
 msgstr "ISO C90 不允許彈性陣列成員"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:12099
+#: cp/decl.c:12123
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "錯誤地使用了 %<::%>"
 
-#: cp/decl.c:12121
+#: cp/decl.c:12145
 #, fuzzy, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "宣告的函式 %qD 在中無效的語境"
 
-#: cp/decl.c:12130
+#: cp/decl.c:12154
 #, fuzzy, gcc-internal-format
 #| msgid "function %qD declared virtual inside a union"
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "聯合成員函式 %qD 被宣告為虛函式"
 
-#: cp/decl.c:12139
+#: cp/decl.c:12163
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be declared virtual, since it is always static"
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%qD 不能宣告為虛函式，因為它總是靜態的"
 
-#: cp/decl.c:12153
+#: cp/decl.c:12177
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "在解構函式 %qD 中的夥伴宣告需要限定名"
 
-#: cp/decl.c:12160
+#: cp/decl.c:12184
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "%qD 宣告為 %qT 的一個成員"
 
-#: cp/decl.c:12166
+#: cp/decl.c:12190
 #, fuzzy, gcc-internal-format
 msgid "a destructor cannot be %<concept%>"
 msgstr "解構式無法 %<constexpr%>"
 
-#: cp/decl.c:12171
+#: cp/decl.c:12195
 #, fuzzy, gcc-internal-format
 msgid "a destructor cannot be %<constexpr%>"
 msgstr "解構式無法 %<constexpr%>"
 
-#: cp/decl.c:12177
+#: cp/decl.c:12201
 #, fuzzy, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "預期的限定名稱在中朋友宣告用於建構子 %qD"
 
-#: cp/decl.c:12185
+#: cp/decl.c:12209
 #, fuzzy, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr "解構式無法 %<constexpr%>"
 
-#: cp/decl.c:12190
+#: cp/decl.c:12214
 #, fuzzy, gcc-internal-format
 #| msgid "constructor cannot be static member function"
 msgid "a concept cannot be a member function"
 msgstr "建構式不能是靜態成員函式"
 
-#: cp/decl.c:12199
+#: cp/decl.c:12223
 #, fuzzy, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr "局部特化的別名模板 %qD"
 
-#: cp/decl.c:12202
+#: cp/decl.c:12226
 #, fuzzy, gcc-internal-format
 msgid "variable template declared here"
 msgstr "原來的型態宣告的在此"
 
-#: cp/decl.c:12257
+#: cp/decl.c:12281
 #, fuzzy, gcc-internal-format
 #| msgid "field %qD has incomplete type"
 msgid "field %qD has incomplete type %qT"
 msgstr "欄位 %qD 類型不完全"
 
-#: cp/decl.c:12262
+#: cp/decl.c:12286
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "名稱 %qT 類型不完全"
 
-#: cp/decl.c:12272
+#: cp/decl.c:12296
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE 既不是函式也不是成員函式；不能宣告為夥伴"
 
-#: cp/decl.c:12318
+#: cp/decl.c:12342
 #, fuzzy, gcc-internal-format
 msgid "static data member %qE declared %<concept%>"
 msgstr "非靜態資料成員 %qE 宣告 %<constexpr%>"
 
-#: cp/decl.c:12322
+#: cp/decl.c:12346
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "constexpr 靜態資料成員 %qD 必須有初始設定式"
 
-#: cp/decl.c:12350
+#: cp/decl.c:12374
 #, fuzzy, gcc-internal-format
 msgid "non-static data member %qE declared %<concept%>"
 msgstr "非靜態資料成員 %qE 宣告 %<constexpr%>"
 
-#: cp/decl.c:12354
+#: cp/decl.c:12378
 #, fuzzy, gcc-internal-format
 msgid "non-static data member %qE declared %<constexpr%>"
 msgstr "非靜態資料成員 %qE 宣告 %<constexpr%>"
 
-#: cp/decl.c:12409
+#: cp/decl.c:12433
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "函式 %qs 的存儲類別 %<auto%> 無效"
 
-#: cp/decl.c:12411
+#: cp/decl.c:12435
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "函式 %qs 的存儲類別 %<register%> 無效"
 
-#: cp/decl.c:12415
+#: cp/decl.c:12439
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "函式 %qs 的存儲類別 %<__thread%> 無效"
 
-#: cp/decl.c:12418
+#: cp/decl.c:12442
 #, fuzzy, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "函式 %qs 的存儲類別 %<__thread%> 無效"
 
-#: cp/decl.c:12423
+#: cp/decl.c:12447
 #, fuzzy, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "virt-specifiers 在中 %qs 不允許外側類別定義"
 
-#: cp/decl.c:12434
+#: cp/decl.c:12458
 #, fuzzy, gcc-internal-format
 #| msgid "%<static%> specified invalid for function %qs declared out of global scope"
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "在全域作用欄位外為函式 %qs 指定 %<static%> 無效"
 
-#: cp/decl.c:12438
+#: cp/decl.c:12462
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "在全域作用欄位外為函式 %qs 指定 %<inline%> 無效"
 
-#: cp/decl.c:12446
+#: cp/decl.c:12470
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "虛函式 %qs 不是類別成員"
 
-#: cp/decl.c:12453
+#: cp/decl.c:12477
 #, fuzzy, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "%qs 定義的在中 non-class 範圍"
 
-#: cp/decl.c:12454
+#: cp/decl.c:12478
 #, fuzzy, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "%qs 宣告的在中 non-class 範圍"
 
-#: cp/decl.c:12489
+#: cp/decl.c:12513
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "不能將成員函式 %qD 宣告為有靜態連結"
@@ -46011,79 +46054,79 @@
 
 #. 7.1.1: There can be no static function declarations within a
 #. block.
-#: cp/decl.c:12497
+#: cp/decl.c:12521
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "不能在另一個函式中宣告一個靜態函式"
 
-#: cp/decl.c:12533
+#: cp/decl.c:12557
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "與宣告不同，定義靜態資料成員時不能使用 %<static%>"
 
-#: cp/decl.c:12540
+#: cp/decl.c:12564
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "靜態成員 %qD 宣告為 %<register%>"
 
-#: cp/decl.c:12546
+#: cp/decl.c:12570
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "不能明確地將成員 %q#D 宣告為有外部連結"
 
-#: cp/decl.c:12553
+#: cp/decl.c:12577
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "宣告的 constexpr 變數 %qD 並非定義"
 
-#: cp/decl.c:12574
+#: cp/decl.c:12598
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "宣告的 %q#D 沒有任何初始設定式"
 
-#: cp/decl.c:12585
+#: cp/decl.c:12609
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs 已初始化，卻又被宣告為 %<extern%>"
 
-#: cp/decl.c:12589
+#: cp/decl.c:12613
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs 既有 %<extern%> 又有初始值設定"
 
-#: cp/decl.c:12754
+#: cp/decl.c:12778
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "預設引數 %qE 使用 %qD"
 
-#: cp/decl.c:12757
+#: cp/decl.c:12781
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "預設引數 %qE 使用了局部變數 %qD"
 
-#: cp/decl.c:12841
+#: cp/decl.c:12865
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<virtual%> in template declaration of %q#D"
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "在 %q#D 的範本宣告中使用 %<virtual%> 無效"
 
-#: cp/decl.c:12845
+#: cp/decl.c:12869
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<virtual%> in template declaration of %q#D"
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "在 %q#D 的範本宣告中使用 %<virtual%> 無效"
 
-#: cp/decl.c:12868
+#: cp/decl.c:12892
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "參數 %qD 被無效地被宣告為具有方法類型"
 
-#: cp/decl.c:12895
+#: cp/decl.c:12919
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "參數 %qD 包含指標到陣列的不明約束 %qT"
 
-#: cp/decl.c:12897
+#: cp/decl.c:12921
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "參數 %qD 包含參考到陣列的不明約束 %qT"
@@ -46103,177 +46146,177 @@
 #. or implicitly defined), there's no need to worry about their
 #. existence.  Theoretically, they should never even be
 #. instantiated, but that's hard to forestall.
-#: cp/decl.c:13150
+#: cp/decl.c:13174
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "無效的建構式：您要的可能是 %<%T (const %T&)%>"
 
-#: cp/decl.c:13228
+#: cp/decl.c:13252
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD 不能在命名空間宣告"
 
-#: cp/decl.c:13234
+#: cp/decl.c:13258
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD 不能被宣告為靜態的"
 
-#: cp/decl.c:13261
+#: cp/decl.c:13285
 #, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr "%qD 必須是一個非靜態的成員函式"
 
-#: cp/decl.c:13267
+#: cp/decl.c:13291
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD 必須是一個非靜態成員函式或非成員函式"
 
-#: cp/decl.c:13277
+#: cp/decl.c:13301
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD 的引數必須有類別或列舉類型"
 
 #. 13.4.0.3
-#: cp/decl.c:13303
+#: cp/decl.c:13327
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading operator ?:"
 msgstr "ISO C++ 不允許多載 ?: 運算子"
 
 #. Variadic.
-#: cp/decl.c:13314
+#: cp/decl.c:13338
 #, fuzzy, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD 必須不有可變個數引數數量"
 
-#: cp/decl.c:13338
+#: cp/decl.c:13362
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either zero or one argument"
 msgid "%qD must have either zero or one argument"
 msgstr "%qD 必須帶 0 或 1 個引數"
 
-#: cp/decl.c:13339
+#: cp/decl.c:13363
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either one or two arguments"
 msgid "%qD must have either one or two arguments"
 msgstr "%qD 必須帶 1 或 2 個引數"
 
-#: cp/decl.c:13350
+#: cp/decl.c:13374
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its argument"
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "字尾 %qD 必須使用 %<int%> 做為它的參數"
 
-#: cp/decl.c:13351
+#: cp/decl.c:13375
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its second argument"
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "字尾 %qD 必須使用 %<int%> 做為它的第二個參數"
 
-#: cp/decl.c:13361
+#: cp/decl.c:13385
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have no arguments"
 msgstr "%qD 帶且僅帶 2 個引數"
 
-#: cp/decl.c:13362 cp/decl.c:13371
+#: cp/decl.c:13386 cp/decl.c:13395
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly one argument"
 msgid "%qD must have exactly one argument"
 msgstr "%qD 帶且僅帶 1 個引數"
 
-#: cp/decl.c:13372
+#: cp/decl.c:13396
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have exactly two arguments"
 msgstr "%qD 帶且僅帶 2 個引數"
 
-#: cp/decl.c:13389 cp/decl.c:13392
+#: cp/decl.c:13413 cp/decl.c:13416
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD 不能有預設參數"
 
-#: cp/decl.c:13419
+#: cp/decl.c:13443
 #, fuzzy, gcc-internal-format
 msgid "conversion to a reference to void will never use a type conversion operator"
 msgstr "轉換到參考到虛值將永不使用類型轉換運算子"
 
-#: cp/decl.c:13421
+#: cp/decl.c:13445
 #, fuzzy, gcc-internal-format
 msgid "conversion to void will never use a type conversion operator"
 msgstr "轉換到虛值將永不使用類型轉換運算子"
 
-#: cp/decl.c:13428
+#: cp/decl.c:13452
 #, fuzzy, gcc-internal-format
 msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgstr "轉換到參考到相同型態將永不使用類型轉換運算子"
 
-#: cp/decl.c:13430
+#: cp/decl.c:13454
 #, fuzzy, gcc-internal-format
 msgid "conversion to the same type will never use a type conversion operator"
 msgstr "轉換到相同型態將永不使用類型轉換運算子"
 
-#: cp/decl.c:13438
+#: cp/decl.c:13462
 #, fuzzy, gcc-internal-format
 msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgstr "轉換到參考到基礎類別將永不使用類型轉換運算子"
 
-#: cp/decl.c:13440
+#: cp/decl.c:13464
 #, fuzzy, gcc-internal-format
 msgid "conversion to a base class will never use a type conversion operator"
 msgstr "轉換到基礎類別將永不使用類型轉換運算子"
 
-#: cp/decl.c:13455
+#: cp/decl.c:13479
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "使用者定義的 %qD 總是計算所有兩個參數"
 
-#: cp/decl.c:13474
+#: cp/decl.c:13498
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "字首 %qD 應當回傳 %qT"
 
-#: cp/decl.c:13480
+#: cp/decl.c:13504
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "字尾 %qD 應當回傳 %qT"
 
-#: cp/decl.c:13492
+#: cp/decl.c:13516
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD 應當回傳值而非參照"
 
-#: cp/decl.c:13547
+#: cp/decl.c:13571
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "使用範本類型參數 %qT，在 %qs 後"
 
-#: cp/decl.c:13570
+#: cp/decl.c:13594
 #, fuzzy, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "使用別名模板特殊化 %qT 之後 %qs"
 
-#: cp/decl.c:13573
+#: cp/decl.c:13597
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "使用 typedef 名 %qD，在 %qs 後"
 
-#: cp/decl.c:13575
+#: cp/decl.c:13599
 #, fuzzy, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "%qD 有前一個宣告在此"
 
-#: cp/decl.c:13583
+#: cp/decl.c:13607
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "%qT 做為 %qs 被參照"
 
-#: cp/decl.c:13584 cp/decl.c:13591
+#: cp/decl.c:13608 cp/decl.c:13615
 #, fuzzy, gcc-internal-format
 #| msgid "%q+T has a previous declaration here"
 msgid "%qT has a previous declaration here"
 msgstr "%q+T 先前在此處有過宣告"
 
-#: cp/decl.c:13590
+#: cp/decl.c:13614
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "%qT 做為列舉被參照"
@@ -46285,95 +46328,95 @@
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:13605
+#: cp/decl.c:13629
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "%<%s %T%> 需要範本參數"
 
-#: cp/decl.c:13659 cp/name-lookup.c:4652
+#: cp/decl.c:13683 cp/name-lookup.c:4652
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD 與其宣告所在的類別同名"
 
-#: cp/decl.c:13689 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6425
-#: cp/pt.c:9209
+#: cp/decl.c:13713 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6428
+#: cp/pt.c:9223
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT 不是一個範本"
 
-#: cp/decl.c:13694
+#: cp/decl.c:13718
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:13703 cp/name-lookup.c:4079 cp/name-lookup.c:4086
-#: cp/name-lookup.c:4939 cp/parser.c:6376 cp/parser.c:26300
+#: cp/decl.c:13727 cp/name-lookup.c:4079 cp/name-lookup.c:4086
+#: cp/name-lookup.c:4939 cp/parser.c:6379 cp/parser.c:26297
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "對 %qD 的參照有歧義"
 
-#: cp/decl.c:13806
+#: cp/decl.c:13830
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "使用列舉 %q#D 前沒有給出宣告"
 
-#: cp/decl.c:13842
+#: cp/decl.c:13866
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "%qT 重宣告為非範本"
 
-#: cp/decl.c:13982
+#: cp/decl.c:14006
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "衍生聯合 %qT 無效"
 
-#: cp/decl.c:13989
+#: cp/decl.c:14013
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr ""
 
-#: cp/decl.c:14000
+#: cp/decl.c:14024
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not a direct or virtual base of %qT"
 msgid "%qT defined with direct virtual base"
 msgstr "類型 %qT 不是 %qT 的直接或虛基礎類別"
 
-#: cp/decl.c:14025
+#: cp/decl.c:14049
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "基礎類別型 %qT 不是結構或類別"
 
-#: cp/decl.c:14055
+#: cp/decl.c:14079
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "遞迴的類型 %qT 未定義"
 
-#: cp/decl.c:14057
+#: cp/decl.c:14081
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "重複的基礎類別型 %qT 無效"
 
-#: cp/decl.c:14202
+#: cp/decl.c:14226
 #, fuzzy, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr "範圍/unscoped 不匹配在中 enum %q#T"
 
-#: cp/decl.c:14205 cp/decl.c:14213 cp/decl.c:14225 cp/parser.c:18284
+#: cp/decl.c:14229 cp/decl.c:14237 cp/decl.c:14249 cp/parser.c:18281
 #, fuzzy, gcc-internal-format
 msgid "previous definition here"
 msgstr "前一個定義在此"
 
-#: cp/decl.c:14210
+#: cp/decl.c:14234
 #, fuzzy, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr "下層的型態不匹配在中 enum %q#T"
 
-#: cp/decl.c:14222
+#: cp/decl.c:14246
 #, fuzzy, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr "不同的下層的輸入 enum %q#T"
 
-#: cp/decl.c:14300
+#: cp/decl.c:14324
 #, fuzzy, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr "下層的型態 %<%T%>的 %<%T%>必須是整數類資料類型"
@@ -46382,77 +46425,77 @@
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:14447
+#: cp/decl.c:14471
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "沒有一個整數類型可以表示 %qT 的所有列舉值"
 
-#: cp/decl.c:14619
+#: cp/decl.c:14643
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "列舉值值用於 %qD 不是整數常數"
 
-#: cp/decl.c:14629
+#: cp/decl.c:14653
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "列舉值值用於 %qD 不是整數常數"
 
-#: cp/decl.c:14678
+#: cp/decl.c:14702
 #, fuzzy, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "遞增的列舉值值太大用於 %<unsigned long%>"
 
-#: cp/decl.c:14679
+#: cp/decl.c:14703
 #, fuzzy, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "遞增的列舉值值太大用於 %<unsigned long%>"
 
-#: cp/decl.c:14690
+#: cp/decl.c:14714
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "%qD 處列舉值溢出"
 
-#: cp/decl.c:14710
+#: cp/decl.c:14734
 #, fuzzy, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "列舉值值 %E 太大用於下層的型態 %<%T%>"
 
-#: cp/decl.c:14821
+#: cp/decl.c:14845
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "回傳值類型 %q#T 為不完全"
 
-#: cp/decl.c:14999 cp/typeck.c:9286
+#: cp/decl.c:15023 cp/typeck.c:9286
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> 應當回傳一個對 %<*this%> 的參照"
 
-#: cp/decl.c:15344
+#: cp/decl.c:15368
 #, gcc-internal-format
 msgid "invalid function declaration"
 msgstr "無效的函式宣告"
 
-#: cp/decl.c:15786
+#: cp/decl.c:15810
 #, fuzzy, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr "在有回傳值的函式中未發現 return 敘述"
 
-#: cp/decl.c:15788 cp/typeck.c:9166
+#: cp/decl.c:15812 cp/typeck.c:9166
 #, fuzzy, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "由於 %<volatile%>，函式回傳類型不相容"
 
-#: cp/decl.c:15996
+#: cp/decl.c:16020
 #, gcc-internal-format
 msgid "invalid member function declaration"
 msgstr "無效的成員函式宣告"
 
-#: cp/decl.c:16010
+#: cp/decl.c:16034
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD 已在類別 %qT 中定義過"
 
-#: cp/decl.c:16386
+#: cp/decl.c:16410
 #, fuzzy, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr "型態的 %qD 預設值到 %<int%>"
@@ -46492,7 +46535,7 @@
 msgid "deleting %qT is undefined"
 msgstr "刪除 %qT 未定義"
 
-#: cp/decl2.c:585 cp/pt.c:5552
+#: cp/decl2.c:585 cp/pt.c:5566
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "%q#D 宣告為範本"
@@ -46505,7 +46548,7 @@
 #. [temp.mem]
 #.
 #. A destructor shall not be a member template.
-#: cp/decl2.c:640 cp/pt.c:5511
+#: cp/decl2.c:640 cp/pt.c:5525
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "解構函式 %qD 被宣告為一個成員範本"
@@ -46685,47 +46728,47 @@
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "%<operator delete%> 的第一個參數類型為 %qT"
 
-#: cp/decl2.c:2660
+#: cp/decl2.c:2650
 #, fuzzy, gcc-internal-format
 msgid "%qT has a field %qD whose type has no linkage"
 msgstr "%qT 有欄位 %qD 其型態使用匿名命名空間"
 
-#: cp/decl2.c:2664
+#: cp/decl2.c:2654
 #, fuzzy, gcc-internal-format
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr "%qT 有欄位 %qD 其型態使用匿名命名空間"
 
-#: cp/decl2.c:2669
+#: cp/decl2.c:2659
 #, fuzzy, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr "%qT 有欄位 %qD 其型態使用匿名命名空間"
 
-#: cp/decl2.c:2677
+#: cp/decl2.c:2667
 #, fuzzy, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr "%qT 宣告的與更大可視性比型態的它的欄位 %qD"
 
-#: cp/decl2.c:2695
+#: cp/decl2.c:2685
 #, fuzzy, gcc-internal-format
 msgid "%qT has a base %qT whose type has no linkage"
 msgstr "%qT 有基底 %qT 其型態使用匿名命名空間"
 
-#: cp/decl2.c:2699
+#: cp/decl2.c:2689
 #, fuzzy, gcc-internal-format
 msgid "%qT has a base %qT whose type depends on the type %qT which has no linkage"
 msgstr "%qT 有基底 %qT 其型態使用匿名命名空間"
 
-#: cp/decl2.c:2704
+#: cp/decl2.c:2694
 #, fuzzy, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr "%qT 有基底 %qT 其型態使用匿名命名空間"
 
-#: cp/decl2.c:2711
+#: cp/decl2.c:2701
 #, fuzzy, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr "%qT 宣告的與更大可視性比它的基底 %qT"
 
-#: cp/decl2.c:4309
+#: cp/decl2.c:4299
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using unnamed type, is used but never defined"
 msgstr "%q+#D, 宣告的使用匿名型態，被使用但是永不定義"
@@ -46734,64 +46777,64 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4318
+#: cp/decl2.c:4308
 #, fuzzy, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr "匿名型態不具任何鏈結用來宣告變數 %q#D 與鏈結"
 
-#: cp/decl2.c:4322
+#: cp/decl2.c:4312
 #, fuzzy, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr "匿名型態不具任何鏈結用來宣告函式 %q#D 與鏈結"
 
-#: cp/decl2.c:4326
+#: cp/decl2.c:4316
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D does not refer to the unqualified type, so it is not used for linkage"
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr "%q+#D 未指明非限定類型，所以它不做為外部連結"
 
-#: cp/decl2.c:4334
+#: cp/decl2.c:4324
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "%q+#D, 宣告的使用本地型態 %qT，被使用但是永不定義"
 
-#: cp/decl2.c:4338
+#: cp/decl2.c:4328
 #, fuzzy, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr "型態 %qT 不具任何鏈結用來宣告變數 %q#D 與鏈結"
 
-#: cp/decl2.c:4341
+#: cp/decl2.c:4331
 #, fuzzy, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "型態 %qT 不具任何鏈結用來宣告函式 %q#D 與鏈結"
 
-#: cp/decl2.c:4529
+#: cp/decl2.c:4519
 #, fuzzy, gcc-internal-format
 msgid "mangling of %q#D as %qE conflicts with a previous mangle"
 msgstr "%q#D 衝突與前一個宣告"
 
-#: cp/decl2.c:4532
+#: cp/decl2.c:4522
 #, fuzzy, gcc-internal-format
 msgid "previous mangling %q#D"
 msgstr "前一個宣告 %q+#D"
 
-#: cp/decl2.c:4534
+#: cp/decl2.c:4524
 #, fuzzy, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr "-fabi-version=6 (或=0) 避免這個錯誤與變更在中 mangling"
 
-#: cp/decl2.c:4606 cp/decl2.c:4609
+#: cp/decl2.c:4596 cp/decl2.c:4599
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.c:4956
+#: cp/decl2.c:4946
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D used but never defined"
 msgid "inline function %qD used but never defined"
 msgstr "使用了內聯函式 %q+D 但從未定義過"
 
-#: cp/decl2.c:5143
+#: cp/decl2.c:5133
 #, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr "參數 %P (屬於 %q+#D)缺少預設引數"
@@ -46798,17 +46841,17 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5251
+#: cp/decl2.c:5241
 #, fuzzy, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr "轉換 lambda 該項使用 %<...%>到函式指標"
 
-#: cp/decl2.c:5254
+#: cp/decl2.c:5244
 #, fuzzy, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "使用的刪除的函式 %qD"
 
-#: cp/decl2.c:5307
+#: cp/decl2.c:5297
 #, fuzzy, gcc-internal-format
 #| msgid "using %<typename%> outside of template"
 msgid "use of built-in parameter pack %qD outside of a template"
@@ -47097,338 +47140,338 @@
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr "遞迴求值的預設引數用於 %q#D"
 
-#: cp/init.c:613
+#: cp/init.c:629
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr ""
 
-#: cp/init.c:615
+#: cp/init.c:631
 #, fuzzy, gcc-internal-format
 msgid "defined here"
 msgstr "聯合定義的在此"
 
-#: cp/init.c:673
+#: cp/init.c:689
 #, fuzzy, gcc-internal-format
 msgid "initializer for flexible array member %q#D"
 msgstr "無效的初始設定式用於陣列成員 %q#D"
 
-#: cp/init.c:699
+#: cp/init.c:715
 #, fuzzy, gcc-internal-format
 msgid "%qD should be initialized in the member initialization list"
 msgstr "%qD 應該被初始化的在中成員初始值清單"
 
-#: cp/init.c:720
+#: cp/init.c:736
 #, fuzzy, gcc-internal-format
 msgid "%qD is initialized with itself"
 msgstr "%qD 被初始化的以其本身"
 
-#: cp/init.c:831
+#: cp/init.c:847
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for array member %q#D"
 msgstr "無效的初始設定式用於陣列成員 %q#D"
 
-#: cp/init.c:845 cp/init.c:869 cp/init.c:2410 cp/method.c:1368
+#: cp/init.c:861 cp/init.c:885 cp/init.c:2427 cp/method.c:1368
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr "uninitialized 常數成員在中 %q#T"
 
-#: cp/init.c:847 cp/init.c:864 cp/init.c:871 cp/init.c:2395 cp/init.c:2423
+#: cp/init.c:863 cp/init.c:880 cp/init.c:887 cp/init.c:2412 cp/init.c:2440
 #: cp/method.c:1371 cp/method.c:1382
 #, fuzzy, gcc-internal-format
 msgid "%q#D should be initialized"
 msgstr "%qD 應該被初始化的"
 
-#: cp/init.c:862 cp/init.c:2382 cp/method.c:1379
+#: cp/init.c:878 cp/init.c:2399 cp/method.c:1379
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr "uninitialized 參考成員在中 %q#T"
 
-#: cp/init.c:1041
+#: cp/init.c:1057
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D will be initialized after"
 msgid "%qD will be initialized after"
 msgstr "%q+D 將隨後被初始化"
 
-#: cp/init.c:1044
+#: cp/init.c:1060
 #, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr "基礎類別 %qT 將在"
 
-#: cp/init.c:1048
+#: cp/init.c:1064
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D"
 msgid "  %q#D"
 msgstr "  %q+#D"
 
-#: cp/init.c:1050
+#: cp/init.c:1066
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr "  基礎類別 %qT"
 
-#: cp/init.c:1052
+#: cp/init.c:1068
 #, fuzzy, gcc-internal-format
 msgid "  when initialized here"
 msgstr "  時初始化的在此"
 
-#: cp/init.c:1069
+#: cp/init.c:1085
 #, fuzzy, gcc-internal-format
 msgid "multiple initializations given for %qD"
 msgstr "多重初始化施用於 %qD"
 
-#: cp/init.c:1073
+#: cp/init.c:1089
 #, fuzzy, gcc-internal-format
 msgid "multiple initializations given for base %qT"
 msgstr "多重初始化施用於基底 %qT"
 
-#: cp/init.c:1158
+#: cp/init.c:1174
 #, fuzzy, gcc-internal-format
 msgid "initializations for multiple members of %qT"
 msgstr "初始化用於多重成員的 %qT"
 
-#: cp/init.c:1255
+#: cp/init.c:1271
 #, fuzzy, gcc-internal-format
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr "基礎類別 %q#T 應該是明確的初始化的在中複製建構函式"
 
-#: cp/init.c:1482 cp/init.c:1501
+#: cp/init.c:1498 cp/init.c:1517
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr "類別 %qT 沒具名為 %qD 的欄位"
 
-#: cp/init.c:1488
+#: cp/init.c:1504
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr "%q#D 是一個靜態資料成員；它只能在定義時被初始化"
 
-#: cp/init.c:1495
+#: cp/init.c:1511
 #, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr "%q#D 不是 %qT 的非靜態資料成員"
 
-#: cp/init.c:1534
+#: cp/init.c:1550
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr "對沒有基礎類別的 %qT 的無名初始化"
 
-#: cp/init.c:1542
+#: cp/init.c:1558
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr "對使用了多繼承的 %qT 的無名初始化"
 
-#: cp/init.c:1589
+#: cp/init.c:1605
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr "%qD 既是一個直接基礎類別又是一個間接虛基礎類別"
 
-#: cp/init.c:1597
+#: cp/init.c:1613
 #, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr "類型 %qT 不是 %qT 的直接或虛基礎類別"
 
-#: cp/init.c:1600
+#: cp/init.c:1616
 #, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr "類型 %qT 不是 %qT 的直接基礎類別"
 
-#: cp/init.c:1710 cp/init.c:4386 cp/typeck2.c:1175
+#: cp/init.c:1727 cp/init.c:4402 cp/typeck2.c:1175
 #, fuzzy, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "陣列必須被初始化的與 brace-enclosed 初始設定式"
 
-#: cp/init.c:2019 cp/semantics.c:3268
+#: cp/init.c:2036 cp/semantics.c:3271
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qT 並非類別型態"
 
-#: cp/init.c:2075
+#: cp/init.c:2092
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr "不完全類型 %qT 沒有成員 %qD"
 
-#: cp/init.c:2089
+#: cp/init.c:2106
 #, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr "參照位元段 %qD 指標無效"
 
-#: cp/init.c:2175 cp/typeck.c:1893
+#: cp/init.c:2192 cp/typeck.c:1893
 #, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "對非靜態成員函式 %qD 的使用無效"
 
-#: cp/init.c:2182 cp/semantics.c:1835
+#: cp/init.c:2199 cp/semantics.c:1835
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "對非靜態資料成員 %qD 的無效使用"
 
-#: cp/init.c:2379
+#: cp/init.c:2396
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr "uninitialized 參考成員在中 %q#T 使用 %<new%> 而無需 new-initializer"
 
-#: cp/init.c:2387
+#: cp/init.c:2404
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "uninitialized 參考成員在中 %q#T 使用 %<new%> 而無需 new-initializer"
 
-#: cp/init.c:2391
+#: cp/init.c:2408
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr "uninitialized 參考成員在中 %q#T"
 
-#: cp/init.c:2407
+#: cp/init.c:2424
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr "uninitialized 常數成員在中 %q#T 使用 %<new%> 而無需 new-initializer"
 
-#: cp/init.c:2415
+#: cp/init.c:2432
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "uninitialized 常數成員在中 %q#T 使用 %<new%> 而無需 new-initializer"
 
-#: cp/init.c:2419
+#: cp/init.c:2436
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr "uninitialized 常數成員在中 %q#T"
 
-#: cp/init.c:2710
+#: cp/init.c:2727
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2721
+#: cp/init.c:2738
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2732
+#: cp/init.c:2749
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2880
+#: cp/init.c:2896
 #, fuzzy, gcc-internal-format
 msgid "integer overflow in array size"
 msgstr "整數溢出"
 
-#: cp/init.c:2890
+#: cp/init.c:2906
 #, fuzzy, gcc-internal-format
 msgid "array size in new-expression must be constant"
 msgstr "變數「%s」在 %L 處上下文中必須是常數"
 
-#: cp/init.c:2904
+#: cp/init.c:2920
 #, fuzzy, gcc-internal-format
 msgid "variably modified type not allowed in new-expression"
 msgstr "variably 已修改欄位於檔案範圍"
 
-#: cp/init.c:2920
+#: cp/init.c:2936
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by typedef"
 msgstr ""
 
-#: cp/init.c:2922
+#: cp/init.c:2938
 #, fuzzy, gcc-internal-format
 #| msgid "try removing the parentheses around the type-id"
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr "請嘗試刪除類型識別碼兩邊的括號"
 
-#: cp/init.c:2932
+#: cp/init.c:2948
 #, gcc-internal-format
 msgid "invalid type %<void%> for new"
 msgstr "對 new 而言類型 %<void%> 無效"
 
-#: cp/init.c:2975
+#: cp/init.c:2991
 #, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr "%<new%> %q#T 時常數未初始化"
 
-#: cp/init.c:3101
+#: cp/init.c:3117
 #, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr "找不到合適的 %qD，在類別 %qT 中"
 
-#: cp/init.c:3108 cp/search.c:1023
+#: cp/init.c:3124 cp/search.c:1026
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "對成員 %qD 的請求有歧義"
 
-#: cp/init.c:3181
+#: cp/init.c:3197
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr ""
 
-#: cp/init.c:3184
+#: cp/init.c:3200
 #, fuzzy, gcc-internal-format
 #| msgid "class %qT does not have any field named %qD"
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr "類別 %qT 沒具名為 %qD 的欄位"
 
-#: cp/init.c:3187
+#: cp/init.c:3203
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr ""
 
-#: cp/init.c:3370
+#: cp/init.c:3386
 #, fuzzy, gcc-internal-format
 msgid "parenthesized initializer in array new"
 msgstr "parenthesized 初始設定式在中陣列新"
 
-#: cp/init.c:3633
+#: cp/init.c:3649
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr "陣列 new 的大小必須有整數類型"
 
-#: cp/init.c:3665
+#: cp/init.c:3681
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr "new 不能用於參照類型"
 
-#: cp/init.c:3674
+#: cp/init.c:3690
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr "new 不能用於函式類型"
 
-#: cp/init.c:3743
+#: cp/init.c:3759
 #, fuzzy, gcc-internal-format
 #| msgid "possible problem detected in invocation of delete operator:"
 msgid "possible problem detected in invocation of delete [] operator:"
 msgstr "偵測到呼叫 delete 運算子時可能出現的問題："
 
-#: cp/init.c:3747
+#: cp/init.c:3763
 #, fuzzy, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete [] will be called, even if they are declared when the class is defined"
 msgstr "neither 解構式 nor class-specific 運算子刪除將被 called，即使它們被宣告時類別被定義"
 
-#: cp/init.c:4295
+#: cp/init.c:4311
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "初始值設定在完成之前結束"
 
-#: cp/init.c:4599
+#: cp/init.c:4615
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr "delete 時陣列大小不明"
 
-#: cp/init.c:4623
+#: cp/init.c:4639
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete operator:"
 msgstr "偵測到呼叫 delete 運算子時可能出現的問題："
 
-#: cp/init.c:4628
+#: cp/init.c:4644
 #, fuzzy, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
 msgstr "neither 解構式 nor class-specific 運算子刪除將被 called，即使它們被宣告時類別被定義"
 
-#: cp/init.c:4642
+#: cp/init.c:4658
 #, fuzzy, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr "刪除物件的抽象類別型態 %qT 該項有 non-virtual 解構式將造成未定義的行為"
 
-#: cp/init.c:4647
+#: cp/init.c:4663
 #, fuzzy, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr "刪除物件的 polymorphic 類別型態 %qT 該項有 non-virtual 解構式也許造成未定義的行為"
 
-#: cp/init.c:4954
+#: cp/init.c:4970
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "向量 delete 的引數類型既非指標也非陣列"
@@ -47915,7 +47958,7 @@
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "忽略屬性於模板引數 %qT"
 
-#: cp/name-lookup.c:5111 cp/name-lookup.c:7065
+#: cp/name-lookup.c:5111 cp/name-lookup.c:7073
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "指定 %qD 屬性被忽略"
@@ -47962,55 +48005,55 @@
 msgid "it was later defined here"
 msgstr "結構定義的在此"
 
-#: cp/name-lookup.c:6687
+#: cp/name-lookup.c:6695
 #, gcc-internal-format
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn't a template"
 msgstr ""
 
-#: cp/name-lookup.c:7059
+#: cp/name-lookup.c:7067
 #, fuzzy, gcc-internal-format
 #| msgid "switch %qs is no longer supported"
 msgid "strong using directive no longer supported"
 msgstr "開關 %qs 不再被支援"
 
-#: cp/name-lookup.c:7062
+#: cp/name-lookup.c:7070
 #, gcc-internal-format
 msgid "you may use an inline namespace instead"
 msgstr ""
 
-#: cp/name-lookup.c:7079
+#: cp/name-lookup.c:7087
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on local using directive"
 msgstr "屬性忽略的於 uninstantiated 型態"
 
-#: cp/name-lookup.c:7163
+#: cp/name-lookup.c:7171
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "這裡不允許命名空間別名 %qD，假定為 %qD"
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:7183
+#: cp/name-lookup.c:7191
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qD may not be declared within a namespace"
 msgid "cannot nest more than %d namespaces"
 msgstr "%qD 不能在命名空間宣告"
 
-#: cp/name-lookup.c:7218
+#: cp/name-lookup.c:7226
 #, fuzzy, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr "方法屬性必須被指定的於結束只有"
 
-#: cp/name-lookup.c:7219
+#: cp/name-lookup.c:7227
 #, fuzzy, gcc-internal-format
 msgid "%qD defined here"
 msgstr "標貼 %qD 定義的在此"
 
-#: cp/name-lookup.c:7292
+#: cp/name-lookup.c:7300
 #, gcc-internal-format
 msgid "XXX entering pop_everything ()\n"
 msgstr "XXX 進入 pop_everything ()\n"
 
-#: cp/name-lookup.c:7301
+#: cp/name-lookup.c:7309
 #, gcc-internal-format
 msgid "XXX leaving pop_everything ()\n"
 msgstr "XXX 離開 pop_everything ()\n"
@@ -48030,7 +48073,7 @@
 msgid "LEXER_DEBUGGING_ENABLED_P is not set to true"
 msgstr ""
 
-#: cp/parser.c:1352 cp/parser.c:37254
+#: cp/parser.c:1352 cp/parser.c:37251
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -48055,7 +48098,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr "要求用於成員 %qE 在中 non-class 型態 %qT"
 
-#: cp/parser.c:2949 cp/parser.c:18221
+#: cp/parser.c:2949 cp/parser.c:18218
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "%<%T::%E%>未被宣告"
@@ -48135,7 +48178,7 @@
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "浮點實字無法出現在中 constant-expression"
 
-#: cp/parser.c:3143 cp/pt.c:17853
+#: cp/parser.c:3143 cp/pt.c:17890
 #, fuzzy, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr "演員陣容到型態不同於積分或列舉類型型態無法出現在中 constant-expression"
@@ -48359,7 +48402,7 @@
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr "無法找到字串實字運算子 %qD 與 %qT，%qT 引數"
 
-#: cp/parser.c:4587 cp/parser.c:12940
+#: cp/parser.c:4587 cp/parser.c:12937
 #, fuzzy, gcc-internal-format
 msgid "expected declaration"
 msgstr "預期的宣告"
@@ -48410,7 +48453,7 @@
 msgid "fold-expressions only available with -std=c++17 or -std=gnu++17"
 msgstr "lambda 運算式只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:5275 cp/parser.c:5452 cp/parser.c:5630 cp/semantics.c:3612
+#: cp/parser.c:5275 cp/parser.c:5452 cp/parser.c:5633 cp/semantics.c:3615
 #, fuzzy, gcc-internal-format
 msgid "expected primary-expression"
 msgstr "預期 primary-expression"
@@ -48430,93 +48473,93 @@
 msgid "local variable %qD may not appear in this context"
 msgstr "局部變數 %qD 不應出現在此上下文中"
 
-#: cp/parser.c:5787
+#: cp/parser.c:5790
 #, fuzzy, gcc-internal-format
 msgid "expected id-expression"
 msgstr "預期 id-expression"
 
-#: cp/parser.c:5919
+#: cp/parser.c:5922
 #, fuzzy, gcc-internal-format
 msgid "scope %qT before %<~%> is not a class-name"
 msgstr "範圍 %qT 之前 %<~%>並非 class-name"
 
-#: cp/parser.c:5948 cp/parser.c:7860
+#: cp/parser.c:5951 cp/parser.c:7860
 #, fuzzy, gcc-internal-format
 msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgstr "C++0x 自動只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:6059
+#: cp/parser.c:6062
 #, gcc-internal-format
 msgid "declaration of %<~%T%> as member of %qT"
 msgstr "%<~%T%> 宣告為 %qT 的一個成員"
 
-#: cp/parser.c:6074
+#: cp/parser.c:6077
 #, gcc-internal-format
 msgid "typedef-name %qD used as destructor declarator"
 msgstr "typedef 名 %qD 用於解構函式宣告"
 
-#: cp/parser.c:6111 cp/parser.c:20249
+#: cp/parser.c:6114 cp/parser.c:20246
 #, fuzzy, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr "預期 unqualified-id"
 
-#: cp/parser.c:6220
+#: cp/parser.c:6223
 #, fuzzy, gcc-internal-format
 msgid "found %<:%> in nested-name-specifier, expected %<::%>"
 msgstr "找到 %<:%>在中 nested-name-specifier，預期 %<::%>"
 
-#: cp/parser.c:6288
+#: cp/parser.c:6291
 #, fuzzy, gcc-internal-format
 msgid "decltype evaluates to %qT, which is not a class or enumeration type"
 msgstr "decltype 評估到 %qT，該項並非類別或列舉類型型態"
 
-#: cp/parser.c:6314
+#: cp/parser.c:6317
 #, fuzzy, gcc-internal-format
 #| msgid "incomplete type %qT used in nested name specifier"
 msgid "function template-id %qD in nested-name-specifier"
 msgstr "巢狀名指定中使用了不完全的類型 %qT"
 
-#: cp/parser.c:6322
+#: cp/parser.c:6325
 #, fuzzy, gcc-internal-format
 msgid "variable template-id %qD in nested-name-specifier"
 msgstr "預期 nested-name-specifier"
 
-#: cp/parser.c:6426 cp/typeck.c:2684 cp/typeck.c:2687 cp/typeck.c:2704
+#: cp/parser.c:6429 cp/typeck.c:2684 cp/typeck.c:2687 cp/typeck.c:2704
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD 不是一個範本"
 
-#: cp/parser.c:6504
+#: cp/parser.c:6507
 #, fuzzy, gcc-internal-format
 msgid "expected nested-name-specifier"
 msgstr "預期 nested-name-specifier"
 
-#: cp/parser.c:6711 cp/parser.c:8950
+#: cp/parser.c:6714 cp/parser.c:8950
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr "類型可能無法被定義在中演員陣容"
 
-#: cp/parser.c:6797
+#: cp/parser.c:6800
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a %<typeid%> expression"
 msgstr "類型可能無法被定義在中 %<typeid%> 運算式"
 
-#: cp/parser.c:6889
+#: cp/parser.c:6892
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "錯誤的引數數量到 %<__builtin_shuffle%>"
 
-#: cp/parser.c:6901 cp/pt.c:18416
+#: cp/parser.c:6904 cp/pt.c:18453
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "錯誤的引數數量到 %<__builtin_complex%>"
 
-#: cp/parser.c:6995
+#: cp/parser.c:6998
 #, gcc-internal-format
 msgid "ISO C++ forbids compound-literals"
 msgstr "ISO C++ 不允許複合字面值"
 
-#: cp/parser.c:7054
+#: cp/parser.c:7057
 #, gcc-internal-format
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
@@ -48648,7 +48691,7 @@
 msgid "capture of non-variable %qE"
 msgstr "擷取的 non-variable %qD "
 
-#: cp/parser.c:10391 cp/parser.c:10401 cp/semantics.c:3453 cp/semantics.c:3465
+#: cp/parser.c:10391 cp/parser.c:10401 cp/semantics.c:3456 cp/semantics.c:3468
 #, fuzzy, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "%q+#D 宣告的在此"
@@ -48734,7 +48777,7 @@
 msgid "init-statement in selection statements only available with -std=c++17 or -std=gnu++17"
 msgstr "委派建構子只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:11546 cp/parser.c:28490
+#: cp/parser.c:11546 cp/parser.c:28487
 #, fuzzy, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "預期 selection-statement"
@@ -48754,563 +48797,563 @@
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr "不一致開始/結束類型在中 range-based %<for%> 敘述：%qT 和 %qT"
 
-#: cp/parser.c:12250 cp/parser.c:28493
+#: cp/parser.c:12250 cp/parser.c:28490
 #, fuzzy, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "預期 iteration-statement"
 
-#: cp/parser.c:12298
+#: cp/parser.c:12297
 #, fuzzy, gcc-internal-format
 msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
 msgstr "無限制的聯合只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:12426
+#: cp/parser.c:12423
 #, fuzzy, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr "複合陳述在中 constexpr 函式"
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:12434
+#: cp/parser.c:12431
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ 不允許執行時可知的 goto 目的"
 
-#: cp/parser.c:12447 cp/parser.c:28496
+#: cp/parser.c:12444 cp/parser.c:28493
 #, fuzzy, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "預期 jump-statement"
 
-#: cp/parser.c:12620 cp/parser.c:23584
+#: cp/parser.c:12617 cp/parser.c:23581
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "多餘的 %<;%>"
 
-#: cp/parser.c:12863
+#: cp/parser.c:12860
 #, fuzzy, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr "%<__label__%>無法於起始部分的區塊"
 
-#: cp/parser.c:13083
+#: cp/parser.c:13080
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:13103
+#: cp/parser.c:13100
 #, fuzzy, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr "不一致推導用於 %qT：%qT 然後 %qT"
 
-#: cp/parser.c:13124
+#: cp/parser.c:13121
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr "不能混合宣告和函式定義"
 
-#: cp/parser.c:13148
+#: cp/parser.c:13145
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr "類型可能無法被定義在中 exception-declarations"
 
-#: cp/parser.c:13203
+#: cp/parser.c:13200
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13206
+#: cp/parser.c:13203
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13257
+#: cp/parser.c:13254
 #, fuzzy, gcc-internal-format
 msgid "structured bindings only available with -std=c++17 or -std=gnu++17"
 msgstr "無限制的聯合只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:13306
+#: cp/parser.c:13303
 #, fuzzy, gcc-internal-format
 msgid "empty structured binding declaration"
 msgstr "預期的宣告"
 
-#: cp/parser.c:13324
+#: cp/parser.c:13321
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for structured binding declaration"
 msgstr "無效的初始設定式用於成員函式 %qD"
 
-#: cp/parser.c:13491
+#: cp/parser.c:13488
 #, fuzzy, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr "%<friend%> 使用的外側的類別"
 
-#: cp/parser.c:13558
+#: cp/parser.c:13555
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr "%<auto%> 變更平均在中 C++11; 請移除它"
 
-#: cp/parser.c:13594
+#: cp/parser.c:13591
 #, fuzzy, gcc-internal-format
 msgid "decl-specifier invalid in condition"
 msgstr "decl-specifier 無效的在中條件"
 
-#: cp/parser.c:13600
+#: cp/parser.c:13597
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D invalid in %q#T"
 msgid "%qD invalid in lambda"
 msgstr "%q+D 無效，在 %q#T 中"
 
-#: cp/parser.c:13693
+#: cp/parser.c:13690
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "類別定義不能被宣告為夥伴"
 
-#: cp/parser.c:13763 cp/parser.c:24064
+#: cp/parser.c:13760 cp/parser.c:24061
 #, fuzzy, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr "模板可能無法是 %<virtual%>"
 
-#: cp/parser.c:13805
+#: cp/parser.c:13802
 #, fuzzy, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr "無效的連繫規格"
 
-#: cp/parser.c:13909
+#: cp/parser.c:13906
 #, fuzzy, gcc-internal-format
 msgid "static_assert without a message only available with -std=c++17 or -std=gnu++17"
 msgstr "內聯命名空間只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:14111
+#: cp/parser.c:14108
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr "類型可能無法被定義在中 %<decltype%> 運算式"
 
-#: cp/parser.c:14264
+#: cp/parser.c:14261
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr "類型可能無法被定義在中 new-type-id"
 
-#: cp/parser.c:14291
+#: cp/parser.c:14288
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "無效的使用的 %<auto%> 在中轉換運算子"
 
-#: cp/parser.c:14295
+#: cp/parser.c:14292
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr "無效的使用的 %<auto%> 在中轉換運算子"
 
-#: cp/parser.c:14379
+#: cp/parser.c:14376
 #, fuzzy, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr "只有建構子需成員初始設定式"
 
-#: cp/parser.c:14406
+#: cp/parser.c:14403
 #, fuzzy, gcc-internal-format
 msgid "cannot expand initializer for member %qD"
 msgstr "無法展開初始設定式用於成員 %<%D%>"
 
-#: cp/parser.c:14418 cp/pt.c:24255
+#: cp/parser.c:14415 cp/pt.c:24333
 #, fuzzy, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "mem-initializer 用於 %qD 追隨建構子 delegation"
 
-#: cp/parser.c:14430 cp/pt.c:24267
+#: cp/parser.c:14427 cp/pt.c:24345
 #, fuzzy, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr "建構子 delegation 追隨 mem-initializer 用於 %qD"
 
-#: cp/parser.c:14482
+#: cp/parser.c:14479
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr "年代錯誤的舊式基礎類別初始值設定"
 
-#: cp/parser.c:14552
+#: cp/parser.c:14549
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr "關鍵字 %<typename%> 不允許用在此上下文中(限定的初始值設定隱含地是一個類型)"
 
-#: cp/parser.c:14927
+#: cp/parser.c:14924
 #, fuzzy, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr "缺少空格介於 %<「」%>和字尾識別碼"
 
-#: cp/parser.c:14933
+#: cp/parser.c:14930
 #, fuzzy, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr "預期的字尾識別碼"
 
-#: cp/parser.c:14942
+#: cp/parser.c:14939
 #, fuzzy, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr "預期的清空字串之後 %<operator%> 關鍵字"
 
-#: cp/parser.c:14948
+#: cp/parser.c:14945
 #, fuzzy, gcc-internal-format
 msgid "invalid encoding prefix in literal operator"
 msgstr "無效的運算元在中三進作業"
 
-#: cp/parser.c:14975
+#: cp/parser.c:14972
 #, fuzzy, gcc-internal-format
 msgid "expected operator"
 msgstr "預期的運算子"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:15020
+#: cp/parser.c:15017
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "關鍵字 %<export%> 未實作，將被忽略"
 
-#: cp/parser.c:15190
+#: cp/parser.c:15187
 #, fuzzy, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr "無效的模板 non-type 參數"
 
-#: cp/parser.c:15198
+#: cp/parser.c:15195
 #, fuzzy, gcc-internal-format
 msgid "cv-qualified type parameter"
 msgstr "無效的模板 non-type 參數"
 
-#: cp/parser.c:15283
+#: cp/parser.c:15280
 #, gcc-internal-format
 msgid "variadic constraint introduced without %<...%>"
 msgstr ""
 
-#: cp/parser.c:15347
+#: cp/parser.c:15344
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "無效的使用的模板模板參數 %qT"
 
-#: cp/parser.c:15582 cp/parser.c:15668 cp/parser.c:21694
+#: cp/parser.c:15579 cp/parser.c:15665 cp/parser.c:21691
 #, fuzzy, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "模板參數包裝 %qD 無法有預設引數"
 
-#: cp/parser.c:15586 cp/parser.c:15672
+#: cp/parser.c:15583 cp/parser.c:15669
 #, fuzzy, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr "模板參數包裝無法有預設引數"
 
-#: cp/parser.c:15738
+#: cp/parser.c:15735
 #, fuzzy, gcc-internal-format
 msgid "expected template-id"
 msgstr "預期 template-id"
 
-#: cp/parser.c:15798
+#: cp/parser.c:15795
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "不能以 %<<::%> 開始一個範本引數清單"
 
-#: cp/parser.c:15802
+#: cp/parser.c:15799
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr "%<<:%> 是 %<[%> 的另一種拼法。請在 %<<%> 和 %<::%> 間加上空格"
 
-#: cp/parser.c:15806
+#: cp/parser.c:15803
 #, fuzzy, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr "(如果您使用 %<-fpermissive%> G++將接受您的編碼)"
 
-#: cp/parser.c:15924
+#: cp/parser.c:15921
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "範本引數表語法錯誤"
 
 #. The name does not name a template.
-#: cp/parser.c:15992 cp/parser.c:16122 cp/parser.c:16337
+#: cp/parser.c:15989 cp/parser.c:16119 cp/parser.c:16334
 #, fuzzy, gcc-internal-format
 msgid "expected template-name"
 msgstr "預期 template-name"
 
 #. Explain what went wrong.
-#: cp/parser.c:16038
+#: cp/parser.c:16035
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr "非範本 %qD 做為範本"
 
-#: cp/parser.c:16040
+#: cp/parser.c:16037
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr "使用 %<%T::template %D%> 來表示這是一個範本"
 
-#: cp/parser.c:16189
+#: cp/parser.c:16186
 #, fuzzy, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr "預期的參數包裝之前 %<...%>"
 
-#: cp/parser.c:16298 cp/parser.c:16316 cp/parser.c:16483
+#: cp/parser.c:16295 cp/parser.c:16313 cp/parser.c:16480
 #, fuzzy, gcc-internal-format
 msgid "expected template-argument"
 msgstr "預期 template-argument"
 
-#: cp/parser.c:16458
+#: cp/parser.c:16455
 #, fuzzy, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr "無效的 non-type 模板引數"
 
-#: cp/parser.c:16585
+#: cp/parser.c:16582
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "明確的實體化不應該使用 %<inline%> 說明符"
 
-#: cp/parser.c:16589
+#: cp/parser.c:16586
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "明確的實體化不應該使用 %<constexpr%> 說明符"
 
-#: cp/parser.c:16648
+#: cp/parser.c:16645
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr "特例化範本有 C 連結"
 
-#: cp/parser.c:16869
+#: cp/parser.c:16866
 #, fuzzy, gcc-internal-format
 msgid "expected type specifier"
 msgstr "預期的型態說明符"
 
-#: cp/parser.c:17053
+#: cp/parser.c:17050
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "缺席和刪除的函式只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:17059
+#: cp/parser.c:17056
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "缺席和刪除的函式只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:17064
+#: cp/parser.c:17061
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -fconcepts"
 msgstr ""
 
-#: cp/parser.c:17209
+#: cp/parser.c:17206
 #, fuzzy, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "預期 template-id 用於型態"
 
-#: cp/parser.c:17278
+#: cp/parser.c:17275
 #, fuzzy, gcc-internal-format
 msgid "expected type-name"
 msgstr "預期 type-name"
 
-#: cp/parser.c:17631
+#: cp/parser.c:17628
 #, fuzzy, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr "elaborated-type-specifier 用於範圍的 enum 必須不使用 %<%D%>關鍵字"
 
-#: cp/parser.c:17854
+#: cp/parser.c:17851
 #, fuzzy, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "宣告 %qD 不宣告任何事"
 
-#: cp/parser.c:17942
+#: cp/parser.c:17939
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "屬性忽略的於 uninstantiated 型態"
 
-#: cp/parser.c:17946
+#: cp/parser.c:17943
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "屬性忽略的於模板具現化"
 
-#: cp/parser.c:17951
+#: cp/parser.c:17948
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr "屬性忽略的於 elaborated-type-specifier 該並非前置宣告"
 
-#: cp/parser.c:18085
+#: cp/parser.c:18082
 #, fuzzy, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "%qD 是列舉類型模板"
 
-#: cp/parser.c:18096
+#: cp/parser.c:18093
 #, fuzzy, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr "%qD 沒有積分或列舉類型型態"
 
-#: cp/parser.c:18111
+#: cp/parser.c:18108
 #, fuzzy, gcc-internal-format
 msgid "unnamed scoped enum is not allowed"
 msgstr "%<namespace%> 定義未被允許在此"
 
-#: cp/parser.c:18166
+#: cp/parser.c:18163
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "預期 %<;%>或 %<{%>"
 
-#: cp/parser.c:18215
+#: cp/parser.c:18212
 #, fuzzy, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "無法加入列舉值清單到模板具現化"
 
-#: cp/parser.c:18229
+#: cp/parser.c:18226
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration does not name a class or function"
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "夥伴宣告沒有指定類別或函式名"
 
-#: cp/parser.c:18241 cp/parser.c:23070
+#: cp/parser.c:18238 cp/parser.c:23067
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "宣告的 %qD 在中命名空間 %qD 該項不封閉 %qD"
 
-#: cp/parser.c:18246 cp/parser.c:23075
+#: cp/parser.c:18243 cp/parser.c:23072
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "%qD 宣告出現在 %qD 中，而後者並不包含 %qD"
 
-#: cp/parser.c:18258 cp/parser.c:23089
+#: cp/parser.c:18255 cp/parser.c:23086
 #, fuzzy, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr "額外合格不允許"
 
-#: cp/parser.c:18282
+#: cp/parser.c:18279
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "%q#T 多次定義"
 
-#: cp/parser.c:18295
+#: cp/parser.c:18292
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO C++禁止遞增 enum"
 
-#: cp/parser.c:18315
+#: cp/parser.c:18312
 #, fuzzy, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr "opaque-enum-specifier 而無需名稱"
 
-#: cp/parser.c:18318
+#: cp/parser.c:18315
 #, fuzzy, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr "opaque-enum-specifier 必須使用簡單的識別碼"
 
-#: cp/parser.c:18497
+#: cp/parser.c:18494
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD 不是一個命名空間"
 
-#: cp/parser.c:18503
+#: cp/parser.c:18500
 #, fuzzy, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "預期 namespace-name"
 
-#: cp/parser.c:18570
+#: cp/parser.c:18567
 #, fuzzy, gcc-internal-format
 msgid "nested namespace definitions only available with -std=c++17 or -std=gnu++17"
 msgstr "內聯命名空間只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:18578
+#: cp/parser.c:18575
 #, fuzzy, gcc-internal-format
 msgid "nested namespace name required"
 msgstr "預期 namespace-name"
 
-#: cp/parser.c:18583
+#: cp/parser.c:18580
 #, gcc-internal-format
 msgid "namespace name required"
 msgstr ""
 
-#: cp/parser.c:18587
+#: cp/parser.c:18584
 #, fuzzy, gcc-internal-format
 #| msgid "Enumerator cannot have attributes %C"
 msgid "a nested namespace definition cannot have attributes"
 msgstr "列舉量不能有屬性 %C"
 
-#: cp/parser.c:18590
+#: cp/parser.c:18587
 #, fuzzy, gcc-internal-format
 #| msgid "Warn when an inlined function cannot be inlined"
 msgid "a nested namespace definition cannot be inline"
 msgstr "當內聯函式無法被內聯時給出警告"
 
-#: cp/parser.c:18597
+#: cp/parser.c:18594
 #, fuzzy, gcc-internal-format
 #| msgid "use of namespace %qD as expression"
 msgid "namespace %qD entered"
 msgstr "命名空間 %qD 做為運算式"
 
-#: cp/parser.c:18652
+#: cp/parser.c:18649
 #, fuzzy, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "%<namespace%> 定義未被允許在此"
 
-#: cp/parser.c:18803
+#: cp/parser.c:18800
 #, fuzzy, gcc-internal-format
 msgid "pack expansion in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr "lambda 運算式只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:18818
+#: cp/parser.c:18815
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "範本識別碼不允許出現在 using 宣告中"
 
-#: cp/parser.c:18865
+#: cp/parser.c:18862
 #, fuzzy, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr "缺席和刪除的函式只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:18875
+#: cp/parser.c:18872
 #, fuzzy, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr "存取宣告被不宜用在中 favour 的 using-declarations；建議：加入 %<using%> 關鍵字"
 
-#: cp/parser.c:18940
+#: cp/parser.c:18937
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "類型可能無法被定義在中別名模板宣告"
 
-#: cp/parser.c:19106
+#: cp/parser.c:19103
 #, fuzzy, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr "複合陳述在中 constexpr 函式"
 
-#: cp/parser.c:19493
+#: cp/parser.c:19490
 #, fuzzy, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "function-definition 未被允許在此"
 
-#: cp/parser.c:19504
+#: cp/parser.c:19501
 #, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr "函式定義中不允許出現 asm 指定"
 
-#: cp/parser.c:19508
+#: cp/parser.c:19505
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "函式定義中不允許有屬性"
 
-#: cp/parser.c:19559
+#: cp/parser.c:19556
 #, fuzzy, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr "預期的建構子、解構式，或類型轉換"
 
 #. Anything else is an error.
-#: cp/parser.c:19598 cp/parser.c:21906
+#: cp/parser.c:19595 cp/parser.c:21903
 #, fuzzy, gcc-internal-format
 msgid "expected initializer"
 msgstr "預期的初始設定式"
 
-#: cp/parser.c:19679
+#: cp/parser.c:19676
 #, fuzzy, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "初始設定式提供的用於函式"
 
-#: cp/parser.c:19713
+#: cp/parser.c:19710
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "括起的初始值設定後出現的屬性被忽略"
 
-#: cp/parser.c:19727
+#: cp/parser.c:19724
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared as inline"
 msgid "non-function %qD declared as implicit template"
 msgstr "函式 %q+D 重宣告為內聯的"
 
-#: cp/parser.c:20169
+#: cp/parser.c:20166
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "陣列邊界不是一個整數常數"
 
-#: cp/parser.c:20295
+#: cp/parser.c:20292
 #, fuzzy, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr "無法定義成員的附屬 typedef %qT"
 
-#: cp/parser.c:20299
+#: cp/parser.c:20296
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "%<%T::%E%>並非型態"
@@ -49319,17 +49362,17 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:20328
+#: cp/parser.c:20325
 #, fuzzy, gcc-internal-format
 msgid "invalid declarator"
 msgstr "無效的宣告子"
 
-#: cp/parser.c:20336
+#: cp/parser.c:20333
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "將建構式做為範本用法無效"
 
-#: cp/parser.c:20338
+#: cp/parser.c:20335
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr "使用 %<%T::%D%> 而不是 %<%T::%D%> 來以限定名指定建構式"
@@ -49336,388 +49379,388 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:20410
+#: cp/parser.c:20407
 #, fuzzy, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr "%q+D 在宣告前使用"
 
-#: cp/parser.c:20435
+#: cp/parser.c:20432
 #, fuzzy, gcc-internal-format
 msgid "expected declarator"
 msgstr "預期的宣告子"
 
-#: cp/parser.c:20554
+#: cp/parser.c:20551
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD 是一個命名空間"
 
-#: cp/parser.c:20556
+#: cp/parser.c:20553
 #, fuzzy, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "無法表單成員指標的 non-class %q#T"
 
-#: cp/parser.c:20577
+#: cp/parser.c:20574
 #, fuzzy, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "預期 ptr-operator"
 
-#: cp/parser.c:20638
+#: cp/parser.c:20635
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "重複的 cv 限定"
 
-#: cp/parser.c:20692
+#: cp/parser.c:20689
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate cv-qualifier"
 msgid "multiple ref-qualifiers"
 msgstr "重複的 cv 限定"
 
-#: cp/parser.c:20729
+#: cp/parser.c:20726
 #, gcc-internal-format
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr ""
 
-#: cp/parser.c:20787
+#: cp/parser.c:20784
 #, fuzzy, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "重製 virt-specifier"
 
-#: cp/parser.c:21025
+#: cp/parser.c:21022
 #, fuzzy, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr "在中模板引數用於型態 %qT "
 
-#: cp/parser.c:21031 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2090
+#: cp/parser.c:21028 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2093
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr "無效的使用的 %qT"
 
-#: cp/parser.c:21052
+#: cp/parser.c:21049
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "類型可能無法被定義在中模板引數"
 
-#: cp/parser.c:21057
+#: cp/parser.c:21054
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "無效的 non-type 模板引數"
 
-#: cp/parser.c:21145
+#: cp/parser.c:21142
 #, fuzzy, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "預期 type-specifier"
 
-#: cp/parser.c:21429
+#: cp/parser.c:21426
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "預期 %<,%>或 %<...%>"
 
-#: cp/parser.c:21504
+#: cp/parser.c:21501
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr "類型可能無法被定義在中參數類型"
 
-#: cp/parser.c:21678
+#: cp/parser.c:21675
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "預設參數只允許出現在函式參數中"
 
-#: cp/parser.c:21696
+#: cp/parser.c:21693
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "參數包裝 %qD 無法有預設引數"
 
-#: cp/parser.c:21702
+#: cp/parser.c:21699
 #, fuzzy, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr "模板參數包裝無法有預設引數"
 
-#: cp/parser.c:21704
+#: cp/parser.c:21701
 #, fuzzy, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr "參數包裝無法有預設引數"
 
-#: cp/parser.c:22131
+#: cp/parser.c:22128
 #, fuzzy, gcc-internal-format
 msgid "C++ designated initializers only available with -std=c++2a or -std=gnu++2a"
 msgstr "進階初始設定式只列出可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:22151
+#: cp/parser.c:22148
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr "ISO C++ 不允許指定元素初始值設定"
 
-#: cp/parser.c:22189
+#: cp/parser.c:22186
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C++不允許 C99 指定的初始設定式"
 
-#: cp/parser.c:22203
+#: cp/parser.c:22200
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr ""
 
-#: cp/parser.c:22228
+#: cp/parser.c:22225
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "%<...%> not allowed in designated initializer list"
 msgstr "ISO C++ 不允許指定元素初始值設定"
 
-#: cp/parser.c:22266
+#: cp/parser.c:22263
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr ""
 
-#: cp/parser.c:22322 cp/parser.c:22448
+#: cp/parser.c:22319 cp/parser.c:22445
 #, fuzzy, gcc-internal-format
 msgid "expected class-name"
 msgstr "預期 class-name"
 
-#: cp/parser.c:22650
+#: cp/parser.c:22647
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "預期 %<;%>之後類別定義"
 
-#: cp/parser.c:22653
+#: cp/parser.c:22650
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "預期 %<;%>之後結構定義"
 
-#: cp/parser.c:22656
+#: cp/parser.c:22653
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "預期 %<;%>之後聯合定義"
 
-#: cp/parser.c:23012
+#: cp/parser.c:23009
 #, fuzzy, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "預期 %<{%>或 %<:%>"
 
-#: cp/parser.c:23023
+#: cp/parser.c:23020
 #, fuzzy, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "無法指定 %<override%> 用於類別"
 
-#: cp/parser.c:23031
+#: cp/parser.c:23028
 #, fuzzy, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr "全域合格的類別名稱無效"
 
-#: cp/parser.c:23038
+#: cp/parser.c:23035
 #, fuzzy, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "限定名稱不名稱類別"
 
-#: cp/parser.c:23050
+#: cp/parser.c:23047
 #, fuzzy, gcc-internal-format
 #| msgid "keyword %<typename%> not allowed outside of templates"
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr "關鍵字 %<typename%> 不能在範本以外使用"
 
-#: cp/parser.c:23056
+#: cp/parser.c:23053
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "%qD 的宣告中類別名無效"
 
-#: cp/parser.c:23114
+#: cp/parser.c:23111
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "明確特例化前必須有 %<template <>%>"
 
-#: cp/parser.c:23146
+#: cp/parser.c:23143
 #, fuzzy, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "函式模板 %qD redeclared 做為類別模板"
 
-#: cp/parser.c:23182
+#: cp/parser.c:23179
 #, fuzzy, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr "無法解析 typename 型態"
 
-#: cp/parser.c:23241
+#: cp/parser.c:23238
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+#T"
 msgid "previous definition of %q#T"
 msgstr "%q+#T 的上一個定義"
 
-#: cp/parser.c:23331 cp/parser.c:28499
+#: cp/parser.c:23328 cp/parser.c:28496
 #, fuzzy, gcc-internal-format
 msgid "expected class-key"
 msgstr "預期 class-key"
 
-#: cp/parser.c:23355
+#: cp/parser.c:23352
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:23359
+#: cp/parser.c:23356
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "預期 %<class%>，%<typename%>，或 %<template%>"
 
-#: cp/parser.c:23605
+#: cp/parser.c:23602
 #, fuzzy, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr "在中 C++03 class-key 必須被使用時宣告朋友"
 
-#: cp/parser.c:23623
+#: cp/parser.c:23620
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "夥伴宣告沒有指定類別或函式名"
 
-#: cp/parser.c:23641
+#: cp/parser.c:23638
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:23738
+#: cp/parser.c:23735
 #, fuzzy, gcc-internal-format
 msgid "default member initializers for bit-fields only available with -std=c++2a or -std=gnu++2a"
 msgstr "進階初始設定式只列出可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:23745
+#: cp/parser.c:23742
 #, fuzzy, gcc-internal-format
 msgid "default member initializer for unnamed bit-field"
 msgstr "對齊指定的用於未命名 bit-field"
 
-#: cp/parser.c:23758
+#: cp/parser.c:23755
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr ""
 
-#: cp/parser.c:23903
+#: cp/parser.c:23900
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr "函式定義上有 pure 指定"
 
-#: cp/parser.c:23923
+#: cp/parser.c:23920
 #, fuzzy, gcc-internal-format
 msgid "extra %<;%> after in-class function definition"
 msgstr "預期 %<;%>之後類別定義"
 
-#: cp/parser.c:23970
+#: cp/parser.c:23967
 #, fuzzy, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr "預期 %<;%>於結束的成員宣告"
 
-#: cp/parser.c:23984
+#: cp/parser.c:23981
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "預期 %<;%>於結束的成員宣告"
 
-#: cp/parser.c:24058
+#: cp/parser.c:24055
 #, fuzzy, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr "無效的 pure 說明符 (只有 %<=0%>被允許)"
 
-#: cp/parser.c:24093
+#: cp/parser.c:24090
 #, fuzzy, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "brace-enclosed 初始設定式未被允許在此"
 
-#: cp/parser.c:24223
+#: cp/parser.c:24220
 #, fuzzy, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr "%<virtual%> 指定的一次以上在中 base-specified"
 
-#: cp/parser.c:24243
+#: cp/parser.c:24240
 #, fuzzy, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr "超過一個存取說明符在中 base-specified"
 
-#: cp/parser.c:24267
+#: cp/parser.c:24264
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "關鍵字 %<typename%> 不能在範本以外使用"
 
-#: cp/parser.c:24270
+#: cp/parser.c:24267
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "關鍵字 %<typename%> 不允許用在此上下文中(基礎類別隱含地是一個類型)"
 
-#: cp/parser.c:24364 cp/parser.c:24442
+#: cp/parser.c:24361 cp/parser.c:24439
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "類型可能無法被定義在中 exception-specification"
 
-#: cp/parser.c:24450
+#: cp/parser.c:24447
 #, fuzzy, gcc-internal-format
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "由於不同的異常規格"
 
-#: cp/parser.c:24456
+#: cp/parser.c:24453
 #, fuzzy, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr "動態異常規格被不宜用在中 C++0x; 使用 %<noexcept%> 做為替代"
 
-#: cp/parser.c:24500
+#: cp/parser.c:24497
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "無效的使用的 %<auto%> 在中轉換運算子"
 
-#: cp/parser.c:24539
+#: cp/parser.c:24536
 #, fuzzy, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr "複合陳述在中 constexpr 函式"
 
-#: cp/parser.c:24650
+#: cp/parser.c:24647
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr "類型可能無法被定義在中 exception-declarations"
 
-#: cp/parser.c:25203
+#: cp/parser.c:25200
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr "%s 屬性與 %s 屬性在 %L 處衝突"
 
-#: cp/parser.c:25217
+#: cp/parser.c:25214
 #, fuzzy, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr "需要識別碼或 %<(%>"
 
-#: cp/parser.c:25301
+#: cp/parser.c:25298
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:25305
+#: cp/parser.c:25302
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:25342
+#: cp/parser.c:25339
 #, fuzzy, gcc-internal-format
 msgid "expected attribute before %<...%>"
 msgstr "預期的參數包裝之前 %<...%>"
 
-#: cp/parser.c:25403
+#: cp/parser.c:25400
 #, fuzzy, gcc-internal-format
 msgid "attribute using prefix only available with -std=c++17 or -std=gnu++17"
 msgstr "C++0x 自動只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:25721
+#: cp/parser.c:25718
 #, fuzzy, gcc-internal-format
 msgid "%<requires%> only available with -fconcepts"
 msgstr "%<@required%>不是可用在中 Objective-C 1.0"
 
-#: cp/parser.c:25753
+#: cp/parser.c:25750
 #, fuzzy, gcc-internal-format
 msgid "a requires expression cannot appear outside a template"
 msgstr "異動作業運算式無法出現在中 constant-expression"
 
-#: cp/parser.c:26467
+#: cp/parser.c:26464
 #, fuzzy, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr "專用化成員 %<%T::%E%>需求 %<模板<>%>語法specializing member %<%T::%E%> requires %<template<>%> syntax專用化成員 %<%T::%E%>需求 %<模板<>%>語法"
 
-#: cp/parser.c:26472
+#: cp/parser.c:26469
 #, fuzzy, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "無效的宣告的 %<%T::%E%>"
 
-#: cp/parser.c:26476
+#: cp/parser.c:26473
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "範本參數表太少"
@@ -49726,412 +49769,412 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:26483
+#: cp/parser.c:26480
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "範本參數表太多"
 
-#: cp/parser.c:26832
+#: cp/parser.c:26829
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "具名回傳值不再被支援"
 
-#: cp/parser.c:26991
+#: cp/parser.c:26988
 #, fuzzy, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr "實字運算子模板 %qD 有無效的參數清單。 預期 non-type 模板引數包裝 <char...>"
 
-#: cp/parser.c:26996
+#: cp/parser.c:26993
 #, fuzzy, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr "實字運算子模板 %qD 有無效的參數清單。 預期 non-type 模板引數包裝 <char...>"
 
-#: cp/parser.c:27066
+#: cp/parser.c:27063
 #, fuzzy, gcc-internal-format
 msgid "empty introduction-list"
 msgstr "啟用 multiply 指令"
 
-#: cp/parser.c:27090
+#: cp/parser.c:27087
 #, fuzzy, gcc-internal-format
 #| msgid "no matching template for %qD found"
 msgid "no matching concept for template-introduction"
 msgstr "沒有找到與 %qD 匹配的範本"
 
-#: cp/parser.c:27112
+#: cp/parser.c:27109
 #, fuzzy, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "無效的宣告的成員模板在中區域類別"
 
-#: cp/parser.c:27121
+#: cp/parser.c:27118
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "C 連結的範本"
 
-#: cp/parser.c:27141
+#: cp/parser.c:27138
 #, fuzzy, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "無效的明確的特殊化"
 
-#: cp/parser.c:27245
+#: cp/parser.c:27242
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "模板宣告的 %<typedef%>"
 
-#: cp/parser.c:27296
+#: cp/parser.c:27293
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "a class template declaration must not declare anything else"
 msgstr "沒有宣告任何東西"
 
-#: cp/parser.c:27342
+#: cp/parser.c:27339
 #, fuzzy, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "明確的模板特殊化無法有貯藏類別"
 
-#: cp/parser.c:27650
+#: cp/parser.c:27647
 #, fuzzy, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%<>>%>應該是 %<>>%>在之內巢狀的模板引數清單"
 
-#: cp/parser.c:27663
+#: cp/parser.c:27660
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "可疑的 %<>>%>，使用 %<>%> 來結束範本引數清單"
 
-#: cp/parser.c:27958
+#: cp/parser.c:27955
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:28118
+#: cp/parser.c:28115
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "無效的使用的 %qD 在中連繫規格"
 
-#: cp/parser.c:28133
+#: cp/parser.c:28130
 #, fuzzy, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%>之前 %qD"
 
-#: cp/parser.c:28267
+#: cp/parser.c:28264
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++1998 不支援 %<long long%>"
 
-#: cp/parser.c:28275
+#: cp/parser.c:28272
 #, fuzzy, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "宣告中同時使用了 %<short%> 和 %<char%>"
 
-#: cp/parser.c:28280
+#: cp/parser.c:28277
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "重複的 %qE"
 
-#: cp/parser.c:28304
+#: cp/parser.c:28301
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "重複的 %qs"
 
-#: cp/parser.c:28356
+#: cp/parser.c:28353
 #, fuzzy, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "預期 %<new%>"
 
-#: cp/parser.c:28359
+#: cp/parser.c:28356
 #, fuzzy, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "預期 %<delete%>"
 
-#: cp/parser.c:28362
+#: cp/parser.c:28359
 #, fuzzy, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "預期 %<return%>"
 
-#: cp/parser.c:28368
+#: cp/parser.c:28365
 #, fuzzy, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "預期 %<extern%>"
 
-#: cp/parser.c:28371
+#: cp/parser.c:28368
 #, fuzzy, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "預期 %<static_assert%>"
 
-#: cp/parser.c:28374
+#: cp/parser.c:28371
 #, fuzzy, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "預期 %<decltype%>"
 
-#: cp/parser.c:28377
+#: cp/parser.c:28374
 #, fuzzy, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "預期 %<operator%>"
 
-#: cp/parser.c:28380
+#: cp/parser.c:28377
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "預期 %<class%>"
 
-#: cp/parser.c:28383
+#: cp/parser.c:28380
 #, fuzzy, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "預期 %<template%>"
 
-#: cp/parser.c:28386
+#: cp/parser.c:28383
 #, fuzzy, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "預期 %<namespace%>"
 
-#: cp/parser.c:28389
+#: cp/parser.c:28386
 #, fuzzy, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "預期 %<using%>"
 
-#: cp/parser.c:28392
+#: cp/parser.c:28389
 #, fuzzy, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "預期 %<asm%>"
 
-#: cp/parser.c:28395
+#: cp/parser.c:28392
 #, fuzzy, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "預期 %<try%>"
 
-#: cp/parser.c:28398
+#: cp/parser.c:28395
 #, fuzzy, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "預期 %<catch%>"
 
-#: cp/parser.c:28401
+#: cp/parser.c:28398
 #, fuzzy, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "預期 %<throw%>"
 
-#: cp/parser.c:28404
+#: cp/parser.c:28401
 #, fuzzy, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "預期 %<__label__%>"
 
-#: cp/parser.c:28407
+#: cp/parser.c:28404
 #, fuzzy, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "預期 %<@try%>"
 
-#: cp/parser.c:28410
+#: cp/parser.c:28407
 #, fuzzy, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "預期 %<@synchronized%>"
 
-#: cp/parser.c:28413
+#: cp/parser.c:28410
 #, fuzzy, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "預期 %<@throw%>"
 
-#: cp/parser.c:28416
+#: cp/parser.c:28413
 #, fuzzy, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "預期 %<__transaction_atomic%>"
 
-#: cp/parser.c:28419
+#: cp/parser.c:28416
 #, fuzzy, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "預期 %<__transaction_relaxed%>"
 
-#: cp/parser.c:28451
+#: cp/parser.c:28448
 #, fuzzy, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "預期 %<::%>"
 
-#: cp/parser.c:28463
+#: cp/parser.c:28460
 #, fuzzy, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "預期 %<...%>"
 
-#: cp/parser.c:28466
+#: cp/parser.c:28463
 #, fuzzy, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "預期 %<*%>"
 
-#: cp/parser.c:28469
+#: cp/parser.c:28466
 #, fuzzy, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "預期 %<~%>"
 
-#: cp/parser.c:28475
+#: cp/parser.c:28472
 #, fuzzy, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "預期 %<:%>或 %<::%>"
 
-#: cp/parser.c:28502
+#: cp/parser.c:28499
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "預期 %<class%>，%<typename%>，或 %<template%>"
 
-#: cp/parser.c:28772
+#: cp/parser.c:28769
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "使用了 %qs 標記，在命名 %q#T 時"
 
-#: cp/parser.c:28777
+#: cp/parser.c:28774
 #, fuzzy, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "%q#T 是在之前宣告的在此"
 
-#: cp/parser.c:28798
+#: cp/parser.c:28795
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD 重宣告時有不同的可存取性"
 
-#: cp/parser.c:28819
+#: cp/parser.c:28816
 #, fuzzy, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "做為消歧義的 %<template%> 只能用於範本內"
 
-#: cp/parser.c:29062
+#: cp/parser.c:29059
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "檔案在預設參數處結束"
 
-#: cp/parser.c:29303 cp/parser.c:30620 cp/parser.c:30808
+#: cp/parser.c:29300 cp/parser.c:30617 cp/parser.c:30805
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "位置錯誤的 %<@%D%> Objective-C++ 建構"
 
-#: cp/parser.c:29372
+#: cp/parser.c:29369
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr "objective-c++ 訊息引數被預期"
 
-#: cp/parser.c:29442
+#: cp/parser.c:29439
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr "objective-c++ 訊息引數被預期"
 
-#: cp/parser.c:29473
+#: cp/parser.c:29470
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "%<@encode%> 必須指定一個類型做為引數"
 
-#: cp/parser.c:29883
+#: cp/parser.c:29880
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "無效的 Objective-C++ 選擇子名"
 
-#: cp/parser.c:29958 cp/parser.c:29976
+#: cp/parser.c:29955 cp/parser.c:29973
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr "objective-c++ 方法宣告被預期"
 
-#: cp/parser.c:29970 cp/parser.c:30035
+#: cp/parser.c:29967 cp/parser.c:30032
 #, fuzzy, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "方法屬性必須被指定的於結束"
 
-#: cp/parser.c:30078
+#: cp/parser.c:30075
 #, fuzzy, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr "零星的 %qs 介於 Objective-C++ 方法"
 
-#: cp/parser.c:30284 cp/parser.c:30291 cp/parser.c:30298
+#: cp/parser.c:30281 cp/parser.c:30288 cp/parser.c:30295
 #, fuzzy, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "無效的型態舉例來說變數"
 
-#: cp/parser.c:30413
+#: cp/parser.c:30410
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "%<@protocol%> 需要識別碼"
 
-#: cp/parser.c:30585
+#: cp/parser.c:30582
 #, fuzzy, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr "屬性可能無法被指定的之前 %<@%D%>Objective-C++ 關鍵字"
 
-#: cp/parser.c:30592
+#: cp/parser.c:30589
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "前綴屬性被忽略之前 %<@%D%>"
 
-#: cp/parser.c:30867 cp/parser.c:30874 cp/parser.c:30881
+#: cp/parser.c:30864 cp/parser.c:30871 cp/parser.c:30878
 #, fuzzy, gcc-internal-format
 msgid "invalid type for property"
 msgstr "無效的型態用於內容"
 
-#: cp/parser.c:32011
+#: cp/parser.c:32008
 #, fuzzy, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/parser.c:32724
+#: cp/parser.c:32721
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid reduction-identifier"
 msgstr "無效的初始值設定"
 
-#: cp/parser.c:34911
+#: cp/parser.c:34908
 #, fuzzy, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr "parenthesized 初始化未被允許在中 OpenMP %<for%> 迴圈"
 
-#: cp/parser.c:35231 cp/pt.c:16392
+#: cp/parser.c:35228 cp/pt.c:16414
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "迭代變數 %qD 不應為消除"
 
-#: cp/parser.c:35316
+#: cp/parser.c:35313
 #, fuzzy, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr "不足做迴圈用於崩潰 !$OMP 做於 %L"
 
-#: cp/parser.c:37521
+#: cp/parser.c:37518
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer clause"
 msgstr "無效的初始值設定"
 
-#: cp/parser.c:37549
+#: cp/parser.c:37546
 #, fuzzy, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "預期 id-expression"
 
-#: cp/parser.c:37561
+#: cp/parser.c:37558
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:37662
+#: cp/parser.c:37659
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in declare reduction type list"
 msgstr "不能在回傳類型中定義新類型"
 
-#: cp/parser.c:37682 cp/semantics.c:5405
+#: cp/parser.c:37679 cp/semantics.c:5408
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37687 cp/semantics.c:5414
+#: cp/parser.c:37684 cp/semantics.c:5417
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37690 cp/pt.c:12944 cp/semantics.c:5420
+#: cp/parser.c:37687 cp/pt.c:12966 cp/semantics.c:5423
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37693 cp/semantics.c:5426
+#: cp/parser.c:37690 cp/semantics.c:5429
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:38047
+#: cp/parser.c:38044
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:38057
+#: cp/parser.c:38054
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qD does not refer to a namespace scope function"
@@ -50138,47 +50181,47 @@
 msgstr "%qD 不是一個成員範本函式"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:38392
+#: cp/parser.c:38389
 #, gcc-internal-format
 msgid "atomic_cancel"
 msgstr ""
 
-#: cp/parser.c:38435 cp/semantics.c:8575
+#: cp/parser.c:38432 cp/semantics.c:8578
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr "%<__transaction_relaxed%>而無需 transactional 記憶體支援已啟用"
 
-#: cp/parser.c:38437 cp/semantics.c:8577
+#: cp/parser.c:38434 cp/semantics.c:8580
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr "%<__transaction_atomic%>而無需 transactional 記憶體支援已啟用"
 
-#: cp/parser.c:38631
+#: cp/parser.c:38628
 #, fuzzy, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "垃圾於結束的 %<# pragma GCC pchpreprocess%(_P)>"
 
-#: cp/parser.c:38927
+#: cp/parser.c:38924
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "# pragma GCC 最佳化未被允許內部函式"
 
-#: cp/parser.c:38959
+#: cp/parser.c:38956
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr "# pragma GCC 選項未被允許內部函式"
 
-#: cp/parser.c:39039
+#: cp/parser.c:39036
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "模組間最佳化淍未為 C++ 實作"
 
-#: cp/parser.c:39295
+#: cp/parser.c:39292
 #, fuzzy, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr "模板可能無法是 %<virtual%>"
 
-#: cp/parser.c:39351
+#: cp/parser.c:39348
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
@@ -50266,7 +50309,7 @@
 msgid "specialization of %qD after instantiation"
 msgstr "%qD 的特例化在實體化之後"
 
-#: cp/pt.c:1954 cp/semantics.c:5274
+#: cp/pt.c:1954 cp/semantics.c:5277
 #, fuzzy, gcc-internal-format
 msgid "%s %#qD"
 msgstr "%s %+#D"
@@ -50440,130 +50483,130 @@
 msgid "argument to __integer_pack must be between 0 and %d"
 msgstr "%L 處 ACOS 的參數必須在 -1 和 1 之間"
 
-#: cp/pt.c:3942
+#: cp/pt.c:3955
 #, fuzzy, gcc-internal-format
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr "基底初始設定式擴展 %<%T%>不含任何參數包裝"
 
-#: cp/pt.c:4010
+#: cp/pt.c:4023
 #, fuzzy, gcc-internal-format
 msgid "expansion pattern %qT contains no argument packs"
 msgstr "擴展胚騰 %<%T%>不含任何引數包裝"
 
-#: cp/pt.c:4012
+#: cp/pt.c:4025
 #, fuzzy, gcc-internal-format
 msgid "expansion pattern %qE contains no argument packs"
 msgstr "擴展胚騰 %<%E%>不含任何引數包裝"
 
-#: cp/pt.c:4063
+#: cp/pt.c:4077
 #, fuzzy, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr "參數包裝無法展開的與 %<...%>："
 
-#: cp/pt.c:4080 cp/pt.c:4835
+#: cp/pt.c:4094 cp/pt.c:4849
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
 
-#: cp/pt.c:4082
+#: cp/pt.c:4096
 #, fuzzy, gcc-internal-format
 msgid "        <anonymous>"
 msgstr "        <anonymous>"
 
-#: cp/pt.c:4208
+#: cp/pt.c:4222
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr "%q+D 的宣告隱藏了一個參數"
 
-#: cp/pt.c:4211
+#: cp/pt.c:4225
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of %q+#D shadows template parameter"
 msgstr "%q+D 的宣告隱藏了一個參數"
 
-#: cp/pt.c:4213
+#: cp/pt.c:4227
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter type %qT declared %<friend%>"
 msgid "template parameter %qD declared here"
 msgstr "範本參數類型 %qT 宣告為 %<friend%>"
 
-#: cp/pt.c:4771
+#: cp/pt.c:4785
 #, fuzzy, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr "局部特化的別名模板 %qD"
 
-#: cp/pt.c:4830
+#: cp/pt.c:4844
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "template parameters not deducible in partial specialization:"
 msgstr "部分特例化中未用到範本參數："
 
-#: cp/pt.c:4854
+#: cp/pt.c:4868
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr "部分特例化 %qT 並未特例化任何範本參數"
 
-#: cp/pt.c:4858
+#: cp/pt.c:4872
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:4862 cp/pt.c:4873
+#: cp/pt.c:4876 cp/pt.c:4887
 #, fuzzy, gcc-internal-format
 msgid "primary template here"
 msgstr "在之前宣告的在此"
 
-#: cp/pt.c:4870
+#: cp/pt.c:4884
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:4885
+#: cp/pt.c:4899
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "partial specialization %qD is not more specialized than"
 msgstr "部分特例化 %qT 並未特例化任何範本參數"
 
-#: cp/pt.c:4887
+#: cp/pt.c:4901
 #, fuzzy, gcc-internal-format
 msgid "primary template %qD"
 msgstr "在之前宣告的在此"
 
-#: cp/pt.c:4934
+#: cp/pt.c:4948
 #, fuzzy, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr "參數包裝引數 %qE 必須是於結束的模板引數清單"
 
-#: cp/pt.c:4937
+#: cp/pt.c:4951
 #, fuzzy, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr "參數包裝引數 %qT 必須是於結束的模板引數清單"
 
-#: cp/pt.c:4958
+#: cp/pt.c:4972
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr "範本引數 %qE 混雜了範本參數"
 
-#: cp/pt.c:5004
+#: cp/pt.c:5018
 #, fuzzy, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
 msgstr[0] "型態 %qT 的模板引數 %qE 依存於模板參數"
 
-#: cp/pt.c:5066
+#: cp/pt.c:5080
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "%q#T 的類別範本實體化有歧義"
 
-#: cp/pt.c:5070
+#: cp/pt.c:5084
 #, fuzzy, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "局部特化的 %qT 之後實體化的 %qT"
 
-#: cp/pt.c:5247
+#: cp/pt.c:5261
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "%qD 沒有預設參數"
@@ -50571,48 +50614,48 @@
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5269
+#: cp/pt.c:5283
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "參數包裝 %qE 必須是於結束的模板參數清單"
 
-#: cp/pt.c:5305
+#: cp/pt.c:5319
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "預設模板引數可能無法被已用於函式模板朋友重新宣告"
 
-#: cp/pt.c:5308
+#: cp/pt.c:5322
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "預設模板引數可能無法被已用於函式模板朋友宣告"
 
-#: cp/pt.c:5311
+#: cp/pt.c:5325
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in function templates without -std=c++11 or -std=gnu++11"
 msgstr "預設模板引數可能無法被已用於函式模板而無需 -std=c++11 或 -std=gnu++11"
 
-#: cp/pt.c:5314
+#: cp/pt.c:5328
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr "預設模板引數可能無法被已用於局部特化"
 
-#: cp/pt.c:5317 cp/pt.c:5375
+#: cp/pt.c:5331 cp/pt.c:5389
 #, fuzzy, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "預設引數用於模板參數用於類別封閉 %qD"
 
-#: cp/pt.c:5489
+#: cp/pt.c:5503
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD declared void"
 msgid "template %qD declared"
 msgstr "參數 %qD 被宣告為 void"
 
-#: cp/pt.c:5496
+#: cp/pt.c:5510
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "範本類別沒具名字"
 
-#: cp/pt.c:5504
+#: cp/pt.c:5518
 #, fuzzy, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr "non-member 函式 %qD 無法有 cv-qualifier"
@@ -50622,74 +50665,74 @@
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5526
+#: cp/pt.c:5540
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "%qD 範本宣告無效"
 
-#: cp/pt.c:5669
+#: cp/pt.c:5683
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "對非範本 %q#D 的範本定義"
 
-#: cp/pt.c:5712
+#: cp/pt.c:5726
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "需要 %d 級的 %q#D 範本參數，卻給出了 %d 級"
 
-#: cp/pt.c:5726
+#: cp/pt.c:5740
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "得到 %d 個範本參數，為 %q#D"
 
-#: cp/pt.c:5729
+#: cp/pt.c:5743
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "得到 %d 個範本參數，為 %q#T"
 
-#: cp/pt.c:5731
+#: cp/pt.c:5745
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  但實際需要 %d 個"
 
-#: cp/pt.c:5752
+#: cp/pt.c:5766
 #, fuzzy, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "模板引數到 %qD 不匹配原來的模板 %qD"
 
-#: cp/pt.c:5755
+#: cp/pt.c:5769
 #, fuzzy, gcc-internal-format
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "使用模板<>用於明確的特殊化"
 
-#: cp/pt.c:5882
+#: cp/pt.c:5896
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT 不是一個範本類型"
 
-#: cp/pt.c:5895
+#: cp/pt.c:5909
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "%qD 的宣告中沒有 template 限定"
 
-#: cp/pt.c:5906
+#: cp/pt.c:5920
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
 msgstr[0] "redeclared 與 %d 模板參數"
 
-#: cp/pt.c:5910
+#: cp/pt.c:5924
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
 msgstr[0] "前一個宣告 %q+D 使用 %d 模板參數"
 
-#: cp/pt.c:5947
+#: cp/pt.c:5961
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "範本參數 %q+#D"
 
-#: cp/pt.c:5948
+#: cp/pt.c:5962
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "在這裡又被宣告為 %q#D"
@@ -50698,418 +50741,418 @@
 #.
 #. A template-parameter may not be given default arguments
 #. by two different declarations in the same scope.
-#: cp/pt.c:5958
+#: cp/pt.c:5972
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "重定義 %q#D 的預設參數"
 
-#: cp/pt.c:5960
+#: cp/pt.c:5974
 #, fuzzy, gcc-internal-format
 msgid "original definition appeared here"
 msgstr "原來的定義出現的在此"
 
-#: cp/pt.c:5988
+#: cp/pt.c:6002
 #, fuzzy, gcc-internal-format
 msgid "redeclaration %q#D with different constraints"
 msgstr "重新宣告 %qD 不同在中 %<constexpr%>"
 
-#: cp/pt.c:5991
+#: cp/pt.c:6005
 #, fuzzy, gcc-internal-format
 msgid "original declaration appeared here"
 msgstr "原來的定義出現的在此"
 
-#: cp/pt.c:6250 cp/pt.c:6318
+#: cp/pt.c:6264 cp/pt.c:6332
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%qE 並非有效模板引數用於型態 %qT"
 
-#: cp/pt.c:6253
+#: cp/pt.c:6267
 #, fuzzy, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr "它必須是位址的函式與外部連結"
 
-#: cp/pt.c:6256
+#: cp/pt.c:6270
 #, fuzzy, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr "它必須是位址的函式與外部連結"
 
-#: cp/pt.c:6268
+#: cp/pt.c:6282
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%qE 並非有效模板引數用於型態 %qT 因為 %qD 沒有任何鏈結"
 
-#: cp/pt.c:6272
+#: cp/pt.c:6286
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%qE 並非有效模板引數用於型態 %qT 因為 %qD 沒有外部連結"
 
-#: cp/pt.c:6321
+#: cp/pt.c:6335
 #, fuzzy, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "它必須是成員指標的形式 %<&X::Y%>"
 
-#: cp/pt.c:6323
+#: cp/pt.c:6337
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qT"
 msgid "because it is a member of %qT"
 msgstr "%qD 不是 %qT 的成員"
 
-#: cp/pt.c:6383
+#: cp/pt.c:6397
 #, fuzzy, gcc-internal-format
 msgid "  couldn't deduce template parameter %qD"
 msgstr "  無法 deduce 模板參數 %qD"
 
-#: cp/pt.c:6392
+#: cp/pt.c:6406
 #, fuzzy, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr "  類型 %qT 和 %qT 有不相容的 cv-qualifiers"
 
-#: cp/pt.c:6401
+#: cp/pt.c:6415
 #, fuzzy, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr "  不匹配的類型 %qT 和 %qT"
 
-#: cp/pt.c:6410
+#: cp/pt.c:6424
 #, fuzzy, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr "  模板參數 %qD 並非參數包裝，但是引數 %qD 是"
 
-#: cp/pt.c:6421
+#: cp/pt.c:6435
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "  模板引數 %qE 不匹配成員指標常數 %qE"
 
-#: cp/pt.c:6431
+#: cp/pt.c:6445
 #, fuzzy, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr "  %qE 不是 equivalent 到 %qE"
 
-#: cp/pt.c:6440
+#: cp/pt.c:6454
 #, fuzzy, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr "  不一致參數包裝推導與 %qT 和 %qT"
 
-#: cp/pt.c:6452
+#: cp/pt.c:6466
 #, fuzzy, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr "  deduced 衝突類型用於參數 %qT (%qT 和 %qT)"
 
-#: cp/pt.c:6456
+#: cp/pt.c:6470
 #, fuzzy, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr "  deduced 衝突值用於 non-type 參數 %qE (%qE 和 %qE)"
 
-#: cp/pt.c:6467
+#: cp/pt.c:6481
 #, fuzzy, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "  variable-sized 陣列類型 %qT 並非有效模板引數"
 
-#: cp/pt.c:6478
+#: cp/pt.c:6492
 #, fuzzy, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr "  成員函數型式 %qT 並非有效模板引數"
 
-#: cp/pt.c:6490
+#: cp/pt.c:6504
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
 msgstr[0] "  candidate 預期 %d 引數，%d 提供"
 
-#: cp/pt.c:6521
+#: cp/pt.c:6535
 #, fuzzy, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "  無法轉換 %qE (型態 %qT) 輸入 %qT"
 
-#: cp/pt.c:6534
+#: cp/pt.c:6548
 #, fuzzy, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "  %qT 是模稜兩可的基礎類別的 %qT"
 
-#: cp/pt.c:6538
+#: cp/pt.c:6552
 #, fuzzy, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "  %qT 未被衍生自 %qT"
 
-#: cp/pt.c:6549
+#: cp/pt.c:6563
 #, fuzzy, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr "  模板參數的模板模板引數是不一致與其他 deduced 模板引數"
 
-#: cp/pt.c:6559
+#: cp/pt.c:6573
 #, fuzzy, gcc-internal-format
 msgid "  can't deduce a template for %qT from non-template type %qT"
 msgstr "  無法 deduce 模板用於 %qT 從 non-template 型態 %qT"
 
-#: cp/pt.c:6569
+#: cp/pt.c:6583
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
 msgstr "  模板引數 %qE 不匹配 %qD"
 
-#: cp/pt.c:6609
+#: cp/pt.c:6623
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "%qE 不是類型 %qT 的有效範本引數，因為字面字串不能用在此上下文中"
 
-#: cp/pt.c:6758
+#: cp/pt.c:6772
 #, fuzzy, gcc-internal-format
 msgid "in template argument for type %qT"
 msgstr "在中模板引數用於型態 %qT "
 
-#: cp/pt.c:6772
+#: cp/pt.c:6786
 #, fuzzy, gcc-internal-format
 msgid "template argument %qE for type %qT not a constant integer"
 msgstr "在中模板引數用於型態 %qT "
 
-#: cp/pt.c:6833
+#: cp/pt.c:6847
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qD 並非有效模板引數因為 %qD 是變數，不是位址的變數"
 
-#: cp/pt.c:6841
+#: cp/pt.c:6855
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qD 並非有效模板引數因為 %qD 是變數，不是位址的變數"
 
-#: cp/pt.c:6857
+#: cp/pt.c:6871
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "%qE 並非有效模板引數的型態 %qT 因為 %qE 並非變數"
 
-#: cp/pt.c:6864
+#: cp/pt.c:6878
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr "%qE 並非有效模板引數的型態 %qT 因為 %qD 沒有外部連結"
 
-#: cp/pt.c:6873
+#: cp/pt.c:6887
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE 並非有效模板引數的型態 %qT 因為 %qD 沒有任何鏈結"
 
-#: cp/pt.c:6888
+#: cp/pt.c:6902
 #, fuzzy, gcc-internal-format
 msgid "the address of %qD is not a valid template argument"
 msgstr "  variable-sized 陣列類型 %qT 並非有效模板引數"
 
-#: cp/pt.c:6897
+#: cp/pt.c:6911
 #, fuzzy, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr "  variable-sized 陣列類型 %qT 並非有效模板引數"
 
-#: cp/pt.c:6904
+#: cp/pt.c:6918
 #, fuzzy, gcc-internal-format
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "%qE 並非有效模板引數的型態 %qT 因為 %qD 沒有外部連結"
 
-#: cp/pt.c:6933
+#: cp/pt.c:6947
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "%qE 不是類型 %qT 的有效範本引數，因為 cv 限定衝突"
 
-#: cp/pt.c:6941
+#: cp/pt.c:6955
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE 並非有效模板引數用於型態 %qT 因為它不是 lvalue"
 
-#: cp/pt.c:6959
+#: cp/pt.c:6973
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%q#D 並非有效模板引數用於型態 %qT 因為參考變數沒有常數位址"
 
-#: cp/pt.c:6975
+#: cp/pt.c:6989
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an object with linkage"
 msgstr "%qE 並非有效模板引數用於型態 %qT 因為它不是物件與外部連結"
 
-#: cp/pt.c:6986
+#: cp/pt.c:7000
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "%qE is not a valid template argument for type %qT because object %qD does not have linkage"
 msgstr "%qE 不是類型 %qT 的有效範本引數，因為物件 %qD 沒有外部連結"
 
-#: cp/pt.c:7036
+#: cp/pt.c:7050
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE 不是類型 %qT 的有效範本引數，因為它是一個指標"
 
-#: cp/pt.c:7038
+#: cp/pt.c:7052
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "嘗試使用 %qE 代替"
 
-#: cp/pt.c:7092
+#: cp/pt.c:7106
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE 不是類型 %qT 的有效範本引數，因為它的類型是 %qT"
 
-#: cp/pt.c:7654
+#: cp/pt.c:7668
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "忽略屬性於模板引數 %qT"
 
-#: cp/pt.c:7670
+#: cp/pt.c:7684
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr "忽略屬性於模板引數 %qT"
 
-#: cp/pt.c:7805
+#: cp/pt.c:7819
 #, fuzzy, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "injected-class-name %qD 使用的做為模板模板引數"
 
-#: cp/pt.c:7834
+#: cp/pt.c:7848
 #, fuzzy, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "無效的使用的解構式 %qE 做為型態"
 
-#: cp/pt.c:7839
+#: cp/pt.c:7853
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "需要使用某個範本參數的類型成員時，請使用 %<typename %E%>"
 
-#: cp/pt.c:7855 cp/pt.c:7877 cp/pt.c:7931
+#: cp/pt.c:7869 cp/pt.c:7891 cp/pt.c:7945
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "引數 %d 的類型/值不匹配，在 %qD 的範本參數清單中"
 
-#: cp/pt.c:7860
+#: cp/pt.c:7874
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  需要一個 %qT 類型的常數，卻給出了 %qT"
 
-#: cp/pt.c:7865
+#: cp/pt.c:7879
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  需要一個類別範本，卻給出了 %qE"
 
-#: cp/pt.c:7868
+#: cp/pt.c:7882
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  需要一個類型，卻給出了 %qE"
 
-#: cp/pt.c:7882
+#: cp/pt.c:7896
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  需要一個類型，卻給出了 %qT"
 
-#: cp/pt.c:7885
+#: cp/pt.c:7899
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  需要一個類別範本，卻給出了 %qT"
 
-#: cp/pt.c:7935
+#: cp/pt.c:7949
 #, fuzzy, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  預期的模板的型態 %qD，得到 %qT"
 
-#: cp/pt.c:7949
+#: cp/pt.c:7963
 #, fuzzy, gcc-internal-format
 #| msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "引數 %d 的類型/值不匹配，在 %qD 的範本參數清單中"
 
-#: cp/pt.c:7952
+#: cp/pt.c:7966
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a type, got %qE"
 msgid "  expected %qD but got %qD"
 msgstr "  需要一個類型，卻給出了 %qE"
 
-#: cp/pt.c:8012
+#: cp/pt.c:8026
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert template argument %qE to %qT"
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "不能將範本參數從 %qE 轉換到 %qT"
 
-#: cp/pt.c:8149 cp/pt.c:8465
+#: cp/pt.c:8163 cp/pt.c:8479
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "範本參數 %d 無效"
 
-#: cp/pt.c:8164 cp/pt.c:8298
+#: cp/pt.c:8178 cp/pt.c:8312
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "範本參數數目不正確(不應是 %d 個而應是 %d 個)"
 
-#: cp/pt.c:8294
+#: cp/pt.c:8308
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "範本參數數目不正確(不應是 %d 個而應是 %d 個)"
 
-#: cp/pt.c:8303
+#: cp/pt.c:8317
 #, fuzzy, gcc-internal-format
 #| msgid "provided for %q+D"
 msgid "provided for %qD"
 msgstr "提供給 %q+D"
 
-#: cp/pt.c:8328
+#: cp/pt.c:8342
 #, fuzzy, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr "預設引數用於模板參數用於類別封閉 %qD"
 
-#: cp/pt.c:8332
+#: cp/pt.c:8346
 #, fuzzy, gcc-internal-format
 #| msgid "default argument given for parameter %d of %q#D"
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "為參數 %d (屬於 %q#D)指定了預設引數"
 
-#: cp/pt.c:8431
+#: cp/pt.c:8445
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:9054
+#: cp/pt.c:9068
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%q#D 並非函式模板"
 
-#: cp/pt.c:9221
+#: cp/pt.c:9235
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "非範本類型 %qT 做為範本"
 
-#: cp/pt.c:9223
+#: cp/pt.c:9237
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "對於範本宣告 %q+D"
 
-#: cp/pt.c:9346
+#: cp/pt.c:9360
 #, fuzzy, gcc-internal-format
 #| msgid "internal consistency failure"
 msgid "template constraint failure"
 msgstr "內部一致性錯誤"
 
-#: cp/pt.c:9697
+#: cp/pt.c:9718
 #, fuzzy, gcc-internal-format
 #| msgid "use of %qs in template"
 msgid "use of invalid variable template %qE"
 msgstr "在範本中使用 %qs"
 
-#: cp/pt.c:10125
+#: cp/pt.c:10148
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr "模板具現化深度超出最大值的 %d (使用 -ftemplate-depth=到增加最大值) 替代 %qS"
 
-#: cp/pt.c:11202
+#: cp/pt.c:11225
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD in union"
 msgstr "flexible 陣列成員在中聯合"
 
-#: cp/pt.c:11691
+#: cp/pt.c:11713
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:12160
+#: cp/pt.c:12182
 #, fuzzy, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr "不匹配的引數包裝長度當展開 %<%T%>"
 
-#: cp/pt.c:12163
+#: cp/pt.c:12185
 #, fuzzy, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr "不匹配的引數包裝長度當展開 %<%E%>"
 
-#: cp/pt.c:12747
+#: cp/pt.c:12769
 #, fuzzy, gcc-internal-format
 msgid "  when instantiating default argument for call to %qD"
 msgstr "重定義 %q#D 的預設參數"
@@ -51127,280 +51170,280 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:13708
+#: cp/pt.c:13730
 #, fuzzy, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "變數 %qD 有函數型式"
 
-#: cp/pt.c:13881
+#: cp/pt.c:13903
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "無效的參數類型 %qT"
 
-#: cp/pt.c:13883
+#: cp/pt.c:13905
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "在宣告 %q+D 中"
 
-#: cp/pt.c:14001
+#: cp/pt.c:14023
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "函式回傳了一個陣列"
 
-#: cp/pt.c:14003
+#: cp/pt.c:14025
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "函式回傳了一個函式"
 
-#: cp/pt.c:14043
+#: cp/pt.c:14065
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "產生非類別類型 %qT 的成員函式指標"
 
-#: cp/pt.c:14637
+#: cp/pt.c:14659
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "形成對 void 的參照"
 
-#: cp/pt.c:14639
+#: cp/pt.c:14661
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "表單指標到參考類型 %qT"
 
-#: cp/pt.c:14641
+#: cp/pt.c:14663
 #, fuzzy, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "表單參考到參考類型 %qT"
 
-#: cp/pt.c:14654
+#: cp/pt.c:14676
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "無法宣告指標到經資格修飾函數型式 %qT"
 
-#: cp/pt.c:14657
+#: cp/pt.c:14679
 #, fuzzy, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "無法宣告參考到經資格修飾函數型式 %qT"
 
-#: cp/pt.c:14705
+#: cp/pt.c:14727
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "產生非類別類型 %qT 的成員指標"
 
-#: cp/pt.c:14711
+#: cp/pt.c:14733
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "產生參照類型 %qT 的成員指標"
 
-#: cp/pt.c:14717
+#: cp/pt.c:14739
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "建立參照 void 類型的成員指標"
 
-#: cp/pt.c:14783
+#: cp/pt.c:14805
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "產生 %qT 的陣列"
 
-#: cp/pt.c:14816
+#: cp/pt.c:14838
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT 不是類別、結構或聯合類型"
 
-#: cp/pt.c:14853
+#: cp/pt.c:14875
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT 被解析到非列舉類型 %qT"
 
-#: cp/pt.c:14861
+#: cp/pt.c:14883
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr "%qT 被解析到非類別類型 %qT"
 
-#: cp/pt.c:14925
+#: cp/pt.c:14947
 #, fuzzy, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr "ISO C++不允許初始設定式在中 lambda 運算式擷取清單"
 
-#: cp/pt.c:15000
+#: cp/pt.c:15022
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "在範本中使用 %qs"
 
-#: cp/pt.c:15178
+#: cp/pt.c:15200
 #, fuzzy, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "限定型態 %qT 不匹配解構式名稱 ~%qT"
 
-#: cp/pt.c:15193
+#: cp/pt.c:15215
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "依賴名 %qE 被解析為非類型，但實體化卻產生了一個類型"
 
-#: cp/pt.c:15195
+#: cp/pt.c:15217
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "如果您想指定類型，請使用 %<typename %E%>"
 
-#: cp/pt.c:15394
+#: cp/pt.c:15416
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "使用無效欄位 %qD"
 
-#: cp/pt.c:15883 cp/pt.c:17386
+#: cp/pt.c:15905 cp/pt.c:17408
 #, fuzzy, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "無效的使用的包裝擴展運算式"
 
-#: cp/pt.c:15887 cp/pt.c:17390
+#: cp/pt.c:15909 cp/pt.c:17412
 #, fuzzy, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "使用 %<...%>到展開引數包裝"
 
-#: cp/pt.c:18334
+#: cp/pt.c:18371
 #, fuzzy, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr "%qD 未被宣告在中這個範圍，而找不到任何宣告是由 argument-dependent 查找於點的實體化"
 
-#: cp/pt.c:18362
+#: cp/pt.c:18399
 #, fuzzy, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr "宣告在中附屬基底 %qT 找不到由資格不符的查找"
 
-#: cp/pt.c:18367
+#: cp/pt.c:18404
 #, fuzzy, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "使用 %<this->%D%>做為替代"
 
-#: cp/pt.c:18370
+#: cp/pt.c:18407
 #, fuzzy, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "使用 %<%T::%D%>做為替代"
 
-#: cp/pt.c:18375
+#: cp/pt.c:18412
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "%q+D 宣告的在此，稍後在中轉譯單位"
 
-#: cp/pt.c:18712
+#: cp/pt.c:18752
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT 既不是類別也不是命名空間"
 
-#: cp/pt.c:18715
+#: cp/pt.c:18755
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD 既不是類別也不是命名空間"
 
-#: cp/pt.c:19026
+#: cp/pt.c:19066
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is/uses anonymous type"
 msgid "%qT is/uses unnamed type"
 msgstr "%qT 是/使用了匿名類型"
 
-#: cp/pt.c:19028
+#: cp/pt.c:19068
 #, fuzzy, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "模板引數用於 %qD 使用本地型態 %qT"
 
-#: cp/pt.c:19038
+#: cp/pt.c:19078
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT 是一個可變類型"
 
-#: cp/pt.c:19053
+#: cp/pt.c:19093
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "整型運算式 %qE 不是常數"
 
-#: cp/pt.c:19071
+#: cp/pt.c:19111
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  試圖實體化 %qD"
 
-#: cp/pt.c:22972
+#: cp/pt.c:23050
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#T"
 msgstr "%q#T 的類別範本實體化有歧義"
 
-#: cp/pt.c:22974
+#: cp/pt.c:23052
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#D"
 msgstr "%q#T 的類別範本實體化有歧義"
 
-#: cp/pt.c:22980
+#: cp/pt.c:23058
 #, fuzzy
 msgid "%s %#qS"
 msgstr "%s %+#D"
 
-#: cp/pt.c:23004 cp/pt.c:23091
+#: cp/pt.c:23082 cp/pt.c:23169
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "對非範本 %q#D 的明確實體化"
 
-#: cp/pt.c:23023
+#: cp/pt.c:23101
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD 並非靜態資料成員的類別模板"
 
-#: cp/pt.c:23029 cp/pt.c:23086
+#: cp/pt.c:23107 cp/pt.c:23164
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "沒有找到與 %qD 匹配的範本"
 
-#: cp/pt.c:23034
+#: cp/pt.c:23112
 #, fuzzy, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "型態 %qT 用於明確的實體化 %qD 不匹配宣告的型態 %qT"
 
-#: cp/pt.c:23042
+#: cp/pt.c:23120
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "對 %q#D 的明確實體化"
 
-#: cp/pt.c:23078
+#: cp/pt.c:23156
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "對 %q#D 重複的明確實體化"
 
-#: cp/pt.c:23101 cp/pt.c:23187
+#: cp/pt.c:23179 cp/pt.c:23265
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++1998 禁止使用的 %<extern%> 於明確的實體化"
 
-#: cp/pt.c:23106 cp/pt.c:23204
+#: cp/pt.c:23184 cp/pt.c:23282
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "為範本實體化化套用了存儲類型 %qD"
 
-#: cp/pt.c:23163
+#: cp/pt.c:23241
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "明確的實體化的 non-class 模板 %qD"
 
-#: cp/pt.c:23165
+#: cp/pt.c:23243
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "明確實體化非範本類型 %qT"
 
-#: cp/pt.c:23174
+#: cp/pt.c:23252
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "%q#T 的明確實體化出現在範本定義之前"
 
-#: cp/pt.c:23192
+#: cp/pt.c:23270
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ 不允許在明確實體化時使用 %qE"
 
-#: cp/pt.c:23238
+#: cp/pt.c:23316
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "對 %q#T 重複的明確實體化"
 
-#: cp/pt.c:23536
+#: cp/pt.c:23614
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "exception specification of %qD depends on itself"
@@ -51413,113 +51456,113 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:23842
+#: cp/pt.c:23920
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "明確實體化 %qD 時沒有可用的定義"
 
-#: cp/pt.c:24043
+#: cp/pt.c:24121
 #, fuzzy, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr "模板具現化深度超出最大值的 %d 舉例說明 %q+D, 可能會從虛擬表格產生 (使用 -ftemplate-depth=到增加最大值)"
 
-#: cp/pt.c:24418
+#: cp/pt.c:24496
 #, fuzzy, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "無效的模板 non-type 參數"
 
-#: cp/pt.c:24420
+#: cp/pt.c:24498
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T 並非有效型態用於模板 non-type 參數"
 
-#: cp/pt.c:25723
+#: cp/pt.c:25802
 #, fuzzy, gcc-internal-format
 #| msgid "keyword %<typename%> not allowed outside of templates"
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "關鍵字 %<typename%> 不能在範本以外使用"
 
-#: cp/pt.c:25961
+#: cp/pt.c:26040
 #, fuzzy, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr "deducing 從 brace-enclosed 初始設定式清單需求 # 包含 <initializer_list>"
 
-#: cp/pt.c:26440
+#: cp/pt.c:26519
 #, fuzzy, gcc-internal-format
 #| msgid "non-template %qD used as template"
 msgid "non-class template %qT used without template arguments"
 msgstr "非範本 %qD 做為範本"
 
-#: cp/pt.c:26586
+#: cp/pt.c:26665
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:26593
+#: cp/pt.c:26672
 #, fuzzy, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "%qE 並非有效模板引數的型態 %qT 因為 %qD 沒有任何鏈結"
 
-#: cp/pt.c:26607
+#: cp/pt.c:26686
 #, fuzzy, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "  模板引數推導/替代失敗："
 
-#: cp/pt.c:26614
+#: cp/pt.c:26693
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "不考慮內聯函式"
 
-#: cp/pt.c:26676
+#: cp/pt.c:26755
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:26679
+#: cp/pt.c:26758
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:26711
+#: cp/pt.c:26790
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/pt.c:26746
+#: cp/pt.c:26825
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "無法 deduce %qT 從 %qE"
 
-#: cp/pt.c:26748
+#: cp/pt.c:26827
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "無法 deduce %qT 從 %qE"
 
-#: cp/pt.c:26781
+#: cp/pt.c:26860
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:26785
+#: cp/pt.c:26864
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "指令不滿足其約束："
 
-#: cp/pt.c:26789
+#: cp/pt.c:26868
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "指令不滿足其約束："
 
-#: cp/pt.c:26793
+#: cp/pt.c:26872
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "指令不滿足其約束："
 
-#: cp/pt.c:26912
+#: cp/pt.c:26991
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr "無效的 non-type 模板引數"
@@ -51576,79 +51619,79 @@
 msgid "cannot dynamic_cast %qE (of type %q#T) to type %q#T (%s)"
 msgstr "無法將 %qE 從類型 %qT 動態_轉換到類型 %q#T (%s)"
 
-#: cp/search.c:240
+#: cp/search.c:243
 #, gcc-internal-format
 msgid "%qT is an ambiguous base of %qT"
 msgstr "%qT 是 %qT 的有歧義的基礎類別"
 
-#: cp/search.c:256
+#: cp/search.c:259
 #, gcc-internal-format
 msgid "%qT is an inaccessible base of %qT"
 msgstr "%qT 是 %qT 不可存取的基礎類別"
 
-#: cp/search.c:1905
+#: cp/search.c:1908
 #, fuzzy, gcc-internal-format
 #| msgid "invalid covariant return type for %q+#D"
 msgid "invalid covariant return type for %q#D"
 msgstr "%q+#D 的協變回傳類型無效"
 
-#: cp/search.c:1907 cp/search.c:1922 cp/search.c:1928 cp/search.c:1957
+#: cp/search.c:1910 cp/search.c:1925 cp/search.c:1931 cp/search.c:1960
 #, fuzzy, gcc-internal-format
 msgid "overridden function is %q#D"
 msgstr "強迫刪除的函式 %q+D"
 
-#: cp/search.c:1920
+#: cp/search.c:1923
 #, gcc-internal-format
 msgid "invalid covariant return type for %q+#D"
 msgstr "%q+#D 的協變回傳類型無效"
 
-#: cp/search.c:1926
+#: cp/search.c:1929
 #, gcc-internal-format
 msgid "conflicting return type specified for %q+#D"
 msgstr "為 %q+#D 指定了衝突的回傳類型"
 
-#: cp/search.c:1942
+#: cp/search.c:1945
 #, gcc-internal-format
 msgid "looser throw specifier for %q+#F"
 msgstr "放鬆 %q+#F 的 throw 限定"
 
-#: cp/search.c:1944
+#: cp/search.c:1947
 #, fuzzy, gcc-internal-format
 msgid "overridden function is %q#F"
 msgstr "強迫刪除的函式 %q+D"
 
-#: cp/search.c:1955
+#: cp/search.c:1958
 #, fuzzy, gcc-internal-format
 msgid "conflicting type attributes specified for %q+#D"
 msgstr "衝突型態屬性指定的用於 %q+#D"
 
-#: cp/search.c:1972
+#: cp/search.c:1975
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<transaction_safe_dynamic%>"
 msgstr "預期 %<__transaction_atomic%>"
 
-#: cp/search.c:1974
+#: cp/search.c:1977
 #, fuzzy, gcc-internal-format
 #| msgid "variable %q+D declared %<inline%>"
 msgid "overriding %qD declared %<transaction_safe%>"
 msgstr "變數 %q+D 宣告為 %<inline%>"
 
-#: cp/search.c:1981
+#: cp/search.c:1984
 #, fuzzy, gcc-internal-format
 msgid "deleted function %q+D overriding non-deleted function"
 msgstr "強迫 non-deleted 函式 %q+D"
 
-#: cp/search.c:1984 cp/search.c:1992 cp/search.c:2000
+#: cp/search.c:1987 cp/search.c:1995 cp/search.c:2003
 #, fuzzy, gcc-internal-format
 msgid "overridden function is %qD"
 msgstr "強迫刪除的函式 %q+D"
 
-#: cp/search.c:1989
+#: cp/search.c:1992
 #, fuzzy, gcc-internal-format
 msgid "non-deleted function %q+D overriding deleted function"
 msgstr "non-deleted 函式 %q+D"
 
-#: cp/search.c:1998
+#: cp/search.c:2001
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "virtual function %q+D overriding final function"
@@ -51656,12 +51699,12 @@
 
 #. A static member function cannot match an inherited
 #. virtual member function.
-#: cp/search.c:2082
+#: cp/search.c:2085
 #, gcc-internal-format
 msgid "%q+#D cannot be declared"
 msgstr "無法宣告 %q+#D"
 
-#: cp/search.c:2083
+#: cp/search.c:2086
 #, gcc-internal-format
 msgid "  since %q+#D declared in base class"
 msgstr "  因為 %q+#D 已在基礎類別中宣告過"
@@ -51703,584 +51746,599 @@
 msgid "invalid use of member %qD in static member function"
 msgstr "在靜態成員函式中使用成員 %q+D 無效"
 
-#: cp/semantics.c:2153
+#: cp/semantics.c:2156
 #, gcc-internal-format
 msgid "a statement expression is an insufficient context for overload resolution"
 msgstr ""
 
-#: cp/semantics.c:2540
+#: cp/semantics.c:2543
 #, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr "解構函式不能有參數"
 
-#: cp/semantics.c:2622
+#: cp/semantics.c:2625
 #, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr "靜態成員函式中不能使用 %<this%>"
 
-#: cp/semantics.c:2624
+#: cp/semantics.c:2627
 #, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr "在非成員函式中使用 %<this%> 無效"
 
-#: cp/semantics.c:2626
+#: cp/semantics.c:2629
 #, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr "在頂層使用 %<this%> 無效"
 
-#: cp/semantics.c:2648
+#: cp/semantics.c:2651
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "偽解構函式名的限定作用欄位無效"
 
-#: cp/semantics.c:2656 cp/typeck.c:2604
+#: cp/semantics.c:2659 cp/typeck.c:2604
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "限定的類型 %qT 不匹配解構函式名 ~%qT"
 
-#: cp/semantics.c:2678
+#: cp/semantics.c:2681
 #, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr "%qE 的類型不是 %qT"
 
-#: cp/semantics.c:2751
+#: cp/semantics.c:2754
 #, fuzzy, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr "複合實字的 non-object 型態 %qT"
 
-#: cp/semantics.c:2892
+#: cp/semantics.c:2895
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr "範本參數必須使用 %<class%> 或 %<typename%> 關鍵字"
 
-#: cp/semantics.c:2942
+#: cp/semantics.c:2945
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr "將類型 %qT 做為範本的範本參數的預設值無效"
 
-#: cp/semantics.c:2945
+#: cp/semantics.c:2948
 #, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr "範本的範本參數的預設引數無效"
 
-#: cp/semantics.c:2962
+#: cp/semantics.c:2965
 #, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr "在範本參數清單中定義了 %q#T"
 
-#: cp/semantics.c:2993
+#: cp/semantics.c:2996
 #, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr "對限定類型 %qT 的定義無效"
 
-#: cp/semantics.c:3263
+#: cp/semantics.c:3266
 #, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "無效的基礎類別"
 
-#: cp/semantics.c:3423
+#: cp/semantics.c:3426
 #, fuzzy, gcc-internal-format
 #| msgid "protected member %q+#D in anonymous union"
 msgid "cannot capture member %qD of anonymous union"
 msgstr "匿名聯合中出現保護成員 %q+#D"
 
-#: cp/semantics.c:3443 cp/semantics.c:9269
+#: cp/semantics.c:3446 cp/semantics.c:9272
 #, fuzzy, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qD 未被擷取"
 
-#: cp/semantics.c:3448
+#: cp/semantics.c:3451
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.c:3450
+#: cp/semantics.c:3453
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.c:3462
+#: cp/semantics.c:3465
 #, fuzzy, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr "在包含函式中使用 %<auto%> 變數"
 
-#: cp/semantics.c:3464
+#: cp/semantics.c:3467
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr "在包含函式中使用參數"
 
-#: cp/semantics.c:3596
+#: cp/semantics.c:3599
 #, fuzzy, gcc-internal-format
 msgid "use of parameter outside function body"
 msgstr "使用的參數 %qD 外側函式內文"
 
-#: cp/semantics.c:3606
+#: cp/semantics.c:3609
 #, fuzzy, gcc-internal-format
 msgid "missing template arguments"
 msgstr "不匹配的引數"
 
-#: cp/semantics.c:3633
+#: cp/semantics.c:3636
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr "範本參數 %qD(類型為 %qT)不允許出現在整數運算式中，因為它的類型不是整數或列舉"
 
-#: cp/semantics.c:3664
+#: cp/semantics.c:3667
 #, gcc-internal-format
 msgid "use of namespace %qD as expression"
 msgstr "命名空間 %qD 做為運算式"
 
-#: cp/semantics.c:3669
+#: cp/semantics.c:3672
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr "將類別範本 %qT 做為運算式"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:3675
+#: cp/semantics.c:3678
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "在多繼承網格中對 %qD 的存取有歧義"
 
-#: cp/semantics.c:3702
+#: cp/semantics.c:3705
 #, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "%qD 不能出現在常數運算式中"
 
-#: cp/semantics.c:3841
+#: cp/semantics.c:3844
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "%qE 的類型不明"
 
-#: cp/semantics.c:3870
+#: cp/semantics.c:3873
 #, fuzzy, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr "%qT 不是列舉類型型態"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4009
+#: cp/semantics.c:4012
 #, fuzzy, gcc-internal-format
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr "參數包裝 __bases 只有有效在中模板宣告"
 
-#: cp/semantics.c:4038
+#: cp/semantics.c:4041
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr "無法套用 %<offsetof%> 到解構式 %<~%T%>"
 
-#: cp/semantics.c:4052
+#: cp/semantics.c:4055
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "無法套用 %<offsetof%> 到成員函式 %qD"
 
-#: cp/semantics.c:4056
+#: cp/semantics.c:4059
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function"
 msgstr "無法套用 %<offsetof%> 到成員函式 %qD"
 
-#: cp/semantics.c:4061
+#: cp/semantics.c:4064
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr "無法套用 %<offsetof%> 到成員函式 %qD"
 
-#: cp/semantics.c:4072
+#: cp/semantics.c:4075
 #, gcc-internal-format
 msgid "offsetof within non-standard-layout type %qT is conditionally-supported"
 msgstr ""
 
-#: cp/semantics.c:4583 cp/semantics.c:6069 cp/semantics.c:6140
-#: cp/semantics.c:6183 cp/semantics.c:6533 cp/semantics.c:6632
-#: cp/semantics.c:6775
+#: cp/semantics.c:4586 cp/semantics.c:6072 cp/semantics.c:6143
+#: cp/semantics.c:6186 cp/semantics.c:6536 cp/semantics.c:6635
+#: cp/semantics.c:6778
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5271
+#: cp/semantics.c:5274
 #, fuzzy, gcc-internal-format
 #| msgid "reference to %qD is ambiguous"
 msgid "user defined reduction lookup is ambiguous"
 msgstr "對 %qD 的參照有歧義"
 
-#: cp/semantics.c:5544
+#: cp/semantics.c:5547
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: cp/semantics.c:5592
+#: cp/semantics.c:5595
 #, fuzzy, gcc-internal-format
 msgid "%qE has const type for %<reduction%>"
 msgstr "%qE 有無效的型態用於 %<reduction%>"
 
-#: cp/semantics.c:5707
+#: cp/semantics.c:5710
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:5941
+#: cp/semantics.c:5944
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5955
+#: cp/semantics.c:5958
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5977
+#: cp/semantics.c:5980
 #, fuzzy, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.c:6080
+#: cp/semantics.c:6083
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD 並非變數在中子句 %qs"
 
-#: cp/semantics.c:6152
+#: cp/semantics.c:6155
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "%qD 並非變數在中子句 %<firstprivate%>"
 
-#: cp/semantics.c:6195
+#: cp/semantics.c:6198
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "%qD 並非變數在中子句 %<lastprivate%>"
 
-#: cp/semantics.c:6240
+#: cp/semantics.c:6243
 #, fuzzy, gcc-internal-format
 msgid "%<gang%> static expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.c:6254
+#: cp/semantics.c:6257
 #, fuzzy, gcc-internal-format
 msgid "%<gang%> static value must be positive"
 msgstr "%<num_threads%> 值必須是正值"
 
-#: cp/semantics.c:6288
+#: cp/semantics.c:6291
 #, fuzzy, gcc-internal-format
 msgid "%<gang%> num expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.c:6291
+#: cp/semantics.c:6294
 #, fuzzy, gcc-internal-format
 msgid "%<vector%> length expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.c:6295
+#: cp/semantics.c:6298
 #, fuzzy, gcc-internal-format
 msgid "%<worker%> num expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.c:6317
+#: cp/semantics.c:6320
 #, fuzzy, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr "%<num_threads%> 值必須是正值"
 
-#: cp/semantics.c:6321
+#: cp/semantics.c:6324
 #, fuzzy, gcc-internal-format
 msgid "%<vector%> length value must be positive"
 msgstr "%<num_threads%> 值必須是正值"
 
-#: cp/semantics.c:6326
+#: cp/semantics.c:6329
 #, fuzzy, gcc-internal-format
 msgid "%<worker%> num value must be positive"
 msgstr "%<num_threads%> 值必須是正值"
 
-#: cp/semantics.c:6376
+#: cp/semantics.c:6379
 #, fuzzy, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr "排程資料塊大小運算式必須是積分"
 
-#: cp/semantics.c:6406
+#: cp/semantics.c:6409
 #, fuzzy, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.c:6419
+#: cp/semantics.c:6422
 #, fuzzy, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "崩潰引數需要正面的常數整數運算式"
 
-#: cp/semantics.c:6438
+#: cp/semantics.c:6441
 #, fuzzy, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.c:6466
+#: cp/semantics.c:6469
 #, fuzzy, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.c:6495
+#: cp/semantics.c:6498
 #, fuzzy, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr "切片結束必須是整數"
 
-#: cp/semantics.c:6516
+#: cp/semantics.c:6519
 #, fuzzy, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr "排程資料塊大小運算式必須是積分"
 
-#: cp/semantics.c:6543
+#: cp/semantics.c:6546
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qD 並非變數在中子句 %qs"
 
-#: cp/semantics.c:6557
+#: cp/semantics.c:6560
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:6563
+#: cp/semantics.c:6566
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr "%qD 出現一次以上在中資料子句"
 
-#: cp/semantics.c:6576
+#: cp/semantics.c:6579
 #, fuzzy, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr "排程資料塊大小運算式必須是積分"
 
-#: cp/semantics.c:6625
+#: cp/semantics.c:6628
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr "%qD 並非變數在中子句 %qs"
 
-#: cp/semantics.c:6910
+#: cp/semantics.c:6913
 #, fuzzy, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr "太多 %qs 子句"
 
-#: cp/semantics.c:6914
+#: cp/semantics.c:6917
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6979
+#: cp/semantics.c:6982
 #, fuzzy, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.c:7008
+#: cp/semantics.c:7011
 #, fuzzy, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.c:7037
+#: cp/semantics.c:7040
 #, fuzzy, gcc-internal-format
 msgid "%<num_tasks%> expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.c:7066
+#: cp/semantics.c:7069
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:7105
+#: cp/semantics.c:7108
 #, fuzzy, gcc-internal-format
 #| msgid "%<tree%> is not defined as a pointer type"
 msgid "%<tile%> argument needs integral type"
 msgstr "%<tree%> 未被定義為一個指標類型"
 
-#: cp/semantics.c:7524
+#: cp/semantics.c:7527
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr "%<threadprivate%> %qD 不是檔案，命名空間或區塊範圍變數"
 
-#: cp/semantics.c:7538
+#: cp/semantics.c:7541
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "%<threadprivate%> %qE 指令無法在中 %qT 定義"
 
-#: cp/semantics.c:7743
+#: cp/semantics.c:7746
 #, fuzzy, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr "差異介於 %qE 和 %qD 沒有整數類型"
 
-#: cp/semantics.c:8171
+#: cp/semantics.c:8174
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr "%<# pragma omp 基元的 update%>使用兩不同的變數用於記憶體"
 
-#: cp/semantics.c:8398 cp/semantics.c:8408
+#: cp/semantics.c:8401 cp/semantics.c:8411
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr "%<# pragma omp 基元的 update%>使用兩不同的變數用於記憶體"
 
-#: cp/semantics.c:8702
+#: cp/semantics.c:8705
 #, fuzzy, gcc-internal-format
 msgid "static assertion failed"
 msgstr "靜態假設失敗：%E"
 
-#: cp/semantics.c:8704
+#: cp/semantics.c:8707
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr "靜態假設失敗：%s"
 
-#: cp/semantics.c:8709
+#: cp/semantics.c:8712
 #, fuzzy, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "non-constant 條件用於靜態假設"
 
-#: cp/semantics.c:8739
+#: cp/semantics.c:8742
 #, fuzzy, gcc-internal-format
 msgid "argument to decltype must be an expression"
 msgstr "引數到 decltype 必須是運算式"
 
-#: cp/semantics.c:8767
+#: cp/semantics.c:8770
 #, fuzzy, gcc-internal-format
 msgid "decltype cannot resolve address of overloaded function"
 msgstr "decltype 無法解析位址的多載化函式"
 
-#: cp/semantics.c:9308
+#: cp/semantics.c:9311
 #, fuzzy, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "第三運算元的條件運算式沒有任何效果"
 
-#: cp/semantics.c:9361
+#: cp/semantics.c:9364
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %qE involves template parameter(s)"
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "範本引數 %qE 混雜了範本參數"
 
-#: cp/semantics.c:9363
+#: cp/semantics.c:9366
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:9381
+#: cp/semantics.c:9384
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %<__builtin_return_address%>"
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "%<__builtin_return_address%> 的引數不受支援"
 
-#: cp/tree.c:1276
+#: cp/tree.c:1295
 #, gcc-internal-format
 msgid "%qV qualifiers cannot be applied to %qT"
 msgstr "%qV 限定符不能套用到 %qT 上"
 
-#: cp/tree.c:1788
+#: cp/tree.c:1807
 #, fuzzy, gcc-internal-format
 msgid "lambda-expression in a constant expression"
 msgstr "運算式 %qE 並非 constant-expression"
 
-#: cp/tree.c:1792
+#: cp/tree.c:1811
 #, fuzzy, gcc-internal-format
 msgid "statement-expression in a constant expression"
 msgstr "運算式 %qE 並非 constant-expression"
 
-#: cp/tree.c:4050
+#: cp/tree.c:4083
 #, gcc-internal-format
-msgid "the calling convention for %qT changes in -fabi-version=12 (GCC 8)"
+msgid "-fabi-version=13 (GCC 8.2) fixes the calling convention for %qT, which was accidentally changed in 8.1"
 msgstr ""
 
-#: cp/tree.c:4055
+#: cp/tree.c:4087
 #, gcc-internal-format
+msgid "-fabi-version=12 (GCC 8.1) accidentally changes the calling convention for %qT"
+msgstr ""
+
+#: cp/tree.c:4090
+#, fuzzy, gcc-internal-format
+msgid " declared here"
+msgstr "宣告的在此"
+
+#: cp/tree.c:4094
+#, gcc-internal-format
+msgid "the calling convention for %qT changes in -fabi-version=13 (GCC 8.2)"
+msgstr ""
+
+#: cp/tree.c:4096
+#, gcc-internal-format
 msgid " because all of its copy and move constructors are deleted"
 msgstr ""
 
-#: cp/tree.c:4416
+#: cp/tree.c:4464
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to %qD with void return type"
 msgstr "忽略屬性套用到 %qT 之後定義"
 
-#: cp/tree.c:4423
+#: cp/tree.c:4471
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr "只能為類別定義套用 %qE 屬性"
 
-#: cp/tree.c:4475
+#: cp/tree.c:4523
 #, gcc-internal-format
 msgid "requested init_priority is not an integer constant"
 msgstr "請求的 init_priority 不是一個整數常數"
 
-#: cp/tree.c:4497
+#: cp/tree.c:4545
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr "只能將 %qE 屬性用於某個類別的物件的檔案作用欄位定義"
 
-#: cp/tree.c:4505
+#: cp/tree.c:4553
 #, gcc-internal-format
 msgid "requested init_priority is out of range"
 msgstr "請求的 init_priority 越界"
 
-#: cp/tree.c:4515
+#: cp/tree.c:4563
 #, gcc-internal-format
 msgid "requested init_priority is reserved for internal use"
 msgstr "請求的 init_priority 保留為內部使用"
 
-#: cp/tree.c:4526
+#: cp/tree.c:4574
 #, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr "%qE 屬性在此平臺上不受支援"
 
-#: cp/tree.c:4553
+#: cp/tree.c:4601
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %qE"
 msgstr "%qD 宣告為 %qT 的一個成員"
 
-#: cp/tree.c:4573
+#: cp/tree.c:4621
 #, fuzzy, gcc-internal-format
 msgid "the %qE attribute requires arguments"
 msgstr "%qD 屬性需要單一 NTBS 引數"
 
-#: cp/tree.c:4584
+#: cp/tree.c:4632
 #, fuzzy, gcc-internal-format
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "引數的 %qE 屬性並非字串常數"
 
-#: cp/tree.c:4597 cp/tree.c:4610
+#: cp/tree.c:4645 cp/tree.c:4658
 #, fuzzy, gcc-internal-format
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "引數的 %qE 屬性並非字串常數"
 
-#: cp/tree.c:4599
+#: cp/tree.c:4647
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a valid declarator"
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "%<%T::%D%> 不是一個有效的宣告"
 
-#: cp/tree.c:4612
+#: cp/tree.c:4660
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a valid declarator"
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "%<%T::%D%> 不是一個有效的宣告"
 
-#: cp/tree.c:4636
+#: cp/tree.c:4684
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "%qE 屬性在不是類別的類型上被忽略"
 
-#: cp/tree.c:4642
+#: cp/tree.c:4690
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "忽略屬性套用到 %qT 之後定義"
 
-#: cp/tree.c:4649
+#: cp/tree.c:4697
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "忽略屬性套用到 %qT 之後定義"
 
-#: cp/tree.c:4656
+#: cp/tree.c:4704
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "忽略屬性套用到 %qT 之後定義"
 
-#: cp/tree.c:4678
+#: cp/tree.c:4726
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "%qE 屬性套用只有到函式"
 
-#: cp/tree.c:4684
+#: cp/tree.c:4732
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "%qE 屬性套用只有到函式"
 
-#: cp/tree.c:5440
+#: cp/tree.c:5488
 #, fuzzy, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "零做為空指標常數"
 
-#: cp/tree.c:5453
+#: cp/tree.c:5501
 #, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr "lang_* check：在 %s 中失敗，於 %s:%d"
@@ -53401,110 +53459,110 @@
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "不可使用複合原文初始化類型為 %qT 的聚集"
 
-#: cp/typeck2.c:1496 cp/typeck2.c:1523
+#: cp/typeck2.c:1499 cp/typeck2.c:1526
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "成員 %qD 缺少初始值設定"
 
-#: cp/typeck2.c:1504
+#: cp/typeck2.c:1507
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "成員 %qD 是未初始化的參照"
 
-#: cp/typeck2.c:1511
+#: cp/typeck2.c:1514
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD is uninitialized reference"
 msgid "member %qD with uninitialized reference fields"
 msgstr "成員 %qD 是未初始化的參照"
 
-#: cp/typeck2.c:1587
+#: cp/typeck2.c:1590
 #, fuzzy, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "型態的 %qD 不匹配原來的宣告"
 
-#: cp/typeck2.c:1660
+#: cp/typeck2.c:1663
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "在初始化的聯合中找不到欄位 %qD"
 
-#: cp/typeck2.c:1671
+#: cp/typeck2.c:1674
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "在聯合初始值設定中出現了索引值而不是欄位名"
 
-#: cp/typeck2.c:1858
+#: cp/typeck2.c:1861
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "偵測到循環指標代理"
 
-#: cp/typeck2.c:1872
+#: cp/typeck2.c:1875
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "%<->%> 的基運算元具有非指標類型 %qT"
 
-#: cp/typeck2.c:1898
+#: cp/typeck2.c:1901
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "%<operator->()%> 的結果給出了非指標的結果"
 
-#: cp/typeck2.c:1900
+#: cp/typeck2.c:1903
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "%<->%> 的左運算元不是一個指標"
 
-#: cp/typeck2.c:1927
+#: cp/typeck2.c:1930
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE 不能做為成員指標，因為它的類型為 %qT"
 
-#: cp/typeck2.c:1936
+#: cp/typeck2.c:1939
 #, fuzzy, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "無法套用成員指標 %qE 到 %qE，該項是的 non-class 型態 %qT"
 
-#: cp/typeck2.c:1958
+#: cp/typeck2.c:1961
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "成員指標類型 %qT 與物件類型 %qT 不相容"
 
-#: cp/typeck2.c:2018
+#: cp/typeck2.c:2021
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "在算術運算式中使用了成員指標"
 
-#: cp/typeck2.c:2029
+#: cp/typeck2.c:2032
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "在算術運算式中使用了成員指標"
 
-#: cp/typeck2.c:2037
+#: cp/typeck2.c:2040
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++2a"
 msgstr ""
 
-#: cp/typeck2.c:2080
+#: cp/typeck2.c:2083
 #, fuzzy, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "functional 演員陣容到陣列類型 %qT"
 
-#: cp/typeck2.c:2096
+#: cp/typeck2.c:2099
 #, fuzzy, gcc-internal-format
 msgid "cannot deduce template arguments for %qT from ()"
 msgstr "在中模板引數用於型態 %qT "
 
-#: cp/typeck2.c:2114
+#: cp/typeck2.c:2117
 #, fuzzy, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "無效的 value-initialization 的參考類型"
 
-#: cp/typeck2.c:2341
+#: cp/typeck2.c:2344
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "呼叫的函式 %qD 會拋出不完全的類型 %q#T"
 
-#: cp/typeck2.c:2344
+#: cp/typeck2.c:2347
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "呼叫的函式會拋出不完全的類型 %q#T"
@@ -53726,11 +53784,11 @@
 msgstr "%C 處的任何參照都不能多於 %d 維"
 
 #: fortran/array.c:221 fortran/array.c:661 fortran/check.c:2849
-#: fortran/check.c:5222 fortran/check.c:5260 fortran/check.c:5302
-#: fortran/check.c:5329 fortran/check.c:5529 fortran/match.c:1821
+#: fortran/check.c:5225 fortran/check.c:5263 fortran/check.c:5305
+#: fortran/check.c:5332 fortran/check.c:5532 fortran/match.c:1821
 #: fortran/match.c:3174 fortran/match.c:3516 fortran/match.c:3712
-#: fortran/simplify.c:2909 fortran/simplify.c:2939 fortran/simplify.c:5764
-#: fortran/simplify.c:7658
+#: fortran/simplify.c:2909 fortran/simplify.c:2939 fortran/simplify.c:5769
+#: fortran/simplify.c:7663
 #, fuzzy, gcc-internal-format
 msgid "Coarrays disabled at %C, use %<-fcoarray=%> to enable"
 msgstr "Coarrays 已停用於 %C, 使用 -fcoarray=以啟用"
@@ -53868,121 +53926,127 @@
 msgid "DO-iterator %qs at %L is inside iterator of the same name"
 msgstr "DO 游標「%s」在 %L 處出現在另一個同名游標作用欄位內"
 
-#: fortran/array.c:1073 fortran/array.c:1255
+#: fortran/array.c:1073 fortran/array.c:1264
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in array constructor at %C"
 msgstr "%C 陣列建構語法錯誤"
 
-#: fortran/array.c:1129
+#: fortran/array.c:1105
 #, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "ENTRY statement at %C cannot appear in a contained procedure"
+msgid "NULL() at %C cannot appear in an array constructor"
+msgstr "%C 處 ENTRY 敘述不能出現在被包含的程序中"
+
+#: fortran/array.c:1138
+#, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "[...] style array constructors at %C"
 msgstr "Fortran 2003:[...] 樣式陣列建構子於 %C"
 
-#: fortran/array.c:1149
+#: fortran/array.c:1158
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array constructor including type specification at %C"
 msgstr "Fortran 2003:陣列建構子包含型態規格於 %C"
 
-#: fortran/array.c:1155 fortran/match.c:4148
+#: fortran/array.c:1164 fortran/match.c:4148
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type-spec at %L cannot contain a deferred type parameter"
 msgstr "Type-spec 於 %L 無法包含已推遲型態參數"
 
-#: fortran/array.c:1163
+#: fortran/array.c:1172
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type-spec at %L cannot contain an asterisk for a type parameter"
 msgstr "Type-spec 於 %L 無法包含已推遲型態參數"
 
-#: fortran/array.c:1181
+#: fortran/array.c:1190
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty array constructor at %C is not allowed"
 msgstr "%C 處的空陣列建構不被允許"
 
-#: fortran/array.c:1218 fortran/array.c:1228
+#: fortran/array.c:1227 fortran/array.c:1237
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "incompatible type for argument %d of %qE"
 msgid "Incompatible typespec for array element at %L"
 msgstr "引數 %d(屬於 %qE)類型不相容"
 
-#: fortran/array.c:1302
+#: fortran/array.c:1311
 #, gcc-internal-format, gfc-internal-format
 msgid "Element in %s array constructor at %L is %s"
 msgstr "%s 陣列建構中的元素在 %L 處是 %s"
 
-#: fortran/array.c:1633
+#: fortran/array.c:1642
 #, gcc-internal-format, gfc-internal-format
 msgid "Iterator step at %L cannot be zero"
 msgstr "%L 迭代次數不能為零"
 
-#: fortran/array.c:1770
+#: fortran/array.c:1779
 #, fuzzy, gcc-internal-format
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit.   See %<-fmax-array-constructor%> option"
 msgstr "元件號碼的在中陣列建構子於 %L 需求增加的允許 %d 上限。  參看 -fmax-array-constructor 選項"
 
-#: fortran/array.c:1940
+#: fortran/array.c:1949
 #, gcc-internal-format, gfc-internal-format
 msgid "AC-IMPLIED-DO initial expression references control variable at %L"
 msgstr ""
 
-#: fortran/array.c:1947
+#: fortran/array.c:1956
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "AC-IMPLIED-DO final expression references control variable at %L"
 msgstr "%L 處運算式參照類型錯誤"
 
-#: fortran/array.c:1954
+#: fortran/array.c:1963
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "AC-IMPLIED-DO step expression references control variable at %L"
 msgstr "%L 處運算式參照類型錯誤"
 
-#: fortran/array.c:1966
+#: fortran/array.c:1975
 #, gcc-internal-format, gfc-internal-format
 msgid "Array constructor value at %L shall not be unlimited polymorphic [F2008: C4106]"
 msgstr ""
 
-#: fortran/array.c:2055
+#: fortran/array.c:2067
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor at %L"
 msgstr "不同的字元長度 (%d/%d) 在中陣列建構子於 %L"
 
-#: fortran/array.c:2174
+#: fortran/array.c:2186
 #, gcc-internal-format
 msgid "spec_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2233
+#: fortran/array.c:2245
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2237
+#: fortran/array.c:2249
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad array reference at %L"
 msgid "Bad array dimension at %L"
 msgstr "%L 處陣列參照錯誤"
 
-#: fortran/array.c:2264 fortran/data.c:552 fortran/data.c:571
-#: fortran/data.c:585 fortran/data.c:714
+#: fortran/array.c:2276 fortran/data.c:563 fortran/data.c:582
+#: fortran/data.c:596 fortran/data.c:725
 #, fuzzy, gcc-internal-format
 #| msgid "gimplification failed"
 msgid "Simplification error"
 msgstr "gimplification 失敗"
 
-#: fortran/array.c:2376
+#: fortran/array.c:2388
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimen_type"
 msgstr ""
 
-#: fortran/array.c:2427
+#: fortran/array.c:2439
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2472
+#: fortran/array.c:2484
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad EXPR_ARRAY expr"
 msgstr ""
 
-#: fortran/array.c:2620
+#: fortran/array.c:2632
 #, gcc-internal-format
 msgid "gfc_find_array_ref(): No ref found"
 msgstr ""
@@ -54039,7 +54103,7 @@
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or PROCEDURE"
 msgstr "引數「%s」(屬於內建函式「%s」，位於 %L)必須為 INTEGER 或 PROCEDURE"
 
-#: fortran/check.c:205 fortran/check.c:6658
+#: fortran/check.c:205 fortran/check.c:6661
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a constant"
 msgid "%qs argument of %qs intrinsic at %L must be a constant"
@@ -54166,7 +54230,7 @@
 msgid "Unequal character lengths (%ld/%ld) in %s at %L"
 msgstr "Unequal 字元長度 (%ld/%ld) 在中 %s 於 %L"
 
-#: fortran/check.c:946 fortran/check.c:6602
+#: fortran/check.c:946 fortran/check.c:6605
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' and '%s' arguments of '%s' intrinsic at %L must have the same type"
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have the same type"
@@ -54409,9 +54473,9 @@
 msgstr "『%s』引數的『%s』intrinsic 於 %L 不應該被 coindexed"
 
 #: fortran/check.c:1939 fortran/check.c:2525 fortran/check.c:2628
-#: fortran/check.c:2835 fortran/check.c:2880 fortran/check.c:4256
-#: fortran/check.c:4390 fortran/check.c:4445 fortran/check.c:5515
-#: fortran/check.c:5644
+#: fortran/check.c:2835 fortran/check.c:2880 fortran/check.c:4259
+#: fortran/check.c:4393 fortran/check.c:4448 fortran/check.c:5518
+#: fortran/check.c:5647
 #, fuzzy, gcc-internal-format
 msgid "%qs intrinsic with KIND argument at %L"
 msgstr "Fortran 2003:『%s』intrinsic 與 KIND 引數於 %L"
@@ -54612,7 +54676,7 @@
 msgid "NULL intrinsic with allocatable MOLD at %L"
 msgstr "Fortran 2003:空值 intrinsic 與 allocatable 鑄型於 %L"
 
-#: fortran/check.c:3768 fortran/check.c:5591
+#: fortran/check.c:3768 fortran/check.c:5594
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must provide at least as many elements as there are .TRUE. values in %qs (%ld/%d)"
 msgstr "『%s』引數的『%s』intrinsic 於 %L 必須提供至少做為許多元件做為有些.TRUE。值在中『%s』(%ld/%d)"
@@ -54634,381 +54698,381 @@
 msgid "%qs argument of %qs intrinsic at %L must not be a subobject of %qs"
 msgstr "『%s』引數的『%s』intrinsic 於 %L 必須不是子物件的『%s』"
 
-#: fortran/check.c:3901
+#: fortran/check.c:3904
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The argument of the RANK intrinsic at %L must be a data object"
 msgstr "引數的分級 intrinsic 於 %L 必須是資料物件"
 
-#: fortran/check.c:4005
+#: fortran/check.c:4008
 #, fuzzy, gcc-internal-format
 #| msgid "'shape' argument of 'reshape' intrinsic at %L must be an array of constant size"
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L must be an array of constant size"
 msgstr "「reshape」內建函式的「shape」引數在 %L 處必須是大小為常數的陣列"
 
-#: fortran/check.c:4015
+#: fortran/check.c:4018
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L is empty"
 msgstr "『%s』引數的『%s』intrinsic 於 %L 是空的"
 
-#: fortran/check.c:4022
+#: fortran/check.c:4025
 #, fuzzy, gcc-internal-format
 #| msgid "'shape' argument of 'reshape' intrinsic at %L has more than %d elements"
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L has more than %d elements"
 msgstr "「reshape」內建函式的「shape」引數在 %L 處有多於 %d 個的元素"
 
-#: fortran/check.c:4039
+#: fortran/check.c:4042
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has negative element (%d)"
 msgstr "『%s』引數的『%s』intrinsic 於 %L 有負元件 (%d)"
 
-#: fortran/check.c:4071
+#: fortran/check.c:4074
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Element %d of actual argument of RESHAPE at %L cannot be negative"
 msgstr "複雜引數的記錄檔於 %L 無法零"
 
-#: fortran/check.c:4109
+#: fortran/check.c:4112
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has wrong number of elements (%d/%d)"
 msgstr "『%s』引數的『%s』intrinsic 於 %L 有錯誤的元件號碼的 (%d/%d)"
 
-#: fortran/check.c:4127
+#: fortran/check.c:4130
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has out-of-range dimension (%d)"
 msgstr "『%s』引數的『%s』intrinsic 於 %L 有 out-of-range 尺寸 (%d)"
 
-#: fortran/check.c:4136
+#: fortran/check.c:4139
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has invalid permutation of dimensions (dimension %qd duplicated)"
 msgstr "『%s』引數的『%s』intrinsic 於 %L 有無效的排列的維度 (尺寸『%d』重製)"
 
-#: fortran/check.c:4172
+#: fortran/check.c:4175
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Without padding, there are not enough elements in the intrinsic RESHAPE source at %L to match the shape"
 msgstr "而無需填補，有些不足元件在中 intrinsic 重設形狀來源於 %L 到匹配形狀"
 
-#: fortran/check.c:4189 fortran/check.c:4208
+#: fortran/check.c:4192 fortran/check.c:4211
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L cannot be of type %s"
 msgstr "引數「%s」(屬於內建函式「%s」，位於 %L)必須是 %s"
 
-#: fortran/check.c:4199 fortran/check.c:4218
+#: fortran/check.c:4202 fortran/check.c:4221
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of an extensible type"
 msgstr "『%s』引數的『%s』intrinsic 於 %L 必須是的 extensible 型態"
 
-#: fortran/check.c:4317
+#: fortran/check.c:4320
 #, fuzzy, gcc-internal-format
 msgid "SELECTED_REAL_KIND with neither %<P%> nor %<R%> argument at %L"
 msgstr "Fortran 2008:SELECTED_REAL_KIND 與 neither『P』nor『R』引數於 %L"
 
-#: fortran/check.c:4348
+#: fortran/check.c:4351
 #, fuzzy, gcc-internal-format
 msgid "%qs intrinsic with RADIX argument at %L"
 msgstr "Fortran 2008:『%s』intrinsic 與基數引數於 %L"
 
-#: fortran/check.c:4383
+#: fortran/check.c:4386
 #, fuzzy, gcc-internal-format
 #| msgid "'source' argument of 'shape' intrinsic at %L must not be an assumed size array"
 msgid "%<source%> argument of %<shape%> intrinsic at %L must not be an assumed size array"
 msgstr "「shape」內建函式的「source」引數在 %L 處不能是假定大小的陣列"
 
-#: fortran/check.c:4460 fortran/check.c:6641
+#: fortran/check.c:4463 fortran/check.c:6644
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be a procedure"
 msgstr "『%s』引數的『%s』intrinsic 於 %L 可能無法是程序"
 
-#: fortran/check.c:4473 fortran/check.c:4612 fortran/check.c:6633
+#: fortran/check.c:4476 fortran/check.c:4615 fortran/check.c:6636
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be TYPE(*)"
 msgstr "『%s』引數的『%s』intrinsic 於 %L 不應該被 coindexed"
 
-#: fortran/check.c:4484 fortran/check.c:4624
+#: fortran/check.c:4487 fortran/check.c:4627
 #, fuzzy, gcc-internal-format
 #| msgid "'source' argument of 'shape' intrinsic at %L must not be an assumed size array"
 msgid "%qs argument of %qs intrinsic at %L shall not be an assumed-size array"
 msgstr "「shape」內建函式的「source」引數在 %L 處不能是假定大小的陣列"
 
-#: fortran/check.c:4554
+#: fortran/check.c:4557
 #, gcc-internal-format
 msgid "is_c_interoperable(): gfc_simplify_expr failed"
 msgstr ""
 
-#: fortran/check.c:4603
+#: fortran/check.c:4606
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be an interoperable data entity: %s"
 msgstr "『%s』引數的『%s』intrinsic 於 %L 必須是可交流的資料個體"
 
-#: fortran/check.c:4642
+#: fortran/check.c:4645
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_1 at %L to C_ASSOCIATED shall have the type TYPE(C_PTR) or TYPE(C_FUNPTR)"
 msgstr ""
 
-#: fortran/check.c:4656
+#: fortran/check.c:4659
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_2 at %L to C_ASSOCIATED shall have the same type as C_PTR_1: %s instead of %s"
 msgstr ""
 
-#: fortran/check.c:4680
+#: fortran/check.c:4683
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_POINTER shall have the type TYPE(C_PTR)"
 msgstr ""
 
-#: fortran/check.c:4692
+#: fortran/check.c:4695
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER must be a pointer"
 msgstr "實際引數到『%s』於 %L 必須是 polymorphic"
 
-#: fortran/check.c:4699
+#: fortran/check.c:4702
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FPTR argument at %L to C_F_POINTER shall not be polymorphic"
 msgstr "實際引數到『%s』於 %L 必須是 polymorphic"
 
-#: fortran/check.c:4706
+#: fortran/check.c:4709
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER shall not be coindexed"
 msgstr "實際引數到『%s』於 %L 必須是 polymorphic"
 
-#: fortran/check.c:4713
+#: fortran/check.c:4716
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected SHAPE argument at %L to C_F_POINTER with scalar FPTR"
 msgstr ""
 
-#: fortran/check.c:4719
+#: fortran/check.c:4722
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected SHAPE argument to C_F_POINTER with array FPTR at %L"
 msgstr ""
 
-#: fortran/check.c:4738
+#: fortran/check.c:4741
 #, gcc-internal-format, gfc-internal-format
 msgid "SHAPE argument at %L to C_F_POINTER must have the same size as the RANK of FPTR"
 msgstr ""
 
-#: fortran/check.c:4748
+#: fortran/check.c:4751
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic FPTR at %L to C_F_POINTER"
 msgstr ""
 
-#: fortran/check.c:4753
+#: fortran/check.c:4756
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array FPTR at %L to C_F_POINTER: %s"
 msgstr ""
 
-#: fortran/check.c:4769
+#: fortran/check.c:4772
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_PROCPOINTER shall have the type TYPE(C_FUNPTR)"
 msgstr ""
 
-#: fortran/check.c:4781
+#: fortran/check.c:4784
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall be a procedure pointer"
 msgstr "實際引數到『%s』於 %L 必須是 polymorphic"
 
-#: fortran/check.c:4788
+#: fortran/check.c:4791
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall not be coindexed"
 msgstr "實際引數到『%s』於 %L 必須是 polymorphic"
 
-#: fortran/check.c:4794
+#: fortran/check.c:4797
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure pointer at %L to C_F_PROCPOINTER"
 msgstr ""
 
-#: fortran/check.c:4808
+#: fortran/check.c:4811
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall not be coindexed"
 msgstr "『%s』引數的『%s』intrinsic 於 %L 不應該被 coindexed"
 
-#: fortran/check.c:4823
+#: fortran/check.c:4826
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L is invalid as X argument to C_FUNLOC"
 msgstr "敘述函式『%s』無效在中程序指標指派於 %L"
 
-#: fortran/check.c:4831
+#: fortran/check.c:4834
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall be a procedure or a procedure pointer"
 msgstr ""
 
-#: fortran/check.c:4837
+#: fortran/check.c:4840
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure at %L to C_FUNLOC"
 msgstr "缺少引數「%s」，在呼叫「%s」時，位於 %L"
 
-#: fortran/check.c:4851
+#: fortran/check.c:4854
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall not be coindexed"
 msgstr "『%s』引數的『%s』intrinsic 於 %L 不應該被 coindexed"
 
-#: fortran/check.c:4857
+#: fortran/check.c:4860
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "X argument at %L to C_LOC shall not be polymorphic"
 msgstr "實際引數到『%s』於 %L 必須是 polymorphic"
 
-#: fortran/check.c:4868
+#: fortran/check.c:4871
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Component at %C must have the POINTER attribute"
 msgid "Argument X at %L to C_LOC shall have either the POINTER or the TARGET attribute"
 msgstr "%C 處的元件必須有 POINTER 屬性"
 
-#: fortran/check.c:4876
+#: fortran/check.c:4879
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall be not be a zero-sized string"
 msgstr "引數『S』的最近的於 %L 不應該是零"
 
-#: fortran/check.c:4885
+#: fortran/check.c:4888
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument at %L to C_LOC shall not be polymorphic"
 msgstr "實際引數到『%s』於 %L 必須是 polymorphic"
 
-#: fortran/check.c:4892
+#: fortran/check.c:4895
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array at %L as argument to C_LOC: %s"
 msgstr "缺少引數「%s」，在呼叫「%s」時，位於 %L"
 
-#: fortran/check.c:4903
+#: fortran/check.c:4906
 #, gcc-internal-format, gfc-internal-format
 msgid "Array of interoperable type at %L to C_LOC which is nonallocatable and neither assumed size nor explicit size"
 msgstr ""
 
-#: fortran/check.c:4908
+#: fortran/check.c:4911
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array section at %L to C_LOC"
 msgstr "陣列區段在中『%s』呼叫於 %L"
 
-#: fortran/check.c:4936
+#: fortran/check.c:4939
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "non double precision REAL argument to %s intrinsic at %L"
 msgstr "GNU 延伸：非雙倍精度真實引數到 %s intrinsic 於 %L"
 
-#: fortran/check.c:4949
+#: fortran/check.c:4952
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be less than rank %d"
 msgid "%qs argument of %qs intrinsic at %L must be less than rank %d"
 msgstr "引數「%s」(屬於內建函式「%s」，位於 %L)秩必須小於 %d"
 
-#: fortran/check.c:4968
+#: fortran/check.c:4971
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L is not a valid dimension index"
 msgstr "『%s』引數的『%s』intrinsic 於 %L 並非有效尺寸索引"
 
-#: fortran/check.c:5231
+#: fortran/check.c:5234
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s argument to IMAGE_INDEX must be a rank one array at %L"
 msgstr "%s 引數到 IMAGE_INDEX 必須是分級一個陣列於 %L"
 
-#: fortran/check.c:5242
+#: fortran/check.c:5245
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The number of array elements of the SUB argument to IMAGE_INDEX at %L shall be %d (corank) not %d"
 msgstr "陣列元素數量的子引數到 IMAGE_INDEX 於 %L 應該是 %d (corank) 無法 %d"
 
-#: fortran/check.c:5275
+#: fortran/check.c:5278
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to NUM_IMAGES at %L"
 msgstr ""
 
-#: fortran/check.c:5288
+#: fortran/check.c:5291
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FAILED= argument to NUM_IMAGES at %L"
 msgstr "鑄型引數到空值必要項於 %L"
 
-#: fortran/check.c:5312
+#: fortran/check.c:5315
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "TEAM argument at %L to the intrinsic TEAM_NUMBER shall be of type TEAM_TYPE"
 msgstr "原子引數於 %L 的 %s 內建函式應該是 coarray 或 coindexed"
 
-#: fortran/check.c:5338
+#: fortran/check.c:5341
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DIM argument without COARRAY argument not allowed for THIS_IMAGE intrinsic at %L"
 msgstr "DIM 引數而無需陣列引數不允許用於 THIS_IMAGE intrinsic 於 %L"
 
-#: fortran/check.c:5345
+#: fortran/check.c:5348
 #, gcc-internal-format, gfc-internal-format
 msgid "The DISTANCE argument may not be specified together with the COARRAY or DIM argument in intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:5356
+#: fortran/check.c:5359
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk in formal argument list at %C"
 msgid "Unexpected DIM argument with noncoarray argument at %L"
 msgstr "%C 處參數清單中有非預期的無用字元"
 
-#: fortran/check.c:5374
+#: fortran/check.c:5377
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to THIS_IMAGE at %L"
 msgstr ""
 
-#: fortran/check.c:5454
+#: fortran/check.c:5457
 #, fuzzy, gcc-internal-format
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L must not be %s"
 msgstr "『鑄型』引數的『轉送』intrinsic 於 %L 必須不是 %s"
 
-#: fortran/check.c:5483
+#: fortran/check.c:5486
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic TRANSFER at %L has partly undefined result: source size %ld < result size %ld"
 msgstr "Intrinsic 轉送於 %L 有部分未定義的結果：來源大小 %ld<結果大小 %ld"
 
-#: fortran/check.c:5605
+#: fortran/check.c:5608
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must have the same rank as %qs or be a scalar"
 msgstr "『%s』引數的『%s』intrinsic 於 %L 必須有同級做為『%s』或是純量"
 
-#: fortran/check.c:5618
+#: fortran/check.c:5621
 #, fuzzy, gcc-internal-format
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have identical shape."
 msgstr "『%s』和『%s』引數的『%s』intrinsic 於 %L 必須有相等的形狀。"
 
-#: fortran/check.c:5861 fortran/check.c:5893
+#: fortran/check.c:5864 fortran/check.c:5896
 #, fuzzy, gcc-internal-format
 msgid "Size of %qs argument of %qs intrinsic at %L too small (%i/%i)"
 msgstr "大小的『%s』引數的『%s』intrinsic 於 %L 太小 (%i/%i)"
 
-#: fortran/check.c:5901
+#: fortran/check.c:5904
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many arguments to %s at %L"
 msgstr "給予函式 %s 的參數太多，於 %L"
 
-#: fortran/check.c:5919
+#: fortran/check.c:5922
 #, gcc-internal-format
 msgid "fe_runtime_error string must be null terminated"
 msgstr ""
 
-#: fortran/check.c:5931
+#: fortran/check.c:5934
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "fe_runtime_error: Wrong number of arguments (%d instead of %d)"
 msgstr "範本參數數目不正確(不應是 %d 個而應是 %d 個)"
 
-#: fortran/check.c:5971
+#: fortran/check.c:5974
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr "『%s』引數的『%s』intrinsic 於 %L 不應該被 coindexed"
 
-#: fortran/check.c:5990
+#: fortran/check.c:5993
 #, gcc-internal-format, gfc-internal-format
 msgid "Real COUNT_RATE argument to SYSTEM_CLOCK at %L"
 msgstr ""
 
-#: fortran/check.c:6000
+#: fortran/check.c:6003
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "COUNT_RATE argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr "『%s』引數的『%s』intrinsic 於 %L 不應該被 coindexed"
 
-#: fortran/check.c:6017
+#: fortran/check.c:6020
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "COUNT_MAX argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr "『%s』引數的『%s』intrinsic 於 %L 不應該被 coindexed"
 
-#: fortran/check.c:6234
+#: fortran/check.c:6237
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of a kind not wider than the default kind (%d)"
 msgstr "『%s』引數的『%s』intrinsic 於 %L 必須是的 kind 無法 wider 比預設 kind (%d)"
 
-#: fortran/check.c:6586 fortran/check.c:6594
+#: fortran/check.c:6589 fortran/check.c:6597
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be INTEGER or LOGICAL"
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or LOGICAL"
 msgstr "引數「%s」(屬於內建函式「%s」，位於 %L)必須為 INTEGER 或 LOGICAL"
 
-#: fortran/check.c:6625
+#: fortran/check.c:6628
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic function NULL at %L cannot be an actual argument to STORAGE_SIZE, because it returns a disassociated pointer"
 msgstr ""
@@ -55020,7 +55084,7 @@
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:727 fortran/decl.c:3636 fortran/decl.c:10066
+#: fortran/class.c:727 fortran/decl.c:3655 fortran/decl.c:10091
 #, fuzzy, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr "最大值延伸等級達到的與型態『%s』於 %L"
@@ -55045,42 +55109,47 @@
 msgid "non-constant array in DATA statement %L"
 msgstr "non-constant 陣列在中資料敘述 %L"
 
-#: fortran/data.c:137
+#: fortran/data.c:140
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "failure to simplify substring reference in DATA statement at %L"
 msgstr "簡化子字串參考在中資料敘述於 %L 時失敗"
 
-#: fortran/data.c:170
+#: fortran/data.c:173
 #, gcc-internal-format, gfc-internal-format
 msgid "Unused initialization string at %L because variable has zero length"
 msgstr ""
 
-#: fortran/data.c:176
+#: fortran/data.c:179
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Initialization string at %L was truncated to fit the variable (%ld/%ld)"
 msgstr "初始化字串開始於 %L 被截短至符合變數 (%d/%d)"
 
-#: fortran/data.c:265
+#: fortran/data.c:268
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L already is initialized at %L"
 msgstr "『%s』於 %L 已經被初始化的於 %L"
 
-#: fortran/data.c:289
+#: fortran/data.c:292
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data element below array lower bound at %L"
 msgstr "資料元素下列的陣列下限於 %L"
 
-#: fortran/data.c:306 fortran/data.c:395
+#: fortran/data.c:309 fortran/data.c:398
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data element above array upper bound at %L"
 msgstr "資料元素以上的陣列上限於 %L"
 
-#: fortran/data.c:336 fortran/data.c:505
+#: fortran/data.c:339 fortran/data.c:496
 #, fuzzy, gcc-internal-format
 msgid "re-initialization of %qs at %L"
 msgstr "擴充：「%s」重初始化於 %L"
 
-#: fortran/data.c:727
+#: fortran/data.c:515
+#, fuzzy, gcc-internal-format
+msgid "Nonpointer object %qs with default initialization shall not appear in a DATA statement at %L"
+msgstr "變數『%s』於 %C 與初始設定式已經出現在中資料敘述"
+
+#: fortran/data.c:738
 #, gcc-internal-format
 msgid "TODO: Vector sections in data statements"
 msgstr ""
@@ -55106,804 +55175,803 @@
 msgid "Invalid initializer %s in Data statement at %C"
 msgstr "無效的初始設定式 %s 在中資料敘述於 %C"
 
-#: fortran/decl.c:536
+#: fortran/decl.c:537
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C is not allowed in a PURE procedure"
 msgstr "初始化不允許出現在 %C 處的 PURE 程序中"
 
-#: fortran/decl.c:573
+#: fortran/decl.c:574
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgid "DATA statement at %C cannot appear within an INTERFACE"
 msgstr "%C 處的 ENTRY 敘述不能出現在 INTERFACE 中"
 
-#: fortran/decl.c:597
+#: fortran/decl.c:598
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid substring in data-implied-do at %L in DATA statement"
 msgstr "無效的初始設定式 %s 在中資料敘述於 %C"
 
-#: fortran/decl.c:619
+#: fortran/decl.c:620
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %C is not allowed in a PURE procedure"
 msgstr "DATA 敘述不允許出現在 %C 處的 PURE 程序中"
 
-#: fortran/decl.c:664
+#: fortran/decl.c:662
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Empty old style initializer list at %C"
 msgstr "擴充：%C 處舊式的初始化"
 
-#: fortran/decl.c:684
+#: fortran/decl.c:671
 #, fuzzy, gcc-internal-format, gfc-internal-format
+msgid "Array in initializer list at %L must have an explicit shape"
+msgstr "陣列成分的結構於 %C 必須有明確的形狀"
+
+#: fortran/decl.c:694
+#, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "extra elements in scalar initializer"
 msgid "Repeat spec invalid in scalar initializer at %C"
 msgstr "標量初始化設定中有多餘元素"
 
-#: fortran/decl.c:689
+#: fortran/decl.c:699
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Repeat spec must be an integer at %C"
 msgstr "Cray 指標於 %C 必須是整數"
 
-#: fortran/decl.c:698
+#: fortran/decl.c:710
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected alternate return label at %C"
 msgid "Expected data constant after repeat spec at %C"
 msgstr "%C 處需要替代的回傳標籤"
 
-#: fortran/decl.c:729
+#: fortran/decl.c:742
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected scalar initialization expression at %C"
 msgid "End of scalar initializer expected at %C"
 msgstr "%C 處需要標量初始化運算式"
 
-#: fortran/decl.c:758
+#: fortran/decl.c:773
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "nonconstant array index in initializer"
-msgid "Expected constant array-spec in initializer list at %L"
-msgstr "初始值設定中陣列索引不是常數"
-
-#: fortran/decl.c:767
-#, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "excess elements in array initializer"
 msgid "Not enough elements in array initializer at %C"
 msgstr "陣列初始值設定項中有多餘的元素"
 
-#: fortran/decl.c:769
+#: fortran/decl.c:775
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "excess elements in array initializer"
 msgid "Too many elements in array initializer at %C"
 msgstr "陣列初始值設定項中有多餘的元素"
 
-#: fortran/decl.c:790
+#: fortran/decl.c:795
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in old style initializer list at %C"
 msgstr "語法時發生錯誤 OpenMP 變數清單於 %C"
 
-#: fortran/decl.c:812
+#: fortran/decl.c:821
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The assumed-rank array at %C shall not have a codimension"
 msgstr "資料目標於 %L 不應該有 coindex"
 
-#: fortran/decl.c:876
+#: fortran/decl.c:885
 #, gcc-internal-format, gfc-internal-format
 msgid "Sum of array rank %d and corank %d at %C exceeds maximum allowed dimensions of %d"
 msgstr ""
 
-#: fortran/decl.c:900
+#: fortran/decl.c:909
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad INTENT specification at %C"
 msgstr "%C 處錯誤地指定 INTENT"
 
-#: fortran/decl.c:921
+#: fortran/decl.c:930
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "deferred type parameter at %C"
 msgstr "Fortran 2003:已推遲型態參數於 %C"
 
-#: fortran/decl.c:1004 fortran/resolve.c:11705
+#: fortran/decl.c:1013 fortran/resolve.c:11725
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
 
-#: fortran/decl.c:1030
+#: fortran/decl.c:1039
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Old-style character length at %C"
 msgstr "Obsolescent 特徵：舊式字元長度於 %C"
 
-#: fortran/decl.c:1061
+#: fortran/decl.c:1070
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in character length specification at %C"
 msgstr "%C 處指定字元長度時語法錯誤"
 
-#: fortran/decl.c:1212 fortran/decl.c:1217 fortran/decl.c:1266
+#: fortran/decl.c:1221 fortran/decl.c:1226 fortran/decl.c:1275
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %C is already defined at %L"
 msgid "Procedure %qs at %C is already defined at %L"
 msgstr "程序「%s」在 %C 處已經於 %L 處被宣告"
 
-#: fortran/decl.c:1222
+#: fortran/decl.c:1231
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %C is already defined at %L"
 msgid "Contained procedure %qs at %C clashes with procedure defined at %L"
 msgstr "程序「%s」在 %C 處已經於 %L 處被宣告"
 
-#: fortran/decl.c:1231
+#: fortran/decl.c:1240
 #, fuzzy, gcc-internal-format
 msgid "Name %qs at %C is already defined as a generic interface at %L"
 msgstr "名稱『%s』於 %C 已經定義為通用介面於 %L"
 
-#: fortran/decl.c:1244
+#: fortran/decl.c:1253
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %C has an explicit interface and must not have attributes declared at %L"
 msgid "Procedure %qs at %C has an explicit interface from a previous declaration"
 msgstr "程序「%s」在 %C 處具有顯式介面，而且必須在 %L 處不具有已宣告的屬性"
 
-#: fortran/decl.c:1257
+#: fortran/decl.c:1266
 #, gcc-internal-format
 msgid "Procedure %qs defined in interface body at %L clashes with internal procedure defined at %C"
 msgstr ""
 
-#: fortran/decl.c:1335
+#: fortran/decl.c:1344
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L must have the BIND(C) attribute to be C interoperable"
 msgstr "程序『%s』於 %L 必須有繫結©屬性為 C 可交流的"
 
-#: fortran/decl.c:1362
+#: fortran/decl.c:1371
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because derived type %qs is not C interoperable"
 msgstr "變數『%s』於 %L 是虛引數到繫結©程序『%s』但是不是 C 可交流的因為衍生類型『%s』不是 C 可交流的"
 
-#: fortran/decl.c:1369
+#: fortran/decl.c:1378
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because it is polymorphic"
 msgstr "變數『%s』於 %L 是虛引數到繫結©程序『%s』但是不是 C 可交流的因為它是 polymorphic"
 
-#: fortran/decl.c:1376
+#: fortran/decl.c:1385
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument of the BIND(C) procedure %qs but may not be C interoperable"
 msgstr "變數『%s』於 %L 是參數到繫結©程序『%s』但是可能無法是 C 可交流的"
 
-#: fortran/decl.c:1391
+#: fortran/decl.c:1400
 #, fuzzy, gcc-internal-format
 msgid "Character argument %qs at %L must be length 1 because procedure %qs is BIND(C)"
 msgstr "字元引數『%s』於 %L 必須是長度 1 因為程序『%s』是繫結©"
 
-#: fortran/decl.c:1404
+#: fortran/decl.c:1413
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L with ALLOCATABLE attribute in procedure %qs with BIND(C)"
 msgstr "TS29113:變數『%s』於 %L 與可選的屬性在中程序『%s』該項是繫結©"
 
-#: fortran/decl.c:1412
+#: fortran/decl.c:1421
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L with POINTER attribute in procedure %qs with BIND(C)"
 msgstr "TS29113:變數『%s』於 %L 與可選的屬性在中程序『%s』該項是繫結©"
 
-#: fortran/decl.c:1421
+#: fortran/decl.c:1430
 #, fuzzy, gcc-internal-format
 msgid "Scalar variable %qs at %L with POINTER or ALLOCATABLE in procedure %qs with BIND(C) is not yet supported"
 msgstr "TS29113:變數『%s』於 %L 與可選的屬性在中程序『%s』該項是繫結©"
 
-#: fortran/decl.c:1430
+#: fortran/decl.c:1439
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the OPTIONAL and the VALUE attribute because procedure %qs is BIND(C)"
 msgstr "變數『%s』於 %L 無法同時有可選的和值屬性因為程序『%s』是繫結©"
 
-#: fortran/decl.c:1437
+#: fortran/decl.c:1446
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L with OPTIONAL attribute in procedure %qs which is BIND(C)"
 msgstr "TS29113:變數『%s』於 %L 與可選的屬性在中程序『%s』該項是繫結©"
 
-#: fortran/decl.c:1448
+#: fortran/decl.c:1457
 #, fuzzy, gcc-internal-format
 msgid "Assumed-shape array %qs at %L as dummy argument to the BIND(C) procedure %qs at %L"
 msgstr "Assumed-shape 陣列『%s』於 %L 無法引數到程序『%s』於 %L 因為程序是繫結©"
 
-#: fortran/decl.c:1516
+#: fortran/decl.c:1525
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L already has basic type of %s"
 msgid "Symbol %qs at %C also declared as a type at %L"
 msgstr "符號「%s」在 %L 處已經有了基本類型 %s"
 
-#: fortran/decl.c:1575
+#: fortran/decl.c:1584
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs in common block %qs at %C must be declared with a C interoperable kind since common block %qs is BIND(C)"
 msgstr "變數『%s』在中共同區塊『%s』於 %C 必須被宣告與 C 可交流的 kind 自從共同區塊『%s』是繫結©"
 
-#: fortran/decl.c:1615
+#: fortran/decl.c:1624
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER length must be a constant at %L"
 msgstr "引數必須是常數"
 
-#: fortran/decl.c:1630
+#: fortran/decl.c:1639
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression at %L is being truncated (%ld/%ld)"
 msgstr "字元運算式於 %L 正在被截斷 (%d/%d)"
 
-#: fortran/decl.c:1638
+#: fortran/decl.c:1647
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The CHARACTER elements of the array constructor at %L must have the same length (%ld/%ld)"
 msgstr "字元元件的陣列建構子於 %L 必須有相同長度 (%d/%d)"
 
-#: fortran/decl.c:1729
+#: fortran/decl.c:1738
 #, fuzzy, gcc-internal-format
 #| msgid "Initializer not allowed for PARAMETER '%s' at %C"
 msgid "Initializer not allowed for PARAMETER %qs at %C"
 msgstr "PARAMETER「%s」在 %C 處不允許有初始值設定"
 
-#: fortran/decl.c:1739
+#: fortran/decl.c:1748
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER at %L is missing an initializer"
 msgstr "%L 處 PARAMETER 缺少初始值設定"
 
-#: fortran/decl.c:1749
+#: fortran/decl.c:1758
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %C with an initializer already appears in a DATA statement"
 msgstr "變數『%s』於 %C 與初始設定式已經出現在中資料敘述"
 
-#: fortran/decl.c:1792
+#: fortran/decl.c:1801
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cannot initialize parameter array at %L with variable length elements"
 msgstr "無法初始化 implied-shape 陣列於 %L 與純量"
 
-#: fortran/decl.c:1861
+#: fortran/decl.c:1870
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Can't initialize implied-shape array at %L with scalar"
 msgstr "無法初始化 implied-shape 陣列於 %L 與純量"
 
-#: fortran/decl.c:1896
+#: fortran/decl.c:1905
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-constant lower bound in implied-shape declaration at %L"
 msgstr "Non-constant 下限在中 implied-shape 宣告於 %L"
 
-#: fortran/decl.c:1982 fortran/decl.c:1989
+#: fortran/decl.c:1991 fortran/decl.c:1998
 #, gcc-internal-format, gfc-internal-format
 msgid "Component at %C must have the POINTER attribute"
 msgstr "%C 處的元件必須有 POINTER 屬性"
 
-#: fortran/decl.c:1998
+#: fortran/decl.c:2007
 #, fuzzy, gcc-internal-format
 msgid "Component %qs with CLASS at %C must be allocatable or pointer"
 msgstr "成分『%s』與類別於 %L 必須是 allocatable 或指標"
 
-#: fortran/decl.c:2007
+#: fortran/decl.c:2016
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr "陣列成分的結構於 %C 必須有明確的或已推遲形狀"
 
-#: fortran/decl.c:2031 fortran/symbol.c:2230
+#: fortran/decl.c:2040 fortran/symbol.c:2244
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C already declared at %L"
 msgid "Component %qs at %C already declared at %L"
 msgstr "元件「%s」在 %C 處已經於 %L 處被宣告"
 
-#: fortran/decl.c:2079
+#: fortran/decl.c:2088
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer array component of structure at %C must have a deferred shape"
 msgstr "指標陣列成分的結構於 %C 必須有已推遲形狀"
 
-#: fortran/decl.c:2088
+#: fortran/decl.c:2097
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component of structure at %C must have a deferred shape"
 msgstr "Allocatable 成分的結構於 %C 必須有已推遲形狀"
 
-#: fortran/decl.c:2097
+#: fortran/decl.c:2106
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have an explicit shape"
 msgstr "陣列成分的結構於 %C 必須有明確的形狀"
 
-#: fortran/decl.c:2114
+#: fortran/decl.c:2123
 #, fuzzy, gcc-internal-format
 #| msgid "a parameter list with an ellipsis can%'t match an empty parameter name list declaration"
 msgid "Type parameter %qs at %C has no corresponding entry in the type parameter name list at %L"
 msgstr "帶有省略號的參數清單無法與空參數名清單宣告匹配"
 
-#: fortran/decl.c:2171
+#: fortran/decl.c:2180
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C is ambiguous"
 msgstr "%C 處的 NULL() 初始化有歧義"
 
-#: fortran/decl.c:2188
+#: fortran/decl.c:2197
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C may not have MOLD"
 msgstr "%C 處的 NULL() 初始化有歧義"
 
-#: fortran/decl.c:2205
+#: fortran/decl.c:2214
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of pointer at %C is not allowed in a PURE procedure"
 msgstr "%C 處對指標的初始化不允許出現在 PURE 程序中"
 
-#: fortran/decl.c:2226
+#: fortran/decl.c:2235
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Error in pointer initialization at %C"
 msgstr "在中指標初始化於 %C 時發生錯誤"
 
-#: fortran/decl.c:2233
+#: fortran/decl.c:2242
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "non-NULL pointer initialization at %C"
 msgstr "Fortran 2008:non-NULL 指標初始化於 %C"
 
-#: fortran/decl.c:2256
+#: fortran/decl.c:2265
 #, gcc-internal-format
 msgid "RESULT variable %qs at %L prohibits FUNCTION name %qs at %C from appearing in a specification statement"
 msgstr ""
 
-#: fortran/decl.c:2318
+#: fortran/decl.c:2327
 #, fuzzy, gcc-internal-format
 msgid "%qs not allowed outside STRUCTURE at %C"
 msgstr "值未被允許內部的區塊於 %C"
 
-#: fortran/decl.c:2320
+#: fortran/decl.c:2329
 #, gcc-internal-format
 msgid "%qs at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr ""
 
-#: fortran/decl.c:2327
+#: fortran/decl.c:2336
 #, fuzzy, gcc-internal-format
 #| msgid "Enumerator cannot have attributes %C"
 msgid "%qs entity cannot have attributes at %C"
 msgstr "列舉量不能有屬性 %C"
 
-#: fortran/decl.c:2367
+#: fortran/decl.c:2376
 #, fuzzy, gcc-internal-format
 msgid "Non-PARAMETER symbol %qs at %L can't be implied-shape"
 msgstr "Non-PARAMETER 符號『%s』於 %L 無法 implied-shape"
 
-#: fortran/decl.c:2377
+#: fortran/decl.c:2386
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Implied-shape array at %L"
 msgstr "Fortran 2008:Implied-shape 陣列於 %L"
 
-#: fortran/decl.c:2422
+#: fortran/decl.c:2431
 #, gcc-internal-format, gfc-internal-format
 msgid "Explicit shaped array with nonconstant bounds at %C"
 msgstr ""
 
-#: fortran/decl.c:2501
+#: fortran/decl.c:2510
 #, gcc-internal-format
 msgid "%qs at %C is a redefinition of the declaration in the corresponding interface for MODULE PROCEDURE %qs"
 msgstr ""
 
-#: fortran/decl.c:2512
+#: fortran/decl.c:2521
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "%qs entity cannot have an initializer at %C"
 msgstr "啞元「%s」在 %L 處不能有初始值設定"
 
-#: fortran/decl.c:2538 fortran/decl.c:8369
+#: fortran/decl.c:2547 fortran/decl.c:8388
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr "重製陣列 spec 用於 Cray 點於 %C"
 
-#: fortran/decl.c:2546
+#: fortran/decl.c:2555
 #, gcc-internal-format
 msgid "Couldn't set pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:2609
+#: fortran/decl.c:2618
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Old-style initialization at %C"
 msgstr "擴充：%C 處舊式的初始化"
 
-#: fortran/decl.c:2617
+#: fortran/decl.c:2626
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr "無效的 value-initialization 的參考類型"
 
-#: fortran/decl.c:2630
+#: fortran/decl.c:2639
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in old style initialization of %s at %C"
 msgstr "在中指標初始化於 %C 時發生錯誤"
 
-#: fortran/decl.c:2650 fortran/decl.c:6661
+#: fortran/decl.c:2659 fortran/decl.c:6680
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr "%C 的初始化不是為指標變數準備的"
 
-#: fortran/decl.c:2663
+#: fortran/decl.c:2672
 #, fuzzy, gcc-internal-format
 #| msgid "Pointer initialization at %C requires '=>', not '='"
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr "在 %C 處的指標初始化需要「=>」，而不是「=」"
 
-#: fortran/decl.c:2672 fortran/decl.c:10240
+#: fortran/decl.c:2681 fortran/decl.c:10265
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr "%C 處需要一個初始化運算式"
 
-#: fortran/decl.c:2679
+#: fortran/decl.c:2688
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr "%C 處對變數的初始化不允許出現在 PURE 程序中"
 
-#: fortran/decl.c:2696
+#: fortran/decl.c:2705
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr "初始化的 allocatable 成分於 %C 未被允許"
 
-#: fortran/decl.c:2710
+#: fortran/decl.c:2719
 #, gcc-internal-format, gfc-internal-format
 msgid "The component with KIND or LEN attribute at %C does not not appear in the type parameter list at %L"
 msgstr ""
 
-#: fortran/decl.c:2718
+#: fortran/decl.c:2727
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C that appears in the type parameter list at %L has neither the KIND nor LEN attribute"
 msgstr ""
 
-#: fortran/decl.c:2726
+#: fortran/decl.c:2735
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The component at %C which is a type parameter must be a scalar"
 msgstr "指標成分『%s』的『%s』於 %L 是型態該未被宣告"
 
-#: fortran/decl.c:2789 fortran/decl.c:2825
+#: fortran/decl.c:2798 fortran/decl.c:2834
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr "舊式的型態宣告 %s*%d 在 %C 處不被支援"
 
-#: fortran/decl.c:2831
+#: fortran/decl.c:2840
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr "Nonstandard 類型宣告 %s*%d 於 %C"
 
-#: fortran/decl.c:2890 fortran/decl.c:2967
+#: fortran/decl.c:2899 fortran/decl.c:2976
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis at %C"
 msgstr "缺少右括號於 %C"
 
-#: fortran/decl.c:2903 fortran/decl.c:3038
+#: fortran/decl.c:2912 fortran/decl.c:3047
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr "%C 處需要初始化運算式"
 
-#: fortran/decl.c:2911 fortran/decl.c:3044
+#: fortran/decl.c:2920 fortran/decl.c:3053
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr "%C 處需要標量初始化運算式"
 
-#: fortran/decl.c:2941 fortran/decl.c:3657
+#: fortran/decl.c:2950 fortran/decl.c:3676
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr "Kind %d 不支援用於型態 %s 於 %C"
 
-#: fortran/decl.c:2954
+#: fortran/decl.c:2963
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr "C kind 型態參數是用於型態 %s 但是型態於 %L 是 %s"
 
-#: fortran/decl.c:2965
+#: fortran/decl.c:2974
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr "缺少右括號或逗號於 %C"
 
-#: fortran/decl.c:3070
+#: fortran/decl.c:3079
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr "Kind %d 未被支援用於字元於 %C"
 
-#: fortran/decl.c:3202
+#: fortran/decl.c:3211
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr "%C 的 CHARACTER 宣告語法錯誤"
 
-#: fortran/decl.c:3291
+#: fortran/decl.c:3310
 #, gcc-internal-format, gfc-internal-format
 msgid "RECORD at %C is an extension, enable it with -fdec-structure"
 msgstr ""
 
-#: fortran/decl.c:3304
+#: fortran/decl.c:3323
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected after RECORD at %C"
 msgstr "Interface-name 預期的之後『(』於 %C"
 
-#: fortran/decl.c:3417
+#: fortran/decl.c:3436
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C cannot contain both ASSUMED and DEFERRED parameters"
 msgstr ""
 
-#: fortran/decl.c:3441
+#: fortran/decl.c:3460
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C does not contain enough parameter expressions"
 msgstr "Kind 型態參數用於實體於 %L 不同從 kind 型態參數的 typespec"
 
-#: fortran/decl.c:3465
+#: fortran/decl.c:3484
 #, fuzzy, gcc-internal-format
 msgid "The derived parameter %qs at %C does not have a default value"
 msgstr "第一個參數的 %<operator new%> 無法有預設引數"
 
-#: fortran/decl.c:3497
+#: fortran/decl.c:3516
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The parameter expression at %C must be of INTEGER type and not %s type"
 msgstr "運算式於 %L 必須是的整數類型，找到 %s"
 
-#: fortran/decl.c:3525
+#: fortran/decl.c:3544
 #, gcc-internal-format
 msgid "The KIND parameter %qs at %C cannot either be ASSUMED or DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:3532
+#: fortran/decl.c:3551
 #, fuzzy, gcc-internal-format
 msgid "The value for the KIND parameter %qs at %C does not reduce to a constant expression"
 msgstr "值的 %qD 不是可用在中常數運算式"
 
-#: fortran/decl.c:3547
+#: fortran/decl.c:3566
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C contains too many parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3556
+#: fortran/decl.c:3575
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "reference to %qD is ambiguous"
 msgid "Parameterized derived type at %C is ambiguous"
 msgstr "對 %qD 的參照有歧義"
 
-#: fortran/decl.c:3819
+#: fortran/decl.c:3838
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BYTE type at %C"
 msgstr "擴充：%C 處的 BYTE 類型"
 
-#: fortran/decl.c:3824
+#: fortran/decl.c:3843
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr "%C 使用到的 BYTE 類型在目標平臺上不可"
 
-#: fortran/decl.c:3846
+#: fortran/decl.c:3865
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C is not allowed for components"
 msgstr "By-value 引數於 %L 未被允許在中這個語境"
 
-#: fortran/decl.c:3849
+#: fortran/decl.c:3868
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr ""
 
-#: fortran/decl.c:3872 fortran/decl.c:3903 fortran/decl.c:3932
-#: fortran/decl.c:4216
+#: fortran/decl.c:3891 fortran/decl.c:3922 fortran/decl.c:3951
+#: fortran/decl.c:4235
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr "Fortran 2008:型態與 intrinsic-type-spec 於 %C"
 
-#: fortran/decl.c:3928
+#: fortran/decl.c:3947
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr "延伸：雙倍複雜於 %C"
 
-#: fortran/decl.c:3971 fortran/decl.c:4107 fortran/decl.c:4119
-#: fortran/decl.c:4133 fortran/decl.c:4611 fortran/decl.c:4619
+#: fortran/decl.c:3990 fortran/decl.c:4126 fortran/decl.c:4138
+#: fortran/decl.c:4152 fortran/decl.c:4630 fortran/decl.c:4638
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C is ambiguous"
 msgid "Type name %qs at %C is ambiguous"
 msgstr "類型名「%s」(於 %C 處)有歧義"
 
-#: fortran/decl.c:4066
+#: fortran/decl.c:4085
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CLASS statement at %C"
 msgstr "Fortran 2003:類別敘述於 %C"
 
-#: fortran/decl.c:4148
+#: fortran/decl.c:4167
 #, fuzzy, gcc-internal-format
 msgid "Type name %qs at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr "型態名稱『%s』於 %C 衝突與在之前宣告的實體於 %L, 該項有同名"
 
-#: fortran/decl.c:4287
+#: fortran/decl.c:4306
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr "%C 處 IMPLICIT NONE 敘述重複"
 
-#: fortran/decl.c:4296
+#: fortran/decl.c:4315
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr ""
 
-#: fortran/decl.c:4355
+#: fortran/decl.c:4374
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr "缺少字元範圍在中隱含的於 %C"
 
-#: fortran/decl.c:4401
+#: fortran/decl.c:4420
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr "%C 處 IMPLICIT 敘述中的字母必須按序排列"
 
-#: fortran/decl.c:4454
+#: fortran/decl.c:4473
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "SAVE statement at %C follows blanket SAVE statement"
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr "%C 處 SAVE 敘述跟隨空白 SAVE 敘述"
 
-#: fortran/decl.c:4464
+#: fortran/decl.c:4483
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr "%C IMPLICIT 敘述為空"
 
-#: fortran/decl.c:4570
+#: fortran/decl.c:4589
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr "匯入敘述於 %C 只有允許的在中介面內文"
 
-#: fortran/decl.c:4577
+#: fortran/decl.c:4596
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "F2008: C1210 IMPORT statement at %C is not permitted in a module procedure interface body"
 msgstr "匯入敘述於 %C 只有允許的在中介面內文"
 
-#: fortran/decl.c:4582
+#: fortran/decl.c:4601
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C"
 msgstr "%C IMPLICIT 敘述為空"
 
-#: fortran/decl.c:4596
+#: fortran/decl.c:4615
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr "預期具名的實體清單的於 %C"
 
-#: fortran/decl.c:4625
+#: fortran/decl.c:4644
 #, fuzzy, gcc-internal-format
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr "無法匯入『%s』從主機範圍單位於 %C - 不存在。"
 
-#: fortran/decl.c:4632
+#: fortran/decl.c:4651
 #, fuzzy, gcc-internal-format
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr "『%s』已經匯入的從主機範圍單位於 %C。"
 
-#: fortran/decl.c:4673
+#: fortran/decl.c:4692
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IMPORT statement at %C"
 msgstr "語法時發生錯誤匯入敘述於 %C"
 
-#: fortran/decl.c:5010
+#: fortran/decl.c:5029
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing codimension specification at %C"
 msgstr "缺少codimension 規格於 %C"
 
-#: fortran/decl.c:5012
+#: fortran/decl.c:5031
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr "%C 處沒有指定維數"
 
-#: fortran/decl.c:5107
+#: fortran/decl.c:5126
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr "重複的 %s 屬性，位於 %L"
 
-#: fortran/decl.c:5124
+#: fortran/decl.c:5143
 #, gcc-internal-format
 msgid "%s at %L is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:5141
+#: fortran/decl.c:5160
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr "Fortran 2003:ALLOCATABLE 屬性於 %C 在中類型定義"
 
-#: fortran/decl.c:5150
+#: fortran/decl.c:5169
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "KIND attribute at %C in a TYPE definition"
 msgstr "Fortran 2003:屬性 %s 於 %L 在中類型定義"
 
-#: fortran/decl.c:5158
+#: fortran/decl.c:5177
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be INTEGER"
 msgstr ""
 
-#: fortran/decl.c:5165
+#: fortran/decl.c:5184
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5174
+#: fortran/decl.c:5193
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LEN attribute at %C in a TYPE definition"
 msgstr "Fortran 2003:ALLOCATABLE 屬性於 %C 在中類型定義"
 
-#: fortran/decl.c:5182
+#: fortran/decl.c:5201
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be INTEGER"
 msgstr "成分在中型態於 %C 必須前繼含有"
 
-#: fortran/decl.c:5189
+#: fortran/decl.c:5208
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be default integer kind (%d)"
 msgstr "成分『%s』與類別於 %L 必須是 allocatable 或指標"
 
-#: fortran/decl.c:5198
+#: fortran/decl.c:5217
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr "屬性於 %L 未被允許在中類型定義"
 
-#: fortran/decl.c:5216
+#: fortran/decl.c:5235
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr "Fortran 2003:屬性 %s 於 %L 在中類型定義"
 
-#: fortran/decl.c:5226
+#: fortran/decl.c:5245
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr "%s 屬性於 %L 未被允許外側的規格部分的模組"
 
-#: fortran/decl.c:5236
+#: fortran/decl.c:5255
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed outside a TYPE definition"
 msgstr "屬性於 %L 未被允許在中類型定義"
 
-#: fortran/decl.c:5249
+#: fortran/decl.c:5268
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr "Fortran 2003:非同步屬性於 %C"
 
-#: fortran/decl.c:5260
+#: fortran/decl.c:5279
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr "Fortran 2008:CONTIGUOUS 屬性於 %C"
 
-#: fortran/decl.c:5315 fortran/decl.c:8673
+#: fortran/decl.c:5334 fortran/decl.c:8692
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr "保護的於 %C 只有允許的在中規格部分的模組"
 
-#: fortran/decl.c:5321
+#: fortran/decl.c:5340
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute at %C"
 msgstr "Fortran 2003:保護的屬性於 %C"
 
-#: fortran/decl.c:5355
+#: fortran/decl.c:5374
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VALUE attribute at %C"
 msgstr "Fortran 2003:值屬性於 %C"
 
-#: fortran/decl.c:5362
+#: fortran/decl.c:5381
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
 msgstr "Fortran 2003:易變的屬性於 %C"
 
-#: fortran/decl.c:5369
+#: fortran/decl.c:5388
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr ""
 
-#: fortran/decl.c:5410
+#: fortran/decl.c:5429
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr "多重識別碼提供的與單一名稱=說明符於 %C"
 
-#: fortran/decl.c:5508
+#: fortran/decl.c:5527
 #, fuzzy, gcc-internal-format
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr "隱含地宣告的繫結©函式『%s』於 %L 可能無法是 C 可交流的"
 
-#: fortran/decl.c:5530
+#: fortran/decl.c:5549
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr "變數『%s』在中共同區塊『%s』於 %L 可能無法是 C 可交流的 kind 雖然共同區塊『%s』是繫結©"
 
-#: fortran/decl.c:5539
+#: fortran/decl.c:5558
 #, fuzzy, gcc-internal-format
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr "類型宣告『%s』於 %L 不是 C 可交流的但是它是繫結©"
 
-#: fortran/decl.c:5543
+#: fortran/decl.c:5562
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr "變數『%s』於 %L 可能無法是 C 可交流的 kind 但是它是繫結©"
 
-#: fortran/decl.c:5555
+#: fortran/decl.c:5574
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr "變數『%s』在中共同區塊『%s』於 %L 無法宣告的與繫結©自從它並非全域"
 
-#: fortran/decl.c:5569
+#: fortran/decl.c:5588
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr "變數『%s』於 %L 無法同時有指標和繫結©屬性"
 
-#: fortran/decl.c:5577
+#: fortran/decl.c:5596
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr "變數『%s』於 %L 無法同時有 ALLOCATABLE 和繫結©屬性"
 
-#: fortran/decl.c:5589
+#: fortran/decl.c:5608
 #, fuzzy, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr "傳回類型的繫結©函式『%s』於 %L 無法陣列"
 
-#: fortran/decl.c:5597
+#: fortran/decl.c:5616
 #, fuzzy, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be a character string"
 msgstr "傳回類型的繫結©函式『%s』於 %L 無法字元串"
@@ -55910,974 +55978,979 @@
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:5608
+#: fortran/decl.c:5627
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr "符號『%s』於 %L 被標記私人的但是已被給定的繫結標貼『%s』"
 
-#: fortran/decl.c:5682
+#: fortran/decl.c:5701
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr "需要還是實體或共同區塊名稱用於屬性規格敘述於 %C"
 
-#: fortran/decl.c:5727
+#: fortran/decl.c:5746
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr "缺少實體或共同區塊名稱用於屬性規格敘述於 %C"
 
-#: fortran/decl.c:5734
+#: fortran/decl.c:5753
 #, fuzzy, gcc-internal-format
 #| msgid "missing number"
 msgid "Missing symbol"
 msgstr "缺少數字"
 
-#: fortran/decl.c:5763
+#: fortran/decl.c:5782
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) statement at %C"
 msgstr "Fortran 2008:同步敘述於 %C"
 
-#: fortran/decl.c:5850
+#: fortran/decl.c:5869
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr "衍生類型於 %C 未被在之前定義的和因而無法出現在中衍生類型定義"
 
-#: fortran/decl.c:5892
+#: fortran/decl.c:5911
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in data declaration at %C"
 msgid "Syntax error in anonymous structure declaration at %C"
 msgstr "%C 處資料宣告語法錯誤"
 
-#: fortran/decl.c:5901
+#: fortran/decl.c:5920
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr "%C 處資料宣告語法錯誤"
 
-#: fortran/decl.c:5951
+#: fortran/decl.c:5970
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C"
 msgstr "Fortran 2008:IMPURE 程序於 %C"
 
-#: fortran/decl.c:5996
+#: fortran/decl.c:6015
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IMPURE procedure at %C"
 msgstr "Fortran 2008:IMPURE 程序於 %C"
 
-#: fortran/decl.c:6008
+#: fortran/decl.c:6027
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr "PURE 和 IMPURE 必須不出現兩者於 %C"
 
-#: fortran/decl.c:6054
+#: fortran/decl.c:6073
 #, gcc-internal-format, gfc-internal-format
 msgid "ELEMENTAL prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6061
+#: fortran/decl.c:6080
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PURE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr "Fortran 2008:雙倍科郎在中模組程序敘述於 %L"
 
-#: fortran/decl.c:6068
+#: fortran/decl.c:6087
 #, gcc-internal-format, gfc-internal-format
 msgid "RECURSIVE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6134 fortran/primary.c:1820
+#: fortran/decl.c:6153 fortran/primary.c:1820
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected alternate return label at %C"
 msgid "Alternate-return argument at %C"
 msgstr "%C 處需要替代的回傳標籤"
 
-#: fortran/decl.c:6140 fortran/decl.c:6148
+#: fortran/decl.c:6159 fortran/decl.c:6167
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "A parameter name is required at %C"
 msgstr "參數名稱省略"
 
-#: fortran/decl.c:6188
+#: fortran/decl.c:6207
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is the name of the procedure"
 msgid "Name %qs at %C is the name of the procedure"
 msgstr "名稱「%s」(位於 %C)是一個程序的名稱"
 
-#: fortran/decl.c:6201
+#: fortran/decl.c:6220
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected another dimension in array declaration at %C"
 msgid "Expected parameter list in type declaration at %C"
 msgstr "%C 處陣列宣告需要另外一維"
 
-#: fortran/decl.c:6204
+#: fortran/decl.c:6223
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr "%C 處參數清單中有非預期的無用字元"
 
-#: fortran/decl.c:6222
+#: fortran/decl.c:6241
 #, fuzzy, gcc-internal-format
 msgid "Duplicate name %qs in parameter list at %C"
 msgstr "重製名稱『%s』在中關聯於 %C"
 
-#: fortran/decl.c:6225
+#: fortran/decl.c:6244
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate symbol '%s' in formal argument list at %C"
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr "符號「%s」在 %C 處的參數清單中重複出現"
 
-#: fortran/decl.c:6264
+#: fortran/decl.c:6283
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in MODULE PROCEDURE formal argument names (%s/%s) at %C"
 msgstr ""
 
-#: fortran/decl.c:6270
+#: fortran/decl.c:6289
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in number of MODULE PROCEDURE formal arguments at %C"
 msgstr "Fortran 2008:雙倍科郎在中模組程序敘述於 %L"
 
-#: fortran/decl.c:6309
+#: fortran/decl.c:6328
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr "%C 處 RESULT 變數不能與函式同名"
 
-#: fortran/decl.c:6386
+#: fortran/decl.c:6405
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr "%C 處的函式宣告後有非預期的無用字元"
 
-#: fortran/decl.c:6396 fortran/decl.c:7494
+#: fortran/decl.c:6415 fortran/decl.c:7513
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr "Fortran 2008:繫結©屬性於 %L 可能無法被指定的用於內部程序"
 
-#: fortran/decl.c:6600
+#: fortran/decl.c:6619
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr "繫結©屬性於 %C 需求介面與繫結©"
 
-#: fortran/decl.c:6607
+#: fortran/decl.c:6626
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr "繫結©程序與名稱可能無法有指標屬性於 %C"
 
-#: fortran/decl.c:6613
+#: fortran/decl.c:6632
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr "虛設程序於 %C 可能無法有繫結©屬性與名稱"
 
-#: fortran/decl.c:6636
+#: fortran/decl.c:6655
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr "程序『%s』於 %L 已經有基本型式的 %s"
 
-#: fortran/decl.c:6682 fortran/decl.c:6870 fortran/decl.c:10723
+#: fortran/decl.c:6701 fortran/decl.c:6889 fortran/decl.c:10748
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr "語法時發生錯誤程序敘述於 %C"
 
-#: fortran/decl.c:6731 fortran/decl.c:10623
+#: fortran/decl.c:6750 fortran/decl.c:10648
 #, fuzzy, gcc-internal-format
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr "預期『::』之後 binding-attributes 於 %C"
 
-#: fortran/decl.c:6738
+#: fortran/decl.c:6757
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr "NOPASS 或明確的介面必要項於 %C"
 
-#: fortran/decl.c:6742
+#: fortran/decl.c:6761
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component at %C"
 msgstr "Fortran 2003:程序指標成分於 %C"
 
-#: fortran/decl.c:6814
+#: fortran/decl.c:6833
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in procedure pointer component at %C"
 msgstr "語法時發生錯誤程序指標成分於 %C"
 
-#: fortran/decl.c:6832
+#: fortran/decl.c:6851
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr "程序於 %C 必須是在中通用介面"
 
-#: fortran/decl.c:6841 fortran/decl.c:9392
+#: fortran/decl.c:6860 fortran/decl.c:9411
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr "Fortran 2008:雙倍科郎在中模組程序敘述於 %L"
 
-#: fortran/decl.c:6911
+#: fortran/decl.c:6930
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE statement at %C"
 msgstr "Fortran 2003:程序敘述於 %C"
 
-#: fortran/decl.c:6983
+#: fortran/decl.c:7002
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr "預期的形式引數清單在中函式定義於 %C"
 
-#: fortran/decl.c:7007 fortran/decl.c:7011 fortran/decl.c:7266
-#: fortran/decl.c:7270 fortran/decl.c:7462 fortran/decl.c:7466
-#: fortran/symbol.c:1875
+#: fortran/decl.c:7026 fortran/decl.c:7030 fortran/decl.c:7285
+#: fortran/decl.c:7289 fortran/decl.c:7481 fortran/decl.c:7485
+#: fortran/symbol.c:1889
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr "繫結©屬性於 %L 只能使用用於變數或共同區塊"
 
-#: fortran/decl.c:7164
+#: fortran/decl.c:7183
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C"
 msgstr "%C IMPLICIT 敘述為空"
 
-#: fortran/decl.c:7173
+#: fortran/decl.c:7192
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr "%C 處的 ENTRY 敘述不能出現在 PROGRAM 中"
 
-#: fortran/decl.c:7176
+#: fortran/decl.c:7195
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr "%C 處的 ENTRY 敘述不能出現在 MODULE 中"
 
-#: fortran/decl.c:7179
+#: fortran/decl.c:7198
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgid "ENTRY statement at %C cannot appear within a SUBMODULE"
 msgstr "%C 處的 ENTRY 敘述不能出現在 MODULE 中"
 
-#: fortran/decl.c:7182
+#: fortran/decl.c:7201
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr "%C 處的 ENTRY 敘述不能出現在 BLOCK DATA 中"
 
-#: fortran/decl.c:7186 fortran/decl.c:7231
+#: fortran/decl.c:7205 fortran/decl.c:7250
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr "%C 處的 ENTRY 敘述不能出現在 INTERFACE 中"
 
-#: fortran/decl.c:7190
+#: fortran/decl.c:7209
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgid "ENTRY statement at %C cannot appear within a STRUCTURE block"
 msgstr "%C 處的 ENTRY 敘述不能出現在 SELECT 區塊中"
 
-#: fortran/decl.c:7194
+#: fortran/decl.c:7213
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr "%C 處的 ENTRY 敘述不能出現在 DERIVED TYPE 區塊中"
 
-#: fortran/decl.c:7198
+#: fortran/decl.c:7217
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr "%C 處的 ENTRY 敘述不能出現在 IF-THEN 區塊中"
 
-#: fortran/decl.c:7203
+#: fortran/decl.c:7222
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr "%C 處的 ENTRY 敘述不能出現在 DO 中"
 
-#: fortran/decl.c:7207
+#: fortran/decl.c:7226
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr "%C 處的 ENTRY 敘述不能出現在 SELECT 區塊中"
 
-#: fortran/decl.c:7211
+#: fortran/decl.c:7230
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr "%C 處的 ENTRY 敘述不能出現在 FORALL 區塊中"
 
-#: fortran/decl.c:7215
+#: fortran/decl.c:7234
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr "%C 處的 ENTRY 敘述不能出現在 WHERE 區塊中"
 
-#: fortran/decl.c:7219
+#: fortran/decl.c:7238
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr "%C 處的 ENTRY 敘述不能出現在巢狀的子程式中"
 
-#: fortran/decl.c:7223
+#: fortran/decl.c:7242
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected END statement at %C"
 msgid "Unexpected ENTRY statement at %C"
 msgstr "%C 處非預期的 END 敘述"
 
-#: fortran/decl.c:7244
+#: fortran/decl.c:7263
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr "%C 處 ENTRY 敘述不能出現在被包含的程序中"
 
-#: fortran/decl.c:7295 fortran/decl.c:7501
+#: fortran/decl.c:7314 fortran/decl.c:7520
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr "缺少必要項 parentheses 之前繫結©於 %C"
 
-#: fortran/decl.c:7563 fortran/decl.c:7570
+#: fortran/decl.c:7582 fortran/decl.c:7589
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr "無效的 C 名稱在中名稱=說明符於 %C"
 
-#: fortran/decl.c:7610
+#: fortran/decl.c:7629
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr "語法時發生錯誤名稱=說明符用於繫結標貼於 %C"
 
-#: fortran/decl.c:7626
+#: fortran/decl.c:7645
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr "非同步=說明符於 %L 必須是初始化運算式"
 
-#: fortran/decl.c:7634
+#: fortran/decl.c:7653
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr ""
 
-#: fortran/decl.c:7653
+#: fortran/decl.c:7672
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing closing paren for binding label at %C"
 msgstr "缺少關閉同位用於繫結標貼於 %C"
 
-#: fortran/decl.c:7659
+#: fortran/decl.c:7678
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr "沒有繫結名稱被允許在中繫結©於 %C"
 
-#: fortran/decl.c:7665
+#: fortran/decl.c:7684
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr "用於虛設程序 %s，沒有繫結名稱被允許在中繫結©於 %C"
 
-#: fortran/decl.c:7694
+#: fortran/decl.c:7713
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr "名稱不允許於繫結©用於摘要介面於 %C"
 
-#: fortran/decl.c:7939
+#: fortran/decl.c:7958
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr "%C 處非預期的 END 敘述"
 
-#: fortran/decl.c:7948
+#: fortran/decl.c:7967
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "END statement instead of %s statement at %L"
 msgstr "Fortran 2008:結束敘述以代替 %s 敘述於 %L"
 
 #. We would have required END [something].
-#: fortran/decl.c:7957
+#: fortran/decl.c:7976
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr "需要 %s 敘述在 %L 處"
 
-#: fortran/decl.c:7968
+#: fortran/decl.c:7987
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting %s statement at %C"
 msgid "Expecting %s statement at %L"
 msgstr "需要 %s 敘述，於 %C"
 
-#: fortran/decl.c:7988
+#: fortran/decl.c:8007
 #, fuzzy, gcc-internal-format
 #| msgid "Expected block name of '%s' in %s statement at %C"
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr "需要塊名「%s」在「%s」運算式中，於 %C"
 
-#: fortran/decl.c:8005
+#: fortran/decl.c:8024
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr "%C 處需要結束名"
 
-#: fortran/decl.c:8019 fortran/decl.c:8027
+#: fortran/decl.c:8038 fortran/decl.c:8046
 #, fuzzy, gcc-internal-format
 #| msgid "Expected label '%s' for %s statement at %C"
 msgid "Expected label %qs for %s statement at %C"
 msgstr "需要標籤「%s」，為 %s 敘述，於 %C"
 
-#: fortran/decl.c:8126
+#: fortran/decl.c:8145
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr "缺少陣列規格於 %L 在中尺寸敘述"
 
-#: fortran/decl.c:8134
+#: fortran/decl.c:8153
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Dimensions specified for %s at %L after its initialization"
 msgstr "維度指定的用於 %s 於 %L 之後它的 initialisation"
 
-#: fortran/decl.c:8142
+#: fortran/decl.c:8161
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr "缺少陣列規格於 %L 在中 CODIMENSION 敘述"
 
-#: fortran/decl.c:8151
+#: fortran/decl.c:8170
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr "%L 處陣列指定必須延遲"
 
-#: fortran/decl.c:8249
+#: fortran/decl.c:8268
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr "%C 處變數清單中有非預期的無用字元"
 
-#: fortran/decl.c:8286
+#: fortran/decl.c:8305
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "Expected %<(%> at %C"
 msgstr "在 %C 處需要「(」"
 
-#: fortran/decl.c:8300 fortran/decl.c:8340
+#: fortran/decl.c:8319 fortran/decl.c:8359
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr "在 %C 處需要變數名"
 
-#: fortran/decl.c:8316
+#: fortran/decl.c:8335
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C must be an integer"
 msgstr "Cray 指標於 %C 必須是整數"
 
-#: fortran/decl.c:8320
+#: fortran/decl.c:8339
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr "Cray 指標於 %C 有 %d 位元組的精確度；記憶體位址需求 %d 位元組"
 
-#: fortran/decl.c:8326
+#: fortran/decl.c:8345
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr "在 %C 處需要「,」"
 
-#: fortran/decl.c:8365
+#: fortran/decl.c:8384
 #, gcc-internal-format
 msgid "Couldn't set Cray pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:8389
+#: fortran/decl.c:8408
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr "在 %C 處需要「)」"
 
-#: fortran/decl.c:8401
+#: fortran/decl.c:8420
 #, fuzzy, gcc-internal-format
 #| msgid "Expected \",\" or end of statement at %C"
 msgid "Expected %<,%> or end of statement at %C"
 msgstr "在 %C 處需要「,」或敘述尾"
 
-#: fortran/decl.c:8427
+#: fortran/decl.c:8446
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr "含義未被允許內部的區塊於 %C"
 
-#: fortran/decl.c:8459
+#: fortran/decl.c:8478
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr "可選的未被允許內部的區塊於 %C"
 
-#: fortran/decl.c:8478
+#: fortran/decl.c:8497
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer declaration at %C requires -fcray-pointer flag"
 msgstr "Cray 指標宣告於 %C 需求 -fcray-pointer 旗標"
 
-#: fortran/decl.c:8517
+#: fortran/decl.c:8536
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS statement at %C"
 msgstr "Fortran 2008:CONTIGUOUS 敘述於 %C"
 
-#: fortran/decl.c:8623
+#: fortran/decl.c:8642
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr "存取規格的 %s 運算子於 %C 已指定的"
 
-#: fortran/decl.c:8640
+#: fortran/decl.c:8659
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr "存取規格的.%s。運算子於 %C 已指定的"
 
-#: fortran/decl.c:8679
+#: fortran/decl.c:8698
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED statement at %C"
 msgstr "Fortran 2003:保護的敘述於 %C"
 
-#: fortran/decl.c:8717
+#: fortran/decl.c:8736
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr "語法時發生錯誤保護的敘述於 %C"
 
-#: fortran/decl.c:8741
+#: fortran/decl.c:8760
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr "私人的敘述於 %C 是只有允許的在中規格部分的模組"
 
-#: fortran/decl.c:8778
+#: fortran/decl.c:8797
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr "公用的敘述於 %C 是只有允許的在中規格部分的模組"
 
-#: fortran/decl.c:8806
+#: fortran/decl.c:8825
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr "預期的變數名稱於 %C 在中參數敘述"
 
-#: fortran/decl.c:8813
+#: fortran/decl.c:8832
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr "%C 在 PARAMETER 敘述中需要 = 符號"
 
-#: fortran/decl.c:8819
+#: fortran/decl.c:8838
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr "%C 在 PARAMETER 敘述中需要運算式"
 
-#: fortran/decl.c:8839
+#: fortran/decl.c:8858
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Initializing already initialized variable at %C"
 msgstr "初始化已經初始化的變數於 %C"
 
 #. With legacy PARAMETER statements, don't expect a terminating ')'.
-#: fortran/decl.c:8864
+#: fortran/decl.c:8883
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER without '()' at %C"
 msgstr ""
 
-#: fortran/decl.c:8880
+#: fortran/decl.c:8899
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr "%C 處 PARAMETER 敘述中有非預期的字元"
 
-#: fortran/decl.c:8899 fortran/decl.c:8955
+#: fortran/decl.c:8918 fortran/decl.c:8974
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:8934
+#: fortran/decl.c:8953
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected variable in READ statement at %C"
 msgid "Expected entity-list in AUTOMATIC statement at %C"
 msgstr "%C READ 敘述需要變數"
 
-#: fortran/decl.c:8941
+#: fortran/decl.c:8960
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in AUTOMATIC statement at %C"
 msgstr "語法時發生錯誤易變的敘述於 %C"
 
-#: fortran/decl.c:8990
+#: fortran/decl.c:9009
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected variable in READ statement at %C"
 msgid "Expected entity-list in STATIC statement at %C"
 msgstr "%C READ 敘述需要變數"
 
-#: fortran/decl.c:8997
+#: fortran/decl.c:9016
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in STATIC statement at %C"
 msgstr "%C SAVE 敘述語法錯誤"
 
-#: fortran/decl.c:9016
+#: fortran/decl.c:9035
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr "Blanket 儲存敘述於 %C 追隨前一個儲存敘述"
 
-#: fortran/decl.c:9027
+#: fortran/decl.c:9046
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr "%C 處 SAVE 敘述跟隨空白 SAVE 敘述"
 
-#: fortran/decl.c:9073
+#: fortran/decl.c:9092
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr "%C SAVE 敘述語法錯誤"
 
-#: fortran/decl.c:9087
+#: fortran/decl.c:9106
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr "值未被允許內部的區塊於 %C"
 
-#: fortran/decl.c:9091
+#: fortran/decl.c:9110
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VALUE statement at %C"
 msgstr "Fortran 2003:值敘述於 %C"
 
-#: fortran/decl.c:9129
+#: fortran/decl.c:9148
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VALUE statement at %C"
 msgstr "語法時發生錯誤值敘述於 %C"
 
-#: fortran/decl.c:9141
+#: fortran/decl.c:9160
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE statement at %C"
 msgstr "Fortran 2003:易變的敘述於 %C"
 
-#: fortran/decl.c:9168
+#: fortran/decl.c:9187
 #, fuzzy, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr "指定易變的用於 coarray 變數『%s』於 %C, 該項是 use-/ host-associated"
 
-#: fortran/decl.c:9193
+#: fortran/decl.c:9212
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr "語法時發生錯誤易變的敘述於 %C"
 
-#: fortran/decl.c:9205
+#: fortran/decl.c:9224
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS statement at %C"
 msgstr "Fortran 2003:非同步敘述於 %C"
 
-#: fortran/decl.c:9249
+#: fortran/decl.c:9268
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr "語法時發生錯誤非同步敘述於 %C"
 
-#: fortran/decl.c:9274
+#: fortran/decl.c:9293
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE declaration at %C"
 msgstr "Fortran 2008:程序清單於 %C"
 
-#: fortran/decl.c:9367
+#: fortran/decl.c:9386
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr "模組程序於 %C 必須是在中通用模組介面"
 
-#: fortran/decl.c:9425
+#: fortran/decl.c:9444
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr "Intrinsic 程序於 %L 無法模組程序"
 
-#: fortran/decl.c:9474
+#: fortran/decl.c:9493
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr "模稜兩可的符號在中類型定義於 %C"
 
-#: fortran/decl.c:9483
+#: fortran/decl.c:9502
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr "符號『%s』於 %C 已主機關聯的"
 
-#: fortran/decl.c:9489
+#: fortran/decl.c:9508
 #, fuzzy, gcc-internal-format
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr "『%s』在中延伸運算式於 %C 並非衍生類型"
 
-#: fortran/decl.c:9496
+#: fortran/decl.c:9515
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr "『%s』無法進階於 %C 因為它是繫結©"
 
-#: fortran/decl.c:9503
+#: fortran/decl.c:9522
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr "『%s』無法進階於 %C 因為它是序列型態"
 
-#: fortran/decl.c:9526
+#: fortran/decl.c:9545
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr "衍生類型於 %C 只能是私人的在中規格部分的模組"
 
-#: fortran/decl.c:9538
+#: fortran/decl.c:9557
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr "衍生類型於 %C 只能是公用的在中規格部分的模組"
 
-#: fortran/decl.c:9559
+#: fortran/decl.c:9578
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
 msgstr "摘要型態『%s』使用的於 %L"
 
-#: fortran/decl.c:9605
+#: fortran/decl.c:9624
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate construct label '%s' at %C"
 msgid "Failed to create structure type '%s' at %C"
 msgstr "重複的建構標籤「%s」出現在 %C 處"
 
-#: fortran/decl.c:9611
+#: fortran/decl.c:9630
 #, fuzzy, gcc-internal-format
 msgid "Type definition of %qs at %C was already defined at %L"
 msgstr "衍生類型定義的『%s』於 %C 已定義"
 
-#: fortran/decl.c:9658
+#: fortran/decl.c:9677
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Junk after MAP statement at %C"
 msgstr "垃圾之後關聯敘述於 %C"
 
-#: fortran/decl.c:9691
+#: fortran/decl.c:9710
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Junk after UNION statement at %C"
 msgstr "垃圾之後關聯敘述於 %C"
 
-#: fortran/decl.c:9726
+#: fortran/decl.c:9745
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr ""
 
-#: fortran/decl.c:9740
+#: fortran/decl.c:9759
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after function declaration at %C"
 msgid "Structure name expected in non-nested structure declaration at %C"
 msgstr "%C 處的函式宣告後有非預期的無用字元"
 
-#: fortran/decl.c:9758
+#: fortran/decl.c:9777
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Junk after non-nested STRUCTURE statement at %C"
 msgstr "垃圾之後關聯敘述於 %C"
 
-#: fortran/decl.c:9765
+#: fortran/decl.c:9784
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C cannot be the same as an intrinsic type"
 msgid "Structure name %qs at %C cannot be the same as an intrinsic type"
 msgstr "類型「%s」(位於 %C)不能與內建類型同名"
 
-#: fortran/decl.c:9926
+#: fortran/decl.c:9947
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr "%C 在 TYPE 定義中需要 ::"
 
-#: fortran/decl.c:9954
+#: fortran/decl.c:9975
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C cannot be the same as an intrinsic type"
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr "類型「%s」(位於 %C)不能與內建類型同名"
 
-#: fortran/decl.c:9964
+#: fortran/decl.c:9986
 #, fuzzy, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr "衍生類型名稱『%s』於 %C 已經有基本型式的 %s"
 
-#: fortran/decl.c:9981
+#: fortran/decl.c:9989
 #, fuzzy, gcc-internal-format
+msgid "Derived type name %qs at %C already has a basic type"
+msgstr "衍生類型名稱『%s』於 %C 已經有基本型式的 %s"
+
+#: fortran/decl.c:10006
+#, fuzzy, gcc-internal-format
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr "衍生類型定義的『%s』於 %C 已定義"
 
-#: fortran/decl.c:10042
+#: fortran/decl.c:10067
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CHARACTER declaration at %C"
 msgid "Garbage after PARAMETERIZED TYPE declaration at %C"
 msgstr "%C 的 CHARACTER 宣告語法錯誤"
 
-#: fortran/decl.c:10126
+#: fortran/decl.c:10151
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr "Cray 點於 %C 無法假設的形狀陣列"
 
-#: fortran/decl.c:10146
+#: fortran/decl.c:10171
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENUM and ENUMERATOR at %C"
 msgstr "Fortran 2003:ENUM 和列舉值於 %C"
 
-#: fortran/decl.c:10178
+#: fortran/decl.c:10203
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr "%C 處：列舉量超過 C 整數類型"
 
-#: fortran/decl.c:10257
+#: fortran/decl.c:10282
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr "列舉值 %L 無法初始化的與整數運算式"
 
-#: fortran/decl.c:10305
+#: fortran/decl.c:10330
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr "ENUM 定義敘述預期的之前 %C"
 
-#: fortran/decl.c:10341
+#: fortran/decl.c:10366
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr "%C 處 ENUMERATOR 定義中語法錯誤"
 
-#: fortran/decl.c:10388 fortran/decl.c:10403
+#: fortran/decl.c:10413 fortran/decl.c:10428
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate access-specifier at %C"
 msgstr "重製 access-specifier 於 %C"
 
-#: fortran/decl.c:10423
+#: fortran/decl.c:10448
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr "繫結屬性已經指定傳遞，不合法的 NOPASS 於 %C"
 
-#: fortran/decl.c:10443
+#: fortran/decl.c:10468
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr "繫結屬性已經指定傳遞，不合法的回合於 %C"
 
-#: fortran/decl.c:10470
+#: fortran/decl.c:10495
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate POINTER attribute at %C"
 msgstr "重製指標屬性於 %C"
 
-#: fortran/decl.c:10488
+#: fortran/decl.c:10513
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr "重製 NON_OVERRIDABLE 於 %C"
 
-#: fortran/decl.c:10504
+#: fortran/decl.c:10529
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DEFERRED at %C"
 msgstr "重製已推遲於 %C"
 
-#: fortran/decl.c:10517
+#: fortran/decl.c:10542
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected access-specifier at %C"
 msgstr "預期 access-specifier 於 %C"
 
-#: fortran/decl.c:10519
+#: fortran/decl.c:10544
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr "預期的繫結屬性於 %C"
 
-#: fortran/decl.c:10527
+#: fortran/decl.c:10552
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED can't both appear at %C"
 msgstr "NON_OVERRIDABLE 和已推遲無法兩者出現於 %C"
 
-#: fortran/decl.c:10539
+#: fortran/decl.c:10564
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr "指標屬性被必要項用於程序指標成分於 %C"
 
-#: fortran/decl.c:10581
+#: fortran/decl.c:10606
 #, fuzzy, gcc-internal-format
 msgid "Interface-name expected after %<(%> at %C"
 msgstr "Interface-name 預期的之後『(』於 %C"
 
-#: fortran/decl.c:10587
+#: fortran/decl.c:10612
 #, fuzzy, gcc-internal-format
 msgid "%<)%> expected at %C"
 msgstr "『)』預期的於 %C"
 
-#: fortran/decl.c:10607
+#: fortran/decl.c:10632
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr "介面必須被指定的用於已推遲繫結於 %C"
 
-#: fortran/decl.c:10612
+#: fortran/decl.c:10637
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr "程序 (介面) 於 %C 應該被宣告已推遲"
 
-#: fortran/decl.c:10635
+#: fortran/decl.c:10660
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr "預期的繫結名稱於 %C"
 
-#: fortran/decl.c:10639
+#: fortran/decl.c:10664
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
 msgstr "Fortran 2008:程序清單於 %C"
 
-#: fortran/decl.c:10651
+#: fortran/decl.c:10676
 #, fuzzy, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr "『=>目標』無效用於已推遲繫結於 %C"
 
-#: fortran/decl.c:10657
+#: fortran/decl.c:10682
 #, fuzzy, gcc-internal-format
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr "『::』所需的在中程序繫結與明確的目標於 %C"
 
-#: fortran/decl.c:10667
+#: fortran/decl.c:10692
 #, fuzzy, gcc-internal-format
 msgid "Expected binding target after %<=>%> at %C"
 msgstr "預期的繫結目標之後『=>』於 %C"
 
-#: fortran/decl.c:10684
+#: fortran/decl.c:10709
 #, fuzzy, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr "型態『%s』包含已推遲繫結於 %C 不是摘要"
 
-#: fortran/decl.c:10695
+#: fortran/decl.c:10720
 #, fuzzy, gcc-internal-format
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr "已經有程序與繫結名稱『%s』用於衍生類型『%s』於 %C"
 
-#: fortran/decl.c:10746
+#: fortran/decl.c:10771
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr "通用於 %C 必須是內部衍生類型含有"
 
-#: fortran/decl.c:10766
+#: fortran/decl.c:10791
 #, fuzzy, gcc-internal-format
 msgid "Expected %<::%> at %C"
 msgstr "預期『::』於 %C"
 
-#: fortran/decl.c:10778
+#: fortran/decl.c:10803
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected generic name or operator descriptor at %C"
 msgstr "預期的通用名稱或運算子描述元於 %C"
 
-#: fortran/decl.c:10799
+#: fortran/decl.c:10824
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Malformed GENERIC statement at %C"
 msgstr "%C IMPLICIT 敘述為空"
 
-#: fortran/decl.c:10810
+#: fortran/decl.c:10835
 #, fuzzy, gcc-internal-format
 msgid "Expected %<=>%> at %C"
 msgstr "預期『=>』於 %C"
 
-#: fortran/decl.c:10846
+#: fortran/decl.c:10871
 #, fuzzy, gcc-internal-format
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr "那裡『s 已經 non-generic 程序與繫結名稱 』%s『 用於衍生類型 』%s' 於 %C"
 
-#: fortran/decl.c:10854
+#: fortran/decl.c:10879
 #, fuzzy, gcc-internal-format
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr "繫結於 %C 必須有相同存取做為已經定義的繫結『%s』"
 
-#: fortran/decl.c:10902
+#: fortran/decl.c:10927
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr "預期的特定的繫結名稱於 %C"
 
-#: fortran/decl.c:10912
+#: fortran/decl.c:10937
 #, fuzzy, gcc-internal-format
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr "『%s』已經定義為特定的繫結用於通用『%s』於 %C"
 
-#: fortran/decl.c:10930
+#: fortran/decl.c:10955
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr "垃圾之後通用繫結於 %C"
 
-#: fortran/decl.c:10965
+#: fortran/decl.c:10990
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr "最後的宣告於 %C 必須是內部衍生類型含有區段"
 
-#: fortran/decl.c:10976
+#: fortran/decl.c:11001
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr "衍生類型宣告與最後的於 %C 必須是在中規格部分的模組"
 
-#: fortran/decl.c:10998
+#: fortran/decl.c:11023
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr "清空最後的於 %C"
 
-#: fortran/decl.c:11005
+#: fortran/decl.c:11030
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr "預期的模組程序名稱於 %C"
 
-#: fortran/decl.c:11015
+#: fortran/decl.c:11040
 #, fuzzy, gcc-internal-format
 #| msgid "Expected \",\" at %C"
 msgid "Expected %<,%> at %C"
 msgstr "在 %C 處需要「,」"
 
-#: fortran/decl.c:11021
+#: fortran/decl.c:11046
 #, fuzzy, gcc-internal-format
 msgid "Unknown procedure name %qs at %C"
 msgstr "不明程序名稱「%s」於 %C"
 
-#: fortran/decl.c:11034
+#: fortran/decl.c:11059
 #, fuzzy, gcc-internal-format
 msgid "%qs at %C is already defined as FINAL procedure"
 msgstr "『%s』於 %C 已經定義為最後的程序！"
 
-#: fortran/decl.c:11104
+#: fortran/decl.c:11129
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr "不明屬性在中！GCC $ 屬性敘述於 %C"
 
-#: fortran/decl.c:11150
+#: fortran/decl.c:11175
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr "語法時發生錯誤！GCC $ 屬性敘述於 %C"
 
-#: fortran/decl.c:11170
+#: fortran/decl.c:11195
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive requires a non-negative integral constant less than or equal to %u at %C"
 msgstr ""
 
-#: fortran/decl.c:11184
+#: fortran/decl.c:11209
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in FORALL iterator at %C"
 msgid "Syntax error in !GCC$ UNROLL directive at %C"
@@ -57226,27 +57299,27 @@
 msgid "BOZ literal at %L used to initialize non-integer variable %qs"
 msgstr "延伸：BOZ 實字於 %L 用來初始化 non-integer 變數『%s』"
 
-#: fortran/expr.c:3369 fortran/resolve.c:10197
+#: fortran/expr.c:3369 fortran/resolve.c:10210
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal at %L outside a DATA statement and outside INT/REAL/DBLE/CMPLX"
 msgstr "延伸：BOZ 實字於 %L 外側資料敘述和外側整數/真實/DBLE/CMPLX"
 
-#: fortran/expr.c:3380 fortran/resolve.c:10208
+#: fortran/expr.c:3380 fortran/resolve.c:10221
 #, fuzzy, gcc-internal-format
 msgid "BOZ literal at %L is bitwise transferred non-integer symbol %qs"
 msgstr "BOZ 實字於 %L 是逐位元已轉送 non-integer 符號『%s』"
 
-#: fortran/expr.c:3388 fortran/resolve.c:10217
+#: fortran/expr.c:3388 fortran/resolve.c:10230
 #, fuzzy, gcc-internal-format
 msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "算術欠位的逐位元已轉送 BOZ 於 %L.這個檢查可以已停用與選項 -fno-range-check"
 
-#: fortran/expr.c:3392 fortran/resolve.c:10221
+#: fortran/expr.c:3392 fortran/resolve.c:10234
 #, fuzzy, gcc-internal-format
 msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "算術溢位的逐位元已轉送 BOZ 於 %L.這個檢查可以已停用與選項 -fno-range-check"
 
-#: fortran/expr.c:3396 fortran/resolve.c:10225
+#: fortran/expr.c:3396 fortran/resolve.c:10238
 #, fuzzy, gcc-internal-format
 msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "算術 NaN 的逐位元已轉送 BOZ 於 %L.這個檢查可以已停用與選項 -fno-range-check"
@@ -57256,147 +57329,147 @@
 msgid "The assignment to a KIND or LEN component of a parameterized type at %L is not allowed"
 msgstr ""
 
-#: fortran/expr.c:3426
+#: fortran/expr.c:3429
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Incompatible types in DATA statement at %L; attempted conversion of %s to %s"
 msgstr "不相容的類型在中資料敘述於 %L; 試圖的轉換的 %s 到 %s"
 
-#: fortran/expr.c:3465
+#: fortran/expr.c:3468
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is not a POINTER at %L"
 msgstr "指標指派目標並非指標於 %L"
 
-#: fortran/expr.c:3473
+#: fortran/expr.c:3476
 #, fuzzy, gcc-internal-format
 msgid "%qs in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgstr "『%s』在中指標指派於 %L 無法 l-value 自從它是程序"
 
-#: fortran/expr.c:3496
+#: fortran/expr.c:3499
 #, fuzzy, gcc-internal-format
 msgid "Expected bounds specification for %qs at %L"
 msgstr "預期的邊界規格用於『%s』於 %L"
 
-#: fortran/expr.c:3501
+#: fortran/expr.c:3504
 #, fuzzy, gcc-internal-format
 msgid "Bounds specification for %qs in pointer assignment at %L"
 msgstr "Fortran 2003:邊界規格用於『%s』在中指標指派於 %L"
 
-#: fortran/expr.c:3514
+#: fortran/expr.c:3517
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Lower bound has to be present at %L"
 msgstr "下限必須都到位於 %L"
 
-#: fortran/expr.c:3520
+#: fortran/expr.c:3523
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Stride must not be present at %L"
 msgstr "Stride 必須不都到位於 %L"
 
-#: fortran/expr.c:3532
+#: fortran/expr.c:3535
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the upper bounds must be specified at %L"
 msgstr "還是所有或沒有任何上限必須被指定的於 %L"
 
-#: fortran/expr.c:3558
+#: fortran/expr.c:3561
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %L shall not have a coindex"
 msgstr "指標物件於 %L 不應該有 coindex"
 
-#: fortran/expr.c:3579
+#: fortran/expr.c:3582
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure pointer assignment at %L"
 msgstr "無效的程序指標指派於 %L"
 
-#: fortran/expr.c:3603
+#: fortran/expr.c:3606
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs is invalid as proc-target in procedure pointer assignment at %L"
 msgstr "敘述函式『%s』無效在中程序指標指派於 %L"
 
-#: fortran/expr.c:3612
+#: fortran/expr.c:3615
 #, fuzzy, gcc-internal-format
 msgid "Abstract interface %qs is invalid in procedure pointer assignment at %L"
 msgstr "摘要介面『%s』無效在中程序指標指派於 %L"
 
-#: fortran/expr.c:3622
+#: fortran/expr.c:3625
 #, fuzzy, gcc-internal-format
 msgid "Statement function %qs is invalid in procedure pointer assignment at %L"
 msgstr "敘述函式『%s』無效在中程序指標指派於 %L"
 
-#: fortran/expr.c:3628
+#: fortran/expr.c:3631
 #, fuzzy, gcc-internal-format
 msgid "Internal procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "內部程序『%s』無效在中程序指標指派於 %L"
 
-#: fortran/expr.c:3635
+#: fortran/expr.c:3638
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic %qs at %L is invalid in procedure pointer assignment"
 msgstr "內部程序『%s』無效在中程序指標指派於 %L"
 
-#: fortran/expr.c:3643
+#: fortran/expr.c:3646
 #, fuzzy, gcc-internal-format
 msgid "Nonintrinsic elemental procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "Nonintrinsic elemental 程序『%s』無效在中程序指標 assigment 於 %L"
 
-#: fortran/expr.c:3666
+#: fortran/expr.c:3669
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in the procedure pointer assignment at %L: mismatch in the calling convention"
 msgstr "不匹配在中程序指標指派於 %L:不匹配在中呼叫慣例"
 
-#: fortran/expr.c:3719
+#: fortran/expr.c:3722
 #, fuzzy, gcc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %qs is not a subroutine"
 msgstr "介面不匹配在中程序指標指派於 %L:%s"
 
-#: fortran/expr.c:3729 fortran/expr.c:3744
+#: fortran/expr.c:3732 fortran/expr.c:3747
 #, fuzzy, gcc-internal-format
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr "關鍵字引數需求明確的介面用於程序指標成分『%s』於 %L"
 
-#: fortran/expr.c:3735 fortran/expr.c:3750 fortran/resolve.c:2566
+#: fortran/expr.c:3738 fortran/expr.c:3753 fortran/resolve.c:2566
 #, fuzzy, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr "NOPASS 或明確的介面必要項於 %C"
 
-#: fortran/expr.c:3762
+#: fortran/expr.c:3765
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %s"
 msgstr "介面不匹配在中程序指標指派於 %L:%s"
 
-#: fortran/expr.c:3771
+#: fortran/expr.c:3774
 #, gcc-internal-format
 msgid "Procedure pointer target %qs at %L must be either an intrinsic, host or use associated, referenced or have the EXTERNAL attribute"
 msgstr ""
 
-#: fortran/expr.c:3788
+#: fortran/expr.c:3791
 #, gcc-internal-format, gfc-internal-format
 msgid "Data-pointer-object at %L must be unlimited polymorphic, or of a type with the BIND or SEQUENCE attribute, to be compatible with an unlimited polymorphic target"
 msgstr ""
 
-#: fortran/expr.c:3793
+#: fortran/expr.c:3796
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Different types in pointer assignment at %L; attempted assignment of %s to %s"
 msgstr "不同的類型在中指標指派於 %L; 試圖的指派的 %s 到 %s"
 
-#: fortran/expr.c:3802
+#: fortran/expr.c:3805
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Different kind type parameters in pointer assignment at %L"
 msgstr "不同的 kind 型態參數在中指標指派於 %L"
 
-#: fortran/expr.c:3809
+#: fortran/expr.c:3812
 #, gcc-internal-format, gfc-internal-format
 msgid "Different ranks in pointer assignment at %L"
 msgstr "%L 處指標賦值時秩不同"
 
-#: fortran/expr.c:3828
+#: fortran/expr.c:3831
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is smaller than size of the pointer (%ld < %ld) at %L"
 msgstr "分級重新映射目標是小於大小的指標 (%ld<%ld) 於 %L"
 
-#: fortran/expr.c:3841
+#: fortran/expr.c:3844
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target must be rank 1 or simply contiguous at %L"
 msgstr "分級重新映射目標必須是分級 1 或僅需 contiguous 於 %L"
 
-#: fortran/expr.c:3845
+#: fortran/expr.c:3848
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is not rank 1 at %L"
 msgstr "Fortran 2008:分級重新映射目標不是分級 1 於 %L"
@@ -57404,147 +57477,152 @@
 #. The test above might need to be extend when F08, Note 5.4 has to be
 #. interpreted in the way that target and pointer with the same coindex
 #. are allowed.
-#: fortran/expr.c:3877 fortran/expr.c:3925
+#: fortran/expr.c:3880 fortran/expr.c:3928
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data target at %L shall not have a coindex"
 msgstr "資料目標於 %L 不應該有 coindex"
 
-#: fortran/expr.c:3880
+#: fortran/expr.c:3883
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr "目標運算式在中指標指派於 %L 必須投遞指標結果"
 
-#: fortran/expr.c:3888
+#: fortran/expr.c:3891
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr "指標指派目標是 neither 目標 nor 指標於 %L"
 
-#: fortran/expr.c:3895
+#: fortran/expr.c:3898
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr "不當的目標在中指標指派在中 PURE 程序於 %L"
 
-#: fortran/expr.c:3904
+#: fortran/expr.c:3907
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr "指標指派與向量註標於 rhs 於 %L"
 
-#: fortran/expr.c:3912
+#: fortran/expr.c:3915
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr "指標指派目標有保護的屬性於 %L"
 
-#: fortran/expr.c:3936
+#: fortran/expr.c:3939
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to contiguous pointer from non-contiguous target at %L"
 msgstr ""
 
-#: fortran/expr.c:3975
+#: fortran/expr.c:3978
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr "目標運算式在中指標指派於 %L 必須投遞指標結果"
 
-#: fortran/expr.c:4051 fortran/resolve.c:1452
+#: fortran/expr.c:4054 fortran/resolve.c:1452
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr "指標初始化目標於 %L 必須不是 ALLOCATABLE "
 
-#: fortran/expr.c:4057
+#: fortran/expr.c:4060
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr "指標初始化目標於 %C 必須有目標屬性"
 
-#: fortran/expr.c:4072 fortran/resolve.c:1458
+#: fortran/expr.c:4075 fortran/resolve.c:1458
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr "指標初始化目標於 %L 必須有儲存屬性"
 
-#: fortran/expr.c:4084
+#: fortran/expr.c:4087
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr "程序指標初始化目標於 %L 可能無法是程序指標"
 
-#: fortran/expr.c:5512
+#: fortran/expr.c:4557
+#, gcc-internal-format
+msgid "generate_isocbinding_initializer(): bad iso_c_binding type, expected %<c_ptr%> or %<c_funptr%>"
+msgstr ""
+
+#: fortran/expr.c:5568
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr "Fortran 2008:指標函式在中變數定義語境 (%s) 於 %L"
 
-#: fortran/expr.c:5520
+#: fortran/expr.c:5576
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr "Non-variable 運算式在中變數定義語境 (%s) 於 %L"
 
-#: fortran/expr.c:5528
+#: fortran/expr.c:5584
 #, fuzzy, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr "具名的常數『%s』在中變數定義語境 (%s) 於 %L"
 
-#: fortran/expr.c:5537
+#: fortran/expr.c:5593
 #, fuzzy, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr "『%s』在中變數定義語境 (%s) 於 %L 並非變數"
 
-#: fortran/expr.c:5548
+#: fortran/expr.c:5604
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr "Non-POINTER 在中指標關聯語境 (%s) 於 %L"
 
-#: fortran/expr.c:5557
+#: fortran/expr.c:5613
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr "具名的常數『%s』在中變數定義語境 (%s) 於 %L"
 
-#: fortran/expr.c:5570
+#: fortran/expr.c:5626
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr "LOCK_TYPE 在中變數定義語境 (%s) 於 %L"
 
-#: fortran/expr.c:5583
+#: fortran/expr.c:5639
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr "LOCK_TYPE 在中變數定義語境 (%s) 於 %L"
 
-#: fortran/expr.c:5613
+#: fortran/expr.c:5669
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr "虛引數『%s』與含義 (在中) 在中指標關聯語境 (%s) 於 %L"
 
-#: fortran/expr.c:5621
+#: fortran/expr.c:5677
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr "虛引數『%s』與含義 (在中) 在中變數定義語境 (%s) 於 %L"
 
-#: fortran/expr.c:5634
+#: fortran/expr.c:5690
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a pointer association context (%s) at %L"
 msgstr "變數『%s』是保護的和無法出現在中指標關聯語境 (%s) 於 %L"
 
-#: fortran/expr.c:5642
+#: fortran/expr.c:5698
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a variable definition context (%s) at %L"
 msgstr "變數『%s』是保護的和無法出現在中變數定義語境 (%s) 於 %L"
 
-#: fortran/expr.c:5654
+#: fortran/expr.c:5710
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs can not appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr "變數『%s』無法出現在中變數定義語境 (%s) 於 %L 在中 PURE 程序"
 
-#: fortran/expr.c:5713
+#: fortran/expr.c:5769
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
 msgstr "『%s』於 %L 關聯的到 vector-indexed 目標無法已用於變數定義語境 (%s)"
 
-#: fortran/expr.c:5717
+#: fortran/expr.c:5773
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L associated to expression can not be used in a variable definition context (%s)"
 msgstr "『%s』於 %L 關聯的到運算式無法已用於變數定義語境 (%s)"
 
-#: fortran/expr.c:5728
+#: fortran/expr.c:5784
 #, fuzzy, gcc-internal-format
 msgid "Associate-name %qs can not appear in a variable definition context (%s) at %L because its target at %L can not, either"
 msgstr "Associate-name『%s』無法出現在中變數定義語境 (%s) 於 %L 因為它的目標於 %L 無法，還是"
 
-#: fortran/expr.c:5770
+#: fortran/expr.c:5826
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr "『%s』於 %L 關聯的到運算式無法已用於變數定義語境 (%s)"
@@ -57554,23 +57632,23 @@
 msgid "can't open input file: %s"
 msgstr "無法開啟輸入檔案：%s"
 
-#: fortran/frontend-passes.c:190
+#: fortran/frontend-passes.c:192
 #, fuzzy, gcc-internal-format
 msgid "No location in statement"
 msgstr "在中敘述"
 
-#: fortran/frontend-passes.c:205
+#: fortran/frontend-passes.c:207
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected exponent in expression at %C"
 msgid "No location in expression near %L"
 msgstr "%C 處運算式中需要指數部分"
 
-#: fortran/frontend-passes.c:409
+#: fortran/frontend-passes.c:414
 #, gcc-internal-format
 msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
-#: fortran/frontend-passes.c:817 fortran/trans-array.c:1182
+#: fortran/frontend-passes.c:822 fortran/trans-array.c:1182
 #: fortran/trans-array.c:6440 fortran/trans-array.c:7864
 #: fortran/trans-intrinsic.c:7307
 #, fuzzy, gcc-internal-format, gfc-internal-format
@@ -57577,68 +57655,68 @@
 msgid "Creating array temporary at %L"
 msgstr "建立陣列暫時的於 %L"
 
-#: fortran/frontend-passes.c:842 fortran/frontend-passes.c:846
+#: fortran/frontend-passes.c:847 fortran/frontend-passes.c:851
 #, fuzzy, gcc-internal-format
 msgid "Removing call to function %qs at %L"
 msgstr "移除呼叫到函式『%s』於 %L"
 
-#: fortran/frontend-passes.c:1273 fortran/frontend-passes.c:1312
+#: fortran/frontend-passes.c:1278 fortran/frontend-passes.c:1317
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "bad expression"
 msgstr "需要運算式"
 
-#: fortran/frontend-passes.c:1308
+#: fortran/frontend-passes.c:1313
 #, fuzzy, gcc-internal-format
 msgid "bad op"
 msgstr "不當的移動"
 
-#: fortran/frontend-passes.c:2161
+#: fortran/frontend-passes.c:2166
 #, fuzzy, gcc-internal-format
 msgid "illegal OP in optimize_comparison"
 msgstr "無效的運算元在中 gimple 比較"
 
-#: fortran/frontend-passes.c:2407
+#: fortran/frontend-passes.c:2412
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L set to undefined value inside loop  beginning at %L as INTENT(OUT) argument to subroutine %qs"
 msgstr "變數『%s』於 %C 無法重新定義的內部迴圈起始部分於 %L"
 
-#: fortran/frontend-passes.c:2414
+#: fortran/frontend-passes.c:2419
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to subroutine %qs"
 msgstr "變數『%s』於 %C 無法重新定義的內部迴圈起始部分於 %L"
 
-#: fortran/frontend-passes.c:2637 fortran/frontend-passes.c:2661
+#: fortran/frontend-passes.c:2642 fortran/frontend-passes.c:2666
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L out of bounds (%ld < %ld) in loop beginning at %L"
 msgstr "陣列參照於 %L 是超出邊界 (%ld<%ld) 在中 codimension %d"
 
-#: fortran/frontend-passes.c:2646 fortran/frontend-passes.c:2670
+#: fortran/frontend-passes.c:2651 fortran/frontend-passes.c:2675
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L out of bounds (%ld > %ld) in loop beginning at %L"
 msgstr "陣列參照於 %L 是超出邊界 (%ld>%ld) 在中 codimension %d"
 
-#: fortran/frontend-passes.c:2730
+#: fortran/frontend-passes.c:2735
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L set to undefined value inside loop beginning at %L as INTENT(OUT) argument to function %qs"
 msgstr "變數『%s』於 %C 無法重新定義的內部迴圈起始部分於 %L"
 
-#: fortran/frontend-passes.c:2736
+#: fortran/frontend-passes.c:2741
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr "變數『%s』於 %C 無法重新定義的內部迴圈起始部分於 %L"
 
-#: fortran/frontend-passes.c:3128 fortran/trans-expr.c:1581
+#: fortran/frontend-passes.c:3133 fortran/trans-expr.c:1581
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr ""
 
-#: fortran/frontend-passes.c:3637
+#: fortran/frontend-passes.c:3642
 #, gcc-internal-format
 msgid "Scalarization using DIMEN_RANGE unimplemented"
 msgstr ""
 
-#: fortran/frontend-passes.c:4429
+#: fortran/frontend-passes.c:4434
 #, gcc-internal-format, gfc-internal-format
 msgid "Interchanging loops at %L"
 msgstr ""
@@ -57762,12 +57840,12 @@
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "%L 處定義賦值的第二個參數必須是 INTENT(IN)"
 
-#: fortran/interface.c:970 fortran/resolve.c:16351
+#: fortran/interface.c:970 fortran/resolve.c:16378
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "%L 處運算子介面的第一個參數必須是 INTENT(IN)"
 
-#: fortran/interface.c:977 fortran/resolve.c:16369
+#: fortran/interface.c:977 fortran/resolve.c:16396
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "%L 處運算子介面的第二個參數必須是 INTENT(IN)"
@@ -58982,7 +59060,7 @@
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr "名稱表列物件『%s』在中名稱表列『%s』於 %L 是 polymorphic 和需要定義的輸入/輸出程序"
 
-#: fortran/io.c:3369 fortran/resolve.c:14263
+#: fortran/io.c:3369 fortran/resolve.c:14283
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr "Fortran 2003:名稱表列物件『%s』在中名稱表列『%s』於 %L 與 ALLOCATABLE 或指標成分"
@@ -59150,7 +59228,7 @@
 msgid "Integer too large at %C"
 msgstr "%C 處整數太大"
 
-#: fortran/match.c:580 fortran/parse.c:1132
+#: fortran/match.c:580 fortran/parse.c:1136
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many digits in statement label at %C"
 msgstr "%C 處的敘述標籤太多位數"
@@ -59916,57 +59994,57 @@
 msgid "Expected block name %qs of SELECT construct at %C"
 msgstr "預期的區塊名稱『%s』的選取建構於 %C"
 
-#: fortran/match.c:6186
+#: fortran/match.c:6201
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "parse error in SELECT TYPE statement at %C"
 msgstr "語法時發生錯誤保護的敘述於 %C"
 
-#: fortran/match.c:6211
+#: fortran/match.c:6226
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr "選擇器在中選取型態於 %C 並非具名的變數；使用 associate-name=>"
 
-#: fortran/match.c:6249
+#: fortran/match.c:6264
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr "%C 處非預期的 CASE 敘述"
 
-#: fortran/match.c:6301
+#: fortran/match.c:6316
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CASE specification at %C"
 msgstr "語法時發生錯誤大小寫規格於 %C"
 
-#: fortran/match.c:6319
+#: fortran/match.c:6334
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected TYPE IS statement at %C"
 msgstr "未預期的型態是敘述於 %C"
 
-#: fortran/match.c:6351
+#: fortran/match.c:6366
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr ""
 
-#: fortran/match.c:6362
+#: fortran/match.c:6377
 #, gcc-internal-format, gfc-internal-format
 msgid "All the LEN type parameters in the TYPE IS statement at %C must be ASSUMED"
 msgstr ""
 
-#: fortran/match.c:6373
+#: fortran/match.c:6388
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr "語法時發生錯誤型態是規格於 %C"
 
-#: fortran/match.c:6449
+#: fortran/match.c:6464
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr "語法時發生錯誤類別是規格於 %C"
 
-#: fortran/match.c:6572
+#: fortran/match.c:6587
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr "其他情況下敘述於 %C 無法夾於位置區塊"
 
-#: fortran/match.c:6610
+#: fortran/match.c:6625
 #, fuzzy, gcc-internal-format
 msgid "Label %qs at %C doesn't match WHERE label %qs"
 msgstr "標貼『%s』於 %C 不匹配位置標貼『%s』"
@@ -60124,191 +60202,191 @@
 msgid "mio_array_ref(): Unknown array ref"
 msgstr ""
 
-#: fortran/module.c:3716
+#: fortran/module.c:3718
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Namelist %s cannot be renamed by USE association to %s"
 msgstr "名稱表列 %s 無法重新命名的由使用關聯到 %s"
 
-#: fortran/module.c:4832
+#: fortran/module.c:4834
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4835
+#: fortran/module.c:4837
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:5029
+#: fortran/module.c:5031
 #, fuzzy, gcc-internal-format
 msgid "%qs of module %qs, imported at %C, is also the name of the current program unit"
 msgstr "『%s』的模組『%s』，匯入的於 %C, 也是名稱的目前的程式單元"
 
-#: fortran/module.c:5381
+#: fortran/module.c:5383
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in module %qs"
 msgstr "符號『%s』引用於 %L 找不到在中模組『%s』"
 
-#: fortran/module.c:5388
+#: fortran/module.c:5390
 #, fuzzy, gcc-internal-format
 msgid "User operator %qs referenced at %L not found in module %qs"
 msgstr "使用者運算子『%s』引用於 %L 找不到在中模組『%s』"
 
-#: fortran/module.c:5393
+#: fortran/module.c:5395
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic operator %qs referenced at %L not found in module %qs"
 msgstr "Intrinsic 運算子『%s』引用於 %L 找不到在中模組『%s』"
 
-#: fortran/module.c:5628
+#: fortran/module.c:5630
 #, gcc-internal-format
 msgid "write_symbol(): bad module symbol %qs"
 msgstr ""
 
-#: fortran/module.c:5961
+#: fortran/module.c:5963
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr ""
 
-#: fortran/module.c:6148
+#: fortran/module.c:6150
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open module file '%s' for writing at %C: %s"
 msgid "Can't open module file %qs for writing at %C: %s"
 msgstr "無法開啟模組檔案「%s」寫入，在 %C 處：%s"
 
-#: fortran/module.c:6169
+#: fortran/module.c:6171
 #, fuzzy, gcc-internal-format
 #| msgid "Error writing module file '%s' for writing: %s"
 msgid "Error writing module file %qs for writing: %s"
 msgstr "寫入模組檔案「%s」時發生錯誤：%s"
 
-#: fortran/module.c:6180
+#: fortran/module.c:6182
 #, fuzzy, gcc-internal-format
 msgid "Can't delete module file %qs: %s"
 msgstr "無法刪除模組檔案『%s』：%s"
 
-#: fortran/module.c:6183
+#: fortran/module.c:6185
 #, fuzzy, gcc-internal-format
 msgid "Can't rename module file %qs to %qs: %s"
 msgstr "無法重新命名模組檔案『%s』到『%s』：%s"
 
-#: fortran/module.c:6189
+#: fortran/module.c:6191
 #, fuzzy, gcc-internal-format
 msgid "Can't delete temporary module file %qs: %s"
 msgstr "無法刪除暫時的模組檔案『%s』：%s"
 
-#: fortran/module.c:6246
+#: fortran/module.c:6248
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C already declared"
 msgstr "符號『%s』已經宣告"
 
-#: fortran/module.c:6317
+#: fortran/module.c:6319
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr ""
 
-#: fortran/module.c:6425 fortran/module.c:6769
+#: fortran/module.c:6427 fortran/module.c:6771
 #, fuzzy, gcc-internal-format
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr "符號『%s』，引用於 %L, 不是在中已選標準"
 
-#: fortran/module.c:6553
+#: fortran/module.c:6555
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr "符號『%s』引用於 %L 找不到在中 intrinsic 模組 ISO_C_BINDING"
 
-#: fortran/module.c:6574 fortran/module.c:6607 fortran/module.c:6649
+#: fortran/module.c:6576 fortran/module.c:6609 fortran/module.c:6651
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs already declared"
 msgstr "符號『%s』已經宣告"
 
-#: fortran/module.c:6754
+#: fortran/module.c:6756
 #, fuzzy, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr "使用的 intrinsic 模組『%s』於 %C 衝突與非內建模組名稱使用的在之前"
 
-#: fortran/module.c:6776
+#: fortran/module.c:6778
 #, fuzzy, gcc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr "使用的 NUMERIC_STORAGE_SIZE 具名的常數從 intrinsic 模組 ISO_FORTRAN_ENV 於 %L 是不相容的與選項 %s"
 
-#: fortran/module.c:6844
+#: fortran/module.c:6846
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr "使用的 NUMERIC_STORAGE_SIZE 具名的常數從 intrinsic 模組 ISO_FORTRAN_ENV 於 %C 是不相容的與選項 %s"
 
-#: fortran/module.c:6898
+#: fortran/module.c:6900
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr "符號『%s』引用於 %L 找不到在中 intrinsic 模組 ISO_FORTRAN_ENV"
 
-#: fortran/module.c:6924
+#: fortran/module.c:6926
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr "%C 處非預期的 CASE 敘述"
 
-#: fortran/module.c:6953
+#: fortran/module.c:6955
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr "Fortran 2003:ISO_FORTRAN_ENV intrinsic 模組於 %C"
 
-#: fortran/module.c:6965
+#: fortran/module.c:6967
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
 msgstr "Fortran 2003:ISO_C_BINDING 模組於 %C"
 
-#: fortran/module.c:6978
+#: fortran/module.c:6980
 #, fuzzy, gcc-internal-format
 msgid "Can't find an intrinsic module named %qs at %C"
 msgstr "找不到 intrinsic 模組具名的『%s』於 %C"
 
-#: fortran/module.c:6984
+#: fortran/module.c:6986
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr "Fortran 2003:「使用::模組」於 %C"
 
-#: fortran/module.c:6990
+#: fortran/module.c:6992
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr "Fortran 2003:ISO_C_BINDING 模組於 %C"
 
-#: fortran/module.c:6996
+#: fortran/module.c:6998
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr "Fortran 2003:ISO_C_BINDING 模組於 %C"
 
-#: fortran/module.c:7006
+#: fortran/module.c:7008
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open module file '%s' for reading at %C: %s"
 msgid "Can't open module file %qs for reading at %C: %s"
 msgstr "無法開啟模組檔案「%s」讀取，在 %C 處：%s"
 
-#: fortran/module.c:7009
+#: fortran/module.c:7011
 #, gcc-internal-format
 msgid "Module file %qs has not been generated, either because the module does not contain a MODULE PROCEDURE or there is an error in the module."
 msgstr ""
 
-#: fortran/module.c:7020
+#: fortran/module.c:7022
 #, fuzzy, gcc-internal-format
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr "使用的非內建模組『%s』於 %C 衝突與 intrinsic 模組名稱使用的在之前"
 
-#: fortran/module.c:7043
+#: fortran/module.c:7045
 #, fuzzy, gcc-internal-format
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr "檔案『%s』開啟的於 %C 並非 GFORTRAN 模組檔案"
 
-#: fortran/module.c:7051
+#: fortran/module.c:7053
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr ""
 
-#: fortran/module.c:7066
+#: fortran/module.c:7068
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Can't USE the same %smodule we're building"
 msgstr "無法使用相同模組我們正在建立！"
 
 #: fortran/openmp.c:296 fortran/openmp.c:397 fortran/openmp.c:692
-#: fortran/openmp.c:3167
+#: fortran/openmp.c:3166
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "COMMON block /%s/ not found at %C"
 msgstr "共同區塊/%s/找不到於 %C"
@@ -60388,865 +60466,865 @@
 #: fortran/openmp.c:2180
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid second argument of IBSET at %L"
-msgid "Invalid argument to !$ACC WAIT at %L"
+msgid "Invalid argument to !$ACC WAIT at %C"
 msgstr "%L 處 IBSET 的第二個參數無效"
 
-#: fortran/openmp.c:2188
+#: fortran/openmp.c:2187
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "WAIT clause at %L requires a scalar INTEGER expression"
 msgstr "NUM_THREADS 子句於 %L 需要純量整數運算式"
 
-#: fortran/openmp.c:2221
+#: fortran/openmp.c:2220
 #, gcc-internal-format, gfc-internal-format
 msgid "ACC CACHE directive must be inside of loop %C"
 msgstr ""
 
-#: fortran/openmp.c:2252
+#: fortran/openmp.c:2251
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for typename"
 msgid "Multiple loop axes specified for routine"
 msgstr "為類型名指定了存儲類別"
 
-#: fortran/openmp.c:2278
+#: fortran/openmp.c:2277
 #, gcc-internal-format, gfc-internal-format
 msgid "Only the !$ACC ROUTINE form without list is allowed in interface block at %C"
 msgstr ""
 
-#: fortran/openmp.c:2306
+#: fortran/openmp.c:2305
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$ACC ROUTINE ( NAME ) at %C, invalid function name %s"
 msgstr ""
 
-#: fortran/openmp.c:2315
+#: fortran/openmp.c:2314
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$ACC ROUTINE ( NAME ) at %C"
 msgstr "語法時發生錯誤！GCC $ 屬性敘述於 %C"
 
-#: fortran/openmp.c:2322
+#: fortran/openmp.c:2321
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$ACC ROUTINE ( NAME ) at %C, expecting ')' after NAME"
 msgstr ""
 
-#: fortran/openmp.c:2457 fortran/openmp.c:2481
+#: fortran/openmp.c:2456 fortran/openmp.c:2480
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP CRITICAL statement at %C"
 msgstr "未預期的垃圾之後 $OMP 重要敘述於 %C"
 
-#: fortran/openmp.c:2548
+#: fortran/openmp.c:2547
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP FLUSH statement at %C"
 msgstr "未預期的垃圾之後 $OMP 清理敘述於 %C"
 
-#: fortran/openmp.c:2942 fortran/openmp.c:6225
+#: fortran/openmp.c:2941 fortran/openmp.c:6230
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined %s !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2946 fortran/openmp.c:6229
+#: fortran/openmp.c:2945 fortran/openmp.c:6234
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2951
+#: fortran/openmp.c:2950
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2953
+#: fortran/openmp.c:2952
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2973
+#: fortran/openmp.c:2972
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after !$OMP DECLARE REDUCTION at %C"
 msgstr "未預期的垃圾之後 $OMP 已排序的敘述於 %C"
 
-#: fortran/openmp.c:3010
+#: fortran/openmp.c:3009
 #, gcc-internal-format, gfc-internal-format
 msgid "Only the !$OMP DECLARE TARGET form without clauses is allowed in interface block at %C"
 msgstr ""
 
-#: fortran/openmp.c:3025
+#: fortran/openmp.c:3024
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after !$OMP DECLARE TARGET at %C"
 msgstr "未預期的垃圾之後 $OMP 已排序的敘述於 %C"
 
-#: fortran/openmp.c:3048
+#: fortran/openmp.c:3047
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET variable at %L is an element of a COMMON block"
 msgstr "Threadprivate 變數於 %C 是元件的共同區塊"
 
-#: fortran/openmp.c:3053
+#: fortran/openmp.c:3052
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET variable at %L previously mentioned in LINK clause and later in TO clause"
 msgstr ""
 
-#: fortran/openmp.c:3059
+#: fortran/openmp.c:3058
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET variable at %L previously mentioned in TO clause and later in LINK clause"
 msgstr ""
 
-#: fortran/openmp.c:3063
+#: fortran/openmp.c:3062
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable at %L mentioned multiple times in clauses of the same OMP DECLARE TARGET directive"
 msgstr ""
 
-#: fortran/openmp.c:3078
+#: fortran/openmp.c:3077
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET COMMON at %L previously mentioned in LINK clause and later in TO clause"
 msgstr ""
 
-#: fortran/openmp.c:3084
+#: fortran/openmp.c:3083
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET COMMON at %L previously mentioned in TO clause and later in LINK clause"
 msgstr ""
 
-#: fortran/openmp.c:3088
+#: fortran/openmp.c:3087
 #, gcc-internal-format, gfc-internal-format
 msgid "COMMON at %L mentioned multiple times in clauses of the same OMP DECLARE TARGET directive"
 msgstr ""
 
-#: fortran/openmp.c:3115
+#: fortran/openmp.c:3114
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$OMP DECLARE TARGET list at %C"
 msgstr "語法時發生錯誤 !$OMP THREADPRIVATE 清單於 %C"
 
-#: fortran/openmp.c:3147
+#: fortran/openmp.c:3146
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate variable at %C is an element of a COMMON block"
 msgstr "Threadprivate 變數於 %C 是元件的共同區塊"
 
-#: fortran/openmp.c:3184
+#: fortran/openmp.c:3183
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after OMP THREADPRIVATE at %C"
 msgstr "未預期的垃圾之後 $OMP 已排序的敘述於 %C"
 
-#: fortran/openmp.c:3191
+#: fortran/openmp.c:3190
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$OMP THREADPRIVATE list at %C"
 msgstr "語法時發生錯誤 !$OMP THREADPRIVATE 清單於 %C"
 
-#: fortran/openmp.c:3405
+#: fortran/openmp.c:3404
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after TASKWAIT clause at %C"
 msgstr "未預期的垃圾之後 TASKWAIT 子句於 %C"
 
-#: fortran/openmp.c:3419
+#: fortran/openmp.c:3418
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after TASKYIELD clause at %C"
 msgstr "未預期的垃圾之後 TASKYIELD 子句於 %C"
 
-#: fortran/openmp.c:3478
+#: fortran/openmp.c:3477
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP WORKSHARE statement at %C"
 msgstr "未預期的垃圾之後 $OMP WORKSHARE 敘述於 %C"
 
-#: fortran/openmp.c:3492
+#: fortran/openmp.c:3491
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP MASTER statement at %C"
 msgstr "未預期的垃圾之後 $OMP 主敘述於 %C"
 
-#: fortran/openmp.c:3551
+#: fortran/openmp.c:3550
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP ATOMIC statement at %C"
 msgstr "未預期的垃圾之後 $OMP 基元的敘述於 %C"
 
-#: fortran/openmp.c:3578
+#: fortran/openmp.c:3577
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP BARRIER statement at %C"
 msgstr "未預期的垃圾之後 $OMP 障礙敘述於 %C"
 
-#: fortran/openmp.c:3592
+#: fortran/openmp.c:3591
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP TASKGROUP statement at %C"
 msgstr "未預期的垃圾之後 $OMP 主敘述於 %C"
 
-#: fortran/openmp.c:3642
+#: fortran/openmp.c:3641
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP CANCELLATION POINT statement at %C"
 msgstr "未預期的垃圾之後 $OMP 基元的敘述於 %C"
 
-#: fortran/openmp.c:3662
+#: fortran/openmp.c:3661
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after NOWAIT clause at %C"
 msgstr "未預期的垃圾之後 NOWAIT 子句於 %C"
 
-#: fortran/openmp.c:3704
+#: fortran/openmp.c:3703
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s clause at %L requires a scalar INTEGER expression"
 msgstr "NUM_THREADS 子句於 %L 需要純量整數運算式"
 
-#: fortran/openmp.c:3715
+#: fortran/openmp.c:3714
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "INTEGER expression of %s clause at %L must be positive"
 msgstr "大小於 %L 必須是正值"
 
-#: fortran/openmp.c:3726
+#: fortran/openmp.c:3725
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "INTEGER expression of %s clause at %L must be non-negative"
 msgstr "單元號碼在中敘述於 %L 必須是 non-negative"
 
-#: fortran/openmp.c:3737
+#: fortran/openmp.c:3736
 #, fuzzy, gcc-internal-format
 msgid "POINTER object %qs of derived type in %s clause at %L"
 msgstr "指標物件『%s』在中 %s 子句於 %L"
 
-#: fortran/openmp.c:3740
+#: fortran/openmp.c:3739
 #, fuzzy, gcc-internal-format
 msgid "Cray pointer object %qs of derived type in %s clause at %L"
 msgstr "Cray 指標『%s』在中 %s 子句於 %L"
 
-#: fortran/openmp.c:3743
+#: fortran/openmp.c:3742
 #, fuzzy, gcc-internal-format
 msgid "Cray pointee object %qs of derived type in %s clause at %L"
 msgstr "Cray 點『%s』在中 %s 子句於 %L"
 
-#: fortran/openmp.c:3749 fortran/openmp.c:4687
+#: fortran/openmp.c:3748 fortran/openmp.c:4686
 #, fuzzy, gcc-internal-format
 msgid "POINTER object %qs of polymorphic type in %s clause at %L"
 msgstr "指標物件『%s』在中 %s 子句於 %L"
 
-#: fortran/openmp.c:3754
+#: fortran/openmp.c:3753
 #, fuzzy, gcc-internal-format
 msgid "Cray pointer object %qs of polymorphic type in %s clause at %L"
 msgstr "Cray 指標『%s』在中 %s 子句於 %L"
 
-#: fortran/openmp.c:3759
+#: fortran/openmp.c:3758
 #, fuzzy, gcc-internal-format
 msgid "Cray pointee object %qs of polymorphic type in %s clause at %L"
 msgstr "Cray 點『%s』在中 %s 子句於 %L"
 
-#: fortran/openmp.c:3769 fortran/openmp.c:4385 fortran/openmp.c:4490
+#: fortran/openmp.c:3768 fortran/openmp.c:4384 fortran/openmp.c:4489
 #, fuzzy, gcc-internal-format
 msgid "Assumed size array %qs in %s clause at %L"
 msgstr "假設的大小陣列『%s』在中 %s 子句於 %L"
 
-#: fortran/openmp.c:3772
+#: fortran/openmp.c:3771
 #, fuzzy, gcc-internal-format
 msgid "Assumed rank array %qs in %s clause at %L"
 msgstr "假設的大小陣列『%s』在中 %s 子句於 %L"
 
-#: fortran/openmp.c:3776
+#: fortran/openmp.c:3775
 #, fuzzy, gcc-internal-format
 msgid "Noncontiguous deferred shape array %qs in %s clause at %L"
 msgstr "假設的大小陣列『%s』在中 %s 子句於 %L"
 
-#: fortran/openmp.c:3784
+#: fortran/openmp.c:3783
 #, fuzzy, gcc-internal-format
 msgid "ALLOCATABLE object %qs of derived type in %s clause at %L"
 msgstr "指標物件『%s』在中 %s 子句於 %L"
 
-#: fortran/openmp.c:3789
+#: fortran/openmp.c:3788
 #, fuzzy, gcc-internal-format
 msgid "ALLOCATABLE object %qs of polymorphic type in %s clause at %L"
 msgstr "指標物件『%s』在中 %s 子句於 %L"
 
-#: fortran/openmp.c:3801 fortran/openmp.c:4480
+#: fortran/openmp.c:3800 fortran/openmp.c:4479
 #, fuzzy, gcc-internal-format
 msgid "POINTER object %qs in %s clause at %L"
 msgstr "指標物件『%s』在中 %s 子句於 %L"
 
-#: fortran/openmp.c:3806 fortran/openmp.c:4691
+#: fortran/openmp.c:3805 fortran/openmp.c:4690
 #, fuzzy, gcc-internal-format
 msgid "Cray pointer object %qs in %s clause at %L"
 msgstr "Cray 指標『%s』在中 %s 子句於 %L"
 
-#: fortran/openmp.c:3811 fortran/openmp.c:4694
+#: fortran/openmp.c:3810 fortran/openmp.c:4693
 #, fuzzy, gcc-internal-format
 msgid "Cray pointee object %qs in %s clause at %L"
 msgstr "Cray 點『%s』在中 %s 子句於 %L"
 
-#: fortran/openmp.c:3816 fortran/openmp.c:4682
+#: fortran/openmp.c:3815 fortran/openmp.c:4681
 #, fuzzy, gcc-internal-format
 msgid "ALLOCATABLE object %qs in %s clause at %L"
 msgstr "指標物件『%s』在中 %s 子句於 %L"
 
-#: fortran/openmp.c:3819
+#: fortran/openmp.c:3818
 #, fuzzy, gcc-internal-format
 msgid "VALUE object %qs in %s clause at %L"
 msgstr "指標物件『%s』在中 %s 子句於 %L"
 
-#: fortran/openmp.c:3862
+#: fortran/openmp.c:3861
 #, gcc-internal-format, gfc-internal-format
 msgid "Implicitly declared function %s used in !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:3911
+#: fortran/openmp.c:3910
 #, gcc-internal-format, gfc-internal-format
 msgid "Implicitly declared subroutine %s used in !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:3944
+#: fortran/openmp.c:3943
 #, gcc-internal-format, gfc-internal-format
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:3952 fortran/openmp.c:3963 fortran/resolve.c:10028
-#: fortran/resolve.c:11295
+#: fortran/openmp.c:3951 fortran/openmp.c:3962 fortran/resolve.c:10041
+#: fortran/resolve.c:11315
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "如果子句於 %L 需要純量邏輯的運算式"
 
-#: fortran/openmp.c:3967
+#: fortran/openmp.c:3966
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause without modifier at %L used together with IF clauses with modifiers"
 msgstr ""
 
-#: fortran/openmp.c:4044
+#: fortran/openmp.c:4043
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause modifier %s at %L not appropriate for the current OpenMP construct"
 msgstr ""
 
-#: fortran/openmp.c:4054
+#: fortran/openmp.c:4053
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FINAL clause at %L requires a scalar LOGICAL expression"
 msgstr "最後的子句於 %L 需要純量邏輯的運算式"
 
-#: fortran/openmp.c:4064
+#: fortran/openmp.c:4063
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SCHEDULE clause's chunk_size at %L requires a scalar INTEGER expression"
 msgstr "排程子句 chunksize 於 %L 需要純量整數運算式(_S)"
 
-#: fortran/openmp.c:4069
+#: fortran/openmp.c:4068
 #, gcc-internal-format, gfc-internal-format
 msgid "INTEGER expression of SCHEDULE clause's chunk_size at %L must be positive"
 msgstr ""
 
-#: fortran/openmp.c:4084
+#: fortran/openmp.c:4083
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' has not been assigned a target label at %L"
 msgid "Variable %qs is not a dummy argument at %L"
 msgstr "變數「%s」在 %L 尚未指派到目標標籤"
 
-#: fortran/openmp.c:4116
+#: fortran/openmp.c:4115 fortran/openmp.c:5998
 #, fuzzy, gcc-internal-format
 msgid "Object %qs is not a variable at %L"
 msgstr "物件『%s』並非變數於 %L"
 
-#: fortran/openmp.c:4132 fortran/openmp.c:4143 fortran/openmp.c:4151
-#: fortran/openmp.c:4162 fortran/openmp.c:4174 fortran/openmp.c:4189
-#: fortran/openmp.c:6023
+#: fortran/openmp.c:4131 fortran/openmp.c:4142 fortran/openmp.c:4150
+#: fortran/openmp.c:4161 fortran/openmp.c:4173 fortran/openmp.c:4188
+#: fortran/openmp.c:6028
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs present on multiple clauses at %L"
 msgstr "符號『%s』呈現於多重子句於 %L"
 
-#: fortran/openmp.c:4196
+#: fortran/openmp.c:4195
 #, fuzzy, gcc-internal-format
 msgid "Array %qs is not permitted in reduction at %L"
 msgstr "陣列區段無法允許的在中『%s』呼叫於 %L"
 
-#: fortran/openmp.c:4209
+#: fortran/openmp.c:4208
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs present on both FROM and TO clauses at %L"
 msgstr "符號『%s』呈現於多重子句於 %L"
 
-#: fortran/openmp.c:4231
+#: fortran/openmp.c:4230
 #, fuzzy, gcc-internal-format
 msgid "Non-THREADPRIVATE object %qs in COPYIN clause at %L"
 msgstr "Non-THREADPRIVATE 物件『%s』在中 COPYIN 子句於 %L"
 
-#: fortran/openmp.c:4239
+#: fortran/openmp.c:4238
 #, fuzzy, gcc-internal-format
 msgid "Assumed size array %qs in COPYPRIVATE clause at %L"
 msgstr "假設的大小陣列『%s』在中 COPYPRIVATE 子句於 %L"
 
-#: fortran/openmp.c:4242
+#: fortran/openmp.c:4241
 #, fuzzy, gcc-internal-format
 msgid "INTENT(IN) POINTER %qs in COPYPRIVATE clause at %L"
 msgstr "假設的大小陣列『%s』在中 COPYPRIVATE 子句於 %L"
 
-#: fortran/openmp.c:4250
+#: fortran/openmp.c:4249
 #, fuzzy, gcc-internal-format
 msgid "THREADPRIVATE object %qs in SHARED clause at %L"
 msgstr "THREADPRIVATE 物件『%s』在中共享的子句於 %L"
 
-#: fortran/openmp.c:4253
+#: fortran/openmp.c:4252
 #, fuzzy, gcc-internal-format
 msgid "Cray pointee %qs in SHARED clause at %L"
 msgstr "Cray 點『%s』在中共享的子句於 %L"
 
-#: fortran/openmp.c:4256
+#: fortran/openmp.c:4255
 #, fuzzy, gcc-internal-format
 msgid "ASSOCIATE name %qs in SHARED clause at %L"
 msgstr "THREADPRIVATE 物件『%s』在中共享的子句於 %L"
 
-#: fortran/openmp.c:4271
+#: fortran/openmp.c:4270
 #, gcc-internal-format
 msgid "%qs in ALIGNED clause must be POINTER, ALLOCATABLE, Cray pointer or C_PTR at %L"
 msgstr ""
 
-#: fortran/openmp.c:4283
+#: fortran/openmp.c:4282
 #, fuzzy, gcc-internal-format
 msgid "%qs in ALIGNED clause at %L requires a scalar positive constant integer alignment expression"
 msgstr "崩潰引數需要正面的常數整數運算式"
 
-#: fortran/openmp.c:4302
+#: fortran/openmp.c:4301
 #, gcc-internal-format, gfc-internal-format
 msgid "SINK dependence type only allowed on ORDERED directive at %L"
 msgstr ""
 
-#: fortran/openmp.c:4306
+#: fortran/openmp.c:4305
 #, gcc-internal-format, gfc-internal-format
 msgid "DEPEND SINK used together with DEPEND SOURCE on the same construct at %L"
 msgstr ""
 
-#: fortran/openmp.c:4316
+#: fortran/openmp.c:4315
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "accumulator is not a constant integer"
 msgid "SINK addend not a constant integer at %L"
 msgstr "累加數不是一個整常數"
 
-#: fortran/openmp.c:4322
+#: fortran/openmp.c:4321
 #, gcc-internal-format, gfc-internal-format
 msgid "Only SOURCE or SINK dependence types are allowed on ORDERED directive at %L"
 msgstr ""
 
-#: fortran/openmp.c:4333 fortran/openmp.c:4354
+#: fortran/openmp.c:4332 fortran/openmp.c:4353
 #, gcc-internal-format
 msgid "%qs in %s clause at %L is not a proper array section"
 msgstr ""
 
-#: fortran/openmp.c:4337
+#: fortran/openmp.c:4336
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coarrays not supported in %s clause at %L"
 msgstr "Cray 點『%s』在中 %s 子句於 %L"
 
-#: fortran/openmp.c:4346
+#: fortran/openmp.c:4345
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Stride should not be specified for array section in %s clause at %L"
 msgstr "假設的大小陣列『%s』在中 %s 子句於 %L"
 
-#: fortran/openmp.c:4367
+#: fortran/openmp.c:4366
 #, gcc-internal-format
 msgid "%qs in DEPEND clause at %L is a zero size array section"
 msgstr ""
 
-#: fortran/openmp.c:4403
+#: fortran/openmp.c:4402
 #, gcc-internal-format, gfc-internal-format
 msgid "TARGET%s with map-type other than TO, FROM, TOFROM, or ALLOC on MAP clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4419
+#: fortran/openmp.c:4418
 #, gcc-internal-format, gfc-internal-format
 msgid "TARGET ENTER DATA with map-type other than TO, or ALLOC on MAP clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4434
+#: fortran/openmp.c:4433
 #, gcc-internal-format, gfc-internal-format
 msgid "TARGET EXIT DATA with map-type other than FROM, RELEASE, or DELETE on MAP clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4450 fortran/openmp.c:4466
+#: fortran/openmp.c:4449 fortran/openmp.c:4465
 #, fuzzy, gcc-internal-format
 msgid "THREADPRIVATE object %qs in %s clause at %L"
 msgstr "THREADPRIVATE 物件『%s』在中 %s 子句於 %L"
 
-#: fortran/openmp.c:4453 fortran/openmp.c:4469
+#: fortran/openmp.c:4452 fortran/openmp.c:4468
 #, fuzzy, gcc-internal-format
 msgid "Cray pointee %qs in %s clause at %L"
 msgstr "Cray 點『%s』在中 %s 子句於 %L"
 
-#: fortran/openmp.c:4472
+#: fortran/openmp.c:4471
 #, fuzzy, gcc-internal-format
 msgid "ASSOCIATE name %qs in %s clause at %L"
 msgstr "指標物件『%s』在中 %s 子句於 %L"
 
-#: fortran/openmp.c:4477
+#: fortran/openmp.c:4476
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer %qs in %s clause at %L"
 msgstr "Cray 指標『%s』在中 %s 子句於 %L"
 
-#: fortran/openmp.c:4483
+#: fortran/openmp.c:4482
 #, fuzzy, gcc-internal-format
 msgid "Cray pointer %qs in %s clause at %L"
 msgstr "Cray 指標『%s』在中 %s 子句於 %L"
 
-#: fortran/openmp.c:4493
+#: fortran/openmp.c:4492
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs in %s clause is used in NAMELIST statement at %L"
 msgstr "變數『%s』在中 %s 子句被已用於名稱表列敘述於 %L"
 
 #. case OMP_LIST_REDUCTION:
-#: fortran/openmp.c:4503
+#: fortran/openmp.c:4502
 #, fuzzy, gcc-internal-format
 msgid "INTENT(IN) POINTER %qs in %s clause at %L"
 msgstr "指標物件『%s』在中 %s 子句於 %L"
 
-#: fortran/openmp.c:4596
+#: fortran/openmp.c:4595
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP DECLARE REDUCTION %s not found for type %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:4622
+#: fortran/openmp.c:4621
 #, gcc-internal-format, gfc-internal-format
 msgid "LINEAR clause modifier used on DO or SIMD construct at %L"
 msgstr ""
 
-#: fortran/openmp.c:4627
+#: fortran/openmp.c:4626
 #, gcc-internal-format, gfc-internal-format
 msgid "LINEAR clause specified together with ORDERED clause with argument at %L"
 msgstr ""
 
-#: fortran/openmp.c:4632
+#: fortran/openmp.c:4631
 #, fuzzy, gcc-internal-format
 msgid "LINEAR variable %qs must be INTEGER at %L"
 msgstr "%s 消除變數『%s』必須是整數於 %L"
 
-#: fortran/openmp.c:4637
+#: fortran/openmp.c:4636
 #, gcc-internal-format
 msgid "LINEAR dummy argument %qs with VALUE attribute with %s modifier at %L"
 msgstr ""
 
-#: fortran/openmp.c:4648
+#: fortran/openmp.c:4647
 #, fuzzy, gcc-internal-format
 msgid "%qs in LINEAR clause at %L requires a scalar integer linear-step expression"
 msgstr "最後的子句於 %L 需要純量邏輯的運算式"
 
-#: fortran/openmp.c:4665
+#: fortran/openmp.c:4664
 #, gcc-internal-format
 msgid "%qs in LINEAR clause at %L requires a constant integer linear-step expression or dummy argument specified in UNIFORM clause"
 msgstr ""
 
-#: fortran/openmp.c:4699
+#: fortran/openmp.c:4698
 #, gcc-internal-format
 msgid "%s clause variable %qs at %L is neither a POINTER nor an array"
 msgstr ""
 
-#: fortran/openmp.c:4731
+#: fortran/openmp.c:4730
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DIST_SCHEDULE clause's chunk_size at %L requires a scalar INTEGER expression"
 msgstr "排程子句 chunksize 於 %L 需要純量整數運算式(_S)"
 
-#: fortran/openmp.c:4763
+#: fortran/openmp.c:4762
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Incompatible use of TILE and COLLAPSE at %L"
 msgstr "不相容的分級在中 %s (%d 和 %d) 於 %L"
 
-#: fortran/openmp.c:4765
+#: fortran/openmp.c:4764
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE dependence type only allowed on ORDERED directive at %L"
 msgstr ""
 
-#: fortran/openmp.c:4778
+#: fortran/openmp.c:4777
 #, gcc-internal-format, gfc-internal-format
 msgid "%s must contain at least one MAP clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4875
+#: fortran/openmp.c:4874
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unexpected !$OMP ATOMIC expression at %L"
 msgstr "未預期的垃圾之後 $OMP 基元的敘述於 %C"
 
-#: fortran/openmp.c:4904
+#: fortran/openmp.c:4903
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC statement must set a scalar variable of intrinsic type at %L"
 msgstr "!$OMP 基元的敘述必須設定純量變數的 intrinsic 型態於 %L"
 
-#: fortran/openmp.c:4929
+#: fortran/openmp.c:4928
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC READ statement must read from a scalar variable of intrinsic type at %L"
 msgstr "!$OMP 基元的讀取敘述必須讀取從純量變數的 intrinsic 型態於 %L"
 
-#: fortran/openmp.c:4934
+#: fortran/openmp.c:4933
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "expr in !$OMP ATOMIC WRITE assignment var = expr must be scalar and cannot reference var at %L"
 msgstr "expr 在中 !$OMP 基元的寫入指派 var=expr 必須是純量和無法參考 var 於 %L"
 
-#: fortran/openmp.c:4956 fortran/openmp.c:5247
+#: fortran/openmp.c:4955 fortran/openmp.c:5246
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE capture statement must read from a scalar variable of intrinsic type at %L"
 msgstr "!$OMP 基元的擷取擷取敘述必須讀取從純量變數的 intrinsic 型態於 %L"
 
-#: fortran/openmp.c:4971
+#: fortran/openmp.c:4970
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE update statement must set a scalar variable of intrinsic type at %L"
 msgstr "!$OMP 基元的擷取更新敘述必須設定純量變數的 intrinsic 型態於 %L"
 
-#: fortran/openmp.c:4978 fortran/openmp.c:5254
+#: fortran/openmp.c:4977 fortran/openmp.c:5253
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE capture statement reads from different variable than update statement writes into at %L"
 msgstr "!$OMP 基元的擷取擷取敘述讀取從不同的變數比更新敘述寫入進入於 %L"
 
-#: fortran/openmp.c:4994
+#: fortran/openmp.c:4993
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC with ALLOCATABLE variable at %L"
 msgstr ""
 
-#: fortran/openmp.c:5036
+#: fortran/openmp.c:5035
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment operator must be binary +, *, -, /, .AND., .OR., .EQV. or .NEQV. at %L"
 msgstr "!$OMP 基元的指派運算子必須是+, *, -,/,.AND.,.OR.,.EQV。或.NEQV。於 %L"
 
-#: fortran/openmp.c:5084
+#: fortran/openmp.c:5083
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment must be var = var op expr or var = expr op var at %L"
 msgstr "!$OMP 基元的指派必須是 var=var op expr 或 var=expr op var 於 %L"
 
-#: fortran/openmp.c:5098
+#: fortran/openmp.c:5097
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC var = var op expr not mathematically equivalent to var = var op (expr) at %L"
 msgstr "!$OMP 基元的 var=var op expr 無法數學的 equivalent 到 var=var op (expr) 於 %L"
 
-#: fortran/openmp.c:5130
+#: fortran/openmp.c:5129
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "expr in !$OMP ATOMIC assignment var = var op expr must be scalar and cannot reference var at %L"
 msgstr "expr 在中 !$OMP 基元的指派 var=var op expr 必須是純量和無法參考 var 於 %L"
 
-#: fortran/openmp.c:5154
+#: fortran/openmp.c:5153
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment intrinsic IAND, IOR or IEOR must have two arguments at %L"
 msgstr "!$OMP 基元的指派 intrinsic IAND，IOR 或 IEOR 必須有兩引數於 %L"
 
-#: fortran/openmp.c:5161
+#: fortran/openmp.c:5160
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment intrinsic must be MIN, MAX, IAND, IOR or IEOR at %L"
 msgstr "!$OMP 基元的指派 intrinsic 必須是最小、最大、IAND，IOR 或 IEOR 於 %L"
 
-#: fortran/openmp.c:5178
+#: fortran/openmp.c:5177
 #, fuzzy, gcc-internal-format
 msgid "!$OMP ATOMIC intrinsic arguments except one must not reference %qs at %L"
 msgstr "!$OMP 基元的 intrinsic 引數除了一個必須不參考『%s』於 %L"
 
-#: fortran/openmp.c:5185
+#: fortran/openmp.c:5184
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC intrinsic arguments must be scalar at %L"
 msgstr "!$OMP 基元的 intrinsic 引數必須是純量於 %L"
 
-#: fortran/openmp.c:5193
+#: fortran/openmp.c:5192
 #, fuzzy, gcc-internal-format
 msgid "First or last !$OMP ATOMIC intrinsic argument must be %qs at %L"
 msgstr "第一個或最後一筆 !$OMP 基元的 intrinsic 引數必須是『%s』於 %L"
 
-#: fortran/openmp.c:5211
+#: fortran/openmp.c:5210
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment must have an operator or intrinsic on right hand side at %L"
 msgstr "!$OMP 基元的指派必須有運算子或 intrinsic 右側手側邊於 %L"
 
-#: fortran/openmp.c:5225
+#: fortran/openmp.c:5224
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE capture statement must set a scalar variable of intrinsic type at %L"
 msgstr "!$OMP 基元的擷取擷取敘述必須設定純量變數的 intrinsic 型態於 %L"
 
-#: fortran/openmp.c:5544
+#: fortran/openmp.c:5543
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s cannot be a DO WHILE or DO without loop control at %L"
 msgstr "!$OMP 做無法做當或做而無需迴圈控制於 %L"
 
-#: fortran/openmp.c:5550
+#: fortran/openmp.c:5549
 #, gcc-internal-format, gfc-internal-format
 msgid "%s cannot be a DO CONCURRENT loop at %L"
 msgstr ""
 
-#: fortran/openmp.c:5556
+#: fortran/openmp.c:5555
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable must be of type integer at %L"
 msgstr "!$OMP 做迭代變數必須是的型態整數於 %L"
 
-#: fortran/openmp.c:5560
+#: fortran/openmp.c:5559
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable must not be THREADPRIVATE at %L"
 msgstr "!$OMP 做迭代變數必須不是 THREADPRIVATE 於 %L"
 
-#: fortran/openmp.c:5573
+#: fortran/openmp.c:5572
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable present on clause other than PRIVATE or LASTPRIVATE at %L"
 msgstr "!$OMP 做迭代變數呈現於子句不同於私人的或 LASTPRIVATE 於 %L"
 
-#: fortran/openmp.c:5577
+#: fortran/openmp.c:5576
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable present on clause other than LASTPRIVATE at %L"
 msgstr "!$OMP 做迭代變數呈現於子句不同於私人的或 LASTPRIVATE 於 %L"
 
-#: fortran/openmp.c:5581
+#: fortran/openmp.c:5580
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable present on clause other than LINEAR at %L"
 msgstr "!$OMP 做迭代變數呈現於子句不同於私人的或 LASTPRIVATE 於 %L"
 
-#: fortran/openmp.c:5599
+#: fortran/openmp.c:5598
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s collapsed loops don't form rectangular iteration space at %L"
 msgstr "!$OMP 做崩潰的迴圈不表單矩形迭代空格於 %L"
 
-#: fortran/openmp.c:5611
+#: fortran/openmp.c:5610
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "collapsed %s loops not perfectly nested at %L"
 msgstr "崩潰 !$OMP 做迴圈無法 perfectly 巢狀的於 %L"
 
-#: fortran/openmp.c:5620 fortran/openmp.c:5628
+#: fortran/openmp.c:5619 fortran/openmp.c:5627
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for collapsed %s at %L"
 msgstr "不足做迴圈用於崩潰 !$OMP 做於 %L"
 
-#: fortran/openmp.c:5712 fortran/openmp.c:5725
+#: fortran/openmp.c:5711 fortran/openmp.c:5724
 #, gcc-internal-format, gfc-internal-format
 msgid "The %s directive cannot be specified within a %s region at %L"
 msgstr ""
 
-#: fortran/openmp.c:5744
+#: fortran/openmp.c:5743
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP cannot be a DO WHILE or DO without loop control at %L"
 msgstr "!$OMP 做無法做當或做而無需迴圈控制於 %L"
 
-#: fortran/openmp.c:5750
+#: fortran/openmp.c:5749
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP iteration variable must be of type integer at %L"
 msgstr "!$OMP 做迭代變數必須是的型態整數於 %L"
 
-#: fortran/openmp.c:5766
+#: fortran/openmp.c:5765
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s loops don't form rectangular iteration space at %L"
 msgstr "!$OMP 做崩潰的迴圈不表單矩形迭代空格於 %L"
 
-#: fortran/openmp.c:5778
+#: fortran/openmp.c:5777
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s !$ACC LOOP loops not perfectly nested at %L"
 msgstr "崩潰 !$OMP 做迴圈無法 perfectly 巢狀的於 %L"
 
-#: fortran/openmp.c:5788 fortran/openmp.c:5797
+#: fortran/openmp.c:5787 fortran/openmp.c:5796
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for %s !$ACC LOOP at %L"
 msgstr "不足做迴圈用於崩潰 !$OMP 做於 %L"
 
-#: fortran/openmp.c:5812 fortran/openmp.c:5819
+#: fortran/openmp.c:5811 fortran/openmp.c:5818
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s in PARALLEL region doesn't allow %s arguments at %L"
 msgstr ""
 
-#: fortran/openmp.c:5841
+#: fortran/openmp.c:5840
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside another loop parallelized across gangs at %L"
 msgstr ""
 
-#: fortran/openmp.c:5845 fortran/openmp.c:5849
+#: fortran/openmp.c:5844 fortran/openmp.c:5848
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside loop parallelized across workers at %L"
 msgstr ""
 
-#: fortran/openmp.c:5856
+#: fortran/openmp.c:5855
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across workers at %L"
 msgstr ""
 
-#: fortran/openmp.c:5860
+#: fortran/openmp.c:5859
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across vectors at %L"
 msgstr ""
 
-#: fortran/openmp.c:5866
+#: fortran/openmp.c:5865
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across vectors is not allowed inside another loop parallelized across vectors at %L"
 msgstr ""
 
-#: fortran/openmp.c:5878
+#: fortran/openmp.c:5877
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgid "Clause SEQ conflicts with INDEPENDENT at %L"
 msgstr "INTENT (%s) 與 INTENT(%s) 在 %L 衝突"
 
-#: fortran/openmp.c:5880
+#: fortran/openmp.c:5879
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "Clause SEQ conflicts with GANG at %L"
 msgstr "%s 屬性與 %s 屬性在 %L 處衝突"
 
-#: fortran/openmp.c:5882
+#: fortran/openmp.c:5881
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with WORKER at %L"
 msgstr "鑄型標籤於 %L 衝突與來源標籤於 %L"
 
-#: fortran/openmp.c:5884
+#: fortran/openmp.c:5883
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with VECTOR at %L"
 msgstr "鑄型標籤於 %L 衝突與來源標籤於 %L"
 
-#: fortran/openmp.c:5886
+#: fortran/openmp.c:5885
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with AUTO at %L"
 msgstr "鑄型標籤於 %L 衝突與來源標籤於 %L"
 
-#: fortran/openmp.c:5891
+#: fortran/openmp.c:5890
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "Clause AUTO conflicts with GANG at %L"
 msgstr "%s 屬性與 %s 屬性在 %L 處衝突"
 
-#: fortran/openmp.c:5893
+#: fortran/openmp.c:5892
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with WORKER at %L"
 msgstr "鑄型標籤於 %L 衝突與來源標籤於 %L"
 
-#: fortran/openmp.c:5895
+#: fortran/openmp.c:5894
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with VECTOR at %L"
 msgstr "鑄型標籤於 %L 衝突與來源標籤於 %L"
 
-#: fortran/openmp.c:5899
+#: fortran/openmp.c:5898
 #, gcc-internal-format, gfc-internal-format
 msgid "Tiled loop cannot be parallelized across gangs, workers and vectors at the same time at %L"
 msgstr ""
 
-#: fortran/openmp.c:5934
+#: fortran/openmp.c:5933
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "TILE requires constant expression at %L"
 msgstr "%qE 並非常數運算式"
 
-#: fortran/openmp.c:5999
+#: fortran/openmp.c:6004
 #, fuzzy, gcc-internal-format
 msgid "PARAMETER object %qs is not allowed at %L"
 msgstr "指標物件『%s』在中 %s 子句於 %L"
 
-#: fortran/openmp.c:6006
+#: fortran/openmp.c:6011
 #, fuzzy, gcc-internal-format
 msgid "Array sections: %qs not allowed in !$ACC DECLARE at %L"
 msgstr "陣列區段無法允許的在中『%s』呼叫於 %L"
 
-#: fortran/openmp.c:6133
+#: fortran/openmp.c:6138
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP TARGET UPDATE at %L requires at least one TO or FROM clause"
 msgstr ""
 
-#: fortran/openmp.c:6155
+#: fortran/openmp.c:6160
 #, gcc-internal-format
 msgid "!$OMP DECLARE SIMD should refer to containing procedure %qs at %L"
 msgstr ""
 
-#: fortran/openmp.c:6179
+#: fortran/openmp.c:6184
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_PRIV or OMP_ORIG used in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6187
+#: fortran/openmp.c:6192
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_OUT or OMP_IN used in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6216
+#: fortran/openmp.c:6221
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid operator for !$OMP DECLARE REDUCTION %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:6238
+#: fortran/openmp.c:6243
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER length in !$OMP DECLARE REDUCTION %s not constant at %L"
 msgstr ""
 
-#: fortran/openmp.c:6254
+#: fortran/openmp.c:6259
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6269
+#: fortran/openmp.c:6274
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6279
+#: fortran/openmp.c:6284
 #, gcc-internal-format, gfc-internal-format
 msgid "One of actual subroutine arguments in INITIALIZER clause of !$OMP DECLARE REDUCTION must be OMP_PRIV at %L"
 msgstr ""
 
-#: fortran/openmp.c:6287
+#: fortran/openmp.c:6292
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing INITIALIZER clause for !$OMP DECLARE REDUCTION of derived type without default initializer at %L"
 msgstr ""
@@ -61359,497 +61437,497 @@
 msgid "Unclassifiable statement at %C"
 msgstr "%C 敘述無法歸類別"
 
-#: fortran/parse.c:629
+#: fortran/parse.c:631
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "OpenACC directives at %C may not appear in PURE procedures"
 msgstr "OpenMP 指令於 %C 可能無法出現在中 PURE 或 ELEMENTAL 程序"
 
-#: fortran/parse.c:705
+#: fortran/parse.c:707
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable OpenACC directive at %C"
 msgstr "Unclassifiable OpenMP 指令於 %C"
 
-#: fortran/parse.c:831 fortran/parse.c:1040
+#: fortran/parse.c:835 fortran/parse.c:1044
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "OpenMP directives other than SIMD or DECLARE TARGET at %C may not appear in PURE or ELEMENTAL procedures"
 msgstr "OpenMP 指令於 %C 可能無法出現在中 PURE 或 ELEMENTAL 程序"
 
-#: fortran/parse.c:1024
+#: fortran/parse.c:1028
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable OpenMP directive at %C"
 msgstr "Unclassifiable OpenMP 指令於 %C"
 
-#: fortran/parse.c:1076
+#: fortran/parse.c:1080
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable GCC directive at %C"
 msgstr "Unclassifiable GCC 指令於 %C"
 
-#: fortran/parse.c:1135 fortran/parse.c:1362
+#: fortran/parse.c:1139 fortran/parse.c:1366
 #, gcc-internal-format, gfc-internal-format
 msgid "Zero is not a valid statement label at %C"
 msgstr "零不是 %C 處的一個有效的敘述標籤"
 
-#: fortran/parse.c:1142 fortran/parse.c:1354
+#: fortran/parse.c:1146 fortran/parse.c:1358
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-numeric character in statement label at %C"
 msgstr "Non-numeric 字元在中敘述標貼於 %C"
 
-#: fortran/parse.c:1154 fortran/parse.c:1403
+#: fortran/parse.c:1158 fortran/parse.c:1407
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Semicolon at %C needs to be preceded by statement"
 msgstr "分號於 %C 需要被前繼由敘述"
 
-#: fortran/parse.c:1161 fortran/parse.c:1418
+#: fortran/parse.c:1165 fortran/parse.c:1422
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Statement label without statement at %L"
 msgstr "忽略敘述標貼在中清空敘述於 %L"
 
-#: fortran/parse.c:1224 fortran/parse.c:1405
+#: fortran/parse.c:1228 fortran/parse.c:1409
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Semicolon at %C without preceding statement"
 msgstr "Fortran 2008:分號於 %C 而無需前繼敘述"
 
-#: fortran/parse.c:1247 fortran/parse.c:1381
+#: fortran/parse.c:1251 fortran/parse.c:1385
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad continuation line at %C"
 msgstr "%C 處錯誤的續列"
 
-#: fortran/parse.c:1679
+#: fortran/parse.c:1683
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT statement at %L does not have a statement label"
 msgstr "%L 處 FORMAT 敘述沒有敘述標籤"
 
-#: fortran/parse.c:2435
+#: fortran/parse.c:2439
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_ascii_statement(): Bad statement code"
 msgstr "gfc_trans_code()：錯誤的敘述程式碼"
 
-#: fortran/parse.c:2577
+#: fortran/parse.c:2581
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement at %C"
 msgstr "非預期的 %s 敘述於 %C 處"
 
-#: fortran/parse.c:2732
+#: fortran/parse.c:2736
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot follow %s statement at %L"
 msgstr "%s 敘述在 %C 處不能跟隨 %s 敘述在 %L 處"
 
-#: fortran/parse.c:2749
+#: fortran/parse.c:2753
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of file in '%s'"
 msgid "Unexpected end of file in %qs"
 msgstr "「%s」中非預期的檔案結尾"
 
-#: fortran/parse.c:2784
+#: fortran/parse.c:2788
 #, fuzzy, gcc-internal-format
 msgid "Derived-type %qs with SEQUENCE must not have a CONTAINS section at %C"
 msgstr "衍生類型『%s』與序列必須不有含有區段於 %C"
 
-#: fortran/parse.c:2787
+#: fortran/parse.c:2791
 #, fuzzy, gcc-internal-format
 msgid "Derived-type %qs with BIND(C) must not have a CONTAINS section at %C"
 msgstr "衍生類型『%s』與繫結©必須不有含有區段於 %C"
 
-#: fortran/parse.c:2807
+#: fortran/parse.c:2811
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Components in TYPE at %C must precede CONTAINS"
 msgstr "成分在中型態於 %C 必須前繼含有"
 
-#: fortran/parse.c:2811
+#: fortran/parse.c:2815
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type-bound procedure at %C"
 msgstr "Fortran 2003: Type-bound 程序於 %C"
 
-#: fortran/parse.c:2819
+#: fortran/parse.c:2823
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "GENERIC binding at %C"
 msgstr "垃圾之後通用繫結於 %C"
 
-#: fortran/parse.c:2827
+#: fortran/parse.c:2831
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure declaration at %C"
 msgstr "Fortran 2003: 最後的程序宣告於 %C"
 
-#: fortran/parse.c:2839
+#: fortran/parse.c:2843
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Derived type definition at %C with empty CONTAINS section"
 msgstr "Fortran 2008:衍生類型定義於 %C 與清空含有區段"
 
-#: fortran/parse.c:2849 fortran/parse.c:3304
+#: fortran/parse.c:2853 fortran/parse.c:3308
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement in TYPE at %C must be inside a MODULE"
 msgstr "私人的敘述在中型態於 %C 必須是內部模組"
 
-#: fortran/parse.c:2856
+#: fortran/parse.c:2860
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede procedure bindings"
 msgstr "私人的敘述於 %C 必須前繼程序繫結"
 
-#: fortran/parse.c:2863 fortran/parse.c:3317
+#: fortran/parse.c:2867 fortran/parse.c:3321
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PRIVATE statement at %C"
 msgstr "%C 處重複的 PRIVATE 敘述"
 
-#: fortran/parse.c:2873
+#: fortran/parse.c:2877
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede CONTAINS"
 msgstr "序列敘述於 %C 必須前繼含有"
 
-#: fortran/parse.c:2877
+#: fortran/parse.c:2881
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Already inside a CONTAINS block at %C"
 msgstr "已經內部含有區塊於 %C"
 
-#: fortran/parse.c:2996
+#: fortran/parse.c:3000
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component %s at %L of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray, which is not possible as the component has the pointer attribute"
 msgstr "成分 %s 於 %L 的型態 LOCK_TYPE 必須有 codimension 或是 subcomponent 的 coarray，該項不是可能的做為成分有指標屬性"
 
-#: fortran/parse.c:3002
+#: fortran/parse.c:3006
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer component %s at %L has a noncoarray subcomponent of type LOCK_TYPE, which must have a codimension or be a subcomponent of a coarray"
 msgstr "指標成分 %s 於 %L 有 noncoarray subcomponent 的型態 LOCK_TYPE，該項必須有 codimension 或是 subcomponent 的 coarray"
 
-#: fortran/parse.c:3007
+#: fortran/parse.c:3011
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L of type LOCK_TYPE must have a codimension"
 msgstr "Allocatable 成分 %s 於 %L 的型態 LOCK_TYPE 必須有 codimension"
 
-#: fortran/parse.c:3011
+#: fortran/parse.c:3015
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L must have a codimension as it has a noncoarray subcomponent of type LOCK_TYPE"
 msgstr "Allocatable 成分 %s 於 %L 必須有 codimension 做為它有 noncoarray subcomponent 的型態 LOCK_TYPE"
 
-#: fortran/parse.c:3016
+#: fortran/parse.c:3020
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as already a coarray subcomponent exists)"
 msgstr "Noncoarray 成分 %s 於 %L 的型態 LOCK_TYPE 或與 subcomponent 的型態 LOCK_TYPE 必須有 codimension 或是 subcomponent 的 coarray。(變數的型態 %s 可能無法有 codimension 做為已經 coarray subcomponent 存在)"
 
-#: fortran/parse.c:3023
+#: fortran/parse.c:3027
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as %s at %L has a codimension or a coarray subcomponent)"
 msgstr "Noncoarray 成分 %s 於 %L 的型態 LOCK_TYPE 或與 subcomponent 的型態 LOCK_TYPE 必須有 codimension 或是 subcomponent 的 coarray。(變數的型態 %s 可能無法有 codimension 做為 %s 於 %L 有 codimension 或 coarray subcomponent)"
 
-#: fortran/parse.c:3033
+#: fortran/parse.c:3037
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component %s at %L of type EVENT_TYPE must have a codimension or be a subcomponent of a coarray, which is not possible as the component has the pointer attribute"
 msgstr "成分 %s 於 %L 的型態 LOCK_TYPE 必須有 codimension 或是 subcomponent 的 coarray，該項不是可能的做為成分有指標屬性"
 
-#: fortran/parse.c:3039
+#: fortran/parse.c:3043
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer component %s at %L has a noncoarray subcomponent of type EVENT_TYPE, which must have a codimension or be a subcomponent of a coarray"
 msgstr "指標成分 %s 於 %L 有 noncoarray subcomponent 的型態 LOCK_TYPE，該項必須有 codimension 或是 subcomponent 的 coarray"
 
-#: fortran/parse.c:3044
+#: fortran/parse.c:3048
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L of type EVENT_TYPE must have a codimension"
 msgstr "Allocatable 成分 %s 於 %L 的型態 LOCK_TYPE 必須有 codimension"
 
-#: fortran/parse.c:3048
+#: fortran/parse.c:3052
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L must have a codimension as it has a noncoarray subcomponent of type EVENT_TYPE"
 msgstr "Allocatable 成分 %s 於 %L 必須有 codimension 做為它有 noncoarray subcomponent 的型態 LOCK_TYPE"
 
-#: fortran/parse.c:3053
+#: fortran/parse.c:3057
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as already a coarray subcomponent exists)"
 msgstr "Noncoarray 成分 %s 於 %L 的型態 LOCK_TYPE 或與 subcomponent 的型態 LOCK_TYPE 必須有 codimension 或是 subcomponent 的 coarray。(變數的型態 %s 可能無法有 codimension 做為已經 coarray subcomponent 存在)"
 
-#: fortran/parse.c:3060
+#: fortran/parse.c:3064
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as %s at %L has a codimension or a coarray subcomponent)"
 msgstr "Noncoarray 成分 %s 於 %L 的型態 LOCK_TYPE 或與 subcomponent 的型態 LOCK_TYPE 必須有 codimension 或是 subcomponent 的 coarray。(變數的型態 %s 可能無法有 codimension 做為 %s 於 %L 有 codimension 或 coarray subcomponent)"
 
-#: fortran/parse.c:3112
+#: fortran/parse.c:3116
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "failed to create map component '%s'"
 msgstr "開啟 %s 時失敗"
 
-#: fortran/parse.c:3145
+#: fortran/parse.c:3149
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "failed to create union component '%s'"
 msgstr "開啟 %s 時失敗"
 
-#: fortran/parse.c:3200
+#: fortran/parse.c:3204
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in data declaration at %C"
 msgid "Syntax error in nested structure declaration at %C"
 msgstr "%C 處資料宣告語法錯誤"
 
-#: fortran/parse.c:3287
+#: fortran/parse.c:3291
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside CONTAINS"
 msgstr "最後的宣告於 %C 必須是內部含有"
 
-#: fortran/parse.c:3295
+#: fortran/parse.c:3299
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Derived type definition at %C without components"
 msgstr "Fortran 2003:衍生類型定義於 %C 而無需成分"
 
-#: fortran/parse.c:3311
+#: fortran/parse.c:3315
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede structure components"
 msgstr "私人的敘述於 %C 必須前繼結構成分"
 
-#: fortran/parse.c:3328
+#: fortran/parse.c:3332
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede structure components"
 msgstr "序列敘述於 %C 必須前繼結構成分"
 
-#: fortran/parse.c:3334
+#: fortran/parse.c:3338
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE attribute at %C already specified in TYPE statement"
 msgstr "序列屬性於 %C 已經指定的在中型態敘述"
 
-#: fortran/parse.c:3339
+#: fortran/parse.c:3343
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SEQUENCE statement at %C"
 msgstr "%C 處重複的 SEQUENCE 敘述"
 
-#: fortran/parse.c:3349
+#: fortran/parse.c:3353
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS block in derived type definition at %C"
 msgstr "Fortran 2003: 含有區塊在中衍生類型定義於 %C"
 
-#: fortran/parse.c:3407
+#: fortran/parse.c:3411
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENUM declaration at %C has no ENUMERATORS"
 msgstr "ENUM 宣告於 %C 沒有任何列舉值"
 
-#: fortran/parse.c:3494
+#: fortran/parse.c:3498
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in INTERFACE block at %C"
 msgstr "非預期的 %s 敘述出現在 %C 處的 INTERFACE 區塊中"
 
-#: fortran/parse.c:3518
+#: fortran/parse.c:3522
 #, fuzzy, gcc-internal-format
 msgid "Name %qs of ABSTRACT INTERFACE at %C cannot be the same as an intrinsic type"
 msgstr "名稱『%s』的摘要介面於 %C 無法如同 intrinsic 型態"
 
-#: fortran/parse.c:3552
+#: fortran/parse.c:3556
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement at %C in INTERFACE body"
 msgstr "非預期的 %s 敘述出現在 %C 處的 INTERFACE 體中"
 
-#: fortran/parse.c:3570
+#: fortran/parse.c:3574
 #, fuzzy, gcc-internal-format
 msgid "INTERFACE procedure %qs at %L has the same name as the enclosing procedure"
 msgstr "介面程序『%s』於 %L 有同名做為封閉程序"
 
-#: fortran/parse.c:3700
+#: fortran/parse.c:3704
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement is not allowed inside of BLOCK at %C"
 msgstr "%s 敘述未被允許內部的區塊於 %C"
 
-#: fortran/parse.c:3732
+#: fortran/parse.c:3736
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement is not allowed inside of BLOCK DATA at %C"
 msgstr "%s 敘述未被允許內部的區塊於 %C"
 
-#: fortran/parse.c:3822
+#: fortran/parse.c:3826
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement must appear in a MODULE"
 msgstr "%s 敘述必須出現在 MODULE 中"
 
-#: fortran/parse.c:3830
+#: fortran/parse.c:3834
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C follows another accessibility specification"
 msgstr "%s 敘述於 %C 追隨另外的輔助工具規格"
 
-#: fortran/parse.c:3882
+#: fortran/parse.c:3886
 #, fuzzy, gcc-internal-format
 msgid "Bad kind expression for function %qs at %L"
 msgstr "不當的 kind 運算式用於函式『%s』於 %L"
 
-#: fortran/parse.c:3886
+#: fortran/parse.c:3890
 #, fuzzy, gcc-internal-format
 msgid "The type for function %qs at %L is not accessible"
 msgstr "型態用於函式『%s』於 %L 不是可存取"
 
-#: fortran/parse.c:3946
+#: fortran/parse.c:3950
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C follows previous unmasked ELSEWHERE"
 msgstr "其他情況下敘述於 %C 追隨前一個取消遮罩的其他情況下"
 
-#: fortran/parse.c:3968
+#: fortran/parse.c:3972
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in WHERE block at %C"
 msgstr "非預期的 %s 敘述出現在 %C 處的 WHERE 區塊中"
 
-#: fortran/parse.c:4027
+#: fortran/parse.c:4031
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in FORALL block at %C"
 msgstr "非預期的 %s 敘述出現在 %C 處的 FORALL 區塊中"
 
-#: fortran/parse.c:4078
+#: fortran/parse.c:4082
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSE IF statement at %C cannot follow ELSE statement at %L"
 msgstr "%C 處的 ELSE IF 敘述不能出現在 %L 處的 ELSE 敘述之後"
 
-#: fortran/parse.c:4096
+#: fortran/parse.c:4100
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ELSE statements at %L and %C"
 msgstr "%L 和 %C 處重複的 ELSE 敘述"
 
-#: fortran/parse.c:4157
+#: fortran/parse.c:4161
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected a CASE or END SELECT statement following SELECT CASE at %C"
 msgstr "預期的大小寫或結束選取敘述下列選取大小寫於 %C"
 
-#: fortran/parse.c:4241
+#: fortran/parse.c:4245
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected TYPE IS, CLASS IS or END SELECT statement following SELECT TYPE at %C"
 msgstr "預期的型態是，類別是或結束選取敘述下列選取型態於 %C"
 
-#: fortran/parse.c:4303
+#: fortran/parse.c:4307
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %C cannot be redefined inside loop beginning at %L"
 msgstr "變數『%s』於 %C 無法重新定義的內部迴圈起始部分於 %L"
 
-#: fortran/parse.c:4336
+#: fortran/parse.c:4340
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is within another block"
 msgstr "結束的 nonblock 做敘述於 %C 是在之內另外的區塊"
 
-#: fortran/parse.c:4346
+#: fortran/parse.c:4350
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is interwoven with another DO loop"
 msgstr "結束的 nonblock 做敘述於 %C 被 interwoven 與另外的做迴圈"
 
-#: fortran/parse.c:4372
+#: fortran/parse.c:4376
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL block inside of OpenACC region at %C"
 msgstr "Fortran 2003: 含有區塊在中衍生類型定義於 %C"
 
-#: fortran/parse.c:4373
+#: fortran/parse.c:4377
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL block inside of OpenMP region at %C"
 msgstr "Fortran 2003: 含有區塊在中衍生類型定義於 %C"
 
-#: fortran/parse.c:4399
+#: fortran/parse.c:4403
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Statement label in END CRITICAL at %C does not match CRITICAL label"
 msgstr "敘述標貼在中結束重要於 %C 不匹配 CRITIAL 標貼"
 
-#: fortran/parse.c:4468
+#: fortran/parse.c:4472
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BLOCK construct at %C"
 msgstr "Fortran 2008:區塊建構於 %C"
 
-#: fortran/parse.c:4502
+#: fortran/parse.c:4506
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASSOCIATE construct at %C"
 msgstr "Fortran 2003:關聯建構於 %C"
 
-#: fortran/parse.c:4690
+#: fortran/parse.c:4694
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Statement label in ENDDO at %C doesn't match DO label"
 msgstr "敘述標貼在中 ENDDO 於 %C 不匹配做標貼"
 
-#: fortran/parse.c:4706
+#: fortran/parse.c:4710
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Named block DO at %L requires matching ENDDO name"
 msgstr "具名的區塊做於 %L 需求匹配 ENDDO 名稱"
 
-#: fortran/parse.c:4897
+#: fortran/parse.c:4901
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing !$OMP END ATOMIC after !$OMP ATOMIC CAPTURE at %C"
 msgstr "缺少!$OMP 結束基元的之後 !$OMP 基元的擷取於 %C"
 
-#: fortran/parse.c:4913 fortran/parse.c:4972
+#: fortran/parse.c:4917 fortran/parse.c:4976
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "OpenACC directive inside of CRITICAL block at %C"
 msgstr "巢狀的重要區塊於 %C"
 
-#: fortran/parse.c:4947
+#: fortran/parse.c:4951
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting %s statement at %C"
 msgid "Expecting %s at %C"
 msgstr "需要 %s 敘述，於 %C"
 
-#: fortran/parse.c:4991
+#: fortran/parse.c:4995
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "Expected DO loop at %C"
 msgstr "在 %C 處需要「(」"
 
-#: fortran/parse.c:5011
+#: fortran/parse.c:5015
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Redundant !$ACC END LOOP at %C"
 msgstr "冗餘 ACQUIRED_LOCK 標籤找到於 %L "
 
-#: fortran/parse.c:5225
+#: fortran/parse.c:5229
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Name after !$omp critical and !$omp end critical does not match at %C"
 msgstr "名稱之後 !$omp 重要和 !$omp 結束重要不匹配於 %C"
 
-#: fortran/parse.c:5283
+#: fortran/parse.c:5287
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot terminate a non-block DO loop"
 msgstr "%s 敘述於 %C 無法終止 non-block 做迴圈"
 
-#: fortran/parse.c:5297
+#: fortran/parse.c:5301
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %C after the first executable statement"
 msgstr "%L 處 FORMAT 敘述沒有敘述標籤"
 
-#: fortran/parse.c:5423
+#: fortran/parse.c:5427
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive does not commence a loop at %C"
 msgstr ""
 
-#: fortran/parse.c:5538
+#: fortran/parse.c:5542
 #, fuzzy, gcc-internal-format
 msgid "Contained procedure %qs at %C is already ambiguous"
 msgstr "包含的程序『%s』於 %C 已經模稜兩可的"
 
-#: fortran/parse.c:5595
+#: fortran/parse.c:5599
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in CONTAINS section at %C"
 msgstr "非預期的 %s 敘述出現在 %C 處的 CONTAINS 段中"
 
-#: fortran/parse.c:5620
+#: fortran/parse.c:5624
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS statement without FUNCTION or SUBROUTINE statement at %L"
 msgstr "Fortran 2008:含有敘述而無需函式或副常式敘述於 %C"
 
-#: fortran/parse.c:5732
+#: fortran/parse.c:5736
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS statement at %C is already in a contained program unit"
 msgstr "含有敘述於 %C 已經在中包含的程式單元"
 
-#: fortran/parse.c:5784
+#: fortran/parse.c:5788
 #, fuzzy, gcc-internal-format
 msgid "Global binding name %qs at %L is already being used as a %s at %L"
 msgstr "總體名稱『%s』於 %L 已經被做為 %s 於 %L"
 
-#: fortran/parse.c:5788
+#: fortran/parse.c:5792
 #, fuzzy, gcc-internal-format
 msgid "Global name %qs at %L is already being used as a %s at %L"
 msgstr "總體名稱『%s』於 %L 已經被做為 %s 於 %L"
 
-#: fortran/parse.c:5794
+#: fortran/parse.c:5798
 #, fuzzy, gcc-internal-format
 msgid "Global binding name %qs at %L is already being used at %L"
 msgstr "總體名稱『%s』於 %L 已經被做為 %s 於 %L"
 
-#: fortran/parse.c:5797
+#: fortran/parse.c:5801
 #, fuzzy, gcc-internal-format
 msgid "Global name %qs at %L is already being used at %L"
 msgstr "總體名稱『%s』於 %L 已經被做為 %s 於 %L"
 
-#: fortran/parse.c:5819
+#: fortran/parse.c:5823
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Blank BLOCK DATA at %C conflicts with prior BLOCK DATA at %L"
 msgstr "空白區塊資料於 %C 衝突與事前區塊資料於 %L"
 
-#: fortran/parse.c:5845
+#: fortran/parse.c:5849
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in BLOCK DATA at %C"
 msgstr "非預期的 %s 敘述出現在 %C 處的 DATA 區塊中"
 
-#: fortran/parse.c:5949
+#: fortran/parse.c:5953
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in MODULE at %C"
 msgstr "非預期的 %s 敘述出現在 %C 處的 MODULE 中"
@@ -61857,7 +61935,7 @@
 #. If we see a duplicate main program, shut down.  If the second
 #. instance is an implied main program, i.e. data decls or executable
 #. statements, we're in for lots of errors.
-#: fortran/parse.c:6333
+#: fortran/parse.c:6337
 #, gcc-internal-format, gfc-internal-format
 msgid "Two main PROGRAMs at %L and %C"
 msgstr "%L 和 %C 處有兩個主 PROGRAM"
@@ -62612,7 +62690,7 @@
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr "非遞迴程序『%s』於 %L 是可能會呼叫它自己遞迴。 宣告它遞迴或使用 -frecursive"
 
-#: fortran/resolve.c:1893 fortran/resolve.c:9560 fortran/resolve.c:11225
+#: fortran/resolve.c:1893 fortran/resolve.c:9573 fortran/resolve.c:11245
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "標籤 %d(參照自 %L)從未被定義"
@@ -62727,7 +62805,7 @@
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "函式「%s」在 %L 處沒有 IMPLICIT 類型"
 
-#: fortran/resolve.c:2905 fortran/resolve.c:16283
+#: fortran/resolve.c:2905 fortran/resolve.c:16310
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Function %qs at %L has no IMPLICIT type"
@@ -62849,199 +62927,199 @@
 msgid "logical_to_bitwise(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:4059
+#: fortran/resolve.c:4065
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:4229 fortran/resolve.c:4252
+#: fortran/resolve.c:4235 fortran/resolve.c:4258
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:4347
+#: fortran/resolve.c:4353
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "陣列參照於 %L 是超出邊界 (%ld<%ld) 在中尺寸 %d"
 
-#: fortran/resolve.c:4352
+#: fortran/resolve.c:4358
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr "陣列參照於 %L 是超出邊界 (%ld<%ld) 在中 codimension %d"
 
-#: fortran/resolve.c:4362
+#: fortran/resolve.c:4368
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "陣列參照於 %L 是超出邊界 (%ld>%ld) 在中尺寸 %d"
 
-#: fortran/resolve.c:4367
+#: fortran/resolve.c:4373
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr "陣列參照於 %L 是超出邊界 (%ld>%ld) 在中 codimension %d"
 
-#: fortran/resolve.c:4387
+#: fortran/resolve.c:4393
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr "%L 零間隔無效"
 
-#: fortran/resolve.c:4404
+#: fortran/resolve.c:4410
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "降低陣列參照於 %L 是超出邊界 (%ld<%ld) 在中尺寸 %d"
 
-#: fortran/resolve.c:4412
+#: fortran/resolve.c:4418
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "降低陣列參照於 %L 是超出邊界 (%ld>%ld) 在中尺寸 %d"
 
-#: fortran/resolve.c:4428
+#: fortran/resolve.c:4434
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "大寫陣列參照於 %L 是超出邊界 (%ld<%ld) 在中尺寸 %d"
 
-#: fortran/resolve.c:4437
+#: fortran/resolve.c:4443
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "大寫陣列參照於 %L 是超出邊界 (%ld>%ld) 在中尺寸 %d"
 
-#: fortran/resolve.c:4453
+#: fortran/resolve.c:4459
 #, fuzzy, gcc-internal-format
 #| msgid "subscript missing in array reference"
 msgid "check_dimension(): Bad array reference"
 msgstr "陣列參照缺少下標"
 
-#: fortran/resolve.c:4476
+#: fortran/resolve.c:4482
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr "Rightmost 上限的假設的大小陣列區段尚未指定於 %L"
 
-#: fortran/resolve.c:4486
+#: fortran/resolve.c:4492
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr "%L 處陣列參照中秩不匹配(%d/%d)"
 
-#: fortran/resolve.c:4494
+#: fortran/resolve.c:4500
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr "Coindex 分級不匹配在中陣列參照於 %L (%d/%d)"
 
-#: fortran/resolve.c:4510
+#: fortran/resolve.c:4516
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr "Coindex 的 codimension %d 必須是純量於 %L"
 
-#: fortran/resolve.c:4538
+#: fortran/resolve.c:4544
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr "%L 處陣列索引必須是標量"
 
-#: fortran/resolve.c:4544
+#: fortran/resolve.c:4550
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr "陣列索引於 %L 必須是的整數類型，找到 %s"
 
-#: fortran/resolve.c:4550
+#: fortran/resolve.c:4556
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr "擴充：%L 處的 REAL 陣列索引"
 
-#: fortran/resolve.c:4589
+#: fortran/resolve.c:4595
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr "%L 引數維數必須是標量"
 
-#: fortran/resolve.c:4596
+#: fortran/resolve.c:4602
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr "%L 處引數維數必須具有 INTEGER 類型"
 
-#: fortran/resolve.c:4641
+#: fortran/resolve.c:4647
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr ""
 
-#: fortran/resolve.c:4652
+#: fortran/resolve.c:4658
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.c:4663
+#: fortran/resolve.c:4669
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.c:4706
+#: fortran/resolve.c:4712
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr "%L 處陣列索引是一個秩為 %d 的陣列"
 
-#: fortran/resolve.c:4804
+#: fortran/resolve.c:4810
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr "%L 處的子字串起始索引類型必須為 INTEGER"
 
-#: fortran/resolve.c:4811
+#: fortran/resolve.c:4817
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr "%L 處的子字串起始索引必須是標量"
 
-#: fortran/resolve.c:4820
+#: fortran/resolve.c:4826
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr "%L 處的子字串起始索引小於 1"
 
-#: fortran/resolve.c:4833
+#: fortran/resolve.c:4839
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr "%L 處的子字串終止索引類型必須為 INTEGER"
 
-#: fortran/resolve.c:4840
+#: fortran/resolve.c:4846
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr "%L 處的子字串終止索引必須是標量"
 
-#: fortran/resolve.c:4850
+#: fortran/resolve.c:4856
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr "子字串結束索引於 %L 超出字串長度"
 
-#: fortran/resolve.c:4860
+#: fortran/resolve.c:4866
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr "子字串結束索引於 %L 太大"
 
-#: fortran/resolve.c:5013
+#: fortran/resolve.c:5019
 #, fuzzy, gcc-internal-format
 #| msgid "Bad array reference at %L"
 msgid "resolve_ref(): Bad array reference"
 msgstr "%L 處陣列參照錯誤"
 
-#: fortran/resolve.c:5027
+#: fortran/resolve.c:5033
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr "成分到權限的部分參考與非零值分級必須不有指標屬性於 %L"
 
-#: fortran/resolve.c:5037
+#: fortran/resolve.c:5043
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr "成分到權限的部分參考與非零值分級必須不有 ALLOCATABLE 屬性於 %L"
 
-#: fortran/resolve.c:5056
+#: fortran/resolve.c:5062
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr "兩個以上部分參考與非零值分級必須不被指定的於 %L"
 
-#: fortran/resolve.c:5154
+#: fortran/resolve.c:5160
 #, gcc-internal-format
 msgid "expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.c:5236
+#: fortran/resolve.c:5242
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr "假定外形的陣列在 %L 處必須是啞引數"
 
-#: fortran/resolve.c:5246
+#: fortran/resolve.c:5252
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr "假定外形的陣列在 %L 處必須是啞引數"
@@ -63050,12 +63128,12 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5256
+#: fortran/resolve.c:5262
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5271
+#: fortran/resolve.c:5277
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr "假定外形的陣列在 %L 處必須是啞引數"
@@ -63064,269 +63142,269 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5281
+#: fortran/resolve.c:5287
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5292
+#: fortran/resolve.c:5298
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr "Coarray 變數『%s』於 %L 不應該有 codimensions 與已推遲形狀"
 
-#: fortran/resolve.c:5301
+#: fortran/resolve.c:5307
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr "Coarray 變數『%s』於 %L 不應該有 codimensions 與已推遲形狀"
 
-#: fortran/resolve.c:5316
+#: fortran/resolve.c:5322
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr "Coarray 變數『%s』於 %L 不應該有 codimensions 與已推遲形狀"
 
-#: fortran/resolve.c:5478
+#: fortran/resolve.c:5484
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr "變數『%s』，已用於規格運算式，被引用於 %L 之前條目敘述在中該項它是參數"
 
-#: fortran/resolve.c:5483
+#: fortran/resolve.c:5489
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr "變數『%s』被使用於 %L 之前條目敘述在中該項它是參數"
 
-#: fortran/resolve.c:5553
+#: fortran/resolve.c:5559
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr "Polymorphic 子物件的 coindexed 物件於 %L"
 
-#: fortran/resolve.c:5566
+#: fortran/resolve.c:5572
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr "Coindexed 物件與 polymorphic allocatable subcomponent 於 %L"
 
-#: fortran/resolve.c:5919
+#: fortran/resolve.c:5925
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "Passed-object 於 %L 必須是純量"
 
-#: fortran/resolve.c:5926
+#: fortran/resolve.c:5932
 #, fuzzy, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr "基底物件用於 procedure-pointer 成分呼叫於 %L 是的摘要型態『%s』"
 
-#: fortran/resolve.c:5961
+#: fortran/resolve.c:5967
 #, fuzzy, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr "基底物件用於 type-bound 程序呼叫於 %L 是的摘要型態『%s』"
 
-#: fortran/resolve.c:5970
+#: fortran/resolve.c:5976
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr "基底物件用於 NOPASS type-bound 程序呼叫於 %L 必須是純量"
 
 #. Nothing matching found!
-#: fortran/resolve.c:6158
+#: fortran/resolve.c:6164
 #, fuzzy, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr "找到沒有匹配特定的繫結用於呼叫到通用『%s』於 %L"
 
-#: fortran/resolve.c:6185
+#: fortran/resolve.c:6191
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "『%s』於 %L 應該是副常式"
 
-#: fortran/resolve.c:6236
+#: fortran/resolve.c:6242
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr "『%s』於 %L 應該是函式"
 
-#: fortran/resolve.c:6786
+#: fortran/resolve.c:6792
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "需要運算式類型"
 
-#: fortran/resolve.c:6812
+#: fortran/resolve.c:6818
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s (%L 處)必須是一個標量"
 
-#: fortran/resolve.c:6822
+#: fortran/resolve.c:6828
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "『%s』於 %L 必須是 nonnegative"
 
-#: fortran/resolve.c:6826 fortran/resolve.c:6833
+#: fortran/resolve.c:6832 fortran/resolve.c:6839
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s (%L 處)必須是 INTEGER"
 
-#: fortran/resolve.c:6875
+#: fortran/resolve.c:6881
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "步進敘述於 %L 處的 DO 迴圈中不可為零"
 
-#: fortran/resolve.c:6911
+#: fortran/resolve.c:6917
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr "做迴圈於 %L 將被執行零次"
 
-#: fortran/resolve.c:6928
+#: fortran/resolve.c:6934
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.c:6934
+#: fortran/resolve.c:6940
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.c:6995
+#: fortran/resolve.c:7001
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "%L 處 FORALL 索引名稱必須是 INTEGER 標量"
 
-#: fortran/resolve.c:7000
+#: fortran/resolve.c:7006
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "%L 處的 FORALL 啟始敘述必須是 INTEGER 標量"
 
-#: fortran/resolve.c:7007
+#: fortran/resolve.c:7013
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "%L 處的 FORALL 結束敘述必須是 INTEGER 標量"
 
-#: fortran/resolve.c:7015
+#: fortran/resolve.c:7021
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "%L 處的 FORALL 步幅敘述必須是 %s 標量"
 
-#: fortran/resolve.c:7020
+#: fortran/resolve.c:7026
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "%L 處的 FORALL 步幅敘述不能為零"
 
-#: fortran/resolve.c:7033
+#: fortran/resolve.c:7039
 #, fuzzy, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "FORALL 索引『%s』可能無法出現在中 triplet 規格於 %L"
 
-#: fortran/resolve.c:7136 fortran/resolve.c:7428
+#: fortran/resolve.c:7142 fortran/resolve.c:7434
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "Allocate-object 於 %L 必須是 ALLOCATABLE 或指標"
 
-#: fortran/resolve.c:7144 fortran/resolve.c:7393
+#: fortran/resolve.c:7150 fortran/resolve.c:7399
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr "Coindexed allocatable 物件於 %L"
 
-#: fortran/resolve.c:7250
+#: fortran/resolve.c:7256
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr "Source-expr 於 %L 必須是純量或有同級做為 allocate-object 於 %L"
 
-#: fortran/resolve.c:7281
+#: fortran/resolve.c:7287
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr "Source-expr 於 %L 和 allocate-object 於 %L 必須有相同形狀"
 
-#: fortran/resolve.c:7439
+#: fortran/resolve.c:7445
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr "型態的實體於 %L 是型態不相容的與 source-expr 於 %L"
 
-#: fortran/resolve.c:7451
+#: fortran/resolve.c:7457
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr "allocate-object 於 %L 和 source-expr 於 %L 應該有相同 kind 型態參數"
 
-#: fortran/resolve.c:7465
+#: fortran/resolve.c:7471
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr "source-expr 於 %L 應該 neither 是的型態 LOCK_TYPE nor 有 LOCK_TYPE 成分如果 allocate-object 於 %L 是 coarray"
 
-#: fortran/resolve.c:7480
+#: fortran/resolve.c:7486
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr "source-expr 於 %L 應該 neither 是的型態 LOCK_TYPE nor 有 LOCK_TYPE 成分如果 allocate-object 於 %L 是 coarray"
 
-#: fortran/resolve.c:7493
+#: fortran/resolve.c:7499
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr "配置 %s 的摘要基底類型於 %L 需要 type-spec 或 source-expr"
 
-#: fortran/resolve.c:7511
+#: fortran/resolve.c:7517
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr "配置 %s 於 %L 與 type-spec 需求相同 character-length 參數做為在中宣告"
 
-#: fortran/resolve.c:7592 fortran/resolve.c:7607
+#: fortran/resolve.c:7598 fortran/resolve.c:7613
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "陣列規格必要項在中配置敘述於 %L"
 
-#: fortran/resolve.c:7599
+#: fortran/resolve.c:7605
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "陣列規格必要項在中配置敘述於 %L"
 
-#: fortran/resolve.c:7622
+#: fortran/resolve.c:7628
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "Coarray 規格必要項在中配置敘述於 %L"
 
-#: fortran/resolve.c:7649
+#: fortran/resolve.c:7655
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "不當的陣列規格在中配置敘述於 %L"
 
-#: fortran/resolve.c:7668
+#: fortran/resolve.c:7674
 #, fuzzy, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr "『%s』必須不出現在中陣列規格於 %L 在中相同配置敘述位置它是它自己配置"
 
-#: fortran/resolve.c:7683
+#: fortran/resolve.c:7689
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr "預期『*』在中 coindex 規格在中配置敘述於 %L"
 
-#: fortran/resolve.c:7694
+#: fortran/resolve.c:7700
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "不當的 coarray 規格在中配置敘述於 %L"
 
-#: fortran/resolve.c:7726
+#: fortran/resolve.c:7732
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "Stat-variable 於 %L 必須是純量整數變數"
 
-#: fortran/resolve.c:7749
+#: fortran/resolve.c:7755
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "Stat-variable 於 %L 不應該是 %sd 在之內相同 %s 敘述"
 
-#: fortran/resolve.c:7760
+#: fortran/resolve.c:7766
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr "ERRMSG 於 %L 是無用的而無需 STAT 標籤"
 
-#: fortran/resolve.c:7771
+#: fortran/resolve.c:7782
 #, fuzzy, gcc-internal-format, gfc-internal-format
-msgid "Errmsg-variable at %L must be a scalar CHARACTER variable"
-msgstr "Errmsg-variable 於 %L 必須是純量字元變數"
+msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
+msgstr "ERRMSG=引數於 %L 必須是純量字元變數"
 
-#: fortran/resolve.c:7794
+#: fortran/resolve.c:7805
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr "Errmsg-variable 於 %L 不應該是 %sd 在之內相同 %s 敘述"
 
-#: fortran/resolve.c:7824
+#: fortran/resolve.c:7835
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr "Allocate-object 於 %L 也出現於 %L"
 
-#: fortran/resolve.c:7830 fortran/resolve.c:7836
+#: fortran/resolve.c:7841 fortran/resolve.c:7847
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr "Allocate-object 於 %L 是子物件的物件於 %L"
@@ -63335,232 +63413,232 @@
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8064
+#: fortran/resolve.c:8075
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "大小寫標貼於 %L 重疊與大小寫標貼於 %L"
 
-#: fortran/resolve.c:8115
+#: fortran/resolve.c:8126
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "%L 處 CASE 敘述中的運算式必須具有 %s 類型"
 
-#: fortran/resolve.c:8126
+#: fortran/resolve.c:8137
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "運算式在中條件敘述於 %L 必須是的 kind %d"
 
-#: fortran/resolve.c:8139
+#: fortran/resolve.c:8150
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "%L 處 CASE 敘述中的運算式必須為標量"
 
-#: fortran/resolve.c:8185
+#: fortran/resolve.c:8196
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "選擇運算式在中計算的前往敘述於 %L 必須是純量整數運算式"
 
-#: fortran/resolve.c:8204
+#: fortran/resolve.c:8215
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "%L 處 SELECT 敘述的引數不能是 %s"
 
-#: fortran/resolve.c:8214
+#: fortran/resolve.c:8225
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "%L 處 SELECT 敘述的引數不能是 %s"
 
-#: fortran/resolve.c:8232 fortran/resolve.c:8240
+#: fortran/resolve.c:8243 fortran/resolve.c:8251
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "運算式在中條件敘述於 %L 不是在中範圍的 %s"
 
-#: fortran/resolve.c:8302 fortran/resolve.c:8873
+#: fortran/resolve.c:8313 fortran/resolve.c:8884
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "預設大小寫於 %L 無法在之後秒預設大小寫於 %L"
 
-#: fortran/resolve.c:8328
+#: fortran/resolve.c:8339
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "邏輯的範圍在中條件敘述於 %L 未被允許"
 
-#: fortran/resolve.c:8340
+#: fortran/resolve.c:8351
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "常數邏輯的值在中條件敘述被重複於 %L"
 
-#: fortran/resolve.c:8355
+#: fortran/resolve.c:8366
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "範圍規格於 %L 可以永不被匹配"
 
-#: fortran/resolve.c:8458
+#: fortran/resolve.c:8469
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "邏輯的選取大小寫區塊於 %L 有更多該兩大小寫"
 
-#: fortran/resolve.c:8518
+#: fortran/resolve.c:8529
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr "關聯目標於 %C 必須不被 coindexed"
 
-#: fortran/resolve.c:8523
+#: fortran/resolve.c:8534
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr "關聯目標於 %C 必須不被 coindexed"
 
-#: fortran/resolve.c:8545
+#: fortran/resolve.c:8556
 #, fuzzy, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr "Associate-name『%s』於 %L 被做為陣列"
 
-#: fortran/resolve.c:8556
+#: fortran/resolve.c:8567
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:8763
+#: fortran/resolve.c:8774
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "選擇器應該是 polymorphic 在中選取型態敘述於 %L"
 
-#: fortran/resolve.c:8783 fortran/resolve.c:8795
+#: fortran/resolve.c:8794 fortran/resolve.c:8806
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr "關聯目標於 %C 必須不被 coindexed"
 
-#: fortran/resolve.c:8824
+#: fortran/resolve.c:8835
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "大小寫標貼於 %L 重疊與大小寫標貼於 %L"
 
-#: fortran/resolve.c:8836
+#: fortran/resolve.c:8847
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr "衍生類型『%s』於 %L 必須是 extensible"
 
-#: fortran/resolve.c:8848
+#: fortran/resolve.c:8859
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "衍生類型『%s』於 %L 必須是延伸的『%s』"
 
-#: fortran/resolve.c:8851
+#: fortran/resolve.c:8862
 #, fuzzy, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "未預期的空值() intrinsic 於 %L 到虛設『%s』"
 
-#: fortran/resolve.c:8861
+#: fortran/resolve.c:8872
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr "Type-spec 於 %L 無法包含已推遲型態參數"
 
-#: fortran/resolve.c:9108
+#: fortran/resolve.c:9119
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr "雙倍類別是區塊在中選取型態敘述於 %L"
 
-#: fortran/resolve.c:9204
+#: fortran/resolve.c:9215
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "無效的語境用於空值() 指標於 %%L"
 
-#: fortran/resolve.c:9257
+#: fortran/resolve.c:9268
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "停止編碼於 %L 必須是純量"
 
-#: fortran/resolve.c:9267
+#: fortran/resolve.c:9278
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr "資料轉移元件於 %L 無法 polymorphic 除非它被處理由定義的輸入/輸出程序"
 
-#: fortran/resolve.c:9280
+#: fortran/resolve.c:9291
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "資料轉移元件於 %L 無法有指標成分除非它被處理由定義的輸入/輸出程序"
 
-#: fortran/resolve.c:9289
+#: fortran/resolve.c:9300
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "資料轉移元件於 %L 無法有程序指標成分"
 
-#: fortran/resolve.c:9296
+#: fortran/resolve.c:9307
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "資料轉移元件於 %L 無法有 ALLOCATABLE 成分除非它被處理由定義的輸入/輸出程序"
 
-#: fortran/resolve.c:9307
+#: fortran/resolve.c:9318
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "資料轉移元件於 %L 無法有私人的成分"
 
-#: fortran/resolve.c:9313
+#: fortran/resolve.c:9324
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr "資料轉移元件於 %L 無法有指標成分除非它被處理由定義的輸入/輸出程序"
 
-#: fortran/resolve.c:9328
+#: fortran/resolve.c:9339
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "資料轉移元件於 %L 無法全部參考到 assumed-size 陣列"
 
-#: fortran/resolve.c:9388
+#: fortran/resolve.c:9399
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "鎖定變數於 %L 必須是純量的型態 LOCK_TYPE"
 
-#: fortran/resolve.c:9398
+#: fortran/resolve.c:9409
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr "鎖定變數於 %L 必須是純量的型態 LOCK_TYPE"
 
-#: fortran/resolve.c:9402
+#: fortran/resolve.c:9413
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "實際引數到『%s』於 %L 必須是 coarray"
 
-#: fortran/resolve.c:9405
+#: fortran/resolve.c:9416
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "實際引數到『%s』於 %L 必須是 coarray"
 
-#: fortran/resolve.c:9412 fortran/resolve.c:9533
+#: fortran/resolve.c:9423 fortran/resolve.c:9545
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "STAT=引數於 %L 必須是純量整數變數"
 
-#: fortran/resolve.c:9424 fortran/resolve.c:9540
+#: fortran/resolve.c:9435 fortran/resolve.c:9553
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "ERRMSG=引數於 %L 必須是純量字元變數"
 
-#: fortran/resolve.c:9436
+#: fortran/resolve.c:9447
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "ACQUIRED_LOCK=引數於 %L 必須是純量邏輯的變數"
 
-#: fortran/resolve.c:9449
+#: fortran/resolve.c:9460
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "Imageset 引數於 %L 必須是純量或 rank-1 整數運算式"
 
-#: fortran/resolve.c:9510
+#: fortran/resolve.c:9521
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "Imageset 引數於 %L 必須是純量或 rank-1 整數運算式"
 
-#: fortran/resolve.c:9514 fortran/resolve.c:9524
+#: fortran/resolve.c:9525 fortran/resolve.c:9535
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "Imageset 引數於 %L 必須介於 1 和 numimages()(_I)"
 
-#: fortran/resolve.c:9567
+#: fortran/resolve.c:9580
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "敘述於 %L 並非有效分支目標敘述用於分支敘述於 %L"
 
-#: fortran/resolve.c:9577
+#: fortran/resolve.c:9590
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr "分支於 %L 也許會導致無窮迴圈"
@@ -63567,12 +63645,12 @@
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:9594 fortran/resolve.c:9617
+#: fortran/resolve.c:9607 fortran/resolve.c:9630
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr "前往敘述於 %L 樹葉重要建構用於標貼於 %L"
 
-#: fortran/resolve.c:9598 fortran/resolve.c:9623
+#: fortran/resolve.c:9611 fortran/resolve.c:9636
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr "前往敘述於 %L 樹葉做共時建構用於標貼於 %L"
@@ -63580,109 +63658,109 @@
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:9638
+#: fortran/resolve.c:9651
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "標貼於 %L 不是在中相同區塊做為前往敘述於 %L"
 
-#: fortran/resolve.c:9710
+#: fortran/resolve.c:9723
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "位置遮罩於 %L 有不一致形狀"
 
-#: fortran/resolve.c:9726
+#: fortran/resolve.c:9739
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "位置指派目標於 %L 有不一致形狀"
 
-#: fortran/resolve.c:9734 fortran/resolve.c:9821
+#: fortran/resolve.c:9747 fortran/resolve.c:9834
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr "Non-ELEMENTAL 使用者定義的指派在中位置於 %L"
 
-#: fortran/resolve.c:9744 fortran/resolve.c:9831
+#: fortran/resolve.c:9757 fortran/resolve.c:9844
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "%L 處在 WHERE 內不支援的敘述"
 
-#: fortran/resolve.c:9775
+#: fortran/resolve.c:9788
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "%L 處向 FORALL 索引變數賦值"
 
-#: fortran/resolve.c:9784
+#: fortran/resolve.c:9797
 #, fuzzy, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "FORALL 與索引『%s』未被使用左側的側邊的指派於 %L 和因而也許造成多重指派到這個物件"
 
-#: fortran/resolve.c:9949
+#: fortran/resolve.c:9962
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "%L 處 FORALL 索引名稱必須是 INTEGER 標量"
 
-#: fortran/resolve.c:9959
+#: fortran/resolve.c:9972
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "外 FORALL 建構已經有索引與這個名稱 %L"
 
-#: fortran/resolve.c:10036
+#: fortran/resolve.c:10049
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "%L 處的 WHERE/ELSEWHERE 子句需要一個 LOGICAL 陣列"
 
-#: fortran/resolve.c:10138
+#: fortran/resolve.c:10151
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:10251
+#: fortran/resolve.c:10264
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr "字元運算式將被截斷在中指派 (%d/%d) 於 %L"
 
-#: fortran/resolve.c:10283
+#: fortran/resolve.c:10296
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "Coindexed 運算式於 %L 被指派到衍生類型變數與指標成分在中 PURE 程序"
 
-#: fortran/resolve.c:10288
+#: fortran/resolve.c:10301
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The impure variable at %L is assigned to a derived type variable with a POINTER component in a PURE procedure (12.6)"
 msgstr "impure 變數於 %L 被指派到衍生類型變數與指標成分在中 PURE 程序 (12.6)"
 
-#: fortran/resolve.c:10298
+#: fortran/resolve.c:10311
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "指派到 coindexed 變數於 %L 在中 PURE 程序"
 
-#: fortran/resolve.c:10330
+#: fortran/resolve.c:10343
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:10334
+#: fortran/resolve.c:10347
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assignment to a FORALL index variable at %L"
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "%L 處向 FORALL 索引變數賦值"
 
-#: fortran/resolve.c:10339
+#: fortran/resolve.c:10352
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.c:10346
+#: fortran/resolve.c:10359
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr "變數必須不是 polymorphic 在中 intrinsic 指派於 %L - 檢查該有匹配特定的副常式用於『=』運算子"
 
-#: fortran/resolve.c:10357
+#: fortran/resolve.c:10370
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr "Coindexed 變數必須不是有 allocatable ultimate 成分在中指派於 %L"
 
-#: fortran/resolve.c:10663
+#: fortran/resolve.c:10683
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
@@ -63689,70 +63767,70 @@
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:10905
+#: fortran/resolve.c:10925
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr "無效的程序指標指派於 %L"
 
-#: fortran/resolve.c:10917
+#: fortran/resolve.c:10937
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr "目標運算式在中指標指派於 %L 必須投遞指標結果"
 
-#: fortran/resolve.c:11157
+#: fortran/resolve.c:11177
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgstr "指派的前往敘述於 %L 需求整數變數"
 
-#: fortran/resolve.c:11160
+#: fortran/resolve.c:11180
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' has not been assigned a target label at %L"
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "變數「%s」在 %L 尚未指派到目標標籤"
 
-#: fortran/resolve.c:11171
+#: fortran/resolve.c:11191
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "交替回傳敘述於 %L 需要 SCALAR-INTEGER 回傳說明符"
 
-#: fortran/resolve.c:11233
+#: fortran/resolve.c:11253
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "指派敘述於 %L 需要純量預設整數變數"
 
-#: fortran/resolve.c:11278
+#: fortran/resolve.c:11298
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Invalid NULL at %L"
 msgstr "%s 種別無效，於 %L 處"
 
-#: fortran/resolve.c:11282
+#: fortran/resolve.c:11302
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr "算術如果敘述於 %L 需要數值運算式"
 
-#: fortran/resolve.c:11339
+#: fortran/resolve.c:11359
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:11344
+#: fortran/resolve.c:11364
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "離開條件的做當迴圈於 %L 必須是純量邏輯的運算式"
 
-#: fortran/resolve.c:11428
+#: fortran/resolve.c:11448
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "FORALL 遮罩子句於 %L 需要純量邏輯的運算式"
 
-#: fortran/resolve.c:11507
+#: fortran/resolve.c:11527
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_trans_code()：錯誤的敘述程式碼"
 
-#: fortran/resolve.c:11617
+#: fortran/resolve.c:11637
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "繫結標貼『%s』於 %L collides 與全域實體『%s』於 %L"
@@ -63759,7 +63837,7 @@
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:11630
+#: fortran/resolve.c:11650
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr ""
@@ -63767,58 +63845,58 @@
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:11647
+#: fortran/resolve.c:11667
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "繫結標貼『%s』於 %L collides 與全域實體『%s』於 %L"
 
-#: fortran/resolve.c:11732
+#: fortran/resolve.c:11752
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "字串長度於 %L 太大"
 
-#: fortran/resolve.c:11961
+#: fortran/resolve.c:11981
 #, fuzzy, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "可指派的陣列「%s」在 %L 處必須有延遲的外形"
 
-#: fortran/resolve.c:11965
+#: fortran/resolve.c:11985
 #, fuzzy, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "純量物件『%s』於 %L 可能無法是 ALLOCATABLE"
 
-#: fortran/resolve.c:11973
+#: fortran/resolve.c:11993
 #, fuzzy, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "陣列指標「%s」在 %L 處必須有延遲的外形"
 
-#: fortran/resolve.c:11983
+#: fortran/resolve.c:12003
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "陣列「%s」在 %L 處不能有延遲的外形"
 
-#: fortran/resolve.c:11998
+#: fortran/resolve.c:12018
 #, fuzzy, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr "型態『%s』的類別變數『%s』於 %L 不是 extensible"
 
-#: fortran/resolve.c:12010
+#: fortran/resolve.c:12030
 #, fuzzy, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr "類別變數『%s』於 %L 必須是虛設，allocatable 或指標"
 
-#: fortran/resolve.c:12041
+#: fortran/resolve.c:12061
 #, fuzzy, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr "型態『%s』無法主機關聯的於 %L 因為它被阻斷由不相容的物件的同名宣告的於 %L"
 
-#: fortran/resolve.c:12063
+#: fortran/resolve.c:12083
 #, fuzzy, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr "Fortran 2008:意味著的儲存用於模組變數『%s』於 %L, 所需的由於預設初始化"
 
-#: fortran/resolve.c:12090
+#: fortran/resolve.c:12110
 #, fuzzy, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr "實體『%s』於 %L 有已推遲型態參數和需求還是指標或 allocatable 屬性"
@@ -63825,902 +63903,908 @@
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12131
+#: fortran/resolve.c:12151
 #, fuzzy, gcc-internal-format
 #| msgid "The module or main program array '%s' at %L must have constant shape"
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "模組或主程式陣列「%s」在 %L 處必須有常態的外形"
 
-#: fortran/resolve.c:12150
+#: fortran/resolve.c:12170
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "實體與假設的字元長度於 %L 必須是虛引數或參數"
 
-#: fortran/resolve.c:12171
+#: fortran/resolve.c:12191
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr "『%s』於 %L 必須有常數字元長度在中這個語境"
 
-#: fortran/resolve.c:12178
+#: fortran/resolve.c:12198
 #, fuzzy, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "共同變數『%s』於 %L 必須有常數字元長度"
 
-#: fortran/resolve.c:12225
+#: fortran/resolve.c:12245
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable '%s' at %L cannot have an initializer"
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "可指派的「%s」在 %L 處不能有初始值設定"
 
-#: fortran/resolve.c:12228
+#: fortran/resolve.c:12248
 #, fuzzy, gcc-internal-format
 #| msgid "External '%s' at %L cannot have an initializer"
 msgid "External %qs at %L cannot have an initializer"
 msgstr "外部「%s」在 %L 處不能有初始值設定"
 
-#: fortran/resolve.c:12232
+#: fortran/resolve.c:12252
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "啞元「%s」在 %L 處不能有初始值設定"
 
-#: fortran/resolve.c:12235
+#: fortran/resolve.c:12255
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L cannot have an initializer"
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "內建函式「%s」在 %L 處不能有初始值設定"
 
-#: fortran/resolve.c:12238
+#: fortran/resolve.c:12258
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L cannot have an initializer"
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "函式結果「%s」在 %L 處不能有初始值設定"
 
-#: fortran/resolve.c:12241
+#: fortran/resolve.c:12261
 #, fuzzy, gcc-internal-format
 #| msgid "Automatic array '%s' at %L cannot have an initializer"
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "自動陣列「%s」在 %L 處不能有初始值設定"
 
-#: fortran/resolve.c:12283
+#: fortran/resolve.c:12303
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "in %s, at %s:%d"
 msgid "%s at %L"
 msgstr "在 %s 中，於 %s:%d"
 
-#: fortran/resolve.c:12310
+#: fortran/resolve.c:12330
 #, fuzzy, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "Character-valued 敘述函式『%s』於 %L 必須有常數長度"
 
-#: fortran/resolve.c:12332
+#: fortran/resolve.c:12352
 #, fuzzy, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "Fortran 2003:『%s』是的私人的型態和無法虛引數的『%s』，該項是公用的於 %L"
 
-#: fortran/resolve.c:12354
+#: fortran/resolve.c:12374
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr "Fortran 2003:程序『%s』在中公用的介面『%s』於 %L 需虛引數的『%s』該項是私人的"
 
-#: fortran/resolve.c:12372
+#: fortran/resolve.c:12392
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "函式『%s』於 %L 無法有初始設定式"
 
-#: fortran/resolve.c:12381
+#: fortran/resolve.c:12401
 #, fuzzy, gcc-internal-format
 #| msgid "External object '%s' at %L may not have an initializer"
 msgid "External object %qs at %L may not have an initializer"
 msgstr "外部物件「%s」在 %L 處不能有初始值設定"
 
-#: fortran/resolve.c:12389
+#: fortran/resolve.c:12409
 #, fuzzy, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "ELEMENTAL 函式『%s』於 %L 必須有純量結果"
 
-#: fortran/resolve.c:12399
+#: fortran/resolve.c:12419
 #, fuzzy, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "敘述函式『%s』於 %L 可能無法有指標或 allocatable 屬性"
 
-#: fortran/resolve.c:12418
+#: fortran/resolve.c:12438
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be array-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "CHARACTER(*) 函式「%s」(位於 %L)不能以陣列賦值"
 
-#: fortran/resolve.c:12422
+#: fortran/resolve.c:12442
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pointer-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "CHARACTER(*) 函式「%s」(位於 %L)不能以指標賦值"
 
-#: fortran/resolve.c:12426
+#: fortran/resolve.c:12446
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "CHARACTER(*) 函式「%s」(位於 %L)不能是純量"
 
-#: fortran/resolve.c:12430
+#: fortran/resolve.c:12450
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "字元 (*) 函式『%s』於 %L 無法遞迴"
 
-#: fortran/resolve.c:12443
+#: fortran/resolve.c:12463
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "CHARACTER(*) 函式「%s」(位於 %L)不能是純量"
 
-#: fortran/resolve.c:12452
+#: fortran/resolve.c:12472
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "程序『%s』在中 %s 於 %L 沒有任何明確的介面"
 
-#: fortran/resolve.c:12458
+#: fortran/resolve.c:12478
 #, fuzzy, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "虛設程序『%s』於 %C 無法有通用介面"
 
-#: fortran/resolve.c:12470
+#: fortran/resolve.c:12490
 #, fuzzy, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr "變數『%s』於 %L 無法同時有 ALLOCATABLE 和繫結©屬性"
 
-#: fortran/resolve.c:12527
+#: fortran/resolve.c:12547
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "程序屬性衝突與儲存屬性在中『%s』於 %L"
 
-#: fortran/resolve.c:12533
+#: fortran/resolve.c:12553
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "程序屬性衝突與含義屬性在中『%s』於 %L"
 
-#: fortran/resolve.c:12539
+#: fortran/resolve.c:12559
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "程序屬性衝突與結果屬性在中『%s』於 %L"
 
-#: fortran/resolve.c:12547
+#: fortran/resolve.c:12567
 #, fuzzy, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "外部屬性衝突與函式屬性在中『%s』於 %L"
 
-#: fortran/resolve.c:12553
+#: fortran/resolve.c:12573
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr "程序指標結果『%s』於 %L 缺少指標屬性"
 
-#: fortran/resolve.c:12596
+#: fortran/resolve.c:12616
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12604
+#: fortran/resolve.c:12624
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12612
+#: fortran/resolve.c:12632
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12621
+#: fortran/resolve.c:12641
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.c:12705
+#: fortran/resolve.c:12725
 #, fuzzy, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "最後的程序『%s』於 %L 並非副常式"
 
-#: fortran/resolve.c:12714
+#: fortran/resolve.c:12734
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "最後的程序於 %L 必須有精確的一個引數"
 
-#: fortran/resolve.c:12723
+#: fortran/resolve.c:12743
 #, fuzzy, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "引數的最後的程序於 %L 必須是的型態『%s』"
 
-#: fortran/resolve.c:12731
+#: fortran/resolve.c:12751
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "引數的最後的程序於 %L 必須不是指標"
 
-#: fortran/resolve.c:12737
+#: fortran/resolve.c:12757
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "引數的最後的程序於 %L 必須不是 ALLOCATABLE"
 
-#: fortran/resolve.c:12743
+#: fortran/resolve.c:12763
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "引數的最後的程序於 %L 必須不是可選的"
 
-#: fortran/resolve.c:12751
+#: fortran/resolve.c:12771
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "引數的最後的程序於 %L 必須不是含義 (出)"
 
-#: fortran/resolve.c:12760
+#: fortran/resolve.c:12780
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "Non-scalar 最後的程序於 %L 應該已假設形狀引數"
 
-#: fortran/resolve.c:12782
+#: fortran/resolve.c:12802
 #, fuzzy, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "最後的程序『%s』宣告的於 %L 有同級 (%d) 做為『%s』"
 
-#: fortran/resolve.c:12819
+#: fortran/resolve.c:12839
 #, fuzzy, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr "只有陣列最後的程序宣告的用於衍生類型『%s』定義的於 %L, 建議也純量一個"
 
-#: fortran/resolve.c:12859
+#: fortran/resolve.c:12879
 #, fuzzy, gcc-internal-format
 msgid "%qs and %qs can't be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr "『%s』和『%s』無法混合的函式/副常式用於通用『%s』於 %L"
 
-#: fortran/resolve.c:12895
+#: fortran/resolve.c:12915
 #, fuzzy, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr "『%s』和『%s』用於通用『%s』於 %L 是模稜兩可的"
 
-#: fortran/resolve.c:12954
+#: fortran/resolve.c:12974
 #, fuzzy, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr "未定義的特定的繫結『%s』做為目標的通用『%s』於 %L"
 
-#: fortran/resolve.c:12966
+#: fortran/resolve.c:12986
 #, fuzzy, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr "通用『%s』於 %L 必須目標特定的繫結，『%s』是通用，太"
 
-#: fortran/resolve.c:12994
+#: fortran/resolve.c:13014
 #, fuzzy, gcc-internal-format
 msgid "GENERIC %qs at %L can't overwrite specific binding with the same name"
 msgstr "通用『%s』於 %L 無法覆寫特定的繫結與同名"
 
-#: fortran/resolve.c:13050
+#: fortran/resolve.c:13070
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L can't be NOPASS"
 msgstr "Type-bound 運算子於 %L 無法 NOPASS"
 
-#: fortran/resolve.c:13242
+#: fortran/resolve.c:13262
 #, fuzzy, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "『%s』必須是模組程序或外部程序與明確的介面於 %L"
 
-#: fortran/resolve.c:13284
+#: fortran/resolve.c:13304
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "程序『%s』與回合 (%s) 於 %L 沒有任何引數『%s』"
 
-#: fortran/resolve.c:13298
+#: fortran/resolve.c:13318
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "程序『%s』與回合於 %L 必須至少有一個引數"
 
-#: fortran/resolve.c:13312 fortran/resolve.c:13778
+#: fortran/resolve.c:13332 fortran/resolve.c:13798
 #, fuzzy, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "Non-polymorphic passed-object 虛引數的『%s』於 %L"
 
-#: fortran/resolve.c:13320
+#: fortran/resolve.c:13340
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "引數『%s』的『%s』與回合 (%s) 於 %L 必須是的衍生類型『%s』"
 
-#: fortran/resolve.c:13329
+#: fortran/resolve.c:13349
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "Passed-object 虛引數的『%s』於 %L 必須是純量"
 
-#: fortran/resolve.c:13335
+#: fortran/resolve.c:13355
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "Passed-object 虛引數的『%s』於 %L 必須不是 ALLOCATABLE"
 
-#: fortran/resolve.c:13341
+#: fortran/resolve.c:13361
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "Passed-object 虛引數的『%s』於 %L 必須不是指標"
 
-#: fortran/resolve.c:13370
+#: fortran/resolve.c:13390
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "程序『%s』於 %L 有同名做為成分的『%s』"
 
-#: fortran/resolve.c:13380
+#: fortran/resolve.c:13400
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "程序『%s』於 %L 有同名做為繼承的成分的『%s』"
 
-#: fortran/resolve.c:13472
+#: fortran/resolve.c:13492
 #, fuzzy, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr "衍生類型『%s』宣告的於 %L 必須是摘要因為『%s』是已推遲和無法 overridden"
 
-#: fortran/resolve.c:13574
+#: fortran/resolve.c:13594
 #, fuzzy, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "Coarray 成分『%s』於 %L 必須是 allocatable 與已推遲形狀"
 
-#: fortran/resolve.c:13583
+#: fortran/resolve.c:13603
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "成分『%s』於 %L 的型態 (C_PTR) 或型態 (C_FUNPTR) 不應該是 coarray"
 
-#: fortran/resolve.c:13593
+#: fortran/resolve.c:13613
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr "成分『%s』於 %L 與 coarray 成分應該是 nonpointer，nonallocatable 純量"
 
-#: fortran/resolve.c:13602
+#: fortran/resolve.c:13622
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr "成分『%s』於 %L 有 CONTIGUOUS 屬性但是不是陣列指標"
 
-#: fortran/resolve.c:13613
+#: fortran/resolve.c:13633
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ICHAR at %L must be of length one"
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "%L 處 ICHAR 的參數長度必須為 1"
 
-#: fortran/resolve.c:13711
+#: fortran/resolve.c:13731
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "程序指標成分『%s』與回合 (%s) 於 %L 沒有任何引數『%s』"
 
-#: fortran/resolve.c:13725
+#: fortran/resolve.c:13745
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "程序指標成分『%s』與回合於 %L 必須至少有一個引數"
 
-#: fortran/resolve.c:13741
+#: fortran/resolve.c:13761
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "引數『%s』的『%s』與回合 (%s) 於 %L 必須是的衍生類型『%s』"
 
-#: fortran/resolve.c:13751
+#: fortran/resolve.c:13771
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "引數『%s』的『%s』與回合 (%s) 於 %L 必須是純量"
 
-#: fortran/resolve.c:13760
+#: fortran/resolve.c:13780
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "引數『%s』的『%s』與回合 (%s) 於 %L 可能無法有指標屬性"
 
-#: fortran/resolve.c:13769
+#: fortran/resolve.c:13789
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "引數『%s』的『%s』與回合 (%s) 於 %L 可能無法是 ALLOCATABLE"
 
-#: fortran/resolve.c:13811
+#: fortran/resolve.c:13831
 #, fuzzy, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "成分『%s』的『%s』於 %L 有同名做為繼承 type-bound 程序"
 
-#: fortran/resolve.c:13824
+#: fortran/resolve.c:13844
 #, fuzzy, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "字元長度的成分『%s』需要是常數規格運算式於 %L"
 
-#: fortran/resolve.c:13835
+#: fortran/resolve.c:13855
 #, fuzzy, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr "字元成分『%s』的『%s』於 %L 與已推遲長度必須是指標或 ALLOCATABLE"
 
-#: fortran/resolve.c:13868
+#: fortran/resolve.c:13888
 #, fuzzy, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "Fortran 2003:成分『%s』是私人的型態和無法成分的『%s』，該項是公用的於 %L"
 
-#: fortran/resolve.c:13876
+#: fortran/resolve.c:13896
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr "Polymorphic 成分 %s 於 %L 在中序列或繫結©型態 %s"
 
-#: fortran/resolve.c:13885
+#: fortran/resolve.c:13905
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "成分 %s 的序列型態宣告的於 %L 沒有序列屬性"
 
-#: fortran/resolve.c:13903 fortran/resolve.c:13915
+#: fortran/resolve.c:13923 fortran/resolve.c:13935
 #, fuzzy, gcc-internal-format
 msgid "The pointer component %qs of %qs at %L is a type that has not been declared"
 msgstr "指標成分『%s』的『%s』於 %L 是型態該未被宣告"
 
-#: fortran/resolve.c:13989
+#: fortran/resolve.c:14009
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "衝突在中屬性的函式引數於 %C"
 
-#: fortran/resolve.c:14034
+#: fortran/resolve.c:14054
 #, fuzzy, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr "做為延伸型態『%s』於 %L 有 coarray 成分，親代型態『%s』應該也有一個"
 
-#: fortran/resolve.c:14047
+#: fortran/resolve.c:14067
 #, fuzzy, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "Non-extensible 衍生類型『%s』於 %L 必須不是摘要"
 
-#: fortran/resolve.c:14111
+#: fortran/resolve.c:14131
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14144
+#: fortran/resolve.c:14164
 #, fuzzy, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr "Fortran 2003:通用名稱『%s』的函式『%s』於 %L 相同名稱做為衍生類型於 %L"
 
-#: fortran/resolve.c:14216
+#: fortran/resolve.c:14236
 #, fuzzy, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "假設的大小陣列『%s』在中名稱表列『%s』於 %L 未被允許"
 
-#: fortran/resolve.c:14222
+#: fortran/resolve.c:14242
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "Fortran 2003:名稱表列陣列物件『%s』與假設的形狀在中名稱表列『%s』於 %L"
 
-#: fortran/resolve.c:14228
+#: fortran/resolve.c:14248
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "Fortran 2003:名稱表列陣列物件『%s』與 nonconstant 形狀在中名稱表列『%s』於 %L"
 
-#: fortran/resolve.c:14236
+#: fortran/resolve.c:14256
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "Fortran 2003:名稱表列物件『%s』與 nonconstant 字元長度在中名稱表列『%s』於 %L"
 
-#: fortran/resolve.c:14253
+#: fortran/resolve.c:14273
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "名稱表列物件『%s』被宣告私人的和無法成員的公用的名稱表列『%s』於 %L"
 
-#: fortran/resolve.c:14275
+#: fortran/resolve.c:14295
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "名稱表列物件『%s』已 use-associated 私人的成分和無法成員的名稱表列『%s』於 %L"
 
-#: fortran/resolve.c:14286
+#: fortran/resolve.c:14306
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "名稱表列物件『%s』有私人的成分和無法成員的公用的名稱表列『%s』於 %L"
 
-#: fortran/resolve.c:14313
+#: fortran/resolve.c:14333
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "程序屬性衝突與名稱表列屬性在中『%s』於 %L"
 
-#: fortran/resolve.c:14337
+#: fortran/resolve.c:14357
 #, fuzzy, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "參數陣列『%s』於 %L 無法自動或的已推遲形狀"
 
-#: fortran/resolve.c:14353
+#: fortran/resolve.c:14373
 #, fuzzy, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "隱含地型態的參數『%s』於 %L 不匹配稍後隱含的型態"
 
-#: fortran/resolve.c:14364
+#: fortran/resolve.c:14384
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "不相容的衍生類型在中參數於 %L"
 
-#: fortran/resolve.c:14372
+#: fortran/resolve.c:14392
 #, fuzzy, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "共同區塊『%s』於 %L 無法有外部屬性"
 
-#: fortran/resolve.c:14423
+#: fortran/resolve.c:14443
 #, fuzzy, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr "實體『%s』於 %L 有已推遲型態參數和需求還是指標或 allocatable 屬性"
 
-#: fortran/resolve.c:14434
+#: fortran/resolve.c:14454
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.c:14441
+#: fortran/resolve.c:14461
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.c:14480
+#: fortran/resolve.c:14500
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:14544
+#: fortran/resolve.c:14564
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "保護的屬性衝突與外部屬性於 %L"
 
-#: fortran/resolve.c:14547
+#: fortran/resolve.c:14567
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "程序屬性衝突與保護的屬性於 %L"
 
-#: fortran/resolve.c:14643
+#: fortran/resolve.c:14663
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr "『%s』於 %L 有 CONTIGUOUS 屬性但是不是陣列指標或 assumed-shape 陣列"
 
-#: fortran/resolve.c:14664
+#: fortran/resolve.c:14684
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr "不當的規格用於假設的大小陣列於 %C"
 
-#: fortran/resolve.c:14677
+#: fortran/resolve.c:14697
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "假定大小的陣列在 %L 處必須是啞引數"
 
-#: fortran/resolve.c:14680
+#: fortran/resolve.c:14700
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "假定外形的陣列在 %L 處必須是啞引數"
 
-#: fortran/resolve.c:14688
+#: fortran/resolve.c:14708
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "假定外形的陣列在 %L 處必須是啞引數"
 
-#: fortran/resolve.c:14695
+#: fortran/resolve.c:14715
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:14708
+#: fortran/resolve.c:14728
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "%L 處的符號不是一個 DUMMY 變數"
 
-#: fortran/resolve.c:14714
+#: fortran/resolve.c:14734
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "『%s』於 %L 無法有值屬性因為它並非虛引數"
 
-#: fortran/resolve.c:14724
+#: fortran/resolve.c:14744
 #, fuzzy, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "字元虛設變數『%s』於 %L 與值屬性必須有常數長度"
 
-#: fortran/resolve.c:14733
+#: fortran/resolve.c:14753
 #, fuzzy, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "C 可交流的字元虛設變數『%s』於 %L 與值屬性必須有長度一個"
 
-#: fortran/resolve.c:14746 fortran/resolve.c:14923
+#: fortran/resolve.c:14766 fortran/resolve.c:14943
 #, fuzzy, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "衍生類型『%s』於 %L 是的型態『%s』，該項未被定義"
 
-#: fortran/resolve.c:14760
+#: fortran/resolve.c:14780
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14769
+#: fortran/resolve.c:14789
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:14778
+#: fortran/resolve.c:14798
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "變數『%s』於 %L 無法同時有 ALLOCATABLE 和繫結©屬性"
 
-#: fortran/resolve.c:14786
+#: fortran/resolve.c:14806
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "變數『%s』於 %L 無法同時有指標和繫結©屬性"
 
-#: fortran/resolve.c:14793
+#: fortran/resolve.c:14813
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:14813
+#: fortran/resolve.c:14833
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "假設的形狀陣列『%s』於 %L 未被允許在中初始化運算式"
 
-#: fortran/resolve.c:14820
+#: fortran/resolve.c:14840
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "變數『%s』於 %L 無法同時有 ALLOCATABLE 和繫結©屬性"
 
-#: fortran/resolve.c:14827
+#: fortran/resolve.c:14847
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "變數『%s』於 %L 無法同時有指標和繫結©屬性"
 
-#: fortran/resolve.c:14834
+#: fortran/resolve.c:14854
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr "迴圈變數於 %C 無法 coarray"
 
-#: fortran/resolve.c:14860
+#: fortran/resolve.c:14880
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr "變數『%s』於 %L 無法繫結©因為它是 neither 共同區塊 nor 宣告的於模組等級範圍"
 
-#: fortran/resolve.c:14870
+#: fortran/resolve.c:14890
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "%s 的參數(位於 %L)長度必須為 1"
 
-#: fortran/resolve.c:14949
+#: fortran/resolve.c:14969
 #, fuzzy, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "Fortran 2003:公用的 %s『%s』於 %L 的私人的衍生類型『%s』"
 
-#: fortran/resolve.c:14964
+#: fortran/resolve.c:14984
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr "變數 %s 於 %L 的型態 LOCK_TYPE 或與 subcomponent 的型態 LOCK_TYPE 必須是 coarray"
 
-#: fortran/resolve.c:14977
+#: fortran/resolve.c:14997
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr "變數 %s 於 %L 的型態 LOCK_TYPE 或與 subcomponent 的型態 LOCK_TYPE 必須是 coarray"
 
-#: fortran/resolve.c:14995
+#: fortran/resolve.c:15015
 #, fuzzy, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "含義 (出) 虛引數『%s』於 %L 是假設的大小和因而無法有預設初始設定式"
 
-#: fortran/resolve.c:15007
+#: fortran/resolve.c:15027
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "虛引數『%s』於 %L 的 LOCK_TYPE 不應該是含義 (出)"
 
-#: fortran/resolve.c:15016
+#: fortran/resolve.c:15036
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "虛引數『%s』於 %L 的 LOCK_TYPE 不應該是含義 (出)"
 
-#: fortran/resolve.c:15028
+#: fortran/resolve.c:15048
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "函數計算結果『%s』於 %L 不應該是 coarray 或有 coarray 成分"
 
-#: fortran/resolve.c:15037
+#: fortran/resolve.c:15057
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "變數『%s』於 %L 的型態 (C_PTR) 或型態 (C_FUNPTR) 不應該是 coarray"
 
-#: fortran/resolve.c:15049
+#: fortran/resolve.c:15069
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr "變數『%s』於 %L 與 coarray 成分應該是 nonpointer，nonallocatable 純量"
 
-#: fortran/resolve.c:15065
+#: fortran/resolve.c:15085
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr "變數『%s』於 %L 是 coarray 和不是 ALLOCATABLE，儲存 nor 虛引數"
 
-#: fortran/resolve.c:15073
+#: fortran/resolve.c:15093
 #, fuzzy, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "Coarray 變數『%s』於 %L 不應該有 codimensions 與已推遲形狀"
 
-#: fortran/resolve.c:15080
+#: fortran/resolve.c:15100
 #, fuzzy, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "Allocatable coarray 變數『%s』於 %L 必須已已推遲形狀"
 
-#: fortran/resolve.c:15092
+#: fortran/resolve.c:15112
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "變數『%s』於 %L 是含義 (出) 和可以因而無法是 allocatable coarray 或有 coarray 成分"
 
-#: fortran/resolve.c:15101
+#: fortran/resolve.c:15121
 #, fuzzy, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "Coarray 虛設變數『%s』於 %L 不允許在中繫結©程序『%s』"
 
-#: fortran/resolve.c:15117
+#: fortran/resolve.c:15137
 #, fuzzy, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "Coarray 虛設變數『%s』於 %L 不允許在中繫結©程序『%s』"
 
-#: fortran/resolve.c:15123
+#: fortran/resolve.c:15143
 #, fuzzy, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "Coarray 虛設變數『%s』於 %L 不允許在中繫結©程序『%s』"
 
-#: fortran/resolve.c:15148
+#: fortran/resolve.c:15168
 #, fuzzy, gcc-internal-format
 msgid "Namelist %qs can not be an argument to subroutine or function at %L"
 msgstr "名稱表列 %s 無法重新命名的由使用關聯到 %s"
 
-#: fortran/resolve.c:15218
+#: fortran/resolve.c:15238
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "Threadprivate 於 %L 不是儲存"
 
-#: fortran/resolve.c:15229
+#: fortran/resolve.c:15249
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:15333
+#: fortran/resolve.c:15353
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:15339
+#: fortran/resolve.c:15359
 #, fuzzy, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "區塊資料元素『%s』於 %L 必須是在中共同"
 
-#: fortran/resolve.c:15345
+#: fortran/resolve.c:15365
 #, fuzzy, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "資料陣列『%s』於 %L 必須被指定的在中前一個宣告"
 
-#: fortran/resolve.c:15354
+#: fortran/resolve.c:15374
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "資料元素『%s』於 %L 無法有 coindex"
 
-#: fortran/resolve.c:15368
+#: fortran/resolve.c:15388
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr "資料元素『%s』於 %L 是指標和因而必須是全部陣列"
 
-#: fortran/resolve.c:15414
+#: fortran/resolve.c:15434
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "Nonconstant 陣列區段於 %L 在中資料敘述"
 
-#: fortran/resolve.c:15427
+#: fortran/resolve.c:15447
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "資料敘述於 %L 有更多變數比值"
 
-#: fortran/resolve.c:15526
+#: fortran/resolve.c:15546
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr "開始的 implied-do 迴圈於 %L 無法被簡化到常數"
 
-#: fortran/resolve.c:15534
+#: fortran/resolve.c:15554
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr "結束的 implied-do 迴圈於 %L 無法被簡化到常數"
 
-#: fortran/resolve.c:15542
+#: fortran/resolve.c:15562
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr "步驟的 implied-do 迴圈於 %L 無法被簡化到常數"
 
-#: fortran/resolve.c:15667
+#: fortran/resolve.c:15687
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "資料敘述於 %L 有更多值比變數"
 
-#: fortran/resolve.c:15832
+#: fortran/resolve.c:15852
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "標籤 %d 於 %L 經定義但未被使用"
 
-#: fortran/resolve.c:15838
+#: fortran/resolve.c:15858
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "標籤 %d 於 %L 經定義但無法被使用"
 
-#: fortran/resolve.c:15922
+#: fortran/resolve.c:15942
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "衍生類型變數『%s』於 %L 必須有序列屬性為等價物件"
 
-#: fortran/resolve.c:15931
+#: fortran/resolve.c:15951
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "衍生類型變數『%s』於 %L 無法有 ALLOCATABLE 成分為等價物件"
 
-#: fortran/resolve.c:15939
+#: fortran/resolve.c:15959
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "衍生類型變數『%s』於 %L 與預設初始化無法在中等價與變數在中共同"
 
-#: fortran/resolve.c:15955
+#: fortran/resolve.c:15975
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "衍生類型變數『%s』於 %L 與指標成分無法等價物件"
 
-#: fortran/resolve.c:16058
+#: fortran/resolve.c:16078
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "%L 處 EQUIVALENCE 敘述語法錯誤"
 
-#: fortran/resolve.c:16073
+#: fortran/resolve.c:16093
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr "還是所有或沒有任何物件在中等價設定於 %L 應該有保護的屬性"
 
-#: fortran/resolve.c:16098
+#: fortran/resolve.c:16118
 #, fuzzy, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "共同區塊成員『%s』於 %L 無法等價物件在中 pure 程序『%s』"
 
-#: fortran/resolve.c:16107
+#: fortran/resolve.c:16127
 #, fuzzy, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "具名的常數『%s』於 %L 無法等價物件"
 
-#: fortran/resolve.c:16180
+#: fortran/resolve.c:16200
 #, fuzzy, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "陣列『%s』於 %L 與 non-constant 邊界無法等價物件"
 
-#: fortran/resolve.c:16191
+#: fortran/resolve.c:16211
 #, fuzzy, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "結構成分『%s』於 %L 無法等價物件"
 
-#: fortran/resolve.c:16202
+#: fortran/resolve.c:16222
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "%L 的子字串長度為零"
 
-#: fortran/resolve.c:16293
+#: fortran/resolve.c:16253
 #, fuzzy, gcc-internal-format
+#| msgid "Syntax error in character length specification at %C"
+msgid "Self reference in character length expression for %qs at %L"
+msgstr "%C 處指定字元長度時語法錯誤"
+
+#: fortran/resolve.c:16320
+#, fuzzy, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "Fortran 2003:公用的函式『%s』於 %L 的私人的型態『%s』"
 
-#: fortran/resolve.c:16306
+#: fortran/resolve.c:16333
 #, fuzzy, gcc-internal-format
 #| msgid "ENTRY '%s' at %L has no IMPLICIT type"
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "ENTRY「%s」在 %L 處沒有 IMPLICIT 類型"
 
-#: fortran/resolve.c:16326
+#: fortran/resolve.c:16353
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "使用者運算子程序『%s』於 %L 必須是函式"
 
-#: fortran/resolve.c:16336
+#: fortran/resolve.c:16363
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "使用者運算子程序『%s』於 %L 無法假設的字元長度"
 
-#: fortran/resolve.c:16344
+#: fortran/resolve.c:16371
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "使用者運算子程序『%s』於 %L 必須至少有一個引數"
 
-#: fortran/resolve.c:16358
+#: fortran/resolve.c:16385
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "第一個引數的運算子介面於 %L 無法可選的"
 
-#: fortran/resolve.c:16376
+#: fortran/resolve.c:16403
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "秒引數的運算子介面於 %L 無法可選的"
 
-#: fortran/resolve.c:16383
+#: fortran/resolve.c:16410
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "運算子介面於 %L 必須有，最多，兩引數"
 
-#: fortran/resolve.c:16461
+#: fortran/resolve.c:16488
 #, fuzzy, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr "包含的程序『%s』於 %L 的 PURE 程序必須也是 PURE"
@@ -65049,19 +65133,12 @@
 msgid "simplify_min_max(): Bad type in arglist"
 msgstr ""
 
-#. Result is processor-dependent.
-#: fortran/simplify.c:5472
-#, gcc-internal-format, gfc-internal-format
-msgid "Second argument MOD at %L is zero"
-msgstr "%L 處 MOD 的第二個參數為 0"
+#: fortran/simplify.c:5470 fortran/simplify.c:5478
+#, fuzzy, gcc-internal-format
+msgid "Argument %qs of MOD at %L shall not be zero"
+msgstr "引數『S』的最近的於 %L 不應該是零"
 
-#. Result is processor-dependent.
-#: fortran/simplify.c:5483
-#, gcc-internal-format, gfc-internal-format
-msgid "Second argument of MOD at %L is zero"
-msgstr "%L 處 MOD 的第二個參數為 0"
-
-#: fortran/simplify.c:5494
+#: fortran/simplify.c:5484
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_simplify_mod(): Bad arguments"
@@ -65070,101 +65147,101 @@
 #. Result is processor-dependent. This processor just opts
 #. to not handle it at all.
 #. Result is processor-dependent.
-#: fortran/simplify.c:5520 fortran/simplify.c:5532
+#: fortran/simplify.c:5525 fortran/simplify.c:5537
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of MODULO at %L is zero"
 msgstr "%L 處 MODULO 的第二個參數為 0"
 
-#: fortran/simplify.c:5552
+#: fortran/simplify.c:5557
 #, gcc-internal-format
 msgid "gfc_simplify_modulo(): Bad arguments"
 msgstr ""
 
-#: fortran/simplify.c:5600
+#: fortran/simplify.c:5605
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Result of NEAREST is NaN at %L"
 msgstr "結果的最近的是 NaN 於 %L"
 
-#: fortran/simplify.c:6081
+#: fortran/simplify.c:6086
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative at %L"
 msgstr "引數 NCOPIES 的重複 intrinsic 是負於 %L"
 
-#: fortran/simplify.c:6137
+#: fortran/simplify.c:6142
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument NCOPIES of REPEAT intrinsic is too large at %L"
 msgstr "引數 NCOPIES 的重複 intrinsic 太大於 %L"
 
-#: fortran/simplify.c:6174
+#: fortran/simplify.c:6179
 #, gcc-internal-format, gfc-internal-format
 msgid "Evaluation of string longer than 2**28 at %L deferred to runtime, expect bugs"
 msgstr ""
 
-#: fortran/simplify.c:6302
+#: fortran/simplify.c:6307
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Integer too large at %C"
 msgid "Reshaped array too large at %C"
 msgstr "%C 處整數太大"
 
-#: fortran/simplify.c:6416
+#: fortran/simplify.c:6421
 #, gcc-internal-format, gfc-internal-format
 msgid "Result of SCALE overflows its kind at %L"
 msgstr "%L 處 SCALE 的結果向上溢位其種別"
 
-#: fortran/simplify.c:6995
+#: fortran/simplify.c:7000
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "Bad type in gfc_simplify_sign"
 msgstr "常數運算式中類型錯誤"
 
-#: fortran/simplify.c:7024
+#: fortran/simplify.c:7029
 #, gcc-internal-format
 msgid "in gfc_simplify_sin(): Bad type"
 msgstr ""
 
-#: fortran/simplify.c:7151 fortran/simplify.c:7431
+#: fortran/simplify.c:7156 fortran/simplify.c:7436
 #, gcc-internal-format
 msgid "Failure getting length of a constant array."
 msgstr ""
 
-#: fortran/simplify.c:7161
+#: fortran/simplify.c:7166
 #, fuzzy, gcc-internal-format
 msgid "The number of elements (%d) in the array constructor at %L requires an increase of the allowed %d upper limit.  See %<-fmax-array-constructor%> option."
 msgstr "元件號碼的在中陣列建構子於 %L 需求增加的允許 %d 上限。  參看 -fmax-array-constructor 選項"
 
-#: fortran/simplify.c:7227
+#: fortran/simplify.c:7232
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Simplification of SPREAD at %C not yet implemented"
 msgstr "Finalization 於 %L 不是未實作"
 
-#: fortran/simplify.c:7251
+#: fortran/simplify.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SQRT at %L has a negative value"
 msgstr "%L 處 SQRT 的參數為負"
 
-#: fortran/simplify.c:7267
+#: fortran/simplify.c:7272
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid second argument of IBSET at %L"
 msgid "invalid argument of SQRT at %L"
 msgstr "%L 處 IBSET 的第二個參數無效"
 
-#: fortran/simplify.c:7598
+#: fortran/simplify.c:7603
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY lower bound is %ld)"
 msgstr "發信匣的邊界在中 IMAGE_INDEX 於 %L 用於尺寸 %d，子有 %ld 和 COARRAY 下限是 %ld)"
 
-#: fortran/simplify.c:7621
+#: fortran/simplify.c:7626
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY upper bound is %ld)"
 msgstr "發信匣的邊界在中 IMAGE_INDEX 於 %L 用於尺寸 %d，子有 %ld 和 COARRAY 上限是 %ld)"
 
-#: fortran/simplify.c:7993
+#: fortran/simplify.c:7998
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_conv_constant_to_tree(): invalid type: %s"
 msgid "gfc_convert_constant(): Unexpected type"
 msgstr "gfc_conv_constant_to_tree()：無效類型；%s"
 
-#: fortran/simplify.c:8078
+#: fortran/simplify.c:8083
 #, fuzzy, gcc-internal-format
 msgid "Character %qs in string at %L cannot be converted into character kind %d"
 msgstr "字元『%s』在中字串於 %L 無法轉換的進入字元 kind %d"
@@ -65272,7 +65349,7 @@
 msgid "BIND(C) applied to %s %s at %L"
 msgstr "繫結©套用到 %s %s 於 %L"
 
-#: fortran/symbol.c:901 fortran/symbol.c:912 fortran/symbol.c:1762
+#: fortran/symbol.c:901 fortran/symbol.c:912 fortran/symbol.c:1776
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute conflicts with %s attribute at %L"
 msgstr "%s 屬性與 %s 屬性在 %L 處衝突"
@@ -65348,17 +65425,23 @@
 msgid "Duplicate VOLATILE attribute specified at %L"
 msgstr "重製易變的屬性指定的於 %L"
 
-#: fortran/symbol.c:1367
+#: fortran/symbol.c:1360
 #, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "SAVE attribute at %L cannot be specified in a PURE procedure"
+msgid "VOLATILE attribute at %L cannot be specified in a PURE procedure"
+msgstr "%L 處 PURE 程序不能指定 SAVE 屬性"
+
+#: fortran/symbol.c:1381
+#, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ASYNCHRONOUS attribute specified at %L"
 msgstr "重製非同步屬性指定的於 %L"
 
-#: fortran/symbol.c:1758
+#: fortran/symbol.c:1772
 #, fuzzy, gcc-internal-format
 msgid "%s attribute of %qs conflicts with %s attribute at %L"
 msgstr "%s 屬性的『%s』衝突與 %s 屬性於 %L"
 
-#: fortran/symbol.c:1794
+#: fortran/symbol.c:1808
 #, gcc-internal-format, gfc-internal-format
 msgid ""
 "%s procedure at %L is already declared as %s procedure. \n"
@@ -65365,215 +65448,215 @@
 "F2008: A pointer function assignment is ambiguous if it is the first executable statement after the specification block. Please add any other kind of executable statement before it. FIXME"
 msgstr ""
 
-#: fortran/symbol.c:1802
+#: fortran/symbol.c:1816
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s procedure at %L is already declared as %s procedure"
 msgstr "%s 程序於 %L 已經宣告的做為 %s 程序"
 
-#: fortran/symbol.c:1837
+#: fortran/symbol.c:1851
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgstr "INTENT (%s) 與 INTENT(%s) 在 %L 衝突"
 
-#: fortran/symbol.c:1861
+#: fortran/symbol.c:1875
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ACCESS specification at %L was already specified"
 msgstr "存取規格於 %L 已經指定的"
 
-#: fortran/symbol.c:1878
+#: fortran/symbol.c:1892
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate BIND attribute specified at %L"
 msgstr "重製繫結屬性指定的於 %L"
 
-#: fortran/symbol.c:1885
+#: fortran/symbol.c:1899
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) at %L"
 msgstr "Fortran 2003:繫結©於 %L"
 
-#: fortran/symbol.c:1901
+#: fortran/symbol.c:1915
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate EXTENDS attribute specified at %L"
 msgstr "重製延伸屬性指定的於 %L"
 
-#: fortran/symbol.c:1905
+#: fortran/symbol.c:1919
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "EXTENDS at %L"
 msgstr "Fortran 2003:延伸於 %L"
 
-#: fortran/symbol.c:1931
+#: fortran/symbol.c:1945
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L already has an explicit interface"
 msgid "Symbol %qs at %L already has an explicit interface"
 msgstr "符號「%s」在 %L 處已經有了明確介面"
 
-#: fortran/symbol.c:1938
+#: fortran/symbol.c:1952
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L has attributes specified outside its INTERFACE body"
 msgstr "『%s』於 %L 有屬性指定的外側它的介面內文"
 
-#: fortran/symbol.c:1976
+#: fortran/symbol.c:1990
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L conflicts with symbol from module %qs, use-associated at %L"
 msgstr "符號『%s』於 %L 衝突與符號從模組『%s』，use-associated 於 %L"
 
-#: fortran/symbol.c:1980
+#: fortran/symbol.c:1994
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L already has basic type of %s"
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr "符號「%s」在 %L 處已經有了基本類型 %s"
 
-#: fortran/symbol.c:1987
+#: fortran/symbol.c:2001
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr "程序『%s』於 %L 可能無法有基本型式的 %s"
 
-#: fortran/symbol.c:1999
+#: fortran/symbol.c:2013
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L cannot have a type"
 msgid "Symbol %qs at %L cannot have a type"
 msgstr "符號「%s」於 %L 處不能有類型"
 
-#: fortran/symbol.c:2242
+#: fortran/symbol.c:2256
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %C already in the parent type at %L"
 msgstr "成分『%s』於 %C 已經在中親代型態於 %L"
 
-#: fortran/symbol.c:2327
+#: fortran/symbol.c:2341
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C is ambiguous"
 msgid "Symbol %qs at %C is ambiguous"
 msgstr "符號「%s」在 %C 處有歧義"
 
-#: fortran/symbol.c:2359
+#: fortran/symbol.c:2373
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr "衍生類型『%s』於 %C 正在被使用之前它被定義"
 
-#: fortran/symbol.c:2508
+#: fortran/symbol.c:2522
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C is a PRIVATE component of '%s'"
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr "元件「%s」在 %C 處是「%s」的 PRIVATE 元件"
 
-#: fortran/symbol.c:2529
+#: fortran/symbol.c:2543
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is not a member of the '%s' structure"
 msgid "%qs at %C is not a member of the %qs structure; did you mean %qs?"
 msgstr "「%s」在 %C 處不是「%s」結構的成員"
 
-#: fortran/symbol.c:2533
+#: fortran/symbol.c:2547
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is not a member of the '%s' structure"
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr "「%s」在 %C 處不是「%s」結構的成員"
 
-#: fortran/symbol.c:2697
+#: fortran/symbol.c:2711
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr "重複的敘述標籤 %d 出現在 %L 和 %L 處"
 
-#: fortran/symbol.c:2708
+#: fortran/symbol.c:2722
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr "標貼 %d 於 %C 已經引用做為分支目標"
 
-#: fortran/symbol.c:2718
+#: fortran/symbol.c:2732
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr "標貼 %d 於 %C 已經引用做為格式標貼"
 
-#: fortran/symbol.c:2724
+#: fortran/symbol.c:2738
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:2766
+#: fortran/symbol.c:2780
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr "標貼 %d 於 %C 在之前使用的做為格式標貼"
 
-#: fortran/symbol.c:2775
+#: fortran/symbol.c:2789
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr "標貼 %d 於 %C 在之前使用的做為分支目標"
 
-#: fortran/symbol.c:2781
+#: fortran/symbol.c:2795
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Shared DO termination label %d at %C"
 msgstr "%C 處需要結束名"
 
-#: fortran/symbol.c:3110
+#: fortran/symbol.c:3124
 #, gcc-internal-format
 msgid "new_symbol(): Symbol name too long"
 msgstr ""
 
-#: fortran/symbol.c:3135
+#: fortran/symbol.c:3149
 #, fuzzy, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr "名稱『%s』於 %C 是模稜兩可的參考到『%s』從模組『%s』"
 
-#: fortran/symbol.c:3138
+#: fortran/symbol.c:3152
 #, fuzzy, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
 msgstr "名稱『%s』於 %C 是模稜兩可的參考到『%s』從目前的程式單元"
 
 #. Symbol is from another namespace.
-#: fortran/symbol.c:3381
+#: fortran/symbol.c:3395
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C has already been host associated"
 msgstr "符號『%s』於 %C 已主機關聯的"
 
-#: fortran/symbol.c:4397
+#: fortran/symbol.c:4411
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr ""
 
-#: fortran/symbol.c:4410
+#: fortran/symbol.c:4424
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr "衍生類型『%s』宣告的於 %L 必須有繫結屬性為 C 可交流的"
 
-#: fortran/symbol.c:4428
+#: fortran/symbol.c:4442
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr "衍生類型『%s』與繫結©屬性於 %L 是空的，而也許會是不可存取由 C companion 處理器"
 
-#: fortran/symbol.c:4449
+#: fortran/symbol.c:4463
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr "成分『%s』於 %L 無法有指標屬性因為它是成員的繫結©衍生類型『%s』於 %L"
 
-#: fortran/symbol.c:4459
+#: fortran/symbol.c:4473
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs at %L cannot be a member of the BIND(C) derived type %qs at %L"
 msgstr "程序指標成分『%s』於 %L 無法成員的繫結©衍生類型『%s』於 %L"
 
-#: fortran/symbol.c:4470
+#: fortran/symbol.c:4484
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr "成分『%s』於 %L 無法有 ALLOCATABLE 屬性因為它是成員的繫結©衍生類型『%s』於 %L"
 
-#: fortran/symbol.c:4509
+#: fortran/symbol.c:4523
 #, fuzzy, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr "成分『%s』在中衍生類型『%s』於 %L 可能無法是 C 可交流的，甚至雖然衍生類型『%s』是繫結©"
 
-#: fortran/symbol.c:4519
+#: fortran/symbol.c:4533
 #, fuzzy, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr "成分『%s』在中衍生類型『%s』於 %L 可能無法是 C 可交流的"
 
-#: fortran/symbol.c:4533
+#: fortran/symbol.c:4547
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L cannot be declared with both PRIVATE and BIND(C) attributes"
 msgstr "衍生類型『%s』於 %L 無法宣告的與兩者私人的和繫結©屬性"
 
-#: fortran/symbol.c:4541
+#: fortran/symbol.c:4555
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr "衍生類型『%s』於 %L 無法有序列屬性因為它是繫結©"
 
-#: fortran/symbol.c:5018 fortran/symbol.c:5023
+#: fortran/symbol.c:5032 fortran/symbol.c:5037
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs is used before it is typed at %L"
 msgstr "符號『%s』被使用之前它被型態於 %L"
@@ -65620,7 +65703,7 @@
 msgid "Creating array temporary at %L for argument %qs"
 msgstr "建立陣列暫時的於 %L 用於引數『%s』"
 
-#: fortran/trans-array.c:10693
+#: fortran/trans-array.c:10724
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr "不當的運算式型態在的期間遍歷 (%d)"
@@ -65825,12 +65908,12 @@
 msgid "%<dim%> argument of %s intrinsic at %L is not a valid dimension index"
 msgstr "『dim』引數的 %s intrinsic 於 %L 並非有效尺寸索引"
 
-#: fortran/trans-intrinsic.c:10572 fortran/trans-stmt.c:1050
+#: fortran/trans-intrinsic.c:10574 fortran/trans-stmt.c:1050
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Sorry, the event component of derived type at %L is not yet supported"
 msgstr "Deferred-length 字元成分『%s』於 %L 不是未支援"
 
-#: fortran/trans-intrinsic.c:10579
+#: fortran/trans-intrinsic.c:10581
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The event variable at %L shall not be coindexed"
 msgstr "指標物件於 %C 不應該被 coindexed"
@@ -65870,7 +65953,7 @@
 msgid "Sorry, only support for integer kind %d implemented for image-set at %L"
 msgstr "抱歉，只有支援用於整數 kind %d 實作的用於 image-set 於 %L"
 
-#: fortran/trans-stmt.c:3346
+#: fortran/trans-stmt.c:3343
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_trans_select(): Bad type for case expr."
@@ -65997,7 +66080,7 @@
 msgid "two or more sections for %s"
 msgstr "兩個以上區段用於 %s"
 
-#: lto/lto-partition.c:516
+#: lto/lto-partition.c:570
 #, gcc-internal-format
 msgid "min partition size cannot be greater than max partition size"
 msgstr ""
@@ -66132,58 +66215,58 @@
 msgid "Cannot read %s"
 msgstr "無法讀取 %s"
 
-#: lto/lto.c:2369
+#: lto/lto.c:2337
 #, fuzzy, gcc-internal-format
 msgid "lto_obj_file_open() failed"
 msgstr "lto_obj_file_open() 失敗"
 
-#: lto/lto.c:2394
+#: lto/lto.c:2362
 #, fuzzy, gcc-internal-format
 msgid "waitpid failed"
 msgstr "atexit 失敗"
 
-#: lto/lto.c:2397
+#: lto/lto.c:2365
 #, fuzzy, gcc-internal-format
 msgid "streaming subprocess failed"
 msgstr "重新命名.rpo 檔案：%m"
 
-#: lto/lto.c:2400
+#: lto/lto.c:2368
 #, gcc-internal-format
 msgid "streaming subprocess was killed by signal"
 msgstr ""
 
-#: lto/lto.c:2476
+#: lto/lto.c:2445
 #, fuzzy, gcc-internal-format
 msgid "no LTRANS output list filename provided"
 msgstr "沒有 LTRANS 輸出清單檔名提供"
 
-#: lto/lto.c:2564
+#: lto/lto.c:2525
 #, fuzzy, gcc-internal-format
 msgid "opening LTRANS output list %s: %m"
 msgstr "開啟 LTRANS 輸出清單 %s：%m"
 
-#: lto/lto.c:2570
+#: lto/lto.c:2532
 #, fuzzy, gcc-internal-format
 msgid "writing to LTRANS output list %s: %m"
 msgstr "寫入 LTRANS 輸出清單 %s：%m"
 
-#: lto/lto.c:2581
+#: lto/lto.c:2542
 #, fuzzy, gcc-internal-format
 msgid "closing LTRANS output list %s: %m"
 msgstr "關閉 LTRANS 輸出清單 %s：%m"
 
-#: lto/lto.c:2833
+#: lto/lto.c:2794
 #, fuzzy, gcc-internal-format
 msgid "could not open symbol resolution file: %m"
 msgstr "無法開啟符號解析度檔案：%m"
 
-#: lto/lto.c:2954
+#: lto/lto.c:2915
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing braces around initializer for %qT"
 msgid "missing resolution data for %s"
 msgstr "%qT 的初始值設定周圍缺少大括號"
 
-#: lto/lto.c:2986
+#: lto/lto.c:2947
 #, fuzzy, gcc-internal-format
 msgid "errors during merging of translation units"
 msgstr "錯誤在的期間合併的轉譯單位"
@@ -67795,6 +67878,9 @@
 #~ msgid "Set the target VM version"
 #~ msgstr "設定目標 VM 版本"
 
+#~ msgid "Warn if the loop cannot be optimized due to nontrivial assumptions."
+#~ msgstr "當循環因為不平凡的假定而不能被最佳化時給出警告"
+
 #, fuzzy
 #~ msgid "Compare the results of several data dependence analyzers."
 #~ msgstr "比較結果的多個資料 dependence 分析器。"
@@ -69281,6 +69367,10 @@
 #~ msgstr "形狀參數用於呼叫到 %s 於 %L 必須是分級 1 整數陣列"
 
 #, fuzzy
+#~ msgid "Errmsg-variable at %L must be a scalar CHARACTER variable"
+#~ msgstr "Errmsg-variable 於 %L 必須是純量字元變數"
+
+#, fuzzy
 #~ msgid "NULL intrinsic at %L in data transfer statement requires MOLD="
 #~ msgstr "空值 intrinsic 於 %L 在中資料轉移敘述需求鑄型="
 
Index: gcc/po/id.po
===================================================================
--- gcc/po/id.po	(.../tags/gcc_8_2_0_release)
+++ gcc/po/id.po	(.../branches/gcc-8-branch)
@@ -7,7 +7,7 @@
 msgstr ""
 "Project-Id-Version: gcc 4.4.1\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2018-05-01 20:30+0000\n"
+"POT-Creation-Date: 2018-07-25 14:25+0000\n"
 "PO-Revision-Date: 2009-11-10 09:00+0700\n"
 "Last-Translator: Arif E. Nugroho <arif_endro@yahoo.com>\n"
 "Language-Team: Indonesian <translation-team-id@lists.sourceforge.net>\n"
@@ -38,13 +38,13 @@
 msgid "[cannot find %s]"
 msgstr "[tidak dapat menemukan %s]"
 
-#: collect2.c:1557
+#: collect2.c:1585
 #, fuzzy, c-format
 #| msgid "collect2 version %s"
 msgid "collect2 version %s\n"
 msgstr "collect2 versi %s"
 
-#: collect2.c:1664
+#: collect2.c:1692
 #, fuzzy, c-format
 #| msgid "%d constructor(s) found\n"
 msgid "%d constructor found\n"
@@ -52,7 +52,7 @@
 msgstr[0] "%d konstruktor ditemukan\n"
 msgstr[1] "%d konstruktor ditemukan\n"
 
-#: collect2.c:1668
+#: collect2.c:1696
 #, fuzzy, c-format
 #| msgid "%d destructor(s)  found\n"
 msgid "%d destructor found\n"
@@ -60,7 +60,7 @@
 msgstr[0] "%d destruktor ditemukan\n"
 msgstr[1] "%d destruktor ditemukan\n"
 
-#: collect2.c:1672
+#: collect2.c:1700
 #, fuzzy, c-format
 #| msgid "%d frame table(s) found\n"
 msgid "%d frame table found\n"
@@ -68,12 +68,12 @@
 msgstr[0] "%d tabel frame ditemukan\n"
 msgstr[1] "%d tabel frame ditemukan\n"
 
-#: collect2.c:1836
+#: collect2.c:1864
 #, c-format
 msgid "[Leaving %s]\n"
 msgstr "[Meninggalkan %s]\n"
 
-#: collect2.c:2068
+#: collect2.c:2094
 #, c-format
 msgid ""
 "\n"
@@ -82,7 +82,7 @@
 "\n"
 "write_c_file - nama keluaran adalah %s, awalan adalah %s\n"
 
-#: collect2.c:2584
+#: collect2.c:2610
 #, c-format
 msgid ""
 "\n"
@@ -109,7 +109,7 @@
 msgid "%s: some warnings being treated as errors"
 msgstr "%s: peringatan: tidak ada akses baca untuk berkas '%s'\n"
 
-#: diagnostic.c:324 input.c:222 input.c:1834 c-family/c-opts.c:1377
+#: diagnostic.c:324 input.c:222 input.c:1834 c-family/c-opts.c:1392
 #: fortran/cpp.c:576 fortran/error.c:1008 fortran/error.c:1028
 msgid "<built-in>"
 msgstr "<sudah-termasuk>"
@@ -208,13 +208,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:4164 config/arc/arc.c:5784 config/i386/i386.c:17302
+#: final.c:4164 config/arc/arc.c:5775 config/i386/i386.c:17305
 #: config/pdp11/pdp11.c:1715
 #, c-format
 msgid "floating constant misused"
 msgstr "konstanta pecahan disalah gunakan"
 
-#: final.c:4222 config/arc/arc.c:5881 config/i386/i386.c:17393
+#: final.c:4222 config/arc/arc.c:5872 config/i386/i386.c:17396
 #: config/pdp11/pdp11.c:1756
 #, c-format
 msgid "invalid expression as operand"
@@ -1246,7 +1246,7 @@
 msgid "GCSE disabled"
 msgstr "GCSE tidak aktif"
 
-#: gimple-ssa-isolate-paths.c:542 c/c-typeck.c:10240
+#: gimple-ssa-isolate-paths.c:542 c/c-typeck.c:10245
 #, gcc-internal-format
 msgid "function returns address of local variable"
 msgstr "fungsi mengembalikan alamat dari variabel lokal"
@@ -1559,7 +1559,7 @@
 msgid "options enabled: "
 msgstr "pilihan aktif: "
 
-#: tree-diagnostic.c:299 c/c-decl.c:5419 c/c-typeck.c:7259 cp/error.c:1042
+#: tree-diagnostic.c:299 c/c-decl.c:5439 c/c-typeck.c:7264 cp/error.c:1042
 #: c-family/c-pretty-print.c:413
 #, gcc-internal-format
 msgid "<anonymous>"
@@ -3146,71 +3146,71 @@
 msgstr "pemodifikasi panjang dalam format strfmon"
 
 #. Handle deferred options from command-line.
-#: c-family/c-opts.c:1402 fortran/cpp.c:590
+#: c-family/c-opts.c:1417 fortran/cpp.c:590
 msgid "<command-line>"
 msgstr "<baris-perintah>"
 
-#: config/aarch64/aarch64.c:6613
+#: config/aarch64/aarch64.c:6629
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "unsupported operand for code '%c'"
 msgstr "operan tidak valid untuk kode '%c'"
 
-#: config/aarch64/aarch64.c:6624 config/aarch64/aarch64.c:6640
-#: config/aarch64/aarch64.c:6652 config/aarch64/aarch64.c:6663
-#: config/aarch64/aarch64.c:6673 config/aarch64/aarch64.c:6694
-#: config/aarch64/aarch64.c:6764 config/aarch64/aarch64.c:6775
-#: config/aarch64/aarch64.c:6789 config/aarch64/aarch64.c:7011
-#: config/aarch64/aarch64.c:7029
+#: config/aarch64/aarch64.c:6640 config/aarch64/aarch64.c:6656
+#: config/aarch64/aarch64.c:6668 config/aarch64/aarch64.c:6679
+#: config/aarch64/aarch64.c:6689 config/aarch64/aarch64.c:6710
+#: config/aarch64/aarch64.c:6780 config/aarch64/aarch64.c:6791
+#: config/aarch64/aarch64.c:6805 config/aarch64/aarch64.c:7027
+#: config/aarch64/aarch64.c:7045
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "invalid operand for '%%%c'"
 msgstr "operan tidak valid untuk kode '%c'"
 
-#: config/aarch64/aarch64.c:6709 config/aarch64/aarch64.c:6720
-#: config/aarch64/aarch64.c:6871 config/aarch64/aarch64.c:6882
+#: config/aarch64/aarch64.c:6725 config/aarch64/aarch64.c:6736
+#: config/aarch64/aarch64.c:6887 config/aarch64/aarch64.c:6898
 #, fuzzy, c-format
 #| msgid "invalid punctuation %qc in constraint"
 msgid "invalid vector constant"
 msgstr "punctuation %qc tidak valid dalam batasan"
 
-#: config/aarch64/aarch64.c:6732 config/aarch64/aarch64.c:6744
-#: config/aarch64/aarch64.c:6755
+#: config/aarch64/aarch64.c:6748 config/aarch64/aarch64.c:6760
+#: config/aarch64/aarch64.c:6771
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6823 config/arm/arm.c:22704
+#: config/aarch64/aarch64.c:6839 config/arm/arm.c:22704
 #, c-format
 msgid "missing operand"
 msgstr "hilang operan"
 
-#: config/aarch64/aarch64.c:6908
+#: config/aarch64/aarch64.c:6924
 #, fuzzy, c-format
 #| msgid "invalid insn:"
 msgid "invalid constant"
 msgstr "insn tidak valid:"
 
-#: config/aarch64/aarch64.c:6911
+#: config/aarch64/aarch64.c:6927
 #, fuzzy, c-format
 #| msgid "invalid %%d operand"
 msgid "invalid operand"
 msgstr "operan %%d tidak valid"
 
-#: config/aarch64/aarch64.c:7040 config/aarch64/aarch64.c:7045
+#: config/aarch64/aarch64.c:7056 config/aarch64/aarch64.c:7061
 #, fuzzy, c-format
 #| msgid "invalid operand code '%c'"
 msgid "invalid operand prefix '%%%c'"
 msgstr "kode operan '%c' tidak valid"
 
-#: config/aarch64/aarch64.c:7062
+#: config/aarch64/aarch64.c:7078
 #, fuzzy, c-format
 #| msgid "invalid address"
 msgid "invalid address mode"
 msgstr "alamat tidak valid"
 
-#: config/alpha/alpha.c:5125 config/i386/i386.c:18558
-#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21798
+#: config/alpha/alpha.c:5125 config/i386/i386.c:18561
+#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21875
 #: config/sparc/sparc.c:9290
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
@@ -3227,7 +3227,7 @@
 msgstr "nilai %%r tidak valid"
 
 #: config/alpha/alpha.c:5223 config/ia64/ia64.c:5534
-#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21506
+#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21583
 #: config/xtensa/xtensa.c:2429
 #, c-format
 msgid "invalid %%R value"
@@ -3234,13 +3234,13 @@
 msgstr "nilai %%R tidak valid"
 
 #: config/alpha/alpha.c:5229 config/powerpcspe/powerpcspe.c:23933
-#: config/rs6000/rs6000.c:21426 config/xtensa/xtensa.c:2396
+#: config/rs6000/rs6000.c:21503 config/xtensa/xtensa.c:2396
 #, c-format
 msgid "invalid %%N value"
 msgstr "nilai %%N tidak valid"
 
 #: config/alpha/alpha.c:5237 config/powerpcspe/powerpcspe.c:23961
-#: config/rs6000/rs6000.c:21454
+#: config/rs6000/rs6000.c:21531
 #, c-format
 msgid "invalid %%P value"
 msgstr "nilai %%P tidak valid"
@@ -3271,7 +3271,7 @@
 msgstr "nilai %%U tidak valid"
 
 #: config/alpha/alpha.c:5323 config/powerpcspe/powerpcspe.c:24021
-#: config/rs6000/rs6000.c:21514
+#: config/rs6000/rs6000.c:21591
 #, c-format
 msgid "invalid %%s value"
 msgstr "nilai %%s tidak valid"
@@ -3282,7 +3282,7 @@
 msgstr "nilai %%C tidak valid"
 
 #: config/alpha/alpha.c:5371 config/powerpcspe/powerpcspe.c:23797
-#: config/rs6000/rs6000.c:21290
+#: config/rs6000/rs6000.c:21367
 #, c-format
 msgid "invalid %%E value"
 msgstr "nilai %%E tidak valid"
@@ -3293,7 +3293,7 @@
 msgstr "relokasi unspek tidak diketahui"
 
 #: config/alpha/alpha.c:5405 config/cr16/cr16.c:1569
-#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21803
+#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21880
 #: config/spu/spu.c:1458
 #, c-format
 msgid "invalid %%xn code"
@@ -3305,61 +3305,61 @@
 msgid "invalid operand address"
 msgstr "alamat tidak valid"
 
-#: config/arc/arc.c:3810
+#: config/arc/arc.c:3808
 #, fuzzy, c-format
 #| msgid "invalid operand to %%R code"
 msgid "invalid operand to %%Z code"
 msgstr "operan ke kode %%R tidak valid"
 
-#: config/arc/arc.c:3818
+#: config/arc/arc.c:3816
 #, fuzzy, c-format
 #| msgid "invalid operand to %%R code"
 msgid "invalid operand to %%z code"
 msgstr "operan ke kode %%R tidak valid"
 
-#: config/arc/arc.c:3826
+#: config/arc/arc.c:3824
 #, fuzzy, c-format
 #| msgid "invalid operand to %%R code"
 msgid "invalid operands to %%c code"
 msgstr "operan ke kode %%R tidak valid"
 
-#: config/arc/arc.c:3834
+#: config/arc/arc.c:3832
 #, fuzzy, c-format
 #| msgid "invalid operand to %%R code"
 msgid "invalid operand to %%M code"
 msgstr "operan ke kode %%R tidak valid"
 
-#: config/arc/arc.c:3842 config/m32r/m32r.c:2100
+#: config/arc/arc.c:3840 config/m32r/m32r.c:2100
 #, c-format
 msgid "invalid operand to %%p code"
 msgstr "operan ke kode %%p tidak valid"
 
-#: config/arc/arc.c:3853 config/m32r/m32r.c:2093
+#: config/arc/arc.c:3851 config/m32r/m32r.c:2093
 #, c-format
 msgid "invalid operand to %%s code"
 msgstr "operan ke kode %%s tidak valid"
 
-#: config/arc/arc.c:4001 config/m32r/m32r.c:2126
+#: config/arc/arc.c:3999 config/m32r/m32r.c:2126
 #, c-format
 msgid "invalid operand to %%R code"
 msgstr "operan ke kode %%R tidak valid"
 
-#: config/arc/arc.c:4077 config/m32r/m32r.c:2149
+#: config/arc/arc.c:4075 config/m32r/m32r.c:2149
 #, c-format
 msgid "invalid operand to %%H/%%L code"
 msgstr "operan ke kode %%H/%%L tidak valid"
 
-#: config/arc/arc.c:4145 config/m32r/m32r.c:2220
+#: config/arc/arc.c:4143 config/m32r/m32r.c:2220
 #, c-format
 msgid "invalid operand to %%U code"
 msgstr "operan ke kode %%U tidak valid"
 
-#: config/arc/arc.c:4157
+#: config/arc/arc.c:4155
 #, c-format
 msgid "invalid operand to %%V code"
 msgstr "operan ke kode %%V tidak valid"
 
-#: config/arc/arc.c:4214
+#: config/arc/arc.c:4212
 #, fuzzy, c-format
 #| msgid "invalid operand to %%R code"
 msgid "invalid operand to %%O code"
@@ -3367,19 +3367,19 @@
 
 #. Unknown flag.
 #. Undocumented flag.
-#: config/arc/arc.c:4240 config/epiphany/epiphany.c:1305
-#: config/m32r/m32r.c:2247 config/nds32/nds32.c:3079 config/sparc/sparc.c:9569
+#: config/arc/arc.c:4238 config/epiphany/epiphany.c:1305
+#: config/m32r/m32r.c:2247 config/nds32/nds32.c:3080 config/sparc/sparc.c:9569
 #, c-format
 msgid "invalid operand output code"
 msgstr "operan kode keluaran tidak valid"
 
-#: config/arc/arc.c:5869
+#: config/arc/arc.c:5860
 #, fuzzy, c-format
 #| msgid "invalid UNSPEC as operand"
 msgid "invalid UNSPEC as operand: %d"
 msgstr "UNSPEC tidak valid sebagai operan"
 
-#: config/arc/arc.c:6158 config/cris/cris.c:2568
+#: config/arc/arc.c:6149 config/cris/cris.c:2568
 msgid "unrecognized supposed constant"
 msgstr "konstanta yang diharapkan tidak dikenal"
 
@@ -3415,7 +3415,7 @@
 #: config/arm/arm.c:22685 config/arm/arm.c:22692 config/bfin/bfin.c:1441
 #: config/bfin/bfin.c:1448 config/bfin/bfin.c:1455 config/bfin/bfin.c:1462
 #: config/bfin/bfin.c:1471 config/bfin/bfin.c:1478 config/bfin/bfin.c:1485
-#: config/bfin/bfin.c:1492 config/nds32/nds32.c:3098
+#: config/bfin/bfin.c:1492 config/nds32/nds32.c:3099
 #, c-format
 msgid "invalid operand for code '%c'"
 msgstr "operan tidak valid untuk kode '%c'"
@@ -3769,111 +3769,111 @@
 msgid "bad output_condmove_single operand"
 msgstr "operan output_condmove_single buruk"
 
-#: config/i386/i386.c:17387
+#: config/i386/i386.c:17390
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "UNSPEC tidak valid sebagai operan"
 
-#: config/i386/i386.c:17925
+#: config/i386/i386.c:17928
 #, fuzzy, c-format
 #| msgid "invalid use of %<restrict%>"
 msgid "invalid use of register '%s'"
 msgstr "penggunaan tidak valid dari %<restrict%>"
 
-#: config/i386/i386.c:17930
+#: config/i386/i386.c:17933
 #, fuzzy, c-format
 #| msgid "invalid lvalue in asm output %d"
 msgid "invalid use of asm flag output"
 msgstr "lvalue tidak valid dalam keluaran asm %d"
 
-#: config/i386/i386.c:18160
+#: config/i386/i386.c:18163
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "invalid operand size for operand code 'O'"
 msgstr "operan tidak valid untuk kode '%c'"
 
-#: config/i386/i386.c:18195
+#: config/i386/i386.c:18198
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "invalid operand size for operand code 'z'"
 msgstr "operan tidak valid untuk kode '%c'"
 
-#: config/i386/i386.c:18264
+#: config/i386/i386.c:18267
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "operan tidak valid untuk kode '%c'"
 
-#: config/i386/i386.c:18269
+#: config/i386/i386.c:18272
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "invalid operand size for operand code 'Z'"
 msgstr "operan tidak valid untuk kode '%c'"
 
-#: config/i386/i386.c:18346
+#: config/i386/i386.c:18349
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'D'"
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "operan bukan sebuah kode kondisi, kode operan 'D' tidak valid"
 
-#: config/i386/i386.c:18425
+#: config/i386/i386.c:18428
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "operan bukan sebuah kode kondisi, kode operan 'D' tidak valid"
 
-#: config/i386/i386.c:18443
+#: config/i386/i386.c:18446
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'D'"
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "operan bukan sebuah kode kondisi, kode operan 'D' tidak valid"
 
-#: config/i386/i386.c:18456
+#: config/i386/i386.c:18459
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'D'"
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "operan bukan sebuah kode kondisi, kode operan 'D' tidak valid"
 
-#: config/i386/i386.c:18471
+#: config/i386/i386.c:18474
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'D'"
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr "operan bukan sebuah kode kondisi, kode operan 'D' tidak valid"
 
-#: config/i386/i386.c:18499
+#: config/i386/i386.c:18502
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'D'"
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr "operan bukan sebuah kode kondisi, kode operan 'D' tidak valid"
 
-#: config/i386/i386.c:18517
+#: config/i386/i386.c:18520
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'D'"
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr "operan bukan sebuah kode kondisi, kode operan 'D' tidak valid"
 
-#: config/i386/i386.c:18540
+#: config/i386/i386.c:18543
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'D'"
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "operan bukan sebuah kode kondisi, kode operan 'D' tidak valid"
 
-#: config/i386/i386.c:18626
+#: config/i386/i386.c:18629
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "kode operan '%c' tidak valid"
 
-#: config/i386/i386.c:18688
+#: config/i386/i386.c:18691
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "batasan untuk operan tidak valid"
 
-#: config/i386/i386.c:18738
+#: config/i386/i386.c:18741
 #, fuzzy, c-format
 #| msgid "invalid controlling predicate"
 msgid "invalid vector immediate"
 msgstr "predikat pengontrol tidak valid"
 
-#: config/i386/i386.c:29572
+#: config/i386/i386.c:29575
 msgid "unknown insn mode"
 msgstr "mode insn tidak diketahui"
 
@@ -3913,7 +3913,7 @@
 msgstr "operan %%P tidak valid"
 
 #: config/iq2000/iq2000.c:3185 config/powerpcspe/powerpcspe.c:23951
-#: config/rs6000/rs6000.c:21444
+#: config/rs6000/rs6000.c:21521
 #, c-format
 msgid "invalid %%p value"
 msgstr "nilai %%p tidak valid"
@@ -3971,7 +3971,7 @@
 msgstr "alamat post-increment bukan sebuah register"
 
 #: config/m32r/m32r.c:2350 config/m32r/m32r.c:2365
-#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33292
+#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33348
 msgid "bad address"
 msgstr "alamat buruk"
 
@@ -4098,206 +4098,206 @@
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr "Mencoba menjalankan '%s' dalam shell untuk meningkatkan batasannya.\n"
 
-#: config/powerpcspe/powerpcspe.c:4411 config/rs6000/rs6000.c:4258
+#: config/powerpcspe/powerpcspe.c:4411 config/rs6000/rs6000.c:4278
 msgid "-maltivec=le not allowed for big-endian targets"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4423 config/rs6000/rs6000.c:4273
+#: config/powerpcspe/powerpcspe.c:4423 config/rs6000/rs6000.c:4293
 #, fuzzy
 #| msgid "Use hardware floating point"
 msgid "-mvsx requires hardware floating point"
 msgstr "Gunakan piranti keras titik pecahan"
 
-#: config/powerpcspe/powerpcspe.c:4431 config/rs6000/rs6000.c:4281
+#: config/powerpcspe/powerpcspe.c:4431 config/rs6000/rs6000.c:4301
 #, fuzzy
 #| msgid "-f%s and -msdata=%s are incompatible"
 msgid "-mvsx and -mpaired are incompatible"
 msgstr "-f%s dan -msdata=%s tidak kompatibel"
 
-#: config/powerpcspe/powerpcspe.c:4433 config/rs6000/rs6000.c:4283
+#: config/powerpcspe/powerpcspe.c:4433 config/rs6000/rs6000.c:4303
 #, fuzzy
 #| msgid "Disable indexed addressing"
 msgid "-mvsx needs indexed addressing"
 msgstr "Non-aktifkan pengalamatan terindeks"
 
-#: config/powerpcspe/powerpcspe.c:4438 config/rs6000/rs6000.c:4288
+#: config/powerpcspe/powerpcspe.c:4438 config/rs6000/rs6000.c:4308
 #, fuzzy
 #| msgid "-f%s and -msdata=%s are incompatible"
 msgid "-mvsx and -mno-altivec are incompatible"
 msgstr "-f%s dan -msdata=%s tidak kompatibel"
 
-#: config/powerpcspe/powerpcspe.c:4440 config/rs6000/rs6000.c:4290
+#: config/powerpcspe/powerpcspe.c:4440 config/rs6000/rs6000.c:4310
 msgid "-mno-altivec disables vsx"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4648 config/rs6000/rs6000.c:4416
+#: config/powerpcspe/powerpcspe.c:4648 config/rs6000/rs6000.c:4436
 #, fuzzy
 #| msgid "--resource requires -o"
 msgid "-mquad-memory requires 64-bit mode"
 msgstr "--resource membutuhkan -o"
 
-#: config/powerpcspe/powerpcspe.c:4651 config/rs6000/rs6000.c:4419
+#: config/powerpcspe/powerpcspe.c:4651 config/rs6000/rs6000.c:4439
 msgid "-mquad-memory-atomic requires 64-bit mode"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4663 config/rs6000/rs6000.c:4431
+#: config/powerpcspe/powerpcspe.c:4663 config/rs6000/rs6000.c:4451
 #, fuzzy
 #| msgid "Generate code in little endian mode"
 msgid "-mquad-memory is not available in little endian mode"
 msgstr "Hasilkan kode dalam mode little endian"
 
-#: config/powerpcspe/powerpcspe.c:4735 config/rs6000/rs6000.c:4512
+#: config/powerpcspe/powerpcspe.c:4735 config/rs6000/rs6000.c:4532
 #, fuzzy
 #| msgid "--resource requires -o"
 msgid "-mtoc-fusion requires 64-bit"
 msgstr "--resource membutuhkan -o"
 
-#: config/powerpcspe/powerpcspe.c:4742 config/rs6000/rs6000.c:4519
+#: config/powerpcspe/powerpcspe.c:4742 config/rs6000/rs6000.c:4539
 msgid "-mtoc-fusion requires medium/large code model"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10915
+#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10947
 #, fuzzy
 #| msgid "bad test"
 msgid "bad move"
 msgstr "tes buruk"
 
-#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21087
+#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21164
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21278
+#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21355
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%e value"
 msgstr "nilai %%H tidak valid"
 
-#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21299
+#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21376
 #, c-format
 msgid "invalid %%f value"
 msgstr "nilai %%f tidak valid"
 
-#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21308
+#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21385
 #, c-format
 msgid "invalid %%F value"
 msgstr "nilai %%F tidak valid"
 
-#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21317
+#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21394
 #, c-format
 msgid "invalid %%G value"
 msgstr "nilai %%G tidak valid"
 
-#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21352
+#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21429
 #, c-format
 msgid "invalid %%j code"
 msgstr "kode %%j tidak valid"
 
-#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21362
+#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21439
 #, c-format
 msgid "invalid %%J code"
 msgstr "kode %%J tidak valid"
 
-#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21372
+#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21449
 #, c-format
 msgid "invalid %%k value"
 msgstr "nilai %%k tidak valid"
 
-#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21387
+#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21464
 #: config/xtensa/xtensa.c:2415
 #, c-format
 msgid "invalid %%K value"
 msgstr "nilai %%K tidak valid"
 
-#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21434
+#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21511
 #, c-format
 msgid "invalid %%O value"
 msgstr "nilai %%O tidak valid"
 
-#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21481
+#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21558
 #, c-format
 msgid "invalid %%q value"
 msgstr "nilai %%q tidak valid"
 
-#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21534
+#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21611
 #, c-format
 msgid "invalid %%T value"
 msgstr "nilai %%T tidak valid"
 
-#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21546
+#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21623
 #, c-format
 msgid "invalid %%u value"
 msgstr "nilai %%u tidak valid"
 
-#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21560
+#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21637
 #: config/xtensa/xtensa.c:2384
 #, c-format
 msgid "invalid %%v value"
 msgstr "nilai %%v tidak valid"
 
-#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21627
+#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21704
 #: config/xtensa/xtensa.c:2436
 #, c-format
 msgid "invalid %%x value"
 msgstr "nilai %%x tidak valid"
 
-#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21747
+#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21824
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "nilai %%ytidak valid, coba menggunakan batasan 'Z'"
 
-#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22282
+#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22359
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22288
+#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22365
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22294
+#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22371
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36572
+#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36628
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "Argumen AltiVec dilewatkan ke fungsi yang tidak berprototipe"
 
-#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38739
+#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38795
 #, fuzzy
 #| msgid "Do not generate a single exit point for each function"
 msgid "Could not generate addis value for fusion"
 msgstr "Jangan hasilkan sebuah titik keluar tunggal untuk setiap fungsi"
 
-#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38809
+#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38865
 #, fuzzy
 #| msgid "unable to generate reloads for:"
 msgid "Unable to generate load/store offset for fusion"
 msgstr "tidak dapat menghasilkan reloads untuk:"
 
-#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38908
+#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38964
 msgid "Bad GPR fusion"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39126
+#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39182
 msgid "emit_fusion_p9_load, bad reg #1"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39172
+#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39228
 msgid "emit_fusion_p9_load, bad reg #2"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39175
+#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39231
 msgid "emit_fusion_p9_load not MEM"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39213
+#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39269
 msgid "emit_fusion_p9_store, bad reg #1"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39259
+#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39315
 msgid "emit_fusion_p9_store, bad reg #2"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39262
+#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39318
 msgid "emit_fusion_p9_store not MEM"
 msgstr ""
 
@@ -4712,14 +4712,14 @@
 #: c/gimple-parser.c:188 c/gimple-parser.c:197 c/gimple-parser.c:226
 #: c/gimple-parser.c:1375 c/gimple-parser.c:1404 c/gimple-parser.c:1484
 #: c/gimple-parser.c:1511 c/c-parser.c:3204 c/c-parser.c:9967
-#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27841
-#: cp/parser.c:28430
+#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27838
+#: cp/parser.c:28427
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "diduga %<,%>"
 
 #: c/c-parser.c:2431 c/c-parser.c:7573 c/c-parser.c:8015 c/c-parser.c:8058
-#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27839 cp/parser.c:28448
+#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27836 cp/parser.c:28445
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<,%>"
@@ -4735,7 +4735,7 @@
 #: c/gimple-parser.c:821 c/gimple-parser.c:837 c/gimple-parser.c:853
 #: c/gimple-parser.c:880 c/gimple-parser.c:915 c/gimple-parser.c:1038
 #: c/gimple-parser.c:1209 c/gimple-parser.c:1220 c/gimple-parser.c:1342
-#: c/gimple-parser.c:1441 cp/parser.c:28478
+#: c/gimple-parser.c:1441 cp/parser.c:28475
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<)%>"
@@ -4744,7 +4744,7 @@
 #: c/c-parser.c:3824 c/c-parser.c:4733 c/c-parser.c:4769 c/c-parser.c:6441
 #: c/c-parser.c:8125 c/c-parser.c:8983 c/c-parser.c:9127 c/c-parser.c:11588
 #: c/c-parser.c:18220 c/c-parser.c:18222 c/gimple-parser.c:1015
-#: cp/parser.c:28442
+#: cp/parser.c:28439
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<]%>"
@@ -4761,7 +4761,7 @@
 #: c/c-parser.c:17792 c/gimple-parser.c:363 c/gimple-parser.c:811
 #: c/gimple-parser.c:873 c/gimple-parser.c:911 c/gimple-parser.c:1198
 #: c/gimple-parser.c:1339 c/gimple-parser.c:1438 c/c-parser.c:11911
-#: cp/parser.c:28433
+#: cp/parser.c:28430
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "diduga %<(%>"
@@ -4768,7 +4768,7 @@
 
 #: c/c-parser.c:4903 c/c-parser.c:10310 c/c-parser.c:16212 c/c-parser.c:18449
 #: c/gimple-parser.c:141 c/gimple-parser.c:1444 c/c-parser.c:3018
-#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18155 cp/parser.c:28439
+#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18152 cp/parser.c:28436
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "diduga %<{%>"
@@ -4778,14 +4778,14 @@
 #: c/c-parser.c:12351 c/c-parser.c:12493 c/c-parser.c:12864 c/c-parser.c:12957
 #: c/c-parser.c:13566 c/c-parser.c:17636 c/c-parser.c:17695
 #: c/gimple-parser.c:431 c/gimple-parser.c:1492 c/gimple-parser.c:1519
-#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28472 cp/parser.c:29597
-#: cp/parser.c:32279
+#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28469 cp/parser.c:29594
+#: cp/parser.c:32276
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<:%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.c:5974 cp/parser.c:28365
+#: c/c-parser.c:5974 cp/parser.c:28362
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<while%>"
@@ -4797,20 +4797,20 @@
 msgid "expected %<.%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30172
-#: cp/parser.c:30246
+#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30169
+#: cp/parser.c:30243
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@end%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28457
+#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28454
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<>%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28481
+#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28478
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<,%> or %<)%>"
@@ -4819,36 +4819,36 @@
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15190 c/c-parser.c:15234 c/c-parser.c:15466 c/c-parser.c:15701
 #: c/c-parser.c:17833 c/gimple-parser.c:286 c/c-parser.c:4792
-#: cp/parser.c:28460
+#: cp/parser.c:28457
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "diduga %<=%>"
 
-#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28436
-#: cp/parser.c:30389
+#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28433
+#: cp/parser.c:30386
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<}%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35674
+#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35671
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "diduga %<#pragma omp section%> atau %<}%>"
 
-#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28445 cp/parser.c:31535
+#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28442 cp/parser.c:31532
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<[%>"
 msgstr "diduga %<{%>"
 
-#: c/c-typeck.c:7847
+#: c/c-typeck.c:7852
 #, fuzzy
 #| msgid "<anonymous>"
 msgid "(anonymous)"
 msgstr "<anonim>"
 
-#: c/gimple-parser.c:795 cp/parser.c:15791 cp/parser.c:28454
+#: c/gimple-parser.c:795 cp/parser.c:15788 cp/parser.c:28451
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<<%>"
@@ -5151,11 +5151,11 @@
 msgid "%r%s:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr ""
 
-#: cp/pt.c:1949 cp/semantics.c:5268
+#: cp/pt.c:1949 cp/semantics.c:5271
 msgid "candidates are:"
 msgstr "kandidat adalah:"
 
-#: cp/pt.c:1951 cp/pt.c:22975
+#: cp/pt.c:1951 cp/pt.c:23053
 #, fuzzy
 #| msgid "candidate 1:"
 msgid "candidate is:"
@@ -5219,27 +5219,27 @@
 msgid "source type is not polymorphic"
 msgstr ""
 
-#: cp/typeck.c:6083 c/c-typeck.c:4261
+#: cp/typeck.c:6083 c/c-typeck.c:4266
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "tipe argumen salah ke unary minus"
 
-#: cp/typeck.c:6084 c/c-typeck.c:4248
+#: cp/typeck.c:6084 c/c-typeck.c:4253
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "tipe argume salah ke unary plus"
 
-#: cp/typeck.c:6111 c/c-typeck.c:4302
+#: cp/typeck.c:6111 c/c-typeck.c:4307
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "tipe argumen salah ke bit-complement"
 
-#: cp/typeck.c:6128 c/c-typeck.c:4310
+#: cp/typeck.c:6128 c/c-typeck.c:4315
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "tipe argumen salah ke abs"
 
-#: cp/typeck.c:6140 c/c-typeck.c:4322
+#: cp/typeck.c:6140 c/c-typeck.c:4327
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "tipe argumen salah ke konjugasi"
@@ -5497,67 +5497,67 @@
 msgid "Expected attribute bit name"
 msgstr "Diduga nama atribut bit"
 
-#: fortran/module.c:3223
+#: fortran/module.c:3225
 msgid "Expected integer string"
 msgstr "Diduga integer string"
 
-#: fortran/module.c:3227
+#: fortran/module.c:3229
 msgid "Error converting integer"
 msgstr "Error mengubah integer"
 
-#: fortran/module.c:3249
+#: fortran/module.c:3251
 msgid "Expected real string"
 msgstr "Diduga real string"
 
-#: fortran/module.c:3474
+#: fortran/module.c:3476
 msgid "Expected expression type"
 msgstr "Diduga tipe ekspresi"
 
-#: fortran/module.c:3554
+#: fortran/module.c:3556
 msgid "Bad operator"
 msgstr "Operator buruk"
 
-#: fortran/module.c:3671
+#: fortran/module.c:3673
 msgid "Bad type in constant expression"
 msgstr "Tipe buruk dalam ekspresi konstanta"
 
-#: fortran/module.c:7038
+#: fortran/module.c:7040
 msgid "Unexpected end of module"
 msgstr "Tidak terduga akhir dari modul"
 
-#: fortran/parse.c:1757
+#: fortran/parse.c:1761
 msgid "arithmetic IF"
 msgstr "aritmetik IF"
 
-#: fortran/parse.c:1766
+#: fortran/parse.c:1770
 msgid "attribute declaration"
 msgstr "deklarasi atribut"
 
-#: fortran/parse.c:1802
+#: fortran/parse.c:1806
 msgid "data declaration"
 msgstr "deklarasi data"
 
-#: fortran/parse.c:1820
+#: fortran/parse.c:1824
 msgid "derived type declaration"
 msgstr "tipe deklarasi turunan"
 
-#: fortran/parse.c:1947
+#: fortran/parse.c:1951
 msgid "block IF"
 msgstr "blok IF"
 
-#: fortran/parse.c:1956
+#: fortran/parse.c:1960
 msgid "implied END DO"
 msgstr "Diimplikasikan END DO"
 
-#: fortran/parse.c:2050 fortran/resolve.c:11199
+#: fortran/parse.c:2054 fortran/resolve.c:11219
 msgid "assignment"
 msgstr "assignment"
 
-#: fortran/parse.c:2053 fortran/resolve.c:11250 fortran/resolve.c:11253
+#: fortran/parse.c:2057 fortran/resolve.c:11270 fortran/resolve.c:11273
 msgid "pointer assignment"
 msgstr "assignmen penunjuk"
 
-#: fortran/parse.c:2071
+#: fortran/parse.c:2075
 msgid "simple IF"
 msgstr "IF sederhana"
 
@@ -5680,125 +5680,130 @@
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr "Operan dari operator numerik unary '%s' di %%L adalah %s"
 
-#: fortran/resolve.c:3878
+#: fortran/resolve.c:3879
+#, c-format
+msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
+msgstr ""
+
+#: fortran/resolve.c:3884
 #, fuzzy, c-format
 #| msgid "Operands of binary numeric operator '%s' at %%L are %s/%s"
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr "Operan dari operan binari numerik '%s' di %%L adalah %s/%s"
 
-#: fortran/resolve.c:3893
+#: fortran/resolve.c:3899
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr "Operan dari string operator konkatenasi di %%L adalah %s/%s"
 
-#: fortran/resolve.c:3926
+#: fortran/resolve.c:3932
 #, fuzzy, c-format
 #| msgid "Operands of logical operator '%s' at %%L are %s/%s"
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr "Operan dari operator logikal '%s' di %%L adalah %s/%s"
 
-#: fortran/resolve.c:3949
+#: fortran/resolve.c:3955
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr "Operan dari operator .not. di %%L adalah %s"
 
-#: fortran/resolve.c:3963
+#: fortran/resolve.c:3969
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "kuantitas KOMPLEKS tidak dapat dibandingkan di %L"
 
-#: fortran/resolve.c:4015
+#: fortran/resolve.c:4021
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr "Logikal di %%L harus dibandingkan dengan %s daripada %s"
 
-#: fortran/resolve.c:4021
+#: fortran/resolve.c:4027
 #, fuzzy, c-format
 #| msgid "Operands of comparison operator '%s' at %%L are %s/%s"
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr "Operan dari operator perbandingan '%s' di %%L adalah %s/%s"
 
-#: fortran/resolve.c:4034
+#: fortran/resolve.c:4040
 #, fuzzy, c-format
 #| msgid "Unknown operator '%s' at %%L"
 msgid "Unknown operator %%<%s%%> at %%L; did you mean '%s'?"
 msgstr "Operator tidak dikenal '%s' di %%L"
 
-#: fortran/resolve.c:4037
+#: fortran/resolve.c:4043
 #, fuzzy, c-format
 #| msgid "Unknown operator '%s' at %%L"
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr "Operator tidak dikenal '%s' di %%L"
 
-#: fortran/resolve.c:4040
+#: fortran/resolve.c:4046
 #, fuzzy, c-format
 #| msgid "Operand of user operator '%s' at %%L is %s"
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr "Operan dari operator pengguna '%s' di %%L adalah %s"
 
-#: fortran/resolve.c:4044
+#: fortran/resolve.c:4050
 #, fuzzy, c-format
 #| msgid "Operands of user operator '%s' at %%L are %s/%s"
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr "Operan dari operator pengguna '%s' di %%L adalah %s/%s"
 
-#: fortran/resolve.c:4132
+#: fortran/resolve.c:4138
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "Tingkat tidak konsisten untuk operator di %%L dan %%L"
 
-#: fortran/resolve.c:6849
+#: fortran/resolve.c:6855
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.c:6853
+#: fortran/resolve.c:6859
 #, fuzzy
 #| msgid "%qD is not a variable"
 msgid "iterator variable"
 msgstr "%qD bukan sebuah variabel"
 
-#: fortran/resolve.c:6857
+#: fortran/resolve.c:6863
 #, fuzzy
 #| msgid "Step expression in DO loop at %L cannot be zero"
 msgid "Start expression in DO loop"
 msgstr "Ekspresi step dalam loop DO di %L tidak dapat berupa nol"
 
-#: fortran/resolve.c:6861
+#: fortran/resolve.c:6867
 #, fuzzy
 #| msgid "invalid expression as operand"
 msgid "End expression in DO loop"
 msgstr "ekspresi sebagai operan tidak valid"
 
-#: fortran/resolve.c:6865
+#: fortran/resolve.c:6871
 #, fuzzy
 #| msgid "Step expression in DO loop at %L cannot be zero"
 msgid "Step expression in DO loop"
 msgstr "Ekspresi step dalam loop DO di %L tidak dapat berupa nol"
 
-#: fortran/resolve.c:7150 fortran/resolve.c:7153
+#: fortran/resolve.c:7156 fortran/resolve.c:7159
 #, fuzzy
 #| msgid "DEALLOCATE "
 msgid "DEALLOCATE object"
 msgstr "DEALOKASIKAN "
 
-#: fortran/resolve.c:7525 fortran/resolve.c:7528
+#: fortran/resolve.c:7531 fortran/resolve.c:7534
 #, fuzzy
 #| msgid "ALLOCATE "
 msgid "ALLOCATE object"
 msgstr "ALOKASIKAN "
 
-#: fortran/resolve.c:7720 fortran/resolve.c:9417
+#: fortran/resolve.c:7726 fortran/resolve.c:9428
 msgid "STAT variable"
 msgstr ""
 
-#: fortran/resolve.c:7764 fortran/resolve.c:9429
+#: fortran/resolve.c:7770 fortran/resolve.c:9440
 msgid "ERRMSG variable"
 msgstr ""
 
-#: fortran/resolve.c:9219
+#: fortran/resolve.c:9230
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.c:9441
+#: fortran/resolve.c:9452
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
@@ -5834,7 +5839,7 @@
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:10154
+#: fortran/trans-expr.c:10157
 msgid "Assignment of scalar to unallocated array"
 msgstr ""
 
@@ -5844,13 +5849,13 @@
 msgid "Unequal character lengths (%ld/%ld) in %s"
 msgstr "Panjang karakter tidak sama (%ld/%ld) dalam %s di %L"
 
-#: fortran/trans-intrinsic.c:8088
+#: fortran/trans-intrinsic.c:8090
 #, fuzzy, c-format
 #| msgid "Argument NCOPIES of REPEAT intrinsic is negative at %L"
 msgid "Argument NCOPIES of REPEAT intrinsic is negative (its value is %ld)"
 msgstr "Argumen NCOPIES dari REPEAT intrinsik adalah negatif di %L"
 
-#: fortran/trans-intrinsic.c:8120
+#: fortran/trans-intrinsic.c:8122
 #, fuzzy
 #| msgid "Argument NCOPIES of REPEAT intrinsic is too large at %L"
 msgid "Argument NCOPIES of REPEAT intrinsic is too large"
@@ -5877,15 +5882,15 @@
 msgid "Invalid image number %d in SYNC IMAGES"
 msgstr ""
 
-#: fortran/trans-stmt.c:2180
+#: fortran/trans-stmt.c:2177
 msgid "Loop iterates infinitely"
 msgstr ""
 
-#: fortran/trans-stmt.c:2200 fortran/trans-stmt.c:2456
+#: fortran/trans-stmt.c:2197 fortran/trans-stmt.c:2453
 msgid "Loop variable has been modified"
 msgstr ""
 
-#: fortran/trans-stmt.c:2309
+#: fortran/trans-stmt.c:2306
 msgid "DO step value is zero"
 msgstr ""
 
@@ -6604,10 +6609,10 @@
 msgid "Allow dollar signs in entity names."
 msgstr "Ijinkan tanda dollar dalam nama entity"
 
-#: fortran/lang.opt:485 config/alpha/alpha.opt:31 common.opt:783
-#: common.opt:985 common.opt:989 common.opt:993 common.opt:997 common.opt:1532
-#: common.opt:1588 common.opt:1712 common.opt:1716 common.opt:1946
-#: common.opt:2116 common.opt:2792
+#: fortran/lang.opt:485 config/alpha/alpha.opt:31 common.opt:649
+#: common.opt:783 common.opt:989 common.opt:993 common.opt:997 common.opt:1001
+#: common.opt:1536 common.opt:1592 common.opt:1716 common.opt:1720
+#: common.opt:1950 common.opt:2120 common.opt:2796
 #, fuzzy
 #| msgid "Does nothing.  Preserved for backward compatibility."
 msgid "Does nothing. Preserved for backward compatibility."
@@ -6900,12 +6905,12 @@
 msgstr "Tambahkan garis bawah ke nama eksternal yang tampak"
 
 #: fortran/lang.opt:751 c-family/c.opt:1356 c-family/c.opt:1384
-#: c-family/c.opt:1634 config/pa/pa.opt:42 config/pa/pa.opt:70 common.opt:1154
-#: common.opt:1333 common.opt:1408 common.opt:1676 common.opt:1799
-#: common.opt:2169 common.opt:2205 common.opt:2298 common.opt:2302
-#: common.opt:2407 common.opt:2498 common.opt:2506 common.opt:2514
-#: common.opt:2522 common.opt:2623 common.opt:2675 common.opt:2755
-#: common.opt:2893 common.opt:2897 common.opt:2901 common.opt:2905
+#: c-family/c.opt:1634 config/pa/pa.opt:42 config/pa/pa.opt:70 common.opt:1158
+#: common.opt:1337 common.opt:1412 common.opt:1680 common.opt:1803
+#: common.opt:2173 common.opt:2209 common.opt:2302 common.opt:2306
+#: common.opt:2411 common.opt:2502 common.opt:2510 common.opt:2518
+#: common.opt:2526 common.opt:2627 common.opt:2679 common.opt:2759
+#: common.opt:2897 common.opt:2901 common.opt:2905 common.opt:2909
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr "Tidak melakukan apa-apa. Dijaga untuk kompabilitas versi sebelumnya."
 
@@ -6971,7 +6976,7 @@
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:220 c-family/c.opt:224
 #: c-family/c.opt:236 c-family/c.opt:1855 c-family/c.opt:1863 brig/lang.opt:39
-#: config/darwin.opt:56 common.opt:338 common.opt:341 common.opt:3046
+#: config/darwin.opt:56 common.opt:338 common.opt:341 common.opt:3050
 #, c-format
 msgid "missing filename after %qs"
 msgstr "hilang nama berkas setelah %qs"
@@ -7745,7 +7750,7 @@
 #: c-family/c.opt:1525 c-family/c.opt:1528 c-family/c.opt:1569
 #: c-family/c.opt:1704 c-family/c.opt:1731 c-family/c.opt:1771
 #: c-family/c.opt:1802 c-family/c.opt:1806 c-family/c.opt:1822
-#: config/ia64/ia64.opt:167 config/ia64/ia64.opt:170 c-family/c-opts.c:434
+#: config/ia64/ia64.opt:167 config/ia64/ia64.opt:170 c-family/c-opts.c:432
 #, gcc-internal-format
 msgid "switch %qs is no longer supported"
 msgstr "pilihan %qs tidak lagi didukung"
@@ -17191,10 +17196,6 @@
 msgid "Warn if dereferencing a NULL pointer may lead to erroneous or undefined behavior."
 msgstr ""
 
-#: common.opt:649
-msgid "Warn if the loop cannot be optimized due to nontrivial assumptions."
-msgstr "Peringatkan jika loop tidak dapat dioptimasi karena asumsi tidak trivial."
-
 #: common.opt:656
 msgid "Warn about some C++ One Definition Rule violations during link time optimization."
 msgstr ""
@@ -17435,2241 +17436,2241 @@
 msgid "-dumpdir <dir>\tSet the directory name to be used for dumps."
 msgstr "Set berkas nama dasar yang akan digunakan untuk dumps"
 
-#: common.opt:946
+#: common.opt:950
 msgid "The version of the C++ ABI in use."
 msgstr ""
 
-#: common.opt:950
+#: common.opt:954
 msgid "Aggressively optimize loops using language constraints."
 msgstr ""
 
-#: common.opt:954
+#: common.opt:958
 #, fuzzy
 #| msgid "Align the start of functions"
 msgid "Align the start of functions."
 msgstr "Align awal dari fungsi"
 
-#: common.opt:964
+#: common.opt:968
 #, fuzzy
 #| msgid "Align labels which are only reached by jumping"
 msgid "Align labels which are only reached by jumping."
 msgstr "Align labels yang hanya dicapai dengan melompat"
 
-#: common.opt:971
+#: common.opt:975
 #, fuzzy
 #| msgid "Align all labels"
 msgid "Align all labels."
 msgstr "Align seluruh labels"
 
-#: common.opt:978
+#: common.opt:982
 #, fuzzy
 #| msgid "Align the start of loops"
 msgid "Align the start of loops."
 msgstr "Align awal dari loops"
 
-#: common.opt:1001
+#: common.opt:1005
 msgid "Select what to sanitize."
 msgstr ""
 
-#: common.opt:1005
+#: common.opt:1009
 msgid "Select type of coverage sanitization."
 msgstr ""
 
-#: common.opt:1009
+#: common.opt:1013
 msgid "-fasan-shadow-offset=<number>\tUse custom shadow memory offset."
 msgstr ""
 
-#: common.opt:1013
+#: common.opt:1017
 msgid "-fsanitize-sections=<sec1,sec2,...>\tSanitize global variables in user-defined sections."
 msgstr ""
 
-#: common.opt:1018
+#: common.opt:1022
 msgid "After diagnosing undefined behavior attempt to continue execution."
 msgstr ""
 
-#: common.opt:1022
+#: common.opt:1026
 #, fuzzy
 #| msgid "This switch is deprecated; use -Wextra instead"
 msgid "This switch is deprecated; use -fsanitize-recover= instead."
 msgstr "Pilihan ini sudah ditinggalkan; lebih baik gunakan -Wextra"
 
-#: common.opt:1029
+#: common.opt:1033
 msgid "Use trap instead of a library function for undefined behavior sanitization."
 msgstr ""
 
-#: common.opt:1033
+#: common.opt:1037
 #, fuzzy
 #| msgid "Generate unwind tables that are exact at each instruction boundary"
 msgid "Generate unwind tables that are exact at each instruction boundary."
 msgstr "Hasilkan tabel unwind yang tepat di setiap batasan instruksi"
 
-#: common.opt:1037
+#: common.opt:1041
 #, fuzzy
 #| msgid "Generate auto-inc/dec instructions"
 msgid "Generate auto-inc/dec instructions."
 msgstr "Hasilkan instruksi auto-inc/dec"
 
-#: common.opt:1041
+#: common.opt:1045
 msgid "Use sample profile information for call graph node weights. The default profile file is fbdata.afdo in 'pwd'."
 msgstr ""
 
-#: common.opt:1046
+#: common.opt:1050
 msgid "Use sample profile information for call graph node weights. The profile file is specified in the argument."
 msgstr ""
 
-#: common.opt:1055
+#: common.opt:1059
 #, fuzzy
 #| msgid "Generate code to check bounds before indexing arrays"
 msgid "Generate code to check bounds before indexing arrays."
 msgstr "Hasilkan kode untuk memeriksa batasan sebelum array pengindeksan"
 
-#: common.opt:1059
+#: common.opt:1063
 #, fuzzy
 #| msgid "Replace add, compare, branch with branch on count register"
 msgid "Replace add, compare, branch with branch on count register."
 msgstr "Gantikan tambah, banding, cabang dengan cabang di jumlah register"
 
-#: common.opt:1063
+#: common.opt:1067
 #, fuzzy
 #| msgid "Use profiling information for branch probabilities"
 msgid "Use profiling information for branch probabilities."
 msgstr "Gunakan informasi profiling untuk setiap kemungkinan percabangan"
 
-#: common.opt:1067
+#: common.opt:1071
 #, fuzzy
 #| msgid "Perform branch target load optimization before prologue / epilogue threading"
 msgid "Perform branch target load optimization before prologue / epilogue threading."
 msgstr "Lakukan target percabangan load optimisasi sebelum prologue / epilog threading"
 
-#: common.opt:1071
+#: common.opt:1075
 #, fuzzy
 #| msgid "Perform branch target load optimization after prologue / epilogue threading"
 msgid "Perform branch target load optimization after prologue / epilogue threading."
 msgstr "Lakukan target percabangan optimisasi setelah prolog / epilog threading"
 
-#: common.opt:1075
+#: common.opt:1079
 #, fuzzy
 #| msgid "Restrict target load migration not to re-use registers in any basic block"
 msgid "Restrict target load migration not to re-use registers in any basic block."
 msgstr "Batasi target load migrasi bukan untuk re-use register dalam blok dasar apapun"
 
-#: common.opt:1079
+#: common.opt:1083
 #, fuzzy
 #| msgid "Mark <register> as being preserved across functions"
 msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions."
 msgstr "Tandai <register> sebagai telah disimpan dalam fungsi"
 
-#: common.opt:1083
+#: common.opt:1087
 #, fuzzy
 #| msgid "Mark <register> as being corrupted by function calls"
 msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls."
 msgstr "Tandai <register> sebagai telah terkorupsi oleh pemanggilan fungsi"
 
-#: common.opt:1090
+#: common.opt:1094
 #, fuzzy
 #| msgid "Save registers around function calls"
 msgid "Save registers around function calls."
 msgstr "Simpan register dalam pemanggilan fungsi"
 
-#: common.opt:1094
+#: common.opt:1098
 #, fuzzy
 #| msgid "This switch is deprecated; use -Wextra instead"
 msgid "This switch is deprecated; do not use."
 msgstr "Pilihan ini sudah ditinggalkan; lebih baik gunakan -Wextra"
 
-#: common.opt:1098
+#: common.opt:1102
 #, fuzzy
 #| msgid "Check the return value of new"
 msgid "Check the return value of new in C++."
 msgstr "Periksa nilai kembali dari new"
 
-#: common.opt:1102 common.opt:1106
+#: common.opt:1106 common.opt:1110
 #, fuzzy
 #| msgid "internal consistency failure"
 msgid "Perform internal consistency checkings."
 msgstr "kegagalan konsistensi internal"
 
-#: common.opt:1110
+#: common.opt:1114
 #, fuzzy
 #| msgid "Enable function profiling"
 msgid "Enable code hoisting."
 msgstr "Aktifkan profiling fungsi"
 
-#: common.opt:1114
+#: common.opt:1118
 msgid "Looks for opportunities to reduce stack adjustments and stack references."
 msgstr ""
 
-#: common.opt:1118
+#: common.opt:1122
 #, fuzzy
 #| msgid "Do not put uninitialized globals in the common section"
 msgid "Do not put uninitialized globals in the common section."
 msgstr "Jangan letakan tidak terinisialisasi global dalam daerah umum"
 
-#: common.opt:1126
+#: common.opt:1130
 msgid "-fcompare-debug[=<opts>]\tCompile with and without e.g. -gtoggle, and compare the final-insns dump."
 msgstr ""
 
-#: common.opt:1130
+#: common.opt:1134
 msgid "Run only the second compilation of -fcompare-debug."
 msgstr ""
 
-#: common.opt:1134
+#: common.opt:1138
 #, fuzzy
 #| msgid "Perform global common subexpression elimination after register allocation"
 msgid "Perform comparison elimination after register allocation has finished."
 msgstr "Lakukan penghapusan global common subexpression setelah alokasi register"
 
-#: common.opt:1138
+#: common.opt:1142
 #, fuzzy
 #| msgid "Do not perform optimizations increasing noticeably stack usage"
 msgid "Do not perform optimizations increasing noticeably stack usage."
 msgstr "Jangan lakukan optimisasi semakin meningkat dapat dinotifikasi penggunaan stack"
 
-#: common.opt:1142
+#: common.opt:1146
 #, fuzzy
 #| msgid "Perform a register copy-propagation optimization pass"
 msgid "Perform a register copy-propagation optimization pass."
 msgstr "Lakukan sebuah register tahap optimisasi copy-propagation"
 
-#: common.opt:1146
+#: common.opt:1150
 #, fuzzy
 #| msgid "Perform cross-jumping optimization"
 msgid "Perform cross-jumping optimization."
 msgstr "Lakukan optimisasi cross-jumping"
 
-#: common.opt:1150
+#: common.opt:1154
 #, fuzzy
 #| msgid "When running CSE, follow jumps to their targets"
 msgid "When running CSE, follow jumps to their targets."
 msgstr "Ketika menjalankan CSE, ikuti jump ke targetnya"
 
-#: common.opt:1158
+#: common.opt:1162
 #, fuzzy
 #| msgid "Omit range reduction step when performing complex division"
 msgid "Omit range reduction step when performing complex division."
 msgstr "Abaikan tahap reduksi jangkauan ketika menjalankan pembagian kompleks"
 
-#: common.opt:1162
+#: common.opt:1166
 #, fuzzy
 #| msgid "Complex multiplication and division follow Fortran rules"
 msgid "Complex multiplication and division follow Fortran rules."
 msgstr "Perkalian dan pembagian kompleks mengikuti aturan Fortran"
 
-#: common.opt:1166
+#: common.opt:1170
 #, fuzzy
 #| msgid "Place data items into their own section"
 msgid "Place data items into their own section."
 msgstr "Tempatkan data item kedalam daerah mereka"
 
-#: common.opt:1170
+#: common.opt:1174
 msgid "List all available debugging counters with their limits and counts."
 msgstr "Daftar seluruh debugging counter yang tersedia dengan batasan dan jumlah mereka"
 
-#: common.opt:1174
+#: common.opt:1178
 #, fuzzy
 #| msgid "-fdbg-cnt=<counter>:<limit>[,<counter>:<limit>,...]    Set the debug counter limit.   "
 msgid "-fdbg-cnt=<counter>:<limit>[,<counter>:<limit>,...]\tSet the debug counter limit."
 msgstr "-fdbg-cnt=<counter>:<limit>[,<counter>:<limit>,...]    Set the debug counter batas.   "
 
-#: common.opt:1178
+#: common.opt:1182
 #, fuzzy
 #| msgid "Map one directory name to another in debug information"
 msgid "-fdebug-prefix-map=<old>=<new> Map one directory name to another in debug information."
 msgstr "Petakan satu nama direktori ke yang lainnya dalam informasi debug"
 
-#: common.opt:1182
+#: common.opt:1186
 #, fuzzy
 #| msgid "Map one directory name to another in debug information"
 msgid "-ffile-prefix-map=<old>=<new> Map one directory name to another in compilation result."
 msgstr "Petakan satu nama direktori ke yang lainnya dalam informasi debug"
 
-#: common.opt:1186
+#: common.opt:1190
 msgid "Output .debug_types section when using DWARF v4 debuginfo."
 msgstr ""
 
-#: common.opt:1192
+#: common.opt:1196
 #, fuzzy
 #| msgid "Defer popping functions args from stack until later"
 msgid "Defer popping functions args from stack until later."
 msgstr "Defer popping fungsi args dari stack sampai kemudian"
 
-#: common.opt:1196
+#: common.opt:1200
 #, fuzzy
 #| msgid "Attempt to fill delay slots of branch instructions"
 msgid "Attempt to fill delay slots of branch instructions."
 msgstr "Coba untuk mengisi delay slot dalam instruksi percabangan"
 
-#: common.opt:1200
+#: common.opt:1204
 msgid "Delete dead instructions that may throw exceptions."
 msgstr ""
 
-#: common.opt:1204
+#: common.opt:1208
 #, fuzzy
 #| msgid "Delete useless null pointer checks"
 msgid "Delete useless null pointer checks."
 msgstr "Hapus ketidak bergunaan pemeriksaan penunjuk kosong"
 
-#: common.opt:1208
+#: common.opt:1212
 msgid "Stream extra data to support more aggressive devirtualization in LTO local transformation mode."
 msgstr ""
 
-#: common.opt:1212
+#: common.opt:1216
 #, fuzzy
 #| msgid "Perform superblock formation via tail duplication"
 msgid "Perform speculative devirtualization."
 msgstr "Lakukan formasi superblok melalaui duplikasi tail"
 
-#: common.opt:1216
+#: common.opt:1220
 msgid "Try to convert virtual calls to direct ones."
 msgstr ""
 
-#: common.opt:1220
+#: common.opt:1224
 #, fuzzy
 #| msgid "How often to emit source location at the beginning of line-wrapped diagnostics"
 msgid "-fdiagnostics-show-location=[once|every-line]\tHow often to emit source location at the beginning of line-wrapped diagnostics."
 msgstr "Seberapa sering mengeluarkan sumber lokasi di awal dari baris-wrapped diagnosa"
 
-#: common.opt:1237
+#: common.opt:1241
 msgid "Show the source line with a caret indicating the column."
 msgstr ""
 
-#: common.opt:1245
+#: common.opt:1249
 msgid "-fdiagnostics-color=[never|always|auto]\tColorize diagnostics."
 msgstr ""
 
-#: common.opt:1265
+#: common.opt:1269
 msgid "Print fix-it hints in machine-readable form."
 msgstr ""
 
-#: common.opt:1269
+#: common.opt:1273
 msgid "Print fix-it hints to stderr in unified diff format."
 msgstr ""
 
-#: common.opt:1273
+#: common.opt:1277
 #, fuzzy
 #| msgid "Amend appropriate diagnostic messages with the command line option that controls them"
 msgid "Amend appropriate diagnostic messages with the command line option that controls them."
 msgstr "Tambahkan pesan diagnosa yang sesuai dengan pilihan baris perintah yang mengontrolnya"
 
-#: common.opt:1277
+#: common.opt:1281
 msgid "-fdisable-[tree|rtl|ipa]-<pass>=range1+range2 disables an optimization pass."
 msgstr ""
 
-#: common.opt:1281
+#: common.opt:1285
 msgid "-fenable-[tree|rtl|ipa]-<pass>=range1+range2 enables an optimization pass."
 msgstr ""
 
-#: common.opt:1285
+#: common.opt:1289
 #, fuzzy
 #| msgid "Dump various compiler internals to a file"
 msgid "-fdump-<type>\tDump various compiler internals to a file."
 msgstr "Dump beberapa kompiler internal ke sebuah berkas"
 
-#: common.opt:1292
+#: common.opt:1296
 msgid "-fdump-final-insns=filename\tDump to filename the insns at the end of translation."
 msgstr ""
 
-#: common.opt:1296
+#: common.opt:1300
 msgid "-fdump-go-spec=filename\tWrite all declarations to file as Go code."
 msgstr ""
 
-#: common.opt:1300
+#: common.opt:1304
 #, fuzzy
 #| msgid "Suppress output of addresses in debugging dumps"
 msgid "Suppress output of addresses in debugging dumps."
 msgstr "Tekan keluaran dari alamat dalam dump debugging"
 
-#: common.opt:1304
+#: common.opt:1308
 msgid "Collect and dump debug information into temporary file if ICE in C/C++ compiler occurred."
 msgstr ""
 
-#: common.opt:1309
+#: common.opt:1313
 msgid "Dump detailed information on GCC's internal representation of source code locations."
 msgstr ""
 
-#: common.opt:1313
+#: common.opt:1317
 #, fuzzy
 #| msgid "Do the full register move optimization pass"
 msgid "Dump optimization passes."
 msgstr "Lakukan tahap optimisasi register penuh"
 
-#: common.opt:1317
+#: common.opt:1321
 #, fuzzy
 #| msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps"
 msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps."
 msgstr "Tekan keluaran dari jumlah instruksi, catatan nomor baris dan alamat dalam debugging dumps"
 
-#: common.opt:1321
+#: common.opt:1325
 #, fuzzy
 #| msgid "Suppress output of addresses in debugging dumps"
 msgid "Suppress output of previous and next insn numbers in debugging dumps."
 msgstr "Tekan keluaran dari alamat dalam dump debugging"
 
-#: common.opt:1325
+#: common.opt:1329
 msgid "Enable CFI tables via GAS assembler directives."
 msgstr "Aktfikan tabel CFI melalui direktif perakit GAS."
 
-#: common.opt:1329
+#: common.opt:1333
 #, fuzzy
 #| msgid "Perform early inlining"
 msgid "Perform early inlining."
 msgstr "Lakukan inlining awal"
 
-#: common.opt:1337
+#: common.opt:1341
 #, fuzzy
 #| msgid "Perform Interprocedural constant propagation"
 msgid "Perform interprocedural reduction of aggregates."
 msgstr "Lakukan propagasi konstanta interprosedural"
 
-#: common.opt:1341
+#: common.opt:1345
 #, fuzzy
 #| msgid "Perform unused type elimination in debug info"
 msgid "Perform unused symbol elimination in debug info."
 msgstr "Lakukan penghapusan tidak tidak digunakan dalam informasi debug"
 
-#: common.opt:1345
+#: common.opt:1349
 #, fuzzy
 #| msgid "Perform unused type elimination in debug info"
 msgid "Perform unused type elimination in debug info."
 msgstr "Lakukan penghapusan tidak tidak digunakan dalam informasi debug"
 
-#: common.opt:1349
+#: common.opt:1353
 msgid "Do not suppress C++ class debug information."
 msgstr "Jangan tekan informasi debug C++ class."
 
-#: common.opt:1353
+#: common.opt:1357
 #, fuzzy
 #| msgid "Enable exception handling"
 msgid "Enable exception handling."
 msgstr "Aktifkan penanganan eksepsi"
 
-#: common.opt:1357
+#: common.opt:1361
 #, fuzzy
 #| msgid "Perform a number of minor, expensive optimizations"
 msgid "Perform a number of minor, expensive optimizations."
 msgstr "Lakukan beberapa dari minor, ekspensi optimisasi"
 
-#: common.opt:1361
+#: common.opt:1365
 msgid "-fexcess-precision=[fast|standard]\tSpecify handling of excess floating-point precision."
 msgstr ""
 
-#: common.opt:1364
+#: common.opt:1368
 #, fuzzy, c-format
 #| msgid "unknown demangling style '%s'"
 msgid "unknown excess precision style %qs"
 msgstr "gaya demangling '%s' tidak diketahui"
 
-#: common.opt:1376
+#: common.opt:1380
 msgid "-fpermitted-flt-eval-methods=[c11|ts-18661]\tSpecify which values of FLT_EVAL_METHOD are permitted."
 msgstr ""
 
-#: common.opt:1379
+#: common.opt:1383
 #, c-format
 msgid "unknown specification for the set of FLT_EVAL_METHOD values to permit %qs"
 msgstr ""
 
-#: common.opt:1392
+#: common.opt:1396
 msgid "Output lto objects containing both the intermediate language and binary output."
 msgstr ""
 
-#: common.opt:1396
+#: common.opt:1400
 #, fuzzy
 #| msgid "Assume no NaNs or infinities are generated"
 msgid "Assume no NaNs or infinities are generated."
 msgstr "Asumsikan tidak ada NaN atau tidak terhingga dihasilkan"
 
-#: common.opt:1400
+#: common.opt:1404
 #, fuzzy
 #| msgid "Mark <register> as being unavailable to the compiler"
 msgid "-ffixed-<register>\tMark <register> as being unavailable to the compiler."
 msgstr "Tandai <register> sebagai tidak tersedia ke kompiler"
 
-#: common.opt:1404
+#: common.opt:1408
 #, fuzzy
 #| msgid "Don't allocate floats and doubles in extended-precision registers"
 msgid "Don't allocate floats and doubles in extended-precision registers."
 msgstr "Jangan alokasikan float dan double dalam register presisi ekstended"
 
-#: common.opt:1412
+#: common.opt:1416
 #, fuzzy
 #| msgid "Perform a forward propagation pass on RTL"
 msgid "Perform a forward propagation pass on RTL."
 msgstr "Lakukan sebuah tahap propagasi ke depan dalam RTL"
 
-#: common.opt:1416
+#: common.opt:1420
 msgid "-ffp-contract=[off|on|fast]\tPerform floating-point expression contraction."
 msgstr ""
 
-#: common.opt:1419
+#: common.opt:1423
 #, fuzzy, c-format
 #| msgid "Place floating point constants in TOC"
 msgid "unknown floating point contraction style %qs"
 msgstr "Tempatkan konstanta titik pecahan dalam TOC"
 
-#: common.opt:1433
+#: common.opt:1437
 msgid "Allow built-in functions ceil, floor, round, trunc to raise \"inexact\" exceptions."
 msgstr ""
 
-#: common.opt:1440
+#: common.opt:1444
 #, fuzzy
 #| msgid "Allow function addresses to be held in registers"
 msgid "Allow function addresses to be held in registers."
 msgstr "Ijinkan alamat fungsi untuk disimpan dalam register"
 
-#: common.opt:1444
+#: common.opt:1448
 #, fuzzy
 #| msgid "Place each function into its own section"
 msgid "Place each function into its own section."
 msgstr "Tempatkan setiap fungsi kedalam daerahnya masing-masing"
 
-#: common.opt:1448
+#: common.opt:1452
 #, fuzzy
 #| msgid "Perform global common subexpression elimination"
 msgid "Perform global common subexpression elimination."
 msgstr "Lakukan penghapusan global comman subexpression"
 
-#: common.opt:1452
+#: common.opt:1456
 #, fuzzy
 #| msgid "Perform enhanced load motion during global common subexpression elimination"
 msgid "Perform enhanced load motion during global common subexpression elimination."
 msgstr "Lakukan penghapusan enhanced load motion selama global common subexpression"
 
-#: common.opt:1456
+#: common.opt:1460
 #, fuzzy
 #| msgid "Perform store motion after global common subexpression elimination"
 msgid "Perform store motion after global common subexpression elimination."
 msgstr "Lakukan store motion setelah penghapusan global common subexpression"
 
-#: common.opt:1460
+#: common.opt:1464
 #, fuzzy
 #| msgid "Perform redundant load after store elimination in global common subexpression"
 msgid "Perform redundant load after store elimination in global common subexpression elimination."
 msgstr "Lakukan redundansi load setelah penghapusan store dalam global common subexpressionn"
 
-#: common.opt:1465
+#: common.opt:1469
 #, fuzzy
 #| msgid "Perform global common subexpression elimination after register allocation"
 msgid "Perform global common subexpression elimination after register allocation has finished."
 msgstr "Lakukan penghapusan global common subexpression setelah alokasi register"
 
-#: common.opt:1482
+#: common.opt:1486
 msgid "-fgnat-encodings=[all|gdb|minimal]\tSelect the balance between GNAT encodings and standard DWARF emitted in the debug information"
 msgstr ""
 
-#: common.opt:1487
+#: common.opt:1491
 #, fuzzy
 #| msgid "Enable in and out of Graphite representation"
 msgid "Enable in and out of Graphite representation."
 msgstr "Aktifkan in dan keluar dari representasi Graphite"
 
-#: common.opt:1491
+#: common.opt:1495
 #, fuzzy
 #| msgid "Enable Graphite Identity transformation"
 msgid "Enable Graphite Identity transformation."
 msgstr "Aktifkan transformasi Graphite Identify"
 
-#: common.opt:1495
+#: common.opt:1499
 msgid "Enable hoisting adjacent loads to encourage generating conditional move instructions."
 msgstr ""
 
-#: common.opt:1504
+#: common.opt:1508
 msgid "Mark all loops as parallel."
 msgstr ""
 
-#: common.opt:1508 common.opt:1516 common.opt:2587
+#: common.opt:1512 common.opt:1520 common.opt:2591
 msgid "Enable loop nest transforms.  Same as -floop-nest-optimize."
 msgstr ""
 
-#: common.opt:1512
+#: common.opt:1516
 #, fuzzy
 #| msgid "Enable loop header copying on trees"
 msgid "Enable loop interchange on trees."
 msgstr "Aktifkan penyalinan loop header pada pohon"
 
-#: common.opt:1520
+#: common.opt:1524
 #, fuzzy
 #| msgid "Perform loop unrolling for all loops"
 msgid "Perform unroll-and-jam on loops."
 msgstr "Lakukan penguraian loop untuk semua loops"
 
-#: common.opt:1524
+#: common.opt:1528
 msgid "Enable support for GNU transactional memory."
 msgstr ""
 
-#: common.opt:1528
+#: common.opt:1532
 msgid "Use STB_GNU_UNIQUE if supported by the assembler."
 msgstr ""
 
-#: common.opt:1536
+#: common.opt:1540
 #, fuzzy
 #| msgid "Enable label alignment optimizations"
 msgid "Enable the loop nest optimizer."
 msgstr "Aktifkan optimisasi label alignmen"
 
-#: common.opt:1540
+#: common.opt:1544
 msgid "Force bitfield accesses to match their type width."
 msgstr ""
 
-#: common.opt:1544
+#: common.opt:1548
 msgid "Merge adjacent stores."
 msgstr ""
 
-#: common.opt:1548
+#: common.opt:1552
 #, fuzzy
 #| msgid "Enable guessing of branch probabilities"
 msgid "Enable guessing of branch probabilities."
 msgstr "Aktifkan penerkaan kemungkinan dari percabangan"
 
-#: common.opt:1556
+#: common.opt:1560
 #, fuzzy
 #| msgid "Process #ident directives"
 msgid "Process #ident directives."
 msgstr "Proses #ident direktif"
 
-#: common.opt:1560
+#: common.opt:1564
 #, fuzzy
 #| msgid "Perform conversion of conditional jumps to branchless equivalents"
 msgid "Perform conversion of conditional jumps to branchless equivalents."
 msgstr "Lakukan konversi dari kondisional jump ke branchless ekuivalen"
 
-#: common.opt:1564
+#: common.opt:1568
 #, fuzzy
 #| msgid "Perform conversion of conditional jumps to conditional execution"
 msgid "Perform conversion of conditional jumps to conditional execution."
 msgstr "Lakukan konversi dari kondisional lompat ke kondisional eksekusi"
 
-#: common.opt:1568
+#: common.opt:1572
 msgid "-fstack-reuse=[all|named_vars|none]\tSet stack reuse level for local variables."
 msgstr ""
 
-#: common.opt:1571
+#: common.opt:1575
 #, fuzzy, c-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown Stack Reuse Level %qs"
 msgstr "mode mesin %qs tidak dikenal"
 
-#: common.opt:1584
+#: common.opt:1588
 #, fuzzy
 #| msgid "Perform conversion of conditional jumps to branchless equivalents"
 msgid "Convert conditional jumps in innermost loops to branchless equivalents."
 msgstr "Lakukan konversi dari kondisional jump ke branchless ekuivalen"
 
-#: common.opt:1596
+#: common.opt:1600
 #, fuzzy
 #| msgid "Do not generate .size directives"
 msgid "Do not generate .size directives."
 msgstr "Jangan hasilkan direktif .size"
 
-#: common.opt:1600
+#: common.opt:1604
 #, fuzzy
 #| msgid "Perform indirect inlining"
 msgid "Perform indirect inlining."
 msgstr "Lakukan inlining tidak langsung"
 
-#: common.opt:1606
+#: common.opt:1610
 msgid "Enable inlining of function declared \"inline\", disabling disables all inlining."
 msgstr ""
 
-#: common.opt:1610
+#: common.opt:1614
 #, fuzzy
 #| msgid "Integrate simple functions into their callers when code size is known to not growth"
 msgid "Integrate functions into their callers when code size is known not to grow."
 msgstr "Integrasikan fungsi sederhana kedalam pemanggilnya ketika ukuran kode diketahui tidak berkembang"
 
-#: common.opt:1614
+#: common.opt:1618
 #, fuzzy
 #| msgid "Integrate functions called once into their callers"
 msgid "Integrate functions not declared \"inline\" into their callers when profitable."
 msgstr "Integrasikan fungsi dipanggil sekali dalam pemanggilnya"
 
-#: common.opt:1618
+#: common.opt:1622
 #, fuzzy
 #| msgid "Integrate functions called once into their callers"
 msgid "Integrate functions only required by their single caller."
 msgstr "Integrasikan fungsi dipanggil sekali dalam pemanggilnya"
 
-#: common.opt:1625
+#: common.opt:1629
 #, fuzzy
 #| msgid "Limit the size of inlined functions to <number>"
 msgid "-finline-limit=<number>\tLimit the size of inlined functions to <number>."
 msgstr "Batasi ukuran dari fungsi diinline ke <angka>"
 
-#: common.opt:1629
+#: common.opt:1633
 msgid "Inline __atomic operations when a lock free instruction sequence is available."
 msgstr ""
 
-#: common.opt:1636
+#: common.opt:1640
 msgid "-fcf-protection=[full|branch|return|none]\tInstrument functions with checks to verify jump/call/return control-flow transfer instructions have valid targets."
 msgstr ""
 
-#: common.opt:1640
+#: common.opt:1644
 #, c-format
 msgid "unknown Control-Flow Protection Level %qs"
 msgstr ""
 
-#: common.opt:1656
+#: common.opt:1660
 #, fuzzy
 #| msgid "Instrument function entry and exit with profiling calls"
 msgid "Instrument function entry and exit with profiling calls."
 msgstr "Instrumen fungsi masukan dan keluaran dengan profiling panggilan"
 
-#: common.opt:1660
+#: common.opt:1664
 #, fuzzy
 #| msgid "-finstrument-functions-exclude-function-list=name,...  Do not instrument listed functions"
 msgid "-finstrument-functions-exclude-function-list=name,...  Do not instrument listed functions."
 msgstr "-finstrumen-functions-exclude-function-list=name,... jangan instrumen fungsi yang terdaftar"
 
-#: common.opt:1664
+#: common.opt:1668
 #, fuzzy
 #| msgid "-finstrument-functions-exclude-file-list=filename,...  Do not instrument functions listed in files"
 msgid "-finstrument-functions-exclude-file-list=filename,...  Do not instrument functions listed in files."
 msgstr "-finstrument-functions-exclude-file-list=filename,... Jangan instrumen fungsi yang terdaftar dalam berkas"
 
-#: common.opt:1668
+#: common.opt:1672
 #, fuzzy
 #| msgid "Perform Interprocedural constant propagation"
 msgid "Perform interprocedural constant propagation."
 msgstr "Lakukan propagasi konstanta interprosedural"
 
-#: common.opt:1672
+#: common.opt:1676
 #, fuzzy
 #| msgid "Perform cloning to make Interprocedural constant propagation stronger"
 msgid "Perform cloning to make Interprocedural constant propagation stronger."
 msgstr "Lakukan cloning untuk membuat propagasi konstanta lebih kuat antar prosedur"
 
-#: common.opt:1680
+#: common.opt:1684
 #, fuzzy
 #| msgid "Perform Interprocedural constant propagation"
 msgid "Perform interprocedural bitwise constant propagation."
 msgstr "Lakukan propagasi konstanta interprosedural"
 
-#: common.opt:1684
+#: common.opt:1688
 #, fuzzy
 #| msgid "Perform Interprocedural constant propagation"
 msgid "Perform interprocedural profile propagation."
 msgstr "Lakukan propagasi konstanta interprosedural"
 
-#: common.opt:1688
+#: common.opt:1692
 #, fuzzy
 #| msgid "Perform interprocedural points-to analysis"
 msgid "Perform interprocedural points-to analysis."
 msgstr "Lakukan analisa interprosedural titik-ke"
 
-#: common.opt:1692
+#: common.opt:1696
 #, fuzzy
 #| msgid "Discover pure and const functions"
 msgid "Discover pure and const functions."
 msgstr "Temukan fungsi pure dan const"
 
-#: common.opt:1696
+#: common.opt:1700
 msgid "Perform Identical Code Folding for functions and read-only variables."
 msgstr ""
 
-#: common.opt:1700
+#: common.opt:1704
 msgid "Perform Identical Code Folding for functions."
 msgstr ""
 
-#: common.opt:1704
+#: common.opt:1708
 msgid "Perform Identical Code Folding for variables."
 msgstr ""
 
-#: common.opt:1708
+#: common.opt:1712
 #, fuzzy
 #| msgid "Discover readonly and non addressable static variables"
 msgid "Discover readonly and non addressable static variables."
 msgstr "Temukan baca-saja dan variabel statis tidak beralamat"
 
-#: common.opt:1720
+#: common.opt:1724
 #, fuzzy
 #| msgid "Perform Value Range Propagation on trees"
 msgid "Perform IPA Value Range Propagation."
 msgstr "Lakukan Propagasi Jangkauan Nilai pada pohon"
 
-#: common.opt:1724
+#: common.opt:1728
 #, fuzzy
 #| msgid "-fira-algorithm=[CB|priority] Set the used IRA algorithm"
 msgid "-fira-algorithm=[CB|priority]\tSet the used IRA algorithm."
 msgstr "-fire-algorithm=[CB|prioritas] Set penggunaan algoritma IRA"
 
-#: common.opt:1727
+#: common.opt:1731
 #, fuzzy, c-format
 #| msgid "unknown ira algorithm \"%s\""
 msgid "unknown IRA algorithm %qs"
 msgstr "algoritma ira \"%s\" tidak diketahui"
 
-#: common.opt:1737
+#: common.opt:1741
 #, fuzzy
 #| msgid "-fira-region=[one|all|mixed] Set regions for IRA"
 msgid "-fira-region=[one|all|mixed]\tSet regions for IRA."
 msgstr "-fira-region=[one|all|mixed] Set daerah untuk IRA"
 
-#: common.opt:1740
+#: common.opt:1744
 #, fuzzy, c-format
 #| msgid "unknown ira region \"%s\""
 msgid "unknown IRA region %qs"
 msgstr "daerah ira \"%s\" tidak diketahui"
 
-#: common.opt:1753
+#: common.opt:1757
 msgid "Use IRA based register pressure calculation in RTL hoist optimizations."
 msgstr ""
 
-#: common.opt:1758
+#: common.opt:1762
 msgid "Use IRA based register pressure calculation in RTL loop optimizations."
 msgstr ""
 
-#: common.opt:1763
+#: common.opt:1767
 msgid "Share slots for saving different hard registers."
 msgstr "Share slots untuk menyimpan register keras berbeda."
 
-#: common.opt:1767
+#: common.opt:1771
 msgid "Share stack slots for spilled pseudo-registers."
 msgstr "Share stack slots untuk spilled pseudo-register."
 
-#: common.opt:1771
+#: common.opt:1775
 #, fuzzy
 #| msgid "-fira-verbose=<number> Control IRA's level of diagnostic messages."
 msgid "-fira-verbose=<number>\tControl IRA's level of diagnostic messages."
 msgstr "-fira-verbose=<angka>  Kontrol tingkat dari pesan diagnosa IRA."
 
-#: common.opt:1775
+#: common.opt:1779
 #, fuzzy
 #| msgid "Optimize induction variables on trees"
 msgid "Optimize induction variables on trees."
 msgstr "Optimasi variabel induksi dalam pohon"
 
-#: common.opt:1779
+#: common.opt:1783
 #, fuzzy
 #| msgid "Use jump tables for sufficiently large switch statements"
 msgid "Use jump tables for sufficiently large switch statements."
 msgstr "Gunakan tabel jump untuk pernyataan secara mencukupi besar switch"
 
-#: common.opt:1783
+#: common.opt:1787
 #, fuzzy
 #| msgid "Generate code for functions even if they are fully inlined"
 msgid "Generate code for functions even if they are fully inlined."
 msgstr "Hasilkan kode untuk fungsi walaupun jika mereka secara penuh inlined"
 
-#: common.opt:1787
+#: common.opt:1791
 #, fuzzy
 #| msgid "Generate code for functions even if they are fully inlined"
 msgid "Generate code for static functions even if they are never called."
 msgstr "Hasilkan kode untuk fungsi walaupun jika mereka secara penuh inlined"
 
-#: common.opt:1791
+#: common.opt:1795
 #, fuzzy
 #| msgid "Emit static const variables even if they are not used"
 msgid "Emit static const variables even if they are not used."
 msgstr "Keluarkan variabel statis const walapu mereka tidak digunakan"
 
-#: common.opt:1795
+#: common.opt:1799
 #, fuzzy
 #| msgid "Give external symbols a leading underscore"
 msgid "Give external symbols a leading underscore."
 msgstr "Berikan eksternal simbol sebuah awalan garis bawah"
 
-#: common.opt:1803
+#: common.opt:1807
 msgid "Do CFG-sensitive rematerialization in LRA."
 msgstr ""
 
-#: common.opt:1807
+#: common.opt:1811
 #, fuzzy
 #| msgid "Enable linker optimizations"
 msgid "Enable link-time optimization."
 msgstr "Aktifkan optimasi penghubung"
 
-#: common.opt:1811
+#: common.opt:1815
 msgid "Link-time optimization with number of parallel jobs or jobserver."
 msgstr ""
 
-#: common.opt:1814
+#: common.opt:1818
 #, fuzzy, c-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown LTO partitioning model %qs"
 msgstr "mode mesin %qs tidak dikenal"
 
-#: common.opt:1833
+#: common.opt:1837
 msgid "Specify the algorithm to partition symbols and vars at linktime."
 msgstr ""
 
-#: common.opt:1838
+#: common.opt:1842
 msgid "-flto-compression-level=<number>\tUse zlib compression level <number> for IL."
 msgstr ""
 
-#: common.opt:1842
+#: common.opt:1846
 msgid "Merge C++ types using One Definition Rule."
 msgstr ""
 
-#: common.opt:1846
+#: common.opt:1850
 msgid "Report various link-time optimization statistics."
 msgstr ""
 
-#: common.opt:1850
+#: common.opt:1854
 msgid "Report various link-time optimization statistics for WPA only."
 msgstr ""
 
-#: common.opt:1854
+#: common.opt:1858
 #, fuzzy
 #| msgid "Set errno after built-in math functions"
 msgid "Set errno after built-in math functions."
 msgstr "Set errno setelah fungsi matematik bawaan"
 
-#: common.opt:1858
+#: common.opt:1862
 #, fuzzy
 #| msgid "Maximum number of errors to report"
 msgid "-fmax-errors=<number>\tMaximum number of errors to report."
 msgstr "Jumlah maksimum dari error untuk dilaporkan"
 
-#: common.opt:1862
+#: common.opt:1866
 #, fuzzy
 #| msgid "Report on permanent memory allocation"
 msgid "Report on permanent memory allocation."
 msgstr "Laporkan pada alokasi memori permanen"
 
-#: common.opt:1866
+#: common.opt:1870
 #, fuzzy
 #| msgid "Report on permanent memory allocation"
 msgid "Report on permanent memory allocation in WPA only."
 msgstr "Laporkan pada alokasi memori permanen"
 
-#: common.opt:1873
+#: common.opt:1877
 #, fuzzy
 #| msgid "Attempt to merge identical constants and constant variables"
 msgid "Attempt to merge identical constants and constant variables."
 msgstr "Mencoba menggabungkan konstanta identik dan konstanta variabel"
 
-#: common.opt:1877
+#: common.opt:1881
 #, fuzzy
 #| msgid "Attempt to merge identical constants across compilation units"
 msgid "Attempt to merge identical constants across compilation units."
 msgstr "Mencoba menggabungkan konstanta identik melewati satuan kompilasi"
 
-#: common.opt:1881
+#: common.opt:1885
 #, fuzzy
 #| msgid "Attempt to merge identical debug strings across compilation units"
 msgid "Attempt to merge identical debug strings across compilation units."
 msgstr "Mencoba untuk menggabungkan debug string identik across satuan kompilasi"
 
-#: common.opt:1885
+#: common.opt:1889
 #, fuzzy
 #| msgid "Limit diagnostics to <number> characters per line.  0 suppresses line-wrapping"
 msgid "-fmessage-length=<number>\tLimit diagnostics to <number> characters per line.  0 suppresses line-wrapping."
 msgstr "Batasi diagnosa sampai <number> karakter per baris. 0 tekan line-wrapping"
 
-#: common.opt:1889
+#: common.opt:1893
 #, fuzzy
 #| msgid "Perform SMS based modulo scheduling before the first scheduling pass"
 msgid "Perform SMS based modulo scheduling before the first scheduling pass."
 msgstr "Lakukan penjadwalan berdasarkan SMS modulo sebelum tahap penjadwalan pertama"
 
-#: common.opt:1893
+#: common.opt:1897
 #, fuzzy
 #| msgid "Perform SMS based modulo scheduling with register moves allowed"
 msgid "Perform SMS based modulo scheduling with register moves allowed."
 msgstr "Lakukan penjadwalan berdasarkan module SMS dengan perpindahan register diperbolehkan"
 
-#: common.opt:1897
+#: common.opt:1901
 #, fuzzy
 #| msgid "Move loop invariant computations out of loops"
 msgid "Move loop invariant computations out of loops."
 msgstr "Move loop invarian komputasi diluar dari loops"
 
-#: common.opt:1901
+#: common.opt:1905
 #, fuzzy
 #| msgid "Use the RTL dead code elimination pass"
 msgid "Use the RTL dead code elimination pass."
 msgstr "Gunaka tahap penghapusan RTL kode mati"
 
-#: common.opt:1905
+#: common.opt:1909
 #, fuzzy
 #| msgid "Use the RTL dead store elimination pass"
 msgid "Use the RTL dead store elimination pass."
 msgstr "Gunakan tahap penghapusan RTL dead store"
 
-#: common.opt:1909
+#: common.opt:1913
 #, fuzzy
 #| msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling"
 msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling."
 msgstr "Aktifkan/Non-aktifkan penjadwalan tradisional dalam loop yang telah dilewatkan penjadwalan modulo"
 
-#: common.opt:1913
+#: common.opt:1917
 #, fuzzy
 #| msgid "Support synchronous non-call exceptions"
 msgid "Support synchronous non-call exceptions."
 msgstr "Dukung eksepsi sinkronous bukan panggilan"
 
-#: common.opt:1916
+#: common.opt:1920
 #, fuzzy, c-format
 #| msgid "assertion missing after %qs"
 msgid "options or targets missing after %qs"
 msgstr "assertion hilang setelah %qs"
 
-#: common.opt:1917
+#: common.opt:1921
 msgid "-foffload=<targets>=<options>  Specify offloading targets and options for them."
 msgstr ""
 
-#: common.opt:1921
+#: common.opt:1925
 msgid "-foffload-abi=[lp64|ilp32]     Set the ABI to use in an offload compiler."
 msgstr ""
 
-#: common.opt:1924
+#: common.opt:1928
 #, fuzzy, c-format
 #| msgid "unknown tls-model \"%s\""
 msgid "unknown offload ABI %qs"
 msgstr "tls-model \"%s\" tidak dikenal"
 
-#: common.opt:1934
+#: common.opt:1938
 #, fuzzy
 #| msgid "When possible do not generate stack frames"
 msgid "When possible do not generate stack frames."
 msgstr "Jika memungkinkan jangan hasilkan stack frames"
 
-#: common.opt:1938
+#: common.opt:1942
 #, fuzzy
 #| msgid "Enable loop optimizations on tree level"
 msgid "Enable all optimization info dumps on stderr."
 msgstr "Aktifkan optimasi loop pada tingkat pohon"
 
-#: common.opt:1942
+#: common.opt:1946
 msgid "-fopt-info[-<type>=filename]\tDump compiler optimization details."
 msgstr ""
 
-#: common.opt:1950
+#: common.opt:1954
 #, fuzzy
 #| msgid "Optimize sibling and tail recursive calls"
 msgid "Optimize sibling and tail recursive calls."
 msgstr "Optimisasi sibling dan tail rekursi calls"
 
-#: common.opt:1954
+#: common.opt:1958
 #, fuzzy
 #| msgid "Perform early inlining"
 msgid "Perform partial inlining."
 msgstr "Lakukan inlining awal"
 
-#: common.opt:1958 common.opt:1962
+#: common.opt:1962 common.opt:1966
 #, fuzzy
 #| msgid "Report on memory allocation before interprocedural optimization"
 msgid "Report on memory allocation before interprocedural optimization."
 msgstr "Laporkan dalam alokasi memori sebelum optimisasi interprosedural"
 
-#: common.opt:1966
+#: common.opt:1970
 #, fuzzy
 #| msgid "Pack structure members together without holes"
 msgid "Pack structure members together without holes."
 msgstr "Pack anggota struktur bersama tanpa lubang"
 
-#: common.opt:1970
+#: common.opt:1974
 #, fuzzy
 #| msgid "Set initial maximum structure member alignment"
 msgid "-fpack-struct=<number>\tSet initial maximum structure member alignment."
 msgstr "Set inisial maksimal alignmen anggota struktur"
 
-#: common.opt:1974
+#: common.opt:1978
 #, fuzzy
 #| msgid "Return small aggregates in memory, not registers"
 msgid "Return small aggregates in memory, not registers."
 msgstr "Kembali agregate kecil dalam memori, bukan register"
 
-#: common.opt:1978
+#: common.opt:1982
 #, fuzzy
 #| msgid "Perform loop peeling"
 msgid "Perform loop peeling."
 msgstr "Lakukan loop peeling"
 
-#: common.opt:1982
+#: common.opt:1986
 #, fuzzy
 #| msgid "Enable machine specific peephole optimizations"
 msgid "Enable machine specific peephole optimizations."
 msgstr "Aktifkan mesin spesifik peephole optimisasi"
 
-#: common.opt:1986
+#: common.opt:1990
 #, fuzzy
 #| msgid "Enable an RTL peephole pass before sched2"
 msgid "Enable an RTL peephole pass before sched2."
 msgstr "Aktifkan sebuah tahap RTL peephole sebelum sched2"
 
-#: common.opt:1990
+#: common.opt:1994
 #, fuzzy
 #| msgid "Generate position-independent code if possible (large mode)"
 msgid "Generate position-independent code if possible (large mode)."
 msgstr "Hasilkan kode bebas posisi jika memungkinkan (mode besar)"
 
-#: common.opt:1994
+#: common.opt:1998
 #, fuzzy
 #| msgid "Generate position-independent code for executables if possible (large mode)"
 msgid "Generate position-independent code for executables if possible (large mode)."
 msgstr "Hasilkan kode bebas posisi untuk executables jika memungkinkan (mode besar)"
 
-#: common.opt:1998
+#: common.opt:2002
 #, fuzzy
 #| msgid "Generate position-independent code if possible (small mode)"
 msgid "Generate position-independent code if possible (small mode)."
 msgstr "Hasilkan kode bebas posisi jika memungkinkan (mode kecil)"
 
-#: common.opt:2002
+#: common.opt:2006
 #, fuzzy
 #| msgid "Generate position-independent code for executables if possible (small mode)"
 msgid "Generate position-independent code for executables if possible (small mode)."
 msgstr "Hasilkan kode bebas posisi untuk executables jika memungkinkan (mode kecil)"
 
-#: common.opt:2006
+#: common.opt:2010
 msgid "Use PLT for PIC calls (-fno-plt: load the address from GOT at call site)."
 msgstr ""
 
-#: common.opt:2010
+#: common.opt:2014
 #, fuzzy
 #| msgid "Specify options to GNAT"
 msgid "Specify a plugin to load."
 msgstr "Spesifikasikan pilihan ke GNAT"
 
-#: common.opt:2014
+#: common.opt:2018
 msgid "-fplugin-arg-<name>-<key>[=<value>]\tSpecify argument <key>=<value> for plugin <name>."
 msgstr ""
 
-#: common.opt:2018
+#: common.opt:2022
 msgid "Run predictive commoning optimization."
 msgstr "Jalankan optimisasi prediktif commoning."
 
-#: common.opt:2022
+#: common.opt:2026
 #, fuzzy
 #| msgid "Generate prefetch instructions, if available, for arrays in loops"
 msgid "Generate prefetch instructions, if available, for arrays in loops."
 msgstr "Hasilkan instruksi prefetch, jika tersedia, untuk array dalam loops"
 
-#: common.opt:2026
+#: common.opt:2030
 #, fuzzy
 #| msgid "Enable basic program profiling code"
 msgid "Enable basic program profiling code."
 msgstr "Aktifkan aplikasi dasar profiling kode"
 
-#: common.opt:2030
+#: common.opt:2034
 msgid "Generate absolute source path names for gcov."
 msgstr ""
 
-#: common.opt:2034
+#: common.opt:2038
 #, fuzzy
 #| msgid "Insert arc-based program profiling code"
 msgid "Insert arc-based program profiling code."
 msgstr "Masukan aplikasi berbasis arc profiling kode"
 
-#: common.opt:2038
+#: common.opt:2042
 #, fuzzy
 #| msgid "Set the top-level directory for storing the profile data."
 msgid "Set the top-level directory for storing the profile data. The default is 'pwd'."
 msgstr "Set direktori tingkat atas untuk menyimpan data profile."
 
-#: common.opt:2043
+#: common.opt:2047
 #, fuzzy
 #| msgid "Enable correction of flow inconsistent profile data input"
 msgid "Enable correction of flow inconsistent profile data input."
 msgstr "Aktifkan koreksi dari alur profile tidak konsisten masukan data"
 
-#: common.opt:2047
+#: common.opt:2051
 msgid "-fprofile-update=[single|atomic|prefer-atomic]\tSet the profile update method."
 msgstr ""
 
-#: common.opt:2050
+#: common.opt:2054
 #, fuzzy, c-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown profile update method %qs"
 msgstr "mode mesin %qs tidak dikenal"
 
-#: common.opt:2063
+#: common.opt:2067
 #, fuzzy
 #| msgid "Enable common options for generating profile info for profile feedback directed optimizations"
 msgid "Enable common options for generating profile info for profile feedback directed optimizations."
 msgstr "Aktifkan pilihan umum untuk menghasilkan informasi profile untuk feedback profile direkted optimisasi"
 
-#: common.opt:2067
+#: common.opt:2071
 #, fuzzy
 #| msgid "Enable common options for generating profile info for profile feedback directed optimizations, and set -fprofile-dir="
 msgid "Enable common options for generating profile info for profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr "Aktifkan pilihan umum untuk menghasilkan informasi profile untuk feedback profile direkted optimisasi, dan set -fprofile-dir="
 
-#: common.opt:2071
+#: common.opt:2075
 #, fuzzy
 #| msgid "Enable common options for performing profile feedback directed optimizations"
 msgid "Enable common options for performing profile feedback directed optimizations."
 msgstr "Aktifkan pilihan umum untuk melakukan profile feedback directed optimisasi"
 
-#: common.opt:2075
+#: common.opt:2079
 #, fuzzy
 #| msgid "Enable common options for performing profile feedback directed optimizations, and set -fprofile-dir="
 msgid "Enable common options for performing profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr "Aktifkan pilihan umum untuk melakukan profile feedback directed optimisasi, dan set -fprofile-dir="
 
-#: common.opt:2079
+#: common.opt:2083
 #, fuzzy
 #| msgid "Insert code to profile values of expressions"
 msgid "Insert code to profile values of expressions."
 msgstr "Masukan kode untuk profile nilai dari ekspresi"
 
-#: common.opt:2083
+#: common.opt:2087
 #, fuzzy
 #| msgid "internal consistency failure"
 msgid "Report on consistency of profile."
 msgstr "kegagalan konsistensi internal"
 
-#: common.opt:2087
+#: common.opt:2091
 #, fuzzy
 #| msgid "Reorder functions to improve code placement"
 msgid "Enable function reordering that improves code placement."
 msgstr "Urutkan kembali fungsi untuk meningkatkan penempatan kode"
 
-#: common.opt:2091
+#: common.opt:2095
 #, fuzzy
 #| msgid "Generate cld instruction in the function prologue."
 msgid "Insert NOP instructions at each function entry."
 msgstr "Hasilkan instruksi cld dalam fungsi prolog."
 
-#: common.opt:2098
+#: common.opt:2102
 #, fuzzy
 #| msgid "Make compile reproducible using <string>"
 msgid "-frandom-seed=<string>\tMake compile reproducible using <string>."
 msgstr "Buat kompile reproducible menggunakan <string>"
 
-#: common.opt:2108
+#: common.opt:2112
 msgid "Record gcc command line switches in the object file."
 msgstr "Rekam pilihan baris perintah gcc dalam berkas objek."
 
-#: common.opt:2112
+#: common.opt:2116
 #, fuzzy
 #| msgid "Return small aggregates in registers"
 msgid "Return small aggregates in registers."
 msgstr "Kembali kumpulan kecil dalam registers"
 
-#: common.opt:2120
+#: common.opt:2124
 msgid "Tell DSE that the storage for a C++ object is dead when the constructor starts and when the destructor finishes."
 msgstr ""
 
-#: common.opt:2128
+#: common.opt:2132
 msgid "Relief of register pressure through live range shrinkage."
 msgstr ""
 
-#: common.opt:2132
+#: common.opt:2136
 #, fuzzy
 #| msgid "Perform a register renaming optimization pass"
 msgid "Perform a register renaming optimization pass."
 msgstr "Lakukan sebuah tahap optimisasi pengubahan nama register"
 
-#: common.opt:2136
+#: common.opt:2140
 #, fuzzy
 #| msgid "Perform a register renaming optimization pass"
 msgid "Perform a target dependent instruction fusion optimization pass."
 msgstr "Lakukan sebuah tahap optimisasi pengubahan nama register"
 
-#: common.opt:2140
+#: common.opt:2144
 #, fuzzy
 #| msgid "Reorder basic blocks to improve code placement"
 msgid "Reorder basic blocks to improve code placement."
 msgstr "Urutkan kembali blok dasar untuk meningkatkan penempatan kode"
 
-#: common.opt:2144
+#: common.opt:2148
 msgid "-freorder-blocks-algorithm=[simple|stc]\tSet the used basic block reordering algorithm."
 msgstr ""
 
-#: common.opt:2147
+#: common.opt:2151
 #, fuzzy, c-format
 #| msgid "unknown ira algorithm \"%s\""
 msgid "unknown basic block reordering algorithm %qs"
 msgstr "algoritma ira \"%s\" tidak diketahui"
 
-#: common.opt:2157
+#: common.opt:2161
 #, fuzzy
 #| msgid "Reorder basic blocks and partition into hot and cold sections"
 msgid "Reorder basic blocks and partition into hot and cold sections."
 msgstr "Urutkan kembali blok dasar dan partisi kedalam daerah panas dan dingin"
 
-#: common.opt:2161
+#: common.opt:2165
 #, fuzzy
 #| msgid "Reorder functions to improve code placement"
 msgid "Reorder functions to improve code placement."
 msgstr "Urutkan kembali fungsi untuk meningkatkan penempatan kode"
 
-#: common.opt:2165
+#: common.opt:2169
 #, fuzzy
 #| msgid "Add a common subexpression elimination pass after loop optimizations"
 msgid "Add a common subexpression elimination pass after loop optimizations."
 msgstr "Tambahkan sebuah tahap penghapusan umum subexpression setelah optimisasi loop"
 
-#: common.opt:2173
+#: common.opt:2177
 #, fuzzy
 #| msgid "Disable optimizations that assume default FP rounding behavior"
 msgid "Disable optimizations that assume default FP rounding behavior."
 msgstr "Non-aktifkan optimisasi yang mengasumsikan perilaku baku pembulatan titik pecahan"
 
-#: common.opt:2177
+#: common.opt:2181
 #, fuzzy
 #| msgid "Enable scheduling across basic blocks"
 msgid "Enable scheduling across basic blocks."
 msgstr "Aktifkan penjadwalan melewati blok dasar"
 
-#: common.opt:2181
+#: common.opt:2185
 msgid "Enable register pressure sensitive insn scheduling."
 msgstr ""
 
-#: common.opt:2185
+#: common.opt:2189
 #, fuzzy
 #| msgid "Allow speculative motion of non-loads"
 msgid "Allow speculative motion of non-loads."
 msgstr "Ijinkan perpindahan spekulasi dari bukan loads"
 
-#: common.opt:2189
+#: common.opt:2193
 #, fuzzy
 #| msgid "Allow speculative motion of some loads"
 msgid "Allow speculative motion of some loads."
 msgstr "Ijinkan perpindahan spekulasi dari beberapa loads"
 
-#: common.opt:2193
+#: common.opt:2197
 #, fuzzy
 #| msgid "Allow speculative motion of more loads"
 msgid "Allow speculative motion of more loads."
 msgstr "Ijinkan spekulasi motion dari beberapa loads"
 
-#: common.opt:2197
+#: common.opt:2201
 #, fuzzy
 #| msgid "Set the verbosity level of the scheduler"
 msgid "-fsched-verbose=<number>\tSet the verbosity level of the scheduler."
 msgstr "Set tingkat verbositas dari penjadwal"
 
-#: common.opt:2201
+#: common.opt:2205
 #, fuzzy
 #| msgid "If scheduling post reload, do superblock scheduling"
 msgid "If scheduling post reload, do superblock scheduling."
 msgstr "Jika penjadwalan post reload, lakukan penjadwalan superblok"
 
-#: common.opt:2209
+#: common.opt:2213
 #, fuzzy
 #| msgid "Reschedule instructions before register allocation"
 msgid "Reschedule instructions before register allocation."
 msgstr "Atur penjadwalan instruksi sebelum alokasi register"
 
-#: common.opt:2213
+#: common.opt:2217
 #, fuzzy
 #| msgid "Reschedule instructions after register allocation"
 msgid "Reschedule instructions after register allocation."
 msgstr "Atur penjadwalan instruksi setelah alokasi register"
 
-#: common.opt:2220
+#: common.opt:2224
 #, fuzzy
 #| msgid "Schedule instructions using selective scheduling algorithm"
 msgid "Schedule instructions using selective scheduling algorithm."
 msgstr "Instruksi penjadwalan menggunakan algoritma penjadwalan selektif"
 
-#: common.opt:2224
+#: common.opt:2228
 #, fuzzy
 #| msgid "Run selective scheduling after reload"
 msgid "Run selective scheduling after reload."
 msgstr "Jalankan penjadwalan selektif setelah reload"
 
-#: common.opt:2228
+#: common.opt:2232
 msgid "Run self-tests, using the given path to locate test files."
 msgstr ""
 
-#: common.opt:2232
+#: common.opt:2236
 #, fuzzy
 #| msgid "Perform software pipelining of inner loops during selective scheduling"
 msgid "Perform software pipelining of inner loops during selective scheduling."
 msgstr "Lakukan software pipelining dari loops dalam selama penjadwalan selektif"
 
-#: common.opt:2236
+#: common.opt:2240
 #, fuzzy
 #| msgid "Perform software pipelining of outer loops during selective scheduling"
 msgid "Perform software pipelining of outer loops during selective scheduling."
 msgstr "Lakukan software pipelining dari loops luar selama penjadwalan selektif"
 
-#: common.opt:2240
+#: common.opt:2244
 #, fuzzy
 #| msgid "Reschedule pipelined regions without pipelining"
 msgid "Reschedule pipelined regions without pipelining."
 msgstr "Reschedule daerah pipelined tanpa pipelining"
 
-#: common.opt:2244
+#: common.opt:2248
 msgid "Allow interposing function (or variables) by ones with different semantics (or initializer) respectively by dynamic linker."
 msgstr ""
 
-#: common.opt:2250
+#: common.opt:2254
 #, fuzzy
 #| msgid "Allow premature scheduling of queued insns"
 msgid "Allow premature scheduling of queued insns."
 msgstr "Ijinkan premature penjadwalan dari antrian instruksi"
 
-#: common.opt:2254
+#: common.opt:2258
 #, fuzzy
 #| msgid "Set number of queued insns that can be prematurely scheduled"
 msgid "-fsched-stalled-insns=<number>\tSet number of queued insns that can be prematurely scheduled."
 msgstr "Set jumlah dari antrian instruksi yang dapat secara permature dijadwalkan"
 
-#: common.opt:2262
+#: common.opt:2266
 #, fuzzy
 #| msgid "Set dependence distance checking in premature scheduling of queued insns"
 msgid "Set dependence distance checking in premature scheduling of queued insns."
 msgstr "Set dependence pemeriksaan jarak dalam premature penjadwalan dari antrian instruksi"
 
-#: common.opt:2266
+#: common.opt:2270
 #, fuzzy
 #| msgid "Set dependence distance checking in premature scheduling of queued insns"
 msgid "-fsched-stalled-insns-dep=<number>\tSet dependence distance checking in premature scheduling of queued insns."
 msgstr "Set dependence pemeriksaan jarak dalam premature penjadwalan dari antrian instruksi"
 
-#: common.opt:2270
+#: common.opt:2274
 msgid "Enable the group heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2274
+#: common.opt:2278
 msgid "Enable the critical path heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2278
+#: common.opt:2282
 msgid "Enable the speculative instruction heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2282
+#: common.opt:2286
 #, fuzzy
 #| msgid "Set the verbosity level of the scheduler"
 msgid "Enable the rank heuristic in the scheduler."
 msgstr "Set tingkat verbositas dari penjadwal"
 
-#: common.opt:2286
+#: common.opt:2290
 msgid "Enable the last instruction heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2290
+#: common.opt:2294
 msgid "Enable the dependent count heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2294
+#: common.opt:2298
 #, fuzzy
 #| msgid "Access data in the same section from shared anchor points"
 msgid "Access data in the same section from shared anchor points."
 msgstr "Akses data dalam daerah sama dari titik achor terbagi"
 
-#: common.opt:2306
+#: common.opt:2310
 msgid "Turn on Redundant Extensions Elimination pass."
 msgstr ""
 
-#: common.opt:2310
+#: common.opt:2314
 #, fuzzy
 #| msgid "Show column numbers in diagnostics, when available.  Default off"
 msgid "Show column numbers in diagnostics, when available.  Default on."
 msgstr "Tampilkan jumlah kolom dalam diagnosa, jika tersedia. Baku tidak aktif"
 
-#: common.opt:2314
+#: common.opt:2318
 msgid "Emit function prologues only before parts of the function that need it, rather than at the top of the function."
 msgstr ""
 
-#: common.opt:2319
+#: common.opt:2323
 msgid "Shrink-wrap parts of the prologue and epilogue separately."
 msgstr ""
 
-#: common.opt:2323
+#: common.opt:2327
 #, fuzzy
 #| msgid "Disable optimizations observable by IEEE signaling NaNs"
 msgid "Disable optimizations observable by IEEE signaling NaNs."
 msgstr "Non-aktifkan optimisasi dilihat oleh IEEE pensinyalan NaN"
 
-#: common.opt:2327
+#: common.opt:2331
 #, fuzzy
 #| msgid "Disable floating point optimizations that ignore the IEEE signedness of zero"
 msgid "Disable floating point optimizations that ignore the IEEE signedness of zero."
 msgstr "Non-aktifkan optimisasi titik pecahan yang mengabaikan IEEE signedness dari nol"
 
-#: common.opt:2331
+#: common.opt:2335
 #, fuzzy
 #| msgid "Convert floating point constants to single precision constants"
 msgid "Convert floating point constants to single precision constants."
 msgstr "Ubah konstanta titik pecahan ke konstanta presisi tunggal"
 
-#: common.opt:2335
+#: common.opt:2339
 #, fuzzy
 #| msgid "Split lifetimes of induction variables when loops are unrolled"
 msgid "Split lifetimes of induction variables when loops are unrolled."
 msgstr "Bagi waktu-hidup dari variabel induksi ketika loops diunroll"
 
-#: common.opt:2339
+#: common.opt:2343
 #, fuzzy
 #| msgid "Generate APCS conformant stack frames"
 msgid "Generate discontiguous stack frames."
 msgstr "Hasilkan APCS konforman stack frames"
 
-#: common.opt:2343
+#: common.opt:2347
 #, fuzzy
 #| msgid "Split wide types into independent registers"
 msgid "Split wide types into independent registers."
 msgstr "Bagi tipe lebar kedalam register independent"
 
-#: common.opt:2347
+#: common.opt:2351
 msgid "Enable backward propagation of use properties at the SSA level."
 msgstr ""
 
-#: common.opt:2351
+#: common.opt:2355
 msgid "Optimize conditional patterns using SSA PHI nodes."
 msgstr ""
 
-#: common.opt:2355
+#: common.opt:2359
 msgid "Optimize amount of stdarg registers saved to stack at start of function."
 msgstr ""
 
-#: common.opt:2359
+#: common.opt:2363
 #, fuzzy
 #| msgid "Apply variable expansion when loops are unrolled"
 msgid "Apply variable expansion when loops are unrolled."
 msgstr "Aplikasikan ekspansi variabel ketika loops diuraikan"
 
-#: common.opt:2363
+#: common.opt:2367
 #, fuzzy
 #| msgid "Insert stack checking code into the program"
 msgid "-fstack-check=[no|generic|specific]\tInsert stack checking code into the program."
 msgstr "Masukan pemeriksaan kode stack kedalam aplikasi"
 
-#: common.opt:2367
+#: common.opt:2371
 #, fuzzy
 #| msgid "Insert stack checking code into the program.  Same as -fstack-check=specific"
 msgid "Insert stack checking code into the program.  Same as -fstack-check=specific."
 msgstr "Masukan pemeriksaan kode stack kedalam aplikasi. Sama seperti -fstack-check=specific"
 
-#: common.opt:2371
+#: common.opt:2375
 msgid "Insert code to probe each page of stack space as it is allocated to protect from stack-clash style attacks."
 msgstr ""
 
-#: common.opt:2379
+#: common.opt:2383
 #, fuzzy
 #| msgid "Trap if the stack goes past <register>"
 msgid "-fstack-limit-register=<register>\tTrap if the stack goes past <register>."
 msgstr "Trap jika stact pergi melampaui <register>"
 
-#: common.opt:2383
+#: common.opt:2387
 #, fuzzy
 #| msgid "Trap if the stack goes past symbol <name>"
 msgid "-fstack-limit-symbol=<name>\tTrap if the stack goes past symbol <name>."
 msgstr "Trap jika stack pergi melampaui simbol <nama>"
 
-#: common.opt:2387
+#: common.opt:2391
 #, fuzzy
 #| msgid "Use propolice as a stack protection method"
 msgid "Use propolice as a stack protection method."
 msgstr "Gunakan propolice sebagai sebuah metode proteksi stack"
 
-#: common.opt:2391
+#: common.opt:2395
 #, fuzzy
 #| msgid "Use a stack protection method for every function"
 msgid "Use a stack protection method for every function."
 msgstr "Gunakan sebuah metode proteksi stact untuk setiap fungsi"
 
-#: common.opt:2395
+#: common.opt:2399
 #, fuzzy
 #| msgid "Use a stack protection method for every function"
 msgid "Use a smart stack protection method for certain functions."
 msgstr "Gunakan sebuah metode proteksi stact untuk setiap fungsi"
 
-#: common.opt:2399
+#: common.opt:2403
 #, fuzzy
 #| msgid "Use a stack protection method for every function"
 msgid "Use stack protection method only for functions with the stack_protect attribute."
 msgstr "Gunakan sebuah metode proteksi stact untuk setiap fungsi"
 
-#: common.opt:2403
+#: common.opt:2407
 #, fuzzy
 #| msgid "Reuse r30 on a per function basis"
 msgid "Output stack usage information on a per-function basis."
 msgstr "Reuse r30 di sebuah per fungsi dasar"
 
-#: common.opt:2415
+#: common.opt:2419
 #, fuzzy
 #| msgid "Assume strict aliasing rules apply"
 msgid "Assume strict aliasing rules apply."
 msgstr "Asumsikan aturan strict aliasing berjalan"
 
-#: common.opt:2419
+#: common.opt:2423
 #, fuzzy
 #| msgid "Treat signed overflow as undefined"
 msgid "Treat signed overflow as undefined.  Negated as -fwrapv -fwrapv-pointer."
 msgstr "Perlakukan signed overflow sebagai tidak terdefinisi"
 
-#: common.opt:2423
+#: common.opt:2427
 msgid "Implement __atomic operations via libcalls to legacy __sync functions."
 msgstr ""
 
-#: common.opt:2427
+#: common.opt:2431
 #, fuzzy
 #| msgid "Check for syntax errors, then stop"
 msgid "Check for syntax errors, then stop."
 msgstr "Periksa untuk sintaks errors kemudian berhenti"
 
-#: common.opt:2431
+#: common.opt:2435
 #, fuzzy
 #| msgid "Create data files needed by \"gcov\""
 msgid "Create data files needed by \"gcov\"."
 msgstr "Buat sebuah berkas data dibutuhkan oleh \"gcov\""
 
-#: common.opt:2435
+#: common.opt:2439
 #, fuzzy
 #| msgid "Perform jump threading optimizations"
 msgid "Perform jump threading optimizations."
 msgstr "Lakukan optimasi jump threading"
 
-#: common.opt:2439
+#: common.opt:2443
 #, fuzzy
 #| msgid "Report the time taken by each compiler pass"
 msgid "Report the time taken by each compiler pass."
 msgstr "Laporkan waktu yang diambil oleh setiap tahap kompiler"
 
-#: common.opt:2443
+#: common.opt:2447
 msgid "Record times taken by sub-phases separately."
 msgstr ""
 
-#: common.opt:2447
+#: common.opt:2451
 #, fuzzy
 #| msgid "Set the default thread-local storage code generation model"
 msgid "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tSet the default thread-local storage code generation model."
 msgstr "Set mode baku pembuatan kode TLS"
 
-#: common.opt:2450
+#: common.opt:2454
 #, fuzzy, c-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown TLS model %qs"
 msgstr "mode mesin %qs tidak dikenal"
 
-#: common.opt:2466
+#: common.opt:2470
 #, fuzzy
 #| msgid "Reorder top level functions, variables, and asms"
 msgid "Reorder top level functions, variables, and asms."
 msgstr "Urutkan kembali fungsi tingkat atas, variabel, dan asm"
 
-#: common.opt:2470
+#: common.opt:2474
 #, fuzzy
 #| msgid "Perform superblock formation via tail duplication"
 msgid "Perform superblock formation via tail duplication."
 msgstr "Lakukan formasi superblok melalaui duplikasi tail"
 
-#: common.opt:2474
+#: common.opt:2478
 msgid "For targets that normally need trampolines for nested functions, always generate them instead of using descriptors."
 msgstr ""
 
-#: common.opt:2482
+#: common.opt:2486
 #, fuzzy
 #| msgid "Assume floating-point operations can trap"
 msgid "Assume floating-point operations can trap."
 msgstr "Asumsikan operasi titik pecahan dapat trap"
 
-#: common.opt:2486
+#: common.opt:2490
 #, fuzzy
 #| msgid "Trap for signed overflow in addition, subtraction and multiplication"
 msgid "Trap for signed overflow in addition, subtraction and multiplication."
 msgstr "Trap untuk signed overflow dalam penambahan, pengurangan dan perkalian"
 
-#: common.opt:2490
+#: common.opt:2494
 #, fuzzy
 #| msgid "Enable SSA-CCP optimization on trees"
 msgid "Enable SSA-CCP optimization on trees."
 msgstr "Aktifkan optimasi SSA-CCP pada pohon"
 
-#: common.opt:2494
+#: common.opt:2498
 #, fuzzy
 #| msgid "Enable SSA-CCP optimization on trees"
 msgid "Enable SSA-BIT-CCP optimization on trees."
 msgstr "Aktifkan optimasi SSA-CCP pada pohon"
 
-#: common.opt:2502
+#: common.opt:2506
 #, fuzzy
 #| msgid "Enable loop header copying on trees"
 msgid "Enable loop header copying on trees."
 msgstr "Aktifkan penyalinan loop header pada pohon"
 
-#: common.opt:2510
+#: common.opt:2514
 #, fuzzy
 #| msgid "Enable SSA code sinking on trees"
 msgid "Enable SSA coalescing of user variables."
 msgstr "Aktifkan penenggelaman kode SSA pada pohon"
 
-#: common.opt:2518
+#: common.opt:2522
 #, fuzzy
 #| msgid "Enable copy propagation on trees"
 msgid "Enable copy propagation on trees."
 msgstr "Aktifkan salin propagasi pada pohon"
 
-#: common.opt:2526
+#: common.opt:2530
 #, fuzzy
 #| msgid "Transform condition stores into unconditional ones"
 msgid "Transform condition stores into unconditional ones."
 msgstr "Transformasi kondisi stores kedalam tidak terkondisi satu"
 
-#: common.opt:2530
+#: common.opt:2534
 msgid "Perform conversions of switch initializations."
 msgstr "Lakukan konversi dari kondisional switch."
 
-#: common.opt:2534
+#: common.opt:2538
 #, fuzzy
 #| msgid "Enable SSA dead code elimination optimization on trees"
 msgid "Enable SSA dead code elimination optimization on trees."
 msgstr "Aktifkan optimasi penghapusan kode mati SSA pada pohon"
 
-#: common.opt:2538
+#: common.opt:2542
 #, fuzzy
 #| msgid "Enable dominator optimizations"
 msgid "Enable dominator optimizations."
 msgstr "Aktifkan optimasi dominator"
 
-#: common.opt:2542
+#: common.opt:2546
 #, fuzzy
 #| msgid "Enable loop header copying on trees"
 msgid "Enable tail merging on trees."
 msgstr "Aktifkan penyalinan loop header pada pohon"
 
-#: common.opt:2546
+#: common.opt:2550
 #, fuzzy
 #| msgid "Enable dead store elimination"
 msgid "Enable dead store elimination."
 msgstr "Aktifkan penghapusan dead store"
 
-#: common.opt:2550
+#: common.opt:2554
 #, fuzzy
 #| msgid "Enable copy propagation on trees"
 msgid "Enable forward propagation on trees."
 msgstr "Aktifkan salin propagasi pada pohon"
 
-#: common.opt:2554
+#: common.opt:2558
 #, fuzzy
 #| msgid "Enable Full Redundancy Elimination (FRE) on trees"
 msgid "Enable Full Redundancy Elimination (FRE) on trees."
 msgstr "Aktifkan Penghapusan Redundasi Penuh (FRE) pada pohon"
 
-#: common.opt:2558
+#: common.opt:2562
 #, fuzzy
 #| msgid "Enable SSA-CCP optimization on trees"
 msgid "Enable string length optimizations on trees."
 msgstr "Aktifkan optimasi SSA-CCP pada pohon"
 
-#: common.opt:2562
+#: common.opt:2566
 msgid "Detect paths that trigger erroneous or undefined behavior due to dereferencing a null pointer.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
-#: common.opt:2568
+#: common.opt:2572
 msgid "Detect paths that trigger erroneous or undefined behavior due to a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
-#: common.opt:2575
+#: common.opt:2579
 #, fuzzy
 #| msgid "Enable loop distribution on trees"
 msgid "Enable loop distribution on trees."
 msgstr "Aktifkan loop distribusi pada pohon"
 
-#: common.opt:2579
+#: common.opt:2583
 #, fuzzy
 #| msgid "Enable loop distribution on trees"
 msgid "Enable loop distribution for patterns transformed into a library call."
 msgstr "Aktifkan loop distribusi pada pohon"
 
-#: common.opt:2583
+#: common.opt:2587
 #, fuzzy
 #| msgid "Enable loop invariant motion on trees"
 msgid "Enable loop invariant motion on trees."
 msgstr "Aktifkan loop tidak variant pergerakan pada pohon"
 
-#: common.opt:2591
+#: common.opt:2595
 #, fuzzy
 #| msgid "Create canonical induction variables in loops"
 msgid "Create canonical induction variables in loops."
 msgstr "Buat variabel induksi kanonikal dalam loops"
 
-#: common.opt:2595
+#: common.opt:2599
 #, fuzzy
 #| msgid "Enable loop optimizations on tree level"
 msgid "Enable loop optimizations on tree level."
 msgstr "Aktifkan optimasi loop pada tingkat pohon"
 
-#: common.opt:2599
+#: common.opt:2603
 #, fuzzy
 #| msgid "Enable automatic parallelization of loops"
 msgid "-ftree-parallelize-loops=<number>\tEnable automatic parallelization of loops."
 msgstr "Aktifkan paralelisasi otomatis dari loops"
 
-#: common.opt:2603
+#: common.opt:2607
 #, fuzzy
 #| msgid "Enable conditional moves"
 msgid "Enable hoisting loads from conditional pointers."
 msgstr "Aktifkan perpindahan kondisional"
 
-#: common.opt:2607
+#: common.opt:2611
 #, fuzzy
 #| msgid "Enable SSA-PRE optimization on trees"
 msgid "Enable SSA-PRE optimization on trees."
 msgstr "Aktifkan SSA-PRE optimisasi pada pohon"
 
-#: common.opt:2611
+#: common.opt:2615
 msgid "In SSA-PRE optimization on trees, enable partial-partial redundancy elimination."
 msgstr ""
 
-#: common.opt:2615
+#: common.opt:2619
 #, fuzzy
 #| msgid "Perform interprocedural points-to analysis"
 msgid "Perform function-local points-to analysis on trees."
 msgstr "Lakukan analisa interprosedural titik-ke"
 
-#: common.opt:2619
+#: common.opt:2623
 #, fuzzy
 #| msgid "Enable reassociation on tree level"
 msgid "Enable reassociation on tree level."
 msgstr "Aktifkan reasosiasi pada tingkat pohon"
 
-#: common.opt:2627
+#: common.opt:2631
 #, fuzzy
 #| msgid "Enable SSA code sinking on trees"
 msgid "Enable SSA code sinking on trees."
 msgstr "Aktifkan penenggelaman kode SSA pada pohon"
 
-#: common.opt:2631
+#: common.opt:2635
 msgid "Perform straight-line strength reduction."
 msgstr ""
 
-#: common.opt:2635
+#: common.opt:2639
 #, fuzzy
 #| msgid "Perform scalar replacement of aggregates"
 msgid "Perform scalar replacement of aggregates."
 msgstr "Lakukan penggantian skalar dari kumpulan"
 
-#: common.opt:2639
+#: common.opt:2643
 #, fuzzy
 #| msgid "Replace temporary expressions in the SSA->normal pass"
 msgid "Replace temporary expressions in the SSA->normal pass."
 msgstr "Gantikan ekspresi sementara dalam tahap SSA->normal"
 
-#: common.opt:2643
+#: common.opt:2647
 #, fuzzy
 #| msgid "Perform live range splitting during the SSA->normal pass"
 msgid "Perform live range splitting during the SSA->normal pass."
 msgstr "Lakukan jangkauan hidup pemisahaan selama tahap SSA->normal"
 
-#: common.opt:2647
+#: common.opt:2651
 #, fuzzy
 #| msgid "Perform Value Range Propagation on trees"
 msgid "Perform Value Range Propagation on trees."
 msgstr "Lakukan Propagasi Jangkauan Nilai pada pohon"
 
-#: common.opt:2651
+#: common.opt:2655
 msgid "Split paths leading to loop backedges."
 msgstr ""
 
-#: common.opt:2655
+#: common.opt:2659
 msgid "Assume common declarations may be overridden with ones with a larger trailing array."
 msgstr ""
 
-#: common.opt:2660
+#: common.opt:2664
 #, fuzzy
 #| msgid "Compile whole compilation unit at a time"
 msgid "Compile whole compilation unit at a time."
 msgstr "Kompile seluruh satuan kompilasi di satu waktu"
 
-#: common.opt:2664
+#: common.opt:2668
 #, fuzzy
 #| msgid "Perform loop unrolling when iteration count is known"
 msgid "Perform loop unrolling when iteration count is known."
 msgstr "Lakukan penguraian loop ketika jumlah iterasi diketahui"
 
-#: common.opt:2668
+#: common.opt:2672
 #, fuzzy
 #| msgid "Perform loop unrolling for all loops"
 msgid "Perform loop unrolling for all loops."
 msgstr "Lakukan penguraian loop untuk semua loops"
 
-#: common.opt:2679
+#: common.opt:2683
 #, fuzzy
 #| msgid "Allow optimization for floating-point arithmetic which may change the"
 msgid "Allow optimization for floating-point arithmetic which may change the result of the operation due to rounding."
 msgstr "Ijinkan optimisasi untuk aritmetik titik pecahan dimana mungkin mengubah"
 
-#: common.opt:2684
+#: common.opt:2688
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr "Sama seperti -fassociative-math untuk ekspresi yang memasukan pembagian."
 
-#: common.opt:2692
+#: common.opt:2696
 #, fuzzy
 #| msgid "Allow math optimizations that may violate IEEE or ISO standards"
 msgid "Allow math optimizations that may violate IEEE or ISO standards."
 msgstr "Ijinkan optimisasi matematik yang mungkin melanggar standar  IEEE atau ISO"
 
-#: common.opt:2696
+#: common.opt:2700
 #, fuzzy
 #| msgid "Perform loop unswitching"
 msgid "Perform loop unswitching."
 msgstr "Lakukan loop unswitching"
 
-#: common.opt:2700
+#: common.opt:2704
 #, fuzzy
 #| msgid "Perform loop peeling"
 msgid "Perform loop splitting."
 msgstr "Lakukan loop peeling"
 
-#: common.opt:2704
+#: common.opt:2708
 #, fuzzy
 #| msgid "Just generate unwind tables for exception handling"
 msgid "Just generate unwind tables for exception handling."
 msgstr "Buat tabel unwind untuk penanganan eksepsi"
 
-#: common.opt:2708
+#: common.opt:2712
 msgid "Use the bfd linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2712
+#: common.opt:2716
 msgid "Use the gold linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2724
+#: common.opt:2728
 #, fuzzy
 #| msgid "Perform variable tracking"
 msgid "Perform variable tracking."
 msgstr "Lakukan pelacakan variabel"
 
-#: common.opt:2732
+#: common.opt:2736
 #, fuzzy
 #| msgid "Perform variable tracking"
 msgid "Perform variable tracking by annotating assignments."
 msgstr "Lakukan pelacakan variabel"
 
-#: common.opt:2738
+#: common.opt:2742
 msgid "Toggle -fvar-tracking-assignments."
 msgstr ""
 
-#: common.opt:2746
+#: common.opt:2750
 #, fuzzy
 #| msgid "Perform variable tracking and also tag variables that are uninitialized"
 msgid "Perform variable tracking and also tag variables that are uninitialized."
 msgstr "Lakukan pelacakan variabel dan juga variabel tag yang tidak terinisialisasi"
 
-#: common.opt:2751
+#: common.opt:2755
 #, fuzzy
 #| msgid "Enable loop vectorization on trees"
 msgid "Enable vectorization on trees."
 msgstr "Aktifkan vektorisasi loop pada pohon"
 
-#: common.opt:2759
+#: common.opt:2763
 #, fuzzy
 #| msgid "Enable loop vectorization on trees"
 msgid "Enable loop vectorization on trees."
 msgstr "Aktifkan vektorisasi loop pada pohon"
 
-#: common.opt:2763
+#: common.opt:2767
 #, fuzzy
 #| msgid "Enable loop vectorization on trees"
 msgid "Enable basic block vectorization (SLP) on trees."
 msgstr "Aktifkan vektorisasi loop pada pohon"
 
-#: common.opt:2767
+#: common.opt:2771
 msgid "Specifies the cost model for vectorization. -fvect-cost-model=[unlimited|dynamic|cheap]\tSpecifies the cost model for vectorization."
 msgstr ""
 
-#: common.opt:2772
+#: common.opt:2776
 msgid "-fsimd-cost-model=[unlimited|dynamic|cheap]\tSpecifies the vectorization cost model for code marked with a simd directive."
 msgstr ""
 
-#: common.opt:2775
+#: common.opt:2779
 #, fuzzy, c-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown vectorizer cost model %qs"
 msgstr "mode mesin %qs tidak dikenal"
 
-#: common.opt:2788
+#: common.opt:2792
 #, fuzzy
 #| msgid "Does nothing.  Preserved for backward compatibility."
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr "Tidak melakukan apa-apa. Dijaga untuk kompabilitas versi sebelumnya."
 
-#: common.opt:2796
+#: common.opt:2800
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr "Aktifkan propagasi penyalinan dari informasi skalar-evolusi."
 
-#: common.opt:2806
+#: common.opt:2810
 #, fuzzy
 #| msgid "Add extra commentary to assembler output"
 msgid "Add extra commentary to assembler output."
 msgstr "Tambahkan ekstra komentar ke keluaran perakit"
 
-#: common.opt:2810
+#: common.opt:2814
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility."
 msgstr ""
 
-#: common.opt:2813
+#: common.opt:2817
 #, fuzzy, c-format
 #| msgid "unrecognized visibility value \"%s\""
 msgid "unrecognized visibility value %qs"
 msgstr "nilai visibility \"%s\" tidak dikenal"
 
-#: common.opt:2829
+#: common.opt:2833
 msgid "Validate vtable pointers before using them."
 msgstr ""
 
-#: common.opt:2832
+#: common.opt:2836
 #, fuzzy, c-format
 #| msgid "(near initialization for %qs)"
 msgid "unknown vtable verify initialization priority %qs"
 msgstr "(dekat inisialisasi untuk %qs)"
 
-#: common.opt:2845
+#: common.opt:2849
 msgid "Output vtable verification counters."
 msgstr ""
 
-#: common.opt:2849
+#: common.opt:2853
 msgid "Output vtable verification pointer sets information."
 msgstr ""
 
-#: common.opt:2853
+#: common.opt:2857
 #, fuzzy
 #| msgid "Use expression value profiles in optimizations"
 msgid "Use expression value profiles in optimizations."
 msgstr "Gunakan nilai ekspresi profiles dalam optimisasi"
 
-#: common.opt:2857
+#: common.opt:2861
 #, fuzzy
 #| msgid "Construct webs and split unrelated uses of single variable"
 msgid "Construct webs and split unrelated uses of single variable."
 msgstr "Konstruksi webs dan pisahkan penggunaan tidak berelasi dari variabel tunggal"
 
-#: common.opt:2861
+#: common.opt:2865
 #, fuzzy
 #| msgid "Enable conditional dead code elimination for builtin calls"
 msgid "Enable conditional dead code elimination for builtin calls."
 msgstr "Aktifkan kondisional penghapusan kode mati untuk panggilan bawaan"
 
-#: common.opt:2865
+#: common.opt:2869
 #, fuzzy
 #| msgid "Perform whole program optimizations"
 msgid "Perform whole program optimizations."
 msgstr "Lakukan optimisasi seluruh aplikasi"
 
-#: common.opt:2869
+#: common.opt:2873
 #, fuzzy
 #| msgid "Assume signed arithmetic overflow wraps around"
 msgid "Assume pointer overflow wraps around."
 msgstr "Asumsikan perbaikan signed aritmetik overflow"
 
-#: common.opt:2873
+#: common.opt:2877
 #, fuzzy
 #| msgid "Assume signed arithmetic overflow wraps around"
 msgid "Assume signed arithmetic overflow wraps around."
 msgstr "Asumsikan perbaikan signed aritmetik overflow"
 
-#: common.opt:2877
+#: common.opt:2881
 #, fuzzy
 #| msgid "Put zero initialized data in the bss section"
 msgid "Put zero initialized data in the bss section."
 msgstr "Tempatkan nol data terinisialisasi dalam daerah bss"
 
-#: common.opt:2881
+#: common.opt:2885
 #, fuzzy
 #| msgid "Generate debug information in default format"
 msgid "Generate debug information in default format."
 msgstr "Hasilkan informasi debug dalam format baku"
 
-#: common.opt:2885
+#: common.opt:2889
 msgid "Assume assembler support for (DWARF2+) .loc directives"
 msgstr ""
 
-#: common.opt:2889
+#: common.opt:2893
 msgid "Assume assembler support for view in (DWARF2+) .loc directives"
 msgstr ""
 
-#: common.opt:2892 common.opt:2896 common.opt:2900 common.opt:2904
+#: common.opt:2896 common.opt:2900 common.opt:2904 common.opt:2908
 #, fuzzy, c-format
 #| msgid "switch %qs is no longer supported"
 msgid "switch %qs no longer supported"
 msgstr "pilihan %qs tidak lagi didukung"
 
-#: common.opt:2909
+#: common.opt:2913
 msgid "Record DW_AT_decl_column and DW_AT_call_column in DWARF."
 msgstr ""
 
-#: common.opt:2913
+#: common.opt:2917
 #, fuzzy
 #| msgid "Generate debug information in default format"
 msgid "Generate debug information in default version of DWARF format."
 msgstr "Hasilkan informasi debug dalam format baku"
 
-#: common.opt:2917
+#: common.opt:2921
 #, fuzzy
 #| msgid "Generate debug information in DWARF v2 format"
 msgid "Generate debug information in DWARF v2 (or later) format."
 msgstr "Hasilkan informasi debug dalam formas DWARF v2"
 
-#: common.opt:2921
+#: common.opt:2925
 #, fuzzy
 #| msgid "Generate debug information in default extended format"
 msgid "Generate debug information in default extended format."
 msgstr "Hasilkan informasi debug dalam format baku extended"
 
-#: common.opt:2925
+#: common.opt:2929
 #, fuzzy
 #| msgid "Generate a single exit point for each function"
 msgid "Generate extended entry point information for inlined functions"
 msgstr "Hasilkan sebuah titik keluar tunggal untuk setiap fungsi"
 
-#: common.opt:2929
+#: common.opt:2933
 msgid "Compute locview reset points based on insn length estimates"
 msgstr ""
 
-#: common.opt:2937
+#: common.opt:2941
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:2941
+#: common.opt:2945
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:2945
+#: common.opt:2949
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr ""
 
-#: common.opt:2949
+#: common.opt:2953
 #, fuzzy
 #| msgid "Record gcc command line switches in the object file."
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr "Rekam pilihan baris perintah gcc dalam berkas objek."
 
-#: common.opt:2953
+#: common.opt:2957
 #, fuzzy
 #| msgid "Generate debug information in default format"
 msgid "Generate debug information in separate .dwo files."
 msgstr "Hasilkan informasi debug dalam format baku"
 
-#: common.opt:2957
+#: common.opt:2961
 #, fuzzy
 #| msgid "Generate debug information in STABS format"
 msgid "Generate debug information in STABS format."
 msgstr "Hasilkan informasi debug dalam format STABS"
 
-#: common.opt:2961
+#: common.opt:2965
 #, fuzzy
 #| msgid "Generate debug information in extended STABS format"
 msgid "Generate debug information in extended STABS format."
 msgstr "Hasilkan informasi debug dalam formas STABS extended"
 
-#: common.opt:2965
+#: common.opt:2969
 msgid "Emit progressive recommended breakpoint locations."
 msgstr ""
 
-#: common.opt:2969
+#: common.opt:2973
 msgid "Don't emit DWARF additions beyond selected version."
 msgstr ""
 
-#: common.opt:2973
+#: common.opt:2977
 #, fuzzy
 #| msgid "Generate debug information in VMS format"
 msgid "Toggle debug information generation."
 msgstr "Hasilkan informasi debug dalam format VMS"
 
-#: common.opt:2977
+#: common.opt:2981
 msgid "Augment variable location lists with progressive views."
 msgstr ""
 
-#: common.opt:2984
+#: common.opt:2988
 #, fuzzy
 #| msgid "Generate debug information in VMS format"
 msgid "Generate debug information in VMS format."
 msgstr "Hasilkan informasi debug dalam format VMS"
 
-#: common.opt:2988
+#: common.opt:2992
 #, fuzzy
 #| msgid "Generate debug information in XCOFF format"
 msgid "Generate debug information in XCOFF format."
 msgstr "Hasilkan informasi debug dalam format XCOFF"
 
-#: common.opt:2992
+#: common.opt:2996
 #, fuzzy
 #| msgid "Generate debug information in extended XCOFF format"
 msgid "Generate debug information in extended XCOFF format."
 msgstr "Hasilkan informasi debug dalam format XCOFF extended"
 
-#: common.opt:3010
+#: common.opt:3014
 #, fuzzy
 #| msgid "Generate isel instructions"
 msgid "Generate compressed debug sections."
 msgstr "Hasilkan instruksi isel"
 
-#: common.opt:3014
+#: common.opt:3018
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>."
 msgstr ""
 
-#: common.opt:3021
+#: common.opt:3025
 #, fuzzy
 #| msgid "-imultilib <dir> Set <dir> to be the multilib include subdirectory"
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory."
 msgstr "-multilib <dir> Set <dir> untuk menjadi multilib inlude subdirektori"
 
-#: common.opt:3025
+#: common.opt:3029
 #, fuzzy
 #| msgid "-imultilib <dir> Set <dir> to be the multilib include subdirectory"
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory."
 msgstr "-multilib <dir> Set <dir> untuk menjadi multilib inlude subdirektori"
 
-#: common.opt:3047
+#: common.opt:3051
 #, fuzzy
 #| msgid "Place output into <file>"
 msgid "-o <file>\tPlace output into <file>."
 msgstr "Tempatkan keluaran kedalam <berkas>"
 
-#: common.opt:3051
+#: common.opt:3055
 #, fuzzy
 #| msgid "Enable function profiling"
 msgid "Enable function profiling."
 msgstr "Aktifkan profiling fungsi"
 
-#: common.opt:3061
+#: common.opt:3065
 #, fuzzy
 #| msgid "Like -pedantic but issue them as errors"
 msgid "Like -pedantic but issue them as errors."
 msgstr "Seperti -pedantic tetapi menisukannya sebagai errors"
 
-#: common.opt:3101
+#: common.opt:3105
 #, fuzzy
 #| msgid "Do not display functions compiled or elapsed time"
 msgid "Do not display functions compiled or elapsed time."
 msgstr "Jangan tampilkan fungsi yang dikompile atau waktu yang sudah lewat"
 
-#: common.opt:3133
+#: common.opt:3137
 #, fuzzy
 #| msgid "Enable verbose output"
 msgid "Enable verbose output."
 msgstr "Aktifkan keluaran verbose"
 
-#: common.opt:3137
+#: common.opt:3141
 #, fuzzy
 #| msgid "Display the compiler's version"
 msgid "Display the compiler's version."
 msgstr "Tampilkan versi dari kompiler"
 
-#: common.opt:3141
+#: common.opt:3145
 #, fuzzy
 #| msgid "Suppress warnings"
 msgid "Suppress warnings."
 msgstr "Tekan peringatan"
 
-#: common.opt:3151
+#: common.opt:3155
 #, fuzzy
 #| msgid "Create a shared library"
 msgid "Create a shared library."
 msgstr "Buat sebuah perpustakaan terbagi"
 
-#: common.opt:3196
+#: common.opt:3200
 #, fuzzy
 #| msgid "Create a position independent executable"
 msgid "Don't create a dynamically linked position independent executable."
 msgstr "Buat sebuah aplikasi bebas posisi"
 
-#: common.opt:3200
+#: common.opt:3204
 #, fuzzy
 #| msgid "Create a position independent executable"
 msgid "Create a dynamically linked position independent executable."
 msgstr "Buat sebuah aplikasi bebas posisi"
 
-#: common.opt:3204
+#: common.opt:3208
 #, fuzzy
 #| msgid "Create a position independent executable"
 msgid "Create a static position independent executable."
 msgstr "Buat sebuah aplikasi bebas posisi"
 
-#: common.opt:3211
+#: common.opt:3215
 msgid "Use caller save register across calls if possible."
 msgstr ""
 
-#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:598 cp/cvt.c:1308
+#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:599 cp/cvt.c:1308
 #: cp/cvt.c:1561
 #, gcc-internal-format
 msgid "value computed is not used"
@@ -19706,7 +19707,7 @@
 msgstr "diduga bukan tuple"
 
 #: go/gofrontend/expressions.cc:4331 c/c-parser.c:13477 c/c-parser.c:13484
-#: cp/parser.c:33264 cp/parser.c:33271
+#: cp/parser.c:33261 cp/parser.c:33268
 #, fuzzy, gcc-internal-format
 #| msgid "Expected integer"
 msgid "expected integer"
@@ -20247,8 +20248,8 @@
 msgid "ignoring attribute %qE because it conflicts with attribute %qs"
 msgstr "%qE atribut konflik dengan atribut %s"
 
-#: attribs.c:449 c-family/c-attribs.c:1894 cp/decl.c:13690 cp/friend.c:302
-#: cp/tree.c:4559
+#: attribs.c:449 c-family/c-attribs.c:1905 cp/decl.c:13714 cp/friend.c:302
+#: cp/tree.c:4607
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D here"
 msgid "previous declaration here"
@@ -20255,7 +20256,7 @@
 msgstr "deklarasi sebelumnya %q+#D disini"
 
 #. Warn about and ignore all others for now, but store them.
-#: attribs.c:564 c-family/c-attribs.c:2717 objc/objc-act.c:4963
+#: attribs.c:564 c-family/c-attribs.c:2728 objc/objc-act.c:4963
 #: objc/objc-act.c:6932 objc/objc-act.c:8119 objc/objc-act.c:8170
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute directive ignored"
@@ -20277,18 +20278,18 @@
 #. This is a c++11 attribute that appertains to a
 #. type-specifier, outside of the definition of, a class
 #. type.  Ignore it.
-#: attribs.c:590 cp/decl.c:10999
+#: attribs.c:590 cp/decl.c:11023
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored"
 msgid "attribute ignored"
 msgstr "%qE atribut diabaikan"
 
-#: attribs.c:592 cp/decl.c:11000
+#: attribs.c:592 cp/decl.c:11024
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
 
-#: attribs.c:610 c-family/c-attribs.c:3219
+#: attribs.c:610 c-family/c-attribs.c:3230
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute does not apply to types"
 msgid "%qE attribute does not apply to types"
@@ -20306,40 +20307,40 @@
 msgstr "tipe atribut diabaikan setelah tipe telah didefinisikan"
 
 #: attribs.c:691 attribs.c:1622 attribs.c:1632 attribs.c:1642
-#: c-family/c-attribs.c:540 c-family/c-attribs.c:559 c-family/c-attribs.c:577
-#: c-family/c-attribs.c:607 c-family/c-attribs.c:628 c-family/c-attribs.c:649
-#: c-family/c-attribs.c:690 c-family/c-attribs.c:717 c-family/c-attribs.c:733
-#: c-family/c-attribs.c:750 c-family/c-attribs.c:766 c-family/c-attribs.c:792
-#: c-family/c-attribs.c:807 c-family/c-attribs.c:835 c-family/c-attribs.c:852
-#: c-family/c-attribs.c:870 c-family/c-attribs.c:893 c-family/c-attribs.c:931
-#: c-family/c-attribs.c:954 c-family/c-attribs.c:971 c-family/c-attribs.c:1000
-#: c-family/c-attribs.c:1021 c-family/c-attribs.c:1042
-#: c-family/c-attribs.c:1069 c-family/c-attribs.c:1099
-#: c-family/c-attribs.c:1136 c-family/c-attribs.c:1189
-#: c-family/c-attribs.c:1255 c-family/c-attribs.c:1313
-#: c-family/c-attribs.c:1402 c-family/c-attribs.c:1432
-#: c-family/c-attribs.c:1483 c-family/c-attribs.c:1998
-#: c-family/c-attribs.c:2035 c-family/c-attribs.c:2096
-#: c-family/c-attribs.c:2152 c-family/c-attribs.c:2230
-#: c-family/c-attribs.c:2312 c-family/c-attribs.c:2371
-#: c-family/c-attribs.c:2390 c-family/c-attribs.c:2498
-#: c-family/c-attribs.c:2514 c-family/c-attribs.c:2530
-#: c-family/c-attribs.c:2551 c-family/c-attribs.c:2608
-#: c-family/c-attribs.c:2635 c-family/c-attribs.c:2690
-#: c-family/c-attribs.c:2870 c-family/c-attribs.c:2891
-#: c-family/c-attribs.c:3004 c-family/c-attribs.c:3031
-#: c-family/c-attribs.c:3221 c-family/c-attribs.c:3239
-#: c-family/c-attribs.c:3262 c-family/c-attribs.c:3301
-#: c-family/c-attribs.c:3383 c-family/c-attribs.c:3439
-#: c-family/c-attribs.c:3455 c-family/c-attribs.c:3549
-#: c-family/c-common.c:5600 config/darwin.c:2072 config/arm/arm.c:6868
+#: c-family/c-attribs.c:547 c-family/c-attribs.c:566 c-family/c-attribs.c:584
+#: c-family/c-attribs.c:614 c-family/c-attribs.c:635 c-family/c-attribs.c:656
+#: c-family/c-attribs.c:697 c-family/c-attribs.c:728 c-family/c-attribs.c:744
+#: c-family/c-attribs.c:761 c-family/c-attribs.c:777 c-family/c-attribs.c:803
+#: c-family/c-attribs.c:818 c-family/c-attribs.c:846 c-family/c-attribs.c:863
+#: c-family/c-attribs.c:881 c-family/c-attribs.c:904 c-family/c-attribs.c:942
+#: c-family/c-attribs.c:965 c-family/c-attribs.c:982 c-family/c-attribs.c:1011
+#: c-family/c-attribs.c:1032 c-family/c-attribs.c:1053
+#: c-family/c-attribs.c:1080 c-family/c-attribs.c:1110
+#: c-family/c-attribs.c:1147 c-family/c-attribs.c:1200
+#: c-family/c-attribs.c:1266 c-family/c-attribs.c:1324
+#: c-family/c-attribs.c:1413 c-family/c-attribs.c:1443
+#: c-family/c-attribs.c:1494 c-family/c-attribs.c:2009
+#: c-family/c-attribs.c:2046 c-family/c-attribs.c:2107
+#: c-family/c-attribs.c:2163 c-family/c-attribs.c:2241
+#: c-family/c-attribs.c:2323 c-family/c-attribs.c:2382
+#: c-family/c-attribs.c:2401 c-family/c-attribs.c:2509
+#: c-family/c-attribs.c:2525 c-family/c-attribs.c:2541
+#: c-family/c-attribs.c:2562 c-family/c-attribs.c:2619
+#: c-family/c-attribs.c:2646 c-family/c-attribs.c:2701
+#: c-family/c-attribs.c:2881 c-family/c-attribs.c:2902
+#: c-family/c-attribs.c:3015 c-family/c-attribs.c:3042
+#: c-family/c-attribs.c:3232 c-family/c-attribs.c:3250
+#: c-family/c-attribs.c:3273 c-family/c-attribs.c:3312
+#: c-family/c-attribs.c:3394 c-family/c-attribs.c:3450
+#: c-family/c-attribs.c:3466 c-family/c-attribs.c:3560
+#: c-family/c-common.c:5598 config/darwin.c:2072 config/arm/arm.c:6868
 #: config/arm/arm.c:6896 config/arm/arm.c:6913 config/avr/avr.c:9698
-#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6497
-#: config/i386/i386.c:41520 config/ia64/ia64.c:788
-#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33056
-#: config/spu/spu.c:3743 ada/gcc-interface/utils.c:6244
-#: ada/gcc-interface/utils.c:6261 ada/gcc-interface/utils.c:6277
-#: ada/gcc-interface/utils.c:6303 brig/brig-lang.c:476 lto/lto-lang.c:283
+#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6500
+#: config/i386/i386.c:41514 config/ia64/ia64.c:788
+#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33112
+#: config/spu/spu.c:3743 ada/gcc-interface/utils.c:6249
+#: ada/gcc-interface/utils.c:6266 ada/gcc-interface/utils.c:6282
+#: ada/gcc-interface/utils.c:6308 brig/brig-lang.c:476 lto/lto-lang.c:283
 #, gcc-internal-format
 msgid "%qE attribute ignored"
 msgstr "%qE atribut diabaikan"
@@ -20727,96 +20728,112 @@
 msgid "%Kattempt to free a non-heap object"
 msgstr "%Kmencoba membebaskan sebuah objek bukan heap"
 
-#: calls.c:1434
+#: calls.c:1291 file-prefix-map.c:50
 #, fuzzy, gcc-internal-format
+#| msgid "invalid type argument of %qs"
+msgid "invalid argument %qs to %qs"
+msgstr "tipe argumen tidak valid dari %qs"
+
+#: calls.c:1452
+#, fuzzy, gcc-internal-format
 #| msgid "Argument of %s function at %L is negative"
 msgid "%Kargument %i value %qE is negative"
 msgstr "Argumen dari %s fungsi di %L adalah negatif"
 
-#: calls.c:1452
+#: calls.c:1470
 #, fuzzy, gcc-internal-format
 #| msgid "Second argument MOD at %L is zero"
 msgid "%Kargument %i value is zero"
 msgstr "Argumen kedua MOD di %L adalah nol"
 
-#: calls.c:1469
+#: calls.c:1487
 #, gcc-internal-format
 msgid "%Kargument %i value %qE exceeds maximum object size %E"
 msgstr ""
 
-#: calls.c:1483
+#: calls.c:1501
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of %s function at %L is negative"
 msgid "%Kargument %i range [%E, %E] is negative"
 msgstr "Argumen dari %s fungsi di %L adalah negatif"
 
-#: calls.c:1490
+#: calls.c:1508
 #, gcc-internal-format
 msgid "%Kargument %i range [%E, %E] exceeds maximum object size %E"
 msgstr ""
 
-#: calls.c:1520
+#: calls.c:1538
 #, gcc-internal-format
 msgid "%Kproduct %<%E * %E%> of arguments %i and %i exceeds %<SIZE_MAX%>"
 msgstr ""
 
-#: calls.c:1526
+#: calls.c:1544
 #, gcc-internal-format
 msgid "%Kproduct %<%E * %E%> of arguments %i and %i exceeds maximum object size %E"
 msgstr ""
 
-#: calls.c:1537 calls.c:1540
+#: calls.c:1555 calls.c:1558
 #, gcc-internal-format
 msgid "argument %i in the range [%E, %E]"
 msgstr ""
 
-#: calls.c:1551
+#: calls.c:1569
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "in a call to built-in allocation function %qD"
 msgstr "panggilan ke bukan-fungsi %qD"
 
-#: calls.c:1554
+#: calls.c:1572
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D declared but never defined"
 msgid "in a call to allocation function %qD declared here"
 msgstr "fungsi inline %q+D dideklarasikan tetapi tidak pernah didefinisikan"
 
-#: calls.c:1711
+#: calls.c:1835
 #, gcc-internal-format
-msgid "%qD argument %i declared attribute %<nonstring%> is smaller than the specified bound %E"
+msgid "%qD argument %i declared attribute %<nonstring%> is smaller than the specified bound %wu"
 msgstr ""
 
-#: calls.c:1716
+#: calls.c:1841
+#, gcc-internal-format
+msgid "%qD argument %i declared attribute %<nonstring%> is smaller than the specified bound [%E, %E]"
+msgstr ""
+
+#: calls.c:1847
+#, gcc-internal-format
+msgid "%qD argument %i declared attribute %<nonstring%> may be smaller than the specified bound [%E, %E]"
+msgstr ""
+
+#: calls.c:1857
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared with attribute noinline"
 msgid "%qD argument %i declared attribute %<nonstring%>"
 msgstr "fungsi %q+D redeklarasi dengan atribut noinline"
 
-#: calls.c:1721
+#: calls.c:1862
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "argument %qD declared here"
 msgstr "%q+D dideklarasikan disini"
 
-#: calls.c:1735
+#: calls.c:1876
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot find class %qs"
 msgid "cannot tail-call: %s"
 msgstr "tidak dapat menemukan class %qs"
 
-#: calls.c:3365
+#: calls.c:3506
 #, gcc-internal-format
 msgid "function call has aggregate value"
 msgstr "pemanggilan fungsi memiliki nilai bersama"
 
-#: calls.c:4059
+#: calls.c:4200
 #, fuzzy, gcc-internal-format
 #| msgid "missing argument to \"%s\""
 msgid "passing too large argument on stack"
 msgstr "hilang argumen ke \"%s\""
 
-#: cfgexpand.c:1665 function.c:1002 varasm.c:2231
+#: cfgexpand.c:1665 function.c:1002 varasm.c:2242
 #, gcc-internal-format
 msgid "size of variable %q+D is too large"
 msgstr "ukuran dari variabel %q+D terlalu besar"
@@ -21426,244 +21443,244 @@
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr "jumlah dari catatan bb dalam rantai instruksi (%d) != n_basic_blocks (%d)"
 
-#: cgraph.c:3051
+#: cgraph.c:3056
 #, fuzzy, gcc-internal-format
 #| msgid "caller edge count is negative"
 msgid "caller edge count invalid"
 msgstr "jumlah ujung pemanggil negatif"
 
-#: cgraph.c:3135
+#: cgraph.c:3140
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr "field tambahan diset untuk ujung  %s->%s"
 
-#: cgraph.c:3142
+#: cgraph.c:3147
 #, gcc-internal-format
 msgid "cgraph count invalid"
 msgstr ""
 
-#: cgraph.c:3147
+#: cgraph.c:3152
 #, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr ""
 
-#: cgraph.c:3152
+#: cgraph.c:3157
 #, fuzzy, gcc-internal-format
 #| msgid "Assume symbols might be invalid"
 msgid "local symbols must be defined"
 msgstr "Asumsikan simbol mungkin tidak valid"
 
-#: cgraph.c:3157
+#: cgraph.c:3162
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr ""
 
-#: cgraph.c:3162
+#: cgraph.c:3167
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr ""
 
-#: cgraph.c:3167
+#: cgraph.c:3172
 #, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr ""
 
-#: cgraph.c:3174
+#: cgraph.c:3179
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "aux field set for edge %s->%s"
 msgid "aux field set for indirect edge from %s"
 msgstr "field tambahan diset untuk ujung  %s->%s"
 
-#: cgraph.c:3181
+#: cgraph.c:3186
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr ""
 
-#: cgraph.c:3196
+#: cgraph.c:3201
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr ""
 
-#: cgraph.c:3206
+#: cgraph.c:3211
 #, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr "penunjuk inlined_to salah"
 
-#: cgraph.c:3211
+#: cgraph.c:3216
 #, gcc-internal-format
 msgid "multiple inline callers"
 msgstr "multiple pemanggil inline"
 
-#: cgraph.c:3218
+#: cgraph.c:3223
 #, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr "penunjuk inlined_to diset untuk pemanggil bukan inline"
 
-#: cgraph.c:3239
+#: cgraph.c:3244
 #, fuzzy, gcc-internal-format
 #| msgid "incoming edge count does not match number of PHI arguments"
 msgid "caller edge count does not match BB count"
 msgstr "jumlah ujung masukan tidak cocok dengan jumlah dari argumen PHI"
 
-#: cgraph.c:3261
+#: cgraph.c:3266
 #, fuzzy, gcc-internal-format
 #| msgid "incoming edge count does not match number of PHI arguments"
 msgid "indirect call count does not match BB count"
 msgstr "jumlah ujung masukan tidak cocok dengan jumlah dari argumen PHI"
 
-#: cgraph.c:3272
+#: cgraph.c:3277
 #, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr "penunjuk inlined_to diset tetapi tidak ada predecessor ditemukan"
 
-#: cgraph.c:3277
+#: cgraph.c:3282
 #, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr "penunjuk inlined_to mereferensikan ke dirinya sendiri"
 
-#: cgraph.c:3289
+#: cgraph.c:3294
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr ""
 
-#: cgraph.c:3301
+#: cgraph.c:3306
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr ""
 
-#: cgraph.c:3307
+#: cgraph.c:3312
 #, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr ""
 
-#: cgraph.c:3312
+#: cgraph.c:3317
 #, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr ""
 
-#: cgraph.c:3317
+#: cgraph.c:3322
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr ""
 
-#: cgraph.c:3329
+#: cgraph.c:3334
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr ""
 
-#: cgraph.c:3337
+#: cgraph.c:3342
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr ""
 
-#: cgraph.c:3342
+#: cgraph.c:3347
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr ""
 
-#: cgraph.c:3349
+#: cgraph.c:3354
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr ""
 
-#: cgraph.c:3358
+#: cgraph.c:3363
 #, gcc-internal-format
 msgid "Instrumentation clone does not reference original node"
 msgstr ""
 
-#: cgraph.c:3365
+#: cgraph.c:3370
 #, gcc-internal-format
 msgid "Not instrumented node has non-NULL original declaration"
 msgstr ""
 
-#: cgraph.c:3375
+#: cgraph.c:3380
 #, gcc-internal-format
 msgid "Instrumented node has wrong original declaration"
 msgstr ""
 
-#: cgraph.c:3393
+#: cgraph.c:3398
 #, gcc-internal-format
 msgid "Node has more than one chkp reference"
 msgstr ""
 
-#: cgraph.c:3398
+#: cgraph.c:3403
 #, gcc-internal-format
 msgid "Wrong node is referenced with chkp reference"
 msgstr ""
 
-#: cgraph.c:3406
+#: cgraph.c:3411
 #, gcc-internal-format
 msgid "Analyzed node has no reference to instrumented version"
 msgstr ""
 
-#: cgraph.c:3420
+#: cgraph.c:3425
 #, gcc-internal-format
 msgid "Alias chain for instrumented node is broken"
 msgstr ""
 
-#: cgraph.c:3429
+#: cgraph.c:3434
 #, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3434
+#: cgraph.c:3439
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3439
+#: cgraph.c:3444
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr ""
 
-#: cgraph.c:3445
+#: cgraph.c:3450
 #, gcc-internal-format
 msgid "Instrumentation thunk has wrong edge callee"
 msgstr ""
 
-#: cgraph.c:3481
+#: cgraph.c:3486
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr "shared call_stmt:"
 
-#: cgraph.c:3489
+#: cgraph.c:3494
 #, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr "titik ujung ke deklarasi salah:"
 
-#: cgraph.c:3498
+#: cgraph.c:3503
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr ""
 
-#: cgraph.c:3508
+#: cgraph.c:3513
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr "hilang ujung callgraph untuk pemanggilan stmt:"
 
-#: cgraph.c:3518
+#: cgraph.c:3523
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "reference to dead statement"
 msgstr "diduga pernyataan"
 
-#: cgraph.c:3531
+#: cgraph.c:3536
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr "ujung %s->%s tidak memiliki korespondensi call_stmt"
 
-#: cgraph.c:3543
+#: cgraph.c:3548
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "edge %s->%s has no corresponding call_stmt"
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr "ujung %s->%s tidak memiliki korespondensi call_stmt"
 
-#: cgraph.c:3554
+#: cgraph.c:3559
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr "verify_cgraph_node gagal"
 
-#: cgraph.c:3661 varpool.c:306
+#: cgraph.c:3666 varpool.c:306
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument to '-%s' is missing"
 msgid "%s: section %s is missing"
@@ -21700,12 +21717,12 @@
 msgstr "%qE atribut diabaikan karena %qT telah didefinisikan"
 
 #. include_self=
-#: cgraphunit.c:981 c/c-decl.c:11282
+#: cgraphunit.c:981 c/c-decl.c:11302
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F digunakan tetapi tidak pernah didefinisikan"
 
-#: cgraphunit.c:983 c/c-decl.c:11291
+#: cgraphunit.c:983 c/c-decl.c:11311
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "%q+F dideklarasikan %<static%> tetapi tidak pernah didefinisikan"
@@ -21831,13 +21848,13 @@
 msgid "cannot find '%s'"
 msgstr "tidak dapat menemukan '%s'"
 
-#: collect-utils.c:183 collect2.c:2361 collect2.c:2560 gcc.c:3080 gcc.c:6856
+#: collect-utils.c:183 collect2.c:2387 collect2.c:2586 gcc.c:3080 gcc.c:6856
 #, fuzzy, gcc-internal-format
 #| msgid "pex_init failed"
 msgid "pex_init failed: %m"
 msgstr "pex_init gagal"
 
-#: collect-utils.c:192 collect2.c:2370 collect2.c:2568 gcc.c:8498
+#: collect-utils.c:192 collect2.c:2396 collect2.c:2594 gcc.c:8498
 #, fuzzy, gcc-internal-format
 #| msgid "%s: %s"
 msgid "%s: %m"
@@ -21848,7 +21865,7 @@
 msgid "COLLECT_LTO_WRAPPER must be set"
 msgstr ""
 
-#: collect2.c:966 gcc.c:7382 lto-wrapper.c:1666
+#: collect2.c:969 gcc.c:7382 lto-wrapper.c:1692
 #: config/i386/intelmic-mkoffload.c:556 config/nvptx/mkoffload.c:405
 #, fuzzy, gcc-internal-format
 #| msgid "pex_init failed"
@@ -21855,92 +21872,92 @@
 msgid "atexit failed"
 msgstr "pex_init gagal"
 
-#: collect2.c:1064
+#: collect2.c:1067
 #, gcc-internal-format
 msgid "no arguments"
 msgstr "tidak ada argumen"
 
-#: collect2.c:1303 opts.c:904
+#: collect2.c:1311 opts.c:904
 #, fuzzy, gcc-internal-format
 #| msgid "-m%s not supported in this configuration"
 msgid "LTO support has not been enabled in this configuration"
 msgstr "-m%s tidak didukung dalam konfigurasi ini"
 
-#: collect2.c:1344
+#: collect2.c:1352
 #, gcc-internal-format
 msgid "can't open %s: %m"
 msgstr "tidak dapat membuka %s: %m"
 
-#: collect2.c:1450
+#: collect2.c:1472
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown demangling style '%s'"
 msgstr "gaya demangling '%s' tidak diketahui"
 
-#: collect2.c:1546 collect2.c:1729 collect2.c:1769
+#: collect2.c:1574 collect2.c:1757 collect2.c:1797
 #, fuzzy, gcc-internal-format
 #| msgid "fopen %s"
 msgid "fopen %s: %m"
 msgstr "fopen %s"
 
-#: collect2.c:1549 collect2.c:1734 collect2.c:1772
+#: collect2.c:1577 collect2.c:1762 collect2.c:1800
 #, fuzzy, gcc-internal-format
 #| msgid "fclose %s"
 msgid "fclose %s: %m"
 msgstr "fclose %s"
 
-#: collect2.c:2335
+#: collect2.c:2361
 #, gcc-internal-format
 msgid "cannot find 'nm'"
 msgstr "tidak dapat menemukan 'nm'"
 
-#: collect2.c:2383
+#: collect2.c:2409
 #, fuzzy, gcc-internal-format
 #| msgid "can't open nm output"
 msgid "can't open nm output: %m"
 msgstr "tidak dapat membuka keluaran nm"
 
-#: collect2.c:2467
+#: collect2.c:2493
 #, gcc-internal-format, gfc-internal-format
 msgid "init function found in object %s"
 msgstr "fungsi init ditemukan dalam objek %s"
 
-#: collect2.c:2478
+#: collect2.c:2504
 #, gcc-internal-format, gfc-internal-format
 msgid "fini function found in object %s"
 msgstr "fungsi fini ditemukan dalam objek %s"
 
-#: collect2.c:2535
+#: collect2.c:2561
 #, gcc-internal-format
 msgid "cannot find 'ldd'"
 msgstr "tidak dapat menemunkan 'ldd'"
 
-#: collect2.c:2581
+#: collect2.c:2607
 #, fuzzy, gcc-internal-format
 #| msgid "can't open ldd output"
 msgid "can't open ldd output: %m"
 msgstr "tidak dapat membukan keluaran ldd"
 
-#: collect2.c:2599
+#: collect2.c:2625
 #, gcc-internal-format, gfc-internal-format
 msgid "dynamic dependency %s not found"
 msgstr "dependensi dinamis %s tidak ditemukan"
 
-#: collect2.c:2611
+#: collect2.c:2637
 #, gcc-internal-format, gfc-internal-format
 msgid "unable to open dynamic dependency '%s'"
 msgstr "tidak dapat membuka dependensi dinamis '%s'"
 
-#: collect2.c:2765
+#: collect2.c:2791
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: not a COFF file"
 msgstr "%s: bukan sebuah berkas COFF"
 
-#: collect2.c:2930
+#: collect2.c:2961
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: cannot open as COFF file"
 msgstr "%s: tidak dapat membuka sebagai berkas COFF"
 
-#: collect2.c:2989
+#: collect2.c:3020
 #, gcc-internal-format, gfc-internal-format
 msgid "library lib%s not found"
 msgstr "perpustakaan lib%s tidak ditemukan"
@@ -22161,12 +22178,12 @@
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr ""
 
-#: dwarf2out.c:10901
+#: dwarf2out.c:10909
 #, gcc-internal-format
 msgid "-gdwarf-6 is output as version 5 with incompatibilities"
 msgstr ""
 
-#: dwarf2out.c:14415
+#: dwarf2out.c:14423
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
@@ -22290,12 +22307,6 @@
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr "%K panggilan ke %qs dideklarasikan dengan atribut peringatan: %s"
 
-#: file-prefix-map.c:50
-#, fuzzy, gcc-internal-format
-#| msgid "invalid type argument of %qs"
-msgid "invalid argument %qs to %qs"
-msgstr "tipe argumen tidak valid dari %qs"
-
 #: final.c:1868
 #, gcc-internal-format
 msgid "the frame size of %wd bytes is larger than %wd bytes"
@@ -22318,42 +22329,42 @@
 msgid "large fixed-point constant implicitly truncated to fixed-point type"
 msgstr "konstanta titik-tetap besar secara implisit dipotong ke tipe titik-tetap"
 
-#: fold-const.c:4151 fold-const.c:4161
+#: fold-const.c:4157 fold-const.c:4167
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d due to width of bit-field"
 msgstr "perbandingan selalu %d karena lebar dari bit-field"
 
-#: fold-const.c:5478 tree-ssa-reassoc.c:2374 tree-ssa-reassoc.c:3214
+#: fold-const.c:5484 tree-ssa-reassoc.c:2379 tree-ssa-reassoc.c:3219
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr "diasumsikan signed overflow tidak terjadi ketika menyederhanakan pemeriksaan jangkauan"
 
-#: fold-const.c:5928 fold-const.c:5942
+#: fold-const.c:5934 fold-const.c:5948
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr "perbandingan selalu %d"
 
-#: fold-const.c:6085
+#: fold-const.c:6091
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr "%<or%> dari pemeriksaan tidak cocok tidak-sama selalu 1"
 
-#: fold-const.c:6090
+#: fold-const.c:6096
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr "%<and%> dari mutually eksklusif test-sama selalu 0"
 
-#: fold-const.c:8310
+#: fold-const.c:8316
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr "diasumsikan signed overflow tidak terjadi ketika mereduksi konstanta dalam perbandingan"
 
-#: fold-const.c:8710
+#: fold-const.c:8716
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr "diasumsikan signed overflow tidak terjadi ketika mengkombinasi konstan diantar sebuah perbandingan"
 
-#: fold-const.c:12063
+#: fold-const.c:12069
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr "pemeriksaan fold: pohon asal diubah oleh fold"
@@ -22364,7 +22375,7 @@
 msgid "total size of local objects too large"
 msgstr "%J ukuran total dari objek lokal terlalu besar"
 
-#: function.c:1776 gimplify.c:6270
+#: function.c:1776 gimplify.c:6273
 #, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr "batasan tidak memungkinkan dalam %<asm%>"
@@ -22699,7 +22710,7 @@
 msgid "%s: linker input file unused because linking not done"
 msgstr "%s: berkas masukan penghubung tidak digunakan karena proses penyambungan belum selesai"
 
-#: gcc.c:8420 c-family/c-opts.c:770
+#: gcc.c:8420 c-family/c-opts.c:768
 #, gcc-internal-format
 msgid "cannot use %<-%> as input filename for a precompiled header"
 msgstr ""
@@ -22961,7 +22972,7 @@
 msgid "%G%qD destination unchanged after copying no bytes"
 msgstr ""
 
-#: gimple-fold.c:2052 tree-ssa-strlen.c:2050
+#: gimple-fold.c:2052 tree-ssa-strlen.c:2074
 msgid "%G%qD specified bound %E equals destination size"
 msgstr ""
 
@@ -22985,12 +22996,12 @@
 msgid "null pointer dereference"
 msgstr "penunjuk circular delegasi terdeteksi"
 
-#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12451
-#: tree.c:12488 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10147
-#: c/c-typeck.c:10164 c/gimple-parser.c:1616 c/gimple-parser.c:1624
+#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12455
+#: tree.c:12492 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10152
+#: c/c-typeck.c:10169 c/gimple-parser.c:1616 c/gimple-parser.c:1624
 #: cp/call.c:6493 cp/call.c:8098 cp/constexpr.c:820 cp/constexpr.c:2309
-#: cp/cvt.c:1015 cp/cvt.c:1042 cp/decl.c:7334 cp/decl2.c:5256 cp/pt.c:8334
-#: cp/semantics.c:1836 cp/semantics.c:4053 cp/typeck.c:1700 cp/typeck.c:1895
+#: cp/cvt.c:1015 cp/cvt.c:1042 cp/decl.c:7355 cp/decl2.c:5246 cp/pt.c:8348
+#: cp/semantics.c:1836 cp/semantics.c:4056 cp/typeck.c:1700 cp/typeck.c:1895
 #: cp/typeck.c:3837
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
@@ -23002,27 +23013,27 @@
 msgid "nonnull argument %qD compared to NULL"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2517 gimple-ssa-sprintf.c:2637
+#: gimple-ssa-sprintf.c:2555 gimple-ssa-sprintf.c:2675
 #, gcc-internal-format
 msgid "%qE output may be truncated before the last format character"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2519 gimple-ssa-sprintf.c:2639
+#: gimple-ssa-sprintf.c:2557 gimple-ssa-sprintf.c:2677
 #, gcc-internal-format
 msgid "%qE output truncated before the last format character"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2522 gimple-ssa-sprintf.c:2642
+#: gimple-ssa-sprintf.c:2560 gimple-ssa-sprintf.c:2680
 #, gcc-internal-format
 msgid "%qE may write a terminating nul past the end of the destination"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2524 gimple-ssa-sprintf.c:2644
+#: gimple-ssa-sprintf.c:2562 gimple-ssa-sprintf.c:2682
 #, gcc-internal-format
 msgid "%qE writing a terminating nul past the end of the destination"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2534
+#: gimple-ssa-sprintf.c:2572
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size %wu"
@@ -23029,7 +23040,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.c:2541
+#: gimple-ssa-sprintf.c:2579
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size %wu"
@@ -23036,7 +23047,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.c:2548
+#: gimple-ssa-sprintf.c:2586
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size %wu"
@@ -23043,67 +23054,67 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.c:2559
+#: gimple-ssa-sprintf.c:2597
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2562
+#: gimple-ssa-sprintf.c:2600
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2564
+#: gimple-ssa-sprintf.c:2602
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2576
+#: gimple-ssa-sprintf.c:2614
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2579
+#: gimple-ssa-sprintf.c:2617
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2582
+#: gimple-ssa-sprintf.c:2620
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2591
+#: gimple-ssa-sprintf.c:2629
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2594
+#: gimple-ssa-sprintf.c:2632
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2597
+#: gimple-ssa-sprintf.c:2635
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2606
+#: gimple-ssa-sprintf.c:2644
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2609
+#: gimple-ssa-sprintf.c:2647
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2611
+#: gimple-ssa-sprintf.c:2649
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2653
+#: gimple-ssa-sprintf.c:2691
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size between %wu and %wu"
@@ -23110,7 +23121,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.c:2660
+#: gimple-ssa-sprintf.c:2698
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size between %wu and %wu"
@@ -23117,7 +23128,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.c:2668
+#: gimple-ssa-sprintf.c:2706
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size between %wu and %wu"
@@ -23124,102 +23135,102 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.c:2680
+#: gimple-ssa-sprintf.c:2718
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2683
+#: gimple-ssa-sprintf.c:2721
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2686
+#: gimple-ssa-sprintf.c:2724
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2699
+#: gimple-ssa-sprintf.c:2737
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2702
+#: gimple-ssa-sprintf.c:2740
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2705
+#: gimple-ssa-sprintf.c:2743
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2715
+#: gimple-ssa-sprintf.c:2753
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2718
+#: gimple-ssa-sprintf.c:2756
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2721
+#: gimple-ssa-sprintf.c:2759
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2730
+#: gimple-ssa-sprintf.c:2768
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2733
+#: gimple-ssa-sprintf.c:2771
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2736
+#: gimple-ssa-sprintf.c:2774
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2825
+#: gimple-ssa-sprintf.c:2863
 #, gcc-internal-format
 msgid "%<%.*s%> directive argument is null"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2890
+#: gimple-ssa-sprintf.c:2928
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes exceeds minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2897
+#: gimple-ssa-sprintf.c:2935
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may exceed minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2900
+#: gimple-ssa-sprintf.c:2938
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes exceeds minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2929
+#: gimple-ssa-sprintf.c:2967
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2936
+#: gimple-ssa-sprintf.c:2974
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2939
+#: gimple-ssa-sprintf.c:2977
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may cause result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2949
+#: gimple-ssa-sprintf.c:2987
 #, gcc-internal-format
 msgid "assuming directive output of %wu byte"
 msgid_plural "assuming directive output of %wu bytes"
@@ -23226,80 +23237,80 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.c:2956
+#: gimple-ssa-sprintf.c:2994
 #, fuzzy, gcc-internal-format
 #| msgid "invalid option argument %qs"
 msgid "directive argument %qE"
 msgstr "pilihan argumen %qs tidak valid"
 
-#: gimple-ssa-sprintf.c:2958
+#: gimple-ssa-sprintf.c:2996
 #, fuzzy, gcc-internal-format
 #| msgid "%s expects an integer literal in the range [%d, %d]."
 msgid "directive argument in the range [%E, %E]"
 msgstr "%s diduga sebuah integer literal dalam jangkauan [%d, %d]."
 
-#: gimple-ssa-sprintf.c:2962
+#: gimple-ssa-sprintf.c:3000
 #, gcc-internal-format
 msgid "using the range [%E, %E] for directive argument"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2982
+#: gimple-ssa-sprintf.c:3020
 #, gcc-internal-format
 msgid "%qE output %wu byte into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2983
+#: gimple-ssa-sprintf.c:3021
 #, gcc-internal-format
 msgid "%qE output %wu bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2987
+#: gimple-ssa-sprintf.c:3025
 #, gcc-internal-format
 msgid "%qE output between %wu and %wu bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2992
+#: gimple-ssa-sprintf.c:3030
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes (assuming %wu) into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2997
+#: gimple-ssa-sprintf.c:3035
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3368
+#: gimple-ssa-sprintf.c:3406
 #, gcc-internal-format
 msgid "%<%.*s%> directive width out of range"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3402
+#: gimple-ssa-sprintf.c:3440
 #, gcc-internal-format
 msgid "%<%.*s%> directive precision out of range"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3893
+#: gimple-ssa-sprintf.c:3931
 #, gcc-internal-format
 msgid "specified bound %wu exceeds maximum object size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3899
+#: gimple-ssa-sprintf.c:3937
 #, gcc-internal-format
 msgid "specified bound %wu exceeds %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3949
+#: gimple-ssa-sprintf.c:3987
 #, fuzzy, gcc-internal-format
 #| msgid "Maintain backchain pointer"
 msgid "null destination pointer"
 msgstr "jaga backchain penunjuk"
 
-#: gimple-ssa-sprintf.c:3966
+#: gimple-ssa-sprintf.c:4004
 #, gcc-internal-format
 msgid "specified bound %wu exceeds the size %wu of the destination object"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3978
+#: gimple-ssa-sprintf.c:4016
 #, fuzzy, gcc-internal-format
 #| msgid "%s in format string at %L"
 msgid "null format string"
@@ -23523,10 +23534,10 @@
 msgstr ""
 
 #: gimple-ssa-warn-restrict.c:1678 c/c-decl.c:3603 c/c-decl.c:3874
-#: c/c-typeck.c:8345 cp/class.c:1346 cp/class.c:3098 cp/decl.c:3979
-#: cp/decl.c:10753 cp/decl.c:11151 cp/decl.c:11160 cp/friend.c:384
+#: c/c-typeck.c:8350 cp/class.c:1346 cp/class.c:3102 cp/decl.c:3979
+#: cp/decl.c:10777 cp/decl.c:11175 cp/decl.c:11184 cp/friend.c:384
 #: cp/friend.c:393 cp/parser.c:3275 cp/parser.c:3372 cp/parser.c:3422
-#: cp/parser.c:6327 cp/parser.c:21027
+#: cp/parser.c:6330 cp/parser.c:21024
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%qD declared here"
@@ -23602,238 +23613,238 @@
 msgid "using result of function returning %<void%>"
 msgstr "tidak ada pernyataaan kembali dalam fungsi yang mengembalikan bukan void"
 
-#: gimplify.c:6128
+#: gimplify.c:6131
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid lvalue in asm output %d"
 msgstr "lvalue tidak valid dalam keluaran asm %d"
 
-#: gimplify.c:6271
+#: gimplify.c:6274
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr "masukan %d bukan memori harus tetap berada dalam memori"
 
-#: gimplify.c:6311 gimplify.c:6320
+#: gimplify.c:6314 gimplify.c:6323
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr "masukan memori %d tidak secara langsung dapat dialamatkan"
 
-#: gimplify.c:6928
+#: gimplify.c:6931
 #, fuzzy, gcc-internal-format
 #| msgid "register variable %qD used in nested function"
 msgid "threadprivate variable %qE used in target region"
 msgstr "variabel register %qD digunakan dalam fungsi nested"
 
-#: gimplify.c:6930
+#: gimplify.c:6933
 #, fuzzy, gcc-internal-format
 #| msgid "%Henclosing parallel"
 msgid "enclosing target region"
 msgstr "%Hparallel yang melingkupi"
 
-#: gimplify.c:6942
+#: gimplify.c:6945
 #, fuzzy, gcc-internal-format
 #| msgid "register variable %qD used in nested function"
 msgid "threadprivate variable %qE used in untied task"
 msgstr "variabel register %qD digunakan dalam fungsi nested"
 
-#: gimplify.c:6944
+#: gimplify.c:6947
 #, fuzzy, gcc-internal-format
 #| msgid "%Henclosing parallel"
 msgid "enclosing task"
 msgstr "%Hparallel yang melingkupi"
 
-#: gimplify.c:7016
+#: gimplify.c:7019
 #, fuzzy, gcc-internal-format
 #| msgid "%qs not specified in enclosing parallel"
 msgid "%qE not specified in enclosing %qs"
 msgstr "%qs tidak dispesifikan dalam parallel yang melingkupi"
 
-#: gimplify.c:7018
+#: gimplify.c:7021
 #, fuzzy, gcc-internal-format
 #| msgid "error closing %s: %m"
 msgid "enclosing %qs"
 msgstr "error menutup %s: %m"
 
-#: gimplify.c:7143
+#: gimplify.c:7146
 #, fuzzy, gcc-internal-format
 #| msgid "%qs not specified in enclosing parallel"
 msgid "%qE not specified in enclosing OpenACC %qs construct"
 msgstr "%qs tidak dispesifikan dalam parallel yang melingkupi"
 
-#: gimplify.c:7145
+#: gimplify.c:7148
 #, gcc-internal-format
 msgid "enclosing OpenACC %qs construct"
 msgstr ""
 
-#: gimplify.c:7198
+#: gimplify.c:7201
 #, gcc-internal-format
 msgid "%qE with %<link%> clause used in %<routine%> function"
 msgstr ""
 
-#: gimplify.c:7206
+#: gimplify.c:7209
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE undeclared (first use in this function)"
 msgid "%qE requires a %<declare%> directive for use in a %<routine%> function"
 msgstr "%H%qE tidak dideklarasikan (pertama digunakan dalam fungsi ini)"
 
-#: gimplify.c:7272 gimplify.c:7872
+#: gimplify.c:7275 gimplify.c:7875
 #, fuzzy, gcc-internal-format
 #| msgid "variable %q+D declared %<inline%>"
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr "variabel %q+D dideklarasikan %<inline%>"
 
-#: gimplify.c:7293
+#: gimplify.c:7296
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr ""
 
-#: gimplify.c:7411 gimplify.c:7443
+#: gimplify.c:7414 gimplify.c:7446
 #, fuzzy, gcc-internal-format
 #| msgid "%Hiteration variable %qE is unsigned"
 msgid "iteration variable %qE is predetermined linear"
 msgstr "%H variabel iterasi %qE unsigned"
 
-#: gimplify.c:7414
+#: gimplify.c:7417
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable %qs should be private"
 msgid "iteration variable %qE should be private"
 msgstr "iterasi variabel %qs seharusnya private"
 
-#: gimplify.c:7428
+#: gimplify.c:7431
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable %qD should not be firstprivate"
 msgid "iteration variable %qE should not be firstprivate"
 msgstr "iterasi variabel %qD seharusnya bukan first private"
 
-#: gimplify.c:7431
+#: gimplify.c:7434
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable %qs should not be reduction"
 msgid "iteration variable %qE should not be reduction"
 msgstr "iterasi variabel %qs seharusnya bukan reduksi"
 
-#: gimplify.c:7434
+#: gimplify.c:7437
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable %qs should not be reduction"
 msgid "iteration variable %qE should not be linear"
 msgstr "iterasi variabel %qs seharusnya bukan reduksi"
 
-#: gimplify.c:7437
+#: gimplify.c:7440
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable %qD should not be firstprivate"
 msgid "iteration variable %qE should not be lastprivate"
 msgstr "iterasi variabel %qD seharusnya bukan first private"
 
-#: gimplify.c:7440
+#: gimplify.c:7443
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable %qs should be private"
 msgid "iteration variable %qE should not be private"
 msgstr "iterasi variabel %qs seharusnya private"
 
-#: gimplify.c:7742
+#: gimplify.c:7745
 #, gcc-internal-format
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr ""
 
-#: gimplify.c:7949
+#: gimplify.c:7952
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr ""
 
-#: gimplify.c:8160
+#: gimplify.c:8163
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qE appears more than once in map clauses"
 msgstr "%qE muncul lebih dari sekali dalam clause data"
 
-#: gimplify.c:8464
+#: gimplify.c:8467
 #, fuzzy, gcc-internal-format
 #| msgid "%s variable %qs is private in outer context"
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr "%s variabel %qs private dalam konteks luar"
 
-#: gimplify.c:8484
+#: gimplify.c:8487
 #, fuzzy, gcc-internal-format
 #| msgid "%s variable %qs is private in outer context"
 msgid "%s variable %qE is private in outer context"
 msgstr "%s variabel %qs private dalam konteks luar"
 
-#: gimplify.c:8510
+#: gimplify.c:8513
 #, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr ""
 
-#: gimplify.c:8775
+#: gimplify.c:8778
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr ""
 
-#: gimplify.c:8808
+#: gimplify.c:8811
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:9000
+#: gimplify.c:9003
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:9051
+#: gimplify.c:9054
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr ""
 
-#: gimplify.c:9133
+#: gimplify.c:9136
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to present_or_copy"
 msgstr ""
 
-#: gimplify.c:9278
+#: gimplify.c:9281
 #, fuzzy, gcc-internal-format
 #| msgid "invalid template declaration of %qD"
 msgid "invalid private reduction on %qE"
 msgstr "deklarasi template dari %qD tidak valid"
 
-#: gimplify.c:11103 omp-low.c:2791
+#: gimplify.c:11106 omp-low.c:2791
 #, fuzzy, gcc-internal-format
 #| msgid "ordered region must be closely nested inside a loop region with an ordered clause"
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr "daerah terurut harus secara dekat nested didalam sebuah daerah loop dalam sebuah clause terurut"
 
-#: gimplify.c:11121
+#: gimplify.c:11124
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr ""
 
-#: gimplify.c:11134
+#: gimplify.c:11137
 #, gcc-internal-format
 msgid "number of variables in %<depend(sink)%> clause does not match number of iteration variables"
 msgstr ""
 
-#: gimplify.c:11147
+#: gimplify.c:11150
 #, gcc-internal-format
 msgid "more than one %<depend(source)%> clause on an %<ordered%> construct"
 msgstr ""
 
-#: gimplify.c:11158
+#: gimplify.c:11161
 #, gcc-internal-format
 msgid "%<depend(source)%> clause specified together with %<depend(sink:)%> clauses on the same construct"
 msgstr ""
 
-#: gimplify.c:12393
+#: gimplify.c:12396
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr "gimplification gagal"
 
-#: gimplify.c:12936
+#: gimplify.c:12939
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr "%qT dipromosikan ke %qT ketika dilewatkan melalui %<...%>"
 
-#: gimplify.c:12941
+#: gimplify.c:12944
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr "(jadi anda harus melewatkan %qT bukan %qT ke %<va_arg%>)"
 
-#: gimplify.c:12948
+#: gimplify.c:12951
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr "jika kode ini dicapai, aplikasi akan digagalkan"
@@ -24327,49 +24338,49 @@
 msgid "Max. number of generated reload insns per insn is achieved (%d)\n"
 msgstr ""
 
-#: lto-cgraph.c:1294
+#: lto-cgraph.c:1296
 #, gcc-internal-format, gfc-internal-format
 msgid "bytecode stream: found multiple instances of cgraph node with uid %d"
 msgstr ""
 
-#: lto-cgraph.c:1472
+#: lto-cgraph.c:1474
 #, gcc-internal-format
 msgid "bytecode stream: no caller found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1478
+#: lto-cgraph.c:1480
 #, gcc-internal-format
 msgid "bytecode stream: no callee found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1552
+#: lto-cgraph.c:1554
 #, gcc-internal-format
 msgid "bytecode stream: found empty cgraph node"
 msgstr ""
 
-#: lto-cgraph.c:1730
+#: lto-cgraph.c:1732
 #, gcc-internal-format, gfc-internal-format
 msgid "At most %i profile runs is supported. Perhaps corrupted profile?"
 msgstr ""
 
-#: lto-cgraph.c:1817
+#: lto-cgraph.c:1819
 #, gcc-internal-format, gfc-internal-format
 msgid "Profile information in %s corrupted"
 msgstr ""
 
-#: lto-cgraph.c:1855
+#: lto-cgraph.c:1857
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot find class %qs"
 msgid "cannot find LTO cgraph in %s"
 msgstr "tidak dapat menemukan class %qs"
 
-#: lto-cgraph.c:1865
+#: lto-cgraph.c:1867
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot find protocol declaration for %qs"
 msgid "cannot find LTO section refs in %s"
 msgstr "tidak dapat menemukan deklarasi protokol untuk %qs"
 
-#: lto-cgraph.c:1946
+#: lto-cgraph.c:1948
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid rotate insn"
 msgid "invalid offload table in %s"
@@ -24445,92 +24456,98 @@
 msgid "bytecode stream in file %qs generated with LTO version %d.%d instead of the expected %d.%d"
 msgstr ""
 
-#: lto-wrapper.c:117
+#: lto-wrapper.c:118
 #, fuzzy, gcc-internal-format
 #| msgid "opening output file %s: %m"
 msgid "deleting LTRANS file %s: %m"
 msgstr "membuka berkas keluaran %s: %m"
 
-#: lto-wrapper.c:154
+#: lto-wrapper.c:155
 #, gcc-internal-format
 msgid "malformed COLLECT_GCC_OPTIONS"
 msgstr ""
 
-#: lto-wrapper.c:308
+#: lto-wrapper.c:309
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "created and used with different endianness"
 msgid "Option %s with different values"
 msgstr "dibuat dan digunakan dengan endianness berbeda"
 
-#: lto-wrapper.c:392
+#: lto-wrapper.c:393
 #, gcc-internal-format, gfc-internal-format
 msgid "Option %s not used consistently in all LTO input files"
 msgstr ""
 
-#: lto-wrapper.c:832
+#: lto-wrapper.c:833
 #, gcc-internal-format, gfc-internal-format
 msgid "problem with building target image for %s\n"
 msgstr ""
 
-#: lto-wrapper.c:852
+#: lto-wrapper.c:853
 #, fuzzy, gcc-internal-format
 #| msgid "no input files"
 msgid "reading input file"
 msgstr "tidak ada berkas masukan"
 
-#: lto-wrapper.c:857
+#: lto-wrapper.c:858
 #, fuzzy, gcc-internal-format
 #| msgid "%s:error writing output file '%s'\n"
 msgid "writing output file"
 msgstr "%s:error menulis berkas keluaran '%s'\n"
 
-#: lto-wrapper.c:889
+#: lto-wrapper.c:890
 #, gcc-internal-format
 msgid "installation error, can't find crtoffloadtable.o"
 msgstr ""
 
-#: lto-wrapper.c:1000 lto-wrapper.c:1012
+#: lto-wrapper.c:1001 lto-wrapper.c:1013
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s: %s"
 msgid "%s: %s\n"
 msgstr "%s: %s"
 
-#: lto-wrapper.c:1056
+#: lto-wrapper.c:1064
 #, fuzzy, gcc-internal-format
 #| msgid "environment variable DJGPP not defined"
 msgid "environment variable COLLECT_GCC must be set"
 msgstr "variabel lingkungan DJGPP tidak didefinisikan"
 
-#: lto-wrapper.c:1060 config/nvptx/mkoffload.c:363
+#: lto-wrapper.c:1068 config/nvptx/mkoffload.c:363
 #, fuzzy, gcc-internal-format
 #| msgid "environment variable DJGPP not defined"
 msgid "environment variable COLLECT_GCC_OPTIONS must be set"
 msgstr "variabel lingkungan DJGPP tidak didefinisikan"
 
-#: lto-wrapper.c:1229 lto-wrapper.c:1285
+#: lto-wrapper.c:1237 lto-wrapper.c:1293
 #, fuzzy, gcc-internal-format
 #| msgid "can't open %s: %m"
 msgid "cannot open %s: %m"
 msgstr "tidak dapat membuka %s: %m"
 
-#: lto-wrapper.c:1232 lto-wrapper.c:1291
+#: lto-wrapper.c:1240 lto-wrapper.c:1299
 #, fuzzy, gcc-internal-format
 #| msgid "can%'t read %s: %m"
 msgid "cannot read %s: %m"
 msgstr "tidak dapat membaca %s: %m"
 
-#: lto-wrapper.c:1259
+#: lto-wrapper.c:1267
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid #pragma %s"
 msgid "invalid format of %s"
 msgstr "#pragma %s tidak valid"
 
-#: lto-wrapper.c:1482
+#: lto-wrapper.c:1491
 #, fuzzy, gcc-internal-format
 #| msgid "fopen %s"
 msgid "fopen: %s: %m"
 msgstr "fopen %s"
 
+#: lto-wrapper.c:1508
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "opening output file %s: %s"
+msgid "Corrupted ltrans output file %s"
+msgstr "membuka berkas keluaran %s: %s"
+
 #: multiple_target.c:76
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
@@ -24909,13 +24926,13 @@
 msgid "unrecognized argument in option %qs"
 msgstr "pilihan baris perintah \"%s\" tidak dikenal"
 
-#: opts-common.c:1198 config/i386/i386.c:3206
+#: opts-common.c:1198 config/i386/i386.c:3209
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "argumen dari atribut %qs tidak valid"
 
-#: opts-common.c:1201 config/i386/i386.c:3209
+#: opts-common.c:1201 config/i386/i386.c:3212
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %qs are: %s"
@@ -25560,22 +25577,22 @@
 msgid "output operand %d must use %<&%> constraint"
 msgstr "keluaran operan %d harus menggunakan batasan %<&%>"
 
-#: regcprop.c:1187
+#: regcprop.c:1193
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad next_regno for empty chain (%u)"
 msgstr "validate_value_data: [%u] Buruk nex_regno untuk rantai kosong (%u)"
 
-#: regcprop.c:1199
+#: regcprop.c:1205
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: Loop in regno chain (%u)"
 msgstr "validate_value_data: Loop dalam rantai regno (%u)"
 
-#: regcprop.c:1202
+#: regcprop.c:1208
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad oldest_regno (%u)"
 msgstr "validate_value_data: [%u] Buruk oldest_regno (%u)"
 
-#: regcprop.c:1214
+#: regcprop.c:1220
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Non-empty reg in chain (%s %u %i)"
 msgstr "validate_value_data: [%u] Tidak kosong reg dalam rantai (%s %u %i)"
@@ -25624,7 +25641,7 @@
 msgstr "register digunakan untuk dua variabel register global"
 
 #: reginfo.c:789 config/powerpcspe/powerpcspe.c:32259
-#: config/rs6000/rs6000.c:29453
+#: config/rs6000/rs6000.c:29530
 #, fuzzy, gcc-internal-format
 #| msgid "  conflict with %q+D"
 msgid "conflicts with %qD"
@@ -25879,159 +25896,164 @@
 msgid "function symbol is not function"
 msgstr "fungsi mengembalikan sebuah fungsi"
 
-#: symtab.c:1006
+#: symtab.c:1005
+#, gcc-internal-format
+msgid "inconsistent `ifunc' attribute"
+msgstr ""
+
+#: symtab.c:1013
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to variables"
 msgid "variable symbol is not variable"
 msgstr "%qs atribut hanya berlaku ke variabel"
 
-#: symtab.c:1012
+#: symtab.c:1019
 #, gcc-internal-format
 msgid "node has unknown type"
 msgstr ""
 
-#: symtab.c:1021
+#: symtab.c:1028
 #, gcc-internal-format
 msgid "node not found node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.c:1029
+#: symtab.c:1036
 #, gcc-internal-format
 msgid "node differs from node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.c:1038
+#: symtab.c:1045
 #, gcc-internal-format
 msgid "assembler name hash list corrupted"
 msgstr ""
 
-#: symtab.c:1051
+#: symtab.c:1058
 #, fuzzy, gcc-internal-format
 #| msgid "node not found in cgraph_hash"
 msgid "node not found in symtab assembler name hash"
 msgstr "titik tidak ditemukan dalam cgraph_hash"
 
-#: symtab.c:1058
+#: symtab.c:1065
 #, gcc-internal-format
 msgid "double linked list of assembler names corrupted"
 msgstr ""
 
-#: symtab.c:1063
+#: symtab.c:1070
 #, gcc-internal-format
 msgid "node has body_removed but is definition"
 msgstr ""
 
-#: symtab.c:1068
+#: symtab.c:1075
 #, fuzzy, gcc-internal-format
 #| msgid "called object %qE is not a function"
 msgid "node is analyzed but it is not a definition"
 msgstr "dipanggil objek %qE bukan sebuah fungsi"
 
-#: symtab.c:1073
+#: symtab.c:1080
 #, gcc-internal-format
 msgid "node is alias but not implicit alias"
 msgstr ""
 
-#: symtab.c:1078
+#: symtab.c:1085
 #, fuzzy, gcc-internal-format
 #| msgid "%Jold-style function definition"
 msgid "node is alias but not definition"
 msgstr "%J definisi fungsi gaya-lama"
 
-#: symtab.c:1083
+#: symtab.c:1090
 #, gcc-internal-format
 msgid "node is weakref but not an transparent_alias"
 msgstr ""
 
-#: symtab.c:1088
+#: symtab.c:1095
 #, gcc-internal-format
 msgid "node is transparent_alias but not an alias"
 msgstr ""
 
-#: symtab.c:1097
+#: symtab.c:1104
 #, gcc-internal-format
 msgid "node is in same_comdat_group list but has no comdat_group"
 msgstr ""
 
-#: symtab.c:1102
+#: symtab.c:1109
 #, gcc-internal-format
 msgid "same_comdat_group list across different groups"
 msgstr ""
 
-#: symtab.c:1107
+#: symtab.c:1114
 #, gcc-internal-format
 msgid "mixing different types of symbol in same comdat groups is not supported"
 msgstr ""
 
-#: symtab.c:1112
+#: symtab.c:1119
 #, gcc-internal-format
 msgid "node is alone in a comdat group"
 msgstr ""
 
-#: symtab.c:1119
+#: symtab.c:1126
 #, gcc-internal-format
 msgid "same_comdat_group is not a circular list"
 msgstr ""
 
-#: symtab.c:1134
+#: symtab.c:1141
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local symbol referred to by %s outside its comdat"
 msgstr ""
 
-#: symtab.c:1144
+#: symtab.c:1151
 #, gcc-internal-format
 msgid "implicit_section flag is set but section isn't"
 msgstr ""
 
-#: symtab.c:1151
+#: symtab.c:1158
 #, gcc-internal-format
 msgid "Both section and comdat group is set"
 msgstr ""
 
-#: symtab.c:1163
+#: symtab.c:1170
 #, gcc-internal-format
 msgid "Alias and target's section differs"
 msgstr ""
 
-#: symtab.c:1170
+#: symtab.c:1177
 #, gcc-internal-format
 msgid "Alias and target's comdat groups differs"
 msgstr ""
 
-#: symtab.c:1185
+#: symtab.c:1192
 #, gcc-internal-format
 msgid "Transparent alias and target's assembler names differs"
 msgstr ""
 
-#: symtab.c:1193
+#: symtab.c:1200
 #, gcc-internal-format
 msgid "Chained transparent aliases"
 msgstr ""
 
-#: symtab.c:1216 symtab.c:1253
+#: symtab.c:1223 symtab.c:1260
 #, fuzzy, gcc-internal-format
 #| msgid "verify_ssa failed"
 msgid "symtab_node::verify failed"
 msgstr "verify_ssa gagal"
 
-#: symtab.c:1249
+#: symtab.c:1256
 #, gcc-internal-format
 msgid "Two symbols with same comdat_group are not linked by the same_comdat_group list."
 msgstr ""
 
-#: symtab.c:1658
+#: symtab.c:1665
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared as inline"
 msgid "function %q+D part of alias cycle"
 msgstr "fungsi %q+D redeklarasi sebagai inline"
 
-#: symtab.c:1660
+#: symtab.c:1667
 #, fuzzy, gcc-internal-format
 #| msgid "variable %qD has function type"
 msgid "variable %q+D part of alias cycle"
 msgstr "variabel %qD memiliki tipe fungsi"
 
-#: symtab.c:1688
+#: symtab.c:1695
 #, gcc-internal-format
 msgid "section of alias %q+D must match section of its target"
 msgstr ""
@@ -26893,7 +26915,7 @@
 msgid "the first argument of a VEC_COND_EXPR must be of a boolean vector type of the same number of elements as the result"
 msgstr ""
 
-#: tree-cfg.c:4395 c/c-typeck.c:5212
+#: tree-cfg.c:4395 c/c-typeck.c:5217
 #, gcc-internal-format
 msgid "type mismatch in conditional expression"
 msgstr "tipe tidak cocok dalam ekspresi kondisional"
@@ -27267,24 +27289,24 @@
 msgid "missing edge %i->%i"
 msgstr "hilang edge %i->%i"
 
-#: tree-cfg.c:9379
+#: tree-cfg.c:9388
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<noreturn%> function does return"
 msgid "%<noreturn%> function does return"
 msgstr "%H%<noreturn%> fungsi tidak kembali"
 
-#: tree-cfg.c:9400 tree-cfg.c:9432
+#: tree-cfg.c:9409 tree-cfg.c:9441
 #, gcc-internal-format
 msgid "control reaches end of non-void function"
 msgstr "kontrol mencapai akhir dari fungsi bukan void"
 
-#: tree-cfg.c:9498 cp/cvt.c:1039
+#: tree-cfg.c:9507 cp/cvt.c:1039
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of %qD, declared with attribute warn_unused_result"
 msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgstr "%H mengabaikan nilai kembali dari %qD, dideklarasikan dengan atribut warn_unused_result"
 
-#: tree-cfg.c:9503 cp/cvt.c:1046
+#: tree-cfg.c:9512 cp/cvt.c:1046
 #, fuzzy, gcc-internal-format
 #| msgid "%Hignoring return value of function declared with attribute warn_unused_result"
 msgid "ignoring return value of function declared with attribute warn_unused_result"
@@ -27567,47 +27589,47 @@
 msgid "stmt volatile flag not up-to-date"
 msgstr ""
 
-#: tree-ssa-strlen.c:1975
+#: tree-ssa-strlen.c:1999
 msgid "%G%qD output truncated before terminating nul copying %E byte from a string of the same length"
 msgid_plural "%G%qD output truncated before terminating nul copying %E bytes from a string of the same length"
 msgstr[0] ""
 msgstr[1] ""
 
-#: tree-ssa-strlen.c:1989
+#: tree-ssa-strlen.c:2013
 msgid "%G%qD output truncated copying %E byte from a string of length %wu"
 msgid_plural "%G%qD output truncated copying %E bytes from a string of length %wu"
 msgstr[0] ""
 msgstr[1] ""
 
-#: tree-ssa-strlen.c:1996
+#: tree-ssa-strlen.c:2020
 msgid "%G%qD output truncated copying between %wu and %wu bytes from a string of length %wu"
 msgstr ""
 
-#: tree-ssa-strlen.c:2008
+#: tree-ssa-strlen.c:2032
 msgid "%G%qD output may be truncated copying %E byte from a string of length %wu"
 msgid_plural "%G%qD output may be truncated copying %E bytes from a string of length %wu"
 msgstr[0] ""
 msgstr[1] ""
 
-#: tree-ssa-strlen.c:2015 tree-ssa-strlen.c:2029
+#: tree-ssa-strlen.c:2039 tree-ssa-strlen.c:2053
 msgid "%G%qD output may be truncated copying between %wu and %wu bytes from a string of length %wu"
 msgstr ""
 
-#: tree-ssa-strlen.c:2150
+#: tree-ssa-strlen.c:2174
 msgid "%G%qD output truncated before terminating nul copying as many bytes from a string as its length"
 msgstr ""
 
-#: tree-ssa-strlen.c:2156
+#: tree-ssa-strlen.c:2180
 msgid "%G%qD specified bound depends on the length of the source argument"
 msgstr ""
 
-#: tree-ssa-strlen.c:2163
+#: tree-ssa-strlen.c:2187
 #, fuzzy, gcc-internal-format
 #| msgid "length modifier"
 msgid "length computed here"
 msgstr "pemodifikasi panjang"
 
-#: tree-ssa-uninit.c:191 varasm.c:331
+#: tree-ssa-uninit.c:191 varasm.c:342
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qD was declared here"
 msgid "%qD was declared here"
@@ -27787,27 +27809,27 @@
 msgid "target specific builtin not available"
 msgstr "pilihan target spesifik tidak cocok"
 
-#: tree-vect-generic.c:287
+#: tree-vect-generic.c:283
 #, gcc-internal-format
 msgid "vector operation will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-generic.c:290
+#: tree-vect-generic.c:286
 #, gcc-internal-format
 msgid "vector operation will be expanded in parallel"
 msgstr ""
 
-#: tree-vect-generic.c:341
+#: tree-vect-generic.c:337
 #, gcc-internal-format
 msgid "vector operation will be expanded with a single scalar operation"
 msgstr ""
 
-#: tree-vect-generic.c:941
+#: tree-vect-generic.c:937
 #, gcc-internal-format
 msgid "vector condition will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-generic.c:1373
+#: tree-vect-generic.c:1369
 #, gcc-internal-format
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr ""
@@ -27817,31 +27839,31 @@
 msgid "vectorization did not happen for a simd loop"
 msgstr ""
 
-#: tree-vrp.c:4930 tree-vrp.c:4974
+#: tree-vrp.c:4931 tree-vrp.c:4975
 #, fuzzy, gcc-internal-format
 #| msgid "%Harray subscript is above array bounds"
 msgid "array subscript %E is above array bounds of %qT"
 msgstr "%H array subscript diatas dari array bounds"
 
-#: tree-vrp.c:4956
+#: tree-vrp.c:4957
 #, fuzzy, gcc-internal-format
 #| msgid "%Harray subscript is outside array bounds"
 msgid "array subscript [%E, %E] is outside array bounds of %qT"
 msgstr "%H array subscript diluar dari cakupan array"
 
-#: tree-vrp.c:4988
+#: tree-vrp.c:4989
 #, fuzzy, gcc-internal-format
 #| msgid "%Harray subscript is below array bounds"
 msgid "array subscript %E is below array bounds of %qT"
 msgstr "%Harray subscrip dibawah dari array bounds"
 
-#: tree-vrp.c:5046
+#: tree-vrp.c:5047
 #, fuzzy, gcc-internal-format
 #| msgid "%Harray subscript is below array bounds"
 msgid "array subscript %wi is below array bounds of %qT"
 msgstr "%Harray subscrip dibawah dari array bounds"
 
-#: tree-vrp.c:5060
+#: tree-vrp.c:5061
 #, fuzzy, gcc-internal-format
 #| msgid "%Harray subscript is above array bounds"
 msgid "array subscript %wu is above array bounds of %qT"
@@ -27857,98 +27879,98 @@
 msgid "side-effects element in no-side-effects CONSTRUCTOR"
 msgstr ""
 
-#: tree.c:7852
+#: tree.c:7856
 #, gcc-internal-format
 msgid "arrays of functions are not meaningful"
 msgstr "array dari fungsi tidak berarti"
 
-#: tree.c:8019
+#: tree.c:8023
 #, gcc-internal-format
 msgid "function return type cannot be function"
 msgstr "tipe kembali fungsi tidak dapat berupa fungsi"
 
-#: tree.c:9327 tree.c:9412 tree.c:9473
+#: tree.c:9331 tree.c:9416 tree.c:9477
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: %s, have %s in %s, at %s:%d"
 msgstr "pemeriksaan pohon: %s, memiliki %s dalam %s, di %s:%d"
 
-#: tree.c:9364
+#: tree.c:9368
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected none of %s, have %s in %s, at %s:%d"
 msgstr "pemeriksaan pohon: diduga kosong dari %s, memiliki %s dalam %s, di %s:%d"
 
-#: tree.c:9377
+#: tree.c:9381
 #, gcc-internal-format
 msgid "tree check: expected class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "pemeriksaan pohon: diduga kelas %qs, memiliki %qs (%s) dalam %s, di %s:%d"
 
-#: tree.c:9426
+#: tree.c:9430
 #, gcc-internal-format
 msgid "tree check: did not expect class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "pemeriksaan pohon: tidak menduga kelas %qs, memiliki %qs (%s dalam %s, di %s:%d"
 
-#: tree.c:9439
+#: tree.c:9443
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected omp_clause %s, have %s in %s, at %s:%d"
 msgstr "pemeriksaan pohon: diduga omp_clause %s, memiliki %s dalam %s, di %s:%d"
 
-#: tree.c:9499
+#: tree.c:9503
 #, gcc-internal-format
 msgid "tree check: expected tree that contains %qs structure, have %qs in %s, at %s:%d"
 msgstr "pemeriksaan pohon: diduga pohon yang berisi struktur %qs, memiliki %qs dalam %s, di %s:%d"
 
-#: tree.c:9513
+#: tree.c:9517
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "tree check: accessed elt %d of tree_vec with %d elts in %s, at %s:%d"
 msgid "tree check: accessed elt %d of tree_int_cst with %d elts in %s, at %s:%d"
 msgstr "pemeriksaan pohon: diakses elt %d dari tree_vec dengan %d elts dalam %s, di %s:%d"
 
-#: tree.c:9525
+#: tree.c:9529
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_vec with %d elts in %s, at %s:%d"
 msgstr "pemeriksaan pohon: diakses elt %d dari tree_vec dengan %d elts dalam %s, di %s:%d"
 
-#: tree.c:9538
+#: tree.c:9542
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of %s with %d operands in %s, at %s:%d"
 msgstr "pemeriksaan pohon: diakses operan %d dari %s dengan %d operan dalam %s, di %s:%d"
 
-#: tree.c:9551
+#: tree.c:9555
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of omp_clause %s with %d operands in %s, at %s:%d"
 msgstr "pemeriksaan pohon: diakses operan %d dari omp_clause %s dengan %d operan dalam %s, di %s:%d"
 
-#: tree.c:12446
+#: tree.c:12450
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated"
 msgid "%qD is deprecated: %s"
 msgstr "%qs sudah ditinggalkan"
 
-#: tree.c:12449
+#: tree.c:12453
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated"
 msgid "%qD is deprecated"
 msgstr "%qs sudah ditinggalkan"
 
-#: tree.c:12473 tree.c:12495
+#: tree.c:12477 tree.c:12499
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated"
 msgid "%qE is deprecated: %s"
 msgstr "%qs sudah ditinggalkan"
 
-#: tree.c:12476 tree.c:12498
+#: tree.c:12480 tree.c:12502
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated"
 msgid "%qE is deprecated"
 msgstr "%qs sudah ditinggalkan"
 
-#: tree.c:12482 tree.c:12503
+#: tree.c:12486 tree.c:12507
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "type is deprecated"
 msgid "type is deprecated: %s"
 msgstr "tipe sudah ditinggalkan"
 
-#: tree.c:12485 tree.c:12506
+#: tree.c:12489 tree.c:12510
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr "tipe sudah ditinggalkan"
@@ -27973,245 +27995,245 @@
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.c:13043
+#: tree.c:13047
 #, gcc-internal-format, gfc-internal-format
 msgid "type variant differs by %s"
 msgstr ""
 
-#: tree.c:13084
+#: tree.c:13088
 #, gcc-internal-format
 msgid "type variant has different TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13086
+#: tree.c:13090
 #, gcc-internal-format
 msgid "type variant's TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13088
+#: tree.c:13092
 #, gcc-internal-format
 msgid "type's TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13108
+#: tree.c:13112
 #, gcc-internal-format
 msgid "type variant with TYPE_ALIAS_SET_KNOWN_P"
 msgstr ""
 
-#: tree.c:13121
+#: tree.c:13125
 #, gcc-internal-format
 msgid "type variant has different TYPE_VFIELD"
 msgstr ""
 
-#: tree.c:13157
+#: tree.c:13161
 #, gcc-internal-format
 msgid "type variant has different TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13159
+#: tree.c:13163
 #, gcc-internal-format
 msgid "type variant's TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13161
+#: tree.c:13165
 #, gcc-internal-format
 msgid "type's TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13199
+#: tree.c:13203
 #, gcc-internal-format
 msgid "type variant has different TYPE_FIELDS"
 msgstr ""
 
-#: tree.c:13201
+#: tree.c:13205
 #, gcc-internal-format
 msgid "first mismatch is field"
 msgstr ""
 
-#: tree.c:13203
+#: tree.c:13207
 #, gcc-internal-format
 msgid "and field"
 msgstr ""
 
-#: tree.c:13220
+#: tree.c:13224
 #, gcc-internal-format
 msgid "type variant has different TREE_TYPE"
 msgstr ""
 
-#: tree.c:13222 tree.c:13233
+#: tree.c:13226 tree.c:13237
 #, gcc-internal-format
 msgid "type variant's TREE_TYPE"
 msgstr ""
 
-#: tree.c:13224 tree.c:13235
+#: tree.c:13228 tree.c:13239
 #, gcc-internal-format
 msgid "type's TREE_TYPE"
 msgstr ""
 
-#: tree.c:13231
+#: tree.c:13235
 #, fuzzy, gcc-internal-format
 #| msgid "assert: %s is assign compatible with %s"
 msgid "type is not compatible with its variant"
 msgstr "assert: %s adalah assign kompatibel dengan %s"
 
-#: tree.c:13534
+#: tree.c:13538
 #, fuzzy, gcc-internal-format
 #| msgid "environment variable \"%s\" not defined"
 msgid "Main variant is not defined"
 msgstr "variabel lingkungan \"%s\" tidak terdefinisi"
 
-#: tree.c:13539
+#: tree.c:13543
 #, gcc-internal-format
 msgid "TYPE_MAIN_VARIANT has different TYPE_MAIN_VARIANT"
 msgstr ""
 
-#: tree.c:13551
+#: tree.c:13555
 #, gcc-internal-format
 msgid "TYPE_CANONICAL has different TYPE_CANONICAL"
 msgstr ""
 
-#: tree.c:13569
+#: tree.c:13573
 #, gcc-internal-format
 msgid "TYPE_CANONICAL is not compatible"
 msgstr ""
 
-#: tree.c:13577
+#: tree.c:13581
 #, gcc-internal-format
 msgid "TYPE_MODE of TYPE_CANONICAL is not compatible"
 msgstr ""
 
-#: tree.c:13583
+#: tree.c:13587
 #, gcc-internal-format
 msgid "TYPE_CANONICAL of main variant is not main variant"
 msgstr ""
 
-#: tree.c:13599
+#: tree.c:13603
 #, gcc-internal-format
 msgid "TYPE_VFIELD is not FIELD_DECL nor TREE_LIST"
 msgstr ""
 
-#: tree.c:13609
+#: tree.c:13613
 #, gcc-internal-format
 msgid "TYPE_NEXT_PTR_TO is not POINTER_TYPE"
 msgstr ""
 
-#: tree.c:13619
+#: tree.c:13623
 #, gcc-internal-format
 msgid "TYPE_NEXT_REF_TO is not REFERENCE_TYPE"
 msgstr ""
 
-#: tree.c:13640
+#: tree.c:13644
 #, gcc-internal-format
 msgid "TYPE_BINFO is not TREE_BINFO"
 msgstr ""
 
-#: tree.c:13646
+#: tree.c:13650
 #, gcc-internal-format
 msgid "TYPE_BINFO type is not TYPE_MAIN_VARIANT"
 msgstr ""
 
-#: tree.c:13657
+#: tree.c:13661
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not record nor union"
 msgstr ""
 
-#: tree.c:13668
+#: tree.c:13672
 #, gcc-internal-format
 msgid "TYPE_OFFSET_BASETYPE is not record nor union"
 msgstr ""
 
-#: tree.c:13686
+#: tree.c:13690
 #, gcc-internal-format
 msgid "TYPE_ARRAY_MAX_SIZE not INTEGER_CST"
 msgstr ""
 
-#: tree.c:13693
+#: tree.c:13697
 #, gcc-internal-format
 msgid "TYPE_MAX_VALUE_RAW non-NULL"
 msgstr ""
 
-#: tree.c:13700
+#: tree.c:13704
 #, gcc-internal-format
 msgid "TYPE_LANG_SLOT_1 (binfo) field is non-NULL"
 msgstr ""
 
-#: tree.c:13716
+#: tree.c:13720
 #, gcc-internal-format
 msgid "Enum value is not CONST_DECL or INTEGER_CST"
 msgstr ""
 
-#: tree.c:13724
+#: tree.c:13728
 #, gcc-internal-format
 msgid "Enum value type is not INTEGER_TYPE nor convertible to the enum"
 msgstr ""
 
-#: tree.c:13731
+#: tree.c:13735
 #, gcc-internal-format
 msgid "Enum value name is not IDENTIFIER_NODE"
 msgstr ""
 
-#: tree.c:13741
+#: tree.c:13745
 #, gcc-internal-format
 msgid "Array TYPE_DOMAIN is not integer type"
 msgstr ""
 
-#: tree.c:13750
+#: tree.c:13754
 #, fuzzy, gcc-internal-format
 #| msgid "field %qs has incomplete type"
 msgid "TYPE_FIELDS defined in incomplete type"
 msgstr "field %qs memiliki tipe tidak lengkap"
 
-#: tree.c:13772
+#: tree.c:13776
 #, gcc-internal-format
 msgid "Wrong tree in TYPE_FIELDS list"
 msgstr ""
 
-#: tree.c:13787
+#: tree.c:13791
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is %i while TYPE_CACHED_VALUES is %p"
 msgstr ""
 
-#: tree.c:13793
+#: tree.c:13797
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES is not TREE_VEC"
 msgstr ""
 
-#: tree.c:13806
+#: tree.c:13810
 #, gcc-internal-format
 msgid "wrong TYPE_CACHED_VALUES entry"
 msgstr ""
 
-#: tree.c:13819
+#: tree.c:13823
 #, gcc-internal-format
 msgid "TREE_PURPOSE is non-NULL in TYPE_ARG_TYPES list"
 msgstr ""
 
-#: tree.c:13825
+#: tree.c:13829
 #, gcc-internal-format
 msgid "Wrong entry in TYPE_ARG_TYPES list"
 msgstr ""
 
-#: tree.c:13832
+#: tree.c:13836
 #, gcc-internal-format
 msgid "TYPE_VALUES_RAW field is non-NULL"
 msgstr ""
 
-#: tree.c:13844
+#: tree.c:13848
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is set while it should not"
 msgstr ""
 
-#: tree.c:13850
+#: tree.c:13854
 #, gcc-internal-format
 msgid "TYPE_STRING_FLAG is set on wrong type code"
 msgstr ""
 
-#: tree.c:13860
+#: tree.c:13864
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not main variant"
 msgstr ""
 
-#: tree.c:13867
+#: tree.c:13871
 #, fuzzy, gcc-internal-format
 #| msgid "verify_gimple failed"
 msgid "verify_type failed"
@@ -28239,197 +28261,197 @@
 msgid "corrupted value profile: %s profile counter (%d out of %d) inconsistent with basic-block count (%d)"
 msgstr "%H nilai profile terkorupsi: %s profiler jumlah overall (%d) tidak cocok jumlah BB (%d)"
 
-#: var-tracking.c:7166
+#: var-tracking.c:7184
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded with -fvar-tracking-assignments, retrying without"
 msgstr ""
 
-#: var-tracking.c:7170
+#: var-tracking.c:7188
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded"
 msgstr ""
 
-#: varasm.c:326
+#: varasm.c:337
 #, fuzzy, gcc-internal-format
 #| msgid "%+D causes a section type conflict"
 msgid "%+qD causes a section type conflict with %qD"
 msgstr "%+D menyebabkan konflik sebuah tipe daerah"
 
-#: varasm.c:329
+#: varasm.c:340
 #, fuzzy, gcc-internal-format
 #| msgid "  conflict with %q+D"
 msgid "section type conflict with %qD"
 msgstr "  konflik dengan %q+D"
 
-#: varasm.c:334
+#: varasm.c:345
 #, fuzzy, gcc-internal-format
 #| msgid "%+D causes a section type conflict"
 msgid "%+qD causes a section type conflict"
 msgstr "%+D menyebabkan konflik sebuah tipe daerah"
 
-#: varasm.c:336
+#: varasm.c:347
 #, fuzzy, gcc-internal-format
 #| msgid "%+D causes a section type conflict"
 msgid "section type conflict"
 msgstr "%+D menyebabkan konflik sebuah tipe daerah"
 
-#: varasm.c:1019
+#: varasm.c:1030
 #, fuzzy, gcc-internal-format
 #| msgid "alignment of %q+D is greater than maximum object file alignment.  Using %d"
 msgid "alignment of %q+D is greater than maximum object file alignment %d"
 msgstr "alignmen dari %q+D lebih besar dari berkas objek maksimum alignmen. Menggunakan %d"
 
-#: varasm.c:1172
+#: varasm.c:1183
 #, fuzzy, gcc-internal-format
 #| msgid "Put zero initialized data in the bss section"
 msgid "only zero initializers are allowed in section %qs"
 msgstr "Tempatkan nol data terinisialisasi dalam daerah bss"
 
-#: varasm.c:1378 varasm.c:1387
+#: varasm.c:1389 varasm.c:1398
 #, gcc-internal-format
 msgid "register name not specified for %q+D"
 msgstr "nama register tidak dispesifikasikan untuk %q+D"
 
-#: varasm.c:1389
+#: varasm.c:1400
 #, gcc-internal-format
 msgid "invalid register name for %q+D"
 msgstr "nama register tidak valid untuk %q+D"
 
-#: varasm.c:1391
+#: varasm.c:1402
 #, gcc-internal-format
 msgid "data type of %q+D isn%'t suitable for a register"
 msgstr "tipe data dari %q+D tidak cocok untuk sebuah register"
 
-#: varasm.c:1394
+#: varasm.c:1405
 #, fuzzy, gcc-internal-format
 #| msgid "register specified for %q+D isn%'t suitable for data type"
 msgid "the register specified for %q+D cannot be accessed by the current target"
 msgstr "register yang dispesifikasikan untuk %q+D tidak cocok untuk tipe data"
 
-#: varasm.c:1397
+#: varasm.c:1408
 #, fuzzy, gcc-internal-format
 #| msgid "register used for two global register variables"
 msgid "the register specified for %q+D is not general enough to be used as a register variable"
 msgstr "register digunakan untuk dua variabel register global"
 
-#: varasm.c:1400
+#: varasm.c:1411
 #, gcc-internal-format
 msgid "register specified for %q+D isn%'t suitable for data type"
 msgstr "register yang dispesifikasikan untuk %q+D tidak cocok untuk tipe data"
 
-#: varasm.c:1410
+#: varasm.c:1421
 #, gcc-internal-format
 msgid "global register variable has initial value"
 msgstr "variabel global register memiliki nilai inisial"
 
-#: varasm.c:1414
+#: varasm.c:1425
 #, gcc-internal-format
 msgid "optimization may eliminate reads and/or writes to register variables"
 msgstr "optimisasi mungkin menghapus baca dan/atau tulis ke variabel register"
 
-#: varasm.c:1460
+#: varasm.c:1471
 #, gcc-internal-format
 msgid "register name given for non-register variable %q+D"
 msgstr "nama register diberikan untuk variabel bukan register %q+D"
 
-#: varasm.c:1870
+#: varasm.c:1881
 #, gcc-internal-format
 msgid "Patchable function entry > size"
 msgstr ""
 
-#: varasm.c:2069
+#: varasm.c:2080
 #, gcc-internal-format
 msgid "thread-local COMMON data not implemented"
 msgstr "thread-local COMMON data tidak terimplementasi"
 
-#: varasm.c:2102
+#: varasm.c:2113
 #, gcc-internal-format
 msgid "requested alignment for %q+D is greater than implemented alignment of %wu"
 msgstr "alignmen yang diminta untuk %q+D lebih besar dari alignmen yang diimplementasikan dari %wu"
 
-#: varasm.c:2205 c/c-decl.c:5027 c/c-parser.c:1534
+#: varasm.c:2216 c/c-decl.c:5027 c/c-parser.c:1534
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t known"
 msgstr "ukuran penyimpanan dari %q+D tidak diketahui"
 
-#: varasm.c:4910
+#: varasm.c:4921
 #, gcc-internal-format
 msgid "initializer for integer/fixed-point value is too complicated"
 msgstr "penginisialisasi untuk nilai integer/titik-tetap terlalu kompleks"
 
-#: varasm.c:4915
+#: varasm.c:4926
 #, gcc-internal-format
 msgid "initializer for floating value is not a floating constant"
 msgstr "penginisialisasi untuk nilai pecahan bukan sebuah konstanta pecahan"
 
-#: varasm.c:5227
+#: varasm.c:5238
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initial value for member %qs"
 msgid "invalid initial value for member %qE"
 msgstr "nilai inisial tidak valid untuk anggota %qs"
 
-#: varasm.c:5487
+#: varasm.c:5498
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after being called"
 msgid "%+qD declared weak after being used"
 msgstr "%q+D dideklarasikan inline setelah dipanggil"
 
-#: varasm.c:5539
+#: varasm.c:5550
 #, fuzzy, gcc-internal-format
 #| msgid "weak declaration of %q+D must precede definition"
 msgid "weak declaration of %q+D being applied to a already existing, static definition"
 msgstr "deklarasi lemah dari %q+D harus mengawali definisi"
 
-#: varasm.c:5575
+#: varasm.c:5586
 #, gcc-internal-format
 msgid "weak declaration of %q+D must be public"
 msgstr "deklarasi lemah dari %q+D harus berupa publik"
 
-#: varasm.c:5579
+#: varasm.c:5590
 #, gcc-internal-format
 msgid "weak declaration of %q+D not supported"
 msgstr "deklarasi lemah dari %q+D tidak didukung"
 
-#: varasm.c:5608 varasm.c:5912
+#: varasm.c:5619 varasm.c:5926
 #, gcc-internal-format
 msgid "only weak aliases are supported in this configuration"
 msgstr "hanya aliases lemah yang didukung dalam konfigurasi ini"
 
-#: varasm.c:5802
+#: varasm.c:5813
 #, fuzzy, gcc-internal-format
 #| msgid "%Jweakref is not supported in this configuration"
 msgid "weakref is not supported in this configuration"
 msgstr "%J weakref tidak didukung dalam konfigurasi ini"
 
-#: varasm.c:5834
+#: varasm.c:5846
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "ifunc is not supported on this target"
 msgstr "batas stact tidak didukung dalam target ini"
 
-#: varasm.c:5892
+#: varasm.c:5904
 #, gcc-internal-format
 msgid "weakref %q+D ultimately targets itself"
 msgstr "weakref %q+D secara ultimate mentarget dirinya sendiri"
 
-#: varasm.c:5894
+#: varasm.c:5906
 #, gcc-internal-format
 msgid "weakref %q+D must have static linkage"
 msgstr "weakref %q+D harus memiliki static linkage"
 
-#: varasm.c:5901
+#: varasm.c:5913
 #, fuzzy, gcc-internal-format
 #| msgid "%Jalias definitions not supported in this configuration"
 msgid "alias definitions not supported in this configuration"
 msgstr "%J definisi alias tidak didukung dalam konfigurasi ini"
 
-#: varasm.c:5909
+#: varasm.c:5923
 #, fuzzy, gcc-internal-format
 #| msgid "-m%s not supported in this configuration"
 msgid "ifunc is not supported in this configuration"
 msgstr "-m%s tidak didukung dalam konfigurasi ini"
 
-#: varasm.c:6127 config/sol2.c:159 config/i386/winnt.c:265
+#: varasm.c:6141 config/sol2.c:159 config/i386/winnt.c:265
 #, gcc-internal-format
 msgid "visibility attribute not supported in this configuration; ignored"
 msgstr "visibility atribut tidak didukung dalam konfigurasi ini; diabaikan"
@@ -28508,192 +28530,198 @@
 msgid "bytecode stream: tag %s is not in the expected range [%s, %s]"
 msgstr ""
 
-#: c-family/c-attribs.c:529
+#: c-family/c-attribs.c:524
+#, fuzzy, gcc-internal-format
+#| msgid "%qE attribute ignored for %qE"
+msgid "%qE attribute ignored for type %qT"
+msgstr "%qE atribut diabaikan untuk %qE"
+
+#: c-family/c-attribs.c:536
 #, gcc-internal-format
 msgid "%qE attribute ignored for field of type %qT"
 msgstr "%qE atribut diabaikan untuk daerah dari tipe %qT"
 
-#: c-family/c-attribs.c:696
+#: c-family/c-attribs.c:706
 #, fuzzy, gcc-internal-format
 #| msgid "alias argument not a string"
 msgid "no_sanitize argument not a string"
 msgstr "alias argumen bukan sebuah string"
 
-#: c-family/c-attribs.c:826 ada/gcc-interface/utils.c:6235
+#: c-family/c-attribs.c:837 ada/gcc-interface/utils.c:6240
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "%qE attribute ignored due to conflict with attribute %qs"
 msgstr "%qE atribut konflik dengan atribut %s"
 
-#: c-family/c-attribs.c:875
+#: c-family/c-attribs.c:886
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute ignored. Use -fcf-protection option to enable it"
 msgstr "%qE atribut diabaikan dalam tipe bukan-class"
 
-#: c-family/c-attribs.c:914 c-family/c-attribs.c:920 c-family/c-attribs.c:3388
-#: c-family/c-attribs.c:3423 c-family/c-attribs.c:3429
+#: c-family/c-attribs.c:925 c-family/c-attribs.c:931 c-family/c-attribs.c:3399
+#: c-family/c-attribs.c:3434 c-family/c-attribs.c:3440
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "%qE attribute ignored due to conflict with %qs attribute"
 msgstr "%qE atribut konflik dengan atribut %s"
 
-#: c-family/c-attribs.c:976 brig/brig-lang.c:482 lto/lto-lang.c:288
+#: c-family/c-attribs.c:987 brig/brig-lang.c:482 lto/lto-lang.c:288
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute have effect only on public objects"
 msgid "%qE attribute has no effect on unit local functions"
 msgstr "%qE atribut hanya memiliki efek dalam objek publik"
 
-#: c-family/c-attribs.c:1130
+#: c-family/c-attribs.c:1141
 #, gcc-internal-format
 msgid "%qE attribute have effect only on public objects"
 msgstr "%qE atribut hanya memiliki efek dalam objek publik"
 
-#: c-family/c-attribs.c:1159
+#: c-family/c-attribs.c:1170
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to variables"
 msgid "%qE attribute only affects top level objects"
 msgstr "%qs atribut hanya berlaku ke variabel"
 
-#: c-family/c-attribs.c:1198 c-family/c-attribs.c:2682
+#: c-family/c-attribs.c:1209 c-family/c-attribs.c:2693
 #, fuzzy, gcc-internal-format
 #| msgid "%<return%> with a value, in function returning void"
 msgid "%qE attribute on function returning %<void%>"
 msgstr "%<return%> dengan sebuah nilai, dalam fungsi mengembalikan void"
 
-#: c-family/c-attribs.c:1221 c-family/c-pragma.c:419
+#: c-family/c-attribs.c:1232 c-family/c-pragma.c:419
 #, gcc-internal-format
 msgid "scalar_storage_order is not supported because endianness is not uniform"
 msgstr ""
 
-#: c-family/c-attribs.c:1238
+#: c-family/c-attribs.c:1249
 #, gcc-internal-format
 msgid "scalar_storage_order argument must be one of \"big-endian\" or \"little-endian\""
 msgstr ""
 
-#: c-family/c-attribs.c:1334
+#: c-family/c-attribs.c:1345
 #, gcc-internal-format
 msgid "destructor priorities are not supported"
 msgstr "prioritas destruktor tidak didukung"
 
-#: c-family/c-attribs.c:1336
+#: c-family/c-attribs.c:1347
 #, gcc-internal-format
 msgid "constructor priorities are not supported"
 msgstr "prioritas konstruktor tidak didukung"
 
-#: c-family/c-attribs.c:1358
+#: c-family/c-attribs.c:1369
 #, gcc-internal-format, gfc-internal-format
 msgid "destructor priorities from 0 to %d are reserved for the implementation"
 msgstr "prioritas destruktor dari 0 ke %d direserve untuk implementasi"
 
-#: c-family/c-attribs.c:1363
+#: c-family/c-attribs.c:1374
 #, gcc-internal-format, gfc-internal-format
 msgid "constructor priorities from 0 to %d are reserved for the implementation"
 msgstr "prioritas konstruktor dari 0 ke %d direserve untuk implementasi"
 
-#: c-family/c-attribs.c:1371
+#: c-family/c-attribs.c:1382
 #, gcc-internal-format, gfc-internal-format
 msgid "destructor priorities must be integers from 0 to %d inclusive"
 msgstr "prioritas destruktor harus berupa integer dari 0 ke %d inklusif"
 
-#: c-family/c-attribs.c:1374
+#: c-family/c-attribs.c:1385
 #, gcc-internal-format, gfc-internal-format
 msgid "constructor priorities must be integers from 0 to %d inclusive"
 msgstr "prioritas konstruktor harus berupa integer dari 0 ke %d inklusif"
 
-#: c-family/c-attribs.c:1527
+#: c-family/c-attribs.c:1538
 #, fuzzy, gcc-internal-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown machine mode %qE"
 msgstr "mode mesin %qs tidak dikenal"
 
-#: c-family/c-attribs.c:1557
+#: c-family/c-attribs.c:1568
 #, gcc-internal-format
 msgid "specifying vector types with __attribute__ ((mode)) is deprecated"
 msgstr "spesifikasikan tipe vektor dengan __attribute__ ((mode)) sudah ditinggalkan"
 
-#: c-family/c-attribs.c:1560
+#: c-family/c-attribs.c:1571
 #, gcc-internal-format
 msgid "use __attribute__ ((vector_size)) instead"
 msgstr "lebih baik gunakan __attribute__ ((vector_size))"
 
-#: c-family/c-attribs.c:1569
+#: c-family/c-attribs.c:1580
 #, gcc-internal-format
 msgid "unable to emulate %qs"
 msgstr "tidak dapat mengemulasikan %qs"
 
-#: c-family/c-attribs.c:1582
+#: c-family/c-attribs.c:1593
 #, gcc-internal-format
 msgid "invalid pointer mode %qs"
 msgstr "mode pointer tidak valid %qs"
 
-#: c-family/c-attribs.c:1599
+#: c-family/c-attribs.c:1610
 #, fuzzy, gcc-internal-format
 #| msgid "signness of type and machine mode %qs don't match"
 msgid "signedness of type and machine mode %qs don%'t match"
 msgstr "signness dari tipe dan mode mesin %qs tidak cocok"
 
-#: c-family/c-attribs.c:1610
+#: c-family/c-attribs.c:1621
 #, gcc-internal-format
 msgid "no data type for mode %qs"
 msgstr "tidak ada tipe data untuk mode %qs"
 
-#: c-family/c-attribs.c:1620
+#: c-family/c-attribs.c:1631
 #, gcc-internal-format
 msgid "cannot use mode %qs for enumeral types"
 msgstr "tidak dapat menggunakan mode %qs untuk tipe enumeral"
 
-#: c-family/c-attribs.c:1647
+#: c-family/c-attribs.c:1658
 #, gcc-internal-format
 msgid "mode %qs applied to inappropriate type"
 msgstr "mode %qs diaplikasikan ke tipe yang tidak sesuai"
 
-#: c-family/c-attribs.c:1669
+#: c-family/c-attribs.c:1680
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsection attributes are not supported for this target"
 msgid "section attributes are not supported for this target"
 msgstr "%Jatribut daerah tidak didukung untuk target ini"
 
-#: c-family/c-attribs.c:1675
+#: c-family/c-attribs.c:1686
 #, gcc-internal-format
 msgid "section attribute not allowed for %q+D"
 msgstr "atribut daerah tidak diijinkan untuk %q+D"
 
-#: c-family/c-attribs.c:1681
+#: c-family/c-attribs.c:1692
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute argument not a string constant"
 msgid "section attribute argument not a string constant"
 msgstr "argumen atribut %qs bukan sebuah konstanta string"
 
-#: c-family/c-attribs.c:1690
+#: c-family/c-attribs.c:1701
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsection attribute cannot be specified for local variables"
 msgid "section attribute cannot be specified for local variables"
 msgstr "%J atribut daerah tidak dapat dispesifikasikan untuk variabel lokal"
 
-#: c-family/c-attribs.c:1700 config/bfin/bfin.c:4806 config/bfin/bfin.c:4857
+#: c-family/c-attribs.c:1711 config/bfin/bfin.c:4806 config/bfin/bfin.c:4857
 #: config/bfin/bfin.c:4883 config/bfin/bfin.c:4896
 #, gcc-internal-format
 msgid "section of %q+D conflicts with previous declaration"
 msgstr "daerah dari %q+D konflik dengan deklarasi sebelumnya"
 
-#: c-family/c-attribs.c:1708
+#: c-family/c-attribs.c:1719
 #, gcc-internal-format
 msgid "section of %q+D cannot be overridden"
 msgstr "daerah dari %q+D tidak dapat dioverridden"
 
-#: c-family/c-attribs.c:1773
+#: c-family/c-attribs.c:1784
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "requested alignment is too large"
 msgid "requested alignment %d is larger than %d"
 msgstr "alignmen yang diminta terlalu besar"
 
-#: c-family/c-attribs.c:1866
+#: c-family/c-attribs.c:1877
 #, gcc-internal-format
 msgid "alignment may not be specified for %q+D"
 msgstr "alignmen mungkin tidak dispesifikasikan untuk %q+D"
 
-#: c-family/c-attribs.c:1886
+#: c-family/c-attribs.c:1897
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute of '%s' conflicts with %s attribute at %L"
 msgid "ignoring attribute %<%E (%u)%> because it conflicts with attribute %<%E (%u)%>"
@@ -28700,316 +28728,316 @@
 msgstr "%s atribut dari '%s' konflik dengan %s atribut di %L"
 
 #. Do not error out for attribute warn_if_not_aligned.
-#: c-family/c-attribs.c:1891 c-family/c-attribs.c:1920
+#: c-family/c-attribs.c:1902 c-family/c-attribs.c:1931
 #, gcc-internal-format
 msgid "alignment for %q+D must be at least %d"
 msgstr "alignmen untuk %q+D harus paling tidak %d"
 
-#: c-family/c-attribs.c:1916
+#: c-family/c-attribs.c:1927
 #, gcc-internal-format
 msgid "alignment for %q+D was previously specified as %d and may not be decreased"
 msgstr "alignmen untuk %q+D telah dispesifikasikan sebelumnya sebagai %d dan tidak boleh diturunkan"
 
-#: c-family/c-attribs.c:1943
+#: c-family/c-attribs.c:1954
 #, fuzzy, gcc-internal-format
 #| msgid "alignment may not be specified for %q+D"
 msgid "%<warn_if_not_aligned%> may not be specified for %q+D"
 msgstr "alignmen mungkin tidak dispesifikasikan untuk %q+D"
 
-#: c-family/c-attribs.c:1986
+#: c-family/c-attribs.c:1997
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D cannot be declared weak"
 msgid "inline function %q+D declared weak"
 msgstr "fungsi inline %q+D tidak dapat dideklarasikan lemah"
 
-#: c-family/c-attribs.c:1991
+#: c-family/c-attribs.c:2002
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D cannot be declared weak"
 msgid "indirect function %q+D cannot be declared weak"
 msgstr "fungsi inline %q+D tidak dapat dideklarasikan lemah"
 
-#: c-family/c-attribs.c:2015
+#: c-family/c-attribs.c:2026
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to functions"
 msgid "%qE attribute is only applicable on functions"
 msgstr "atribut %qs hanya berlaku ke fungsi"
 
-#: c-family/c-attribs.c:2046
+#: c-family/c-attribs.c:2057
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D defined both normally and as an alias"
 msgid "%q+D defined both normally and as %qE attribute"
 msgstr "%q+D didefinisikan baik secara normal dan sebagai sebuah alias"
 
-#: c-family/c-attribs.c:2054
+#: c-family/c-attribs.c:2065
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be defaulted"
 msgid "weak %q+D cannot be defined %qE"
 msgstr "%qD tidak dapat dibakukan"
 
-#: c-family/c-attribs.c:2071 c-family/c-attribs.c:2582
+#: c-family/c-attribs.c:2082 c-family/c-attribs.c:2593
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute argument not a string constant"
 msgid "attribute %qE argument not a string"
 msgstr "argumen atribut %qs bukan sebuah konstanta string"
 
-#: c-family/c-attribs.c:2106
+#: c-family/c-attribs.c:2117
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after being called"
 msgid "%+qD declared alias after being used"
 msgstr "%q+D dideklarasikan inline setelah dipanggil"
 
-#: c-family/c-attribs.c:2108
+#: c-family/c-attribs.c:2119
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after being called"
 msgid "%+qD declared ifunc after being used"
 msgstr "%q+D dideklarasikan inline setelah dipanggil"
 
-#: c-family/c-attribs.c:2159
+#: c-family/c-attribs.c:2170
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D cannot be declared weak"
 msgid "indirect function %q+D cannot be declared weakref"
 msgstr "fungsi inline %q+D tidak dapat dideklarasikan lemah"
 
-#: c-family/c-attribs.c:2181
+#: c-family/c-attribs.c:2192
 #, fuzzy, gcc-internal-format
 #| msgid "%Jweakref attribute must appear before alias attribute"
 msgid "weakref attribute must appear before alias attribute"
 msgstr "%J weakref atribut harus muncul sebelum atribut alias"
 
-#: c-family/c-attribs.c:2193
+#: c-family/c-attribs.c:2204
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after being called"
 msgid "%+qD declared weakref after being used"
 msgstr "%q+D dideklarasikan inline setelah dipanggil"
 
-#: c-family/c-attribs.c:2217
+#: c-family/c-attribs.c:2228
 #, gcc-internal-format
 msgid "%qE attribute ignored on non-class types"
 msgstr "%qE atribut diabaikan dalam tipe bukan-class"
 
-#: c-family/c-attribs.c:2223
+#: c-family/c-attribs.c:2234
 #, gcc-internal-format
 msgid "%qE attribute ignored because %qT is already defined"
 msgstr "%qE atribut diabaikan karena %qT telah didefinisikan"
 
-#: c-family/c-attribs.c:2236
+#: c-family/c-attribs.c:2247
 #, gcc-internal-format
 msgid "visibility argument not a string"
 msgstr "visibility argumen bukan sebuah string"
 
-#: c-family/c-attribs.c:2248
+#: c-family/c-attribs.c:2259
 #, gcc-internal-format
 msgid "%qE attribute ignored on types"
 msgstr "%qE attribut diabaikan dalam tipe"
 
-#: c-family/c-attribs.c:2264
+#: c-family/c-attribs.c:2275
 #, gcc-internal-format
 msgid "visibility argument must be one of \"default\", \"hidden\", \"protected\" or \"internal\""
 msgstr "visibility argumen harus salah satu dari \"default\", \"hidden\", \"terproteksi\" atau \"internal\""
 
-#: c-family/c-attribs.c:2275
+#: c-family/c-attribs.c:2286
 #, gcc-internal-format
 msgid "%qD redeclared with different visibility"
 msgstr "%qD diredeklarasi dengan visibility berbeda"
 
-#: c-family/c-attribs.c:2278 c-family/c-attribs.c:2282
+#: c-family/c-attribs.c:2289 c-family/c-attribs.c:2293
 #, gcc-internal-format
 msgid "%qD was declared %qs which implies default visibility"
 msgstr "%qD telah dideklarasi %qs yang mengimplikasikan default visibility"
 
-#: c-family/c-attribs.c:2320
+#: c-family/c-attribs.c:2331
 #, gcc-internal-format
 msgid "tls_model argument not a string"
 msgstr "argumen tls_model bukan sebuah string"
 
-#: c-family/c-attribs.c:2333
+#: c-family/c-attribs.c:2344
 #, gcc-internal-format
 msgid "tls_model argument must be one of \"local-exec\", \"initial-exec\", \"local-dynamic\" or \"global-dynamic\""
 msgstr "tls_model argumen harus satu dari \"local-exec\", \"initial-exec\", \"local-dynamic\" atau \"global-dynamic\""
 
-#: c-family/c-attribs.c:2353 c-family/c-attribs.c:2656
-#: c-family/c-attribs.c:3497 config/m32c/m32c.c:2944
+#: c-family/c-attribs.c:2364 c-family/c-attribs.c:2667
+#: c-family/c-attribs.c:3508 config/m32c/m32c.c:2944
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qE attribute applies only to functions"
 msgid "%qE attribute applies only to functions"
 msgstr "atribut %J%qE berlaku hanya untuk fungsi"
 
-#: c-family/c-attribs.c:2417
+#: c-family/c-attribs.c:2428
 #, gcc-internal-format
 msgid "alloc_size parameter outside range"
 msgstr "alloc_size parameter diluar dari jangkauan"
 
-#: c-family/c-attribs.c:2443
+#: c-family/c-attribs.c:2454
 #, fuzzy, gcc-internal-format
 #| msgid "alloc_size parameter outside range"
 msgid "alloc_align parameter outside range"
 msgstr "alloc_size parameter diluar dari jangkauan"
 
-#: c-family/c-attribs.c:2467
+#: c-family/c-attribs.c:2478
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute argument not an integer constant"
 msgid "assume_aligned parameter not integer constant"
 msgstr "argumen atribut %qs bukan sebuah konstanta integer"
 
-#: c-family/c-attribs.c:2595
+#: c-family/c-attribs.c:2606
 #, gcc-internal-format
 msgid "only %<inbranch%> and %<notinbranch%> flags are allowed for %<__simd__%> attribute"
 msgstr ""
 
-#: c-family/c-attribs.c:2662 c-family/c-attribs.c:3503
+#: c-family/c-attribs.c:2673 c-family/c-attribs.c:3514
 #, fuzzy, gcc-internal-format
 #| msgid "%Jcan%'t set %qE attribute after definition"
 msgid "can%'t set %qE attribute after definition"
 msgstr "%J tidak dapat menset atribut %qE setelah definisi"
 
-#: c-family/c-attribs.c:2727
+#: c-family/c-attribs.c:2738
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored"
 msgid "%qE attribute duplicated"
 msgstr "%qE atribut diabaikan"
 
-#: c-family/c-attribs.c:2729
+#: c-family/c-attribs.c:2740
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored for %qE"
 msgid "%qE attribute follows %qE"
 msgstr "%qE atribut diabaikan untuk %qE"
 
-#: c-family/c-attribs.c:2828
+#: c-family/c-attribs.c:2839
 #, fuzzy, gcc-internal-format
 #| msgid "after previous declaration %q+D"
 msgid "type was previously declared %qE"
 msgstr "setelah deklarasi sebelumnya %q+D"
 
-#: c-family/c-attribs.c:2841 cp/class.c:4397
+#: c-family/c-attribs.c:2852 cp/class.c:4401
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
 msgstr "%qs hanya dapat dispesifikasikan untuk fungsi"
 
-#: c-family/c-attribs.c:2899
+#: c-family/c-attribs.c:2910
 #, fuzzy, gcc-internal-format
 #| msgid "cleanup argument not an identifier"
 msgid "%qE argument not an identifier"
 msgstr "membersihkan argumen bukan sebuah identifikasi"
 
-#: c-family/c-attribs.c:2910
+#: c-family/c-attribs.c:2921
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not declared in %qD"
 msgid "%qD is not compatible with %qD"
 msgstr "%qD tidak dideklarasikan dalam %qD"
 
-#: c-family/c-attribs.c:2913
+#: c-family/c-attribs.c:2924
 #, fuzzy, gcc-internal-format
 #| msgid "cleanup argument not a function"
 msgid "%qE argument is not a function"
 msgstr "membersihkan argumen bukan sebuah fungsi"
 
-#: c-family/c-attribs.c:2961
+#: c-family/c-attribs.c:2972
 #, fuzzy, gcc-internal-format
 #| msgid "version attribute is not a string"
 msgid "deprecated message is not a string"
 msgstr "atribut versi bukan sebuah string"
 
-#: c-family/c-attribs.c:3002
+#: c-family/c-attribs.c:3013
 #, gcc-internal-format
 msgid "%qE attribute ignored for %qE"
 msgstr "%qE atribut diabaikan untuk %qE"
 
-#: c-family/c-attribs.c:3065
+#: c-family/c-attribs.c:3076
 #, gcc-internal-format
 msgid "invalid vector type for attribute %qE"
 msgstr "tipe vektori tidak valid untuk atribut %qE"
 
-#: c-family/c-attribs.c:3071 ada/gcc-interface/utils.c:3896
+#: c-family/c-attribs.c:3082 ada/gcc-interface/utils.c:3899
 #, gcc-internal-format
 msgid "vector size not an integral multiple of component size"
 msgstr "ukuran vektor bukan sebuah kelipatan integral dari ukuran komponen"
 
-#: c-family/c-attribs.c:3077 ada/gcc-interface/utils.c:3903
+#: c-family/c-attribs.c:3088 ada/gcc-interface/utils.c:3906
 #, gcc-internal-format
 msgid "zero vector size"
 msgstr "ukuran vektor nol"
 
-#: c-family/c-attribs.c:3085
+#: c-family/c-attribs.c:3096
 #, gcc-internal-format
 msgid "number of components of the vector not a power of two"
 msgstr "jumlah dari komponen dari vektor bukan kelipatan dari dua"
 
-#: c-family/c-attribs.c:3118 ada/gcc-interface/utils.c:6092
+#: c-family/c-attribs.c:3129 ada/gcc-interface/utils.c:6098
 #, gcc-internal-format
 msgid "nonnull attribute without arguments on a non-prototype"
 msgstr "atribut bukan null tanpa argumen di sebuah bukan prototipe"
 
-#: c-family/c-attribs.c:3137 ada/gcc-interface/utils.c:6106
+#: c-family/c-attribs.c:3148 ada/gcc-interface/utils.c:6112
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument has invalid operand number (argument %lu)"
 msgstr "argumen bukan null memiliki jumlah operan tidak valid (argumen %lu)"
 
-#: c-family/c-attribs.c:3159 ada/gcc-interface/utils.c:6128
+#: c-family/c-attribs.c:3170 ada/gcc-interface/utils.c:6134
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument with out-of-range operand number (argument %lu, operand %lu)"
 msgstr "argumen bukan null dengan diluar-dari-jangkauan jumlah operan (argumen %lu, operan %lu)"
 
-#: c-family/c-attribs.c:3168 ada/gcc-interface/utils.c:6137
+#: c-family/c-attribs.c:3179 ada/gcc-interface/utils.c:6143
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument references non-pointer operand (argument %lu, operand %lu)"
 msgstr "referensi argumen nonnull operan bukan penunjuk (argumen %lu, operan %lu)"
 
-#: c-family/c-attribs.c:3208
+#: c-family/c-attribs.c:3219
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored for field of type %qT"
 msgid "%qE attribute ignored on objects of type %qT"
 msgstr "%qE atribut diabaikan untuk daerah dari tipe %qT"
 
-#: c-family/c-attribs.c:3216
+#: c-family/c-attribs.c:3227
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute does not apply to types"
 msgid "%qE attribute does not apply to functions"
 msgstr "atribut %qs tidak mengaplikasi ke tipe"
 
-#: c-family/c-attribs.c:3273
+#: c-family/c-attribs.c:3284
 #, gcc-internal-format
 msgid "cleanup argument not an identifier"
 msgstr "membersihkan argumen bukan sebuah identifikasi"
 
-#: c-family/c-attribs.c:3280
+#: c-family/c-attribs.c:3291
 #, gcc-internal-format
 msgid "cleanup argument not a function"
 msgstr "membersihkan argumen bukan sebuah fungsi"
 
-#: c-family/c-attribs.c:3317
+#: c-family/c-attribs.c:3328
 #, gcc-internal-format
 msgid "%qE attribute requires prototypes with named arguments"
 msgstr "%qE atribut membutuhkan prototipe dengan argumen bernama"
 
-#: c-family/c-attribs.c:3325
+#: c-family/c-attribs.c:3336
 #, gcc-internal-format
 msgid "%qE attribute only applies to variadic functions"
 msgstr "%qE atribut hanya berlaku untuk fungsi variadic"
 
-#: c-family/c-attribs.c:3341 ada/gcc-interface/utils.c:6179
+#: c-family/c-attribs.c:3352 ada/gcc-interface/utils.c:6185
 #, gcc-internal-format
 msgid "requested position is not an integer constant"
 msgstr "posisi yang diminta bukan sebuah konstanta integer"
 
-#: c-family/c-attribs.c:3349 ada/gcc-interface/utils.c:6186
+#: c-family/c-attribs.c:3360 ada/gcc-interface/utils.c:6192
 #, gcc-internal-format
 msgid "requested position is less than zero"
 msgstr "posisi yang diminta lebih kecil dari nol"
 
-#: c-family/c-attribs.c:3404
+#: c-family/c-attribs.c:3415
 #, fuzzy, gcc-internal-format
 #| msgid "Expected binding attribute at %C"
 msgid "empty string in attribute %<target%>"
 msgstr "Diduga atribut binding di %C"
 
-#: c-family/c-attribs.c:3520
+#: c-family/c-attribs.c:3531
 #, fuzzy, gcc-internal-format
 #| msgid "return-statement with a value, in function returning 'void'"
 msgid "returns_nonnull attribute on a function not returning a pointer"
 msgstr "pernyataan kembali dengan sebuah nilai, dalam fungsi mengembalikan 'void'"
 
-#: c-family/c-attribs.c:3535
+#: c-family/c-attribs.c:3546
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to function types"
 msgid "%qE attribute is only valid on %<struct%> type"
@@ -29057,13 +29085,13 @@
 msgid "__builtin_shuffle argument vector(s) inner type must have the same size as inner type of the mask"
 msgstr ""
 
-#: c-family/c-common.c:1262 c-family/c-warn.c:1194
+#: c-family/c-common.c:1262 c-family/c-warn.c:1202
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT discards qualifiers"
 msgid "unsigned conversion from %qT to %qT changes value from %qE to %qE"
 msgstr "konversi dari %qT ke %qT mengabaikan kualifikasi"
 
-#: c-family/c-common.c:1267 c-family/c-warn.c:1202
+#: c-family/c-common.c:1267 c-family/c-warn.c:1210
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "unsigned conversion from %qT to %qT changes the value of %qE"
@@ -29198,7 +29226,7 @@
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "disarankan parentheses disekitar assignmen digunakan sebagai nilai kebenaran"
 
-#: c-family/c-common.c:3518 c/c-decl.c:4325 c/c-decl.c:6430 c/c-typeck.c:14177
+#: c-family/c-common.c:3518 c/c-decl.c:4325 c/c-decl.c:6450 c/c-typeck.c:14182
 #, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr "penggunaan tidak valid dari %<restrict%>"
@@ -29283,7 +29311,7 @@
 msgid "duplicate case value"
 msgstr "duplikasi nilai case"
 
-#: c-family/c-common.c:4867 c-family/c-warn.c:2216
+#: c-family/c-common.c:4867 c-family/c-warn.c:2225
 #, fuzzy, gcc-internal-format
 #| msgid "%Jpreviously used here"
 msgid "previously used here"
@@ -29332,214 +29360,214 @@
 msgid "missing sentinel in function call"
 msgstr "hilang sentinel dalam pemanggilan fungsi"
 
-#: c-family/c-common.c:5411
+#: c-family/c-common.c:5409
 #, gcc-internal-format, gfc-internal-format
 msgid "null argument where non-null required (argument %lu)"
 msgstr "argumen null dimana bukan null dibutuhkan (argumen %lu)"
 
-#: c-family/c-common.c:5506 c-family/c-common.c:5553
+#: c-family/c-common.c:5504 c-family/c-common.c:5551
 #, fuzzy, gcc-internal-format
 #| msgid "Bad option %s to pragma attribute"
 msgid "bad option %qs to attribute %<optimize%>"
 msgstr "Pilihan %s buruk untuk atribut pragma"
 
-#: c-family/c-common.c:5509 c-family/c-common.c:5557
+#: c-family/c-common.c:5507 c-family/c-common.c:5555
 #, fuzzy, gcc-internal-format
 #| msgid "Bad option %s to pragma attribute"
 msgid "bad option %qs to pragma %<optimize%>"
 msgstr "Pilihan %s buruk untuk atribut pragma"
 
-#: c-family/c-common.c:5589
+#: c-family/c-common.c:5587
 #, gcc-internal-format
 msgid "%<fallthrough%> attribute specified multiple times"
 msgstr ""
 
-#: c-family/c-common.c:5593
+#: c-family/c-common.c:5591
 #, gcc-internal-format
 msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr ""
 
-#: c-family/c-common.c:5733 c-family/c-common.c:6485 c-family/c-common.c:6558
+#: c-family/c-common.c:5731 c-family/c-common.c:6477 c-family/c-common.c:6550
 #: c/c-typeck.c:3555
 #, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr "terlalu sediki argumen ke fungsi %qE"
 
-#: c-family/c-common.c:5738 c-family/c-common.c:6584 c/c-typeck.c:3284
+#: c-family/c-common.c:5736 c-family/c-common.c:6576 c/c-typeck.c:3284
 #, gcc-internal-format
 msgid "too many arguments to function %qE"
 msgstr "terlalu banyak argumen ke fungsi %qE"
 
-#: c-family/c-common.c:5769
+#: c-family/c-common.c:5767
 #, fuzzy, gcc-internal-format
 #| msgid "third argument to %<__builtin_prefetch%> must be a constant"
 msgid "third argument to function %qE must be a constant integer"
 msgstr "argumen ketiga ke %<__builtin_prefetch%> harus berupa sebuah konstan"
 
-#: c-family/c-common.c:5794
+#: c-family/c-common.c:5792
 #, gcc-internal-format
 msgid "second argument to function %qE must be a constant integer power of 2 between %qi and %qu bits"
 msgstr ""
 
-#: c-family/c-common.c:5815 c-family/c-common.c:5859
+#: c-family/c-common.c:5813 c-family/c-common.c:5857
 #, gcc-internal-format
 msgid "non-floating-point argument in call to function %qE"
 msgstr "argumen bukan-titik-pecahan dalam panggilan ke fungsi %qE"
 
-#: c-family/c-common.c:5838
+#: c-family/c-common.c:5836
 #, gcc-internal-format
 msgid "non-floating-point arguments in call to function %qE"
 msgstr "argumen bukan-titik-pecahan dalam panggilan ke fungsi %qE"
 
-#: c-family/c-common.c:5852
+#: c-family/c-common.c:5850
 #, gcc-internal-format
 msgid "non-const integer argument %u in call to function %qE"
 msgstr "argumen bukan-konstanta integer %u dalam panggilan ke fungsi %qE"
 
-#: c-family/c-common.c:5872
+#: c-family/c-common.c:5870
 #, fuzzy, gcc-internal-format
 #| msgid "non-const integer argument %u in call to function %qE"
 msgid "non-integer argument 3 in call to function %qE"
 msgstr "argumen bukan-konstanta integer %u dalam panggilan ke fungsi %qE"
 
-#: c-family/c-common.c:5889 c-family/c-common.c:5925
+#: c-family/c-common.c:5887 c-family/c-common.c:5923
 #, fuzzy, gcc-internal-format
 #| msgid "%Hdifference between %qE and %qD does not have integer type"
 msgid "argument %u in call to function %qE does not have integral type"
 msgstr "%Hperbedaan antara %qE dan %qD tidak memiliki tipe integer"
 
-#: c-family/c-common.c:5896
+#: c-family/c-common.c:5894
 #, gcc-internal-format
 msgid "argument 3 in call to function %qE does not have pointer to integral type"
 msgstr ""
 
-#: c-family/c-common.c:5902
+#: c-family/c-common.c:5900
 #, fuzzy, gcc-internal-format
 #| msgid "call to function %qD which throws incomplete type %q#T"
 msgid "argument 3 in call to function %qE has pointer to enumerated type"
 msgstr "panggilan ke fungsi %qD yang melemparkan tipe tidak lengkap %q#T"
 
-#: c-family/c-common.c:5908
+#: c-family/c-common.c:5906
 #, gcc-internal-format
 msgid "argument 3 in call to function %qE has pointer to boolean type"
 msgstr ""
 
-#: c-family/c-common.c:5931
+#: c-family/c-common.c:5929
 #, fuzzy, gcc-internal-format
 #| msgid "non-const integer argument %u in call to function %qE"
 msgid "argument 3 in call to function %qE has enumerated type"
 msgstr "argumen bukan-konstanta integer %u dalam panggilan ke fungsi %qE"
 
-#: c-family/c-common.c:5937
+#: c-family/c-common.c:5935
 #, fuzzy, gcc-internal-format
 #| msgid "non-const integer argument %u in call to function %qE"
 msgid "argument 3 in call to function %qE has boolean type"
 msgstr "argumen bukan-konstanta integer %u dalam panggilan ke fungsi %qE"
 
-#: c-family/c-common.c:6184
+#: c-family/c-common.c:6183
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to static data member %qD"
 msgstr "tidak dapat menjalankan %<offsetof%> ke anggota data statis %qD"
 
-#: c-family/c-common.c:6189
+#: c-family/c-common.c:6188
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> when %<operator[]%> is overloaded"
 msgstr "tidak dapat mengaplikasikan %<offsetof%> ketika %<operator[]%> adalah overloaded"
 
-#: c-family/c-common.c:6196
+#: c-family/c-common.c:6195
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply %<offsetof%> to member function %qD"
 msgid "cannot apply %<offsetof%> to a non constant address"
 msgstr "tidak dapat mengaplikasikan %<offsetof%> ke anggota fungsi %qD"
 
-#: c-family/c-common.c:6209
+#: c-family/c-common.c:6208
 #, gcc-internal-format
 msgid "attempt to take address of bit-field structure member %qD"
 msgstr "mencoba untuk mengambil alamat dari bit-field anggota struktur %qD"
 
-#: c-family/c-common.c:6261
+#: c-family/c-common.c:6260
 #, gcc-internal-format
 msgid "index %E denotes an offset greater than size of %qT"
 msgstr ""
 
-#: c-family/c-common.c:6427 cp/init.c:3004 cp/init.c:3023
+#: c-family/c-common.c:6419 cp/init.c:3020 cp/init.c:3039
 #, gcc-internal-format
 msgid "size of array is too large"
 msgstr "ukuran dari array terlalu besar"
 
-#: c-family/c-common.c:6517
+#: c-family/c-common.c:6509
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible type for argument %d of %qE"
 msgid "operand type %qT is incompatible with argument %d of %qE"
 msgstr "tipe tidak kompatibel untuk argumen %d dari %qE"
 
-#: c-family/c-common.c:6651
+#: c-family/c-common.c:6643
 #, fuzzy, gcc-internal-format
 #| msgid "not enough arguments to function %qE"
 msgid "incorrect number of arguments to function %qE"
 msgstr "tidak cukup argumen ke fungsi %qE"
 
-#: c-family/c-common.c:6665
+#: c-family/c-common.c:6657
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs must be a 2-bit unsigned literal"
 msgid "argument 1 of %qE must be a non-void pointer type"
 msgstr "argumen ke %qs harus berupa sebuah 2 bit unsigned literal"
 
-#: c-family/c-common.c:6674
+#: c-family/c-common.c:6666
 #, fuzzy, gcc-internal-format
 #| msgid "%Kfirst argument of %D must be a pointer, second integer constant"
 msgid "argument 1 of %qE must be a pointer to a constant size type"
 msgstr "%K argumen pertama dari %D harus berupa sebuah penunjuk, integer kedua konstanta"
 
-#: c-family/c-common.c:6685
+#: c-family/c-common.c:6677
 #, fuzzy, gcc-internal-format
 #| msgid "%Kfirst argument of %D must be a pointer, second integer constant"
 msgid "argument 1 of %qE must be a pointer to a nonzero size object"
 msgstr "%K argumen pertama dari %D harus berupa sebuah penunjuk, integer kedua konstanta"
 
-#: c-family/c-common.c:6706
+#: c-family/c-common.c:6698
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE from incompatible pointer type"
 msgid "argument %d of %qE must be a pointer type"
 msgstr "melewatkan argumen %d dari %qE dari tipe penunjuk yang tidak kompatibel"
 
-#: c-family/c-common.c:6714
+#: c-family/c-common.c:6706
 #, fuzzy, gcc-internal-format
 #| msgid "argument %d of %qE might be a candidate for a format attribute"
 msgid "argument %d of %qE must be a pointer to a constant size type"
 msgstr "argumen %d dari %qE mungkin menjadi sebuah kandidat untuk sebuah format atribut"
 
-#: c-family/c-common.c:6720
+#: c-family/c-common.c:6712
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE makes integer from pointer without a cast"
 msgid "argument %d of %qE must not be a pointer to a function"
 msgstr "melewatkan argumen %d dari %qE membuat integer dari penunjuk tanpa sebuah cast"
 
-#: c-family/c-common.c:6728
+#: c-family/c-common.c:6720
 #, fuzzy, gcc-internal-format
 #| msgid "Type/rank mismatch in argument '%s' at %L"
 msgid "size mismatch in argument %d of %qE"
 msgstr "Tipe/tingkat tidak cocok dalam argumen '%s' di %L"
 
-#: c-family/c-common.c:6740
+#: c-family/c-common.c:6732
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible type for argument %d of %qE"
 msgid "non-integer memory model argument %d of %qE"
 msgstr "tipe tidak kompatibel untuk argumen %d dari %qE"
 
-#: c-family/c-common.c:6753
+#: c-family/c-common.c:6745
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument of %qs"
 msgid "invalid memory model argument %d of %qE"
 msgstr "tipe argumen tidak valid dari %qs"
 
-#: c-family/c-common.c:7672
+#: c-family/c-common.c:7664
 #, fuzzy, gcc-internal-format
 #| msgid "index in dimension %d is out of bounds at %L"
 msgid "index value is out of bound"
 msgstr "indeks dalam dimensi %d diluar dari jangkauan di %L"
 
-#: c-family/c-common.c:7714 c-family/c-common.c:7763 c-family/c-common.c:7779
+#: c-family/c-common.c:7706 c-family/c-common.c:7755 c-family/c-common.c:7771
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "conversion of scalar %qT to vector %qT involves truncation"
@@ -29547,25 +29575,25 @@
 
 #. Reject arguments that are built-in functions with
 #. no library fallback.
-#: c-family/c-common.c:7867
+#: c-family/c-common.c:7859
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D cannot be declared weak"
 msgid "built-in function %qE must be directly called"
 msgstr "fungsi inline %q+D tidak dapat dideklarasikan lemah"
 
-#: c-family/c-common.c:7889 c/c-decl.c:6177
+#: c-family/c-common.c:7881 c/c-decl.c:6197
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "size of array %qE is too large"
 msgstr "ukuran dari array %qs adalah terlalu besar"
 
-#: c-family/c-common.c:7891 c/c-decl.c:6180
+#: c-family/c-common.c:7883 c/c-decl.c:6200
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is too large"
 msgid "size of unnamed array is too large"
 msgstr "ukuran dari array terlalu besar"
 
-#: c-family/c-common.c:7921
+#: c-family/c-common.c:7913
 #, gcc-internal-format
 msgid "environment variable SOURCE_DATE_EPOCH must expand to a non-negative integer less than or equal to %wd"
 msgstr ""
@@ -30104,7 +30132,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr ""
 
-#: c-family/c-omp.c:557 cp/semantics.c:8186
+#: c-family/c-omp.c:557 cp/semantics.c:8189
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "tipe tidak valid untuk iterasi variabel %qE"
@@ -30120,22 +30148,22 @@
 msgid "%qE is not initialized"
 msgstr "%qE tidak terinisialisasi"
 
-#: c-family/c-omp.c:599 cp/semantics.c:8076
+#: c-family/c-omp.c:599 cp/semantics.c:8079
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "hilang predikat pengontrol"
 
-#: c-family/c-omp.c:704 cp/semantics.c:7732
+#: c-family/c-omp.c:704 cp/semantics.c:7735
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "predikat pengontrol tidak valid"
 
-#: c-family/c-omp.c:711 cp/semantics.c:8082
+#: c-family/c-omp.c:711 cp/semantics.c:8085
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "hilang ekspresi peningkatan"
 
-#: c-family/c-omp.c:775 cp/semantics.c:7847
+#: c-family/c-omp.c:775 cp/semantics.c:7850
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "ekspresi peningkatan tidak valid"
@@ -30195,114 +30223,129 @@
 msgid "%<-Wabi=1%> is not supported, using =2"
 msgstr "static tidak didukung dalam TPF-OS"
 
-#: c-family/c-opts.c:612 fortran/cpp.c:350
+#: c-family/c-opts.c:610 fortran/cpp.c:350
 #, gcc-internal-format
 msgid "output filename specified twice"
 msgstr "nama berkas keluaran dispesifikasikan dua kali"
 
-#: c-family/c-opts.c:799
+#: c-family/c-opts.c:797
 #, gcc-internal-format
 msgid "-fexcess-precision=standard for C++"
 msgstr ""
 
-#: c-family/c-opts.c:834
+#: c-family/c-opts.c:832
 #, gcc-internal-format
 msgid "-fno-gnu89-inline is only supported in GNU99 or C99 mode"
 msgstr "-fno-gnu89-inline hanya didukung dalam mode GNU99 ata C99"
 
-#: c-family/c-opts.c:880
+#: c-family/c-opts.c:878
 #, gcc-internal-format
 msgid "-Wformat-y2k ignored without -Wformat"
 msgstr "-Wformat-y2k diabaikan tanpa -Wformat"
 
-#: c-family/c-opts.c:882
+#: c-family/c-opts.c:880
 #, gcc-internal-format
 msgid "-Wformat-extra-args ignored without -Wformat"
 msgstr "-Wformat-extra-args diabaikan tanpa -Wformat"
 
-#: c-family/c-opts.c:884
+#: c-family/c-opts.c:882
 #, gcc-internal-format
 msgid "-Wformat-zero-length ignored without -Wformat"
 msgstr "-Wformat-zero-length diabaikan tanpa -Wformat"
 
-#: c-family/c-opts.c:886
+#: c-family/c-opts.c:884
 #, gcc-internal-format
 msgid "-Wformat-nonliteral ignored without -Wformat"
 msgstr "-Wformat-nonliteral dibaikan tanpa -Wformat"
 
-#: c-family/c-opts.c:888
+#: c-family/c-opts.c:886
 #, gcc-internal-format
 msgid "-Wformat-contains-nul ignored without -Wformat"
 msgstr "-Wformat-contains-nul diabaikan tanpa -Wformat"
 
-#: c-family/c-opts.c:890
+#: c-family/c-opts.c:888
 #, gcc-internal-format
 msgid "-Wformat-security ignored without -Wformat"
 msgstr "-Wformat-security diabaikan tanpa -Wformat"
 
-#: c-family/c-opts.c:928
+#: c-family/c-opts.c:918
 #, fuzzy, gcc-internal-format
 #| msgid "-falign-loops=%d is not supported"
 msgid "%<-fabi-compat-version=1%> is not supported, using =2"
 msgstr "-falign-loops=%d tidak didukung"
 
-#: c-family/c-opts.c:988
+#: c-family/c-opts.c:944
+#, gcc-internal-format
+msgid "-Wabi won't warn about anything"
+msgstr ""
+
+#: c-family/c-opts.c:946
+#, gcc-internal-format
+msgid "-Wabi warns about differences from the most up-to-date ABI, which is also used by default"
+msgstr ""
+
+#: c-family/c-opts.c:949
+#, gcc-internal-format
+msgid "use e.g. -Wabi=11 to warn about changes from GCC 7"
+msgstr ""
+
+#: c-family/c-opts.c:1003
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "external TLS initialization functions not supported on this target"
 msgstr "batas stact tidak didukung dalam target ini"
 
-#: c-family/c-opts.c:1001
+#: c-family/c-opts.c:1016
 #, gcc-internal-format, gfc-internal-format
 msgid "too many filenames given.  Type %s --help for usage"
 msgstr "terlalu banyak nama berkas diberikan. Ketik %s --help untuk penggunaan"
 
-#: c-family/c-opts.c:1016
+#: c-family/c-opts.c:1031
 #, gcc-internal-format
 msgid "opening output file %s: %m"
 msgstr "membuka berkas keluaran %s: %m"
 
-#: c-family/c-opts.c:1036
+#: c-family/c-opts.c:1051
 #, gcc-internal-format, gfc-internal-format
 msgid "the \"%s\" debug format cannot be used with pre-compiled headers"
 msgstr ""
 
-#: c-family/c-opts.c:1190
+#: c-family/c-opts.c:1205
 #, gcc-internal-format
 msgid "opening dependency file %s: %m"
 msgstr "membuka berkas  ketergantungan %s: %m"
 
-#: c-family/c-opts.c:1201
+#: c-family/c-opts.c:1216
 #, gcc-internal-format
 msgid "closing dependency file %s: %m"
 msgstr "menutup berkas ketergantungan %s: %m"
 
-#: c-family/c-opts.c:1204
+#: c-family/c-opts.c:1219
 #, gcc-internal-format
 msgid "when writing output to %s: %m"
 msgstr "ketika menulis keluaran ke %s: %m"
 
-#: c-family/c-opts.c:1284
+#: c-family/c-opts.c:1299
 #, gcc-internal-format
 msgid "to generate dependencies you must specify either -M or -MM"
 msgstr "untuk menghasilkan ketergantungan anda harus menspesifikasikan baik -M atau -MM"
 
-#: c-family/c-opts.c:1307
+#: c-family/c-opts.c:1322
 #, gcc-internal-format
 msgid "-MG may only be used with -M or -MM"
 msgstr "-MG hanya boleh digunakan dengan -M atau -MM"
 
-#: c-family/c-opts.c:1340
+#: c-family/c-opts.c:1355
 #, gcc-internal-format
 msgid "-fdirectives-only is incompatible with -Wunused_macros"
 msgstr "-fdirectives-only tidak kompatibel dengan -Wunused_macros"
 
-#: c-family/c-opts.c:1342
+#: c-family/c-opts.c:1357
 #, gcc-internal-format
 msgid "-fdirectives-only is incompatible with -traditional"
 msgstr "-fdirectives-only tidak kompatibel dengan -traditional"
 
-#: c-family/c-opts.c:1534
+#: c-family/c-opts.c:1549
 #, gcc-internal-format
 msgid "too late for # directive to set debug directory"
 msgstr "terlalu terlambat untuk #  direktif untuk menset direktori debug"
@@ -30703,769 +30746,769 @@
 msgid "wrong type argument to %s"
 msgstr "tipe argumen salah ke abs"
 
-#: c-family/c-warn.c:53 c-family/c-warn.c:66 cp/constexpr.c:1847
+#: c-family/c-warn.c:54 c-family/c-warn.c:67 cp/constexpr.c:1847
 #: cp/constexpr.c:4099
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "overflow dalam konstanta ekspresi"
 
-#: c-family/c-warn.c:93
+#: c-family/c-warn.c:94
 #, fuzzy, gcc-internal-format
 #| msgid "integer overflow in expression"
 msgid "integer overflow in expression %qE of type %qT results in %qE"
 msgstr "integer overflow dalam ekspresi"
 
-#: c-family/c-warn.c:95
+#: c-family/c-warn.c:96
 #, fuzzy, gcc-internal-format
 #| msgid "integer overflow in expression"
 msgid "integer overflow in expression of type %qT results in %qE"
 msgstr "integer overflow dalam ekspresi"
 
-#: c-family/c-warn.c:101
+#: c-family/c-warn.c:102
 #, fuzzy, gcc-internal-format
 #| msgid "floating point overflow in expression"
 msgid "floating point overflow in expression %qE of type %qT results in %qE"
 msgstr "floating point overflow dalam ekspresi"
 
-#: c-family/c-warn.c:103
+#: c-family/c-warn.c:104
 #, fuzzy, gcc-internal-format
 #| msgid "floating point overflow in expression"
 msgid "floating point overflow in expression of type %qT results in %qE"
 msgstr "floating point overflow dalam ekspresi"
 
-#: c-family/c-warn.c:109
+#: c-family/c-warn.c:110
 #, fuzzy, gcc-internal-format
 #| msgid "fixed-point overflow in expression"
 msgid "fixed-point overflow in expression %qE of type %qT results in %qE"
 msgstr "fixed-point overflow dalam ekspresi"
 
-#: c-family/c-warn.c:111
+#: c-family/c-warn.c:112
 #, fuzzy, gcc-internal-format
 #| msgid "fixed-point overflow in expression"
 msgid "fixed-point overflow in expression of type %qT results in %qE"
 msgstr "fixed-point overflow dalam ekspresi"
 
-#: c-family/c-warn.c:117
+#: c-family/c-warn.c:118
 #, fuzzy, gcc-internal-format
 #| msgid "vector overflow in expression"
 msgid "vector overflow in expression %qE of type %qT results in %qE"
 msgstr "vektor overflow dalam ekspresi"
 
-#: c-family/c-warn.c:119
+#: c-family/c-warn.c:120
 #, fuzzy, gcc-internal-format
 #| msgid "vector overflow in expression"
 msgid "vector overflow in expression of type %qT results in %qE"
 msgstr "vektor overflow dalam ekspresi"
 
-#: c-family/c-warn.c:126
+#: c-family/c-warn.c:127
 #, fuzzy, gcc-internal-format
 #| msgid "complex integer overflow in expression"
 msgid "complex integer overflow in expression %qE of type %qT results in %qE"
 msgstr "kompleks integer overflow dalam ekspresi"
 
-#: c-family/c-warn.c:128
+#: c-family/c-warn.c:129
 #, fuzzy, gcc-internal-format
 #| msgid "complex integer overflow in expression"
 msgid "complex integer overflow in expression of type %qT results in %qE"
 msgstr "kompleks integer overflow dalam ekspresi"
 
-#: c-family/c-warn.c:132
+#: c-family/c-warn.c:133
 #, fuzzy, gcc-internal-format
 #| msgid "complex floating point overflow in expression"
 msgid "complex floating point overflow in expression %qE of type %qT results in %qE"
 msgstr "kompleks floating point overflow dalam ekspresi"
 
-#: c-family/c-warn.c:134
+#: c-family/c-warn.c:135
 #, fuzzy, gcc-internal-format
 #| msgid "complex floating point overflow in expression"
 msgid "complex floating point overflow in expression of type %qT results in %qE"
 msgstr "kompleks floating point overflow dalam ekspresi"
 
-#: c-family/c-warn.c:216
+#: c-family/c-warn.c:217
 #, gcc-internal-format
 msgid "logical %<or%> applied to non-boolean constant"
 msgstr ""
 
-#: c-family/c-warn.c:219
+#: c-family/c-warn.c:220
 #, gcc-internal-format
 msgid "logical %<and%> applied to non-boolean constant"
 msgstr ""
 
-#: c-family/c-warn.c:289
+#: c-family/c-warn.c:290
 #, fuzzy, gcc-internal-format
 #| msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgid "logical %<or%> of collectively exhaustive tests is always true"
 msgstr "%<and%> dari mutually eksklusif test-sama selalu 0"
 
-#: c-family/c-warn.c:293
+#: c-family/c-warn.c:294
 #, fuzzy, gcc-internal-format
 #| msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgid "logical %<and%> of mutually exclusive tests is always false"
 msgstr "%<and%> dari mutually eksklusif test-sama selalu 0"
 
-#: c-family/c-warn.c:303
+#: c-family/c-warn.c:304
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand in unary expression"
 msgid "logical %<or%> of equal expressions"
 msgstr "operan tidak valid dalam ekspresi unary"
 
-#: c-family/c-warn.c:306
+#: c-family/c-warn.c:307
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand in unary expression"
 msgid "logical %<and%> of equal expressions"
 msgstr "operan tidak valid dalam ekspresi unary"
 
-#: c-family/c-warn.c:384
+#: c-family/c-warn.c:385
 #, gcc-internal-format
 msgid "bitwise comparison always evaluates to false"
 msgstr ""
 
-#: c-family/c-warn.c:387
+#: c-family/c-warn.c:388
 #, fuzzy, gcc-internal-format
 #| msgid "the address of %qD will always evaluate as %<true%>"
 msgid "bitwise comparison always evaluates to true"
 msgstr "alamat dari %qD akan selalu dievaluasi sebagai %<true%>"
 
-#: c-family/c-warn.c:441
+#: c-family/c-warn.c:442
 #, fuzzy, gcc-internal-format
 #| msgid "user-defined %qD always evaluates both arguments"
 msgid "self-comparison always evaluates to true"
 msgstr "definisi-pengguna %qD selalu mengevaluasikan kedua argumen"
 
-#: c-family/c-warn.c:444
+#: c-family/c-warn.c:445
 #, fuzzy, gcc-internal-format
 #| msgid "user-defined %qD always evaluates both arguments"
 msgid "self-comparison always evaluates to false"
 msgstr "definisi-pengguna %qD selalu mengevaluasikan kedua argumen"
 
-#: c-family/c-warn.c:494
+#: c-family/c-warn.c:495
 #, gcc-internal-format
 msgid "logical not is only applied to the left hand side of comparison"
 msgstr ""
 
-#: c-family/c-warn.c:502
+#: c-family/c-warn.c:503
 #, gcc-internal-format
 msgid "add parentheses around left hand side expression to silence this warning"
 msgstr ""
 
-#: c-family/c-warn.c:636
+#: c-family/c-warn.c:637
 #, gcc-internal-format
 msgid "type-punning to incomplete type might break strict-aliasing rules"
 msgstr "tipe-punning untuk tipe tidak lengkap mungkin melanggar aturan strict aliasing"
 
-#: c-family/c-warn.c:654
+#: c-family/c-warn.c:655
 #, gcc-internal-format
 msgid "dereferencing type-punned pointer will break strict-aliasing rules"
 msgstr "dereferencing tipe-punned penunjuk akan melanggar aturan strict aliasing"
 
-#: c-family/c-warn.c:662 c-family/c-warn.c:680
+#: c-family/c-warn.c:663 c-family/c-warn.c:681
 #, gcc-internal-format
 msgid "dereferencing type-punned pointer might break strict-aliasing rules"
 msgstr "dereferencing tipe-punned penunjuk akan melanggar aturan strict aliasing"
 
-#: c-family/c-warn.c:803
+#: c-family/c-warn.c:811
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to use the size of the destination?"
 msgstr ""
 
-#: c-family/c-warn.c:834
+#: c-family/c-warn.c:842
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the destination; did you mean to remove the addressof?"
 msgstr ""
 
-#: c-family/c-warn.c:841
+#: c-family/c-warn.c:849
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the destination; did you mean to provide an explicit length?"
 msgstr ""
 
-#: c-family/c-warn.c:846
+#: c-family/c-warn.c:854
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the destination; did you mean to dereference it?"
 msgstr ""
 
-#: c-family/c-warn.c:858
+#: c-family/c-warn.c:866
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the destination; expected %qT or an explicit length"
 msgstr ""
 
-#: c-family/c-warn.c:874
+#: c-family/c-warn.c:882
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to remove the addressof?"
 msgstr ""
 
-#: c-family/c-warn.c:881
+#: c-family/c-warn.c:889
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to provide an explicit length?"
 msgstr ""
 
-#: c-family/c-warn.c:886
+#: c-family/c-warn.c:894
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to dereference it?"
 msgstr ""
 
-#: c-family/c-warn.c:898
+#: c-family/c-warn.c:906
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the source; expected %qT or an explicit length"
 msgstr ""
 
-#: c-family/c-warn.c:914
+#: c-family/c-warn.c:922
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the first source; did you mean to remove the addressof?"
 msgstr ""
 
-#: c-family/c-warn.c:921
+#: c-family/c-warn.c:929
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the first source; did you mean to provide an explicit length?"
 msgstr ""
 
-#: c-family/c-warn.c:926
+#: c-family/c-warn.c:934
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the first source; did you mean to dereference it?"
 msgstr ""
 
-#: c-family/c-warn.c:938
+#: c-family/c-warn.c:946
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the first source; expected %qT or an explicit length"
 msgstr ""
 
-#: c-family/c-warn.c:954
+#: c-family/c-warn.c:962
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the second source; did you mean to remove the addressof?"
 msgstr ""
 
-#: c-family/c-warn.c:961
+#: c-family/c-warn.c:969
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the second source; did you mean to provide an explicit length?"
 msgstr ""
 
-#: c-family/c-warn.c:966
+#: c-family/c-warn.c:974
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the second source; did you mean to dereference it?"
 msgstr ""
 
-#: c-family/c-warn.c:978
+#: c-family/c-warn.c:986
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the second source; expected %qT or an explicit length"
 msgstr ""
 
-#: c-family/c-warn.c:1007 c-family/c-warn.c:1014
+#: c-family/c-warn.c:1015 c-family/c-warn.c:1022
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter type %qT"
 msgid "%<_Atomic%>-qualified parameter type %qT of %q+D"
 msgstr "tipe parameter %qT tidak valid"
 
-#: c-family/c-warn.c:1024
+#: c-family/c-warn.c:1032
 #, gcc-internal-format
 msgid "first argument of %q+D should be %<int%>"
 msgstr "argumen pertama dari %q+D seharusnya %<int%>"
 
-#: c-family/c-warn.c:1033
+#: c-family/c-warn.c:1041
 #, gcc-internal-format
 msgid "second argument of %q+D should be %<char **%>"
 msgstr "argumen kedua dari %q+D seharusnya %<char **%>"
 
-#: c-family/c-warn.c:1042
+#: c-family/c-warn.c:1050
 #, gcc-internal-format
 msgid "third argument of %q+D should probably be %<char **%>"
 msgstr "argumen ketiga dari %q+D seharusnya %<char **%>"
 
-#: c-family/c-warn.c:1053
+#: c-family/c-warn.c:1061
 #, gcc-internal-format
 msgid "%q+D takes only zero or two arguments"
 msgstr "%q+D hanya mengambil nol atau dua argumen"
 
-#: c-family/c-warn.c:1057
+#: c-family/c-warn.c:1065
 #, fuzzy, gcc-internal-format
 #| msgid "field %qs declared as a function"
 msgid "%q+D declared as variadic function"
 msgstr "field %qs dideklarasikan sebagai sebuah fungsi"
 
-#: c-family/c-warn.c:1099
+#: c-family/c-warn.c:1107
 #, gcc-internal-format
 msgid "conversion to %qT from boolean expression"
 msgstr "konversi ke %qT dari ekspresi boolean"
 
-#: c-family/c-warn.c:1117 c-family/c-warn.c:1192
+#: c-family/c-warn.c:1125 c-family/c-warn.c:1200
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT discards qualifiers"
 msgid "conversion from %qT to %qT changes value from %qE to %qE"
 msgstr "konversi dari %qT ke %qT mengabaikan kualifikasi"
 
-#: c-family/c-warn.c:1121 c-family/c-warn.c:1200
+#: c-family/c-warn.c:1129 c-family/c-warn.c:1208
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "conversion from %qT to %qT changes the value of %qE"
 msgstr "konversi dari %qT ke %qT adalah ambigu"
 
-#: c-family/c-warn.c:1141
+#: c-family/c-warn.c:1149
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT discards qualifiers"
 msgid "conversion from %qT to %qT discards imaginary component"
 msgstr "konversi dari %qT ke %qT mengabaikan kualifikasi"
 
-#: c-family/c-warn.c:1153
+#: c-family/c-warn.c:1161
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %qT from %qT may alter its value"
 msgid "conversion from %qT to %qT may change value"
 msgstr "konversi ke %qT dari %qT mungkin mengubah nilainya"
 
-#: c-family/c-warn.c:1213 c-family/c-warn.c:1230 c-family/c-warn.c:1247
+#: c-family/c-warn.c:1221 c-family/c-warn.c:1238 c-family/c-warn.c:1255
 #, fuzzy, gcc-internal-format
 #| msgid "narrowing conversion of %qE from %qT to %qT inside { }"
 msgid "overflow in conversion from %qT to %qT changes value from %qE to %qE"
 msgstr "menyempitkan konversi %qE dari %qT ke %qT didalam { }"
 
-#: c-family/c-warn.c:1218 c-family/c-warn.c:1235 c-family/c-warn.c:1252
+#: c-family/c-warn.c:1226 c-family/c-warn.c:1243 c-family/c-warn.c:1260
 #, fuzzy, gcc-internal-format
 #| msgid "narrowing conversion of %qE from %qT to %qT inside { }"
 msgid "overflow in conversion from %qT to %qT changes the value of %qE"
 msgstr "menyempitkan konversi %qE dari %qT ke %qT didalam { }"
 
-#: c-family/c-warn.c:1282
+#: c-family/c-warn.c:1290
 #, fuzzy, gcc-internal-format
 #| msgid "%Jcase value %qs not in enumerated type"
 msgid "case value %qs not in enumerated type"
 msgstr "%J case value %qs tidak dalam tipe enumerasi"
 
-#: c-family/c-warn.c:1287
+#: c-family/c-warn.c:1295
 #, fuzzy, gcc-internal-format
 #| msgid "%Jcase value %qs not in enumerated type %qT"
 msgid "case value %qs not in enumerated type %qT"
 msgstr "%J nilai case %qs tidak dalam tipe enumerasi %qT"
 
-#: c-family/c-warn.c:1348
+#: c-family/c-warn.c:1356
 #, fuzzy, gcc-internal-format
 #| msgid "%Hswitch missing default case"
 msgid "switch missing default case"
 msgstr "%H switch hilang kasus baku"
 
-#: c-family/c-warn.c:1393
+#: c-family/c-warn.c:1401
 #, gcc-internal-format
 msgid "switch condition has boolean value"
 msgstr ""
 
-#: c-family/c-warn.c:1466
+#: c-family/c-warn.c:1474
 #, fuzzy, gcc-internal-format
 #| msgid "%Henumeration value %qE not handled in switch"
 msgid "enumeration value %qE not handled in switch"
 msgstr "%H nilai enumerasi %qE tidak ditangani dalam switch"
 
-#: c-family/c-warn.c:1494
+#: c-family/c-warn.c:1502
 #, gcc-internal-format
 msgid "the omitted middle operand in ?: will always be %<true%>, suggest explicit middle operand"
 msgstr ""
 
-#: c-family/c-warn.c:1515
+#: c-family/c-warn.c:1523
 #, fuzzy, gcc-internal-format
 #| msgid "assignment of read-only location %qE"
 msgid "assignment of member %qD in read-only object"
 msgstr "penempatan dari lokasi baca-saja %qE"
 
-#: c-family/c-warn.c:1517
+#: c-family/c-warn.c:1525
 #, fuzzy, gcc-internal-format
 #| msgid "increment of read-only location %qE"
 msgid "increment of member %qD in read-only object"
 msgstr "peningkatan dari lokasi baca-saja %qE"
 
-#: c-family/c-warn.c:1519
+#: c-family/c-warn.c:1527
 #, fuzzy, gcc-internal-format
 #| msgid "decrement of read-only location %qE"
 msgid "decrement of member %qD in read-only object"
 msgstr "pengurangan dari lokasi baca-saja %qE"
 
-#: c-family/c-warn.c:1521
+#: c-family/c-warn.c:1529
 #, fuzzy, gcc-internal-format
 #| msgid "read-only location %qE used as %<asm%> output"
 msgid "member %qD in read-only object used as %<asm%> output"
 msgstr "lokasi baca-saja %qE digunakan sebagai keluaran %<asm%>"
 
-#: c-family/c-warn.c:1525
+#: c-family/c-warn.c:1533
 #, gcc-internal-format
 msgid "assignment of read-only member %qD"
 msgstr "penempatan dari anggota baca-saja %qD"
 
-#: c-family/c-warn.c:1526
+#: c-family/c-warn.c:1534
 #, gcc-internal-format
 msgid "increment of read-only member %qD"
 msgstr "peningkatan dari anggota baca-saja %qD"
 
-#: c-family/c-warn.c:1527
+#: c-family/c-warn.c:1535
 #, gcc-internal-format
 msgid "decrement of read-only member %qD"
 msgstr "pengurangan dari anggota baca-saja %qD"
 
-#: c-family/c-warn.c:1528
+#: c-family/c-warn.c:1536
 #, gcc-internal-format
 msgid "read-only member %qD used as %<asm%> output"
 msgstr "anggota baca-saja %qD digunakan sebagai keluaran %<asm%>"
 
-#: c-family/c-warn.c:1532
+#: c-family/c-warn.c:1540
 #, gcc-internal-format
 msgid "assignment of read-only variable %qD"
 msgstr "penempatan dari variabel baca-saja %qD"
 
-#: c-family/c-warn.c:1533
+#: c-family/c-warn.c:1541
 #, gcc-internal-format
 msgid "increment of read-only variable %qD"
 msgstr "peningkatan dari variabel baca-saja %qD"
 
-#: c-family/c-warn.c:1534
+#: c-family/c-warn.c:1542
 #, gcc-internal-format
 msgid "decrement of read-only variable %qD"
 msgstr "pengurangan dari variabel baca-saja %qD"
 
-#: c-family/c-warn.c:1535
+#: c-family/c-warn.c:1543
 #, gcc-internal-format
 msgid "read-only variable %qD used as %<asm%> output"
 msgstr "variabel baca-saja %qD digunakan sebagai keluaran %<asm%>"
 
-#: c-family/c-warn.c:1538
+#: c-family/c-warn.c:1546
 #, fuzzy, gcc-internal-format
 #| msgid "assignment of read-only member %qD"
 msgid "assignment of read-only parameter %qD"
 msgstr "penempatan dari anggota baca-saja %qD"
 
-#: c-family/c-warn.c:1539
+#: c-family/c-warn.c:1547
 #, fuzzy, gcc-internal-format
 #| msgid "increment of read-only member %qD"
 msgid "increment of read-only parameter %qD"
 msgstr "peningkatan dari anggota baca-saja %qD"
 
-#: c-family/c-warn.c:1540
+#: c-family/c-warn.c:1548
 #, fuzzy, gcc-internal-format
 #| msgid "decrement of read-only member %qD"
 msgid "decrement of read-only parameter %qD"
 msgstr "pengurangan dari anggota baca-saja %qD"
 
-#: c-family/c-warn.c:1541
+#: c-family/c-warn.c:1549
 #, fuzzy, gcc-internal-format
 #| msgid "read-only member %qD used as %<asm%> output"
 msgid "read-only parameter %qD use as %<asm%> output"
 msgstr "anggota baca-saja %qD digunakan sebagai keluaran %<asm%>"
 
-#: c-family/c-warn.c:1546
+#: c-family/c-warn.c:1554
 #, fuzzy, gcc-internal-format
 #| msgid "%s of read-only named return value %qD"
 msgid "assignment of read-only named return value %qD"
 msgstr "%s dari baca-saja bernama mengembalikan nilai %qD"
 
-#: c-family/c-warn.c:1548
+#: c-family/c-warn.c:1556
 #, fuzzy, gcc-internal-format
 #| msgid "%s of read-only named return value %qD"
 msgid "increment of read-only named return value %qD"
 msgstr "%s dari baca-saja bernama mengembalikan nilai %qD"
 
-#: c-family/c-warn.c:1550
+#: c-family/c-warn.c:1558
 #, fuzzy, gcc-internal-format
 #| msgid "%s of read-only named return value %qD"
 msgid "decrement of read-only named return value %qD"
 msgstr "%s dari baca-saja bernama mengembalikan nilai %qD"
 
-#: c-family/c-warn.c:1552
+#: c-family/c-warn.c:1560
 #, fuzzy, gcc-internal-format
 #| msgid "read-only variable %qD used as %<asm%> output"
 msgid "read-only named return value %qD used as %<asm%>output"
 msgstr "variabel baca-saja %qD digunakan sebagai keluaran %<asm%>"
 
-#: c-family/c-warn.c:1557
+#: c-family/c-warn.c:1565
 #, fuzzy, gcc-internal-format
 #| msgid "%s of function %qD"
 msgid "assignment of function %qD"
 msgstr "%s dari fungsi %qD"
 
-#: c-family/c-warn.c:1558
+#: c-family/c-warn.c:1566
 #, fuzzy, gcc-internal-format
 #| msgid "%s of function %qD"
 msgid "increment of function %qD"
 msgstr "%s dari fungsi %qD"
 
-#: c-family/c-warn.c:1559
+#: c-family/c-warn.c:1567
 #, fuzzy, gcc-internal-format
 #| msgid "%s of function %qD"
 msgid "decrement of function %qD"
 msgstr "%s dari fungsi %qD"
 
-#: c-family/c-warn.c:1560
+#: c-family/c-warn.c:1568
 #, fuzzy, gcc-internal-format
 #| msgid "read-only location %qE used as %<asm%> output"
 msgid "function %qD used as %<asm%> output"
 msgstr "lokasi baca-saja %qE digunakan sebagai keluaran %<asm%>"
 
-#: c-family/c-warn.c:1563 c/c-typeck.c:4762
+#: c-family/c-warn.c:1571 c/c-typeck.c:4767
 #, gcc-internal-format
 msgid "assignment of read-only location %qE"
 msgstr "penempatan dari lokasi baca-saja %qE"
 
-#: c-family/c-warn.c:1564 c/c-typeck.c:4765
+#: c-family/c-warn.c:1572 c/c-typeck.c:4770
 #, gcc-internal-format
 msgid "increment of read-only location %qE"
 msgstr "peningkatan dari lokasi baca-saja %qE"
 
-#: c-family/c-warn.c:1565 c/c-typeck.c:4768
+#: c-family/c-warn.c:1573 c/c-typeck.c:4773
 #, gcc-internal-format
 msgid "decrement of read-only location %qE"
 msgstr "pengurangan dari lokasi baca-saja %qE"
 
-#: c-family/c-warn.c:1566
+#: c-family/c-warn.c:1574
 #, gcc-internal-format
 msgid "read-only location %qE used as %<asm%> output"
 msgstr "lokasi baca-saja %qE digunakan sebagai keluaran %<asm%>"
 
-#: c-family/c-warn.c:1580
+#: c-family/c-warn.c:1588
 #, gcc-internal-format
 msgid "lvalue required as left operand of assignment"
 msgstr "lvalue dibutuhkan sebagai operan kiri dari penempatan"
 
-#: c-family/c-warn.c:1583
+#: c-family/c-warn.c:1591
 #, gcc-internal-format
 msgid "lvalue required as increment operand"
 msgstr "lvalue dibutuh sebagai operan peningkatan"
 
-#: c-family/c-warn.c:1586
+#: c-family/c-warn.c:1594
 #, gcc-internal-format
 msgid "lvalue required as decrement operand"
 msgstr "lvalue dibutuhkan sebagai operan pengurangan"
 
-#: c-family/c-warn.c:1589
+#: c-family/c-warn.c:1597
 #, gcc-internal-format
 msgid "lvalue required as unary %<&%> operand"
 msgstr "lvalue dibutuh sebagai operan unary %<&%>"
 
-#: c-family/c-warn.c:1592
+#: c-family/c-warn.c:1600
 #, gcc-internal-format
 msgid "lvalue required in asm statement"
 msgstr "lvalue dibutuhkan dalam pernyataan asm"
 
-#: c-family/c-warn.c:1609
+#: c-family/c-warn.c:1617
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument of %qs (have %qT)"
 msgid "invalid type argument (have %qT)"
 msgstr "tipe argumen tidak valid dari %qs (memiliki %qT)"
 
-#: c-family/c-warn.c:1613
+#: c-family/c-warn.c:1621
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument of %qs (have %qT)"
 msgid "invalid type argument of array indexing (have %qT)"
 msgstr "tipe argumen tidak valid dari %qs (memiliki %qT)"
 
-#: c-family/c-warn.c:1618
+#: c-family/c-warn.c:1626
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument of %qs (have %qT)"
 msgid "invalid type argument of unary %<*%> (have %qT)"
 msgstr "tipe argumen tidak valid dari %qs (memiliki %qT)"
 
-#: c-family/c-warn.c:1623
+#: c-family/c-warn.c:1631
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument of %qs (have %qT)"
 msgid "invalid type argument of %<->%> (have %qT)"
 msgstr "tipe argumen tidak valid dari %qs (memiliki %qT)"
 
-#: c-family/c-warn.c:1628
+#: c-family/c-warn.c:1636
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument of %qs (have %qT)"
 msgid "invalid type argument of %<->*%> (have %qT)"
 msgstr "tipe argumen tidak valid dari %qs (memiliki %qT)"
 
-#: c-family/c-warn.c:1633
+#: c-family/c-warn.c:1641
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument of %qs (have %qT)"
 msgid "invalid type argument of implicit conversion (have %qT)"
 msgstr "tipe argumen tidak valid dari %qs (memiliki %qT)"
 
-#: c-family/c-warn.c:1654
+#: c-family/c-warn.c:1662
 #, gcc-internal-format
 msgid "array subscript has type %<char%>"
 msgstr "array subscript memiliki tipe %<char%>"
 
-#: c-family/c-warn.c:1689 c-family/c-warn.c:1692
+#: c-family/c-warn.c:1697 c-family/c-warn.c:1700
 #, gcc-internal-format
 msgid "suggest parentheses around %<+%> inside %<<<%>"
 msgstr "disarankan tanda kurung diantara %<+%> didalam %<<%>"
 
-#: c-family/c-warn.c:1695 c-family/c-warn.c:1698
+#: c-family/c-warn.c:1703 c-family/c-warn.c:1706
 #, gcc-internal-format
 msgid "suggest parentheses around %<-%> inside %<<<%>"
 msgstr "disarankan tanda kurung diantara %<-%> didalam %<<<%>"
 
-#: c-family/c-warn.c:1704 c-family/c-warn.c:1707
+#: c-family/c-warn.c:1712 c-family/c-warn.c:1715
 #, gcc-internal-format
 msgid "suggest parentheses around %<+%> inside %<>>%>"
 msgstr "disarankan tanda kurung diantara %<+%> didalam %<>>%>"
 
-#: c-family/c-warn.c:1710 c-family/c-warn.c:1713
+#: c-family/c-warn.c:1718 c-family/c-warn.c:1721
 #, gcc-internal-format
 msgid "suggest parentheses around %<-%> inside %<>>%>"
 msgstr "disarankan tanda kurung diantara %<-%> didalam %<>>%>"
 
-#: c-family/c-warn.c:1719 c-family/c-warn.c:1722
+#: c-family/c-warn.c:1727 c-family/c-warn.c:1730
 #, gcc-internal-format
 msgid "suggest parentheses around %<&&%> within %<||%>"
 msgstr "disarankan tanda kurung diantara %<&&%> didalam %<||%>"
 
-#: c-family/c-warn.c:1729 c-family/c-warn.c:1733
+#: c-family/c-warn.c:1737 c-family/c-warn.c:1741
 #, gcc-internal-format
 msgid "suggest parentheses around arithmetic in operand of %<|%>"
 msgstr "disarankan tanda kurung diantara aritmetik dalam operan dari %<|%>"
 
-#: c-family/c-warn.c:1737 c-family/c-warn.c:1740
+#: c-family/c-warn.c:1745 c-family/c-warn.c:1748
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<|%>"
 msgstr "disarankan tanda kurung diantara perbandingan dalam operan dari %<|%>"
 
-#: c-family/c-warn.c:1745
+#: c-family/c-warn.c:1753
 #, gcc-internal-format
 msgid "suggest parentheses around operand of %<!%> or change %<|%> to %<||%> or %<!%> to %<~%>"
 msgstr "disarankan tanda kurung diantara operand dari %<!%> atau ubah %<|%> ke %<||%> atau %<!%> ke %<~%>"
 
-#: c-family/c-warn.c:1753 c-family/c-warn.c:1757
+#: c-family/c-warn.c:1761 c-family/c-warn.c:1765
 #, gcc-internal-format
 msgid "suggest parentheses around arithmetic in operand of %<^%>"
 msgstr "disarankan tanda kurung diantara aritmetik dalam operan dari %<^%>"
 
-#: c-family/c-warn.c:1761 c-family/c-warn.c:1764
+#: c-family/c-warn.c:1769 c-family/c-warn.c:1772
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<^%>"
 msgstr "disarankan tanda kurung diantara perbandingan dalam operan dari %<^%>"
 
-#: c-family/c-warn.c:1770 c-family/c-warn.c:1773
+#: c-family/c-warn.c:1778 c-family/c-warn.c:1781
 #, gcc-internal-format
 msgid "suggest parentheses around %<+%> in operand of %<&%>"
 msgstr "disarankan tanda kurung diantara %<+%> dalam operan dari %<&%>"
 
-#: c-family/c-warn.c:1776 c-family/c-warn.c:1779
+#: c-family/c-warn.c:1784 c-family/c-warn.c:1787
 #, gcc-internal-format
 msgid "suggest parentheses around %<-%> in operand of %<&%>"
 msgstr "disarankan tanda kurung diantara %<-%> dalam operan dari %<&%>"
 
-#: c-family/c-warn.c:1783 c-family/c-warn.c:1786
+#: c-family/c-warn.c:1791 c-family/c-warn.c:1794
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<&%>"
 msgstr "disarankan tanda kurung diantara perbandingan dalam operan  dari %<&%>"
 
-#: c-family/c-warn.c:1791
+#: c-family/c-warn.c:1799
 #, gcc-internal-format
 msgid "suggest parentheses around operand of %<!%> or change %<&%> to %<&&%> or %<!%> to %<~%>"
 msgstr "disarankan tanda kurung diantara operan dari %<!%> atau ubah %<&%> ke %<<&&%> atau %<!%> ke %<~%>"
 
-#: c-family/c-warn.c:1798 c-family/c-warn.c:1801
+#: c-family/c-warn.c:1806 c-family/c-warn.c:1809
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<==%>"
 msgstr "disarankan tanda kurung diantara perbandingan dalam operan dari %<==%>"
 
-#: c-family/c-warn.c:1806 c-family/c-warn.c:1809
+#: c-family/c-warn.c:1814 c-family/c-warn.c:1817
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<!=%>"
 msgstr "disarankan tanda kurung diantara perbandingan dalam operan dari %<!=%>"
 
-#: c-family/c-warn.c:1819 c-family/c-warn.c:1825
+#: c-family/c-warn.c:1827 c-family/c-warn.c:1833
 #, gcc-internal-format
 msgid "comparisons like %<X<=Y<=Z%> do not have their mathematical meaning"
 msgstr "perbandingan seperti %<X<=Y<=Z%> tidak memiliki arti matematisnya"
 
-#: c-family/c-warn.c:1841
+#: c-family/c-warn.c:1849
 #, gcc-internal-format
 msgid "label %q+D defined but not used"
 msgstr "label %q+D didefinisikan tetapi tidak digunakan"
 
-#: c-family/c-warn.c:1843
+#: c-family/c-warn.c:1851
 #, gcc-internal-format
 msgid "label %q+D declared but not defined"
 msgstr "label %q+D dideklarasikan tetapi tidak didefinisikan"
 
-#: c-family/c-warn.c:1866
+#: c-family/c-warn.c:1874
 #, gcc-internal-format
 msgid "division by zero"
 msgstr "pembagian dengan nol"
 
-#: c-family/c-warn.c:1886
+#: c-family/c-warn.c:1894
 #, gcc-internal-format
 msgid "%<memset%> used with constant zero length parameter; this could be due to transposed parameters"
 msgstr ""
 
-#: c-family/c-warn.c:1909
+#: c-family/c-warn.c:1918
 #, gcc-internal-format
 msgid "%<memset%> used with length equal to number of elements without multiplication by element size"
 msgstr ""
 
-#: c-family/c-warn.c:1948 c/c-typeck.c:11499 c/c-typeck.c:11667
+#: c-family/c-warn.c:1957 c/c-typeck.c:11504 c/c-typeck.c:11672
 #: cp/typeck.c:5048
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr "perbandingan diantara tipe %qT dan %qT"
 
-#: c-family/c-warn.c:1998
+#: c-family/c-warn.c:2007
 #, gcc-internal-format
 msgid "comparison of integer expressions of different signedness: %qT and %qT"
 msgstr ""
 
-#: c-family/c-warn.c:2051
+#: c-family/c-warn.c:2060
 #, gcc-internal-format
 msgid "promoted ~unsigned is always non-zero"
 msgstr "~unsigned yang dipromosikan selalu bukan-nol"
 
-#: c-family/c-warn.c:2054
+#: c-family/c-warn.c:2063
 #, gcc-internal-format
 msgid "comparison of promoted ~unsigned with constant"
 msgstr "perbandinga dari dipromosikan ~unsigned dengan konstant"
 
-#: c-family/c-warn.c:2064
+#: c-family/c-warn.c:2073
 #, gcc-internal-format
 msgid "comparison of promoted ~unsigned with unsigned"
 msgstr "perbandingan dari dipromosikan ~unsigned dengan unsigned"
 
-#: c-family/c-warn.c:2118
+#: c-family/c-warn.c:2127
 #, fuzzy, gcc-internal-format
 #| msgid "unused parameter %q+D"
 msgid "unused parameter %qD"
 msgstr "parameter %q+D tidak digunakan"
 
-#: c-family/c-warn.c:2180
+#: c-family/c-warn.c:2189
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D defined but not used"
 msgid "typedef %qD locally defined but not used"
 msgstr "%q+D didefinisikan tetapi tidak digunakan"
 
-#: c-family/c-warn.c:2215
+#: c-family/c-warn.c:2224
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<const%>"
 msgid "duplicated %<if%> condition"
 msgstr "duplikasi %<const%>"
 
-#: c-family/c-warn.c:2244
+#: c-family/c-warn.c:2253
 #, gcc-internal-format
 msgid "optimization attribute on %qD follows definition but the attribute doesn%'t match"
 msgstr ""
 
-#: c-family/c-warn.c:2254
+#: c-family/c-warn.c:2261
 #, fuzzy, gcc-internal-format
 #| msgid "inline declaration of %qD follows declaration with attribute noinline"
 msgid "inline declaration of %qD follows declaration with attribute %qs"
 msgstr "deklarasi inline dari %qD mengikuti deklarasi dengan atribut noinline"
 
-#: c-family/c-warn.c:2259
+#: c-family/c-warn.c:2266
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D with attribute noinline follows inline declaration "
 msgid "declaration of %q+D with attribute %qs follows inline declaration"
 msgstr "deklarasi dari %q+D dengan atribut noinline mengikuti deklarasi inline"
 
-#: c-family/c-warn.c:2306
+#: c-family/c-warn.c:2313
 #, gcc-internal-format
 msgid "result of %qE requires %u bits to represent, but %qT only has %u bits"
 msgstr ""
 
-#: c-family/c-warn.c:2344 c-family/c-warn.c:2368
+#: c-family/c-warn.c:2351 c-family/c-warn.c:2375
 #, fuzzy, gcc-internal-format
 #| msgid "comparison of unsigned expression < 0 is always false"
 msgid "comparison of constant %qE with boolean expression is always false"
 msgstr "perbandingan dari ekspresi unsigned < 0 adalah selalu salah"
 
-#: c-family/c-warn.c:2347 c-family/c-warn.c:2365
+#: c-family/c-warn.c:2354 c-family/c-warn.c:2372
 #, fuzzy, gcc-internal-format
 #| msgid "comparison of unsigned expression >= 0 is always true"
 msgid "comparison of constant %qE with boolean expression is always true"
 msgstr "perbandingan dari ekspresi unsigned >= 0 adalah selalu benar"
 
-#: c-family/c-warn.c:2415
+#: c-family/c-warn.c:2422
 #, fuzzy
 #| msgid "passing argument %d of %qE discards qualifiers from pointer target type"
 msgid "passing argument %i to restrict-qualified parameter aliases with argument %Z"
@@ -31473,17 +31516,17 @@
 msgstr[0] "melewatkan argumen %d dari %qE mengabaikan pengkualifikasi dari tipe target penunjuk"
 msgstr[1] "melewatkan argumen %d dari %qE mengabaikan pengkualifikasi dari tipe target penunjuk"
 
-#: c-family/c-warn.c:2480 c/c-typeck.c:5288 cp/call.c:5365
+#: c-family/c-warn.c:2487 c/c-typeck.c:5293 cp/call.c:5365
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr ""
 
-#: c-family/c-warn.c:2586
+#: c-family/c-warn.c:2593
 #, gcc-internal-format
 msgid "macro expands to multiple statements"
 msgstr ""
 
-#: c-family/c-warn.c:2587
+#: c-family/c-warn.c:2594
 #, gcc-internal-format
 msgid "some parts of macro expansion are not guarded by this %qs clause"
 msgstr ""
@@ -31499,7 +31542,7 @@
 msgid "too many input files"
 msgstr "terlalu banyak berkas masukan"
 
-#: common/config/aarch64/aarch64-common.c:319 config/aarch64/aarch64.c:10686
+#: common/config/aarch64/aarch64-common.c:319 config/aarch64/aarch64.c:10702
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %s for -mfpu"
 msgid "unknown value %qs for -mcpu"
@@ -31532,13 +31575,13 @@
 msgstr ""
 
 #: common/config/arm/arm-common.c:322 common/config/arm/arm-common.c:376
-#: common/config/arm/arm-common.c:423 config/aarch64/aarch64.c:10639
+#: common/config/arm/arm-common.c:423 config/aarch64/aarch64.c:10655
 #, gcc-internal-format
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr ""
 
 #: common/config/arm/arm-common.c:325 common/config/arm/arm-common.c:379
-#: common/config/arm/arm-common.c:426 config/aarch64/aarch64.c:10642
+#: common/config/arm/arm-common.c:426 config/aarch64/aarch64.c:10658
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid type argument of %qs"
 msgid "valid arguments are: %s"
@@ -32049,13 +32092,13 @@
 msgid "profiler support for VxWorks"
 msgstr "dukungan profiler untuk VxWorks"
 
-#: config/aarch64/aarch64-builtins.c:1109 config/arm/arm-builtins.c:2262
+#: config/aarch64/aarch64-builtins.c:1109 config/arm/arm-builtins.c:2272
 #, fuzzy, gcc-internal-format
 #| msgid "argument must be a constant"
 msgid "%Kargument %d must be a constant immediate"
 msgstr "argumen harus berupa sebuah konstanta"
 
-#: config/aarch64/aarch64-builtins.c:1180 config/arm/arm-builtins.c:2492
+#: config/aarch64/aarch64-builtins.c:1180 config/arm/arm-builtins.c:2502
 #, fuzzy, gcc-internal-format
 #| msgid "index mask must be an immediate"
 msgid "%Klane index must be a constant immediate"
@@ -32067,188 +32110,188 @@
 msgid "%Ktotal size and element size must be a non-zero constant immediate"
 msgstr "argumen kedua harus berupa sebuah 4 bit immediate"
 
-#: config/aarch64/aarch64.c:1053
+#: config/aarch64/aarch64.c:1069
 #, fuzzy, gcc-internal-format
 #| msgid "assert: %s is assign compatible with %s"
 msgid "%qs is incompatible with %s %s"
 msgstr "assert: %s adalah assign kompatibel dengan %s"
 
-#: config/aarch64/aarch64.c:1055
+#: config/aarch64/aarch64.c:1071
 #, fuzzy, gcc-internal-format
 #| msgid "assert: %s is assign compatible with %s"
 msgid "%qs feature modifier is incompatible with %s %s"
 msgstr "assert: %s adalah assign kompatibel dengan %s"
 
-#: config/aarch64/aarch64.c:3772
+#: config/aarch64/aarch64.c:3788
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10287
+#: config/aarch64/aarch64.c:10303
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown flag passed in -moverride=%s (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10331
+#: config/aarch64/aarch64.c:10347
 #, gcc-internal-format, gfc-internal-format
 msgid "%s string ill-formed\n"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10388
+#: config/aarch64/aarch64.c:10404
 #, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10406
+#: config/aarch64/aarch64.c:10422
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unknown spec function '%s'"
 msgid "unknown tuning option (%s)"
 msgstr "fungsi spesifikasi '%s' tidak diketahui"
 
-#: config/aarch64/aarch64.c:10683
+#: config/aarch64/aarch64.c:10699
 #, gcc-internal-format
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10690
+#: config/aarch64/aarch64.c:10706
 #, fuzzy, gcc-internal-format
 #| msgid "invalid thread pointer option: -mtp=%s"
 msgid "invalid feature modifier in %<-mcpu=%s%>"
 msgstr "pilihan thread pointer tidak valid: -mtp=%s"
 
-#: config/aarch64/aarch64.c:10717
+#: config/aarch64/aarch64.c:10733
 #, gcc-internal-format
 msgid "missing arch name in %<-march=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10720
+#: config/aarch64/aarch64.c:10736
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %s for -mfpu"
 msgid "unknown value %qs for -march"
 msgstr "nilai %s tidak diketahui untuk pilihan -mfpu"
 
-#: config/aarch64/aarch64.c:10724
+#: config/aarch64/aarch64.c:10740
 #, fuzzy, gcc-internal-format
 #| msgid "invalid thread pointer option: -mtp=%s"
 msgid "invalid feature modifier in %<-march=%s%>"
 msgstr "pilihan thread pointer tidak valid: -mtp=%s"
 
-#: config/aarch64/aarch64.c:10750
+#: config/aarch64/aarch64.c:10766
 #, gcc-internal-format
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10753
+#: config/aarch64/aarch64.c:10769
 #, fuzzy, gcc-internal-format
 #| msgid "unknown value %s for -mfpu"
 msgid "unknown value %qs for -mtune"
 msgstr "nilai %s tidak diketahui untuk pilihan -mfpu"
 
-#: config/aarch64/aarch64.c:10871 config/arm/arm.c:3173
+#: config/aarch64/aarch64.c:10887 config/arm/arm.c:3173
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "switch -mcpu=%s conflicts with -march= switch"
 msgid "switch -mcpu=%s conflicts with -march=%s switch"
 msgstr "pilihan -mcpu=%s konflik dengan pilihan -march="
 
-#: config/aarch64/aarch64.c:10906
+#: config/aarch64/aarch64.c:10922
 #, fuzzy, gcc-internal-format
 #| msgid "does not support multilib"
 msgid "assembler does not support -mabi=ilp32"
 msgstr "tidak mendukung multilib"
 
-#: config/aarch64/aarch64.c:10913
+#: config/aarch64/aarch64.c:10929
 #, gcc-internal-format
 msgid "return address signing is only supported for -mabi=lp64"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10975
+#: config/aarch64/aarch64.c:10991
 #, gcc-internal-format
 msgid "code model %qs with -f%s"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11138
+#: config/aarch64/aarch64.c:11154
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11141
+#: config/aarch64/aarch64.c:11157
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11145 config/aarch64/aarch64.c:11184
-#: config/aarch64/aarch64.c:11257
+#: config/aarch64/aarch64.c:11161 config/aarch64/aarch64.c:11200
+#: config/aarch64/aarch64.c:11273
 #, gcc-internal-format
 msgid "invalid value (\"%s\") in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11177
+#: config/aarch64/aarch64.c:11193
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11180
+#: config/aarch64/aarch64.c:11196
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11213
+#: config/aarch64/aarch64.c:11229
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"tune=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11253
+#: config/aarch64/aarch64.c:11269
 #, gcc-internal-format
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11306 config/aarch64/aarch64.c:11483
+#: config/aarch64/aarch64.c:11322 config/aarch64/aarch64.c:11499
 #, fuzzy, gcc-internal-format
 #| msgid "malformed %<#pragma init%>"
 msgid "malformed %<target()%> pragma or attribute"
 msgstr "salah bentuk %<#pragma init%>"
 
-#: config/aarch64/aarch64.c:11354
+#: config/aarch64/aarch64.c:11370
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11362
+#: config/aarch64/aarch64.c:11378
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11416
+#: config/aarch64/aarch64.c:11432
 #, fuzzy, gcc-internal-format
 #| msgid "attribute(target(\"%s\")) is unknown"
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr "atribut(target(\"%s\")) tidak diketahui"
 
-#: config/aarch64/aarch64.c:11473 config/arm/arm.c:30742
-#: config/i386/i386.c:5440 config/powerpcspe/powerpcspe.c:39760
-#: config/rs6000/rs6000.c:36904 config/s390/s390.c:15746
+#: config/aarch64/aarch64.c:11489 config/arm/arm.c:30742
+#: config/i386/i386.c:5443 config/powerpcspe/powerpcspe.c:39760
+#: config/rs6000/rs6000.c:36960 config/s390/s390.c:15746
 #, fuzzy, gcc-internal-format
 #| msgid "alias argument not a string"
 msgid "attribute %<target%> argument not a string"
 msgstr "alias argumen bukan sebuah string"
 
-#: config/aarch64/aarch64.c:11500
+#: config/aarch64/aarch64.c:11516
 #, fuzzy, gcc-internal-format
 #| msgid "attribute(target(\"%s\")) is unknown"
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr "atribut(target(\"%s\")) tidak diketahui"
 
-#: config/aarch64/aarch64.c:11509
+#: config/aarch64/aarch64.c:11525
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13571
+#: config/aarch64/aarch64.c:13587
 #, gcc-internal-format
 msgid "%Klane %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13573
+#: config/aarch64/aarch64.c:13589
 #, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr ""
@@ -32309,8 +32352,8 @@
 msgid "bad value %qs for -mmemory-latency"
 msgstr "nilai buruk %qs untuk -mmemory-latency"
 
-#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6526
-#: config/arc/arc.c:6800 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
+#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6517
+#: config/arc/arc.c:6791 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
 #: config/tilepro/tilepro.c:3108
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -32428,11 +32471,11 @@
 #: config/arm/arm.c:7029 config/avr/avr.c:9718 config/avr/avr.c:9734
 #: config/bfin/bfin.c:4705 config/bfin/bfin.c:4766 config/bfin/bfin.c:4795
 #: config/epiphany/epiphany.c:491 config/h8300/h8300.c:5459
-#: config/i386/i386.c:6452 config/i386/i386.c:12479 config/i386/i386.c:41424
-#: config/i386/i386.c:41474 config/i386/i386.c:41544 config/m68k/m68k.c:780
+#: config/i386/i386.c:6455 config/i386/i386.c:12482 config/i386/i386.c:41418
+#: config/i386/i386.c:41468 config/i386/i386.c:41538 config/m68k/m68k.c:780
 #: config/mcore/mcore.c:3070 config/nvptx/nvptx.c:4611
 #: config/powerpcspe/powerpcspe.c:35785 config/riscv/riscv.c:2698
-#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:32982
+#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:33038
 #: config/rx/rx.c:2719 config/rx/rx.c:2745 config/s390/s390.c:1056
 #: config/s390/s390.c:1143 config/sh/sh.c:8428 config/sh/sh.c:8446
 #: config/sh/sh.c:8470 config/sh/sh.c:8541 config/sh/sh.c:8564
@@ -32443,122 +32486,122 @@
 msgid "%qE attribute only applies to functions"
 msgstr "atribut %qs hanya berlaku ke fungsi"
 
-#: config/arc/arc.c:6425
+#: config/arc/arc.c:6416
 #, fuzzy, gcc-internal-format
 #| msgid "%<__builtin_next_arg%> called without an argument"
 msgid "__builtin_arc_aligned with non-constant alignment"
 msgstr "%<__builtin_next_arg%> dipanggil tanpa sebuah argumen"
 
-#: config/arc/arc.c:6433
+#: config/arc/arc.c:6424
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to %<__builtin_frame_address%>"
 msgid "invalid alignment value for __builtin_arc_aligned"
 msgstr "argumen ke %<__builtin_frame_address%> tidak valid"
 
-#: config/arc/arc.c:6596
+#: config/arc/arc.c:6587
 #, fuzzy, gcc-internal-format
 #| msgid "-mcorea should be used with -mmulticore"
 msgid "operand 1 should be an unsigned 3-bit immediate"
 msgstr "-mcorea seharusnya digunakan dengan -mmulticore"
 
-#: config/arc/arc.c:6637 config/arc/arc.c:6734
+#: config/arc/arc.c:6628 config/arc/arc.c:6725
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6670 config/arc/arc.c:6702
+#: config/arc/arc.c:6661 config/arc/arc.c:6693
 #, gcc-internal-format
 msgid "operand 1 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6674 config/arc/arc.c:6706
+#: config/arc/arc.c:6665 config/arc/arc.c:6697
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 8-bit value"
 msgstr ""
 
-#: config/arc/arc.c:6738
+#: config/arc/arc.c:6729
 #, gcc-internal-format
 msgid "operand 3 should be an unsigned 8-bit value"
 msgstr ""
 
-#: config/arc/arc.c:6771
+#: config/arc/arc.c:6762
 #, gcc-internal-format
 msgid "operand 4 should be an unsigned 8-bit value (0-255)"
 msgstr ""
 
-#: config/arc/arc.c:6775
+#: config/arc/arc.c:6766
 #, gcc-internal-format
 msgid "operand 3 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6782
+#: config/arc/arc.c:6773
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (subreg 0-7)"
 msgstr ""
 
-#: config/arc/arc.c:6785
+#: config/arc/arc.c:6776
 #, gcc-internal-format
 msgid "operand 2 should be an even 3-bit value (subreg 0,2,4,6)"
 msgstr ""
 
-#: config/arc/arc.c:6832
+#: config/arc/arc.c:6823
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "lvalue required as increment operand"
 msgid "builtin requires an immediate for operand %d"
 msgstr "lvalue dibutuh sebagai operan peningkatan"
 
-#: config/arc/arc.c:6837
+#: config/arc/arc.c:6828
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "operand %d should be a 6 bit unsigned immediate"
 msgstr "argumen 2 harus berupa sebuah 5 bit unsigned literal"
 
-#: config/arc/arc.c:6841
+#: config/arc/arc.c:6832
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "operand %d should be a 8 bit unsigned immediate"
 msgstr "argumen 2 harus berupa sebuah 5 bit unsigned literal"
 
-#: config/arc/arc.c:6845
+#: config/arc/arc.c:6836
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "operand %d should be a 3 bit unsigned immediate"
 msgstr "argumen 2 harus berupa sebuah 5 bit unsigned literal"
 
-#: config/arc/arc.c:6848
+#: config/arc/arc.c:6839
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown builtin immediate operand type for operand %d"
 msgstr ""
 
-#: config/arc/arc.c:6899
+#: config/arc/arc.c:6890
 #, gcc-internal-format
 msgid "register number must be a compile-time constant. Try giving higher optimization levels"
 msgstr ""
 
-#: config/arc/arc.c:7685
+#: config/arc/arc.c:7747
 #, gcc-internal-format
 msgid "Insn addresses not set after shorten_branches"
 msgstr ""
 
-#: config/arc/arc.c:7894
+#: config/arc/arc.c:7956
 #, fuzzy, gcc-internal-format
 #| msgid "Bad address, not register:"
 msgid "insn addresses not freed"
 msgstr "Alamat buruk, bukan register:"
 
-#: config/arc/arc.c:10682
+#: config/arc/arc.c:10670
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to variables"
 msgid "%qE attribute only valid for ARCv2 architecture"
 msgstr "%qs atribut hanya berlaku ke variabel"
 
-#: config/arc/arc.c:10690 config/arc/arc.c:10729
+#: config/arc/arc.c:10678 config/arc/arc.c:10717
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "argument of %qE attribute is missing"
 msgstr "argumen dari atribut %qs bukan sebuah konstanta string"
 
-#: config/arc/arc.c:10701 config/arc/arc.c:10740 config/arc/arc.c:10842
+#: config/arc/arc.c:10689 config/arc/arc.c:10728 config/arc/arc.c:10830
 #: config/avr/avr.c:9790
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
@@ -32565,25 +32608,25 @@
 msgid "%qE attribute allows only an integer constant argument"
 msgstr "atribut %qs membutuhkan sebuah argumen konstanta integer"
 
-#: config/arc/arc.c:10721
+#: config/arc/arc.c:10709
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only available for 64-bit"
 msgid "%qE attribute only valid for ARC EM architecture"
 msgstr "%qs atribut hanya tersedia untuk 64 bit"
 
-#: config/arc/arc.c:10776
+#: config/arc/arc.c:10764
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to function types"
 msgid "%qE attribute only applies to types"
 msgstr "atribut %qs hanya berlaku ke fungsi tipe"
 
-#: config/arc/arc.c:10782
+#: config/arc/arc.c:10770
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored"
 msgid "argument of %qE attribute ignored"
 msgstr "%qE atribut diabaikan"
 
-#: config/arc/arc.c:10832 config/avr/avr.c:9777 config/bfin/bfin.c:4827
+#: config/arc/arc.c:10820 config/avr/avr.c:9777 config/bfin/bfin.c:4827
 #: config/i386/winnt.c:63 config/msp430/msp430.c:2018
 #: config/nvptx/nvptx.c:4634
 #, fuzzy, gcc-internal-format
@@ -32591,176 +32634,176 @@
 msgid "%qE attribute only applies to variables"
 msgstr "%qs atribut hanya berlaku ke variabel"
 
-#: config/arm/arm-builtins.c:2370
+#: config/arm/arm-builtins.c:2380
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "this builtin is not supported for this target"
 msgstr "-fdata-sections tidak didukung untuk target ini"
 
-#: config/arm/arm-builtins.c:2475
+#: config/arm/arm-builtins.c:2485
 #, gcc-internal-format
 msgid "You must enable NEON instructions (e.g. -mfloat-abi=softfp -mfpu=neon) to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2513
+#: config/arm/arm-builtins.c:2523
 #, gcc-internal-format
 msgid "You must enable VFP instructions to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2573
+#: config/arm/arm-builtins.c:2583
 #, gcc-internal-format
 msgid "You must enable crypto instructions (e.g. include -mfloat-abi=softfp -mfpu=crypto-neon...) to use these intrinsics."
 msgstr ""
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:2633 config/arm/arm-builtins.c:2737
+#: config/arm/arm-builtins.c:2643 config/arm/arm-builtins.c:2747
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr "pemilih harus berupa sebuah immediate"
 
-#: config/arm/arm-builtins.c:2641 config/arm/arm-builtins.c:2686
-#: config/arm/arm-builtins.c:2744 config/arm/arm-builtins.c:2753
+#: config/arm/arm-builtins.c:2651 config/arm/arm-builtins.c:2696
+#: config/arm/arm-builtins.c:2754 config/arm/arm-builtins.c:2763
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2646 config/arm/arm-builtins.c:2755
+#: config/arm/arm-builtins.c:2656 config/arm/arm-builtins.c:2765
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2651 config/arm/arm-builtins.c:2757
+#: config/arm/arm-builtins.c:2661 config/arm/arm-builtins.c:2767
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2823
+#: config/arm/arm-builtins.c:2833
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr "mask harus berupa sebuah immediate"
 
-#: config/arm/arm-builtins.c:2828
+#: config/arm/arm-builtins.c:2838
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute argument should be between 0 to 255"
 msgid "the range of mask should be in 0 to 255"
 msgstr "argumen atribut `%s' seharusnya berada diantara 0 sampai 255"
 
-#: config/arm/arm-builtins.c:3016
+#: config/arm/arm-builtins.c:3026
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3018
+#: config/arm/arm-builtins.c:3028
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3020
+#: config/arm/arm-builtins.c:3030
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3022
+#: config/arm/arm-builtins.c:3032
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3028
+#: config/arm/arm-builtins.c:3038
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3030
+#: config/arm/arm-builtins.c:3040
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3035
+#: config/arm/arm-builtins.c:3045
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3037
+#: config/arm/arm-builtins.c:3047
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3039
+#: config/arm/arm-builtins.c:3049
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3041
+#: config/arm/arm-builtins.c:3051
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3043
+#: config/arm/arm-builtins.c:3053
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3045
+#: config/arm/arm-builtins.c:3055
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3047
+#: config/arm/arm-builtins.c:3057
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3049
+#: config/arm/arm-builtins.c:3059
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3051
+#: config/arm/arm-builtins.c:3061
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3053
+#: config/arm/arm-builtins.c:3063
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3055
+#: config/arm/arm-builtins.c:3065
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3057
+#: config/arm/arm-builtins.c:3067
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3059
+#: config/arm/arm-builtins.c:3069
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3061
+#: config/arm/arm-builtins.c:3071
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3063
+#: config/arm/arm-builtins.c:3073
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3065
+#: config/arm/arm-builtins.c:3075
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3067
+#: config/arm/arm-builtins.c:3077
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3069
+#: config/arm/arm-builtins.c:3079
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr ""
@@ -33744,18 +33787,18 @@
 msgid "can%'t set position in PCH file: %m"
 msgstr "tidak dapat menset posisi dalam berkas PCH: %m"
 
-#: config/i386/i386.c:3177
+#: config/i386/i386.c:3180
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function %qs"
 msgid "wrong argument %qs to option %qs"
 msgstr "terlalu banyak argumen ke fungsi %qs"
 
-#: config/i386/i386.c:3183
+#: config/i386/i386.c:3186
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr ""
 
-#: config/i386/i386.c:3193
+#: config/i386/i386.c:3196
 #, fuzzy, gcc-internal-format
 #| msgid "register name not specified for %q+D"
 msgid "wrong strategy name %qs specified for option %qs"
@@ -33762,47 +33805,47 @@
 msgstr "nama register tidak dispesifikasikan untuk %q+D"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3219
+#: config/i386/i386.c:3222
 #, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386.c:3232
+#: config/i386/i386.c:3235
 #, fuzzy, gcc-internal-format
 #| msgid "alignment may not be specified for %q+D"
 msgid "unknown alignment %qs specified for option %qs"
 msgstr "alignmen mungkin tidak dispesifikasikan untuk %q+D"
 
-#: config/i386/i386.c:3242
+#: config/i386/i386.c:3245
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr ""
 
-#: config/i386/i386.c:3249
+#: config/i386/i386.c:3252
 #, fuzzy, gcc-internal-format
 #| msgid "no class name specified with %qs"
 msgid "too many size ranges specified in option %qs"
 msgstr "tidak ada nama class dispesifikasikan dengan %qs"
 
-#: config/i386/i386.c:3302
+#: config/i386/i386.c:3305
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unknown register name: %s"
 msgid "unknown parameter to option -mtune-ctrl: %s"
 msgstr "nama register: %s tidak dikenal"
 
-#: config/i386/i386.c:3726
+#: config/i386/i386.c:3729
 #, fuzzy, gcc-internal-format
 #| msgid "64-bit ABI not supported in ESA/390 mode"
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "64 bit ABI tidak didukung di mode ESA/390"
 
-#: config/i386/i386.c:3775
+#: config/i386/i386.c:3778
 #, fuzzy, gcc-internal-format
 #| msgid "%stune=x86-64%s is deprecated.  Use %stune=k8%s or %stune=generic%s instead as appropriate."
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "%smtune=x86-64%s sudah ditinggalkan. Lebih baik gunakan %stune=k8%s atau %stune=generic%s yang lebih sesuai."
 
-#: config/i386/i386.c:3777
+#: config/i386/i386.c:3780
 #, fuzzy, gcc-internal-format
 #| msgid "%stune=x86-64%s is deprecated.  Use %stune=k8%s or %stune=generic%s instead as appropriate."
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
@@ -33809,549 +33852,549 @@
 msgstr "%smtune=x86-64%s sudah ditinggalkan. Lebih baik gunakan %stune=k8%s atau %stune=generic%s yang lebih sesuai."
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3804
+#: config/i386/i386.c:3807
 #, gcc-internal-format
 msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386.c:3821
+#: config/i386/i386.c:3824
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in the %s bit mode"
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "model kode %qs tidak mendukung dalam mode %s bit"
 
-#: config/i386/i386.c:3833
+#: config/i386/i386.c:3836
 #, fuzzy, gcc-internal-format
 #| msgid "profiling not supported with -mg\n"
 msgid "-mabi=ms not supported with X32 ABI"
 msgstr "profiling tidak didukung dengan -mg\n"
 
-#: config/i386/i386.c:3851 config/i386/i386.c:3860 config/i386/i386.c:3872
-#: config/i386/i386.c:3883 config/i386/i386.c:3894
+#: config/i386/i386.c:3854 config/i386/i386.c:3863 config/i386/i386.c:3875
+#: config/i386/i386.c:3886 config/i386/i386.c:3897
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "model kode %qs tidak mendukung dalam mode %s bit"
 
-#: config/i386/i386.c:3863 config/i386/i386.c:3875
+#: config/i386/i386.c:3866 config/i386/i386.c:3878
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in the %s bit mode"
 msgid "code model %qs not supported in x32 mode"
 msgstr "model kode %qs tidak mendukung dalam mode %s bit"
 
-#: config/i386/i386.c:3881 config/i386/i386.c:3890 config/i386/i386.c:5213
+#: config/i386/i386.c:3884 config/i386/i386.c:3893 config/i386/i386.c:5216
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "model kode %s tidak mendukung kode PIC"
 
-#: config/i386/i386.c:3918
+#: config/i386/i386.c:3921
 #, fuzzy, gcc-internal-format
 #| msgid "-m%s not supported in this configuration"
 msgid "-masm=intel not supported in this configuration"
 msgstr "-m%s tidak didukung dalam konfigurasi ini"
 
-#: config/i386/i386.c:3923
+#: config/i386/i386.c:3926
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "%i-bit mode tidak terkompile"
 
-#: config/i386/i386.c:3932
+#: config/i386/i386.c:3935
 #, fuzzy, gcc-internal-format
 #| msgid "generic CPU can be used only for %stune=%s %s"
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr "CPU generik hanya dapat digunakan untuk pilihan %stune=%s %s"
 
-#: config/i386/i386.c:3934
+#: config/i386/i386.c:3937
 #, fuzzy, gcc-internal-format
 #| msgid "generic CPU can be used only for %stune=%s %s"
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "CPU generik hanya dapat digunakan untuk pilihan %stune=%s %s"
 
-#: config/i386/i386.c:3941
+#: config/i386/i386.c:3944
 #, fuzzy, gcc-internal-format
 #| msgid "generic CPU can be used only for %stune=%s %s"
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr "CPU generik hanya dapat digunakan untuk pilihan %stune=%s %s"
 
-#: config/i386/i386.c:3943
+#: config/i386/i386.c:3946
 #, fuzzy, gcc-internal-format
 #| msgid "generic CPU can be used only for %stune=%s %s"
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "CPU generik hanya dapat digunakan untuk pilihan %stune=%s %s"
 
-#: config/i386/i386.c:3951 config/i386/i386.c:4265
+#: config/i386/i386.c:3954 config/i386/i386.c:4268
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "CPU yang anda pilih tidak mendukung set instruksi x86-64"
 
-#: config/i386/i386.c:4197 config/i386/i386.c:4200
+#: config/i386/i386.c:4200 config/i386/i386.c:4203
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "Intel MPX does not support x32"
 msgstr "%s tidak mendukung %s"
 
-#: config/i386/i386.c:4205
+#: config/i386/i386.c:4208
 #, fuzzy, gcc-internal-format
 #| msgid "bad value %qs for -mcpu switch"
 msgid "bad value (%qs) for %<-march=%> switch"
 msgstr "nilai buruk %qs untuk pilihan -mcpu"
 
-#: config/i386/i386.c:4206
+#: config/i386/i386.c:4209
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for %sarch=%s %s"
 msgid "bad value (%qs) for %<target(\"arch=\")%> attribute"
 msgstr "nilai (%s) buruk untuk pilihan %sarch=%s %s"
 
-#: config/i386/i386.c:4228
+#: config/i386/i386.c:4231
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4230
+#: config/i386/i386.c:4233
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4235
+#: config/i386/i386.c:4238
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr ""
 
-#: config/i386/i386.c:4236
+#: config/i386/i386.c:4239
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "argumen dari atribut %qs tidak valid"
 
-#: config/i386/i386.c:4284
+#: config/i386/i386.c:4287
 #, fuzzy, gcc-internal-format
 #| msgid "bad value %<%s%> for -mtune= switch"
 msgid "bad value (%qs) for %<-mtune=%> switch"
 msgstr "nilai %<%s%> buruk untuk pilihan -mtune="
 
-#: config/i386/i386.c:4285
+#: config/i386/i386.c:4288
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for %stune=%s %s"
 msgid "bad value (%qs) for %<target(\"tune=\")%> attribute"
 msgstr "nilai (%s) buruk untuk %stune=%s %s"
 
-#: config/i386/i386.c:4305
+#: config/i386/i386.c:4308
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4307
+#: config/i386/i386.c:4310
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4312
+#: config/i386/i386.c:4315
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to %<__builtin_return_address%>"
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "argumen ke %<__builtin_return_address%> tidak valid"
 
-#: config/i386/i386.c:4313
+#: config/i386/i386.c:4316
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "argumen dari atribut %qs tidak valid"
 
-#: config/i386/i386.c:4379
+#: config/i386/i386.c:4382
 #, fuzzy, gcc-internal-format
 #| msgid "%sregparm%s is ignored in 64-bit mode"
 msgid "-mregparm is ignored in 64-bit mode"
 msgstr "%sregparm%s diabaikan dalam mode 64 bit"
 
-#: config/i386/i386.c:4381
+#: config/i386/i386.c:4384
 #, gcc-internal-format
 msgid "-mregparm is ignored for Intel MCU psABI"
 msgstr ""
 
-#: config/i386/i386.c:4384
+#: config/i386/i386.c:4387
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%sregparm=%d%s is not between 0 and %d"
 msgid "-mregparm=%d is not between 0 and %d"
 msgstr "%sregparm=%d%s tidak berada diantara 0 dan %d"
 
-#: config/i386/i386.c:4417
+#: config/i386/i386.c:4420
 #, fuzzy, gcc-internal-format
 #| msgid "%srtd%s is ignored in 64bit mode"
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "%srtd%s diabaikan dalam mode 64 bit"
 
-#: config/i386/i386.c:4418
+#: config/i386/i386.c:4421
 #, fuzzy, gcc-internal-format
 #| msgid "%srtd%s is ignored in 64bit mode"
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "%srtd%s diabaikan dalam mode 64 bit"
 
-#: config/i386/i386.c:4497
+#: config/i386/i386.c:4500
 #, fuzzy, gcc-internal-format
 #| msgid "-fprefetch-loop-arrays not supported for this target"
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "-fprefetch-loop-array tidak didukung untuk target ini"
 
-#: config/i386/i386.c:4500
+#: config/i386/i386.c:4503
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%spreferred-stack-boundary=%d%s is not between %d and 12"
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr "%spreferred-stack-boundary=%d%s tidak berada diantara %d dan 12"
 
-#: config/i386/i386.c:4523
+#: config/i386/i386.c:4526
 #, gcc-internal-format, gfc-internal-format
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr "-mincoming-stack-boundary=%d tidak berada diantara %d dan 12"
 
-#: config/i386/i386.c:4536
+#: config/i386/i386.c:4539
 #, fuzzy, gcc-internal-format
 #| msgid "%<-march=%s%> is not compatible with the selected ABI"
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "%<-march=%s%> tidak kompatibel dengan ABI yang dipilih"
 
-#: config/i386/i386.c:4539
+#: config/i386/i386.c:4542
 #, fuzzy, gcc-internal-format
 #| msgid "inter-module optimizations not implemented for C++"
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr "inter-module optimisasi tidak diimplementasikan untuk C++"
 
-#: config/i386/i386.c:4545
+#: config/i386/i386.c:4548
 #, fuzzy, gcc-internal-format
 #| msgid "%ssseregparm%s used without SSE enabled"
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "%ssseregparam%s digunakan tanpa SSE aktif"
 
-#: config/i386/i386.c:4546
+#: config/i386/i386.c:4549
 #, fuzzy, gcc-internal-format
 #| msgid "%ssseregparm%s used without SSE enabled"
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "%ssseregparam%s digunakan tanpa SSE aktif"
 
-#: config/i386/i386.c:4556
+#: config/i386/i386.c:4559
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "set instruksi SSE non-aktif, menggunakan 387 aritmetik"
 
-#: config/i386/i386.c:4563
+#: config/i386/i386.c:4566
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "set instruksi 387 non-aktif, menggunakan aritmetik SSE"
 
-#: config/i386/i386.c:4613
+#: config/i386/i386.c:4616
 #, fuzzy, gcc-internal-format
 #| msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr "stack probing membutuhkan %saccumulate-outgoing-args%s untuk pembenaran"
 
-#: config/i386/i386.c:4615
+#: config/i386/i386.c:4618
 #, fuzzy, gcc-internal-format
 #| msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr "stack probing membutuhkan %saccumulate-outgoing-args%s untuk pembenaran"
 
-#: config/i386/i386.c:4629
+#: config/i386/i386.c:4632
 #, fuzzy, gcc-internal-format
 #| msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr "stack probing membutuhkan %saccumulate-outgoing-args%s untuk pembenaran"
 
-#: config/i386/i386.c:4631
+#: config/i386/i386.c:4634
 #, fuzzy, gcc-internal-format
 #| msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr "stack probing membutuhkan %saccumulate-outgoing-args%s untuk pembenaran"
 
-#: config/i386/i386.c:4741
+#: config/i386/i386.c:4744
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr ""
 
-#: config/i386/i386.c:4744
+#: config/i386/i386.c:4747
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr ""
 
-#: config/i386/i386.c:4748
+#: config/i386/i386.c:4751
 #, gcc-internal-format
 msgid "-mcall-ms2sysv-xlogues isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386.c:4813 config/powerpcspe/powerpcspe.c:5663
+#: config/i386/i386.c:4816 config/powerpcspe/powerpcspe.c:5663
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unknown -m%s= option specified: '%s'"
 msgid "unknown option for -mrecip=%s"
 msgstr "pilihan -m%s= tidak diketahui dispesifikasikan: '%s'"
 
-#: config/i386/i386.c:4870 config/powerpcspe/powerpcspe.c:5339
+#: config/i386/i386.c:4873 config/powerpcspe/powerpcspe.c:5339
 #, gcc-internal-format
 msgid "%qs is not a valid number in -mstack-protector-guard-offset="
 msgstr ""
 
-#: config/i386/i386.c:4875 config/powerpcspe/powerpcspe.c:5344
+#: config/i386/i386.c:4878 config/powerpcspe/powerpcspe.c:5344
 #, gcc-internal-format
 msgid "%qs is not a valid offset in -mstack-protector-guard-offset="
 msgstr ""
 
-#: config/i386/i386.c:4907 config/powerpcspe/powerpcspe.c:5356
+#: config/i386/i386.c:4910 config/powerpcspe/powerpcspe.c:5356
 #, gcc-internal-format
 msgid "%qs is not a valid base register in -mstack-protector-guard-reg="
 msgstr ""
 
-#: config/i386/i386.c:5506 config/i386/i386.c:5553 config/s390/s390.c:15812
+#: config/i386/i386.c:5509 config/i386/i386.c:5556 config/s390/s390.c:15812
 #: config/s390/s390.c:15862 config/s390/s390.c:15879
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr "atribut(target(\"%s\")) tidak diketahui"
 
-#: config/i386/i386.c:5534
+#: config/i386/i386.c:5537
 #, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr "pilihan(\"%s\") telah dispesifikasikan"
 
-#: config/i386/i386.c:5837
+#: config/i386/i386.c:5840
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and cdecl attributes are not compatible"
 msgid "interrupt and naked attributes are not compatible"
 msgstr "atribut stdcall dan cdecl tidak kompatibel"
 
-#: config/i386/i386.c:5852
+#: config/i386/i386.c:5855
 #, gcc-internal-format
 msgid "Only DWARF debug format is supported for interrupt service routine."
 msgstr ""
 
-#: config/i386/i386.c:5901
+#: config/i386/i386.c:5904
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s dan -mcall-%s tidak kompatibel"
 
-#: config/i386/i386.c:5913
+#: config/i386/i386.c:5916
 #, gcc-internal-format
 msgid "%<-mindirect-branch=thunk-extern%>, %<-fcf-protection=branch%> and %<-fcheck-pointer-bounds%> are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5949
+#: config/i386/i386.c:5952
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s dan -mcall-%s tidak kompatibel"
 
-#: config/i386/i386.c:6047
+#: config/i386/i386.c:6050
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Specify when instructions are allowed to access code"
 msgid "%s instructions aren't allowed in %s service routine"
 msgstr "Spesifikasikan kapan instruksi diperbolehkan untuk mengakses kode"
 
-#: config/i386/i386.c:6051
+#: config/i386/i386.c:6054
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in function with no_caller_saved_registers attribute"
 msgstr ""
 
-#: config/i386/i386.c:6465 config/i386/i386.c:6516
+#: config/i386/i386.c:6468 config/i386/i386.c:6519
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "atribut fastcall dan regparm tidak kompatibel"
 
-#: config/i386/i386.c:6470
+#: config/i386/i386.c:6473
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "atribut fastcall dan stdcall tidak kompatibel"
 
-#: config/i386/i386.c:6477 config/i386/i386.c:41444
+#: config/i386/i386.c:6480 config/i386/i386.c:41438
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
 msgid "%qE attribute requires an integer constant argument"
 msgstr "atribut %qs membutuhkan sebuah argumen konstanta integer"
 
-#: config/i386/i386.c:6483
+#: config/i386/i386.c:6486
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs attribute larger than %d"
 msgid "argument to %qE attribute larger than %d"
 msgstr "argumen ke atribut %qs lebih besar daripada %d"
 
-#: config/i386/i386.c:6508 config/i386/i386.c:6551
+#: config/i386/i386.c:6511 config/i386/i386.c:6554
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "atribut fastcall dan cdecl tidak kompatibel"
 
-#: config/i386/i386.c:6512
+#: config/i386/i386.c:6515
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "atribut fastcall dan stdcall tidak kompatibel"
 
-#: config/i386/i386.c:6520 config/i386/i386.c:6569
+#: config/i386/i386.c:6523 config/i386/i386.c:6572
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "atribut fastcall dan stdcall tidak kompatibel"
 
-#: config/i386/i386.c:6530 config/i386/i386.c:6547
+#: config/i386/i386.c:6533 config/i386/i386.c:6550
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "atribut stdcall dan cdecl tidak kompatibel"
 
-#: config/i386/i386.c:6534
+#: config/i386/i386.c:6537
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "atribut stdcall dan fastcall tidak kompatibel"
 
-#: config/i386/i386.c:6538 config/i386/i386.c:6565
+#: config/i386/i386.c:6541 config/i386/i386.c:6568
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and fastcall attributes are not compatible"
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "atribut stdcall dan fastcall tidak kompatibel"
 
-#: config/i386/i386.c:6555 config/i386/i386.c:6573
+#: config/i386/i386.c:6558 config/i386/i386.c:6576
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and fastcall attributes are not compatible"
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "atribut stdcall dan fastcall tidak kompatibel"
 
-#: config/i386/i386.c:6561
+#: config/i386/i386.c:6564
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute is used for non-class method"
 msgstr "%qE atribut diabaikan dalam tipe bukan-class"
 
-#: config/i386/i386.c:6805
+#: config/i386/i386.c:6808
 #, fuzzy, gcc-internal-format
 #| msgid "Calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "Memanggil %qD dengan atribut sseregparm tanpa mengaktifkan SSE/SSE2"
 
-#: config/i386/i386.c:6808
+#: config/i386/i386.c:6811
 #, fuzzy, gcc-internal-format
 #| msgid "Calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "Memanggil %qT dengan atribut sseregparm tanpa mengaktifkan SSE/SSE2"
 
-#: config/i386/i386.c:7126
+#: config/i386/i386.c:7129
 #, fuzzy, gcc-internal-format
 #| msgid "does not support multilib"
 msgid "X32 does not support ms_abi attribute"
 msgstr "tidak mendukung multilib"
 
-#: config/i386/i386.c:7160
+#: config/i386/i386.c:7163
 #, gcc-internal-format
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr ""
 
-#: config/i386/i386.c:7502
+#: config/i386/i386.c:7505
 #, fuzzy, gcc-internal-format
 #| msgid "AVX vector argument without AVX enabled changes the ABI"
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr "argumen vektor AVX tanpa AVX aktif mengubah ABI"
 
-#: config/i386/i386.c:7508
+#: config/i386/i386.c:7511
 #, fuzzy, gcc-internal-format
 #| msgid "AVX vector argument without AVX enabled changes the ABI"
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr "argumen vektor AVX tanpa AVX aktif mengubah ABI"
 
-#: config/i386/i386.c:7522
+#: config/i386/i386.c:7525
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr "argumen vektor AVX tanpa AVX aktif mengubah ABI"
 
-#: config/i386/i386.c:7528
+#: config/i386/i386.c:7531
 #, fuzzy, gcc-internal-format
 #| msgid "AVX vector argument without AVX enabled changes the ABI"
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr "argumen vektor AVX tanpa AVX aktif mengubah ABI"
 
-#: config/i386/i386.c:7544
+#: config/i386/i386.c:7547
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr "argumen vektor SSE tanpa SSE aktif mengubah ABI"
 
-#: config/i386/i386.c:7550
+#: config/i386/i386.c:7553
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr "SSE vektor kembali tanpa SSE aktif mengubah ABI"
 
-#: config/i386/i386.c:7566
+#: config/i386/i386.c:7569
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr "argumen vektor MMX tanpa MMX aktif mengubah ABI"
 
-#: config/i386/i386.c:7572
+#: config/i386/i386.c:7575
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr "MMX vektor kembali tanpa MMX aktif mengubah ABI"
 
-#: config/i386/i386.c:7754
+#: config/i386/i386.c:7757
 #, fuzzy, gcc-internal-format
 #| msgid "The ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr "ABI dari melewatkan struct dengan sebuah anggota array flexible telah berubah dalam GCC 4.4"
 
-#: config/i386/i386.c:7871
+#: config/i386/i386.c:7874
 #, fuzzy, gcc-internal-format
 #| msgid "The ABI of passing union with long double has changed in GCC 4.4"
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr "ABI dari melewatkan union dengan long double telah berubah dalam GCC 4.4"
 
-#: config/i386/i386.c:7989
+#: config/i386/i386.c:7992
 #, fuzzy, gcc-internal-format
 #| msgid "The ABI of passing structure with complex float member has changed in GCC 4.4"
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr "ABI dari melewatkan structure dengan anggota float kompleks telah berubah dalam GCC 4.4"
 
-#: config/i386/i386.c:8152
+#: config/i386/i386.c:8155
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr "register SSE kembali dengan SSE tidak aktif"
 
-#: config/i386/i386.c:8158
+#: config/i386/i386.c:8161
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr "argumen register SSE dengan SSE tidak aktif"
 
-#: config/i386/i386.c:8174
+#: config/i386/i386.c:8177
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr "x87 register kembali dengan x87 tidak aktif"
 
-#: config/i386/i386.c:8471 config/i386/i386.c:8750 config/i386/i386.c:9276
+#: config/i386/i386.c:8474 config/i386/i386.c:8753 config/i386/i386.c:9279
 #, fuzzy, gcc-internal-format
 #| msgid "Calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr "Memanggil %qD dengan atribut sseregparm tanpa mengaktifkan SSE/SSE2"
 
-#: config/i386/i386.c:8473 config/i386/i386.c:8752 config/i386/i386.c:9278
+#: config/i386/i386.c:8476 config/i386/i386.c:8755 config/i386/i386.c:9281
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr ""
 
-#: config/i386/i386.c:9178
+#: config/i386/i386.c:9181
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The ABI of passing union with long double has changed in GCC 4.4"
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr "ABI dari melewatkan union dengan long double telah berubah dalam GCC 4.4"
 
-#: config/i386/i386.c:11601
+#: config/i386/i386.c:11604
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "assert: %s is assign compatible with %s"
 msgid "-mcall-ms2sysv-xlogues is not compatible with %s"
 msgstr "assert: %s adalah assign kompatibel dengan %s"
 
-#: config/i386/i386.c:13593
+#: config/i386/i386.c:13596
 #, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr ""
 
-#: config/i386/i386.c:13683
+#: config/i386/i386.c:13686
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr ""
 
-#: config/i386/i386.c:14970
+#: config/i386/i386.c:14973
 #, fuzzy, gcc-internal-format
 #| msgid "%s not supported for nested functions"
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr "%s tidak didukung untuk fungsi nested"
 
-#: config/i386/i386.c:14990
+#: config/i386/i386.c:14993
 #, fuzzy, gcc-internal-format
 #| msgid "%s not supported for nested functions"
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
@@ -34359,261 +34402,261 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:15001
+#: config/i386/i386.c:15004
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr "ISO C90 tidak mendukung keanggotaan array fleksibel"
 
-#: config/i386/i386.c:17939
+#: config/i386/i386.c:17942
 #, gcc-internal-format
 msgid "'V' modifier on non-integer register"
 msgstr ""
 
-#: config/i386/i386.c:17950 config/i386/i386.c:17964
+#: config/i386/i386.c:17953 config/i386/i386.c:17967
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported operand size for extended register"
 msgid "unsupported size for integer register"
 msgstr "ukuran operan tidak didukung untuk register ekstended"
 
-#: config/i386/i386.c:17996
+#: config/i386/i386.c:17999
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr "register extended tidak memiliki setengah tinggi"
 
-#: config/i386/i386.c:18011
+#: config/i386/i386.c:18014
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr "ukuran operan tidak didukung untuk register ekstended"
 
-#: config/i386/i386.c:18202
+#: config/i386/i386.c:18205
 #, fuzzy, gcc-internal-format
 #| msgid "non-integral used in condition"
 msgid "non-integer operand used with operand code 'z'"
 msgstr "bukan integral digunakan dalam kondisi"
 
-#: config/i386/i386.c:28467
+#: config/i386/i386.c:28470
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine can't be called directly"
 msgstr "Interrupt Sevice Routines tidak dapat dikodekan dalam mode Thumb"
 
-#: config/i386/i386.c:29995
+#: config/i386/i386.c:29998
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in -fabi-version=12 (GCC 8)"
 msgstr ""
 
-#: config/i386/i386.c:32435
+#: config/i386/i386.c:32438
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr ""
 
-#: config/i386/i386.c:32485
+#: config/i386/i386.c:32488
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for %s"
 msgstr ""
 
-#: config/i386/i386.c:32495
+#: config/i386/i386.c:32498
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr ""
 
-#: config/i386/i386.c:32657
+#: config/i386/i386.c:32660
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386.c:32662 config/i386/i386.c:32938
-#: config/rs6000/rs6000.c:37850
+#: config/i386/i386.c:32665 config/i386/i386.c:32941
+#: config/rs6000/rs6000.c:37906
 #, fuzzy, gcc-internal-format
 #| msgid "stack limit expression is not supported"
 msgid "Virtual function multiversioning not supported"
 msgstr "ekspresi batas stack tidak didukung"
 
-#: config/i386/i386.c:32795 config/rs6000/rs6000.c:37607
+#: config/i386/i386.c:32798 config/rs6000/rs6000.c:37663
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "__builtin_eh_return tidak didukung dalam target ini"
 
-#: config/i386/i386.c:33207
+#: config/i386/i386.c:33210
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs must be a 2-bit unsigned literal"
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr "argumen ke %qs harus berupa sebuah 2 bit unsigned literal"
 
-#: config/i386/i386.c:33232 config/i386/i386.c:33282
+#: config/i386/i386.c:33235 config/i386/i386.c:33285
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument to -ffpe-trap is not valid: %s"
 msgid "Parameter to builtin not valid: %s"
 msgstr "Argumen ke -ffpe-trap tidak valid: %s"
 
-#: config/i386/i386.c:33975 config/i386/i386.c:35415
+#: config/i386/i386.c:33978 config/i386/i386.c:35418
 #, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 2 bit immediate"
 
-#: config/i386/i386.c:34370
+#: config/i386/i386.c:34373
 #, fuzzy, gcc-internal-format
 #| msgid "the fifth argument must be a 8-bit immediate"
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "argumen kelima harus berupa sebuah 8 bit immediate"
 
-#: config/i386/i386.c:34465
+#: config/i386/i386.c:34468
 #, fuzzy, gcc-internal-format
 #| msgid "the third argument must be a 8-bit immediate"
 msgid "the third argument must be an 8-bit immediate"
 msgstr "argumen ketiga harus berupa sebuah 8 bit immediate"
 
-#: config/i386/i386.c:35346
+#: config/i386/i386.c:35349
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 1-bit immediate"
 msgid "the last argument must be an 1-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 1 bit immediate"
 
-#: config/i386/i386.c:35361
+#: config/i386/i386.c:35364
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 4-bit immediate"
 msgid "the last argument must be a 3-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 4 bit immediate"
 
-#: config/i386/i386.c:35394
+#: config/i386/i386.c:35397
 #, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 4 bit immediate"
 
-#: config/i386/i386.c:35434
+#: config/i386/i386.c:35437
 #, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 1 bit immediate"
 
-#: config/i386/i386.c:35447
+#: config/i386/i386.c:35450
 #, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 5 bit immediate"
 
-#: config/i386/i386.c:35457
+#: config/i386/i386.c:35460
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "argumen selanjutnya ke terakhir harus berupa sebuah 8 bit immediate"
 
-#: config/i386/i386.c:35462 config/i386/i386.c:36249
+#: config/i386/i386.c:35465 config/i386/i386.c:36252
 #, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 8 bit immediate"
 
-#: config/i386/i386.c:35596
+#: config/i386/i386.c:35599
 #, fuzzy, gcc-internal-format
 #| msgid "argument must be a constant"
 msgid "the third argument must be comparison constant"
 msgstr "argumen harus berupa sebuah konstanta"
 
-#: config/i386/i386.c:35601
+#: config/i386/i386.c:35604
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect comparison mode"
 msgstr "insn tidak benar:"
 
-#: config/i386/i386.c:35607 config/i386/i386.c:35814
+#: config/i386/i386.c:35610 config/i386/i386.c:35817
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect sharing of tree nodes"
 msgid "incorrect rounding operand"
 msgstr "pembagian tidak benar dari titik pohon"
 
-#: config/i386/i386.c:35796
+#: config/i386/i386.c:35799
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 4-bit immediate"
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 4 bit immediate"
 
-#: config/i386/i386.c:35802
+#: config/i386/i386.c:35805
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 5-bit immediate"
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 5 bit immediate"
 
-#: config/i386/i386.c:35805
+#: config/i386/i386.c:35808
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be an 8-bit immediate"
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 8 bit immediate"
 
-#: config/i386/i386.c:36247
+#: config/i386/i386.c:36250
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 2-bit immediate"
 msgid "the last argument must be a 32-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 2 bit immediate"
 
-#: config/i386/i386.c:36329 config/powerpcspe/powerpcspe.c:16219
-#: config/rs6000/rs6000.c:15304
+#: config/i386/i386.c:36332 config/powerpcspe/powerpcspe.c:16219
+#: config/rs6000/rs6000.c:15348
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr "pemilih harus berupa sebuah konstanta integer dalam jangkauan 0..%wi"
 
-#: config/i386/i386.c:36539
+#: config/i386/i386.c:36542
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr "%qE membutuhkan pilihan isa tidak diketahui"
 
-#: config/i386/i386.c:36543
+#: config/i386/i386.c:36546
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "%qE membutuhkan pilihan isa %s"
 
-#: config/i386/i386.c:37381
+#: config/i386/i386.c:37375
 #, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "argumen terakhir harus berupa sebuah immediate"
 
-#: config/i386/i386.c:38108 config/i386/i386.c:38290
+#: config/i386/i386.c:38102 config/i386/i386.c:38284
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 4-bit immediate"
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "argumen terakhir harus berupa sebuah 4 bit immediate"
 
-#: config/i386/i386.c:38343
+#: config/i386/i386.c:38337
 #, fuzzy, gcc-internal-format
 #| msgid "the fifth argument must be a 8-bit immediate"
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "argumen kelima harus berupa sebuah 8 bit immediate"
 
-#: config/i386/i386.c:38349
+#: config/i386/i386.c:38343
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect hint operand"
 msgstr "insn tidak benar:"
 
-#: config/i386/i386.c:38368
+#: config/i386/i386.c:38362
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be an 8-bit immediate"
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 8 bit immediate"
 
-#: config/i386/i386.c:41431
+#: config/i386/i386.c:41425
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only available for 64-bit"
 msgid "%qE attribute only available for 32-bit"
 msgstr "%qs atribut hanya tersedia untuk 64 bit"
 
-#: config/i386/i386.c:41452
+#: config/i386/i386.c:41446
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "argumen dari atribut %qs bukan sebuah konstanta string"
 
-#: config/i386/i386.c:41485 config/i386/i386.c:41494
+#: config/i386/i386.c:41479 config/i386/i386.c:41488
 #, gcc-internal-format
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr "atribut ms_abi dan sysv_abi tidak kompatibel"
 
-#: config/i386/i386.c:41530 config/powerpcspe/powerpcspe.c:35868
-#: config/rs6000/rs6000.c:33065
+#: config/i386/i386.c:41524 config/powerpcspe/powerpcspe.c:35868
+#: config/rs6000/rs6000.c:33121
 #, fuzzy, gcc-internal-format
 #| msgid "%qs incompatible attribute ignored"
 msgid "%qE incompatible attribute ignored"
 msgstr "atribut %qs tidak kompatibel diabaikan"
 
-#: config/i386/i386.c:41555 config/i386/i386.c:41577 config/ia64/ia64.c:815
+#: config/i386/i386.c:41549 config/i386/i386.c:41571 config/ia64/ia64.c:815
 #: config/s390/s390.c:1153
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
@@ -34620,85 +34663,85 @@
 msgid "%qE attribute requires a string constant argument"
 msgstr "atribut %qs membutuhkan sebuah argumen konstanta integer"
 
-#: config/i386/i386.c:41565 config/i386/i386.c:41587 config/s390/s390.c:1182
+#: config/i386/i386.c:41559 config/i386/i386.c:41581 config/s390/s390.c:1182
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "argumen dari atribut %qs bukan sebuah konstanta string"
 
-#: config/i386/i386.c:41619
+#: config/i386/i386.c:41613
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386.c:41626
+#: config/i386/i386.c:41620
 #, gcc-internal-format, gfc-internal-format
 msgid "interrupt service routine should have unsigned %sint as the second argument"
 msgstr ""
 
-#: config/i386/i386.c:41636
+#: config/i386/i386.c:41630
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386.c:41639
+#: config/i386/i386.c:41633
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine can't have non-void return value"
 msgstr "Interrupt Sevice Routines tidak dapat dikodekan dalam mode Thumb"
 
-#: config/i386/i386.c:44676
+#: config/i386/i386.c:44670
 #, fuzzy, gcc-internal-format
 #| msgid "By-value argument at %L is not allowed in this context"
 msgid "alternatives not allowed in asm flag output"
 msgstr "Argumen dengan nilai di %L tidak diperbolehkan dalam konteks ini"
 
-#: config/i386/i386.c:44740
+#: config/i386/i386.c:44734
 #, fuzzy, gcc-internal-format
 #| msgid "unknown ira algorithm \"%s\""
 msgid "unknown asm flag output %qs"
 msgstr "algoritma ira \"%s\" tidak diketahui"
 
-#: config/i386/i386.c:44769
+#: config/i386/i386.c:44763
 #, fuzzy, gcc-internal-format
 #| msgid "invalid lvalue in asm output %d"
 msgid "invalid type for asm flag output"
 msgstr "lvalue tidak valid dalam keluaran asm %d"
 
-#: config/i386/i386.c:50634
+#: config/i386/i386.c:50628
 #, fuzzy, gcc-internal-format
 #| msgid "Unknown architecture '%s'"
 msgid "unknown architecture specific memory model"
 msgstr "Arsitektur '%s' tidak dikenal"
 
-#: config/i386/i386.c:50641
+#: config/i386/i386.c:50635
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50647
+#: config/i386/i386.c:50641
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50671 config/i386/i386.c:50787
+#: config/i386/i386.c:50665 config/i386/i386.c:50781
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "unsupported simdlen %d"
 msgstr "kombinasi tidak didukung: %s"
 
-#: config/i386/i386.c:50690
+#: config/i386/i386.c:50684
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd"
 msgstr ""
 
-#: config/i386/i386.c:50712
+#: config/i386/i386.c:50706
 #, fuzzy, gcc-internal-format
 #| msgid "unused arguments in $-style format"
 msgid "unsupported argument type %qT for simd"
 msgstr "argumen yang tidak digunakan dalam $-gaya format"
 
-#: config/i386/i386.c:51033
+#: config/i386/i386.c:51027
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr ""
@@ -34936,7 +34979,7 @@
 msgstr "interrupt_thread hanya tersedia di fido"
 
 #: config/m68k/m68k.c:1128 config/powerpcspe/powerpcspe.c:28512
-#: config/rs6000/rs6000.c:25791
+#: config/rs6000/rs6000.c:25868
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "ekspresi batas stack tidak didukung"
@@ -35553,10 +35596,10 @@
 
 #. Trampoline is not supported on reduced-set registers yet.
 #: config/nds32/nds32.c:2327 config/nds32/nds32.c:2381
-#: config/nds32/nds32.c:3127 config/nds32/nds32.c:3201
-#: config/nds32/nds32.c:3216 config/nds32/nds32.c:3222
-#: config/nds32/nds32.c:3284 config/nds32/nds32.c:3290
-#: config/nds32/nds32.c:3322
+#: config/nds32/nds32.c:3128 config/nds32/nds32.c:3202
+#: config/nds32/nds32.c:3217 config/nds32/nds32.c:3223
+#: config/nds32/nds32.c:3285 config/nds32/nds32.c:3291
+#: config/nds32/nds32.c:3323
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "a nested function is not supported for reduced registers"
@@ -35563,55 +35606,55 @@
 msgstr "-fdata-sections tidak didukung untuk target ini"
 
 #. The enum index value for array size is out of range.
-#: config/nds32/nds32.c:3025
+#: config/nds32/nds32.c:3026
 #, fuzzy, gcc-internal-format
 #| msgid "invalid register in the instruction"
 msgid "intrinsic register index is out of range"
 msgstr "register tidak valid dalam instruksi"
 
-#: config/nds32/nds32.c:3041 config/nds32/nds32.c:3048
-#: config/nds32/nds32.c:3055 config/nds32/nds32.c:3062
-#: config/nds32/nds32.c:3069
+#: config/nds32/nds32.c:3042 config/nds32/nds32.c:3049
+#: config/nds32/nds32.c:3056 config/nds32/nds32.c:3063
+#: config/nds32/nds32.c:3070
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic function %s(%d) not recognized"
 msgid "CCTL intrinsic function subtype out of range!"
 msgstr "Fungsi instrinsik %s(%d) tidak dikenal"
 
-#: config/nds32/nds32.c:3508
+#: config/nds32/nds32.c:3509
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type for iteration variable %qE"
 msgid "invalid id value for interrupt/exception attribute"
 msgstr "tipe tidak valid untuk iterasi variabel %qE"
 
-#: config/nds32/nds32.c:3536
+#: config/nds32/nds32.c:3537
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "invalid id value for reset attribute"
 msgstr "argumen dari atribut %qs tidak valid"
 
-#: config/nds32/nds32.c:3552
+#: config/nds32/nds32.c:3553
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "invalid nmi function for reset attribute"
 msgstr "argumen dari atribut %qs tidak valid"
 
-#: config/nds32/nds32.c:3565
+#: config/nds32/nds32.c:3566
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "invalid warm function for reset attribute"
 msgstr "argumen dari atribut %qs tidak valid"
 
-#: config/nds32/nds32.c:3638
+#: config/nds32/nds32.c:3639
 #, gcc-internal-format
 msgid "Disable FPU ISA, the ABI option must be enable '-mfloat-abi=soft'"
 msgstr ""
 
-#: config/nds32/nds32.c:3641
+#: config/nds32/nds32.c:3642
 #, gcc-internal-format
 msgid "'-mabi=2fp+' option only support when FPU available, must be enable '-mext-fpu-sp' or '-mext-fpu-dp'"
 msgstr ""
 
-#: config/nds32/nds32.c:3647
+#: config/nds32/nds32.c:3648
 #, fuzzy, gcc-internal-format
 #| msgid "Generate position-independent code if possible (large mode)"
 msgid "position-independent code not supported"
@@ -35965,12 +36008,12 @@
 msgid "junk at end of #pragma longcall"
 msgstr "sampah diakhir dari #pragma longcall"
 
-#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6154
+#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6152
 #, gcc-internal-format
 msgid "vec_lvsl is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6158
+#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6156
 #, gcc-internal-format
 msgid "vec_lvsr is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
@@ -36024,7 +36067,7 @@
 msgid "vec_insert only accepts 3 arguments"
 msgstr "vec_insert hanya menerima 3 argumen"
 
-#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6868
+#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6866
 #, fuzzy, gcc-internal-format
 #| msgid "passing arg %d of %qE discards qualifiers frompointer target type"
 msgid "passing arg %d of %qE discards qualifiers from pointer target type"
@@ -36115,7 +36158,7 @@
 msgid "target attribute or pragma changes SPE ABI"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4351 config/rs6000/rs6000.c:4223
+#: config/powerpcspe/powerpcspe.c:4351 config/rs6000/rs6000.c:4243
 #, gcc-internal-format
 msgid "AltiVec not supported in this target"
 msgstr "AltiVec tidak didukung dalam target ini"
@@ -36268,7 +36311,7 @@
 msgid "-mvsx-small-integer requires -mpower8-vector, -mupper-regs-di, and -mdirect-move"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4959 config/rs6000/rs6000.c:4601
+#: config/powerpcspe/powerpcspe.c:4959 config/rs6000/rs6000.c:4628
 #, gcc-internal-format
 msgid "target attribute or pragma changes long double size"
 msgstr ""
@@ -36310,22 +36353,22 @@
 msgstr "perpusatakaan vektorisasi tidak dikenal tipe ABI (%s) untuk pilihan %sveclibabi=%s %s"
 
 #: config/powerpcspe/powerpcspe.c:5140 config/powerpcspe/powerpcspe.c:5155
-#: config/rs6000/rs6000.c:4766 config/rs6000/rs6000.c:4781
+#: config/rs6000/rs6000.c:4791 config/rs6000/rs6000.c:4806
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:5168 config/rs6000/rs6000.c:4794
+#: config/powerpcspe/powerpcspe.c:5168 config/rs6000/rs6000.c:4819
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:5234 config/rs6000/rs6000.c:4828
+#: config/powerpcspe/powerpcspe.c:5234 config/rs6000/rs6000.c:4853
 #, gcc-internal-format
 msgid "target attribute or pragma changes single precision floating point"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:5237 config/rs6000/rs6000.c:4831
+#: config/powerpcspe/powerpcspe.c:5237 config/rs6000/rs6000.c:4856
 #, gcc-internal-format
 msgid "target attribute or pragma changes double precision floating point"
 msgstr ""
@@ -36335,12 +36378,12 @@
 msgid "-mstack-protector-guard=tls needs a valid base register"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:8415 config/rs6000/rs6000.c:7925
+#: config/powerpcspe/powerpcspe.c:8415 config/rs6000/rs6000.c:7950
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11237
+#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11269
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC vektor dikembalikan dengan referensi: ekstensi bukan standar ABI dengan tidak ada garansi kompabilitas"
@@ -36350,7 +36393,7 @@
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "tidak dapat memberikan nilai kembali dalam register vektor karena instruksi altivec tidak aktif, gunakan -maltivec untuk mengaktifkannya"
 
-#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11595
+#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11633
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The ABI of passing union with long double has changed in GCC 4.4"
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
@@ -36361,13 +36404,13 @@
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "tidak dapat melewatkan argumen dalam vektor register karena instruksi altivek tidak aktif, gunakan -maltivec untuk mengaktifkannya"
 
-#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12604
+#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12648
 #, fuzzy, gcc-internal-format
 #| msgid "The ABI of passing structure with complex float member has changed in GCC 4.4"
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr "ABI dari melewatkan structure dengan anggota float kompleks telah berubah dalam GCC 4.4"
 
-#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12779
+#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12823
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC vektor dilewatkan dengan referensi: bukan ekstensi standar ABI dengan tidak ada garansi kompabilitas"
@@ -36378,30 +36421,30 @@
 msgid "internal error: builtin function %s already processed"
 msgstr "Perlakukan berkas masukan seperti sudah terproses"
 
-#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:13971
+#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:14015
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "argument 1 must be an 8-bit field value"
 msgstr "argumen 1 harus berupa sebuah 5 bit signed literal"
 
-#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14015
+#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14059
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "argumen 1 harus berupa sebuah 5 bit signed literal"
 
 #: config/powerpcspe/powerpcspe.c:14934 config/powerpcspe/powerpcspe.c:16803
-#: config/rs6000/rs6000.c:14101
+#: config/rs6000/rs6000.c:14145
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "argumen 2 harus berupa sebuah 5 bit unsigned literal"
 
-#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14119
+#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14163
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "argumen 2 harus berupa sebuah 5 bit unsigned literal"
 
-#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14135
+#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14179
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 7-bit unsigned literal"
@@ -36423,13 +36466,13 @@
 msgid "builtin %s is only valid in 64-bit mode"
 msgstr "%srtd%s diabaikan dalam mode 64 bit"
 
-#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14791
+#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14835
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument %d must be an unsigned literal"
 msgstr "argumen 2 harus berupa sebuah 5 bit unsigned literal"
 
-#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14793
+#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14837
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument %d is an unsigned literal that is out of range"
@@ -36455,60 +36498,60 @@
 msgid "hwcap %s is an invalid argument to builtin %s"
 msgstr "argumen ke fungsi bawaan tidak valid"
 
-#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15065
+#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15109
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "argumen 3 harus berupa sebuah 4 bit unsigned literal"
 
-#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15090
+#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15134
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "argumen 3 harus berupa sebuah 4 bit unsigned literal"
 
-#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15110
+#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15154
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "argumen 3 harus berupa sebuah 4 bit unsigned literal"
 
-#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15122
+#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15166
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "argument 1 must be 0 or 2"
 msgstr "angka harus berupa 0 atau 1"
 
-#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15134
+#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15178
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "argumen 2 harus berupa sebuah 5 bit unsigned literal"
 
-#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15148
+#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15192
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "argumen 2 harus berupa sebuah 5 bit unsigned literal"
 
-#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15160
+#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15204
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "argument 2 must be 0 or 1"
 msgstr "angka harus berupa 0 atau 1"
 
-#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15168
+#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15212
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ATANH at %L must be inside the range -1 to 1"
 msgid "argument 3 must be in the range 0..15"
 msgstr "Argumen dari ATANH di %L harus berada didalam jangkauan -1 ke 1"
 
-#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15237
-#: config/rs6000/rs6000.c:15569
+#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15281
+#: config/rs6000/rs6000.c:15613
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "argumen ke %qs harus berupa sebuah 2 bit unsigned literal"
 
-#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15394
+#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15438
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr "tidak teresolf overload untuk Altivec bawaan %qF"
@@ -36642,7 +36685,7 @@
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25758
+#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25835
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr "stack frame terlalu besar"
@@ -36652,13 +36695,13 @@
 msgid "-fsplit-stack uses register r29"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29459
+#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29536
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC target is not supported for this machine"
 msgid "Stack frame larger than 2G is not supported for -fsplit-stack"
 msgstr "#pragma GCC target tidak didukung untuk mesin ini"
 
-#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30447
+#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30524
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "tidak ada profiling dari kode 64 bit untuk ABI ini"
@@ -36668,22 +36711,22 @@
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32830
+#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32907
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "penggunaan dari %<long double%> dalam tipe AltiVec tidak valid"
 
-#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32832
+#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32909
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "penggunaan dari tipe boolean dalam tipe AltiVec tidak valid"
 
-#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32834
+#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32911
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "penggunaan dari %<complex%> dalam tipe AltiVec tidak valid"
 
-#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32836
+#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32913
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr "penggunaan dari tipe titik pecahan desimal dalam tipe AltiVec tidak valid"
@@ -36694,7 +36737,7 @@
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr "penggunaan dari %<long%> dalam tipe AltiVec tidak valid untuk kode 64 bit"
 
-#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32845
+#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32922
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "penggunaan dari %<long%> dalam tipe AltiVec sudah ditinggalkan; gunakan %<int%>"
@@ -37256,81 +37299,81 @@
 "Please use an explicit cpu name.  Valid cpu names are: %s"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6168 config/rs6000/rs6000-c.c:6219
-#: config/rs6000/rs6000-c.c:6489 config/rs6000/rs6000-c.c:6555
-#: config/rs6000/rs6000-c.c:6916 config/rs6000/rs6000-c.c:6963
+#: config/rs6000/rs6000-c.c:6166 config/rs6000/rs6000-c.c:6217
+#: config/rs6000/rs6000-c.c:6487 config/rs6000/rs6000-c.c:6553
+#: config/rs6000/rs6000-c.c:6914 config/rs6000/rs6000-c.c:6961
 #, fuzzy, gcc-internal-format
 #| msgid "%s only accepts 2 arguments"
 msgid "builtin %qs only accepts 2 arguments"
 msgstr "%s hanya menerima 2 argumen"
 
-#: config/rs6000/rs6000-c.c:6292 config/rs6000/rs6000-c.c:6375
-#: config/rs6000/rs6000-c.c:6736
+#: config/rs6000/rs6000-c.c:6290 config/rs6000/rs6000-c.c:6373
+#: config/rs6000/rs6000-c.c:6734
 #, fuzzy, gcc-internal-format
 #| msgid "%s only accepts 2 arguments"
 msgid "builtin %qs only accepts 3 arguments"
 msgstr "%s hanya menerima 2 argumen"
 
-#: config/rs6000/rs6000-c.c:6484
+#: config/rs6000/rs6000-c.c:6482
 #, fuzzy, gcc-internal-format
 #| msgid "%s only accepts 1 argument"
 msgid "builtin %qs only accepts 1 argument"
 msgstr "%s hanya menerima 1 argumen"
 
-#: config/rs6000/rs6000-c.c:7054
+#: config/rs6000/rs6000-c.c:7052
 #, gcc-internal-format
 msgid "builtin %qs requires builtin %qs"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:7058
+#: config/rs6000/rs6000-c.c:7056
 #, fuzzy, gcc-internal-format
 #| msgid "%Jalias definitions not supported in this configuration"
 msgid "builtin function %qs not supported in this compiler configuration"
 msgstr "%J definisi alias tidak didukung dalam konfigurasi ini"
 
-#: config/rs6000/rs6000-c.c:7068
+#: config/rs6000/rs6000-c.c:7066
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter combination for AltiVec intrinsic"
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr "kombinasi parameter untuk AltiVec intrinsik tidak valid"
 
-#: config/rs6000/rs6000.c:3754 config/rs6000/rs6000.c:3757
-#: config/rs6000/rs6000.c:3760
+#: config/rs6000/rs6000.c:3772 config/rs6000/rs6000.c:3775
+#: config/rs6000/rs6000.c:3778
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is predetermined %qs for %qs"
 msgid "%qs requires %qs or %qs"
 msgstr "%qE adalah predetermined %qs untuk %qs"
 
-#: config/rs6000/rs6000.c:3861
+#: config/rs6000/rs6000.c:3879
 #, fuzzy, gcc-internal-format
 #| msgid "-m64 requires PowerPC64 architecture, enabling"
 msgid "%qs requires PowerPC64 architecture, enabling"
 msgstr "-m64 membutuhkan arsitektur PowerPC64, mengaktifkan"
 
-#: config/rs6000/rs6000.c:4037
+#: config/rs6000/rs6000.c:4057
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is deprecated"
 msgid "%qs command-line option is deprecated"
 msgstr "%qs sudah ditinggalkan"
 
-#: config/rs6000/rs6000.c:4048
+#: config/rs6000/rs6000.c:4068
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-power is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgid "%qs is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr "-malign-power tidak didukung untuk 64 bit Darwin; ini tidak kompatibel dengan perpustakaan C dan C++ yang terpasang"
 
-#: config/rs6000/rs6000.c:4147
+#: config/rs6000/rs6000.c:4167
 #, gcc-internal-format
 msgid "will not generate %qs instructions because assembler lacks %qs support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4240
+#: config/rs6000/rs6000.c:4260
 #, fuzzy, gcc-internal-format
 #| msgid "-mstring is not supported on little endian systems"
 msgid "%qs is not supported on little endian systems"
 msgstr "-mstring tidak didukung di sistem little endian"
 
-#: config/rs6000/rs6000.c:4333
+#: config/rs6000/rs6000.c:4353
 #, gcc-internal-format
 msgid "power9 target option is incompatible with %<%s=<xxx>%> for <xxx> less than power9"
 msgstr ""
@@ -37337,7 +37380,7 @@
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:4341
+#: config/rs6000/rs6000.c:4361
 #, fuzzy, gcc-internal-format
 #| msgid "-fjni is incompatible with -freduced-reflection"
 msgid "%qs incompatible with explicitly disabled options"
@@ -37347,128 +37390,128 @@
 #. error messages.  However, if users have managed to select
 #. power9-fusion without selecting power8-fusion, they
 #. already know about undocumented flags.
-#: config/rs6000/rs6000.c:4366 config/rs6000/rs6000.c:4373
-#: config/rs6000/rs6000.c:4380 config/rs6000/rs6000.c:4388
-#: config/rs6000/rs6000.c:4407 config/rs6000/rs6000.c:4464
-#: config/rs6000/rs6000.c:4468 config/rs6000/rs6000.c:4485
-#: config/rs6000/rs6000.c:4538 config/rs6000/rs6000.c:4565
-#: config/rs6000/rs6000.c:4580 config/rs6000/rs6000.c:4588
-#: config/rs6000/rs6000.c:4684
+#: config/rs6000/rs6000.c:4386 config/rs6000/rs6000.c:4393
+#: config/rs6000/rs6000.c:4400 config/rs6000/rs6000.c:4408
+#: config/rs6000/rs6000.c:4427 config/rs6000/rs6000.c:4484
+#: config/rs6000/rs6000.c:4488 config/rs6000/rs6000.c:4505
+#: config/rs6000/rs6000.c:4558 config/rs6000/rs6000.c:4585
+#: config/rs6000/rs6000.c:4600 config/rs6000/rs6000.c:4608
+#: config/rs6000/rs6000.c:4709
 #, fuzzy, gcc-internal-format
 #| msgid "%qT referred to as %qs"
 msgid "%qs requires %qs"
 msgstr "%qT mereferensikan sebagai %qs"
 
-#: config/rs6000/rs6000.c:4625
+#: config/rs6000/rs6000.c:4650
 #, gcc-internal-format
 msgid "Using IEEE extended precision long double"
 msgstr "Menggunakan IEEE ekstended presisi long double"
 
-#: config/rs6000/rs6000.c:4627
+#: config/rs6000/rs6000.c:4652
 #, gcc-internal-format
 msgid "Using IBM extended precision long double"
 msgstr "Menggunakan IBM ekstended presisi long double"
 
-#: config/rs6000/rs6000.c:4644
+#: config/rs6000/rs6000.c:4669
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "%qs requires VSX support"
 msgstr "%s tidak mendukung %s"
 
-#: config/rs6000/rs6000.c:4653
+#: config/rs6000/rs6000.c:4678
 #, gcc-internal-format
 msgid "The -mfloat128 option may not be fully supported"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4676
+#: config/rs6000/rs6000.c:4701
 #, gcc-internal-format
 msgid "%qs requires full ISA 3.0 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4743
+#: config/rs6000/rs6000.c:4768
 #, fuzzy, gcc-internal-format
 #| msgid "unknown vectorization library ABI type (%s) for %sveclibabi=%s %s"
 msgid "unknown vectorization library ABI type (%qs) for %qs switch"
 msgstr "perpusatakaan vektorisasi tidak dikenal tipe ABI (%s) untuk pilihan %sveclibabi=%s %s"
 
-#: config/rs6000/rs6000.c:4930
+#: config/rs6000/rs6000.c:4955
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "%qs is not a valid number in %qs"
 msgstr "%qs tidak valid untuk %qs"
 
-#: config/rs6000/rs6000.c:4935
+#: config/rs6000/rs6000.c:4960
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "%qs is not a valid offset in %qs"
 msgstr "%qs tidak valid untuk %qs"
 
-#: config/rs6000/rs6000.c:4947
+#: config/rs6000/rs6000.c:4972
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "%qs is not a valid base register in %qs"
 msgstr "%qs tidak valid untuk %qs"
 
-#: config/rs6000/rs6000.c:4955
+#: config/rs6000/rs6000.c:4980
 #, fuzzy, gcc-internal-format
 #| msgid "Need a call-clobbered target register"
 msgid "%qs needs a valid base register"
 msgstr "Butuh sebuah call-clobbered target register"
 
-#: config/rs6000/rs6000.c:5253
+#: config/rs6000/rs6000.c:5278
 #, fuzzy, gcc-internal-format
 #| msgid "Unknown operator '%s' at %%L"
 msgid "unknown option for %<%s=%s%>"
 msgstr "Operator tidak dikenal '%s' di %%L"
 
-#: config/rs6000/rs6000.c:5290
+#: config/rs6000/rs6000.c:5315
 #, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11401
+#: config/rs6000/rs6000.c:11439
 #, fuzzy, gcc-internal-format
 #| msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgid "cannot return value in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr "tidak dapat memberikan nilai kembali dalam register vektor karena instruksi altivec tidak aktif, gunakan -maltivec untuk mengaktifkannya"
 
-#: config/rs6000/rs6000.c:11862
+#: config/rs6000/rs6000.c:11906
 #, fuzzy, gcc-internal-format
 #| msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr "tidak dapat melewatkan argumen dalam vektor register karena instruksi altivek tidak aktif, gunakan -maltivec untuk mengaktifkannya"
 
-#: config/rs6000/rs6000.c:13572
+#: config/rs6000/rs6000.c:13616
 #, fuzzy, gcc-internal-format
 #| msgid "Treat the input file as already preprocessed"
 msgid "internal error: builtin function %qs already processed"
 msgstr "Perlakukan berkas masukan seperti sudah terproses"
 
-#: config/rs6000/rs6000.c:14150
+#: config/rs6000/rs6000.c:14194
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 1-bit unsigned literal"
 msgstr "argumen 2 harus berupa sebuah 5 bit unsigned literal"
 
-#: config/rs6000/rs6000.c:14189
+#: config/rs6000/rs6000.c:14233
 #, fuzzy, gcc-internal-format
 #| msgid "argument must be a constant"
 msgid "argument 1 of %qs must be a constant"
 msgstr "argumen harus berupa sebuah konstanta"
 
-#: config/rs6000/rs6000.c:14247 config/rs6000/rs6000.c:15898
+#: config/rs6000/rs6000.c:14291 config/rs6000/rs6000.c:15942
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument 1 of %qs is out of range"
 msgstr "argumen 1 dari __builtin_spe_predicate diluar dari jangkauan"
 
-#: config/rs6000/rs6000.c:14742
+#: config/rs6000/rs6000.c:14786
 #, fuzzy, gcc-internal-format
 #| msgid "%srtd%s is ignored in 64bit mode"
 msgid "builtin %qs is only valid in 64-bit mode"
 msgstr "%srtd%s diabaikan dalam mode 64 bit"
 
-#: config/rs6000/rs6000.c:14939
+#: config/rs6000/rs6000.c:14983
 #, fuzzy, gcc-internal-format
 #| msgid "%s only accepts 1 argument"
 msgid "builtin %qs only accepts a string argument"
@@ -37475,7 +37518,7 @@
 msgstr "%s hanya menerima 1 argumen"
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000.c:14958
+#: config/rs6000/rs6000.c:15002
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to built-in function"
 msgid "cpu %qs is an invalid argument to builtin %qs"
@@ -37482,138 +37525,139 @@
 msgstr "argumen ke fungsi bawaan tidak valid"
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000.c:14986
+#: config/rs6000/rs6000.c:15030
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to built-in function"
 msgid "%s %qs is an invalid argument to builtin %qs"
 msgstr "argumen ke fungsi bawaan tidak valid"
 
-#: config/rs6000/rs6000.c:15012
+#: config/rs6000/rs6000.c:15056
 #, gcc-internal-format
 msgid "builtin %qs needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15616
+#: config/rs6000/rs6000.c:15660
 #, fuzzy, gcc-internal-format
 #| msgid "second argument of %q+D should be %<char **%>"
 msgid "second argument to %qs must be 0..12"
 msgstr "argumen kedua dari %q+D seharusnya %<char **%>"
 
-#: config/rs6000/rs6000.c:15631
+#: config/rs6000/rs6000.c:15675
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "third argument to %qs must be 0..12"
 msgstr "argumen dari atribut %qs tidak valid"
 
-#: config/rs6000/rs6000.c:15850
+#: config/rs6000/rs6000.c:15894
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument must be a constant"
 msgid "argument 1 of %s must be a constant"
 msgstr "argumen harus berupa sebuah konstanta"
 
-#: config/rs6000/rs6000.c:15932
+#: config/rs6000/rs6000.c:15976
 #, fuzzy, gcc-internal-format
 #| msgid "this builtin function is only available on the fr450"
 msgid "builtin function %qs is only valid for the cell processor"
 msgstr "fungsi bawaan ini hanya tersedia di fr450"
 
-#: config/rs6000/rs6000.c:15934 config/rs6000/rs6000.c:15936
-#: config/rs6000/rs6000.c:15938 config/rs6000/rs6000.c:15940
-#: config/rs6000/rs6000.c:15946 config/rs6000/rs6000.c:15948
-#: config/rs6000/rs6000.c:15955 config/rs6000/rs6000.c:15962
-#: config/rs6000/rs6000.c:15969 config/rs6000/rs6000.c:15975
+#: config/rs6000/rs6000.c:15978 config/rs6000/rs6000.c:15980
+#: config/rs6000/rs6000.c:15982 config/rs6000/rs6000.c:15984
+#: config/rs6000/rs6000.c:15990 config/rs6000/rs6000.c:15992
+#: config/rs6000/rs6000.c:15999 config/rs6000/rs6000.c:16006
+#: config/rs6000/rs6000.c:16011 config/rs6000/rs6000.c:16014
+#: config/rs6000/rs6000.c:16018 config/rs6000/rs6000.c:16024
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "builtin function %qs requires the %qs option"
 msgstr "fungsi bawaan %q+D dideklarasikan sebagai bukan-fungsi"
 
-#: config/rs6000/rs6000.c:15943 config/rs6000/rs6000.c:15952
-#: config/rs6000/rs6000.c:15959 config/rs6000/rs6000.c:15966
+#: config/rs6000/rs6000.c:15987 config/rs6000/rs6000.c:15996
+#: config/rs6000/rs6000.c:16003
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "builtin function %qs requires the %qs and %qs options"
 msgstr "fungsi bawaan %q+D dideklarasikan sebagai bukan-fungsi"
 
-#: config/rs6000/rs6000.c:15972
+#: config/rs6000/rs6000.c:16021
 #, gcc-internal-format
 msgid "builtin function %qs requires ISA 3.0 IEEE 128-bit floating point"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15978
+#: config/rs6000/rs6000.c:16027
 #, gcc-internal-format
 msgid "builtin function %qs requires the %qs (or newer), and %qs or %qs options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15982
+#: config/rs6000/rs6000.c:16031
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %qs not supported for MIPS16"
 msgid "builtin function %qs is not supported with the current options"
 msgstr "fungsi bawaan %qs tidak didukung untuk MIPS16"
 
-#: config/rs6000/rs6000.c:18218
+#: config/rs6000/rs6000.c:18290
 #, gcc-internal-format
 msgid "internal error: builtin function %qs had an unexpected return type %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18235
+#: config/rs6000/rs6000.c:18307
 #, gcc-internal-format
 msgid "internal error: builtin function %qs, argument %d had unexpected argument type %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:29451
+#: config/rs6000/rs6000.c:29528
 #, fuzzy, gcc-internal-format
 #| msgid "Use registers r2 and r5"
 msgid "%qs uses register r29"
 msgstr "Gunakan register r2 dan r5"
 
-#: config/rs6000/rs6000.c:32748
+#: config/rs6000/rs6000.c:32825
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "tidak dapat mengambil alamat dari %<this%>, yang merupakan ekspresi rvalue"
 
-#: config/rs6000/rs6000.c:32842
+#: config/rs6000/rs6000.c:32919
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long%> in AltiVec types is invalid for 64-bit code"
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "penggunaan dari %<long%> dalam tipe AltiVec tidak valid untuk kode 64 bit"
 
-#: config/rs6000/rs6000.c:32850
+#: config/rs6000/rs6000.c:32927
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long long%> in AltiVec types is invalid"
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "penggunaan dari %<long long%> dalam tipe AltiVec tidak valid"
 
-#: config/rs6000/rs6000.c:32853
+#: config/rs6000/rs6000.c:32930
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<double%> in AltiVec types is invalid"
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "penggunaan dari %<double%> dalam tipe AltiVec tidak valid"
 
-#: config/rs6000/rs6000.c:36876
+#: config/rs6000/rs6000.c:36932
 #, fuzzy, gcc-internal-format
 #| msgid "invalid abstract type %qT for %qE"
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "tipe abstrak tidak valid %qT untuk %qE"
 
-#: config/rs6000/rs6000.c:36879
+#: config/rs6000/rs6000.c:36935
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<#pragma%> is not allowed here"
 msgid "%s%qs%s is not allowed"
 msgstr "%H%<#pragma%> tidak diijinkan disini"
 
-#: config/rs6000/rs6000.c:36881
+#: config/rs6000/rs6000.c:36937
 #, fuzzy, gcc-internal-format
 #| msgid "spec '%s' is invalid"
 msgid "%s%qs%s is invalid"
 msgstr "spesifikasi '%s' tidak valid"
 
-#: config/rs6000/rs6000.c:37416
+#: config/rs6000/rs6000.c:37472
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:37575
+#: config/rs6000/rs6000.c:37631
 #, gcc-internal-format
 msgid "target_clones attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
@@ -38414,53 +38458,53 @@
 msgid "subprogram %q+F not marked Inline"
 msgstr ""
 
-#: ada/gcc-interface/trans.c:6404
+#: ada/gcc-interface/trans.c:6401
 #, gcc-internal-format
 msgid "out-of-bounds access may be optimized away"
 msgstr ""
 
-#: ada/gcc-interface/trans.c:6406
+#: ada/gcc-interface/trans.c:6403
 #, gcc-internal-format
 msgid "containing loop"
 msgstr ""
 
-#: ada/gcc-interface/utils.c:3887
+#: ada/gcc-interface/utils.c:3890
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute %qE"
 msgid "invalid element type for attribute %qs"
 msgstr "tipe vektori tidak valid untuk atribut %qE"
 
-#: ada/gcc-interface/utils.c:3911
+#: ada/gcc-interface/utils.c:3914
 #, fuzzy, gcc-internal-format
 #| msgid "number of components of the vector not a power of two"
 msgid "number of components of vector not a power of two"
 msgstr "jumlah dari komponen dari vektor bukan kelipatan dari dua"
 
-#: ada/gcc-interface/utils.c:6037 ada/gcc-interface/utils.c:6215
-#: ada/gcc-interface/utils.c:6322
+#: ada/gcc-interface/utils.c:6043 ada/gcc-interface/utils.c:6220
+#: ada/gcc-interface/utils.c:6327
 #, gcc-internal-format
 msgid "%qs attribute ignored"
 msgstr "%qs atribut diabaikan"
 
-#: ada/gcc-interface/utils.c:6158
+#: ada/gcc-interface/utils.c:6164
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute requires prototypes with named arguments"
 msgid "%qs attribute requires prototypes with named arguments"
 msgstr "%qE atribut membutuhkan prototipe dengan argumen bernama"
 
-#: ada/gcc-interface/utils.c:6167
+#: ada/gcc-interface/utils.c:6173
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to variadic functions"
 msgid "%qs attribute only applies to variadic functions"
 msgstr "%qE atribut hanya berlaku untuk fungsi variadic"
 
-#: ada/gcc-interface/utils.c:6282
+#: ada/gcc-interface/utils.c:6287
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored"
 msgid "%qE attribute has no effect"
 msgstr "%qE atribut diabaikan"
 
-#: ada/gcc-interface/utils.c:6406
+#: ada/gcc-interface/utils.c:6411
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to variables"
 msgid "attribute %qs applies to array types only"
@@ -38477,7 +38521,7 @@
 #. an unprototyped function, it is compile-time undefined;
 #. making it a constraint in that case was rejected in
 #. DR#252.
-#: c/c-convert.c:101 c/c-typeck.c:2175 c/c-typeck.c:6507 c/c-typeck.c:12138
+#: c/c-convert.c:101 c/c-typeck.c:2175 c/c-typeck.c:6512 c/c-typeck.c:12143
 #: cp/typeck.c:2027 cp/typeck.c:7977 cp/typeck.c:8742
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
@@ -38539,7 +38583,7 @@
 msgid "type of array %q+D completed incompatibly with implicit initialization"
 msgstr "tipe dari array %q+D dilengkapi secara tidak kompatibel dengan inisialisasi implisit"
 
-#: c/c-decl.c:1567 c/c-decl.c:6701 c/c-decl.c:7574 c/c-decl.c:8381
+#: c/c-decl.c:1567 c/c-decl.c:6721 c/c-decl.c:7594 c/c-decl.c:8401
 #, fuzzy, gcc-internal-format
 #| msgid "%Joriginal definition appeared here"
 msgid "originally defined here"
@@ -38969,16 +39013,11 @@
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.c:4548 c/c-decl.c:7147
+#: c/c-decl.c:4548 c/c-decl.c:7167
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr "%<[*]%> tidak diijinkan dalam hal lain selain lingkup prototipe fungsi"
 
-#: c/c-decl.c:4635 cp/decl2.c:1520
-#, gcc-internal-format
-msgid "%q+D in declare target directive does not have mappable type"
-msgstr ""
-
 #: c/c-decl.c:4693
 #, gcc-internal-format
 msgid "%q+D is usually a function"
@@ -39004,7 +39043,7 @@
 #. of VLAs themselves count as VLAs, it does not make
 #. sense to permit them to be initialized given that
 #. ordinary VLAs may not be initialized.
-#: c/c-decl.c:4732 c/c-decl.c:4747 c/c-typeck.c:7630
+#: c/c-decl.c:4732 c/c-decl.c:4747 c/c-typeck.c:7635
 #, gcc-internal-format
 msgid "variable-sized object may not be initialized"
 msgstr "objek berukuran-variabel tidak boleh diinisialisasi"
@@ -39067,222 +39106,227 @@
 msgid "uninitialized const %qD is invalid in C++"
 msgstr "tidak terinisialisasi const %qD"
 
-#: c/c-decl.c:5268
+#: c/c-decl.c:5224 cp/decl.c:7318
 #, gcc-internal-format
+msgid "%q+D in declare target directive does not have mappable type"
+msgstr ""
+
+#: c/c-decl.c:5288
+#, gcc-internal-format
 msgid "ISO C forbids forward parameter declarations"
 msgstr "ISO C melarang deklarasi parameter kedepan"
 
-#: c/c-decl.c:5371
+#: c/c-decl.c:5391
 #, gcc-internal-format
 msgid "defining a type in a compound literal is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:5425 c/c-decl.c:5440
+#: c/c-decl.c:5445 c/c-decl.c:5460
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant"
 msgstr "lebar bit-field %qs bukan sebuah konstanta integer"
 
-#: c/c-decl.c:5435
+#: c/c-decl.c:5455
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qs width not an integer constant"
 msgid "bit-field %qs width not an integer constant expression"
 msgstr "lebar bit-field %qs bukan sebuah konstanta integer"
 
-#: c/c-decl.c:5446
+#: c/c-decl.c:5466
 #, gcc-internal-format
 msgid "negative width in bit-field %qs"
 msgstr "lebar negatif dalam bit-field %qs"
 
-#: c/c-decl.c:5451
+#: c/c-decl.c:5471
 #, gcc-internal-format
 msgid "zero width for bit-field %qs"
 msgstr "lebar nol untuk bit-field %qs"
 
-#: c/c-decl.c:5461
+#: c/c-decl.c:5481
 #, gcc-internal-format
 msgid "bit-field %qs has invalid type"
 msgstr "bit-field %qs memiliki tipe tidak valid"
 
-#: c/c-decl.c:5467
+#: c/c-decl.c:5487
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare bit-field %qD with function type"
 msgid "cannot declare bit-field %qs with %<warn_if_not_aligned%> type"
 msgstr "tidak dapat mendeklarasikan bit-field %qD dengan tipe fungsi"
 
-#: c/c-decl.c:5478
+#: c/c-decl.c:5498
 #, gcc-internal-format
 msgid "type of bit-field %qs is a GCC extension"
 msgstr "tipe dari bit-field  %qs adalah sebuah ekstensi GCC"
 
-#: c/c-decl.c:5484
+#: c/c-decl.c:5504
 #, gcc-internal-format
 msgid "width of %qs exceeds its type"
 msgstr "lebar dari %qs melebihi tipenya"
 
-#: c/c-decl.c:5497
+#: c/c-decl.c:5517
 #, gcc-internal-format
 msgid "%qs is narrower than values of its type"
 msgstr "%qs lebih kecil dari nilai dari tipenya"
 
-#: c/c-decl.c:5512
+#: c/c-decl.c:5532
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids array %qs whose size can%'t be evaluated"
 msgid "ISO C90 forbids array %qE whose size can%'t be evaluated"
 msgstr "ISO C90 melarang array %qs yang ukurannya tidak dapat dievaluasi"
 
-#: c/c-decl.c:5515
+#: c/c-decl.c:5535
 #, gcc-internal-format
 msgid "ISO C90 forbids array whose size can%'t be evaluated"
 msgstr "ISO C90 melarang array yang ukurannya tidak dapat dievaluasi"
 
-#: c/c-decl.c:5522
+#: c/c-decl.c:5542
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable length array %qs"
 msgid "ISO C90 forbids variable length array %qE"
 msgstr "ISO C90 melarang array dengan panjang bervariabel %qs"
 
-#: c/c-decl.c:5524
+#: c/c-decl.c:5544
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array"
 msgstr "ISO C90 melarang array dengan panjang bervariabel"
 
-#: c/c-decl.c:5733 c/c-decl.c:6107 c/c-decl.c:6117
+#: c/c-decl.c:5753 c/c-decl.c:6127 c/c-decl.c:6137
 #, fuzzy, gcc-internal-format
 #| msgid "variably modified %qs at file scope"
 msgid "variably modified %qE at file scope"
 msgstr "variabel dimodifikasi %qs di lingkup berkas"
 
-#: c/c-decl.c:5735
+#: c/c-decl.c:5755
 #, fuzzy, gcc-internal-format
 #| msgid "variably modified %qs at file scope"
 msgid "variably modified field at file scope"
 msgstr "variabel dimodifikasi %qs di lingkup berkas"
 
-#: c/c-decl.c:5755
+#: c/c-decl.c:5775
 #, fuzzy, gcc-internal-format
 #| msgid "type defaults to %<int%> in declaration of %qs"
 msgid "type defaults to %<int%> in declaration of %qE"
 msgstr "tipe baku ke %<int%> dalam deklarasi dari %qs"
 
-#: c/c-decl.c:5759
+#: c/c-decl.c:5779
 #, fuzzy, gcc-internal-format
 #| msgid "type defaults to %<int%> in declaration of %qs"
 msgid "type defaults to %<int%> in type name"
 msgstr "tipe baku ke %<int%> dalam deklarasi dari %qs"
 
-#: c/c-decl.c:5791
+#: c/c-decl.c:5811
 #, gcc-internal-format
 msgid "duplicate %<const%>"
 msgstr "duplikasi %<const%>"
 
-#: c/c-decl.c:5793
+#: c/c-decl.c:5813
 #, gcc-internal-format
 msgid "duplicate %<restrict%>"
 msgstr "duplikasi %<restrict%>"
 
-#: c/c-decl.c:5795
+#: c/c-decl.c:5815
 #, gcc-internal-format
 msgid "duplicate %<volatile%>"
 msgstr "duplikasi %<volatile%>"
 
-#: c/c-decl.c:5797
+#: c/c-decl.c:5817
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<restrict%>"
 msgid "duplicate %<_Atomic%>"
 msgstr "duplikasi %<restrict%>"
 
-#: c/c-decl.c:5800
+#: c/c-decl.c:5820
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "conflicting super class name %qs"
 msgid "conflicting named address spaces (%s vs %s)"
 msgstr "konflik nama super class %qs"
 
-#: c/c-decl.c:5823 c/c-parser.c:2821
+#: c/c-decl.c:5843 c/c-parser.c:2821
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified array type"
 msgstr ""
 
-#: c/c-decl.c:5837
+#: c/c-decl.c:5857
 #, gcc-internal-format
 msgid "function definition declared %<auto%>"
 msgstr "definisi fungsi dideklarasikan %<auto%>"
 
-#: c/c-decl.c:5839
+#: c/c-decl.c:5859
 #, gcc-internal-format
 msgid "function definition declared %<register%>"
 msgstr "definisi fungsi dideklarasikan %<register%>"
 
-#: c/c-decl.c:5841
+#: c/c-decl.c:5861
 #, gcc-internal-format
 msgid "function definition declared %<typedef%>"
 msgstr "definisi fungsi dideklarasikan %<typedef%>"
 
-#: c/c-decl.c:5843
+#: c/c-decl.c:5863
 #, fuzzy, gcc-internal-format
 #| msgid "function definition declared %<auto%>"
 msgid "function definition declared %qs"
 msgstr "definisi fungsi dideklarasikan %<auto%>"
 
-#: c/c-decl.c:5861
+#: c/c-decl.c:5881
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for structure field %qs"
 msgid "storage class specified for structure field %qE"
 msgstr "class penyimpanan dispesifikasikan untuk daerah struktur %qs"
 
-#: c/c-decl.c:5864
+#: c/c-decl.c:5884
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for structure field %qs"
 msgid "storage class specified for structure field"
 msgstr "class penyimpanan dispesifikasikan untuk daerah struktur %qs"
 
-#: c/c-decl.c:5868
+#: c/c-decl.c:5888
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "storage class specified for parameter %qE"
 msgstr "class penyimpanan dispesifikasikan untuk parameter %qs"
 
-#: c/c-decl.c:5871
+#: c/c-decl.c:5891
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "storage class specified for unnamed parameter"
 msgstr "class penyimpanan dispesifikasikan untuk parameter %qs"
 
-#: c/c-decl.c:5874 cp/decl.c:10935
+#: c/c-decl.c:5894 cp/decl.c:10959
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "class penyimpanan dispesifikasikan untuk nama tipe"
 
-#: c/c-decl.c:5891
+#: c/c-decl.c:5911
 #, fuzzy, gcc-internal-format
 #| msgid "%qs initialized and declared %<extern%>"
 msgid "%qE initialized and declared %<extern%>"
 msgstr "%qs diinisialisasi dan dideklarasi %<extern%>"
 
-#: c/c-decl.c:5895
+#: c/c-decl.c:5915
 #, fuzzy, gcc-internal-format
 #| msgid "%qs has both %<extern%> and initializer"
 msgid "%qE has both %<extern%> and initializer"
 msgstr "%qs keduanya memiliki %<extern> dan penginisialisasi"
 
-#: c/c-decl.c:5900
+#: c/c-decl.c:5920
 #, fuzzy, gcc-internal-format
 #| msgid "file-scope declaration of %qs specifies %<auto%>"
 msgid "file-scope declaration of %qE specifies %<auto%>"
 msgstr "deklarasi lingkup-berkas dari %qs menspesifikasikan %<auto%>"
 
-#: c/c-decl.c:5904
+#: c/c-decl.c:5924
 #, fuzzy, gcc-internal-format
 #| msgid "file-scope declaration of %qs specifies %<register%>"
 msgid "file-scope declaration of %qE specifies %<register%>"
 msgstr "deklarasi lingkup-berkas dari %qs menspesifikasikan %<register%>"
 
-#: c/c-decl.c:5909
+#: c/c-decl.c:5929
 #, fuzzy, gcc-internal-format
 #| msgid "nested function %qs declared %<extern%>"
 msgid "nested function %qE declared %<extern%>"
 msgstr "fungsi nested %qs dideklarasikan %<extern%>"
 
-#: c/c-decl.c:5912
+#: c/c-decl.c:5932
 #, fuzzy, gcc-internal-format
 #| msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgid "function-scope %qE implicitly auto and declared %qs"
@@ -39291,778 +39335,778 @@
 #. Only the innermost declarator (making a parameter be of
 #. array type which is converted to pointer type)
 #. may have static or type qualifiers.
-#: c/c-decl.c:5959 c/c-decl.c:6328
+#: c/c-decl.c:5979 c/c-decl.c:6348
 #, gcc-internal-format
 msgid "static or type qualifiers in non-parameter array declarator"
 msgstr "statis atau tipe kualifier dalam array pendeklarasi bukan parameter"
 
-#: c/c-decl.c:6007
+#: c/c-decl.c:6027
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of voids"
 msgid "declaration of %qE as array of voids"
 msgstr "deklarasi dari %qs sebagai dari voids"
 
-#: c/c-decl.c:6009
+#: c/c-decl.c:6029
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of voids"
 msgid "declaration of type name as array of voids"
 msgstr "deklarasi dari %qs sebagai dari voids"
 
-#: c/c-decl.c:6016
+#: c/c-decl.c:6036
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of %qE as array of functions"
 msgstr "deklarasi dari %qs sebagai array dari fungsi"
 
-#: c/c-decl.c:6019
+#: c/c-decl.c:6039
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of type name as array of functions"
 msgstr "deklarasi dari %qs sebagai array dari fungsi"
 
-#: c/c-decl.c:6027 c/c-decl.c:8085
+#: c/c-decl.c:6047 c/c-decl.c:8105
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr "penggunaan tidak valid dari struktur dengan anggota array fleksibel"
 
-#: c/c-decl.c:6053
+#: c/c-decl.c:6073
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs has non-integer type"
 msgid "size of array %qE has non-integer type"
 msgstr "ukuran dari array %qs memiliki tipe bukan integer"
 
-#: c/c-decl.c:6057
+#: c/c-decl.c:6077
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs has non-integer type"
 msgid "size of unnamed array has non-integer type"
 msgstr "ukuran dari array %qs memiliki tipe bukan integer"
 
-#: c/c-decl.c:6064
+#: c/c-decl.c:6084
 #, fuzzy, gcc-internal-format
 #| msgid "elements of array %q#D have incomplete type"
 msgid "size of array %qE has incomplete type"
 msgstr "elemen dari array %q#D memiliki tipe tidak lengkap"
 
-#: c/c-decl.c:6067
+#: c/c-decl.c:6087
 #, fuzzy, gcc-internal-format
 #| msgid "name %qT has incomplete type"
 msgid "size of unnamed array has incomplete type"
 msgstr "nama %qT memiliki tipe tidak lengkap"
 
-#: c/c-decl.c:6078
+#: c/c-decl.c:6098
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids zero-size array %qs"
 msgid "ISO C forbids zero-size array %qE"
 msgstr "ISO C melarang array berukuran-nol %qs"
 
-#: c/c-decl.c:6081
+#: c/c-decl.c:6101
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids zero-size array"
 msgid "ISO C forbids zero-size array"
 msgstr "ISO C++ melarang array berukuran-nol"
 
-#: c/c-decl.c:6090
+#: c/c-decl.c:6110
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is negative"
 msgid "size of array %qE is negative"
 msgstr "ukuran dari array %qs adalah negatif"
 
-#: c/c-decl.c:6092
+#: c/c-decl.c:6112
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is negative"
 msgid "size of unnamed array is negative"
 msgstr "ukuran dari array negatif"
 
-#: c/c-decl.c:6216 c/c-decl.c:6871
+#: c/c-decl.c:6236 c/c-decl.c:6891
 #, gcc-internal-format
 msgid "ISO C90 does not support flexible array members"
 msgstr "ISO C90 tidak mendukung keanggotaan array fleksibel"
 
 #. C99 6.7.5.2p4
-#: c/c-decl.c:6238
+#: c/c-decl.c:6258
 #, gcc-internal-format
 msgid "%<[*]%> not in a declaration"
 msgstr "%<[*]%> tidak dalam sebuah deklarasi"
 
-#: c/c-decl.c:6251
+#: c/c-decl.c:6271
 #, fuzzy, gcc-internal-format
 #| msgid "array type has incomplete element type"
 msgid "array type has incomplete element type %qT"
 msgstr "tipe array memiliki tipe elemen tidak lengkap"
 
-#: c/c-decl.c:6257
+#: c/c-decl.c:6277
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgid "declaration of %qE as multidimensional array must have bounds for all dimensions except the first"
 msgstr "deklarasi dari %qD sebagai array multidimensi harus memiliki batasan untuk seluruh dimensi kecuali yang pertama"
 
-#: c/c-decl.c:6261
+#: c/c-decl.c:6281
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgid "declaration of multidimensional array must have bounds for all dimensions except the first"
 msgstr "deklarasi dari %qD sebagai array multidimensi harus memiliki batasan untuk seluruh dimensi kecuali yang pertama"
 
-#: c/c-decl.c:6364
+#: c/c-decl.c:6384
 #, fuzzy, gcc-internal-format
 #| msgid "%qs declared as function returning a function"
 msgid "%qE declared as function returning a function"
 msgstr "%qs dideklarasikan sebagai fungsi yang mengembalikan sebuah fungsi"
 
-#: c/c-decl.c:6367
+#: c/c-decl.c:6387
 #, fuzzy, gcc-internal-format
 #| msgid "%qs declared as function returning a function"
 msgid "type name declared as function returning a function"
 msgstr "%qs dideklarasikan sebagai fungsi yang mengembalikan sebuah fungsi"
 
-#: c/c-decl.c:6374
+#: c/c-decl.c:6394
 #, fuzzy, gcc-internal-format
 #| msgid "%qs declared as function returning an array"
 msgid "%qE declared as function returning an array"
 msgstr "%qs dideklarasikan sebagai fungsi yang mengembalikan sebuah array"
 
-#: c/c-decl.c:6377
+#: c/c-decl.c:6397
 #, fuzzy, gcc-internal-format
 #| msgid "%qs declared as function returning an array"
 msgid "type name declared as function returning an array"
 msgstr "%qs dideklarasikan sebagai fungsi yang mengembalikan sebuah array"
 
-#: c/c-decl.c:6418
+#: c/c-decl.c:6438
 #, gcc-internal-format
 msgid "function definition has qualified void return type"
 msgstr "definisi fungsi memiliki pengkualifikasi tipe kembali void"
 
-#: c/c-decl.c:6421 cp/decl.c:11201
+#: c/c-decl.c:6441 cp/decl.c:11225
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "tipe pengkualifikasi diabaikan di tipe kembali fungsi"
 
-#: c/c-decl.c:6459 c/c-decl.c:6668 c/c-decl.c:6721 c/c-decl.c:6805
-#: c/c-decl.c:6926 c/c-parser.c:2823
+#: c/c-decl.c:6479 c/c-decl.c:6688 c/c-decl.c:6741 c/c-decl.c:6825
+#: c/c-decl.c:6946 c/c-parser.c:2823
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids qualified function types"
 msgid "%<_Atomic%>-qualified function type"
 msgstr "ISO C melarang pengkualifikasi tipe fungsi"
 
-#: c/c-decl.c:6465 c/c-decl.c:6674 c/c-decl.c:6810 c/c-decl.c:6931
+#: c/c-decl.c:6485 c/c-decl.c:6694 c/c-decl.c:6830 c/c-decl.c:6951
 #, gcc-internal-format
 msgid "ISO C forbids qualified function types"
 msgstr "ISO C melarang pengkualifikasi tipe fungsi"
 
-#: c/c-decl.c:6559
+#: c/c-decl.c:6579
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting type qualifiers for %q+D"
 msgid "%qs combined with %<auto%> qualifier for %qE"
 msgstr "tipe konfliks kualifier untuk %q+D"
 
-#: c/c-decl.c:6563
+#: c/c-decl.c:6583
 #, gcc-internal-format
 msgid "%qs combined with %<register%> qualifier for %qE"
 msgstr ""
 
-#: c/c-decl.c:6569
+#: c/c-decl.c:6589
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid type for iteration variable %qE"
 msgid "%qs specified for auto variable %qE"
 msgstr "%Htipe tidak valid untuk iterasi variabel %qE"
 
-#: c/c-decl.c:6585
+#: c/c-decl.c:6605
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "%qs specified for parameter %qE"
 msgstr "class penyimpanan dispesifikasikan untuk parameter %qs"
 
-#: c/c-decl.c:6588
+#: c/c-decl.c:6608
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "%qs specified for unnamed parameter"
 msgstr "class penyimpanan dispesifikasikan untuk parameter %qs"
 
-#: c/c-decl.c:6594
+#: c/c-decl.c:6614
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for structure field %qs"
 msgid "%qs specified for structure field %qE"
 msgstr "class penyimpanan dispesifikasikan untuk daerah struktur %qs"
 
-#: c/c-decl.c:6597
+#: c/c-decl.c:6617
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for structure field %qs"
 msgid "%qs specified for structure field"
 msgstr "class penyimpanan dispesifikasikan untuk daerah struktur %qs"
 
-#: c/c-decl.c:6612
+#: c/c-decl.c:6632
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qs has invalid type"
 msgid "bit-field %qE has atomic type"
 msgstr "bit-field %qs memiliki tipe tidak valid"
 
-#: c/c-decl.c:6614
+#: c/c-decl.c:6634
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qs has invalid type"
 msgid "bit-field has atomic type"
 msgstr "bit-field %qs memiliki tipe tidak valid"
 
-#: c/c-decl.c:6623
+#: c/c-decl.c:6643
 #, fuzzy, gcc-internal-format
 #| msgid "alignment may not be specified for %q+D"
 msgid "alignment specified for typedef %qE"
 msgstr "alignmen mungkin tidak dispesifikasikan untuk %q+D"
 
-#: c/c-decl.c:6625
+#: c/c-decl.c:6645
 #, fuzzy, gcc-internal-format
 #| msgid "alignment may not be specified for %q+D"
 msgid "alignment specified for %<register%> object %qE"
 msgstr "alignmen mungkin tidak dispesifikasikan untuk %q+D"
 
-#: c/c-decl.c:6630
+#: c/c-decl.c:6650
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "alignment specified for parameter %qE"
 msgstr "class penyimpanan dispesifikasikan untuk parameter %qs"
 
-#: c/c-decl.c:6632
+#: c/c-decl.c:6652
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "alignment specified for unnamed parameter"
 msgstr "class penyimpanan dispesifikasikan untuk parameter %qs"
 
-#: c/c-decl.c:6637
+#: c/c-decl.c:6657
 #, fuzzy, gcc-internal-format
 #| msgid "alignment may not be specified for %q+D"
 msgid "alignment specified for bit-field %qE"
 msgstr "alignmen mungkin tidak dispesifikasikan untuk %q+D"
 
-#: c/c-decl.c:6639
+#: c/c-decl.c:6659
 #, fuzzy, gcc-internal-format
 #| msgid "%<__alignof%> applied to a bit-field"
 msgid "alignment specified for unnamed bit-field"
 msgstr "%<__alignof%> diaplikasikan ke sebuah bit-field"
 
-#: c/c-decl.c:6642
+#: c/c-decl.c:6662
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "alignment specified for function %qE"
 msgstr "%qs hanya dapat dispesifikasikan untuk fungsi"
 
-#: c/c-decl.c:6649
+#: c/c-decl.c:6669
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of %qE"
 msgstr ""
 
-#: c/c-decl.c:6652
+#: c/c-decl.c:6672
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of unnamed field"
 msgstr ""
 
-#: c/c-decl.c:6683
+#: c/c-decl.c:6703
 #, gcc-internal-format
 msgid "typedef %q+D declared %<inline%>"
 msgstr "typedef %q+D dideklarasikan %<inline%>"
 
-#: c/c-decl.c:6685
+#: c/c-decl.c:6705
 #, fuzzy, gcc-internal-format
 #| msgid "typedef %q+D declared %<inline%>"
 msgid "typedef %q+D declared %<_Noreturn%>"
 msgstr "typedef %q+D dideklarasikan %<inline%>"
 
-#: c/c-decl.c:6727
+#: c/c-decl.c:6747
 #, gcc-internal-format
 msgid "ISO C forbids const or volatile function types"
 msgstr "ISO C melarang tipe fungsi const atau volatile"
 
 #. C99 6.7.2.1p8
-#: c/c-decl.c:6738
+#: c/c-decl.c:6758
 #, gcc-internal-format
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "sebuah anggota dari sebuah struktur atau union tidak dapat memiliki sebuah tipe variabel termodifikasi"
 
-#: c/c-decl.c:6755 cp/decl.c:9989
+#: c/c-decl.c:6775 cp/decl.c:10010
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "variabel atau field %qE dideklarasikan void"
 
-#: c/c-decl.c:6795
+#: c/c-decl.c:6815
 #, gcc-internal-format
 msgid "attributes in parameter array declarator ignored"
 msgstr "atribut dalam parameter pendeklarasi array diabaikan"
 
-#: c/c-decl.c:6837
+#: c/c-decl.c:6857
 #, gcc-internal-format
 msgid "parameter %q+D declared %<inline%>"
 msgstr "parameter %q+D dideklarasikan %<inline%>"
 
-#: c/c-decl.c:6839
+#: c/c-decl.c:6859
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared %<inline%>"
 msgid "parameter %q+D declared %<_Noreturn%>"
 msgstr "parameter %q+D dideklarasikan %<inline%>"
 
-#: c/c-decl.c:6852
+#: c/c-decl.c:6872
 #, fuzzy, gcc-internal-format
 #| msgid "field %qs declared as a function"
 msgid "field %qE declared as a function"
 msgstr "field %qs dideklarasikan sebagai sebuah fungsi"
 
-#: c/c-decl.c:6859
+#: c/c-decl.c:6879
 #, fuzzy, gcc-internal-format
 #| msgid "field %qs has incomplete type"
 msgid "field %qE has incomplete type"
 msgstr "field %qs memiliki tipe tidak lengkap"
 
-#: c/c-decl.c:6861
+#: c/c-decl.c:6881
 #, fuzzy, gcc-internal-format
 #| msgid "name %qT has incomplete type"
 msgid "unnamed field has incomplete type"
 msgstr "nama %qT memiliki tipe tidak lengkap"
 
-#: c/c-decl.c:6897 c/c-decl.c:6908 c/c-decl.c:6911
+#: c/c-decl.c:6917 c/c-decl.c:6928 c/c-decl.c:6931
 #, fuzzy, gcc-internal-format
 #| msgid "invalid storage class for function %qs"
 msgid "invalid storage class for function %qE"
 msgstr "class penyimpanan tidak valid untuk fungsi %qs"
 
-#: c/c-decl.c:6968
+#: c/c-decl.c:6988
 #, gcc-internal-format
 msgid "cannot inline function %<main%>"
 msgstr "tidak dapat inline fungsi %<main%>"
 
-#: c/c-decl.c:6970
+#: c/c-decl.c:6990
 #, fuzzy, gcc-internal-format
 #| msgid "%qs initialized and declared %<extern%>"
 msgid "%<main%> declared %<_Noreturn%>"
 msgstr "%qs diinisialisasi dan dideklarasi %<extern%>"
 
-#: c/c-decl.c:6981
+#: c/c-decl.c:7001
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<long long%>"
 msgid "ISO C99 does not support %<_Noreturn%>"
 msgstr "ISO C90 tidak mendukung %<long long%>"
 
-#: c/c-decl.c:6984
+#: c/c-decl.c:7004
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<long long%>"
 msgid "ISO C90 does not support %<_Noreturn%>"
 msgstr "ISO C90 tidak mendukung %<long long%>"
 
-#: c/c-decl.c:7013
+#: c/c-decl.c:7033
 #, gcc-internal-format
 msgid "variable previously declared %<static%> redeclared %<extern%>"
 msgstr "variabel sebelumnya dideklarasikan %<static%> diredeklarasi %<extern%>"
 
-#: c/c-decl.c:7023
+#: c/c-decl.c:7043
 #, gcc-internal-format
 msgid "variable %q+D declared %<inline%>"
 msgstr "variabel %q+D dideklarasikan %<inline%>"
 
-#: c/c-decl.c:7025
+#: c/c-decl.c:7045
 #, fuzzy, gcc-internal-format
 #| msgid "variable %q+D declared %<inline%>"
 msgid "variable %q+D declared %<_Noreturn%>"
 msgstr "variabel %q+D dideklarasikan %<inline%>"
 
-#: c/c-decl.c:7060
+#: c/c-decl.c:7080
 #, fuzzy, gcc-internal-format
 #| msgid "jump into scope of identifier with variably modified type"
 msgid "non-nested function with variably modified type"
 msgstr "melompat kedalam lingkup dari pengidentifikasi dengan tipe variabel dapat dimodifikasi"
 
-#: c/c-decl.c:7062
+#: c/c-decl.c:7082
 #, gcc-internal-format
 msgid "object with variably modified type must have no linkage"
 msgstr "objek dengan tipe variabel termodifikasi harus tidak memiliki hubungan"
 
-#: c/c-decl.c:7153 c/c-decl.c:8821
+#: c/c-decl.c:7173 c/c-decl.c:8841
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr "deklarasi fungsi bukan sebuah prototipe"
 
-#: c/c-decl.c:7163
+#: c/c-decl.c:7183
 #, gcc-internal-format
 msgid "parameter names (without types) in function declaration"
 msgstr "nama parameter (tanpa tipe) dalam deklarasi fungsi"
 
-#: c/c-decl.c:7201
+#: c/c-decl.c:7221
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has incomplete type"
 msgstr "parameter %u (%q+D) memiliki tipe tidak lengkap"
 
-#: c/c-decl.c:7205
+#: c/c-decl.c:7225
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%Jparameter %u has incomplete type"
 msgid "parameter %u has incomplete type"
 msgstr "%J parameter %u memiliki tipe tidak lengkap"
 
-#: c/c-decl.c:7216
+#: c/c-decl.c:7236
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has void type"
 msgstr "parameter %u (%q+D) memiliki tipe void"
 
-#: c/c-decl.c:7220
+#: c/c-decl.c:7240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%Jparameter %u has void type"
 msgid "parameter %u has void type"
 msgstr "%J parameter %u memiliki tipe void"
 
-#: c/c-decl.c:7294
+#: c/c-decl.c:7314
 #, gcc-internal-format
 msgid "%<void%> as only parameter may not be qualified"
 msgstr "%<void%> hanya memiliki parameter tidak boleh dikualifikasikan"
 
-#: c/c-decl.c:7298 c/c-decl.c:7334
+#: c/c-decl.c:7318 c/c-decl.c:7354
 #, gcc-internal-format
 msgid "%<void%> must be the only parameter"
 msgstr "%<void%> harus menjadi parameter satu satunya"
 
-#: c/c-decl.c:7328
+#: c/c-decl.c:7348
 #, gcc-internal-format
 msgid "parameter %q+D has just a forward declaration"
 msgstr "parameter %q+D hanya memiliki sebuah deklarasi kedepan"
 
-#: c/c-decl.c:7374
+#: c/c-decl.c:7394
 #, gcc-internal-format
 msgid "%<%s %E%> declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr ""
 
-#: c/c-decl.c:7380
+#: c/c-decl.c:7400
 #, gcc-internal-format, gfc-internal-format
 msgid "anonymous %s declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr ""
 
-#: c/c-decl.c:7482
+#: c/c-decl.c:7502
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "enum type defined here"
 msgstr "%q+#D sebelumnya didefinisikan disini"
 
-#: c/c-decl.c:7488
+#: c/c-decl.c:7508
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "struct defined here"
 msgstr "%q+#D sebelumnya didefinisikan disini"
 
-#: c/c-decl.c:7494
+#: c/c-decl.c:7514
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "union defined here"
 msgstr "%q+#D sebelumnya didefinisikan disini"
 
-#: c/c-decl.c:7570
+#: c/c-decl.c:7590
 #, gcc-internal-format
 msgid "redefinition of %<union %E%>"
 msgstr "redefinisi dari %<union %E%>"
 
-#: c/c-decl.c:7572
+#: c/c-decl.c:7592
 #, gcc-internal-format
 msgid "redefinition of %<struct %E%>"
 msgstr "redefinisi dari %<struct %E%>"
 
-#: c/c-decl.c:7581
+#: c/c-decl.c:7601
 #, gcc-internal-format
 msgid "nested redefinition of %<union %E%>"
 msgstr "nested redefinisi dari %<union %E%>"
 
-#: c/c-decl.c:7583
+#: c/c-decl.c:7603
 #, gcc-internal-format
 msgid "nested redefinition of %<struct %E%>"
 msgstr "nested redefinisi dari %<struct %E%>"
 
-#: c/c-decl.c:7613 c/c-decl.c:8400
+#: c/c-decl.c:7633 c/c-decl.c:8420
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:7680 cp/decl.c:4802
+#: c/c-decl.c:7700 cp/decl.c:4802
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "redeklarasi tidak mendeklarasikan apapun"
 
-#: c/c-decl.c:7685
+#: c/c-decl.c:7705
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C doesn%'t support unnamed structs/unions"
 msgid "ISO C99 doesn%'t support unnamed structs/unions"
 msgstr "ISO C tidak mendukung structs/unions tidak bernama"
 
-#: c/c-decl.c:7688
+#: c/c-decl.c:7708
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C doesn%'t support unnamed structs/unions"
 msgid "ISO C90 doesn%'t support unnamed structs/unions"
 msgstr "ISO C tidak mendukung structs/unions tidak bernama"
 
-#: c/c-decl.c:7781 c/c-decl.c:7799 c/c-decl.c:7860
+#: c/c-decl.c:7801 c/c-decl.c:7819 c/c-decl.c:7880
 #, gcc-internal-format
 msgid "duplicate member %q+D"
 msgstr "duplikasi anggota %q+D"
 
-#: c/c-decl.c:7886
+#: c/c-decl.c:7906
 #, gcc-internal-format
 msgid "empty struct has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.c:7889
+#: c/c-decl.c:7909
 #, gcc-internal-format
 msgid "empty union has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.c:7994
+#: c/c-decl.c:8014
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr "union tidak memiliki anggota bernama"
 
-#: c/c-decl.c:7996
+#: c/c-decl.c:8016
 #, gcc-internal-format
 msgid "union has no members"
 msgstr "union tidak memiliki anggota"
 
-#: c/c-decl.c:8001
+#: c/c-decl.c:8021
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr "struct tidak memiliki anggota bernama"
 
-#: c/c-decl.c:8003
+#: c/c-decl.c:8023
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr "struct tidak memiliki anggota"
 
-#: c/c-decl.c:8064 cp/decl.c:12069
+#: c/c-decl.c:8084 cp/decl.c:12093
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in union"
 msgid "flexible array member in union"
 msgstr "%J anggota array fleksibel dalam union"
 
-#: c/c-decl.c:8070
+#: c/c-decl.c:8090
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member not at end of struct"
 msgid "flexible array member not at end of struct"
 msgstr "%J anggota array fleksibel tidak diakhir dari struct"
 
-#: c/c-decl.c:8076
+#: c/c-decl.c:8096
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in union"
 msgid "flexible array member in a struct with no named members"
 msgstr "%J anggota array fleksibel dalam union"
 
-#: c/c-decl.c:8107
+#: c/c-decl.c:8127
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "type %qT is too large"
 msgstr "ukuran dari array %qs adalah terlalu besar"
 
-#: c/c-decl.c:8230
+#: c/c-decl.c:8250
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr "union tidak dapat dibuat transparan"
 
-#: c/c-decl.c:8372
+#: c/c-decl.c:8392
 #, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr "nested redefinisi dari %<enum %E%>"
 
 #. This enum is a named one that has been declared already.
-#: c/c-decl.c:8379
+#: c/c-decl.c:8399
 #, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr "redeklarasi dari %<enum %E%>"
 
-#: c/c-decl.c:8458 cp/decl.c:14423
+#: c/c-decl.c:8478 cp/decl.c:14447
 #, gcc-internal-format
 msgid "specified mode too small for enumeral values"
 msgstr "mode yang dispesifikasikan terlalu kecil untuk nilai enumerasi"
 
-#: c/c-decl.c:8473
+#: c/c-decl.c:8493
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr "nilai enumerasi melebihi jangkauan dari integer terbesar"
 
-#: c/c-decl.c:8587 c/c-decl.c:8603
+#: c/c-decl.c:8607 c/c-decl.c:8623
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr "nilai pengenumerasi untuk %qE bukan sebuah konstanta integer"
 
-#: c/c-decl.c:8598
+#: c/c-decl.c:8618
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qE is not an integer constant"
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr "nilai pengenumerasi untuk %qE bukan sebuah konstanta integer"
 
-#: c/c-decl.c:8622
+#: c/c-decl.c:8642
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr "overflow dalam nilai enumerasi"
 
-#: c/c-decl.c:8630
+#: c/c-decl.c:8650
 #, gcc-internal-format
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "ISO C melarang nilai pengenumerasi ke jangkauan dari %<int%>"
 
-#: c/c-decl.c:8715 cp/decl.c:5104 cp/decl.c:14955
+#: c/c-decl.c:8735 cp/decl.c:5104 cp/decl.c:14979
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D given attribute noinline"
 msgid "inline function %qD given attribute noinline"
 msgstr "fungsi inline %q+D memberikan atribut noinline"
 
-#: c/c-decl.c:8733
+#: c/c-decl.c:8753
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr "tipe kembali adalah sebuah tipe tidak lengkap"
 
-#: c/c-decl.c:8744
+#: c/c-decl.c:8764
 #, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr "tipe baku kembali ke %<int%>"
 
-#: c/c-decl.c:8771
+#: c/c-decl.c:8791
 #, fuzzy, gcc-internal-format
 #| msgid "Warn about global functions without prototypes"
 msgid "%q+D defined as variadic function without prototype"
 msgstr "Peringatkan mengenai fungsi global tanpa prototipe"
 
-#: c/c-decl.c:8830
+#: c/c-decl.c:8850
 #, fuzzy, gcc-internal-format
 #| msgid "no previous prototype for %q+D"
 msgid "no previous prototype for %qD"
 msgstr "tidak ada prototipe sebelumnya untuk %q+D"
 
-#: c/c-decl.c:8839
+#: c/c-decl.c:8859
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was used with no prototype before its definition"
 msgid "%qD was used with no prototype before its definition"
 msgstr "%q+D telah digunakan dengan tidak ada prototipe sebelum definisinya"
 
-#: c/c-decl.c:8847 cp/decl.c:15090
+#: c/c-decl.c:8867 cp/decl.c:15114
 #, fuzzy, gcc-internal-format
 #| msgid "no previous declaration for %q+D"
 msgid "no previous declaration for %qD"
 msgstr "tidak deklarasi sebelumnya untuk %q+D"
 
-#: c/c-decl.c:8857
+#: c/c-decl.c:8877
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was used with no declaration before its definition"
 msgid "%qD was used with no declaration before its definition"
 msgstr "%q+D telah digunakan tanpa deklarasi sebelum definisinya"
 
-#: c/c-decl.c:8876
+#: c/c-decl.c:8896
 #, fuzzy, gcc-internal-format
 #| msgid "return type of %q+D is not %<int%>"
 msgid "return type of %qD is not %<int%>"
 msgstr "tipe kembali dari %q+D bukan %<int%>"
 
-#: c/c-decl.c:8878
+#: c/c-decl.c:8898
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr ""
 
-#: c/c-decl.c:8885
+#: c/c-decl.c:8905
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is normally a non-static function"
 msgid "%qD is normally a non-static function"
 msgstr "%q+D secara normal sebuah fungsi bukan-statis"
 
-#: c/c-decl.c:8922
+#: c/c-decl.c:8942
 #, fuzzy, gcc-internal-format
 #| msgid "%Jold-style parameter declarations in prototyped function definition"
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr "%J deklarasi parameter gaya lama dalam definisi fungsi prototipe"
 
-#: c/c-decl.c:8937
+#: c/c-decl.c:8957
 #, fuzzy, gcc-internal-format
 #| msgid "%Jtraditional C rejects ISO C style function definitions"
 msgid "traditional C rejects ISO C style function definitions"
 msgstr "%J tradisional C menolak gaya ISO C definisi fungsi"
 
-#: c/c-decl.c:8953
+#: c/c-decl.c:8973
 #, fuzzy, gcc-internal-format
 #| msgid "%Jparameter name omitted"
 msgid "parameter name omitted"
 msgstr "%J nama parameter diabaikan"
 
-#: c/c-decl.c:8990
+#: c/c-decl.c:9010
 #, fuzzy, gcc-internal-format
 #| msgid "%Jold-style function definition"
 msgid "old-style function definition"
 msgstr "%J definisi fungsi gaya-lama"
 
-#: c/c-decl.c:8999
+#: c/c-decl.c:9019
 #, fuzzy, gcc-internal-format
 #| msgid "%Jparameter name missing from parameter list"
 msgid "parameter name missing from parameter list"
 msgstr "%J nama parameter hilang dari daftar parameter"
 
-#: c/c-decl.c:9015
+#: c/c-decl.c:9035
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a non-parameter"
 msgid "%qD declared as a non-parameter"
 msgstr "%q+D dideklarasikan sebagai sebuah bukan-parameter"
 
-#: c/c-decl.c:9023
+#: c/c-decl.c:9043
 #, fuzzy, gcc-internal-format
 #| msgid "multiple parameters named %q+D"
 msgid "multiple parameters named %qD"
 msgstr "multiple parameter bernama %q+D"
 
-#: c/c-decl.c:9032
+#: c/c-decl.c:9052
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared with void type"
 msgid "parameter %qD declared with void type"
 msgstr "parameter %q+D dideklarasikan dengan tipe void"
 
-#: c/c-decl.c:9061 c/c-decl.c:9066
+#: c/c-decl.c:9081 c/c-decl.c:9086
 #, fuzzy, gcc-internal-format
 #| msgid "type of %q+D defaults to %<int%>"
 msgid "type of %qD defaults to %<int%>"
 msgstr "tipe dari %q+D baku ke %<int%>"
 
-#: c/c-decl.c:9086
+#: c/c-decl.c:9106
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D has incomplete type"
 msgid "parameter %qD has incomplete type"
 msgstr "parameter %q+D memiliki tipe tidak lengkap"
 
-#: c/c-decl.c:9093
+#: c/c-decl.c:9113
 #, fuzzy, gcc-internal-format
 #| msgid "declaration for parameter %q+D but no such parameter"
 msgid "declaration for parameter %qD but no such parameter"
 msgstr "deklarasi untuk parameter %q+D tetapi tidak ada parameter seperti itu"
 
-#: c/c-decl.c:9146
+#: c/c-decl.c:9166
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr "jumlah dari argumen tidak cocok dengan prototipe bawaan"
 
-#: c/c-decl.c:9157
+#: c/c-decl.c:9177
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr "jumlah dari argumen tidak cocok prototipe"
 
-#: c/c-decl.c:9160 c/c-decl.c:9207 c/c-decl.c:9221
+#: c/c-decl.c:9180 c/c-decl.c:9227 c/c-decl.c:9241
 #, gcc-internal-format
 msgid "prototype declaration"
 msgstr "deklarasi prototipe"
 
-#: c/c-decl.c:9199
+#: c/c-decl.c:9219
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr "argumen dipromosikan %qD tidak cocok dengan prototipe bawaan"
 
-#: c/c-decl.c:9204
+#: c/c-decl.c:9224
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr "argumen dipromosikan %qD tidak cocok dengan prototipe"
 
-#: c/c-decl.c:9214
+#: c/c-decl.c:9234
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr "argumen %qD tidak cocok dengan prototipe bawaan"
 
-#: c/c-decl.c:9219
+#: c/c-decl.c:9239
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr "argumen %qD tidak cocok dengan prototipe"
 
-#: c/c-decl.c:9470 cp/decl.c:15873
+#: c/c-decl.c:9490 cp/decl.c:15897
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "tidak ada pernyataaan kembali dalam fungsi yang mengembalikan bukan void"
 
-#: c/c-decl.c:9490 cp/decl.c:15905
+#: c/c-decl.c:9510 cp/decl.c:15929
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD is initialized"
 msgid "parameter %qD set but not used"
@@ -40071,266 +40115,266 @@
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:9586
+#: c/c-decl.c:9606
 #, fuzzy, gcc-internal-format
 #| msgid "%<for%> loop initial declarations are only allowed in C99 mode"
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "%<for%> deklarasi inisial loop hanya diijinkan dalam mode C99"
 
-#: c/c-decl.c:9591
+#: c/c-decl.c:9611
 #, fuzzy, gcc-internal-format
 #| msgid "use option -std=c99 or -std=gnu99 to compile your code"
 msgid "use option -std=c99, -std=gnu99, -std=c11 or -std=gnu11 to compile your code"
 msgstr "gunakan pilihan -std=c99 atau -std=gnu99 untuk mengkompile kode anda"
 
-#: c/c-decl.c:9626
+#: c/c-decl.c:9646
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of static variable %q+D in %<for%> loop initial declaration"
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "deklarasi dari variabel statis %q+D dalam %<for%> inisial deklarasi loop"
 
-#: c/c-decl.c:9630
+#: c/c-decl.c:9650
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %<extern%> variable %q+D in %<for%> loop initial declaration"
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "deklarasi dari variabel %<extern%> %q+D dalam %<for> inisial deklarasi loop"
 
-#: c/c-decl.c:9637
+#: c/c-decl.c:9657
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "%<struct %E%> dideklarasikan dalam %<for%> inisial deklarasi loop"
 
-#: c/c-decl.c:9642
+#: c/c-decl.c:9662
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "%<union %E%> dideklarasikan dalam %<for%> inisial deklarasi loop"
 
-#: c/c-decl.c:9646
+#: c/c-decl.c:9666
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "%<enum %E%> dideklarasikan dalam %<for%> inisial deklarasi loop"
 
-#: c/c-decl.c:9650
+#: c/c-decl.c:9670
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of non-variable %q+D in %<for%> loop initial declaration"
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "deklarasi dari bukan-variabel %q+D dalam %<for%> inisial deklarasi loop"
 
-#: c/c-decl.c:9900
+#: c/c-decl.c:9920
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr ""
 
-#: c/c-decl.c:9958 c/c-decl.c:9965
+#: c/c-decl.c:9978 c/c-decl.c:9985
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "duplicate %qE declaration specifier"
 msgstr "diduga penspesifikasi deklarasi"
 
-#: c/c-decl.c:9992 c/c-decl.c:10376 c/c-decl.c:10766
+#: c/c-decl.c:10012 c/c-decl.c:10396 c/c-decl.c:10786
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr "dua atau lebih tipe data dalam penspesifikasi deklarasi"
 
-#: c/c-decl.c:10004 cp/parser.c:28261
+#: c/c-decl.c:10024 cp/parser.c:28258
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> terlalu panjang untuk GCC"
 
-#: c/c-decl.c:10017
+#: c/c-decl.c:10037
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C90 tidak mendukung %<long long%>"
 
-#: c/c-decl.c:10246 c/c-parser.c:8848
+#: c/c-decl.c:10266 c/c-parser.c:8848
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C90 tidak mendukung tipe kompleks"
 
-#: c/c-decl.c:10292
+#: c/c-decl.c:10312
 #, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr "ISO C tidak mendukung tipe yang bersaturasi"
 
-#: c/c-decl.c:10363 c/c-decl.c:10923
+#: c/c-decl.c:10383 c/c-decl.c:10943
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "duplikasi %qE"
 
-#: c/c-decl.c:10419
+#: c/c-decl.c:10439
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support fixed-point types"
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C tidak mendukung tipe titik tetap"
 
-#: c/c-decl.c:10441
+#: c/c-decl.c:10461
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "%<__int%d%> is not supported on this target"
 msgstr "batas stact tidak didukung dalam target ini"
 
-#: c/c-decl.c:10484
+#: c/c-decl.c:10504
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support complex types"
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C90 tidak mendukung tipe kompleks"
 
-#: c/c-decl.c:10603
+#: c/c-decl.c:10623
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support saturating types"
 msgid "ISO C does not support the %<_Float%d%s%> type"
 msgstr "ISO C tidak mendukung tipe yang bersaturasi"
 
-#: c/c-decl.c:10653
+#: c/c-decl.c:10673
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "batas stact tidak didukung dalam target ini"
 
-#: c/c-decl.c:10724
+#: c/c-decl.c:10744
 #, gcc-internal-format
 msgid "ISO C does not support decimal floating point"
 msgstr "ISO C tidak mendukung titik pecahan desimal"
 
-#: c/c-decl.c:10747 c/c-decl.c:11013 c/c-parser.c:7842
+#: c/c-decl.c:10767 c/c-decl.c:11033 c/c-parser.c:7842
 #, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "tipe titik tetap tidak didukung untuk target ini"
 
-#: c/c-decl.c:10749
+#: c/c-decl.c:10769
 #, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C tidak mendukung tipe titik tetap"
 
-#: c/c-decl.c:10784
+#: c/c-decl.c:10804
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr ""
 
-#: c/c-decl.c:10797
+#: c/c-decl.c:10817
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr "%qE gagal untuk menjadi sebuah typedef atau tipe bawaan"
 
-#: c/c-decl.c:10845
+#: c/c-decl.c:10865
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qE tidak berada di awal dari deklarasi"
 
-#: c/c-decl.c:10866
+#: c/c-decl.c:10886
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<auto%>"
 msgid "%qE used with %<auto%>"
 msgstr "%<__thread%> digunakan dengan %<auto%>"
 
-#: c/c-decl.c:10868
+#: c/c-decl.c:10888
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<register%>"
 msgid "%qE used with %<register%>"
 msgstr "%<__thread%> digunakan dengan %<register%>"
 
-#: c/c-decl.c:10870
+#: c/c-decl.c:10890
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<typedef%>"
 msgid "%qE used with %<typedef%>"
 msgstr "%<__thread%> digunakan dengan %<typedef%>"
 
-#: c/c-decl.c:10884 c/c-parser.c:7360
+#: c/c-decl.c:10904 c/c-parser.c:7360
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "ISO C99 does not support %qE"
 msgstr "%s tidak mendukung %s"
 
-#: c/c-decl.c:10887 c/c-parser.c:7363
+#: c/c-decl.c:10907 c/c-parser.c:7363
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support %<long long%>"
 msgid "ISO C90 does not support %qE"
 msgstr "ISO C90 tidak mendukung %<long long%>"
 
-#: c/c-decl.c:10899
+#: c/c-decl.c:10919
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<__thread%> sebelum %<extern%>"
 
-#: c/c-decl.c:10908
+#: c/c-decl.c:10928
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<__thread%> sebelum %<static%>"
 
-#: c/c-decl.c:10921
+#: c/c-decl.c:10941
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr ""
 
-#: c/c-decl.c:10929
+#: c/c-decl.c:10949
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr "multiple class penyimpanan dalam deklarasi penspesifikasi"
 
-#: c/c-decl.c:10937
+#: c/c-decl.c:10957
 #, fuzzy, gcc-internal-format
 #| msgid "%qs must be used with %qs"
 msgid "%qs used with %qE"
 msgstr "%qs harus digunakan dengan %qs"
 
-#: c/c-decl.c:11010
+#: c/c-decl.c:11030
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "%<_Sat%> digunakan tanpa %<_Fract%> atau %<_Accum%>"
 
-#: c/c-decl.c:11025
+#: c/c-decl.c:11045
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C tidak mendukung plain %<complex%> yang berarti %<double complex%>"
 
-#: c/c-decl.c:11076 c/c-decl.c:11092 c/c-decl.c:11118
+#: c/c-decl.c:11096 c/c-decl.c:11112 c/c-decl.c:11138
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C tidak mendukung tipe integer kompleks"
 
-#: c/c-decl.c:11514 cp/semantics.c:5348
+#: c/c-decl.c:11534 cp/semantics.c:5351
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:11518 cp/semantics.c:5352
+#: c/c-decl.c:11538 cp/semantics.c:5355
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.c:385 c/c-typeck.c:11426 cp/typeck.c:4680
+#: c/c-fold.c:385 c/c-typeck.c:11431 cp/typeck.c:4680
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count is negative"
 msgid "left shift of negative value"
 msgstr "jumlah geser kiri negatif"
 
-#: c/c-fold.c:395 c/c-typeck.c:11435 cp/typeck.c:4688
+#: c/c-fold.c:395 c/c-typeck.c:11440 cp/typeck.c:4688
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "jumlah geser kiri negatif"
 
-#: c/c-fold.c:396 c/c-typeck.c:11365 cp/typeck.c:4633
+#: c/c-fold.c:396 c/c-typeck.c:11370 cp/typeck.c:4633
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "jumlah geser kanan negatif"
 
-#: c/c-fold.c:404 c/c-typeck.c:11454 cp/typeck.c:4696
+#: c/c-fold.c:404 c/c-typeck.c:11459 cp/typeck.c:4696
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "jumlah geser kiri >= lebar dari tipe"
 
-#: c/c-fold.c:405 c/c-typeck.c:11389 cp/typeck.c:4641
+#: c/c-fold.c:405 c/c-typeck.c:11394 cp/typeck.c:4641
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "jumlah geser kanan >= lebar dari tipe"
 
-#: c/c-fold.c:412 c/c-typeck.c:11446
+#: c/c-fold.c:412 c/c-typeck.c:11451
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count >= width of type"
 msgid "left shift count >= width of vector element"
 msgstr "jumlah geser kiri >= lebar dari tipe"
 
-#: c/c-fold.c:413 c/c-typeck.c:11376
+#: c/c-fold.c:413 c/c-typeck.c:11381
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count >= width of type"
 msgid "right shift count >= width of vector element"
@@ -40352,7 +40396,7 @@
 msgid "to match this %qs"
 msgstr ""
 
-#: c/c-parser.c:1216 cp/parser.c:28484
+#: c/c-parser.c:1216 cp/parser.c:28481
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of module"
 msgid "expected end of line"
@@ -40396,7 +40440,7 @@
 msgstr "nama register: %s tidak dikenal"
 
 #: c/c-parser.c:1848 c/c-parser.c:11129 c/c-parser.c:16147 c/c-parser.c:16585
-#: c/c-parser.c:17061 cp/parser.c:36007 cp/parser.c:38993
+#: c/c-parser.c:17061 cp/parser.c:36004 cp/parser.c:38990
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "diduga penspesifikasi deklarasi"
@@ -40413,7 +40457,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "diduga pengidentifikasi atau %<(%>"
 
-#: c/c-parser.c:1906 cp/parser.c:30161 cp/parser.c:30235
+#: c/c-parser.c:1906 cp/parser.c:30158 cp/parser.c:30232
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored for %qE"
 msgid "prefix attributes are ignored for methods"
@@ -40474,7 +40518,7 @@
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr ""
 
-#: c/c-parser.c:2220 cp/parser.c:13002 cp/parser.c:13159
+#: c/c-parser.c:2220 cp/parser.c:12999 cp/parser.c:13156
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "diduga %<,%> atau %<,%>"
@@ -40504,7 +40548,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C90 tidak mendukung %<long long%>"
 
-#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38634
+#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38631
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr "diduga string literal"
@@ -40575,13 +40619,13 @@
 #: c/c-parser.c:10745 c/c-parser.c:10798 c/c-parser.c:10814 c/c-parser.c:10860
 #: c/c-parser.c:11496 c/c-parser.c:11537 c/c-parser.c:13445 c/c-parser.c:13681
 #: c/c-parser.c:15544 c/c-parser.c:18218 c/gimple-parser.c:1058
-#: c/gimple-parser.c:1096 cp/parser.c:28487 cp/parser.c:31013
-#: cp/parser.c:31043 cp/parser.c:31113 cp/parser.c:33230 cp/parser.c:38350
+#: c/gimple-parser.c:1096 cp/parser.c:28484 cp/parser.c:31010
+#: cp/parser.c:31040 cp/parser.c:31110 cp/parser.c:33227 cp/parser.c:38347
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "diduga pengidentifikasi"
 
-#: c/c-parser.c:2995 cp/parser.c:18384
+#: c/c-parser.c:2995 cp/parser.c:18381
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "koma di akhir dari daftar pengenumerasi"
@@ -40752,12 +40796,12 @@
 msgid "expected statement"
 msgstr "diduga pernyataan"
 
-#: c/c-parser.c:5639 cp/parser.c:12516
+#: c/c-parser.c:5639 cp/parser.c:12513
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "disarankan kurung diantara tubuh kosong dalam sebuah pernyataan %<if%>"
 
-#: c/c-parser.c:5681 cp/parser.c:12519
+#: c/c-parser.c:5681 cp/parser.c:12516
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "disarankan kurung diantara tubuh kosong dalam sebuah pernyataan %<else%>"
@@ -41136,7 +41180,7 @@
 msgid "%<__builtin_complex%> operands of different types"
 msgstr "%<__builtin_longjmp%> argumen kedua harus berupa 1"
 
-#: c/c-parser.c:8891 cp/parser.c:6918
+#: c/c-parser.c:8891 cp/parser.c:6921
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgid "wrong number of arguments to %<__builtin_shuffle%>"
@@ -41200,83 +41244,83 @@
 msgid "no type or storage class may be specified here,"
 msgstr "kelas penyimpanan dispesifikasikan untuk %qs"
 
-#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31073
+#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31070
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr ""
 
-#: c/c-parser.c:10682 cp/parser.c:31033
+#: c/c-parser.c:10682 cp/parser.c:31030
 #, fuzzy, gcc-internal-format
 #| msgid "missing %<(%> after %<#pragma pack%> - ignored"
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "hilang %<(%> setelah %<#pragma pack%> - diabaikan"
 
-#: c/c-parser.c:10685 cp/parser.c:31036
+#: c/c-parser.c:10685 cp/parser.c:31033
 #, fuzzy, gcc-internal-format
 #| msgid "missing %<(%> after %<#pragma pack%> - ignored"
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "hilang %<(%> setelah %<#pragma pack%> - diabaikan"
 
-#: c/c-parser.c:10699 cp/parser.c:31051
+#: c/c-parser.c:10699 cp/parser.c:31048
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsection attribute cannot be specified for local variables"
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "%J atribut daerah tidak dapat dispesifikasikan untuk variabel lokal"
 
-#: c/c-parser.c:10704 cp/parser.c:31057
+#: c/c-parser.c:10704 cp/parser.c:31054
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.c:10711 cp/parser.c:31065
+#: c/c-parser.c:10711 cp/parser.c:31062
 #, fuzzy, gcc-internal-format
 #| msgid "%Jaddress area attribute cannot be specified for functions"
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "%J alamat daerah atribut tidak dapat dispesifikasikan untuk fungsi"
 
-#: c/c-parser.c:10905 cp/parser.c:38674
+#: c/c-parser.c:10905 cp/parser.c:38671
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
 #: c/c-parser.c:10949 c/c-parser.c:16582 c/c-parser.c:16840 c/c-parser.c:16899
-#: c/c-parser.c:16983 cp/parser.c:36004 cp/parser.c:36298 cp/parser.c:36386
-#: cp/parser.c:36457 cp/parser.c:38721 cp/parser.c:38736 cp/parser.c:38752
-#: cp/parser.c:38768 cp/parser.c:38784 cp/parser.c:38811 cp/parser.c:38824
-#: cp/parser.c:38847 cp/parser.c:38860
+#: c/c-parser.c:16983 cp/parser.c:36001 cp/parser.c:36295 cp/parser.c:36383
+#: cp/parser.c:36454 cp/parser.c:38718 cp/parser.c:38733 cp/parser.c:38749
+#: cp/parser.c:38765 cp/parser.c:38781 cp/parser.c:38808 cp/parser.c:38821
+#: cp/parser.c:38844 cp/parser.c:38857
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp flush%> may only be used in compound statements"
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<#pragma omp flush%> hanya mungkin digunakan dalam pernyataan compound"
 
-#: c/c-parser.c:10972 cp/parser.c:38837
+#: c/c-parser.c:10972 cp/parser.c:38834
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<#pragma GCC pch_preprocess%> harus menjadi pertama"
 
-#: c/c-parser.c:11050 cp/parser.c:38918
+#: c/c-parser.c:11050 cp/parser.c:38915
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<#pragma omp section%> hanya bisa digunakan dalam %<#pragma omp section%> konstruk"
 
-#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38947 cp/parser.c:38980
+#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38944 cp/parser.c:38977
 #, fuzzy, gcc-internal-format
 #| msgid "for statement expected"
 msgid "for, while or do statement expected"
 msgstr "diduga pernyataan for"
 
-#: c/c-parser.c:11111 cp/parser.c:38711
+#: c/c-parser.c:11111 cp/parser.c:38708
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%> harus menjadi pertama"
 
-#: c/c-parser.c:11421 cp/parser.c:31457
+#: c/c-parser.c:11421 cp/parser.c:31454
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "terlalu banyak %qs clauses"
 
-#: c/c-parser.c:11443 cp/parser.c:31994
+#: c/c-parser.c:11443 cp/parser.c:31991
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "expected integer expression before ')'"
@@ -41293,59 +41337,59 @@
 msgid "%qD is not a variable"
 msgstr "%qD bukan sebuah variabel"
 
-#: c/c-parser.c:11746 cp/semantics.c:6808
+#: c/c-parser.c:11746 cp/semantics.c:6811
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qD is not a pointer variable"
 msgstr "%qD bukan sebuah variabel"
 
-#: c/c-parser.c:11788 cp/parser.c:32073
+#: c/c-parser.c:11788 cp/parser.c:32070
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr "argumen collapes membutuhkan konstanta positif ekspresi integer"
 
-#: c/c-parser.c:11865 cp/parser.c:32137
+#: c/c-parser.c:11865 cp/parser.c:32134
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<none%> or %<present%>"
 msgstr "diduga %<none%> atau %<shared%>"
 
-#: c/c-parser.c:11867 cp/parser.c:32139
+#: c/c-parser.c:11867 cp/parser.c:32136
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "diduga %<none%> atau %<shared%>"
 
-#: c/c-parser.c:11968 cp/parser.c:32242
+#: c/c-parser.c:11968 cp/parser.c:32239
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "diduga %<,%>, %<,%> atau %<}%>"
 
-#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32260
-#: cp/parser.c:36290 cp/parser.c:36378
+#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32257
+#: cp/parser.c:36287 cp/parser.c:36375
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<data%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.c:12035 cp/parser.c:32313
+#: c/c-parser.c:12035 cp/parser.c:32310
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:12042 cp/parser.c:32320
+#: c/c-parser.c:12042 cp/parser.c:32317
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<if%> clauses"
 msgstr "terlalu banyak %qs clauses"
 
-#: c/c-parser.c:12044 cp/parser.c:32322
+#: c/c-parser.c:12044 cp/parser.c:32319
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<if%> clauses without modifier"
 msgstr "terlalu banyak %qs clauses"
 
-#: c/c-parser.c:12050 cp/parser.c:32328
+#: c/c-parser.c:12050 cp/parser.c:32325
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -41368,95 +41412,95 @@
 msgid "%<num_tasks%> value must be positive"
 msgstr "%<num_threads%> nilai harus positif"
 
-#: c/c-parser.c:12229 cp/semantics.c:6992
+#: c/c-parser.c:12229 cp/semantics.c:6995
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<grainsize%> value must be positive"
 msgstr "%<num_threads%> nilai harus positif"
 
-#: c/c-parser.c:12276 cp/semantics.c:7021
+#: c/c-parser.c:12276 cp/semantics.c:7024
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<priority%> value must be non-negative"
 msgstr "%<num_threads%> nilai harus positif"
 
-#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32545 cp/parser.c:32552
+#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32542 cp/parser.c:32549
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<tofrom%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32561 cp/parser.c:32568
+#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32558 cp/parser.c:32565
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<scalar%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.c:12425 cp/semantics.c:6299
+#: c/c-parser.c:12425 cp/semantics.c:6302
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%qs expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6331
+#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6334
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%qs value must be positive"
 msgstr "%<num_threads%> nilai harus positif"
 
-#: c/c-parser.c:12499 cp/parser.c:31853
+#: c/c-parser.c:12499 cp/parser.c:31850
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<static%> arguments"
 msgstr "terlalu banyak %qs clauses"
 
-#: c/c-parser.c:12533 cp/parser.c:31886
+#: c/c-parser.c:12533 cp/parser.c:31883
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected element"
 msgid "unexpected argument"
 msgstr "Elemen tidak diduga"
 
-#: c/c-parser.c:12699 cp/semantics.c:7120
+#: c/c-parser.c:12699 cp/semantics.c:7123
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute argument not an integer constant"
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "argumen atribut %qs bukan sebuah konstanta integer"
 
-#: c/c-parser.c:12765 cp/parser.c:32626
+#: c/c-parser.c:12765 cp/parser.c:32623
 #, fuzzy, gcc-internal-format
 #| msgid "collapse argument needs positive constant integer expression"
 msgid "ordered argument needs positive constant integer expression"
 msgstr "argumen collapes membutuhkan konstanta positif ekspresi integer"
 
-#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37643
+#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37640
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, or %<||%>"
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "diduga %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, atau %<||%>"
 
-#: c/c-parser.c:12967 cp/parser.c:32840
+#: c/c-parser.c:12967 cp/parser.c:32837
 #, fuzzy, gcc-internal-format
 #| msgid "both %<long%> and %<void%> in declaration specifiers"
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "baik %<long%> dan %<void%> dalam penspesifikasi deklarasi"
 
-#: c/c-parser.c:13021 cp/parser.c:32856
+#: c/c-parser.c:13021 cp/parser.c:32853
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "jadwal %<runtime%> tidak mengambil sebuah parameter %<chunk_size%>"
 
-#: c/c-parser.c:13025 cp/parser.c:32859
+#: c/c-parser.c:13025 cp/parser.c:32856
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "penjadwalan %<auto%> tidak mengambil sebuah parameter %<chunk_size%>"
 
-#: c/c-parser.c:13037 cp/semantics.c:6389
+#: c/c-parser.c:13037 cp/semantics.c:6392
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "chunk size value must be positive"
 msgstr "%<num_threads%> nilai harus positif"
 
-#: c/c-parser.c:13060 cp/parser.c:32879
+#: c/c-parser.c:13060 cp/parser.c:32876
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "jenis penjadwalan tidak valid"
@@ -41467,13 +41511,13 @@
 msgid "%<num_teams%> value must be positive"
 msgstr "%<num_threads%> nilai harus positif"
 
-#: c/c-parser.c:13226 cp/semantics.c:6479
+#: c/c-parser.c:13226 cp/semantics.c:6482
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<thread_limit%> value must be positive"
 msgstr "%<num_threads%> nilai harus positif"
 
-#: c/c-parser.c:13271 cp/semantics.c:6589
+#: c/c-parser.c:13271 cp/semantics.c:6592
 #, fuzzy, gcc-internal-format
 #| msgid "%Hcollapse argument needs positive constant integer expression"
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
@@ -41497,19 +41541,19 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr "%Hkolaps argumen membutuhkan konstanta positif integer ekspresi"
 
-#: c/c-parser.c:13584 cp/parser.c:33374 cp/parser.c:33599
+#: c/c-parser.c:13584 cp/parser.c:33371 cp/parser.c:33596
 #, fuzzy, gcc-internal-format
 #| msgid "invalid schedule kind"
 msgid "invalid depend kind"
 msgstr "jenis penjadwalan tidak valid"
 
-#: c/c-parser.c:13669 cp/parser.c:33447
+#: c/c-parser.c:13669 cp/parser.c:33444
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mask"
 msgid "invalid map kind"
 msgstr "topeng tidak valid"
 
-#: c/c-parser.c:13767 cp/parser.c:33546
+#: c/c-parser.c:13767 cp/parser.c:33543
 #, fuzzy, gcc-internal-format
 #| msgid "invalid schedule kind"
 msgid "invalid dist_schedule kind"
@@ -41521,71 +41565,71 @@
 msgid "invalid proc_bind kind"
 msgstr "jenis penjadwalan tidak valid"
 
-#: c/c-parser.c:14059 cp/parser.c:33825
+#: c/c-parser.c:14059 cp/parser.c:33822
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected %<#pragma acc%> clause"
 msgstr "diduga clause %<#pragma omp%>"
 
-#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33836 cp/parser.c:34143
+#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33833 cp/parser.c:34140
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs tidak valid untuk %qs"
 
-#: c/c-parser.c:14214 cp/parser.c:34010
+#: c/c-parser.c:14214 cp/parser.c:34007
 #, fuzzy, gcc-internal-format
 #| msgid "%qs must be used with %qs"
 msgid "%qs must be the first clause of %qs"
 msgstr "%qs harus digunakan dengan %qs"
 
-#: c/c-parser.c:14334 cp/parser.c:34132
+#: c/c-parser.c:14334 cp/parser.c:34129
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "diduga clause %<#pragma omp%>"
 
-#: c/c-parser.c:14472 cp/parser.c:36803
+#: c/c-parser.c:14472 cp/parser.c:36800
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14482 cp/parser.c:36813
+#: c/c-parser.c:14482 cp/parser.c:36810
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14502 cp/parser.c:36833
+#: c/c-parser.c:14502 cp/parser.c:36830
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr ""
 
-#: c/c-parser.c:14513 cp/parser.c:36844
+#: c/c-parser.c:14513 cp/parser.c:36841
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr ""
 
-#: c/c-parser.c:14520 cp/parser.c:36851
+#: c/c-parser.c:14520 cp/parser.c:36848
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %<extern%> variable %q+D in %<for%> loop initial declaration"
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "deklarasi dari variabel %<extern%> %q+D dalam %<for> inisial deklarasi loop"
 
-#: c/c-parser.c:14528 cp/parser.c:36859
+#: c/c-parser.c:14528 cp/parser.c:36856
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14540 cp/parser.c:36871
+#: c/c-parser.c:14540 cp/parser.c:36868
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14632 cp/parser.c:36957
+#: c/c-parser.c:14632 cp/parser.c:36954
 #, fuzzy, gcc-internal-format
 #| msgid "expected a string after %<#pragma message%>"
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "diduga sebuah string setelah %<#pragma message%>"
 
-#: c/c-parser.c:14648 cp/parser.c:36974
+#: c/c-parser.c:14648 cp/parser.c:36971
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr ""
@@ -41602,7 +41646,7 @@
 msgid "expected function name"
 msgstr "diduga nama class"
 
-#: c/c-parser.c:14893 cp/parser.c:38064
+#: c/c-parser.c:14893 cp/parser.c:38061
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is not a function,"
 msgid "%qD does not refer to a function"
@@ -41613,44 +41657,44 @@
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14953 cp/parser.c:38118 cp/parser.c:38160
+#: c/c-parser.c:14953 cp/parser.c:38115 cp/parser.c:38157
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14970 cp/parser.c:38174
+#: c/c-parser.c:14970 cp/parser.c:38171
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> already applied to %qD"
 msgstr ""
 
-#: c/c-parser.c:14979 cp/parser.c:38183
+#: c/c-parser.c:14979 cp/parser.c:38180
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr ""
 
-#: c/c-parser.c:14980 cp/parser.c:38184
+#: c/c-parser.c:14980 cp/parser.c:38181
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma align%> must appear before the declaration of %D, ignoring"
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<#pragma align%> harus muncul sebelum deklarasi dari %D, abaikan"
 
-#: c/c-parser.c:15023 cp/parser.c:37152
+#: c/c-parser.c:15023 cp/parser.c:37149
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
 
-#: c/c-parser.c:15435 cp/parser.c:34511 cp/parser.c:34537
+#: c/c-parser.c:15435 cp/parser.c:34508 cp/parser.c:34534
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operator for %<#pragma omp atomic%>"
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "operator tidak valid untuk %<#pragma omp atomic%>"
 
-#: c/c-parser.c:15439 cp/parser.c:34568 cp/parser.c:34584
+#: c/c-parser.c:15439 cp/parser.c:34565 cp/parser.c:34581
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "operator tidak valid untuk %<#pragma omp atomic%>"
 
-#: c/c-parser.c:15488 cp/semantics.c:8401 cp/semantics.c:8411
+#: c/c-parser.c:15488 cp/semantics.c:8404 cp/semantics.c:8414
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
@@ -41660,22 +41704,22 @@
 msgid "expected %<(%> or end of line"
 msgstr "diduga %<(%> atau akhir dari baris"
 
-#: c/c-parser.c:15619 cp/parser.c:35103
+#: c/c-parser.c:15619 cp/parser.c:35100
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:15630 cp/parser.c:35114
+#: c/c-parser.c:15630 cp/parser.c:35111
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:15648 cp/parser.c:35141
+#: c/c-parser.c:15648 cp/parser.c:35138
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "diduga pernyataan for"
 
-#: c/c-parser.c:15718 cp/semantics.c:8066 cp/semantics.c:8153
+#: c/c-parser.c:15718 cp/semantics.c:8069 cp/semantics.c:8156
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "diduga iterasi deklarasi atau inisialisasi"
@@ -41685,76 +41729,76 @@
 msgid "not enough perfectly nested loops"
 msgstr "tidak cukup secara sempurna nested loops"
 
-#: c/c-parser.c:15862 cp/parser.c:35364
+#: c/c-parser.c:15862 cp/parser.c:35361
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr "collapsed loops tidak secara sempurna nested"
 
-#: c/c-parser.c:15909 cp/parser.c:35184 cp/parser.c:35226 cp/pt.c:16385
+#: c/c-parser.c:15909 cp/parser.c:35181 cp/parser.c:35223 cp/pt.c:16407
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "iterasi variabel %qD seharusnya bukan first private"
 
-#: c/c-parser.c:16000 cp/parser.c:35437
+#: c/c-parser.c:16000 cp/parser.c:35434
 #, fuzzy, gcc-internal-format
 #| msgid "%<void%> as only parameter may not be qualified"
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "%<void%> hanya memiliki parameter tidak boleh dikualifikasikan"
 
-#: c/c-parser.c:16166 cp/parser.c:35600
+#: c/c-parser.c:16166 cp/parser.c:35597
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr "%<#pragma omp barrier%> hanya mungkin digunakan dalam pernyataan compound"
 
-#: c/c-parser.c:16374 cp/parser.c:35799
+#: c/c-parser.c:16374 cp/parser.c:35796
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<for%> after %qs"
 msgstr "diduga %<,%> atau %<,%>"
 
-#: c/c-parser.c:16573 cp/parser.c:35995
+#: c/c-parser.c:16573 cp/parser.c:35992
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<point%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.c:16793 cp/parser.c:36232
+#: c/c-parser.c:16793 cp/parser.c:36229
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16806 cp/parser.c:36245
+#: c/c-parser.c:16806 cp/parser.c:36242
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16853 cp/parser.c:36470
+#: c/c-parser.c:16853 cp/parser.c:36467
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:16925 cp/parser.c:36325
+#: c/c-parser.c:16925 cp/parser.c:36322
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16937 cp/parser.c:36337
+#: c/c-parser.c:16937 cp/parser.c:36334
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17011 cp/parser.c:36414
+#: c/c-parser.c:17011 cp/parser.c:36411
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17024 cp/parser.c:36427
+#: c/c-parser.c:17024 cp/parser.c:36424
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17238 cp/parser.c:36680
+#: c/c-parser.c:17238 cp/parser.c:36677
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -41775,34 +41819,34 @@
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17395 cp/parser.c:37273
+#: c/c-parser.c:17395 cp/parser.c:37270
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17474 cp/parser.c:37343
+#: c/c-parser.c:17474 cp/parser.c:37340
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> with clauses in between %<#pragma omp declare target%> without clauses and %<#pragma omp end declare target%>"
 msgstr ""
 
-#: c/c-parser.c:17493 cp/parser.c:37362
+#: c/c-parser.c:17493 cp/parser.c:37359
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17534 cp/parser.c:37409
+#: c/c-parser.c:17534 cp/parser.c:37406
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<target%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.c:17541 cp/parser.c:37416
+#: c/c-parser.c:17541 cp/parser.c:37413
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<declare%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.c:17547 cp/parser.c:37423
+#: c/c-parser.c:17547 cp/parser.c:37420
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC pop_options%> without a corresponding %<#pragma GCC push_options%>"
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
@@ -41861,48 +41905,48 @@
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:17947 cp/parser.c:37868
+#: c/c-parser.c:17947 cp/parser.c:37865
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp section%> or %<}%>"
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr "diduga %<#pragma omp section%> atau %<}%>"
 
-#: c/c-parser.c:18162 cp/semantics.c:7531
+#: c/c-parser.c:18162 cp/semantics.c:7534
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE dideklarasikan %<threadprivate%> setelah penggunaan pertama"
 
-#: c/c-parser.c:18164 cp/semantics.c:7533
+#: c/c-parser.c:18164 cp/semantics.c:7536
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "variabel otomatis %qE tidak dapat berupa %<threadprivate%>"
 
-#: c/c-parser.c:18168 cp/semantics.c:7535
+#: c/c-parser.c:18168 cp/semantics.c:7538
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%<threadprivate%> %qE memiliki tipe tidak lengkap"
 
-#: c/c-parser.c:18368 cp/parser.c:38565
+#: c/c-parser.c:18368 cp/parser.c:38562
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:18374 cp/parser.c:38571
+#: c/c-parser.c:18374 cp/parser.c:38568
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
 
-#: c/c-parser.c:18383 cp/parser.c:38580
+#: c/c-parser.c:18383 cp/parser.c:38577
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.c:18385 cp/parser.c:38583
+#: c/c-parser.c:18385 cp/parser.c:38580
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.c:18391 cp/parser.c:38589
+#: c/c-parser.c:18391 cp/parser.c:38586
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
@@ -41919,7 +41963,7 @@
 msgid "%qD has an incomplete type %qT"
 msgstr "%qD memiliki tipe tidak lengkap"
 
-#: c/c-typeck.c:237 c/c-typeck.c:9994 c/c-typeck.c:10036 cp/call.c:4147
+#: c/c-typeck.c:237 c/c-typeck.c:9999 c/c-typeck.c:10041 cp/call.c:4147
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "penggunaan tidak valid dari ekspresi void"
@@ -41998,13 +42042,13 @@
 msgid "converting an array compound literal to a pointer is ill-formed in C++"
 msgstr ""
 
-#: c/c-typeck.c:2417 c/c-typeck.c:8641
+#: c/c-typeck.c:2417 c/c-typeck.c:8646
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%qT has no member named %qE; did you mean %qE?"
 msgstr "%qT tidak memiliki anggota bernama %qE"
 
-#: c/c-typeck.c:2421 c/c-typeck.c:8645
+#: c/c-typeck.c:2421 c/c-typeck.c:8650
 #, gcc-internal-format
 msgid "%qT has no member named %qE"
 msgstr "%qT tidak memiliki anggota bernama %qE"
@@ -42213,504 +42257,504 @@
 msgid "pointer to a function used in subtraction"
 msgstr "penunjuk ke sebuah fungsi digunakan dalam pengurangan"
 
-#: c/c-typeck.c:3847
+#: c/c-typeck.c:3852
 #, gcc-internal-format
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "aritmetik di penunjuk ke sebuah tipe tidak lengkap"
 
-#: c/c-typeck.c:3852 cp/typeck.c:5562
+#: c/c-typeck.c:3857 cp/typeck.c:5562
 #, fuzzy, gcc-internal-format
 #| msgid "arithmetic on pointer to an incomplete type"
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr "aritmetik di penunjuk ke sebuah tipe tidak lengkap"
 
-#: c/c-typeck.c:4283
+#: c/c-typeck.c:4288
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %qT from boolean expression"
 msgid "%<~%> on a boolean expression"
 msgstr "konversi ke %qT dari ekspresi boolean"
 
-#: c/c-typeck.c:4287
+#: c/c-typeck.c:4292
 #, gcc-internal-format
 msgid "did you mean to use logical not?"
 msgstr ""
 
-#: c/c-typeck.c:4296
+#: c/c-typeck.c:4301
 #, gcc-internal-format
 msgid "ISO C does not support %<~%> for complex conjugation"
 msgstr "ISO C tidak mendukung %<~%> untuk konjugasi kompleks"
 
-#: c/c-typeck.c:4335
+#: c/c-typeck.c:4340
 #, gcc-internal-format
 msgid "wrong type argument to unary exclamation mark"
 msgstr "tipe argumen salah ke unary exclamation mark"
 
-#: c/c-typeck.c:4393
+#: c/c-typeck.c:4398
 #, gcc-internal-format
 msgid "increment of enumeration value is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:4396
+#: c/c-typeck.c:4401
 #, gcc-internal-format
 msgid "decrement of enumeration value is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:4403
+#: c/c-typeck.c:4408
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %qT from boolean expression"
 msgid "increment of a boolean expression"
 msgstr "konversi ke %qT dari ekspresi boolean"
 
-#: c/c-typeck.c:4406
+#: c/c-typeck.c:4411
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %qT from boolean expression"
 msgid "decrement of a boolean expression"
 msgstr "konversi ke %qT dari ekspresi boolean"
 
-#: c/c-typeck.c:4422
+#: c/c-typeck.c:4427
 #, gcc-internal-format
 msgid "ISO C does not support %<++%> and %<--%> on complex types"
 msgstr "ISO C tidak mendukung %<++%> dan %<--%> di tipe kompleks"
 
-#: c/c-typeck.c:4447 c/c-typeck.c:4481
+#: c/c-typeck.c:4452 c/c-typeck.c:4486
 #, gcc-internal-format
 msgid "wrong type argument to increment"
 msgstr "tipe argumen salah ke peningkatan"
 
-#: c/c-typeck.c:4449 c/c-typeck.c:4484
+#: c/c-typeck.c:4454 c/c-typeck.c:4489
 #, gcc-internal-format
 msgid "wrong type argument to decrement"
 msgstr "tipe argumen salah ke pengurangan"
 
-#: c/c-typeck.c:4469
+#: c/c-typeck.c:4474
 #, fuzzy, gcc-internal-format
 #| msgid "cannot increment a pointer to incomplete type %qT"
 msgid "increment of pointer to an incomplete type %qT"
 msgstr "tidak dapat meningkatkan sebuah penunjuk ke tipe tidak lengkap %qT"
 
-#: c/c-typeck.c:4473
+#: c/c-typeck.c:4478
 #, fuzzy, gcc-internal-format
 #| msgid "cannot decrement a pointer to incomplete type %qT"
 msgid "decrement of pointer to an incomplete type %qT"
 msgstr "tidak dapat mengurangi penunjuk ke tipe tidak lengkap %qT"
 
-#: c/c-typeck.c:4577
+#: c/c-typeck.c:4582
 #, fuzzy, gcc-internal-format
 #| msgid "taking address of temporary"
 msgid "taking address of expression of type %<void%>"
 msgstr "memakai alamat dari sementara"
 
-#: c/c-typeck.c:4636
+#: c/c-typeck.c:4641
 #, gcc-internal-format
 msgid "cannot take address of bit-field %qD"
 msgstr "tidak dapat mengambil alamat dari bit-field %qD"
 
-#: c/c-typeck.c:4649
+#: c/c-typeck.c:4654
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgid "cannot take address of scalar with reverse storage order"
 msgstr "tidak dapat mengambil alamat dari %<this%>, yang merupakan ekspresi rvalue"
 
-#: c/c-typeck.c:4657
+#: c/c-typeck.c:4662
 #, fuzzy, gcc-internal-format
 #| msgid "address of register variable %qD requested"
 msgid "address of array with reverse scalar storage order requested"
 msgstr "alamat dari variabel register %qD diminta"
 
-#: c/c-typeck.c:4838
+#: c/c-typeck.c:4843
 #, gcc-internal-format
 msgid "global register variable %qD used in nested function"
 msgstr "variabel global register %qD digunakan dalam fungsi nested"
 
-#: c/c-typeck.c:4841
+#: c/c-typeck.c:4846
 #, gcc-internal-format
 msgid "register variable %qD used in nested function"
 msgstr "variabel register %qD digunakan dalam fungsi nested"
 
-#: c/c-typeck.c:4846
+#: c/c-typeck.c:4851
 #, gcc-internal-format
 msgid "address of global register variable %qD requested"
 msgstr "alamat dari variabel global register %qD diminta"
 
-#: c/c-typeck.c:4848
+#: c/c-typeck.c:4853
 #, gcc-internal-format
 msgid "address of register variable %qD requested"
 msgstr "alamat dari variabel register %qD diminta"
 
-#: c/c-typeck.c:4951
+#: c/c-typeck.c:4956
 #, gcc-internal-format
 msgid "non-lvalue array in conditional expression"
 msgstr "array bukan lvalue dalam ekspresi kondisional"
 
-#: c/c-typeck.c:5033
+#: c/c-typeck.c:5038
 #, fuzzy, gcc-internal-format
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "implicit conversion from %qT to %qT to match other result of conditional"
 msgstr "meminta untuk konversi implisit dari %qT ke %qT tidak diijinkan dalam C++"
 
-#: c/c-typeck.c:5092 c/c-typeck.c:5098
+#: c/c-typeck.c:5097 c/c-typeck.c:5103
 #, gcc-internal-format
 msgid "operand of ?: changes signedness from %qT to %qT due to unsignedness of other operand"
 msgstr ""
 
-#: c/c-typeck.c:5115
+#: c/c-typeck.c:5120
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr with only one void side"
 msgstr "ISO C melarang kondisional ekspresi dengan hanya satu sisi void"
 
-#: c/c-typeck.c:5132
+#: c/c-typeck.c:5137
 #, fuzzy, gcc-internal-format
 #| msgid "pointer type mismatch in conditional expression"
 msgid "pointers to disjoint address spaces used in conditional expression"
 msgstr "tipe penunjuk tidak cocok dalam ekspresi kondisional"
 
-#: c/c-typeck.c:5143 c/c-typeck.c:5160
+#: c/c-typeck.c:5148 c/c-typeck.c:5165
 #, fuzzy, gcc-internal-format
 #| msgid "pointer type mismatch in conditional expression"
 msgid "pointer to array loses qualifier in conditional expression"
 msgstr "tipe penunjuk tidak cocok dalam ekspresi kondisional"
 
-#: c/c-typeck.c:5148 c/c-typeck.c:5165
+#: c/c-typeck.c:5153 c/c-typeck.c:5170
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr between %<void *%> and function pointer"
 msgstr "ISO C melarang kondisional ekpsresi diantara %<void *%> dan penunjuk fungsi"
 
-#: c/c-typeck.c:5178
+#: c/c-typeck.c:5183
 #, gcc-internal-format
 msgid "pointer type mismatch in conditional expression"
 msgstr "tipe penunjuk tidak cocok dalam ekspresi kondisional"
 
-#: c/c-typeck.c:5187 c/c-typeck.c:5198
+#: c/c-typeck.c:5192 c/c-typeck.c:5203
 #, gcc-internal-format
 msgid "pointer/integer type mismatch in conditional expression"
 msgstr "tipe penunjuk/integer tidak cocok dalam ekspresi kondisional"
 
-#: c/c-typeck.c:5336
+#: c/c-typeck.c:5341
 #, gcc-internal-format
 msgid "left-hand operand of comma expression has no effect"
 msgstr "operan tangan-kiri dari ekspresi koma tidak memiliki efek"
 
-#: c/c-typeck.c:5354 c/c-typeck.c:10636
+#: c/c-typeck.c:5359 c/c-typeck.c:10641
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "right-hand operand of comma expression has no effect"
 msgstr "operan tangan-kiri dari ekspresi koma tidak memiliki efek"
 
-#: c/c-typeck.c:5423
+#: c/c-typeck.c:5428
 #, fuzzy
 #| msgid "cast adds new qualifiers to function type"
 msgid "cast adds %q#v qualifier to function type"
 msgstr "cast menambahkan kualifier baru ke tipe fungsi"
 
-#: c/c-typeck.c:5429
+#: c/c-typeck.c:5434
 #, fuzzy
 #| msgid "cast discards qualifiers from pointer target type"
 msgid "cast discards %qv qualifier from pointer target type"
 msgstr "cast mengabaikan kualifier dari tipe target penunjuk"
 
-#: c/c-typeck.c:5464
+#: c/c-typeck.c:5469
 #, gcc-internal-format
 msgid "to be safe all intermediate pointers in cast from %qT to %qT must be %<const%> qualified"
 msgstr ""
 
-#: c/c-typeck.c:5554
+#: c/c-typeck.c:5559
 #, gcc-internal-format
 msgid "cast specifies array type"
 msgstr "cast menspesifikasikan tipe array"
 
-#: c/c-typeck.c:5560
+#: c/c-typeck.c:5565
 #, gcc-internal-format
 msgid "cast specifies function type"
 msgstr "cast menspesifikasikan tipe fungsi"
 
-#: c/c-typeck.c:5575
+#: c/c-typeck.c:5580
 #, gcc-internal-format
 msgid "ISO C forbids casting nonscalar to the same type"
 msgstr "ISO C melarang casting bukan skalar ke tipe yang sama"
 
-#: c/c-typeck.c:5595
+#: c/c-typeck.c:5600
 #, gcc-internal-format
 msgid "ISO C forbids casts to union type"
 msgstr "ISO melarang cast ke tipe union"
 
-#: c/c-typeck.c:5605
+#: c/c-typeck.c:5610
 #, gcc-internal-format
 msgid "cast to union type from type not present in union"
 msgstr "cast ke tipe union dari tipe yang tidak ada dalam union"
 
-#: c/c-typeck.c:5640
+#: c/c-typeck.c:5645
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint generic address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5645
+#: c/c-typeck.c:5650
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to generic address space pointer from disjoint %s address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5650
+#: c/c-typeck.c:5655
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint %s address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5670
+#: c/c-typeck.c:5675
 #, gcc-internal-format
 msgid "cast increases required alignment of target type"
 msgstr "cast meningkatkan alignmen yang dibutuhkan dari tipe target"
 
-#: c/c-typeck.c:5681
+#: c/c-typeck.c:5686
 #, gcc-internal-format
 msgid "cast from pointer to integer of different size"
 msgstr "cast dari penunjuk ke integer dari ukuran berbeda"
 
-#: c/c-typeck.c:5686
+#: c/c-typeck.c:5691
 #, gcc-internal-format
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "cast dari panggilan fungsi dari tipe %qT ke tipe yang tidak cocok %qT"
 
-#: c/c-typeck.c:5695 cp/typeck.c:7811
+#: c/c-typeck.c:5700 cp/typeck.c:7811
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "cast ke penunjuk dari integer dari ukuran yang berbeda"
 
-#: c/c-typeck.c:5709
+#: c/c-typeck.c:5714
 #, gcc-internal-format
 msgid "ISO C forbids conversion of function pointer to object pointer type"
 msgstr "ISO C melarang konversi dari fungsi penunjuk ke tipe objek penunjuk"
 
-#: c/c-typeck.c:5718
+#: c/c-typeck.c:5723
 #, gcc-internal-format
 msgid "ISO C forbids conversion of object pointer to function pointer type"
 msgstr "ISO C melarang konversi dari objek penunjuk ke tipe fungsi penunjuk"
 
-#: c/c-typeck.c:5728
+#: c/c-typeck.c:5733
 #, fuzzy, gcc-internal-format
 #| msgid "can't convert from incomplete type %qT to %qT"
 msgid "cast between incompatible function types from %qT to %qT"
 msgstr "tidak dapat mengubah dari tipe tidak lengkap %qT ke %qT"
 
-#: c/c-typeck.c:5815
+#: c/c-typeck.c:5820
 #, gcc-internal-format
 msgid "defining a type in a cast is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:5856
+#: c/c-typeck.c:5861
 #, fuzzy, gcc-internal-format
 #| msgid "assignment suppression"
 msgid "assignment to expression with array type"
 msgstr "penekanan penempatan"
 
-#: c/c-typeck.c:5982
+#: c/c-typeck.c:5987
 #, gcc-internal-format
 msgid "enum conversion in assignment is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:6180 c/c-typeck.c:6202 c/c-typeck.c:6226
+#: c/c-typeck.c:6185 c/c-typeck.c:6207 c/c-typeck.c:6231
 #, gcc-internal-format
 msgid "(near initialization for %qs)"
 msgstr "(dekat inisialisasi untuk %qs)"
 
-#: c/c-typeck.c:6241
+#: c/c-typeck.c:6246
 #, gcc-internal-format
 msgid "array initialized from parenthesized string constant"
 msgstr "array terinisialisasi dari konstanta string bertanda-petik"
 
-#: c/c-typeck.c:6284 c/c-typeck.c:6476 c/c-typeck.c:6908
+#: c/c-typeck.c:6289 c/c-typeck.c:6481 c/c-typeck.c:6913
 #, gcc-internal-format
 msgid "expected %qT but argument is of type %qT"
 msgstr "diduga %qT tetapi argumen memiliki tipe %qT"
 
-#: c/c-typeck.c:6471
+#: c/c-typeck.c:6476
 #, fuzzy, gcc-internal-format
 #| msgid "pointer targets in passing argument %d of %qE differ in signedness"
 msgid "enum conversion when passing argument %d of %qE is invalid in C++"
 msgstr "target penunjuk dalam melewatkan argumen %d dari %qE berbeda dalam signedness"
 
-#: c/c-typeck.c:6480
+#: c/c-typeck.c:6485
 #, fuzzy, gcc-internal-format
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "enum conversion from %qT to %qT in assignment is invalid in C++"
 msgstr "meminta untuk konversi implisit dari %qT ke %qT tidak diijinkan dalam C++"
 
-#: c/c-typeck.c:6484
+#: c/c-typeck.c:6489
 #, fuzzy, gcc-internal-format
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "enum conversion from %qT to %qT in initialization is invalid in C++"
 msgstr "meminta untuk konversi implisit dari %qT ke %qT tidak diijinkan dalam C++"
 
-#: c/c-typeck.c:6489
+#: c/c-typeck.c:6494
 #, fuzzy, gcc-internal-format
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "enum conversion from %qT to %qT in return is invalid in C++"
 msgstr "meminta untuk konversi implisit dari %qT ke %qT tidak diijinkan dalam C++"
 
-#: c/c-typeck.c:6523
+#: c/c-typeck.c:6528
 #, gcc-internal-format
 msgid "cannot pass rvalue to reference parameter"
 msgstr "tidak dapat melewatkan rvalue ke parameter referensi"
 
-#: c/c-typeck.c:6656 c/c-typeck.c:6942
+#: c/c-typeck.c:6661 c/c-typeck.c:6947
 #, fuzzy
 #| msgid "passing argument %d of %qE makes qualified function pointer from unqualified"
 msgid "passing argument %d of %qE makes %q#v qualified function pointer from unqualified"
 msgstr "melewatkan argumen %d dari %qE membuat fungsi penunjuk terkualifikasi dari tidak terkualifikasi"
 
-#: c/c-typeck.c:6659 c/c-typeck.c:6945
+#: c/c-typeck.c:6664 c/c-typeck.c:6950
 #, fuzzy
 #| msgid "assignment makes qualified function pointer from unqualified"
 msgid "assignment makes %q#v qualified function pointer from unqualified"
 msgstr "penempatan membuat fungsi penunjuk terkualifikasi dari tidak terkualifikasi"
 
-#: c/c-typeck.c:6662 c/c-typeck.c:6947
+#: c/c-typeck.c:6667 c/c-typeck.c:6952
 #, fuzzy
 #| msgid "initialization makes qualified function pointer from unqualified"
 msgid "initialization makes %q#v qualified function pointer from unqualified"
 msgstr "inisialisasi membuat fungsi penunjuk terkualifikasi dari tidak terkualifikasi"
 
-#: c/c-typeck.c:6665 c/c-typeck.c:6949
+#: c/c-typeck.c:6670 c/c-typeck.c:6954
 #, fuzzy
 #| msgid "return makes qualified function pointer from unqualified"
 msgid "return makes %q#v qualified function pointer from unqualified"
 msgstr "return membuat fungsi penunjuk terkualifikasi dari tidak terkualifikasi"
 
-#: c/c-typeck.c:6673 c/c-typeck.c:6840 c/c-typeck.c:6883
+#: c/c-typeck.c:6678 c/c-typeck.c:6845 c/c-typeck.c:6888
 #, fuzzy
 #| msgid "passing argument %d of %qE discards qualifiers from pointer target type"
 msgid "passing argument %d of %qE discards %qv qualifier from pointer target type"
 msgstr "melewatkan argumen %d dari %qE mengabaikan pengkualifikasi dari tipe target penunjuk"
 
-#: c/c-typeck.c:6675 c/c-typeck.c:6842 c/c-typeck.c:6885
+#: c/c-typeck.c:6680 c/c-typeck.c:6847 c/c-typeck.c:6890
 #, fuzzy
 #| msgid "assignment discards qualifiers from pointer target type"
 msgid "assignment discards %qv qualifier from pointer target type"
 msgstr "penempatan mengabaikan pengkualifikasi dari tipe target penunjuk"
 
-#: c/c-typeck.c:6677 c/c-typeck.c:6844 c/c-typeck.c:6887
+#: c/c-typeck.c:6682 c/c-typeck.c:6849 c/c-typeck.c:6892
 #, fuzzy
 #| msgid "initialization discards qualifiers from pointer target type"
 msgid "initialization discards %qv qualifier from pointer target type"
 msgstr "inisialisasi mengabaikan pengkualifikasi dari tipe target penunjuk"
 
-#: c/c-typeck.c:6679 c/c-typeck.c:6846 c/c-typeck.c:6889
+#: c/c-typeck.c:6684 c/c-typeck.c:6851 c/c-typeck.c:6894
 #, fuzzy
 #| msgid "return discards qualifiers from pointer target type"
 msgid "return discards %qv qualifier from pointer target type"
 msgstr "return mengabaikan pengkualifikasi dari tipe target penunjuk"
 
-#: c/c-typeck.c:6688
+#: c/c-typeck.c:6693
 #, gcc-internal-format
 msgid "ISO C prohibits argument conversion to union type"
 msgstr "ISO C melarang konversi argumen ke tipe union"
 
-#: c/c-typeck.c:6750
+#: c/c-typeck.c:6755
 #, gcc-internal-format
 msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgstr "meminta untuk konversi implisit dari %qT ke %qT tidak diijinkan dalam C++"
 
-#: c/c-typeck.c:6762
+#: c/c-typeck.c:6767
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE from incompatible pointer type"
 msgid "passing argument %d of %qE from pointer to non-enclosed address space"
 msgstr "melewatkan argumen %d dari %qE dari tipe penunjuk yang tidak kompatibel"
 
-#: c/c-typeck.c:6766
+#: c/c-typeck.c:6771
 #, fuzzy, gcc-internal-format
 #| msgid "cast from pointer to integer of different size"
 msgid "assignment from pointer to non-enclosed address space"
 msgstr "cast dari penunjuk ke integer dari ukuran berbeda"
 
-#: c/c-typeck.c:6770
+#: c/c-typeck.c:6775
 #, fuzzy, gcc-internal-format
 #| msgid "initialization from incompatible pointer type"
 msgid "initialization from pointer to non-enclosed address space"
 msgstr "inisialisasi dari tipe penunjuk yang tidak kompatibel"
 
-#: c/c-typeck.c:6774
+#: c/c-typeck.c:6779
 #, gcc-internal-format
 msgid "return from pointer to non-enclosed address space"
 msgstr ""
 
-#: c/c-typeck.c:6792
+#: c/c-typeck.c:6797
 #, gcc-internal-format
 msgid "argument %d of %qE might be a candidate for a format attribute"
 msgstr "argumen %d dari %qE mungkin menjadi sebuah kandidat untuk sebuah format atribut"
 
-#: c/c-typeck.c:6798
+#: c/c-typeck.c:6803
 #, gcc-internal-format
 msgid "assignment left-hand side might be a candidate for a format attribute"
 msgstr "penempatan sisi tangan-kiri mungkin menjadi sebuah kandidat untuk sebuah atribut format"
 
-#: c/c-typeck.c:6803
+#: c/c-typeck.c:6808
 #, gcc-internal-format
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "inisialisasi sisi tangan kiri mungkin menjadi sebuah kandidat untuk sebuah format atribut"
 
-#: c/c-typeck.c:6808 cp/typeck.c:8891
+#: c/c-typeck.c:6813 cp/typeck.c:8891
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "tipe kembali mungkin berupa sebuah kandidat untuk sebuah atribut format"
 
-#: c/c-typeck.c:6857
+#: c/c-typeck.c:6862
 #, gcc-internal-format
 msgid "ISO C forbids passing argument %d of %qE between function pointer and %<void *%>"
 msgstr "ISO C melarang melewatkan argumen %d dari %qE diantara fungsi penunjuk dan %<void *%>"
 
-#: c/c-typeck.c:6860
+#: c/c-typeck.c:6865
 #, gcc-internal-format
 msgid "ISO C forbids assignment between function pointer and %<void *%>"
 msgstr "ISO C melarang penempatan diantara fungsi penunjuk dan %<void *%>"
 
-#: c/c-typeck.c:6862
+#: c/c-typeck.c:6867
 #, gcc-internal-format
 msgid "ISO C forbids initialization between function pointer and %<void *%>"
 msgstr "ISO C melarang inisialisasi diantara fungsi penunjuk dan %<void *%>"
 
-#: c/c-typeck.c:6864
+#: c/c-typeck.c:6869
 #, gcc-internal-format
 msgid "ISO C forbids return between function pointer and %<void *%>"
 msgstr "ISO C melarang kembali diantara fungsi penunjuk dan %<void *%>"
 
-#: c/c-typeck.c:6904
+#: c/c-typeck.c:6909
 #, gcc-internal-format
 msgid "pointer targets in passing argument %d of %qE differ in signedness"
 msgstr "target penunjuk dalam melewatkan argumen %d dari %qE berbeda dalam signedness"
 
-#: c/c-typeck.c:6913
+#: c/c-typeck.c:6918
 #, fuzzy, gcc-internal-format
 #| msgid "pointer targets in assignment differ in signedness"
 msgid "pointer targets in assignment from %qT to %qT differ in signedness"
 msgstr "target penunjuk dalam assignmen berbeda dalam signedness"
 
-#: c/c-typeck.c:6918
+#: c/c-typeck.c:6923
 #, fuzzy, gcc-internal-format
 #| msgid "pointer targets in initialization differ in signedness"
 msgid "pointer targets in initialization of %qT from %qT differ in signedness"
 msgstr "target penunjuk dalam inisialisasi berbeda dalam signedness"
 
-#: c/c-typeck.c:6923
+#: c/c-typeck.c:6928
 #, fuzzy, gcc-internal-format
 #| msgid "pointer targets in passing argument %d of %qE differ in signedness"
 msgid "pointer targets in returning %qT from a function with return type %qT differ in signedness"
 msgstr "target penunjuk dalam melewatkan argumen %d dari %qE berbeda dalam signedness"
 
-#: c/c-typeck.c:6961
+#: c/c-typeck.c:6966
 #, gcc-internal-format
 msgid "passing argument %d of %qE from incompatible pointer type"
 msgstr "melewatkan argumen %d dari %qE dari tipe penunjuk yang tidak kompatibel"
 
-#: c/c-typeck.c:6967
+#: c/c-typeck.c:6972
 #, fuzzy, gcc-internal-format
 #| msgid "assignment from incompatible pointer type"
 msgid "assignment to %qT from incompatible pointer type %qT"
 msgstr "penempatan dari tipe penunjuk yang tidak kompatibel"
 
-#: c/c-typeck.c:6972
+#: c/c-typeck.c:6977
 #, fuzzy, gcc-internal-format
 #| msgid "initialization from incompatible pointer type"
 msgid "initialization of %qT from incompatible pointer type %qT"
 msgstr "inisialisasi dari tipe penunjuk yang tidak kompatibel"
 
-#: c/c-typeck.c:6977
+#: c/c-typeck.c:6982
 #, fuzzy, gcc-internal-format
 #| msgid "return from incompatible pointer type"
 msgid "returning %qT from a function with incompatible return type %qT"
@@ -42718,830 +42762,830 @@
 
 #. ??? This should not be an error when inlining calls to
 #. unprototyped functions.
-#: c/c-typeck.c:6991 c/c-typeck.c:7514 cp/typeck.c:2063
+#: c/c-typeck.c:6996 c/c-typeck.c:7519 cp/typeck.c:2063
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "penggunaan tidak valid dari bukan-lvalue array"
 
-#: c/c-typeck.c:7004
+#: c/c-typeck.c:7009
 #, gcc-internal-format
 msgid "passing argument %d of %qE makes pointer from integer without a cast"
 msgstr "melewatkan argumen %d dari %qE membuat penunjuk dari integer tanpa sebuah cast"
 
-#: c/c-typeck.c:7010
+#: c/c-typeck.c:7015
 #, fuzzy, gcc-internal-format
 #| msgid "assignment makes pointer from integer without a cast"
 msgid "assignment to %qT from %qT makes pointer from integer without a cast"
 msgstr "penempatan membuat penunjuk dari integer tanpa sebuah cast"
 
-#: c/c-typeck.c:7015
+#: c/c-typeck.c:7020
 #, fuzzy, gcc-internal-format
 #| msgid "initialization makes pointer from integer without a cast"
 msgid "initialization of %qT from %qT makes pointer from integer without a cast"
 msgstr "inisialisasi membuat penunjuk dari integer tanpa sebuah cast"
 
-#: c/c-typeck.c:7019
+#: c/c-typeck.c:7024
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE makes pointer from integer without a cast"
 msgid "returning %qT from a function with return type %qT makes pointer from integer without a cast"
 msgstr "melewatkan argumen %d dari %qE membuat penunjuk dari integer tanpa sebuah cast"
 
-#: c/c-typeck.c:7035
+#: c/c-typeck.c:7040
 #, gcc-internal-format
 msgid "passing argument %d of %qE makes integer from pointer without a cast"
 msgstr "melewatkan argumen %d dari %qE membuat integer dari penunjuk tanpa sebuah cast"
 
-#: c/c-typeck.c:7041
+#: c/c-typeck.c:7046
 #, fuzzy, gcc-internal-format
 #| msgid "assignment makes integer from pointer without a cast"
 msgid "assignment to %qT from %qT makes integer from pointer without a cast"
 msgstr "penempatan membuat integer dari penunjuk tanpa sebuah cast"
 
-#: c/c-typeck.c:7046
+#: c/c-typeck.c:7051
 #, fuzzy, gcc-internal-format
 #| msgid "initialization makes integer from pointer without a cast"
 msgid "initialization of %qT from %qT makes integer from pointer without a cast"
 msgstr "inisialisasi membuat integer dari penunjuk tanpa sebuah cast"
 
-#: c/c-typeck.c:7050
+#: c/c-typeck.c:7055
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE makes integer from pointer without a cast"
 msgid "returning %qT from a function with return type %qT makes integer from pointer without a cast"
 msgstr "melewatkan argumen %d dari %qE membuat integer dari penunjuk tanpa sebuah cast"
 
-#: c/c-typeck.c:7073
+#: c/c-typeck.c:7078
 #, gcc-internal-format
 msgid "incompatible type for argument %d of %qE"
 msgstr "tipe tidak kompatibel untuk argumen %d dari %qE"
 
-#: c/c-typeck.c:7078
+#: c/c-typeck.c:7083
 #, gcc-internal-format
 msgid "incompatible types when assigning to type %qT from type %qT"
 msgstr "tipe tidak kompatibel dalam penempatan ke tipe %qT dari tipe %qT"
 
-#: c/c-typeck.c:7083
+#: c/c-typeck.c:7088
 #, gcc-internal-format
 msgid "incompatible types when initializing type %qT using type %qT"
 msgstr "tipe tidak kompatibel ketika menginisialisasi tipe %qT menggunakan tipe %qT"
 
-#: c/c-typeck.c:7088
+#: c/c-typeck.c:7093
 #, gcc-internal-format
 msgid "incompatible types when returning type %qT but %qT was expected"
 msgstr "tipe tidak kompatibel ketika mengembalikan tipe %qT tetapi %qT telah diduga"
 
-#: c/c-typeck.c:7152
+#: c/c-typeck.c:7157
 #, gcc-internal-format
 msgid "traditional C rejects automatic aggregate initialization"
 msgstr "tradisional C menolak inisialisasi otomatis bersama"
 
-#: c/c-typeck.c:7388 c/c-typeck.c:8284 cp/typeck2.c:1045
+#: c/c-typeck.c:7393 c/c-typeck.c:8289 cp/typeck2.c:1045
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "inisialisasi dari sebuah anggota array fleksibel"
 
-#: c/c-typeck.c:7398 cp/typeck2.c:1059
+#: c/c-typeck.c:7403 cp/typeck2.c:1059
 #, gcc-internal-format
 msgid "char-array initialized from wide string"
 msgstr "char-array terinisialisasi dari string lebar"
 
-#: c/c-typeck.c:7407
+#: c/c-typeck.c:7412
 #, gcc-internal-format
 msgid "wide character array initialized from non-wide string"
 msgstr "array karakter lebar terinisialisasi dari string bukan lebar"
 
-#: c/c-typeck.c:7413
+#: c/c-typeck.c:7418
 #, gcc-internal-format
 msgid "wide character array initialized from incompatible wide string"
 msgstr "array karakter lebar terinisialisasi dari string bukan lebar tidak kompatibel"
 
-#: c/c-typeck.c:7446
+#: c/c-typeck.c:7451
 #, gcc-internal-format
 msgid "array of inappropriate type initialized from string constant"
 msgstr "array dari tipe yang tidak sesuai terinisialisasi dari konstanta string"
 
-#: c/c-typeck.c:7533 c/c-typeck.c:7557 c/c-typeck.c:7560 c/c-typeck.c:7568
-#: c/c-typeck.c:7608 c/c-typeck.c:9131 c/c-typeck.c:9181
+#: c/c-typeck.c:7538 c/c-typeck.c:7562 c/c-typeck.c:7565 c/c-typeck.c:7573
+#: c/c-typeck.c:7613 c/c-typeck.c:9136 c/c-typeck.c:9186
 #, gcc-internal-format
 msgid "initializer element is not constant"
 msgstr "elemen penginisialisasi bukan sebuah konstanta"
 
-#: c/c-typeck.c:7542
+#: c/c-typeck.c:7547
 #, gcc-internal-format
 msgid "array initialized from non-constant array expression"
 msgstr "array terinisialisasi dari ekspresi array bukan-konstanta"
 
-#: c/c-typeck.c:7573 c/c-typeck.c:7621 c/c-typeck.c:9191
+#: c/c-typeck.c:7578 c/c-typeck.c:7626 c/c-typeck.c:9196
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not constant"
 msgid "initializer element is not a constant expression"
 msgstr "elemen penginisialisasi bukan sebuah konstanta"
 
-#: c/c-typeck.c:7615 c/c-typeck.c:9186
+#: c/c-typeck.c:7620 c/c-typeck.c:9191
 #, gcc-internal-format
 msgid "initializer element is not computable at load time"
 msgstr "elemen penginisialisasi tidak dapat dihitung di waktu load"
 
-#: c/c-typeck.c:7634
+#: c/c-typeck.c:7639
 #, gcc-internal-format
 msgid "invalid initializer"
 msgstr "penginisialisasi tidak valid"
 
-#: c/c-typeck.c:7912 cp/decl.c:6396
+#: c/c-typeck.c:7917 cp/decl.c:6396
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "tipe vektor opaque tidak dapat diinisialisasi"
 
-#: c/c-typeck.c:8132
+#: c/c-typeck.c:8137
 #, gcc-internal-format
 msgid "extra brace group at end of initializer"
 msgstr "kelebihan grup kurung diakhir dari penginisialisasi"
 
-#: c/c-typeck.c:8215
+#: c/c-typeck.c:8220
 #, gcc-internal-format
 msgid "braces around scalar initializer"
 msgstr "kurung disekitar penginisialisasi skalar"
 
-#: c/c-typeck.c:8281 c/c-typeck.c:9615 cp/typeck2.c:1084 cp/typeck2.c:1297
+#: c/c-typeck.c:8286 c/c-typeck.c:9620 cp/typeck2.c:1084 cp/typeck2.c:1297
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "inisialisasi dari anggota array fleksibel dalam sebuah konteks bertelur"
 
-#: c/c-typeck.c:8318
+#: c/c-typeck.c:8323
 #, gcc-internal-format
 msgid "missing braces around initializer"
 msgstr "hilang kurung disekitar penginisialisasi"
 
-#: c/c-typeck.c:8341
+#: c/c-typeck.c:8346
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "missing initializer for field %qD of %qT"
 msgstr "hilang penginisialisasi untuk anggota %qD"
 
-#: c/c-typeck.c:8365
+#: c/c-typeck.c:8370
 #, gcc-internal-format
 msgid "empty scalar initializer"
 msgstr "penginisialisasi skalar kosong"
 
-#: c/c-typeck.c:8370
+#: c/c-typeck.c:8375
 #, gcc-internal-format
 msgid "extra elements in scalar initializer"
 msgstr "kelebihan elemen dalam penginisialisasi skalar"
 
-#: c/c-typeck.c:8483 c/c-typeck.c:8565
+#: c/c-typeck.c:8488 c/c-typeck.c:8570
 #, gcc-internal-format
 msgid "array index in non-array initializer"
 msgstr "indeks array dalam penginisialisasi bukan-array"
 
-#: c/c-typeck.c:8488 c/c-typeck.c:8627
+#: c/c-typeck.c:8493 c/c-typeck.c:8632
 #, gcc-internal-format
 msgid "field name not in record or union initializer"
 msgstr "nama bagian tidak dalam rekaman atau union penginisialisasi"
 
-#: c/c-typeck.c:8538
+#: c/c-typeck.c:8543
 #, gcc-internal-format
 msgid "array index in initializer not of integer type"
 msgstr "indeks array dalam penginisialisasi bukan tipe integer"
 
-#: c/c-typeck.c:8547 c/c-typeck.c:8556
+#: c/c-typeck.c:8552 c/c-typeck.c:8561
 #, fuzzy, gcc-internal-format
 #| msgid "array index in initializer not of integer type"
 msgid "array index in initializer is not an integer constant expression"
 msgstr "indeks array dalam penginisialisasi bukan tipe integer"
 
-#: c/c-typeck.c:8561 c/c-typeck.c:8563
+#: c/c-typeck.c:8566 c/c-typeck.c:8568
 #, gcc-internal-format
 msgid "nonconstant array index in initializer"
 msgstr "indeks array bukan konstan dalam penginisialisasi"
 
-#: c/c-typeck.c:8567 c/c-typeck.c:8570
+#: c/c-typeck.c:8572 c/c-typeck.c:8575
 #, gcc-internal-format
 msgid "array index in initializer exceeds array bounds"
 msgstr "indeks array dalam penginisialisasi melebihi batasan array"
 
-#: c/c-typeck.c:8589
+#: c/c-typeck.c:8594
 #, gcc-internal-format
 msgid "empty index range in initializer"
 msgstr "jangkauan indeks kosong dalam penginisialisasi"
 
-#: c/c-typeck.c:8598
+#: c/c-typeck.c:8603
 #, gcc-internal-format
 msgid "array index range in initializer exceeds array bounds"
 msgstr "jangkauan indeks array dalam penginisialisasi melebihi batasan array"
 
-#: c/c-typeck.c:8700 c/c-typeck.c:8730 c/c-typeck.c:9274
+#: c/c-typeck.c:8705 c/c-typeck.c:8735 c/c-typeck.c:9279
 #, gcc-internal-format
 msgid "initialized field with side-effects overwritten"
 msgstr "bagian terinisialisasi dengan efek-samping overwritten"
 
-#: c/c-typeck.c:8704 c/c-typeck.c:8734 c/c-typeck.c:9277
+#: c/c-typeck.c:8709 c/c-typeck.c:8739 c/c-typeck.c:9282
 #, gcc-internal-format
 msgid "initialized field overwritten"
 msgstr "bagian terinisialisasi overwritten"
 
-#: c/c-typeck.c:9208
+#: c/c-typeck.c:9213
 #, fuzzy, gcc-internal-format
 #| msgid "Perform conversions of switch initializations."
 msgid "enum conversion in initialization is invalid in C++"
 msgstr "Lakukan konversi dari kondisional switch."
 
-#: c/c-typeck.c:9496
+#: c/c-typeck.c:9501
 #, gcc-internal-format
 msgid "excess elements in char array initializer"
 msgstr "kelebihan elemen dalam char array penginisialisasi"
 
-#: c/c-typeck.c:9503 c/c-typeck.c:9574
+#: c/c-typeck.c:9508 c/c-typeck.c:9579
 #, gcc-internal-format
 msgid "excess elements in struct initializer"
 msgstr "kelebihan elemen dalam struktur penginisialisasi"
 
-#: c/c-typeck.c:9518
+#: c/c-typeck.c:9523
 #, gcc-internal-format
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr ""
 
-#: c/c-typeck.c:9589
+#: c/c-typeck.c:9594
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr "inisialisasi tidak statis dari sebuah anggota array fleksibel"
 
-#: c/c-typeck.c:9687
+#: c/c-typeck.c:9692
 #, gcc-internal-format
 msgid "excess elements in union initializer"
 msgstr "kelebihan elemen dalam penginisialisasi union"
 
-#: c/c-typeck.c:9709
+#: c/c-typeck.c:9714
 #, gcc-internal-format
 msgid "traditional C rejects initialization of unions"
 msgstr "tradisional C menolah inisialisasi dari unions"
 
-#: c/c-typeck.c:9777
+#: c/c-typeck.c:9782
 #, gcc-internal-format
 msgid "excess elements in array initializer"
 msgstr "kelebihan elemen dalam array penginisialisasi"
 
-#: c/c-typeck.c:9811
+#: c/c-typeck.c:9816
 #, gcc-internal-format
 msgid "excess elements in vector initializer"
 msgstr "kelebihan elemen dalam penginisialisasi vektor"
 
-#: c/c-typeck.c:9843
+#: c/c-typeck.c:9848
 #, gcc-internal-format
 msgid "excess elements in scalar initializer"
 msgstr "kelebihan elemen dalam penginisialisasi skalar"
 
-#: c/c-typeck.c:10086
+#: c/c-typeck.c:10091
 #, gcc-internal-format
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C melarang %<goto *expr;%>"
 
-#: c/c-typeck.c:10113 c/gimple-parser.c:1604 cp/typeck.c:9113
+#: c/c-typeck.c:10118 c/gimple-parser.c:1604 cp/typeck.c:9113
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "fungsi dideklarasikan %<noreturn%> memiliki sebuah pernyataan %<return%>"
 
-#: c/c-typeck.c:10139 c/c-typeck.c:10143
+#: c/c-typeck.c:10144 c/c-typeck.c:10148
 #, gcc-internal-format
 msgid "%<return%> with no value, in function returning non-void"
 msgstr "%<return%> dengan tidak ada nilai, dalam fungsi mengembalikan bukan void"
 
-#: c/c-typeck.c:10157 c/gimple-parser.c:1614
+#: c/c-typeck.c:10162 c/gimple-parser.c:1614
 #, gcc-internal-format
 msgid "%<return%> with a value, in function returning void"
 msgstr "%<return%> dengan sebuah nilai, dalam fungsi mengembalikan void"
 
-#: c/c-typeck.c:10160
+#: c/c-typeck.c:10165
 #, gcc-internal-format
 msgid "ISO C forbids %<return%> with expression, in function returning void"
 msgstr "ISO C melarang %<return%> dengan ekspresi, dalam fungsi mengembalikan void"
 
-#: c/c-typeck.c:10236
+#: c/c-typeck.c:10241
 #, fuzzy, gcc-internal-format
 #| msgid "function returns address of local variable"
 msgid "function returns address of label"
 msgstr "fungsi mengembalikan alamat dari variabel lokal"
 
-#: c/c-typeck.c:10327 cp/semantics.c:1171
+#: c/c-typeck.c:10332 cp/semantics.c:1171
 #, gcc-internal-format
 msgid "switch quantity not an integer"
 msgstr "switch kuantiti bukan sebuah integer"
 
-#: c/c-typeck.c:10352
+#: c/c-typeck.c:10357
 #, gcc-internal-format
 msgid "%<long%> switch expression not converted to %<int%> in ISO C"
 msgstr "pilihan %<long%> ekspresi tidak diubah ke %<int%> dalam ISO C"
 
-#: c/c-typeck.c:10390 c/c-typeck.c:10398
+#: c/c-typeck.c:10395 c/c-typeck.c:10403
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "case label is not an integer constant expression"
 msgstr "ukuran dari array bukan sebuah integral konstan ekspresi"
 
-#: c/c-typeck.c:10404 cp/parser.c:11067
+#: c/c-typeck.c:10409 cp/parser.c:11067
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "label case tidak dalam label pernyataan switch"
 
-#: c/c-typeck.c:10406
+#: c/c-typeck.c:10411
 #, gcc-internal-format
 msgid "%<default%> label not within a switch statement"
 msgstr "%<default%> label tidak dalam sebuah pernyataan switch"
 
-#: c/c-typeck.c:10578 cp/parser.c:12356
+#: c/c-typeck.c:10583 cp/parser.c:12353
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "pernyataan break tidak dalam loop atau switch"
 
-#: c/c-typeck.c:10580 cp/parser.c:12379
+#: c/c-typeck.c:10585 cp/parser.c:12376
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "pernyataan continue tidak dalam sebuah loop"
 
-#: c/c-typeck.c:10585 cp/parser.c:12369
+#: c/c-typeck.c:10590 cp/parser.c:12366
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr "pernyataan break digunakan dengan OpenMP untuk loop"
 
-#: c/c-typeck.c:10590
+#: c/c-typeck.c:10595
 #, fuzzy, gcc-internal-format
 #| msgid "break statement not within loop or switch"
 msgid "break statement within %<#pragma simd%> loop body"
 msgstr "pernyataan break tidak dalam loop atau switch"
 
-#: c/c-typeck.c:10592
+#: c/c-typeck.c:10597
 #, fuzzy, gcc-internal-format
 #| msgid "continue statement not within a loop"
 msgid "continue statement within %<#pragma simd%> loop body"
 msgstr "pernyataan continue tidak dalam sebuah loop"
 
-#: c/c-typeck.c:10618 cp/cp-gimplify.c:432
+#: c/c-typeck.c:10623 cp/cp-gimplify.c:432
 #, gcc-internal-format
 msgid "statement with no effect"
 msgstr "pernyataan dengan tidak ada efek"
 
-#: c/c-typeck.c:10662
+#: c/c-typeck.c:10667
 #, gcc-internal-format
 msgid "expression statement has incomplete type"
 msgstr "ekspresi pernyataan memiliki tipe tidak lengkap"
 
-#: c/c-typeck.c:11476 c/c-typeck.c:11644 cp/typeck.c:5017
+#: c/c-typeck.c:11481 c/c-typeck.c:11649 cp/typeck.c:5017
 #, fuzzy, gcc-internal-format
 #| msgid "Warn about comparison of different enum types"
 msgid "comparing vectors with different element types"
 msgstr "Peringatkan mengenai perbandingan dari tipe enum yang berbeda"
 
-#: c/c-typeck.c:11484 c/c-typeck.c:11652 cp/typeck.c:5030
+#: c/c-typeck.c:11489 c/c-typeck.c:11657 cp/typeck.c:5030
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr ""
 
-#: c/c-typeck.c:11509 c/c-typeck.c:11677 cp/typeck.c:5058
+#: c/c-typeck.c:11514 c/c-typeck.c:11682 cp/typeck.c:5058
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr ""
 
-#: c/c-typeck.c:11523 cp/typeck.c:4743
+#: c/c-typeck.c:11528 cp/typeck.c:4743
 #, gcc-internal-format
 msgid "comparing floating point with == or != is unsafe"
 msgstr "membandingkan titik pecahan dengan == atau != adalah tidak aman"
 
-#: c/c-typeck.c:11541 c/c-typeck.c:11562
+#: c/c-typeck.c:11546 c/c-typeck.c:11567
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<false%> for the address of %qD will never be NULL"
 msgstr ""
 
-#: c/c-typeck.c:11547 c/c-typeck.c:11568
+#: c/c-typeck.c:11552 c/c-typeck.c:11573
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<true%> for the address of %qD will never be NULL"
 msgstr ""
 
-#: c/c-typeck.c:11589 c/c-typeck.c:11718
+#: c/c-typeck.c:11594 c/c-typeck.c:11723
 #, fuzzy, gcc-internal-format
 #| msgid "comparison of distinct pointer types lacks a cast"
 msgid "comparison of pointers to disjoint address spaces"
 msgstr "perbandingan dari tipe penunjuk berbeda kurang sebuah cast"
 
-#: c/c-typeck.c:11596 c/c-typeck.c:11602
+#: c/c-typeck.c:11601 c/c-typeck.c:11607
 #, gcc-internal-format
 msgid "ISO C forbids comparison of %<void *%> with function pointer"
 msgstr "ISO C melarang perbandingan dari %<void *%> dengan fungsi penunjuk"
 
-#: c/c-typeck.c:11609 c/c-typeck.c:11728
+#: c/c-typeck.c:11614 c/c-typeck.c:11733
 #, gcc-internal-format
 msgid "comparison of distinct pointer types lacks a cast"
 msgstr "perbandingan dari tipe penunjuk berbeda kurang sebuah cast"
 
-#: c/c-typeck.c:11621 c/c-typeck.c:11626 c/c-typeck.c:11754 c/c-typeck.c:11759
+#: c/c-typeck.c:11626 c/c-typeck.c:11631 c/c-typeck.c:11759 c/c-typeck.c:11764
 #, gcc-internal-format
 msgid "comparison between pointer and integer"
 msgstr "perbandingan diantara penunjuk dan integer"
 
-#: c/c-typeck.c:11706
+#: c/c-typeck.c:11711
 #, gcc-internal-format
 msgid "comparison of complete and incomplete pointers"
 msgstr "perbandingan dari penunjuk lengkap dan tidak lengkap"
 
-#: c/c-typeck.c:11708
+#: c/c-typeck.c:11713
 #, gcc-internal-format
 msgid "ISO C forbids ordered comparisons of pointers to functions"
 msgstr "ISO C melarang perbandingan terurut dari penunjuk ke fungsi"
 
-#: c/c-typeck.c:11713
+#: c/c-typeck.c:11718
 #, fuzzy, gcc-internal-format
 #| msgid "ordered comparison of pointer with integer zero"
 msgid "ordered comparison of pointer with null pointer"
 msgstr "perbandingan terurut dari penunjuk dengan integer nol"
 
-#: c/c-typeck.c:11736 c/c-typeck.c:11739 c/c-typeck.c:11746 c/c-typeck.c:11749
+#: c/c-typeck.c:11741 c/c-typeck.c:11744 c/c-typeck.c:11751 c/c-typeck.c:11754
 #: cp/typeck.c:5081 cp/typeck.c:5088
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "perbandingan terurut dari penunjuk dengan integer nol"
 
-#: c/c-typeck.c:11811
+#: c/c-typeck.c:11816
 #, fuzzy, gcc-internal-format
 #| msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
 msgstr "meminta untuk konversi implisit dari %qT ke %qT tidak diijinkan dalam C++"
 
-#: c/c-typeck.c:12126
+#: c/c-typeck.c:12131
 #, gcc-internal-format
 msgid "used array that cannot be converted to pointer where scalar is required"
 msgstr "menggunakan array yang tidak dapat diubah ke penunjuk dimana skalar dibutuhkan"
 
-#: c/c-typeck.c:12130
+#: c/c-typeck.c:12135
 #, gcc-internal-format
 msgid "used struct type value where scalar is required"
 msgstr "menggunakan nilai tipe struct dimana skalar dibutuhkan"
 
-#: c/c-typeck.c:12134
+#: c/c-typeck.c:12139
 #, gcc-internal-format
 msgid "used union type value where scalar is required"
 msgstr "menggunaka nilai tipe union dimana skalar dibutuhkan"
 
-#: c/c-typeck.c:12150
+#: c/c-typeck.c:12155
 #, fuzzy, gcc-internal-format
 #| msgid "used struct type value where scalar is required"
 msgid "used vector type where scalar is required"
 msgstr "menggunakan nilai tipe struct dimana skalar dibutuhkan"
 
-#: c/c-typeck.c:12340 cp/semantics.c:8508
+#: c/c-typeck.c:12345 cp/semantics.c:8511
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12379 cp/semantics.c:8545
+#: c/c-typeck.c:12384 cp/semantics.c:8548
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12423 c/c-typeck.c:13581 c/c-typeck.c:13642 c/c-typeck.c:13704
+#: c/c-typeck.c:12428 c/c-typeck.c:13586 c/c-typeck.c:13647 c/c-typeck.c:13709
 #, fuzzy, gcc-internal-format
 #| msgid "%Htoo many %qs clauses"
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "%Hterlalu banyak %qs clauses"
 
-#: c/c-typeck.c:12436 c/c-typeck.c:13628 cp/semantics.c:4546
-#: cp/semantics.c:6717
+#: c/c-typeck.c:12441 c/c-typeck.c:13633 cp/semantics.c:4549
+#: cp/semantics.c:6720
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12445 c/c-typeck.c:13652 cp/semantics.c:4556
-#: cp/semantics.c:6735
+#: c/c-typeck.c:12450 c/c-typeck.c:13657 cp/semantics.c:4559
+#: cp/semantics.c:6738
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qE is a member of a union"
 msgstr "%qD bukan sebuah anggota dari fungsi template"
 
-#: c/c-typeck.c:12455 cp/semantics.c:4570 cp/semantics.c:6760
+#: c/c-typeck.c:12460 cp/semantics.c:4573 cp/semantics.c:6763
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD bukan sebuah variabel dalam clause %qs"
 
-#: c/c-typeck.c:12459 c/c-typeck.c:13669 cp/semantics.c:4574
-#: cp/semantics.c:6763
+#: c/c-typeck.c:12464 c/c-typeck.c:13674 cp/semantics.c:4577
+#: cp/semantics.c:6766
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qE bukan sebuah variabel dalam clause %qs"
 
-#: c/c-typeck.c:12466
+#: c/c-typeck.c:12471
 #, fuzzy, gcc-internal-format
 #| msgid "%Htoo many %qs clauses"
 msgid "%<_Atomic%> %qD in %qs clause"
 msgstr "%Hterlalu banyak %qs clauses"
 
-#: c/c-typeck.c:12475 c/c-typeck.c:13676 c/c-typeck.c:13778
-#: cp/semantics.c:4591 cp/semantics.c:6769 cp/semantics.c:6931
+#: c/c-typeck.c:12480 c/c-typeck.c:13681 c/c-typeck.c:13783
+#: cp/semantics.c:4594 cp/semantics.c:6772 cp/semantics.c:6934
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD bukan sebuah variabel dalam clause %qs"
 
-#: c/c-typeck.c:12511 cp/semantics.c:4623
+#: c/c-typeck.c:12516 cp/semantics.c:4626
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "low bound %qE of array section does not have integral type"
 msgstr "ukuran dalam array baru harus memiliki tipe integral"
 
-#: c/c-typeck.c:12518 cp/semantics.c:4630
+#: c/c-typeck.c:12523 cp/semantics.c:4633
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "length %qE of array section does not have integral type"
 msgstr "ukuran dalam array baru harus memiliki tipe integral"
 
-#: c/c-typeck.c:12545 c/c-typeck.c:12609 c/c-typeck.c:12867
-#: cp/semantics.c:4666 cp/semantics.c:4730
+#: c/c-typeck.c:12550 c/c-typeck.c:12614 c/c-typeck.c:12872
+#: cp/semantics.c:4669 cp/semantics.c:4733
 #, fuzzy, gcc-internal-format
 #| msgid "variable length array %qs is used"
 msgid "zero length array section in %qs clause"
 msgstr "array dengan panjang bervariabel %qs digunakan"
 
-#: c/c-typeck.c:12564 cp/semantics.c:4685
+#: c/c-typeck.c:12569 cp/semantics.c:4688
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12572 cp/semantics.c:4693
+#: c/c-typeck.c:12577 cp/semantics.c:4696
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12581 c/c-typeck.c:12691 cp/semantics.c:4702
-#: cp/semantics.c:4812
+#: c/c-typeck.c:12586 c/c-typeck.c:12696 cp/semantics.c:4705
+#: cp/semantics.c:4815
 #, fuzzy, gcc-internal-format
 #| msgid "variable length array %qs is used"
 msgid "negative length in array section in %qs clause"
 msgstr "array dengan panjang bervariabel %qs digunakan"
 
-#: c/c-typeck.c:12598 cp/semantics.c:4719
+#: c/c-typeck.c:12603 cp/semantics.c:4722
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12635 cp/semantics.c:4756
+#: c/c-typeck.c:12640 cp/semantics.c:4759
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12650 cp/semantics.c:4771
+#: c/c-typeck.c:12655 cp/semantics.c:4774
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12683 cp/semantics.c:4804
+#: c/c-typeck.c:12688 cp/semantics.c:4807
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12701 c/c-typeck.c:12810 cp/semantics.c:4822
-#: cp/semantics.c:4934
+#: c/c-typeck.c:12706 c/c-typeck.c:12815 cp/semantics.c:4825
+#: cp/semantics.c:4937
 #, fuzzy, gcc-internal-format
 #| msgid "Copy array sections into a contiguous block on procedure entry"
 msgid "array section is not contiguous in %qs clause"
 msgstr "Salin bagian array kedalam sebuah blok kontinu dalam masukan prosedur"
 
-#: c/c-typeck.c:12709 cp/semantics.c:4830
+#: c/c-typeck.c:12714 cp/semantics.c:4833
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE does not have class type"
 msgid "%qE does not have pointer or array type"
 msgstr "%H%qE tidak memiliki tipe kelas"
 
-#: c/c-typeck.c:13103 c/c-typeck.c:13113
+#: c/c-typeck.c:13108 c/c-typeck.c:13118
 #, gcc-internal-format
 msgid "%qD in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: c/c-typeck.c:13130
+#: c/c-typeck.c:13135
 #, gcc-internal-format
 msgid "%<_Atomic%> %qE in %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13178
+#: c/c-typeck.c:13183
 #, gcc-internal-format
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "%qE memiliki tipe tidak valid untuk %<reduction(%s)%>"
 
-#: c/c-typeck.c:13187 cp/semantics.c:5755
+#: c/c-typeck.c:13192 cp/semantics.c:5758
 #, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr ""
 
-#: c/c-typeck.c:13275
+#: c/c-typeck.c:13280
 #, fuzzy, gcc-internal-format
 #| msgid "variable length array is used"
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "array dengan panjang bervariabel digunakan"
 
-#: c/c-typeck.c:13293 c/c-typeck.c:13836 cp/semantics.c:7249
+#: c/c-typeck.c:13298 c/c-typeck.c:13841 cp/semantics.c:7252
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13305 cp/semantics.c:7289
+#: c/c-typeck.c:13310 cp/semantics.c:7292
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE harus berupa %<threadprivate%> untuk %<copyin%>"
 
-#: c/c-typeck.c:13319 cp/semantics.c:5929
+#: c/c-typeck.c:13324 cp/semantics.c:5932
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr ""
 
-#: c/c-typeck.c:13327
+#: c/c-typeck.c:13332
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with type %qT"
 msgstr ""
 
-#: c/c-typeck.c:13335
+#: c/c-typeck.c:13340
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13354 cp/semantics.c:5999
+#: c/c-typeck.c:13359 cp/semantics.c:6002
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
-#: c/c-typeck.c:13384 c/c-typeck.c:13771 cp/semantics.c:6083
-#: cp/semantics.c:6924
+#: c/c-typeck.c:13389 c/c-typeck.c:13776 cp/semantics.c:6086
+#: cp/semantics.c:6927
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE bukan sebuah variabel dalam clause %qs"
 
-#: c/c-typeck.c:13393 cp/semantics.c:6092
+#: c/c-typeck.c:13398 cp/semantics.c:6095
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in reduction clauses"
 msgstr "%qD muncul lebih dari sekali dalam data clauses"
 
-#: c/c-typeck.c:13404 c/c-typeck.c:13434 c/c-typeck.c:13463
+#: c/c-typeck.c:13409 c/c-typeck.c:13439 c/c-typeck.c:13468
 #, gcc-internal-format
 msgid "%qE appears more than once in data clauses"
 msgstr "%qE muncul lebih dari sekali dalam clause data"
 
-#: c/c-typeck.c:13411 c/c-typeck.c:13440 c/c-typeck.c:13600 c/c-typeck.c:13714
-#: c/c-typeck.c:13720 c/c-typeck.c:13733 c/c-typeck.c:13742
-#: cp/semantics.c:6102 cp/semantics.c:6109 cp/semantics.c:6160
-#: cp/semantics.c:6166 cp/semantics.c:6203 cp/semantics.c:6680
-#: cp/semantics.c:6817 cp/semantics.c:6823 cp/semantics.c:6836
-#: cp/semantics.c:6845
+#: c/c-typeck.c:13416 c/c-typeck.c:13445 c/c-typeck.c:13605 c/c-typeck.c:13719
+#: c/c-typeck.c:13725 c/c-typeck.c:13738 c/c-typeck.c:13747
+#: cp/semantics.c:6105 cp/semantics.c:6112 cp/semantics.c:6163
+#: cp/semantics.c:6169 cp/semantics.c:6206 cp/semantics.c:6683
+#: cp/semantics.c:6820 cp/semantics.c:6826 cp/semantics.c:6839
+#: cp/semantics.c:6848
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr "%qD muncul lebih dari sekali dalam data clauses"
 
-#: c/c-typeck.c:13413 c/c-typeck.c:13442 c/c-typeck.c:13722 c/c-typeck.c:13744
-#: cp/semantics.c:6111 cp/semantics.c:6168 cp/semantics.c:6825
-#: cp/semantics.c:6847
+#: c/c-typeck.c:13418 c/c-typeck.c:13447 c/c-typeck.c:13727 c/c-typeck.c:13749
+#: cp/semantics.c:6114 cp/semantics.c:6171 cp/semantics.c:6828
+#: cp/semantics.c:6850
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears both in data and map clauses"
 msgstr "%qD muncul lebih dari sekali dalam data clauses"
 
-#: c/c-typeck.c:13427 cp/semantics.c:6154
+#: c/c-typeck.c:13432 cp/semantics.c:6157
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "%qE bukan sebuah variabel dalam clause %<firstprivate%>"
 
-#: c/c-typeck.c:13456 cp/semantics.c:6197
+#: c/c-typeck.c:13461 cp/semantics.c:6200
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "%qE bukan sebuah variabel dalam clause %<lastprivate%>"
 
-#: c/c-typeck.c:13475 cp/semantics.c:6545
+#: c/c-typeck.c:13480 cp/semantics.c:6548
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "%qE bukan sebuah variabel dalam clause %qs"
 
-#: c/c-typeck.c:13482
+#: c/c-typeck.c:13487
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array"
 msgstr "tipe dari vektor delete bukan penunjuk ataupun tipe array"
 
-#: c/c-typeck.c:13489
+#: c/c-typeck.c:13494
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<aligned%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13496
+#: c/c-typeck.c:13501
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr "%qE muncul lebih dari sekali dalam clause data"
 
-#: c/c-typeck.c:13551 cp/semantics.c:6627
+#: c/c-typeck.c:13556 cp/semantics.c:6630
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr "%qE bukan sebuah variabel dalam clause %qs"
 
-#: c/c-typeck.c:13573 cp/semantics.c:6658
+#: c/c-typeck.c:13578 cp/semantics.c:6661
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13597 c/c-typeck.c:13731 cp/semantics.c:6677
-#: cp/semantics.c:6834
+#: c/c-typeck.c:13602 c/c-typeck.c:13736 cp/semantics.c:6680
+#: cp/semantics.c:6837
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD muncul lebih dari sekali dalam data clauses"
 
-#: c/c-typeck.c:13603 c/c-typeck.c:13735 cp/semantics.c:6683
-#: cp/semantics.c:6838
+#: c/c-typeck.c:13608 c/c-typeck.c:13740 cp/semantics.c:6686
+#: cp/semantics.c:6841
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD muncul lebih dari sekali dalam data clauses"
 
-#: c/c-typeck.c:13635 cp/semantics.c:6724
+#: c/c-typeck.c:13640 cp/semantics.c:6727
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qE bukan sebuah variabel dalam clause %qs"
 
-#: c/c-typeck.c:13695 c/c-typeck.c:13785 cp/semantics.c:6799
-#: cp/semantics.c:6938
+#: c/c-typeck.c:13700 c/c-typeck.c:13790 cp/semantics.c:6802
+#: cp/semantics.c:6941
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD bukan sebuah variabel dalam clause %qs"
 
-#: c/c-typeck.c:13766 cp/semantics.c:6918
+#: c/c-typeck.c:13771 cp/semantics.c:6921
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE bukan sebuah variabel dalam clause %qs"
 
-#: c/c-typeck.c:13794 cp/semantics.c:6947
+#: c/c-typeck.c:13799 cp/semantics.c:6950
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qE muncul lebih dari sekali dalam clause data"
 
-#: c/c-typeck.c:13808 cp/semantics.c:6962
+#: c/c-typeck.c:13813 cp/semantics.c:6965
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD bukan sebuah variabel dalam clause %qs"
 
-#: c/c-typeck.c:13811 cp/semantics.c:6964
+#: c/c-typeck.c:13816 cp/semantics.c:6967
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qE bukan sebuah variabel dalam clause %qs"
 
-#: c/c-typeck.c:13826
+#: c/c-typeck.c:13831
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "tipe dari vektor delete bukan penunjuk ataupun tipe array"
 
-#: c/c-typeck.c:13900 cp/semantics.c:6359
+#: c/c-typeck.c:13905 cp/semantics.c:6362
 #, gcc-internal-format
 msgid "%<nonmonotonic%> modifier specified for %qs schedule kind"
 msgstr ""
 
-#: c/c-typeck.c:13931 cp/semantics.c:7141
+#: c/c-typeck.c:13936 cp/semantics.c:7144
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:13981 cp/semantics.c:7332
+#: c/c-typeck.c:13986 cp/semantics.c:7335
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE adalah predetermined %qs untuk %qs"
 
-#: c/c-typeck.c:14001 cp/semantics.c:7223
+#: c/c-typeck.c:14006 cp/semantics.c:7226
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:14013 cp/semantics.c:7236
+#: c/c-typeck.c:14018 cp/semantics.c:7239
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14031 cp/semantics.c:7203
+#: c/c-typeck.c:14036 cp/semantics.c:7206
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14204
+#: c/c-typeck.c:14209
 #, gcc-internal-format
 msgid "cannot use %<va_arg%> with reverse storage order"
 msgstr ""
 
-#: c/c-typeck.c:14209
+#: c/c-typeck.c:14214
 #, fuzzy, gcc-internal-format
 #| msgid "first argument to %<va_arg%> not of type %<va_list%>"
 msgid "second argument to %<va_arg%> is of incomplete type %qT"
 msgstr "argumen pertama ke %<va_arg%> bukan dari tipe %<va_list%>"
 
-#: c/c-typeck.c:14215
+#: c/c-typeck.c:14220
 #, gcc-internal-format
 msgid "C++ requires promoted type, not enum type, in %<va_arg%>"
 msgstr ""
@@ -43674,7 +43718,7 @@
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "  untuk konversi dari %qT ke %qT"
 
-#: cp/call.c:3441 cp/pt.c:6495
+#: cp/call.c:3441 cp/pt.c:6509
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -43995,7 +44039,7 @@
 msgid "%q#D is private within this context"
 msgstr "dalam konteks ini"
 
-#: cp/call.c:6478 cp/decl.c:7343
+#: cp/call.c:6478 cp/decl.c:7364
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "declared private here"
@@ -44007,7 +44051,7 @@
 msgid "%q#D is protected within this context"
 msgstr "dalam konteks ini"
 
-#: cp/call.c:6486 cp/decl.c:7344
+#: cp/call.c:6486 cp/decl.c:7365
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "declared protected here"
@@ -44339,7 +44383,7 @@
 msgid "call to non-function %qD"
 msgstr "panggilan ke bukan-fungsi %qD"
 
-#: cp/call.c:9119 cp/pt.c:15053 cp/typeck.c:2901
+#: cp/call.c:9119 cp/pt.c:15075 cp/typeck.c:2901
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
@@ -44577,282 +44621,282 @@
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr "tidak dapat mengubah dari dasar %qT ke tipe turunan %qT melalui basis maya %qT"
 
-#: cp/class.c:2098
+#: cp/class.c:2103
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr "semua anggota fungsi dalam kelas %qT adalah private"
 
-#: cp/class.c:2110
+#: cp/class.c:2115
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr "%q#T hanya mendefinisikan sebuah desktruktor private dan tidak memiliki teman"
 
-#: cp/class.c:2152
+#: cp/class.c:2156
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr "%q#T hanya mendefinisikan konstruktor private dan tidak memiliki teman"
 
-#: cp/class.c:2156
+#: cp/class.c:2160
 #, gcc-internal-format
 msgid "%q#D is public, but requires an existing %q#T object"
 msgstr ""
 
-#: cp/class.c:2430
+#: cp/class.c:2434
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr "tidak ada unik final overrider untuk %qD dalam %qT"
 
-#: cp/class.c:2785
+#: cp/class.c:2789
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D cannot be overloaded"
 msgid "%qD can be marked override"
 msgstr "%q+#D tidak dapat overloaded"
 
-#: cp/class.c:2797
+#: cp/class.c:2801
 #, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr ""
 
-#: cp/class.c:2799
+#: cp/class.c:2803
 #, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr ""
 
-#: cp/class.c:2861
+#: cp/class.c:2865
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was hidden"
 msgid "%qD was hidden"
 msgstr "%q+D telah disembunyikan"
 
-#: cp/class.c:2863
+#: cp/class.c:2867
 #, fuzzy, gcc-internal-format
 #| msgid "  by %q+D"
 msgid "  by %qD"
 msgstr "  oleh %q+D"
 
-#: cp/class.c:2896
+#: cp/class.c:2900
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D invalid; an anonymous union can only have non-static data members"
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "%q+#D tidak valid; sebuah anonymous union hanya dapat mempunnya anggota data tidak statis"
 
-#: cp/class.c:2906 cp/name-lookup.c:3293 cp/parser.c:19720
+#: cp/class.c:2910 cp/name-lookup.c:3293 cp/parser.c:19717
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
 
-#: cp/class.c:3097
+#: cp/class.c:3101
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr ""
 
-#: cp/class.c:3213
+#: cp/class.c:3217
 #, gcc-internal-format
 msgid "bit-field %q+#D with non-integral type"
 msgstr "bit-field %q+#D dengan tipe bukan integral"
 
-#: cp/class.c:3229
+#: cp/class.c:3233
 #, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr "bit-field %q+D lebar bukan sebuah konstanta integer"
 
-#: cp/class.c:3234
+#: cp/class.c:3238
 #, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr "lebar negatif dalam bit-field %q+D"
 
-#: cp/class.c:3239
+#: cp/class.c:3243
 #, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr "lebar nol untuk bit-field %q+D"
 
-#: cp/class.c:3249
+#: cp/class.c:3253
 #, fuzzy, gcc-internal-format
 #| msgid "width of %q+D exceeds its type"
 msgid "width of %qD exceeds its type"
 msgstr "lebar dari %q+D melebihi tipenya"
 
-#: cp/class.c:3255
+#: cp/class.c:3259
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is too small to hold all values of %q#T"
 msgid "%qD is too small to hold all values of %q#T"
 msgstr "%q+D terlalu kecil untuk menjaga seluruh nilai dari %q#T"
 
-#: cp/class.c:3316
+#: cp/class.c:3320
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr "anggota %q#D dengan konstruktor tidak diijinkan dalam union"
 
-#: cp/class.c:3319
+#: cp/class.c:3323
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr "anggota %q+#D dengan desktruktor tidak diijinkan dalam union"
 
-#: cp/class.c:3321
+#: cp/class.c:3325
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr "anggota %q+#D dengan penempatan salinan operator tidak diijinkan dalam union"
 
-#: cp/class.c:3325
+#: cp/class.c:3329
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/class.c:3453
+#: cp/class.c:3457
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D may not be static because it is a member of a union"
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr "%q+D mungkin bukan statis karena ini adalah anggota dari sebuah union"
 
-#: cp/class.c:3460
+#: cp/class.c:3464
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qD has Java class type"
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr "anggota data bukan statis %qD memiliki tipe kelas Java"
 
-#: cp/class.c:3470
+#: cp/class.c:3474
 #, gcc-internal-format
 msgid "field %q+D invalidly declared function type"
 msgstr "field %q+D secara tidak valid mendeklarasikan tipe fungsi"
 
-#: cp/class.c:3476
+#: cp/class.c:3480
 #, gcc-internal-format
 msgid "field %q+D invalidly declared method type"
 msgstr "field %q+D secara tidak valid mendeklrasikan tipe metoda"
 
-#: cp/class.c:3536
+#: cp/class.c:3540
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring packed attribute because of unpacked non-POD field %q+#D"
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr "mengabaikan atribut packed karena dari unpacked non-POD field %q+#D"
 
-#: cp/class.c:3585
+#: cp/class.c:3589
 #, fuzzy, gcc-internal-format
 #| msgid "non-member %qs cannot be declared %<mutable%>"
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr "bukan-anggota %qs tidak dapat dideklarasikan %<mutable%>"
 
-#: cp/class.c:3591
+#: cp/class.c:3595
 #, fuzzy, gcc-internal-format
 #| msgid "non-member %qs cannot be declared %<mutable%>"
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr "bukan-anggota %qs tidak dapat dideklarasikan %<mutable%>"
 
-#: cp/class.c:3617
+#: cp/class.c:3621
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr "multiple field dalam union %qT tida terinisialisasi"
 
-#: cp/class.c:3658
+#: cp/class.c:3662
 #, fuzzy, gcc-internal-format
 #| msgid "field %q+#D with same name as class"
 msgid "field %q#D with same name as class"
 msgstr "field %q+#D dengan nama sama seperti class"
 
-#: cp/class.c:3681
+#: cp/class.c:3685
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr "%q#T memiliki anggota data penunjuk"
 
-#: cp/class.c:3686
+#: cp/class.c:3690
 #, gcc-internal-format
 msgid "  but does not override %<%T(const %T&)%>"
 msgstr "  tetapi tidak override %<%T(const %T&)%>"
 
-#: cp/class.c:3688
+#: cp/class.c:3692
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr "  atau %<operator=(const %T&)%>"
 
-#: cp/class.c:3692
+#: cp/class.c:3696
 #, gcc-internal-format
 msgid "  but does not override %<operator=(const %T&)%>"
 msgstr "  tetapi tidak override %<operator=(const %T&)%>"
 
-#: cp/class.c:4097
+#: cp/class.c:4101
 #, gcc-internal-format
 msgid "alignment of %qD increased in -fabi-version=9 (GCC 5.2)"
 msgstr ""
 
-#: cp/class.c:4100
+#: cp/class.c:4104
 #, gcc-internal-format
 msgid "alignment of %qD will increase in -fabi-version=9"
 msgstr ""
 
-#: cp/class.c:4378
+#: cp/class.c:4382
 #, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "penginisialisasi dispesifikasikan untuk metode %q+D bukan virtual"
 
-#: cp/class.c:4813
+#: cp/class.c:4817
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr ""
 
-#: cp/class.c:4834
+#: cp/class.c:4838
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr ""
 
-#: cp/class.c:5350 cp/constexpr.c:237
+#: cp/class.c:5367 cp/constexpr.c:237
 #, gcc-internal-format
 msgid "enclosing class of %<constexpr%> non-static member function %q+#D is not a literal type"
 msgstr ""
 
-#: cp/class.c:5374
+#: cp/class.c:5391
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a class"
 msgid "%q+T is not literal because:"
 msgstr "%q#T bukan sebuah kelas"
 
-#: cp/class.c:5377
+#: cp/class.c:5394
 #, gcc-internal-format
 msgid "  %qT is a closure type, which is only literal in C++17 and later"
 msgstr ""
 
-#: cp/class.c:5380
+#: cp/class.c:5397
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "  %q+T has a non-trivial destructor"
 msgstr "kelas dasar %q#T memiliki desktruktor tidak virtual"
 
-#: cp/class.c:5387
+#: cp/class.c:5404
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no %<constexpr%> constructor that is not a copy or move constructor"
 msgstr ""
 
-#: cp/class.c:5420
+#: cp/class.c:5437
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "kelas dasar %q#T memiliki desktruktor tidak virtual"
 
-#: cp/class.c:5435
+#: cp/class.c:5452
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qD has Java class type"
 msgid "  non-static data member %qD has non-literal type"
 msgstr "anggota data bukan statis %qD memiliki tipe kelas Java"
 
-#: cp/class.c:5442
+#: cp/class.c:5459
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qD has Java class type"
 msgid "  non-static data member %qD has volatile type"
 msgstr "anggota data bukan statis %qD memiliki tipe kelas Java"
 
-#: cp/class.c:5561
+#: cp/class.c:5578
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "kelas dasar %q#T memiliki desktruktor tidak virtual"
 
-#: cp/class.c:5590
+#: cp/class.c:5607
 #, fuzzy, gcc-internal-format
 #| msgid "non-static reference %q+#D in class without a constructor"
 msgid "non-static reference %q#D in class without a constructor"
 msgstr "referensi bukan-statis %q+#D dalam kelas tanpa sebuah konstruktor"
 
-#: cp/class.c:5596
+#: cp/class.c:5613
 #, fuzzy, gcc-internal-format
 #| msgid "non-static const member %q+#D in class without a constructor"
 msgid "non-static const member %q#D in class without a constructor"
@@ -44860,166 +44904,166 @@
 
 #. If the function is defaulted outside the class, we just
 #. give the synthesis error.
-#: cp/class.c:5624
+#: cp/class.c:5641
 #, gcc-internal-format
 msgid "%q+D declared to take const reference, but implicit declaration would take non-const"
 msgstr ""
 
-#: cp/class.c:5898
+#: cp/class.c:5915
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr "direct base %qT tidak dapat diakses dalam %qT karena adanya ambigu"
 
-#: cp/class.c:5910
+#: cp/class.c:5927
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr "virtual base %qT tidak dapat diakses dalam %qT karena adanya ambigu"
 
-#: cp/class.c:6133
+#: cp/class.c:6150
 #, fuzzy, gcc-internal-format
 #| msgid "offset of %q+D is not ABI-compliant and may change in a future version of GCC"
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr "ofset dari %q+D adalah bukan ABI komplian dan mungkin berubah dalam versi GCC yang akan datang"
 
-#: cp/class.c:6291
+#: cp/class.c:6308
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr "ukuran dari array %qs adalah terlalu besar"
 
-#: cp/class.c:6576
+#: cp/class.c:6593
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of structure with flexible array member"
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr "penggunaan tidak valid dari struktur dengan anggota array fleksibel"
 
-#: cp/class.c:6578
+#: cp/class.c:6595
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of structure with flexible array member"
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr "penggunaan tidak valid dari struktur dengan anggota array fleksibel"
 
-#: cp/class.c:6583
+#: cp/class.c:6600
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "array member %q#D declared here"
 msgstr "  %q+#D dideklarasikan disini"
 
-#: cp/class.c:6610
+#: cp/class.c:6627
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member not at end of struct"
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr "%J anggota array fleksibel tidak diakhir dari struct"
 
-#: cp/class.c:6612
+#: cp/class.c:6629
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in otherwise empty struct"
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr "%J anggota array fleksibel dalam sebaliknya struct kosong"
 
-#: cp/class.c:6620 cp/class.c:6650
+#: cp/class.c:6637 cp/class.c:6667
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %q#T"
 msgid "in the definition of %q#T"
 msgstr "redefinisi dari %q#T"
 
-#: cp/class.c:6628
+#: cp/class.c:6645
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member not at end of struct"
 msgid "flexible array member %qD not at end of %q#T"
 msgstr "%J anggota array fleksibel tidak diakhir dari struct"
 
-#: cp/class.c:6630
+#: cp/class.c:6647
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in otherwise empty struct"
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr "%J anggota array fleksibel dalam sebaliknya struct kosong"
 
-#: cp/class.c:6648
+#: cp/class.c:6665
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "next member %q#D declared here"
 msgstr "  %q+#D dideklarasikan disini"
 
-#: cp/class.c:6760 cp/parser.c:23239
+#: cp/class.c:6777 cp/parser.c:23236
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "redefinisi dari %q#T"
 
-#: cp/class.c:6897
+#: cp/class.c:6914
 #, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "%q#T memiliki fungsi maya dan dapat diakses bukan virtual desktruktor"
 
-#: cp/class.c:6925
+#: cp/class.c:6942
 #, fuzzy, gcc-internal-format
 #| msgid "class %qT does not have any field named %qD"
 msgid "type transparent %q#T does not have any fields"
 msgstr "kelas %qT tidak memiliki field apapun bernama %qD"
 
-#: cp/class.c:6931
+#: cp/class.c:6948
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr ""
 
-#: cp/class.c:6935
+#: cp/class.c:6952
 #, fuzzy, gcc-internal-format
 #| msgid "type %qs has virtual member functions"
 msgid "type transparent class %qT has virtual functions"
 msgstr "tipe %qs memiliki anggota fungsi virtual"
 
-#: cp/class.c:6941
+#: cp/class.c:6958
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:7071
+#: cp/class.c:7088
 #, fuzzy, gcc-internal-format
 #| msgid "definition of %q#D is marked %<dllimport%>"
 msgid "definition of %qD does not match %<#include <initializer_list>%>"
 msgstr "definisi dari %q#D ditandai %<dllimport%>"
 
-#: cp/class.c:7082
+#: cp/class.c:7099
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr "mencoba menyelesaikan struct, tetapi ditendang keluar karena error parse sebelumnya"
 
-#: cp/class.c:7582
+#: cp/class.c:7599
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "bahasa string %<\"%E\"%> tidak dikenal"
 
-#: cp/class.c:7672
+#: cp/class.c:7689
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr "tidak dapat meresolf fungsi overloaded %qD berdasar dari konversi ke tipe %qT"
 
-#: cp/class.c:7817
+#: cp/class.c:7834
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr "tidak cocok mengubah fungsi %qD ke tipe %q#T"
 
-#: cp/class.c:7844
+#: cp/class.c:7861
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "mengubah fungsi overloaded %qD ke tipe %q#T adalah ambigu"
 
-#: cp/class.c:7870
+#: cp/class.c:7887
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "mengasumsikan penunjuk ke anggota %qD"
 
-#: cp/class.c:7873
+#: cp/class.c:7890
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(sebuah penunjuk ke anggota hanya dapat dibentuk dengan %<&%E%>)"
 
-#: cp/class.c:7948 cp/class.c:7990
+#: cp/class.c:7965 cp/class.c:8007
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "tidak cukup informasi mengenai tipe"
 
-#: cp/class.c:7968
+#: cp/class.c:7985
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "tidak dapat mengubah %qE dari tipe %qT ke tipe %qT"
@@ -45029,12 +45073,12 @@
 #. A name N used in a class S shall refer to the same declaration
 #. in its context and when re-evaluated in the completed scope of
 #. S.
-#: cp/class.c:8235
+#: cp/class.c:8252
 #, gcc-internal-format
 msgid "declaration of %q#D"
 msgstr "deklarasi dari %q#D"
 
-#: cp/class.c:8237
+#: cp/class.c:8254
 #, fuzzy, gcc-internal-format
 #| msgid "changes meaning of %qD from %q+#D"
 msgid "changes meaning of %qD from %q#D"
@@ -45480,17 +45524,17 @@
 msgid "unexpected AST of kind %s"
 msgstr "Tidak terduga akhir dari berkas dalam '%s'"
 
-#: cp/cp-gimplify.c:1415
+#: cp/cp-gimplify.c:1416
 #, gcc-internal-format
 msgid "throw will always call terminate()"
 msgstr ""
 
-#: cp/cp-gimplify.c:1418
+#: cp/cp-gimplify.c:1419
 #, gcc-internal-format
 msgid "in C++11 destructors default to noexcept"
 msgstr ""
 
-#: cp/cp-gimplify.c:1429
+#: cp/cp-gimplify.c:1430
 #, gcc-internal-format
 msgid "in C++11 this throw will terminate because destructors default to noexcept"
 msgstr ""
@@ -45951,7 +45995,7 @@
 msgid "redeclaration %qD differs in %<constexpr%> from previous declaration"
 msgstr "menggunakan deklarasi %q+D konflik dengan deklarasi sebelumnya"
 
-#: cp/decl.c:1304 cp/decl.c:13843
+#: cp/decl.c:1304 cp/decl.c:13867
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D"
 msgid "previous declaration %qD"
@@ -46320,7 +46364,7 @@
 msgid "  enters OpenMP structured block"
 msgstr "  memasuki blok terstruktur OpenMP"
 
-#: cp/decl.c:3434 cp/parser.c:12366 cp/parser.c:12387
+#: cp/decl.c:3434 cp/parser.c:12363 cp/parser.c:12384
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr "exit tidak valid dari blok struktur OpenMP"
@@ -46330,7 +46374,7 @@
 msgid "%qD is not a type"
 msgstr "%qD bukan sebuah tipe"
 
-#: cp/decl.c:3838 cp/parser.c:6366
+#: cp/decl.c:3838 cp/parser.c:6369
 #, gcc-internal-format
 msgid "%qD used without template parameters"
 msgstr "%qD digunakan tanpa parameter template"
@@ -46739,8 +46783,8 @@
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.c:6011 cp/decl.c:6234 cp/typeck2.c:1310 cp/typeck2.c:1590
-#: cp/typeck2.c:1638 cp/typeck2.c:1685
+#: cp/decl.c:6011 cp/decl.c:6234 cp/typeck2.c:1310 cp/typeck2.c:1593
+#: cp/typeck2.c:1641 cp/typeck2.c:1688
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "terlalu banyak penginisialisasi untuk %qT"
@@ -46819,13 +46863,13 @@
 msgid "assignment (not initialization) in declaration"
 msgstr "penempatan (tidak terinisialisasi) dalam deklarasi"
 
-#: cp/decl.c:6873 cp/decl.c:12605
+#: cp/decl.c:6873 cp/decl.c:12629
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C++ tidak mengijinkan designated penginisialisasi"
 
-#: cp/decl.c:6877 cp/decl.c:12609
+#: cp/decl.c:6877 cp/decl.c:12633
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for %qs"
 msgid "%<register%> storage class specifier used"
@@ -46852,46 +46896,46 @@
 msgid "function %q#D is initialized like a variable"
 msgstr "fungsi %q#D telah dinisialisasi seperti sebuah variabel"
 
-#: cp/decl.c:7329
+#: cp/decl.c:7350
 #, fuzzy, gcc-internal-format
 #| msgid "  cannot use obsolete binding at %q+D because it has a destructor"
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "  tidak dapat menggunakan obsolete binding di %q+D karena ini memiliki sebuah desktruktor"
 
-#: cp/decl.c:7332
+#: cp/decl.c:7353
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.c:7339
+#: cp/decl.c:7360
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is an inaccessible base of %qT"
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "%qT adalah sebuah dasar tidak dapat diakses dari %qT"
 
-#: cp/decl.c:7365
+#: cp/decl.c:7386
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:7374
+#: cp/decl.c:7395
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:7592
+#: cp/decl.c:7613
 #, fuzzy, gcc-internal-format
 #| msgid "cannot increment a pointer to incomplete type %qT"
 msgid "structured binding refers to incomplete type %qT"
 msgstr "tidak dapat meningkatkan sebuah penunjuk ke tipe tidak lengkap %qT"
 
-#: cp/decl.c:7608
+#: cp/decl.c:7629
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable length array %qs"
 msgid "cannot decompose variable length array %qT"
 msgstr "ISO C90 melarang array dengan panjang bervariabel %qs"
 
-#: cp/decl.c:7617 cp/decl.c:7702
+#: cp/decl.c:7638 cp/decl.c:7723
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%Hinitializer provided for function"
 msgid "%u name provided for structured binding"
@@ -46899,7 +46943,7 @@
 msgstr[0] "%Hpenginisialisasi disediakan untuk fungsi"
 msgstr[1] "%Hpenginisialisasi disediakan untuk fungsi"
 
-#: cp/decl.c:7621
+#: cp/decl.c:7642
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
@@ -46906,7 +46950,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:7624
+#: cp/decl.c:7645
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
@@ -46913,962 +46957,962 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:7669
+#: cp/decl.c:7690
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to %q#T"
 msgid "cannot decompose variable length vector %qT"
 msgstr "tidak dapat mendeklarasikan penunjuk ke %q#T"
 
-#: cp/decl.c:7695
+#: cp/decl.c:7716
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "ukuran dari array bukan sebuah integral konstan ekspresi"
 
-#: cp/decl.c:7704
+#: cp/decl.c:7725
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.c:7725
+#: cp/decl.c:7746
 #, fuzzy, gcc-internal-format
 #| msgid "initialization string truncated to match variable at %L"
 msgid "in initialization of structured binding variable %qD"
 msgstr "inisialisasi dari string terpotong untuk mencocokan dengan variabel di %L"
 
-#: cp/decl.c:7751
+#: cp/decl.c:7772
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %s to qualified function type %qT"
 msgid "cannot decompose union type %qT"
 msgstr "tidak dapat mendeklarasikan %s untuk fungsi yang dikualifikasikan dengan tipe %qT"
 
-#: cp/decl.c:7756
+#: cp/decl.c:7777
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "membuat penunjuk ke anggota dari tipe bukan kelas %qT"
 
-#: cp/decl.c:7761
+#: cp/decl.c:7782
 #, fuzzy, gcc-internal-format
 #| msgid "cannot decompose address"
 msgid "cannot decompose lambda closure type %qT"
 msgstr "tidak dapat menguraikan alamat"
 
-#: cp/decl.c:7765
+#: cp/decl.c:7786
 #, fuzzy, gcc-internal-format
 #| msgid "cannot increment a pointer to incomplete type %qT"
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "tidak dapat meningkatkan sebuah penunjuk ke tipe tidak lengkap %qT"
 
-#: cp/decl.c:7774
+#: cp/decl.c:7795
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply %<offsetof%> to static data member %qD"
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "tidak dapat menjalankan %<offsetof%> ke anggota data statis %qD"
 
-#: cp/decl.c:8213
+#: cp/decl.c:8234
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:8216
+#: cp/decl.c:8237
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:8222
+#: cp/decl.c:8243
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:8450
+#: cp/decl.c:8471
 #, fuzzy, gcc-internal-format
 #| msgid "initializer fails to determine size of %qD"
 msgid "initializer fails to determine size of %qT"
 msgstr "penginisialisasi gagal untuk menentukan ukuran dari %qD"
 
-#: cp/decl.c:8454
+#: cp/decl.c:8475
 #, fuzzy, gcc-internal-format
 #| msgid "array size missing in %qD"
 msgid "array size missing in %qT"
 msgstr "ukuran array hilang dalam %qD"
 
-#: cp/decl.c:8457
+#: cp/decl.c:8478
 #, fuzzy, gcc-internal-format
 #| msgid "zero-size array %qD"
 msgid "zero-size array %qT"
 msgstr "array berukuran-nol %qD"
 
-#: cp/decl.c:8473
+#: cp/decl.c:8494
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "desktruktor untuk alien kelas %qT tidak dapat berupa sebuah anggota"
 
-#: cp/decl.c:8475
+#: cp/decl.c:8496
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "konstruktor untuk alien kelas %qT tidak dapt berupa sebuah anggota"
 
-#: cp/decl.c:8499
+#: cp/decl.c:8520
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD dideklarasikan sebagai sebuah %<virtual%> %s"
 
-#: cp/decl.c:8501
+#: cp/decl.c:8522
 #, fuzzy, gcc-internal-format
 #| msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "%<const%> dan %<volatile%> fungsi penspesifikasi di %qD tidak valid dalam %s deklarasi"
 
-#: cp/decl.c:8506
+#: cp/decl.c:8527
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD dideklarasikan sebagai sebuah %<virtual%> %s"
 
-#: cp/decl.c:8508
+#: cp/decl.c:8529
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD dideklarasikan sebagai sebuah %<inline%> %s"
 
-#: cp/decl.c:8510
+#: cp/decl.c:8531
 #, fuzzy, gcc-internal-format
 #| msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "%<const%> dan %<volatile%> fungsi penspesifikasi di %qD tidak valid dalam %s deklarasi"
 
-#: cp/decl.c:8515
+#: cp/decl.c:8536
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD dideklarasikan sebagai sebuah %<virtual%> %s"
 
-#: cp/decl.c:8517
+#: cp/decl.c:8538
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD dideklarasikan sebagai sebuah %<inline%> %s"
 
-#: cp/decl.c:8519
+#: cp/decl.c:8540
 #, fuzzy, gcc-internal-format
 #| msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "%<const%> dan %<volatile%> fungsi penspesifikasi di %qD tidak valid dalam %s deklarasi"
 
-#: cp/decl.c:8524
+#: cp/decl.c:8545
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a %<virtual%> %s"
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD dideklarasikan sebagai sebuah %<virtual%> %s"
 
-#: cp/decl.c:8526
+#: cp/decl.c:8547
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as an %<inline%> %s"
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD dideklarasikan sebagai sebuah %<inline%> %s"
 
-#: cp/decl.c:8528
+#: cp/decl.c:8549
 #, fuzzy, gcc-internal-format
 #| msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in %s declaration"
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "%<const%> dan %<volatile%> fungsi penspesifikasi di %qD tidak valid dalam %s deklarasi"
 
-#: cp/decl.c:8535
+#: cp/decl.c:8556
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D dideklarasikan sebagai sebuah friend"
 
-#: cp/decl.c:8542
+#: cp/decl.c:8563
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D dideklarasikan dengan spesifikasi eksepsi"
 
-#: cp/decl.c:8574
+#: cp/decl.c:8595
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "definisi dari %qD tidak dalam namespace melingkupi %qT"
 
-#: cp/decl.c:8614
+#: cp/decl.c:8635
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "anggota fungsi statis %q#D dideklarasikan dengan tipe pengkualifikasi"
 
-#: cp/decl.c:8624
+#: cp/decl.c:8645
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a non-parameter"
 msgid "concept %q#D declared with function parameters"
 msgstr "%q+D dideklarasikan sebagai sebuah bukan-parameter"
 
-#: cp/decl.c:8630
+#: cp/decl.c:8651
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %q+D declared with void type"
 msgid "concept %q#D declared with a deduced return type"
 msgstr "parameter %q+D dideklarasikan dengan tipe void"
 
-#: cp/decl.c:8632
+#: cp/decl.c:8653
 #, fuzzy, gcc-internal-format
 #| msgid "Java method %qD has non-Java return type %qT"
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "metoda Java %qD memiliki tipe kembali %qT bukan Java"
 
-#: cp/decl.c:8703
+#: cp/decl.c:8724
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "concept %qD has no definition"
 msgstr "deklarasi dari %qD sebagai bukan fungsi"
 
-#: cp/decl.c:8772
+#: cp/decl.c:8793
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "mendifinisikan eksplisit spesialisasi %qD dalam deklarasi friend"
 
 #. Something like `template <class T> friend void f<T>()'.
-#: cp/decl.c:8782
+#: cp/decl.c:8803
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "penggunaan tidak valid dari template-id %qD dalam deklarasi dari primary template"
 
-#: cp/decl.c:8800
+#: cp/decl.c:8821
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "argumen baku tidak diijinkan dalam deklarasi dari spesialisasi template friend %qD"
 
-#: cp/decl.c:8808
+#: cp/decl.c:8829
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "%<inline%> tidak diijinkan dalam deklarasi dari spesialisasi template friend %qD"
 
-#: cp/decl.c:8857
+#: cp/decl.c:8878
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "tidak dapat mendeklarasikan %<::main%> untuk menjadi sebuah template"
 
-#: cp/decl.c:8859
+#: cp/decl.c:8880
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "tidak dapat mendeklarasikan %<::main%> untuk menjadi inline"
 
-#: cp/decl.c:8861
+#: cp/decl.c:8882
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be inline"
 msgid "cannot declare %<::main%> to be %<constexpr%>"
 msgstr "tidak dapat mendeklarasikan %<::main%> untuk menjadi inline"
 
-#: cp/decl.c:8863
+#: cp/decl.c:8884
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "tidak dapat mendeklarasikan %<::main%> untuk menjadi statis"
 
-#: cp/decl.c:8920
+#: cp/decl.c:8941
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "anggota fungsi statis %qD tidak dapat memiliki cv kualifier"
 
-#: cp/decl.c:8921
+#: cp/decl.c:8942
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "fungsi bukan-anggota %qD tidak dapat memiliki cv-kualifier"
 
-#: cp/decl.c:8929
+#: cp/decl.c:8950
 #, fuzzy, gcc-internal-format
 #| msgid "static member function %qD cannot have cv-qualifier"
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "anggota fungsi statis %qD tidak dapat memiliki cv kualifier"
 
-#: cp/decl.c:8930
+#: cp/decl.c:8951
 #, fuzzy, gcc-internal-format
 #| msgid "non-member function %qD cannot have cv-qualifier"
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "fungsi bukan-anggota %qD tidak dapat memiliki cv-kualifier"
 
-#: cp/decl.c:8940
+#: cp/decl.c:8961
 #, fuzzy, gcc-internal-format
 #| msgid "%qD may not be declared within a namespace"
 msgid "deduction guide %qD must be declared at namespace scope"
 msgstr "%qD mungkin tidak dideklarasikan dalam sebuah namespace"
 
-#: cp/decl.c:8946
+#: cp/decl.c:8967
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "deduction guide %qD must not have a function body"
 msgstr "deklarasi dari %qD sebagai bukan fungsi"
 
-#: cp/decl.c:8959
+#: cp/decl.c:8980
 #, fuzzy, gcc-internal-format
 #| msgid "%Htemplate with C linkage"
 msgid "literal operator with C linkage"
 msgstr "%Htemplate dengan C linkage"
 
-#: cp/decl.c:8969
+#: cp/decl.c:8990
 #, fuzzy, gcc-internal-format
 #| msgid "invalid option argument %qs"
 msgid "%qD has invalid argument list"
 msgstr "pilihan argumen %qs tidak valid"
 
-#: cp/decl.c:8977
+#: cp/decl.c:8998
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:8983
+#: cp/decl.c:9004
 #, gcc-internal-format
 msgid "floating point suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:8991
+#: cp/decl.c:9012
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/decl.c:8996
+#: cp/decl.c:9017
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must be a nonstatic member function"
 msgid "%qD must be a non-member function"
 msgstr "%qD harus berupa sebuah anggota fungsi tidak statis"
 
-#: cp/decl.c:9076
+#: cp/decl.c:9097
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> harus kembali %<int%>"
 
-#: cp/decl.c:9116
+#: cp/decl.c:9137
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "definisi dari secara implisit dideklarasikan %qD"
 
-#: cp/decl.c:9121
+#: cp/decl.c:9142
 #, fuzzy, gcc-internal-format
 #| msgid "definition of implicitly-declared %qD"
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "definisi dari secara implisit dideklarasikan %qD"
 
-#: cp/decl.c:9123
+#: cp/decl.c:9144
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously defined here"
 msgid "%q#D explicitly defaulted here"
 msgstr "%q+#D sebelumnya didefinisikan disini"
 
-#: cp/decl.c:9140
+#: cp/decl.c:9161
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "bukan %q#D anggota fungsi dideklarasikan dalam kelas %qT"
 
-#: cp/decl.c:9329
+#: cp/decl.c:9350
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be a template"
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "tidak dapat mendeklarasikan %<::main%> untuk menjadi sebuah template"
 
-#: cp/decl.c:9337
+#: cp/decl.c:9358
 #, fuzzy, gcc-internal-format
 #| msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "variabel otomatis %qE tidak dapat berupa %<threadprivate%>"
 
-#: cp/decl.c:9344
+#: cp/decl.c:9365
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.c:9464
+#: cp/decl.c:9485
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "tidak valid dalam kelas penginisialisasian dari anggota data statis dari tipe bukan integral %qT"
 
-#: cp/decl.c:9468
+#: cp/decl.c:9489
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "tidak valid dalam kelas penginisialisasian dari anggota data statis dari tipe bukan integral %qT"
 
-#: cp/decl.c:9472
+#: cp/decl.c:9493
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "tidak valid dalam kelas penginisialisasian dari anggota data statis dari tipe bukan integral %qT"
 
-#: cp/decl.c:9486
+#: cp/decl.c:9507
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "tidak valid dalam kelas penginisialisasian dari anggota data statis dari tipe bukan integral %qT"
 
-#: cp/decl.c:9493
+#: cp/decl.c:9514
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ISO C++ melarang dalam kelas inisialisasi dari anggota statis bukan const %qD"
 
-#: cp/decl.c:9498
+#: cp/decl.c:9519
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO C++ melarang inisialisasi dari anggota constant %qD dari bukan integral tipe %qT"
 
-#: cp/decl.c:9598
+#: cp/decl.c:9619
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "ukuran dari array %qD memiliki tipe bukan integral %qT"
 
-#: cp/decl.c:9600
+#: cp/decl.c:9621
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "ukuran dari array memiliki tipe %qT bukan integral"
 
-#: cp/decl.c:9630 cp/decl.c:9680
+#: cp/decl.c:9651 cp/decl.c:9701
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "ukuran dari array bukan sebuah integral konstan ekspresi"
 
-#: cp/decl.c:9646
+#: cp/decl.c:9667
 #, gcc-internal-format
 msgid "size of array %qD is negative"
 msgstr "ukuran dari array %qD negatif"
 
-#: cp/decl.c:9648 cp/init.c:3651
+#: cp/decl.c:9669 cp/init.c:3667
 #, gcc-internal-format
 msgid "size of array is negative"
 msgstr "ukuran dari array negatif"
 
-#: cp/decl.c:9662
+#: cp/decl.c:9683
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C++ melarang array berukuran-nol %qD"
 
-#: cp/decl.c:9664
+#: cp/decl.c:9685
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++ melarang array berukuran-nol"
 
-#: cp/decl.c:9677
+#: cp/decl.c:9698
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "ukuran dari array %qD bukan sebuah integral konstan-ekspresi"
 
-#: cp/decl.c:9686
+#: cp/decl.c:9707
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++ melarang array dengan variabel panjang %qD"
 
-#: cp/decl.c:9688
+#: cp/decl.c:9709
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++ melarang array dengan variabel panjang"
 
-#: cp/decl.c:9694
+#: cp/decl.c:9715
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr "array dengan panjang bervariabel  %qD digunakan"
 
-#: cp/decl.c:9697
+#: cp/decl.c:9718
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr "array dengan panjang bervariabel digunakan"
 
-#: cp/decl.c:9746
+#: cp/decl.c:9767
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "overflow dalam dimensi array"
 
-#: cp/decl.c:9799
+#: cp/decl.c:9820
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "%qD declared as array of %qT"
 msgstr "%q+D dideklarasikan sebagai sebuah friend"
 
-#: cp/decl.c:9809
+#: cp/decl.c:9830
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of voids"
 msgid "declaration of %qD as array of void"
 msgstr "deklarasi dari %qs sebagai dari voids"
 
-#: cp/decl.c:9811
+#: cp/decl.c:9832
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of %qT"
 msgid "creating array of void"
 msgstr "membuat array dari %qT"
 
-#: cp/decl.c:9816
+#: cp/decl.c:9837
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of %qD as array of functions"
 msgstr "deklarasi dari %qs sebagai array dari fungsi"
 
-#: cp/decl.c:9818
+#: cp/decl.c:9839
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of %qT"
 msgid "creating array of functions"
 msgstr "membuat array dari %qT"
 
-#: cp/decl.c:9823
+#: cp/decl.c:9844
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of %qD as array of references"
 msgstr "deklarasi dari %qs sebagai array dari fungsi"
 
-#: cp/decl.c:9825
+#: cp/decl.c:9846
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of %qT"
 msgid "creating array of references"
 msgstr "membuat array dari %qT"
 
-#: cp/decl.c:9830
+#: cp/decl.c:9851
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "declaration of %qD as array of function members"
 msgstr "deklarasi dari %qs sebagai array dari fungsi"
 
-#: cp/decl.c:9832
+#: cp/decl.c:9853
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qs as array of functions"
 msgid "creating array of function members"
 msgstr "deklarasi dari %qs sebagai array dari fungsi"
 
-#: cp/decl.c:9846
+#: cp/decl.c:9867
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "deklarasi dari %qD sebagai array multidimensi harus memiliki batasan untuk seluruh dimensi kecuali yang pertama"
 
-#: cp/decl.c:9850
+#: cp/decl.c:9871
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "array multidimensi harus memiliki batasan untuk seluruh dimensi kecuali yang pertama"
 
-#: cp/decl.c:9909
+#: cp/decl.c:9930
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "spesifikasi tipe kembali untuk konstruktor tidak valid"
 
-#: cp/decl.c:9912
+#: cp/decl.c:9933
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "kualifier tidak diijinkan dalam deklarasi dari %<operator %T%>"
 
-#: cp/decl.c:9922
+#: cp/decl.c:9943
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "spesifikasi tipe kembali untuk desktruktor tidak valid"
 
-#: cp/decl.c:9925
+#: cp/decl.c:9946
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "kualifier tidak diijinkan dalam deklarasi dari %<operator %T%>"
 
-#: cp/decl.c:9937
+#: cp/decl.c:9958
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "tipe kembali yang dispesifikasikan untuk %<operator %T%>"
 
-#: cp/decl.c:9940
+#: cp/decl.c:9961
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "kualifier tidak diijinkan dalam deklarasi dari %<operator %T%>"
 
-#: cp/decl.c:9948
+#: cp/decl.c:9969
 #, fuzzy, gcc-internal-format
 #| msgid "return type specification for destructor invalid"
 msgid "return type specified for deduction guide"
 msgstr "spesifikasi tipe kembali untuk desktruktor tidak valid"
 
-#: cp/decl.c:9951
+#: cp/decl.c:9972
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "kualifier tidak diijinkan dalam deklarasi dari %<operator %T%>"
 
-#: cp/decl.c:9955
+#: cp/decl.c:9976
 #, fuzzy, gcc-internal-format
 #| msgid "too many template parameter lists in declaration of %qD"
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "terlalu banyak daftar parameter template dalam deklarasi dari %qD"
 
-#: cp/decl.c:9964
+#: cp/decl.c:9985
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting specifiers in declaration of %qs"
 msgid "decl-specifier in declaration of deduction guide"
 msgstr "penspesifikasi konflik dalam deklarasi dari %qs"
 
-#: cp/decl.c:9985
+#: cp/decl.c:10006
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "variabel tidak bernama atau field dideklarasikan void"
 
-#: cp/decl.c:9992
+#: cp/decl.c:10013
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "variabel atau field dideklarasikan void"
 
-#: cp/decl.c:10007
+#: cp/decl.c:10028
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "%<inline%> penspesifikasi tidak valid untuk fungsi %qs dideklarasikan diluar dari lingkup global"
 
-#: cp/decl.c:10013
+#: cp/decl.c:10034
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "inline variables are only available with -std=c++17 or -std=gnu++17"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/decl.c:10268
+#: cp/decl.c:10292
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "penggunaan tidak valid dari nama kualifikasi %<::%D%>"
 
-#: cp/decl.c:10271 cp/decl.c:10291
+#: cp/decl.c:10295 cp/decl.c:10315
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "penggunaan tidak valid dari nama kualifikasi %<%T::%D%>"
 
-#: cp/decl.c:10274
+#: cp/decl.c:10298
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "penggunaan tidak valid dari nama kualifikasi %<%D::%D%>"
 
-#: cp/decl.c:10283
+#: cp/decl.c:10307
 #, gcc-internal-format
 msgid "%q#T is not a class or a namespace"
 msgstr "%q#T bukan sebuah kelas atau ruang nama"
 
-#: cp/decl.c:10305 cp/decl.c:10398 cp/decl.c:10407 cp/decl.c:11970
+#: cp/decl.c:10329 cp/decl.c:10422 cp/decl.c:10431 cp/decl.c:11994
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "deklarasi dari %qD sebagai bukan fungsi"
 
-#: cp/decl.c:10311
+#: cp/decl.c:10335
 #, gcc-internal-format
 msgid "declaration of %qD as non-member"
 msgstr "deklarasi dari %qD sebagai bukan anggota"
 
-#: cp/decl.c:10339
+#: cp/decl.c:10363
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "id pendeklarasi hilang; menggunaka kata reserved %qD"
 
-#: cp/decl.c:10390
+#: cp/decl.c:10414
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "definisi fungsi tidak mendeklarasikan parameter"
 
-#: cp/decl.c:10415
+#: cp/decl.c:10439
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as %s"
 msgid "declaration of %qD as %<typedef%>"
 msgstr "deklarasi dari %qD sebagai %s"
 
-#: cp/decl.c:10420
+#: cp/decl.c:10444
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of %qD as parameter"
 msgstr "deklarasi dari %q+D membayangi sebuah parameter"
 
-#: cp/decl.c:10454
+#: cp/decl.c:10478
 #, fuzzy, gcc-internal-format
 #| msgid "%<[*]%> not in a declaration"
 msgid "%<concept%> cannot appear in a typedef declaration"
 msgstr "%<[*]%> tidak dalam sebuah deklarasi"
 
-#: cp/decl.c:10460
+#: cp/decl.c:10484
 #, fuzzy, gcc-internal-format
 #| msgid "%Ha template-id may not appear in a using-declaration"
 msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgstr "%Hsebuah template-id mungkin tidak muncul dalam sebuah using deklarasi"
 
-#: cp/decl.c:10468
+#: cp/decl.c:10492
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "dua atau lebih tipe data dalam deklarasi dari %qs"
 
-#: cp/decl.c:10474
+#: cp/decl.c:10498
 #, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr "penspesifikasi konflik dalam deklarasi dari %qs"
 
-#: cp/decl.c:10515
+#: cp/decl.c:10539
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C tidak mendukung plain %<complex%> yang berarti %<double complex%>"
 
-#: cp/decl.c:10564 cp/decl.c:10567 cp/decl.c:10570
+#: cp/decl.c:10588 cp/decl.c:10591 cp/decl.c:10594
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ melarang deklarasi dari %qs dengan tidak ada tipe"
 
-#: cp/decl.c:10586
+#: cp/decl.c:10610
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_saveregs not supported by this target"
 msgid "%<__int%d%> is not supported by this target"
 msgstr "__builtin_saveregs tidak didukung oleh target ini"
 
-#: cp/decl.c:10592
+#: cp/decl.c:10616
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ 1998 does not support %<long long%>"
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ 1998 tidak mendukung %<long long%>"
 
-#: cp/decl.c:10614 cp/decl.c:10634
+#: cp/decl.c:10638 cp/decl.c:10658
 #, gcc-internal-format
 msgid "%<signed%> or %<unsigned%> invalid for %qs"
 msgstr "%<signed%> atau %<unsigned%> tidak valid untuk %qs"
 
-#: cp/decl.c:10616
+#: cp/decl.c:10640
 #, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgstr "%<signed%> dan %<unsigned%> dispesifikasikan bersama untuk %qs"
 
-#: cp/decl.c:10618
+#: cp/decl.c:10642
 #, gcc-internal-format
 msgid "%<long long%> invalid for %qs"
 msgstr "%<long long%> tidak valid untuk %qs"
 
-#: cp/decl.c:10620
+#: cp/decl.c:10644
 #, gcc-internal-format
 msgid "%<long%> invalid for %qs"
 msgstr "%<long%> tidak valid untuk %qs"
 
-#: cp/decl.c:10622
+#: cp/decl.c:10646
 #, gcc-internal-format
 msgid "%<short%> invalid for %qs"
 msgstr "%<short%> tidak valid untuk %qs"
 
-#: cp/decl.c:10624
+#: cp/decl.c:10648
 #, gcc-internal-format
 msgid "%<long%> or %<short%> invalid for %qs"
 msgstr "%<long%> atau %<short%> tidak valid untuk %qs"
 
-#: cp/decl.c:10626
+#: cp/decl.c:10650
 #, fuzzy, gcc-internal-format
 #| msgid "%<long%> or %<short%> invalid for %qs"
 msgid "%<long%>, %<int%>, %<short%>, or %<char%> invalid for %qs"
 msgstr "%<long%> atau %<short%> tidak valid untuk %qs"
 
-#: cp/decl.c:10628
+#: cp/decl.c:10652
 #, gcc-internal-format
 msgid "%<long%> or %<short%> specified with char for %qs"
 msgstr "%<long%> atau %<short%> dispesifikasikan dengan char untuk %qs"
 
-#: cp/decl.c:10630
+#: cp/decl.c:10654
 #, gcc-internal-format
 msgid "%<long%> and %<short%> specified together for %qs"
 msgstr "%<long%> dan %<short%> dispesifikasikan bersama untuk %qs"
 
-#: cp/decl.c:10636
+#: cp/decl.c:10660
 #, gcc-internal-format
 msgid "%<short%> or %<long%> invalid for %qs"
 msgstr "%<short%> atau %<long%> tidak valid untuk %qs"
 
-#: cp/decl.c:10644
+#: cp/decl.c:10668
 #, gcc-internal-format
 msgid "long, short, signed or unsigned used invalidly for %qs"
 msgstr "long, short, signed, atau unsigned digunakan secara tidak valid untuk %qs"
 
-#: cp/decl.c:10712
+#: cp/decl.c:10736
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "kompleks tidak valid untuk %qs"
 
-#: cp/decl.c:10751
+#: cp/decl.c:10775
 #, gcc-internal-format
 msgid "template placeholder type %qT must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.c:10769
+#: cp/decl.c:10793
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "anggota %qD tidak dapat dideklarasikan baik virtual dan statis"
 
-#: cp/decl.c:10775
+#: cp/decl.c:10799
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD cannot be declared both %<virtual%> and %<constexpr%>"
 msgstr "anggota %qD tidak dapat dideklarasikan baik virtual dan statis"
 
-#: cp/decl.c:10785
+#: cp/decl.c:10809
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "type deklarasi tidak valid dalam parameter deklarasi"
 
-#: cp/decl.c:10790
+#: cp/decl.c:10814
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for parameter %qs"
 msgid "storage class specified for template parameter %qs"
 msgstr "class penyimpanan dispesifikasikan untuk parameter %qs"
 
-#: cp/decl.c:10796
+#: cp/decl.c:10820
 #, gcc-internal-format
 msgid "storage class specifiers invalid in parameter declarations"
 msgstr "penspesifikasi kelas penyimpanan dalam parameter deklarasi"
 
-#: cp/decl.c:10800
+#: cp/decl.c:10824
 #, fuzzy, gcc-internal-format
 #| msgid "parameter declared %<auto%>"
 msgid "a parameter cannot be declared %<concept%>"
 msgstr "parameter dideklarasikan %<auto%>"
 
-#: cp/decl.c:10805
+#: cp/decl.c:10829
 #, fuzzy, gcc-internal-format
 #| msgid "parameter declared %<auto%>"
 msgid "a parameter cannot be declared %<constexpr%>"
 msgstr "parameter dideklarasikan %<auto%>"
 
-#: cp/decl.c:10815
+#: cp/decl.c:10839
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "%<virtual%> diluar deklarasi kelas"
 
-#: cp/decl.c:10825
+#: cp/decl.c:10849
 #, fuzzy, gcc-internal-format
 #| msgid "Warn when an inlined function cannot be inlined"
 msgid "structured binding declaration cannot be %<inline%>"
 msgstr "Peringatkan ketika sebuah fungsi inline tidak dapat diinline"
 
-#: cp/decl.c:10828
+#: cp/decl.c:10852
 #, fuzzy, gcc-internal-format
 #| msgid "function definition declared %<typedef%>"
 msgid "structured binding declaration cannot be %<typedef%>"
 msgstr "definisi fungsi dideklarasikan %<typedef%>"
 
-#: cp/decl.c:10830
+#: cp/decl.c:10854
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<constexpr%>"
 msgstr ""
 
-#: cp/decl.c:10834
+#: cp/decl.c:10858
 #, fuzzy, gcc-internal-format
 #| msgid "attribute ignored in declaration of %q+#T"
 msgid "structured binding declaration cannot be %qs"
 msgstr "atribut diabaikan dalam deklarasi dari %q+#T"
 
-#: cp/decl.c:10839
+#: cp/decl.c:10863
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<concept%>"
 msgstr ""
 
-#: cp/decl.c:10845
+#: cp/decl.c:10869
 #, fuzzy, gcc-internal-format
 #| msgid "subscripting array declared %<register%>"
 msgid "structured binding declaration cannot be %<register%>"
 msgstr "subscripting array dideklarasikan %<register%>"
 
-#: cp/decl.c:10849
+#: cp/decl.c:10873
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<static%>"
 msgstr ""
 
-#: cp/decl.c:10853
+#: cp/decl.c:10877
 #, fuzzy, gcc-internal-format
 #| msgid "nested function %qs declared %<extern%>"
 msgid "structured binding declaration cannot be %<extern%>"
 msgstr "fungsi nested %qs dideklarasikan %<extern%>"
 
-#: cp/decl.c:10857
+#: cp/decl.c:10881
 #, fuzzy, gcc-internal-format
 #| msgid "function %qs cannot be declared %<mutable%>"
 msgid "structured binding declaration cannot be %<mutable%>"
 msgstr "fungsi %qs tidak dapat dideklarasikan %<mutable%>"
 
-#: cp/decl.c:10861
+#: cp/decl.c:10885
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10872
+#: cp/decl.c:10896
 #, fuzzy, gcc-internal-format
 #| msgid "attribute ignored in declaration of %q+#T"
 msgid "structured binding declaration cannot have type %qT"
 msgstr "atribut diabaikan dalam deklarasi dari %q+#T"
 
-#: cp/decl.c:10875
+#: cp/decl.c:10899
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10906
+#: cp/decl.c:10930
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "multiple storage kelas dalam deklarasi dari %qs"
 
-#: cp/decl.c:10929
+#: cp/decl.c:10953
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "kelas penyimpanan dispesifikasikan untuk %qs"
 
-#: cp/decl.c:10933
+#: cp/decl.c:10957
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "class penyimpanan dispesifikasikan untuk parameter %qs"
 
-#: cp/decl.c:10946
+#: cp/decl.c:10970
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "fungsi nested %qs dideklarasikan %<extern%>"
 
-#: cp/decl.c:10950
+#: cp/decl.c:10974
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "top-level deklarasi dari %qs menspesifikasikan %<auto%>"
 
-#: cp/decl.c:10957
+#: cp/decl.c:10981
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "lingkup-fungsi %qs secara implisit auto dan dideklarasikan %<__thread%>"
 
-#: cp/decl.c:10969
+#: cp/decl.c:10993
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "spesifikasi kelas penyimpanan tidak valid dalam deklarasi fungsi friend"
 
-#: cp/decl.c:11050
+#: cp/decl.c:11074
 #, fuzzy, gcc-internal-format
 #| msgid "multiple storage classes in declaration of %qs"
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "multiple storage kelas dalam deklarasi dari %qs"
 
-#: cp/decl.c:11098
+#: cp/decl.c:11122
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.c:11118
+#: cp/decl.c:11142
 #, fuzzy, gcc-internal-format
 #| msgid "%qs function uses %<auto%> type specifier without late return type"
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr "%qs fungsi menggunakan penspesifikasi tipe %<auto%> tanpa tipe kembali late"
 
-#: cp/decl.c:11121
+#: cp/decl.c:11145
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/decl.c:11127
+#: cp/decl.c:11151
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "virtual function cannot have deduced return type"
 msgstr "fungsi virtual tidak dapat menjadi friend"
 
-#: cp/decl.c:11134
+#: cp/decl.c:11158
 #, fuzzy, gcc-internal-format
 #| msgid "%qs function with late return type has %qT as its type rather than plain %<auto%>"
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr "%qs fungsi dengan tipe kembali late memiliki %qT sebagai tipenya daripada plain %<auto%>"
 
-#: cp/decl.c:11147
+#: cp/decl.c:11171
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "deduced class type %qD in function return type"
 msgstr "tipe pengkualifikasi diabaikan di tipe kembali fungsi"
 
-#: cp/decl.c:11156
+#: cp/decl.c:11180
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr ""
 
-#: cp/decl.c:11169
+#: cp/decl.c:11193
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
@@ -47875,63 +47919,63 @@
 
 #. Not using maybe_warn_cpp0x because this should
 #. always be an error.
-#: cp/decl.c:11180
+#: cp/decl.c:11204
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/decl.c:11183
+#: cp/decl.c:11207
 #, fuzzy, gcc-internal-format
 #| msgid "%qs function with late return type not declared with %<auto%> type specifier"
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr "%qs fungsi dengan tipe kembali late tidak dideklarasikan dengan penspesifikasi tipe %<auto%>"
 
-#: cp/decl.c:11212
+#: cp/decl.c:11236
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs dideklarasikan sebagai fungsi yang mengembalikan sebuah fungsi"
 
-#: cp/decl.c:11218
+#: cp/decl.c:11242
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs dideklarasikan sebagai fungsi yang mengembalikan sebuah array"
 
-#: cp/decl.c:11247
+#: cp/decl.c:11271
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "desktruktor tidak dapat berupa anggota statis fungsi"
 
-#: cp/decl.c:11248
+#: cp/decl.c:11272
 #, fuzzy, gcc-internal-format
 #| msgid "destructor cannot be static member function"
 msgid "constructor cannot be static member function"
 msgstr "desktruktor tidak dapat berupa anggota statis fungsi"
 
-#: cp/decl.c:11252
+#: cp/decl.c:11276
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "desktruktor mungkin berupa cv-kualified"
 
-#: cp/decl.c:11253
+#: cp/decl.c:11277
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "constructors may not be cv-qualified"
 msgstr "desktruktor mungkin berupa cv-kualified"
 
-#: cp/decl.c:11261
+#: cp/decl.c:11285
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "destructors may not be ref-qualified"
 msgstr "desktruktor mungkin berupa cv-kualified"
 
-#: cp/decl.c:11262
+#: cp/decl.c:11286
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "constructors may not be ref-qualified"
 msgstr "desktruktor mungkin berupa cv-kualified"
 
-#: cp/decl.c:11280
+#: cp/decl.c:11304
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructors cannot be declared %<virtual%>"
@@ -47938,263 +47982,263 @@
 msgstr "konstruktor tidak dapat dideklarasikan virtual"
 
 #. Cannot be both friend and virtual.
-#: cp/decl.c:11295
+#: cp/decl.c:11319
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "fungsi virtual tidak dapat menjadi friend"
 
-#: cp/decl.c:11299
+#: cp/decl.c:11323
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "deklarasi friend tidak dalam definisi kelas"
 
-#: cp/decl.c:11301
+#: cp/decl.c:11325
 #, fuzzy, gcc-internal-format
 #| msgid "can't define friend function %qs in a local class definition"
 msgid "can%'t define friend function %qs in a local class definition"
 msgstr "tidak dapat mendefinisikan fungsi friend %qs dalam sebuah definisi lokal kelas"
 
-#: cp/decl.c:11313
+#: cp/decl.c:11337
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr ""
 
-#: cp/decl.c:11339
+#: cp/decl.c:11363
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "destruktor mungkin tidak memiliki parameter"
 
-#: cp/decl.c:11379
+#: cp/decl.c:11403
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "tidak dapat mendeklarasikan penunjuk ke %q#T"
 
-#: cp/decl.c:11392 cp/decl.c:11399
+#: cp/decl.c:11416 cp/decl.c:11423
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "tidak dapat mendeklarasikan referensi ke %q#T"
 
-#: cp/decl.c:11401
+#: cp/decl.c:11425
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "tidak dapat mendeklarasikan penunjuk ke %q#T anggota"
 
-#: cp/decl.c:11430
+#: cp/decl.c:11454
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %s to qualified function type %qT"
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "tidak dapat mendeklarasikan %s untuk fungsi yang dikualifikasikan dengan tipe %qT"
 
-#: cp/decl.c:11431
+#: cp/decl.c:11455
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %s to qualified function type %qT"
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "tidak dapat mendeklarasikan %s untuk fungsi yang dikualifikasikan dengan tipe %qT"
 
-#: cp/decl.c:11504
+#: cp/decl.c:11528
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr "tidak dapat mendeklarasikan referensi ke %q#T, yang bukan sebuah typedef atau sebuah argumen tipe template"
 
-#: cp/decl.c:11574
+#: cp/decl.c:11598
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "template-id %qD digunakan sebagai sebuah pendeklarasi"
 
-#: cp/decl.c:11599
+#: cp/decl.c:11623
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "anggota fungsi secara implisit friends dari kelasnya"
 
-#: cp/decl.c:11605
+#: cp/decl.c:11629
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "ekstra kualifikasi %<%T::%> di anggota %qs"
 
-#: cp/decl.c:11635
+#: cp/decl.c:11659
 #, fuzzy, gcc-internal-format
 #| msgid "cannot define member function %<%T::%s%> within %<%T%>"
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "tidak dapat mendefinisikan anggota fungsi %<%T::%s%> dalam %<%T%>"
 
-#: cp/decl.c:11637
+#: cp/decl.c:11661
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare member %<%T::%s%> within %qT"
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "tidak dapat mendeklarasikan anggota %<%T::%s%> dalam %qT"
 
-#: cp/decl.c:11645
+#: cp/decl.c:11669
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "tidak dapat mendeklarasikan anggota %<%T::%s%> dalam %qT"
 
-#: cp/decl.c:11685
+#: cp/decl.c:11709
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "bukan parameter %qs tidak dapat menjadi parameter pack"
 
-#: cp/decl.c:11693
+#: cp/decl.c:11717
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "anggota member tidak boleh memiliki tipe variabel termodifikasi %qT"
 
-#: cp/decl.c:11695
+#: cp/decl.c:11719
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "parameter mungkin tidak memiliki tipe variabel termodifikasi %qT"
 
-#: cp/decl.c:11706
+#: cp/decl.c:11730
 #, fuzzy, gcc-internal-format
 #| msgid "%<virtual%> outside class declaration"
 msgid "%<explicit%> outside class declaration"
 msgstr "%<virtual%> diluar deklarasi kelas"
 
-#: cp/decl.c:11709
+#: cp/decl.c:11733
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<explicit%> in friend declaration"
 msgstr "%<inline%> dalam deklarasi kosong"
 
-#: cp/decl.c:11712
+#: cp/decl.c:11736
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be %<explicit%>"
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "hanya deklarasi dari konstruktor yang dapan berupa %<explicit%>"
 
-#: cp/decl.c:11721
+#: cp/decl.c:11745
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "bukan-anggota %qs tidak dapat dideklarasikan %<mutable%>"
 
-#: cp/decl.c:11726
+#: cp/decl.c:11750
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "anggota bukan-objek %qs tidak dapat dideklarasikan %<mutable%>"
 
-#: cp/decl.c:11732
+#: cp/decl.c:11756
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "fungsi %qs tidak dapat dideklarasikan %<mutable%>"
 
-#: cp/decl.c:11737
+#: cp/decl.c:11761
 #, gcc-internal-format
 msgid "static %qs cannot be declared %<mutable%>"
 msgstr "statis %qs tidak dapat dideklarasikan %<mutable%>"
 
-#: cp/decl.c:11742
+#: cp/decl.c:11766
 #, gcc-internal-format
 msgid "const %qs cannot be declared %<mutable%>"
 msgstr "const %qs tidak dapat dideklarasikan %<mutable%>"
 
-#: cp/decl.c:11747
+#: cp/decl.c:11771
 #, fuzzy, gcc-internal-format
 #| msgid "function %qs cannot be declared %<mutable%>"
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "fungsi %qs tidak dapat dideklarasikan %<mutable%>"
 
-#: cp/decl.c:11778
+#: cp/decl.c:11802
 #, fuzzy, gcc-internal-format
 #| msgid "parameter declared %<auto%>"
 msgid "typedef declared %<auto%>"
 msgstr "parameter dideklarasikan %<auto%>"
 
-#: cp/decl.c:11783
+#: cp/decl.c:11807
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.c:11787
+#: cp/decl.c:11811
 #, fuzzy, gcc-internal-format
 #| msgid "%Jtypedef name may not be a nested-name-specifier"
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "%J typedef nama mungkin berupa sebuah nested-name-specifier"
 
-#: cp/decl.c:11813
+#: cp/decl.c:11837
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ISO C++ melarang tipe nested %qD dengan nama sama seperti kelas yang melingkupi"
 
-#: cp/decl.c:11900
+#: cp/decl.c:11924
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "%<inline%> dispesifikan untuk deklarasi kelas friend"
 
-#: cp/decl.c:11908
+#: cp/decl.c:11932
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "parameter template tidak dapat berupa friends"
 
-#: cp/decl.c:11910
+#: cp/decl.c:11934
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "deklarasi friend membutuhkan kunci kelas, i.e. %<friend class %T::%D%>"
 
-#: cp/decl.c:11914
+#: cp/decl.c:11938
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "deklarasi friend membutuhkan class-key, i.e. %<friend %#T%>"
 
-#: cp/decl.c:11927
+#: cp/decl.c:11951
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "mencoba untuk membuat kelas %qT sebuah friend dari lingkup global"
 
-#: cp/decl.c:11947
+#: cp/decl.c:11971
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "kualifier tidak valid di tipe fungsi bukan anggota"
 
-#: cp/decl.c:11951
+#: cp/decl.c:11975
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.c:11961
+#: cp/decl.c:11985
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "deklarasi abstrak %qT digunakan sebagai deklarasi"
 
-#: cp/decl.c:11976
+#: cp/decl.c:12000
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration of C++ built-in type %qT"
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "redeklarasi dari C++ tipe bawaan %qT"
 
-#: cp/decl.c:11995
+#: cp/decl.c:12019
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "tidak dapat menggunakan %<::%> dalam parameter deklarasi"
 
-#: cp/decl.c:12001
+#: cp/decl.c:12025
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<this%> may not be used in this context"
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "%H%<this%> mungkin tidak digunakan dalam konteks ini"
 
-#: cp/decl.c:12003
+#: cp/decl.c:12027
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "parameter dideklarasikan %<auto%>"
 
-#: cp/decl.c:12052 cp/parser.c:3270
+#: cp/decl.c:12076 cp/parser.c:3270
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid use of template-name %qE without an argument list"
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "%Hpenggunaan tidak vlaid dari nama template %qE tanpa sebuah daftar argumen"
 
-#: cp/decl.c:12056
+#: cp/decl.c:12080
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "non-static data member declared with placeholder %qT"
 msgstr "anggota statis %qD dideklarasikan %<register%>"
 
-#: cp/decl.c:12080
+#: cp/decl.c:12104
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids zero-size array %qD"
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C++ melarang array berukuran-nol %qD"
 
-#: cp/decl.c:12083
+#: cp/decl.c:12107
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array members"
@@ -48201,175 +48245,175 @@
 msgstr "ISO C90 tidak mendukung keanggotaan array fleksibel"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:12099
+#: cp/decl.c:12123
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "penggunaan tidak valid dari %<::%>"
 
-#: cp/decl.c:12121
+#: cp/decl.c:12145
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of C function %q#D conflicts with"
 msgid "declaration of function %qD in invalid context"
 msgstr "deklarasi dari C fungsi %q#D konflik dengan"
 
-#: cp/decl.c:12130
+#: cp/decl.c:12154
 #, fuzzy, gcc-internal-format
 #| msgid "function %qD declared virtual inside a union"
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "fungsi %qD dideklarasikan virtual didalam sebuah union"
 
-#: cp/decl.c:12139
+#: cp/decl.c:12163
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be declared virtual, since it is always static"
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%qD tidak dapat dideklarasikan virtual, karena itu selalu statis"
 
-#: cp/decl.c:12153
+#: cp/decl.c:12177
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "diduga nama yang dikualifikasikan dalam deklarasi friend untuk destruktor %qD"
 
-#: cp/decl.c:12160
+#: cp/decl.c:12184
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "deklarasi dari %qD sebagai anggota dari %qT"
 
-#: cp/decl.c:12166
+#: cp/decl.c:12190
 #, fuzzy, gcc-internal-format
 #| msgid "destructor cannot be static member function"
 msgid "a destructor cannot be %<concept%>"
 msgstr "desktruktor tidak dapat berupa anggota statis fungsi"
 
-#: cp/decl.c:12171
+#: cp/decl.c:12195
 #, fuzzy, gcc-internal-format
 #| msgid "destructor cannot be static member function"
 msgid "a destructor cannot be %<constexpr%>"
 msgstr "desktruktor tidak dapat berupa anggota statis fungsi"
 
-#: cp/decl.c:12177
+#: cp/decl.c:12201
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "diduga kualifikasi nama dalam deklarasi friend untuk konstruktor %qD"
 
-#: cp/decl.c:12185
+#: cp/decl.c:12209
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "a constructor cannot be %<concept%>"
 msgstr "konstruktor tidak dapat dideklarasikan virtual"
 
-#: cp/decl.c:12190
+#: cp/decl.c:12214
 #, fuzzy, gcc-internal-format
 #| msgid "destructor cannot be static member function"
 msgid "a concept cannot be a member function"
 msgstr "desktruktor tidak dapat berupa anggota statis fungsi"
 
-#: cp/decl.c:12199
+#: cp/decl.c:12223
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of implicitly-declared special member function"
 msgid "specialization of variable template %qD declared as function"
 msgstr "spesialisasi dari anggota fungsi spesial secara implist dideklarasikan"
 
-#: cp/decl.c:12202
+#: cp/decl.c:12226
 #, fuzzy, gcc-internal-format
 #| msgid "variable or field declared void"
 msgid "variable template declared here"
 msgstr "variabel atau field dideklarasikan void"
 
-#: cp/decl.c:12257
+#: cp/decl.c:12281
 #, fuzzy, gcc-internal-format
 #| msgid "field %qD has incomplete type"
 msgid "field %qD has incomplete type %qT"
 msgstr "field %qD memiliki tipe tidak lengkap"
 
-#: cp/decl.c:12262
+#: cp/decl.c:12286
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "nama %qT memiliki tipe tidak lengkap"
 
-#: cp/decl.c:12272
+#: cp/decl.c:12296
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE bukan fungsi atau anggota fungsi; tidak dapat dideklarasikan sebagai friend"
 
-#: cp/decl.c:12318
+#: cp/decl.c:12342
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "static data member %qE declared %<concept%>"
 msgstr "anggota statis %qD dideklarasikan %<register%>"
 
-#: cp/decl.c:12322
+#: cp/decl.c:12346
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qD has Java class type"
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "anggota data bukan statis %qD memiliki tipe kelas Java"
 
-#: cp/decl.c:12350
+#: cp/decl.c:12374
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "non-static data member %qE declared %<concept%>"
 msgstr "anggota statis %qD dideklarasikan %<register%>"
 
-#: cp/decl.c:12354
+#: cp/decl.c:12378
 #, fuzzy, gcc-internal-format
 #| msgid "static member %qD declared %<register%>"
 msgid "non-static data member %qE declared %<constexpr%>"
 msgstr "anggota statis %qD dideklarasikan %<register%>"
 
-#: cp/decl.c:12409
+#: cp/decl.c:12433
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "kelas penyimpanan %<auto%> tidak valid untuk fungsi %qs"
 
-#: cp/decl.c:12411
+#: cp/decl.c:12435
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "kelas penyimpanan %<register%> tidak valid untuk fungsi %qs"
 
-#: cp/decl.c:12415
+#: cp/decl.c:12439
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "kelas penyimpanan %<__thread%> tidak valid untuk fungsi %qs"
 
-#: cp/decl.c:12418
+#: cp/decl.c:12442
 #, fuzzy, gcc-internal-format
 #| msgid "storage class %<__thread%> invalid for function %qs"
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "kelas penyimpanan %<__thread%> tidak valid untuk fungsi %qs"
 
-#: cp/decl.c:12423
+#: cp/decl.c:12447
 #, fuzzy, gcc-internal-format
 #| msgid "%Han asm-specification is not allowed on a function-definition"
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "%Hsebuah spesifikasi asm tidak diijinkan dalam sebuah definisi fungsi"
 
-#: cp/decl.c:12434
+#: cp/decl.c:12458
 #, fuzzy, gcc-internal-format
 #| msgid "%<static%> specified invalid for function %qs declared out of global scope"
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "%<static%> dispesifikasikan tidak valid untuk fungsi %qs dideklarasikan diluar lingkup global"
 
-#: cp/decl.c:12438
+#: cp/decl.c:12462
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "%<inline%> penspesifikasi tidak valid untuk fungsi %qs dideklarasikan diluar dari lingkup global"
 
-#: cp/decl.c:12446
+#: cp/decl.c:12470
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "virtual bukan kelas fungsi %qs"
 
-#: cp/decl.c:12453
+#: cp/decl.c:12477
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "%qs didefinisikan dalam sebuah lingkup bukan kelas"
 
-#: cp/decl.c:12454
+#: cp/decl.c:12478
 #, fuzzy, gcc-internal-format
 #| msgid "%qs defined in a non-class scope"
 msgid "%qs declared in a non-class scope"
 msgstr "%qs didefinisikan dalam sebuah lingkup bukan kelas"
 
-#: cp/decl.c:12489
+#: cp/decl.c:12513
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "tidak dapat mendeklarasikan anggota fungsi %qD untuk memiliki linkage statis"
@@ -48376,82 +48420,82 @@
 
 #. 7.1.1: There can be no static function declarations within a
 #. block.
-#: cp/decl.c:12497
+#: cp/decl.c:12521
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "tidak dapat mendeklarasikan fungsi statis didalam fungsi lainnya"
 
-#: cp/decl.c:12533
+#: cp/decl.c:12557
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "%<static%> mungkin tidak digunakan ketika mendefinisikan (terbalik untuk deklarasi) sebuah anggota data statis"
 
-#: cp/decl.c:12540
+#: cp/decl.c:12564
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "anggota statis %qD dideklarasikan %<register%>"
 
-#: cp/decl.c:12546
+#: cp/decl.c:12570
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "tidak dapat secara eksplisit mendeklarasikan anggota %q#D untuk memiliki extern linkage"
 
-#: cp/decl.c:12553
+#: cp/decl.c:12577
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %<extern%> variable %q+D in %<for%> loop initial declaration"
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "deklarasi dari variabel %<extern%> %q+D dalam %<for> inisial deklarasi loop"
 
-#: cp/decl.c:12574
+#: cp/decl.c:12598
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "deklarasi dari %q#D tidak memiliki penginisialisasi"
 
-#: cp/decl.c:12585
+#: cp/decl.c:12609
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs diinisialisasi dan dideklarasi %<extern%>"
 
-#: cp/decl.c:12589
+#: cp/decl.c:12613
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs keduanya memiliki %<extern> dan penginisialisasi"
 
-#: cp/decl.c:12754
+#: cp/decl.c:12778
 #, fuzzy, gcc-internal-format
 #| msgid "default argument %qE uses local variable %qD"
 msgid "default argument %qE uses %qD"
 msgstr "argumen baku %qE menggunakan variabel lokal %qD"
 
-#: cp/decl.c:12757
+#: cp/decl.c:12781
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "argumen baku %qE menggunakan variabel lokal %qD"
 
-#: cp/decl.c:12841
+#: cp/decl.c:12865
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specifiers invalid in parameter declarations"
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "penspesifikasi kelas penyimpanan dalam parameter deklarasi"
 
-#: cp/decl.c:12845
+#: cp/decl.c:12869
 #, fuzzy, gcc-internal-format
 #| msgid "cannot use %<::%> in parameter declaration"
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "tidak dapat menggunakan %<::%> dalam parameter deklarasi"
 
-#: cp/decl.c:12868
+#: cp/decl.c:12892
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "parameter %qD secara tidak valid dideklarasikan tipe metode"
 
-#: cp/decl.c:12895
+#: cp/decl.c:12919
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD includes %s to array of unknown bound %qT"
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "parameter %qD includes %s ke array dari ikatan tidak dikenal %qT"
 
-#: cp/decl.c:12897
+#: cp/decl.c:12921
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD includes %s to array of unknown bound %qT"
 msgid "parameter %qD includes reference to array of unknown bound %qT"
@@ -48472,185 +48516,185 @@
 #. or implicitly defined), there's no need to worry about their
 #. existence.  Theoretically, they should never even be
 #. instantiated, but that's hard to forestall.
-#: cp/decl.c:13150
+#: cp/decl.c:13174
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "konstruktor tidak valid; anda mungkin bermaksud %<%T (const %T&)%>"
 
-#: cp/decl.c:13228
+#: cp/decl.c:13252
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD mungkin tidak dideklarasikan dalam sebuah namespace"
 
-#: cp/decl.c:13234
+#: cp/decl.c:13258
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD tidak boleh dideklarasikan sebagai statis"
 
-#: cp/decl.c:13261
+#: cp/decl.c:13285
 #, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr "%qD harus berupa sebuah anggota fungsi tidak statis"
 
-#: cp/decl.c:13267
+#: cp/decl.c:13291
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD harus baik sebuah anggota fungsi tidak statis atau bukan anggota fungsi"
 
-#: cp/decl.c:13277
+#: cp/decl.c:13301
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD harus memiliki sebuah argumen dari kelas atau tipe enumerasi"
 
 #. 13.4.0.3
-#: cp/decl.c:13303
+#: cp/decl.c:13327
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading operator ?:"
 msgstr "ISO C++ melarang overloading operator ?:"
 
 #. Variadic.
-#: cp/decl.c:13314
+#: cp/decl.c:13338
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD tidak boleh memiliki argumen dengan jumlah bervariabel"
 
-#: cp/decl.c:13338
+#: cp/decl.c:13362
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either zero or one argument"
 msgid "%qD must have either zero or one argument"
 msgstr "%qD harus mengambil baik nol atau satu argumen"
 
-#: cp/decl.c:13339
+#: cp/decl.c:13363
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either one or two arguments"
 msgid "%qD must have either one or two arguments"
 msgstr "%qD harus mengambil baik satu atau dua argumen"
 
-#: cp/decl.c:13350
+#: cp/decl.c:13374
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its argument"
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "postfix %qD harus mengambil %<int%> sebagai argumennya"
 
-#: cp/decl.c:13351
+#: cp/decl.c:13375
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its second argument"
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "postfix %qD harus mengambil %<int%> sebagai argumen keduanya"
 
-#: cp/decl.c:13361
+#: cp/decl.c:13385
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have no arguments"
 msgstr "%qD harus mengambil secara tepat dua argumen"
 
-#: cp/decl.c:13362 cp/decl.c:13371
+#: cp/decl.c:13386 cp/decl.c:13395
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly one argument"
 msgid "%qD must have exactly one argument"
 msgstr "%qD harus mengambil secara tepat satu argumen"
 
-#: cp/decl.c:13372
+#: cp/decl.c:13396
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have exactly two arguments"
 msgstr "%qD harus mengambil secara tepat dua argumen"
 
-#: cp/decl.c:13389 cp/decl.c:13392
+#: cp/decl.c:13413 cp/decl.c:13416
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD tidak dapat memiliki argumen baku"
 
-#: cp/decl.c:13419
+#: cp/decl.c:13443
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to a reference to void will never use a type conversion operator"
 msgstr "konversi ke %s%s tidak akan pernah menggunakan sebuah tipe operator konversi"
 
-#: cp/decl.c:13421
+#: cp/decl.c:13445
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to void will never use a type conversion operator"
 msgstr "konversi ke %s%s tidak akan pernah menggunakan sebuah tipe operator konversi"
 
-#: cp/decl.c:13428
+#: cp/decl.c:13452
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgstr "konversi ke %s%s tidak akan pernah menggunakan sebuah tipe operator konversi"
 
-#: cp/decl.c:13430
+#: cp/decl.c:13454
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to the same type will never use a type conversion operator"
 msgstr "konversi ke %s%s tidak akan pernah menggunakan sebuah tipe operator konversi"
 
-#: cp/decl.c:13438
+#: cp/decl.c:13462
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgstr "konversi ke %s%s tidak akan pernah menggunakan sebuah tipe operator konversi"
 
-#: cp/decl.c:13440
+#: cp/decl.c:13464
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %s%s will never use a type conversion operator"
 msgid "conversion to a base class will never use a type conversion operator"
 msgstr "konversi ke %s%s tidak akan pernah menggunakan sebuah tipe operator konversi"
 
-#: cp/decl.c:13455
+#: cp/decl.c:13479
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "definisi-pengguna %qD selalu mengevaluasikan kedua argumen"
 
-#: cp/decl.c:13474
+#: cp/decl.c:13498
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "prefix %qD seharusnya mengembalikan %qT"
 
-#: cp/decl.c:13480
+#: cp/decl.c:13504
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "postfix %qD seharusnya mengembalikan %qT"
 
-#: cp/decl.c:13492
+#: cp/decl.c:13516
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD seharusnya kembali dengan nilai"
 
-#: cp/decl.c:13547
+#: cp/decl.c:13571
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "menggunakan parameter tipe template %qT setelah %qs"
 
-#: cp/decl.c:13570
+#: cp/decl.c:13594
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous template specialization %qD for %q+D"
 msgid "using alias template specialization %qT after %qs"
 msgstr "spesialisasi template ambigu %qD untuk %q+D"
 
-#: cp/decl.c:13573
+#: cp/decl.c:13597
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "menggunakan typedef-name %qD setelah %qs"
 
-#: cp/decl.c:13575
+#: cp/decl.c:13599
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D has a previous declaration here"
 msgid "%qD has a previous declaration here"
 msgstr "%q+D telah dideklarasikan sebelumnya disini"
 
-#: cp/decl.c:13583
+#: cp/decl.c:13607
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "%qT mereferensikan sebagai %qs"
 
-#: cp/decl.c:13584 cp/decl.c:13591
+#: cp/decl.c:13608 cp/decl.c:13615
 #, fuzzy, gcc-internal-format
 #| msgid "%q+T has a previous declaration here"
 msgid "%qT has a previous declaration here"
 msgstr "%q+T telah dideklarasikan sebelumnya disini"
 
-#: cp/decl.c:13590
+#: cp/decl.c:13614
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "%qT direferensikan sebagai enum"
@@ -48662,96 +48706,96 @@
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:13605
+#: cp/decl.c:13629
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "argumen template dibutuhkan untuk %<%s %T%>"
 
-#: cp/decl.c:13659 cp/name-lookup.c:4652
+#: cp/decl.c:13683 cp/name-lookup.c:4652
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD memiliki nama sama seperti kelas yang telah dideklarasikan"
 
-#: cp/decl.c:13689 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6425
-#: cp/pt.c:9209
+#: cp/decl.c:13713 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6428
+#: cp/pt.c:9223
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT mungkin bukan sebuah template"
 
-#: cp/decl.c:13694
+#: cp/decl.c:13718
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:13703 cp/name-lookup.c:4079 cp/name-lookup.c:4086
-#: cp/name-lookup.c:4939 cp/parser.c:6376 cp/parser.c:26300
+#: cp/decl.c:13727 cp/name-lookup.c:4079 cp/name-lookup.c:4086
+#: cp/name-lookup.c:4939 cp/parser.c:6379 cp/parser.c:26297
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "referensi ke %qD adalah ambigu"
 
-#: cp/decl.c:13806
+#: cp/decl.c:13830
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "penggunaan dari enum %q#D tanpa deklarasi sebelumnya"
 
-#: cp/decl.c:13842
+#: cp/decl.c:13866
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "redeklarasi dari %qT sebagai bukan-template"
 
-#: cp/decl.c:13982
+#: cp/decl.c:14006
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "union turunan %qT tidak valid"
 
-#: cp/decl.c:13989
+#: cp/decl.c:14013
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr ""
 
-#: cp/decl.c:14000
+#: cp/decl.c:14024
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not a direct or virtual base of %qT"
 msgid "%qT defined with direct virtual base"
 msgstr "tipe %qT tidak sebuah langsung atau virtual base dari %qT"
 
-#: cp/decl.c:14025
+#: cp/decl.c:14049
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "tipe base %qT gagal untuk menjadi sebuah struct atau tipe kelas"
 
-#: cp/decl.c:14055
+#: cp/decl.c:14079
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "tipe rekursif %qT tidak terdefinisi"
 
-#: cp/decl.c:14057
+#: cp/decl.c:14081
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "duplikasi tipe dasar %qT tidak valid"
 
-#: cp/decl.c:14202
+#: cp/decl.c:14226
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14205 cp/decl.c:14213 cp/decl.c:14225 cp/parser.c:18284
+#: cp/decl.c:14229 cp/decl.c:14237 cp/decl.c:14249 cp/parser.c:18281
 #, fuzzy, gcc-internal-format
 #| msgid "%Jprevious definition here"
 msgid "previous definition here"
 msgstr "%J definisi sebelumnya disini"
 
-#: cp/decl.c:14210
+#: cp/decl.c:14234
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14222
+#: cp/decl.c:14246
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14300
+#: cp/decl.c:14324
 #, fuzzy, gcc-internal-format
 #| msgid "underlying type %<%T%> of %<%T%> must be an integral type"
 msgid "underlying type %qT of %qT must be an integral type"
@@ -48761,83 +48805,83 @@
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:14447
+#: cp/decl.c:14471
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "tidak ada tipe integral yang dapat merepresentasikan seluruh dari nilai enumerasi untuk %qT"
 
-#: cp/decl.c:14619
+#: cp/decl.c:14643
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qD is not an integer constant"
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "nilai enumerasi untuk %qD bukan sebuah konstanta integer"
 
-#: cp/decl.c:14629
+#: cp/decl.c:14653
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "nilai enumerasi untuk %qD bukan sebuah konstanta integer"
 
-#: cp/decl.c:14678
+#: cp/decl.c:14702
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value %E is too large for underlying type %<%T%>"
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "nilai pengenumerasi untuk %E terlalu besar untuk tipe yang digaris bawahi %<%T%>"
 
-#: cp/decl.c:14679
+#: cp/decl.c:14703
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value %E is too large for underlying type %<%T%>"
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "nilai pengenumerasi untuk %E terlalu besar untuk tipe yang digaris bawahi %<%T%>"
 
-#: cp/decl.c:14690
+#: cp/decl.c:14714
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "overflow dalam nilai enumerasi di %qD"
 
-#: cp/decl.c:14710
+#: cp/decl.c:14734
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value %E is too large for underlying type %<%T%>"
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "nilai pengenumerasi untuk %E terlalu besar untuk tipe yang digaris bawahi %<%T%>"
 
-#: cp/decl.c:14821
+#: cp/decl.c:14845
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "tipe kembali %q#T tidak lengkap"
 
-#: cp/decl.c:14999 cp/typeck.c:9286
+#: cp/decl.c:15023 cp/typeck.c:9286
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> seharusnya mengembalikan referensi ke %<*this%>"
 
-#: cp/decl.c:15344
+#: cp/decl.c:15368
 #, gcc-internal-format
 msgid "invalid function declaration"
 msgstr "deklarasi fungsi tidak valid"
 
-#: cp/decl.c:15786
+#: cp/decl.c:15810
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "no return statements in function returning %qT"
 msgstr "tidak ada pernyataaan kembali dalam fungsi yang mengembalikan bukan void"
 
-#: cp/decl.c:15788 cp/typeck.c:9166
+#: cp/decl.c:15812 cp/typeck.c:9166
 #, fuzzy, gcc-internal-format
 #| msgid "function return types not compatible due to %<volatile%>"
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "tipe kembali fungsi tidak kompatibel karena %<volatile%>"
 
-#: cp/decl.c:15996
+#: cp/decl.c:16020
 #, gcc-internal-format
 msgid "invalid member function declaration"
 msgstr "deklarasi anggota fungsi tidak valid"
 
-#: cp/decl.c:16010
+#: cp/decl.c:16034
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD telah didefinisikan dalam kelas %qT"
 
-#: cp/decl.c:16386
+#: cp/decl.c:16410
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -48878,7 +48922,7 @@
 msgid "deleting %qT is undefined"
 msgstr "menghapus %qT tidak terdefinisi"
 
-#: cp/decl2.c:585 cp/pt.c:5552
+#: cp/decl2.c:585 cp/pt.c:5566
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "template deklarasi dari %q#D"
@@ -48892,7 +48936,7 @@
 #. [temp.mem]
 #.
 #. A destructor shall not be a member template.
-#: cp/decl2.c:640 cp/pt.c:5511
+#: cp/decl2.c:640 cp/pt.c:5525
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "destruktor %qD dideklarasikan sebagai anggota template"
@@ -49079,51 +49123,51 @@
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "%<operator delete%> mengambil tipe %qT sebagai parameter pertama"
 
-#: cp/decl2.c:2660
+#: cp/decl2.c:2650
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgid "%qT has a field %qD whose type has no linkage"
 msgstr "%qT memiliki sebuah field %qD yang tipe menggunakan namespace anonymous"
 
-#: cp/decl2.c:2664
+#: cp/decl2.c:2654
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr "%qT memiliki sebuah field %qD yang tipe menggunakan namespace anonymous"
 
-#: cp/decl2.c:2669
+#: cp/decl2.c:2659
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr "%qT memiliki sebuah field %qD yang tipe menggunakan namespace anonymous"
 
-#: cp/decl2.c:2677
+#: cp/decl2.c:2667
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr "%qT dideklarasikan dengan visibility lebih besar dari tipe dari fieldnya %qD"
 
-#: cp/decl2.c:2695
+#: cp/decl2.c:2685
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgid "%qT has a base %qT whose type has no linkage"
 msgstr "%qT memiliki sebuah base %qT yang menggunakan tipe namespace anonymous"
 
-#: cp/decl2.c:2699
+#: cp/decl2.c:2689
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgid "%qT has a base %qT whose type depends on the type %qT which has no linkage"
 msgstr "%qT memiliki sebuah base %qT yang menggunakan tipe namespace anonymous"
 
-#: cp/decl2.c:2704
+#: cp/decl2.c:2694
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr "%qT memiliki sebuah base %qT yang menggunakan tipe namespace anonymous"
 
-#: cp/decl2.c:2711
+#: cp/decl2.c:2701
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr "%qT dideklarasikan dengan visibility lebih besar dari basenya %qT"
 
-#: cp/decl2.c:4309
+#: cp/decl2.c:4299
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%q#D, declared using unnamed type, is used but never defined"
@@ -49133,68 +49177,68 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4318
+#: cp/decl2.c:4308
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4322
+#: cp/decl2.c:4312
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4326
+#: cp/decl2.c:4316
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D does not refer to the unqualified type, so it is not used for linkage"
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr "%q+#D tidak merefer ke tipe tidak terkualifikasi, jadi ini tidak digunakan untuk linkage"
 
-#: cp/decl2.c:4334
+#: cp/decl2.c:4324
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "%q+F dideklarasikan %<static%> tetapi tidak pernah didefinisikan"
 
-#: cp/decl2.c:4338
+#: cp/decl2.c:4328
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4341
+#: cp/decl2.c:4331
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+#D with %qL linkage"
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "deklarasi sebelumnya dari %q+#D dengan %qL linkage"
 
-#: cp/decl2.c:4529
+#: cp/decl2.c:4519
 #, fuzzy, gcc-internal-format
 #| msgid "section of %q+D conflicts with previous declaration"
 msgid "mangling of %q#D as %qE conflicts with a previous mangle"
 msgstr "daerah dari %q+D konflik dengan deklarasi sebelumnya"
 
-#: cp/decl2.c:4532
+#: cp/decl2.c:4522
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D"
 msgid "previous mangling %q#D"
 msgstr "deklarasi sebelumnya %q+D"
 
-#: cp/decl2.c:4534
+#: cp/decl2.c:4524
 #, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr ""
 
-#: cp/decl2.c:4606 cp/decl2.c:4609
+#: cp/decl2.c:4596 cp/decl2.c:4599
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.c:4956
+#: cp/decl2.c:4946
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D used but never defined"
 msgid "inline function %qD used but never defined"
 msgstr "fungsi inline %q+D digunakan tetapi tidak pernah didefinisikan"
 
-#: cp/decl2.c:5143
+#: cp/decl2.c:5133
 #, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr "argumen baku hilang untuk parameter %P dari %q+#Ddd"
@@ -49201,18 +49245,18 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5251
+#: cp/decl2.c:5241
 #, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.c:5254
+#: cp/decl2.c:5244
 #, fuzzy, gcc-internal-format
 #| msgid "deleted function %q+D"
 msgid "use of deleted function %qD"
 msgstr "fungsi %q+D terhapus"
 
-#: cp/decl2.c:5307
+#: cp/decl2.c:5297
 #, fuzzy, gcc-internal-format
 #| msgid "using %<typename%> outside of template"
 msgid "use of built-in parameter pack %qD outside of a template"
@@ -49531,48 +49575,48 @@
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr "evaluasi rekursi dari argumen baku untuk %q#D"
 
-#: cp/init.c:613
+#: cp/init.c:629
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr ""
 
-#: cp/init.c:615
+#: cp/init.c:631
 #, fuzzy, gcc-internal-format
 #| msgid "used here"
 msgid "defined here"
 msgstr "digunakan disini"
 
-#: cp/init.c:673
+#: cp/init.c:689
 #, fuzzy, gcc-internal-format
 #| msgid "initialization of a flexible array member"
 msgid "initializer for flexible array member %q#D"
 msgstr "inisialisasi dari sebuah anggota array fleksibel"
 
-#: cp/init.c:699
+#: cp/init.c:715
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qD should be initialized in the member initialization list"
 msgid "%qD should be initialized in the member initialization list"
 msgstr "%J%qD seharusnya diinisialisasi dalam daftar anggota inisialisasi"
 
-#: cp/init.c:720
+#: cp/init.c:736
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is used uninitialized in this function"
 msgid "%qD is initialized with itself"
 msgstr "%qD digunakan tidak terinisialisasi dalam fungsi ini"
 
-#: cp/init.c:831
+#: cp/init.c:847
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initial value for member %qs"
 msgid "invalid initializer for array member %q#D"
 msgstr "nilai inisial tidak valid untuk anggota %qs"
 
-#: cp/init.c:845 cp/init.c:869 cp/init.c:2410 cp/method.c:1368
+#: cp/init.c:861 cp/init.c:885 cp/init.c:2427 cp/method.c:1368
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const member %qD"
 msgid "uninitialized const member in %q#T"
 msgstr "anggota const tidak terinisialisasi %qD"
 
-#: cp/init.c:847 cp/init.c:864 cp/init.c:871 cp/init.c:2395 cp/init.c:2423
+#: cp/init.c:863 cp/init.c:880 cp/init.c:887 cp/init.c:2412 cp/init.c:2440
 #: cp/method.c:1371 cp/method.c:1382
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D will be initialized after"
@@ -49579,312 +49623,312 @@
 msgid "%q#D should be initialized"
 msgstr "%qD akan diinisialisasi setelah"
 
-#: cp/init.c:862 cp/init.c:2382 cp/method.c:1379
+#: cp/init.c:878 cp/init.c:2399 cp/method.c:1379
 #, fuzzy, gcc-internal-format
 #| msgid "%Juninitialized reference member %qD"
 msgid "uninitialized reference member in %q#T"
 msgstr "%J anggota referensi tidak terinisialisasi %qD"
 
-#: cp/init.c:1041
+#: cp/init.c:1057
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D will be initialized after"
 msgid "%qD will be initialized after"
 msgstr "%qD akan diinisialisasi setelah"
 
-#: cp/init.c:1044
+#: cp/init.c:1060
 #, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr "dasar %qT akan diinisialisasi setelah"
 
-#: cp/init.c:1048
+#: cp/init.c:1064
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D"
 msgid "  %q#D"
 msgstr "  %q+#D"
 
-#: cp/init.c:1050
+#: cp/init.c:1066
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr "  dasar %qT"
 
-#: cp/init.c:1052
+#: cp/init.c:1068
 #, fuzzy, gcc-internal-format
 #| msgid "%J  when initialized here"
 msgid "  when initialized here"
 msgstr "%J  ketika diinisialisasi disini"
 
-#: cp/init.c:1069
+#: cp/init.c:1085
 #, fuzzy, gcc-internal-format
 #| msgid "%Jmultiple initializations given for %qD"
 msgid "multiple initializations given for %qD"
 msgstr "%J multiple penginisialisasi diberikan untuk %qD"
 
-#: cp/init.c:1073
+#: cp/init.c:1089
 #, fuzzy, gcc-internal-format
 #| msgid "%Jmultiple initializations given for base %qT"
 msgid "multiple initializations given for base %qT"
 msgstr "%J multiple penginisialisasi diberikan untuk dasar %qT"
 
-#: cp/init.c:1158
+#: cp/init.c:1174
 #, fuzzy, gcc-internal-format
 #| msgid "%Jinitializations for multiple members of %qT"
 msgid "initializations for multiple members of %qT"
 msgstr "%J inisialisasi untuk multiple anggota dari %qT"
 
-#: cp/init.c:1255
+#: cp/init.c:1271
 #, fuzzy, gcc-internal-format
 #| msgid "%Jbase class %q#T should be explicitly initialized in the copy constructor"
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr "%J kelas dasar %q#T seharusnya secara eksplisit diinisialisasikan dalam konstruktor salinan"
 
-#: cp/init.c:1482 cp/init.c:1501
+#: cp/init.c:1498 cp/init.c:1517
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr "kelas %qT tidak memiliki field apapun bernama %qD"
 
-#: cp/init.c:1488
+#: cp/init.c:1504
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr "%q#D adalah sebuah anggota data statis; ini hanya dapat diinisialisasikan di definisinya"
 
-#: cp/init.c:1495
+#: cp/init.c:1511
 #, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr "%q#D bukan sebuah anggota data bukan-statis dari %qT"
 
-#: cp/init.c:1534
+#: cp/init.c:1550
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr "penginisialisasi tidak bernama untuk %qT, yang tidak memiliki kelas dasar"
 
-#: cp/init.c:1542
+#: cp/init.c:1558
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr "penginisialisasi tidak bernama untuk %qT, yang menggunakan turunan multiple"
 
-#: cp/init.c:1589
+#: cp/init.c:1605
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr "%qD keduanya sebuah dasar langsung dan sebuah virtual base tidak langsung"
 
-#: cp/init.c:1597
+#: cp/init.c:1613
 #, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr "tipe %qT tidak sebuah langsung atau virtual base dari %qT"
 
-#: cp/init.c:1600
+#: cp/init.c:1616
 #, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr "tipe %qT bukan sebuah dasar langsung dari %qT"
 
-#: cp/init.c:1710 cp/init.c:4386 cp/typeck2.c:1175
+#: cp/init.c:1727 cp/init.c:4402 cp/typeck2.c:1175
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "array harus diinisialisasi dengan sebuah kurung melingkupi penginisialisasi"
 
-#: cp/init.c:2019 cp/semantics.c:3268
+#: cp/init.c:2036 cp/semantics.c:3271
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qT bukan sebuah tipe kelas"
 
-#: cp/init.c:2075
+#: cp/init.c:2092
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr "tipe tidak lengkap %qT tidak memiliki anggota %qD"
 
-#: cp/init.c:2089
+#: cp/init.c:2106
 #, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr "penunjuk tidak valid ke bit-field %qD"
 
-#: cp/init.c:2175 cp/typeck.c:1893
+#: cp/init.c:2192 cp/typeck.c:1893
 #, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "penggunaan tidak valid dari anggota fungsi %qD bukan statis"
 
-#: cp/init.c:2182 cp/semantics.c:1835
+#: cp/init.c:2199 cp/semantics.c:1835
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "penggunaan tidak valid dari anggota data tidak statis %qD"
 
-#: cp/init.c:2379
+#: cp/init.c:2396
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2387
+#: cp/init.c:2404
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2391
+#: cp/init.c:2408
 #, fuzzy, gcc-internal-format
 #| msgid "%Juninitialized reference member %qD"
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr "%J anggota referensi tidak terinisialisasi %qD"
 
-#: cp/init.c:2407
+#: cp/init.c:2424
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const in %<new%> of %q#T"
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr "const tidak terinisialisasi dalam %<new%> dari %q#T"
 
-#: cp/init.c:2415
+#: cp/init.c:2432
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2419
+#: cp/init.c:2436
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const in %<new%> of %q#T"
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr "const tidak terinisialisasi dalam %<new%> dari %q#T"
 
-#: cp/init.c:2710
+#: cp/init.c:2727
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2721
+#: cp/init.c:2738
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2732
+#: cp/init.c:2749
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2880
+#: cp/init.c:2896
 #, fuzzy, gcc-internal-format
 #| msgid "integer overflow in expression"
 msgid "integer overflow in array size"
 msgstr "integer overflow dalam ekspresi"
 
-#: cp/init.c:2890
+#: cp/init.c:2906
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "array size in new-expression must be constant"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/init.c:2904
+#: cp/init.c:2920
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' not allowed in expression at %L"
 msgid "variably modified type not allowed in new-expression"
 msgstr "Dummy argumen '%s' tidak diijinkan dalam ekspresi di %L"
 
-#: cp/init.c:2920
+#: cp/init.c:2936
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by typedef"
 msgstr ""
 
-#: cp/init.c:2922
+#: cp/init.c:2938
 #, fuzzy, gcc-internal-format
 #| msgid "try removing the parentheses around the type-id"
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr "mencoba menghapus tanda kurung disekitar tipe-id"
 
-#: cp/init.c:2932
+#: cp/init.c:2948
 #, gcc-internal-format
 msgid "invalid type %<void%> for new"
 msgstr "tipe %<void%> tidak valid untuk new"
 
-#: cp/init.c:2975
+#: cp/init.c:2991
 #, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr "const tidak terinisialisasi dalam %<new%> dari %q#T"
 
-#: cp/init.c:3101
+#: cp/init.c:3117
 #, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr "tidak ada %qD yang sesuai yang ditemukan dalam kelas %qT"
 
-#: cp/init.c:3108 cp/search.c:1023
+#: cp/init.c:3124 cp/search.c:1026
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "permintaan untuk anggota %qD adalah ambigu"
 
-#: cp/init.c:3181
+#: cp/init.c:3197
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr ""
 
-#: cp/init.c:3184
+#: cp/init.c:3200
 #, fuzzy, gcc-internal-format
 #| msgid "class %qT does not have any field named %qD"
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr "kelas %qT tidak memiliki field apapun bernama %qD"
 
-#: cp/init.c:3187
+#: cp/init.c:3203
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr ""
 
-#: cp/init.c:3370
+#: cp/init.c:3386
 #, fuzzy, gcc-internal-format
 #| msgid "attributes after parenthesized initializer ignored"
 msgid "parenthesized initializer in array new"
 msgstr "atribut setelah tanda kurung penginisialisasi diabaikan"
 
-#: cp/init.c:3633
+#: cp/init.c:3649
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr "ukuran dalam array baru harus memiliki tipe integral"
 
-#: cp/init.c:3665
+#: cp/init.c:3681
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr "new tidak dapat diaplikasikan untuk mereferensikan sebuah tipe"
 
-#: cp/init.c:3674
+#: cp/init.c:3690
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr "new tidak dapat diaplikasikan ke sebuah fungsi tipe"
 
-#: cp/init.c:3743
+#: cp/init.c:3759
 #, fuzzy, gcc-internal-format
 #| msgid "possible problem detected in invocation of delete operator:"
 msgid "possible problem detected in invocation of delete [] operator:"
 msgstr "kemungkinan masalah terdeteksi dalam penggunaan dari operator delete:"
 
-#: cp/init.c:3747
+#: cp/init.c:3763
 #, fuzzy, gcc-internal-format
 #| msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined."
 msgid "neither the destructor nor the class-specific operator delete [] will be called, even if they are declared when the class is defined"
 msgstr "bukan destruktor ataupu class-specific operator delete yang akan dipanggil, meskipun mereka dideklarasikan ketika kelas didefinisikan."
 
-#: cp/init.c:4295
+#: cp/init.c:4311
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "penginisialisasi berakhir secara prematur"
 
-#: cp/init.c:4599
+#: cp/init.c:4615
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr "ukuran array tidak diketahui dalam delete"
 
-#: cp/init.c:4623
+#: cp/init.c:4639
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete operator:"
 msgstr "kemungkinan masalah terdeteksi dalam penggunaan dari operator delete:"
 
-#: cp/init.c:4628
+#: cp/init.c:4644
 #, fuzzy, gcc-internal-format
 #| msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined."
 msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
 msgstr "bukan destruktor ataupu class-specific operator delete yang akan dipanggil, meskipun mereka dideklarasikan ketika kelas didefinisikan."
 
-#: cp/init.c:4642
+#: cp/init.c:4658
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4647
+#: cp/init.c:4663
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4954
+#: cp/init.c:4970
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "tipe dari vektor delete bukan penunjuk ataupun tipe array"
@@ -50388,7 +50432,7 @@
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr ""
 
-#: cp/name-lookup.c:5111 cp/name-lookup.c:7065
+#: cp/name-lookup.c:5111 cp/name-lookup.c:7073
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "atribut %qD direktif diabaikan"
@@ -50438,57 +50482,57 @@
 msgid "it was later defined here"
 msgstr "%J%qD telah dideklarasikan disini"
 
-#: cp/name-lookup.c:6687
+#: cp/name-lookup.c:6695
 #, gcc-internal-format
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn't a template"
 msgstr ""
 
-#: cp/name-lookup.c:7059
+#: cp/name-lookup.c:7067
 #, fuzzy, gcc-internal-format
 #| msgid "switch %qs is no longer supported"
 msgid "strong using directive no longer supported"
 msgstr "pilihan %qs tidak lagi didukung"
 
-#: cp/name-lookup.c:7062
+#: cp/name-lookup.c:7070
 #, gcc-internal-format
 msgid "you may use an inline namespace instead"
 msgstr ""
 
-#: cp/name-lookup.c:7079
+#: cp/name-lookup.c:7087
 #, fuzzy, gcc-internal-format
 #| msgid "attributes ignored on uninstantiated type"
 msgid "attributes ignored on local using directive"
 msgstr "atribut diabaikan di tipe uninstantiasi"
 
-#: cp/name-lookup.c:7163
+#: cp/name-lookup.c:7171
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "namespace alias %qD tidak diijinkan disini, diasumsikan %qD"
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:7183
+#: cp/name-lookup.c:7191
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qD may not be declared within a namespace"
 msgid "cannot nest more than %d namespaces"
 msgstr "%qD mungkin tidak dideklarasikan dalam sebuah namespace"
 
-#: cp/name-lookup.c:7218
+#: cp/name-lookup.c:7226
 #, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr ""
 
-#: cp/name-lookup.c:7219
+#: cp/name-lookup.c:7227
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%qD defined here"
 msgstr "%q+D dideklarasikan disini"
 
-#: cp/name-lookup.c:7292
+#: cp/name-lookup.c:7300
 #, gcc-internal-format
 msgid "XXX entering pop_everything ()\n"
 msgstr "XXX memasuki pop_everything ()\n"
 
-#: cp/name-lookup.c:7301
+#: cp/name-lookup.c:7309
 #, gcc-internal-format
 msgid "XXX leaving pop_everything ()\n"
 msgstr "XXX meninggalkan pop_everything ()\n"
@@ -50510,7 +50554,7 @@
 msgid "LEXER_DEBUGGING_ENABLED_P is not set to true"
 msgstr ""
 
-#: cp/parser.c:1352 cp/parser.c:37254
+#: cp/parser.c:1352 cp/parser.c:37251
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -50539,7 +50583,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr "%Hpermintaan untuk anggota %qE dalam tipe bukan kelas %qT"
 
-#: cp/parser.c:2949 cp/parser.c:18221
+#: cp/parser.c:2949 cp/parser.c:18218
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<%T::%E%> has not been declared"
 msgid "%<%T::%E%> has not been declared"
@@ -50634,7 +50678,7 @@
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "ISO C++ melarang menggunakan penunjuk ke sebuah fungsi  dalam pengurangan"
 
-#: cp/parser.c:3143 cp/pt.c:17853
+#: cp/parser.c:3143 cp/pt.c:17890
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr "sebuah cast ke sebuah tipe selain dari sebuah integral atau tipe enumerasi tidak dapat muncul dalam sebuah ekspresi konstan"
@@ -50889,7 +50933,7 @@
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr ""
 
-#: cp/parser.c:4587 cp/parser.c:12940
+#: cp/parser.c:4587 cp/parser.c:12937
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "expected declaration"
@@ -50948,7 +50992,7 @@
 msgid "fold-expressions only available with -std=c++17 or -std=gnu++17"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:5275 cp/parser.c:5452 cp/parser.c:5630 cp/semantics.c:3612
+#: cp/parser.c:5275 cp/parser.c:5452 cp/parser.c:5633 cp/semantics.c:3615
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "expected primary-expression"
@@ -50972,106 +51016,106 @@
 msgid "local variable %qD may not appear in this context"
 msgstr "%Hvariabel lokal %qD mungkin tidak muncul dalam konteks ini"
 
-#: cp/parser.c:5787
+#: cp/parser.c:5790
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "expected id-expression"
 msgstr "diduga ekspresi"
 
-#: cp/parser.c:5919
+#: cp/parser.c:5922
 #, fuzzy, gcc-internal-format
 #| msgid "%Hscope %qT before %<~%> is not a class-name"
 msgid "scope %qT before %<~%> is not a class-name"
 msgstr "%Hlingkup %qT sebelum %<~%> bukan sebuah class-name"
 
-#: cp/parser.c:5948 cp/parser.c:7860
+#: cp/parser.c:5951 cp/parser.c:7860
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:6059
+#: cp/parser.c:6062
 #, fuzzy, gcc-internal-format
 #| msgid "%Hdeclaration of %<~%T%> as member of %qT"
 msgid "declaration of %<~%T%> as member of %qT"
 msgstr "%Hdeklarasi dari %<~%T%> sebagai anggota dari %qT"
 
-#: cp/parser.c:6074
+#: cp/parser.c:6077
 #, fuzzy, gcc-internal-format
 #| msgid "%Htypedef-name %qD used as destructor declarator"
 msgid "typedef-name %qD used as destructor declarator"
 msgstr "%Htypedef-nama %qD digunakan sebagai desktruktor deklarator"
 
-#: cp/parser.c:6111 cp/parser.c:20249
+#: cp/parser.c:6114 cp/parser.c:20246
 #, fuzzy, gcc-internal-format
 #| msgid "expected specifier-qualifier-list"
 msgid "expected unqualified-id"
 msgstr "diduga specifier-qualifier-list"
 
-#: cp/parser.c:6220
+#: cp/parser.c:6223
 #, gcc-internal-format
 msgid "found %<:%> in nested-name-specifier, expected %<::%>"
 msgstr ""
 
-#: cp/parser.c:6288
+#: cp/parser.c:6291
 #, fuzzy, gcc-internal-format
 #| msgid "%qT resolves to %qT, which is not an enumeration type"
 msgid "decltype evaluates to %qT, which is not a class or enumeration type"
 msgstr "%qT meresolf ke %qT, yang bukan sebuah tipe enumerasi"
 
-#: cp/parser.c:6314
+#: cp/parser.c:6317
 #, fuzzy, gcc-internal-format
 #| msgid "%Hincomplete type %qT used in nested name specifier"
 msgid "function template-id %qD in nested-name-specifier"
 msgstr "%Htipe %qT tidak lengkap digunakan dalam nama penspesifikasi nested"
 
-#: cp/parser.c:6322
+#: cp/parser.c:6325
 #, fuzzy, gcc-internal-format
 #| msgid "%Hincomplete type %qT used in nested name specifier"
 msgid "variable template-id %qD in nested-name-specifier"
 msgstr "%Htipe %qT tidak lengkap digunakan dalam nama penspesifikasi nested"
 
-#: cp/parser.c:6426 cp/typeck.c:2684 cp/typeck.c:2687 cp/typeck.c:2704
+#: cp/parser.c:6429 cp/typeck.c:2684 cp/typeck.c:2687 cp/typeck.c:2704
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD bukan sebuah template"
 
-#: cp/parser.c:6504
+#: cp/parser.c:6507
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "expected nested-name-specifier"
 msgstr "diduga penspesifikasi deklarasi"
 
-#: cp/parser.c:6711 cp/parser.c:8950
+#: cp/parser.c:6714 cp/parser.c:8950
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in casts"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:6797
+#: cp/parser.c:6800
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in a %<typeid%> expression"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:6889
+#: cp/parser.c:6892
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "jumlah dari argumen ke fungsi %<__builtin_next_arg%> salah"
 
-#: cp/parser.c:6901 cp/pt.c:18416
+#: cp/parser.c:6904 cp/pt.c:18453
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "jumlah dari argumen ke fungsi %<__builtin_next_arg%> salah"
 
-#: cp/parser.c:6995
+#: cp/parser.c:6998
 #, gcc-internal-format
 msgid "ISO C++ forbids compound-literals"
 msgstr "ISO C++ melarang compound literals"
 
-#: cp/parser.c:7054
+#: cp/parser.c:7057
 #, gcc-internal-format
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
@@ -51218,7 +51262,7 @@
 msgid "capture of non-variable %qE"
 msgstr "peningkatan dari variabel baca-saja %qD"
 
-#: cp/parser.c:10391 cp/parser.c:10401 cp/semantics.c:3453 cp/semantics.c:3465
+#: cp/parser.c:10391 cp/parser.c:10401 cp/semantics.c:3456 cp/semantics.c:3468
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%q#D declared here"
@@ -51315,7 +51359,7 @@
 msgid "init-statement in selection statements only available with -std=c++17 or -std=gnu++17"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:11546 cp/parser.c:28490
+#: cp/parser.c:11546 cp/parser.c:28487
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration or statement"
 msgid "expected selection-statement"
@@ -51338,225 +51382,225 @@
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:12250 cp/parser.c:28493
+#: cp/parser.c:12250 cp/parser.c:28490
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration or statement"
 msgid "expected iteration-statement"
 msgstr "diduga deklarasi atau pernyataan"
 
-#: cp/parser.c:12298
+#: cp/parser.c:12297
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:12426
+#: cp/parser.c:12423
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr ""
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:12434
+#: cp/parser.c:12431
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ melarang gotos yang sudah dihitung"
 
-#: cp/parser.c:12447 cp/parser.c:28496
+#: cp/parser.c:12444 cp/parser.c:28493
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected jump-statement"
 msgstr "diduga pernyataan"
 
-#: cp/parser.c:12620 cp/parser.c:23584
+#: cp/parser.c:12617 cp/parser.c:23581
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "kelebihan %<;%>"
 
-#: cp/parser.c:12863
+#: cp/parser.c:12860
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<__label__%> not at the beginning of a block"
 msgid "%<__label__%> not at the beginning of a block"
 msgstr "%H%<__label__%> tidak berada diawal dari sebuah blok"
 
-#: cp/parser.c:13083
+#: cp/parser.c:13080
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:13103
+#: cp/parser.c:13100
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr ""
 
-#: cp/parser.c:13124
+#: cp/parser.c:13121
 #, fuzzy, gcc-internal-format
 #| msgid "%Hmixing declarations and function-definitions is forbidden"
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr "%Hpencampuran deklarasi dan definisi fungsi dilarang"
 
-#: cp/parser.c:13148
+#: cp/parser.c:13145
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in a for-range-declaration"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:13203
+#: cp/parser.c:13200
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13206
+#: cp/parser.c:13203
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13257
+#: cp/parser.c:13254
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "structured bindings only available with -std=c++17 or -std=gnu++17"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:13306
+#: cp/parser.c:13303
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "empty structured binding declaration"
 msgstr "deklarasi kosong"
 
-#: cp/parser.c:13324
+#: cp/parser.c:13321
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member function declaration"
 msgid "invalid initializer for structured binding declaration"
 msgstr "deklarasi anggota fungsi tidak valid"
 
-#: cp/parser.c:13491
+#: cp/parser.c:13488
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<friend%> used outside of class"
 msgid "%<friend%> used outside of class"
 msgstr "%H%<friend%> digunakan diluar dari kelas"
 
-#: cp/parser.c:13558
+#: cp/parser.c:13555
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<auto%> will change meaning in C++0x; please remove it"
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr "%H%<auto%> akan mengubah arti dalam C++0x; mohon hapus itu"
 
-#: cp/parser.c:13594
+#: cp/parser.c:13591
 #, fuzzy, gcc-internal-format
 #| msgid "%Hpure-specifier on function-definition"
 msgid "decl-specifier invalid in condition"
 msgstr "%Hpenspesifikasi pure di definisi fungsi"
 
-#: cp/parser.c:13600
+#: cp/parser.c:13597
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D invalid in %q#T"
 msgid "%qD invalid in lambda"
 msgstr "%q+D tidak valid dalam %q#T"
 
-#: cp/parser.c:13693
+#: cp/parser.c:13690
 #, fuzzy, gcc-internal-format
 #| msgid "%Hclass definition may not be declared a friend"
 msgid "class definition may not be declared a friend"
 msgstr "%Hdefinisi kelas mungkin tidka dideklarasikan sebagai friend"
 
-#: cp/parser.c:13763 cp/parser.c:24064
+#: cp/parser.c:13760 cp/parser.c:24061
 #, fuzzy, gcc-internal-format
 #| msgid "%Htemplates may not be %<virtual%>"
 msgid "templates may not be %<virtual%>"
 msgstr "%Htemplate mungkin bukan %<virtual%>"
 
-#: cp/parser.c:13805
+#: cp/parser.c:13802
 #, fuzzy, gcc-internal-format
 #| msgid "invalid base-class specification"
 msgid "invalid linkage-specification"
 msgstr "spesifikasi kelas dasar tidak valid"
 
-#: cp/parser.c:13909
+#: cp/parser.c:13906
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "static_assert without a message only available with -std=c++17 or -std=gnu++17"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:14111
+#: cp/parser.c:14108
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:14264
+#: cp/parser.c:14261
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in a conversion-type-id"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:14291
+#: cp/parser.c:14288
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "penggunaan tidak valid dari %<auto%> dalam operator konversi"
 
-#: cp/parser.c:14295
+#: cp/parser.c:14292
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%> in conversion operator"
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr "penggunaan tidak valid dari %<auto%> dalam operator konversi"
 
-#: cp/parser.c:14379
+#: cp/parser.c:14376
 #, fuzzy, gcc-internal-format
 #| msgid "%Honly constructors take base initializers"
 msgid "only constructors take member initializers"
 msgstr "%Hhanya konstruktor yang mengambil penginisialisasi dasar"
 
-#: cp/parser.c:14406
+#: cp/parser.c:14403
 #, fuzzy, gcc-internal-format
 #| msgid "%Hcannot expand initializer for member %<%D%>"
 msgid "cannot expand initializer for member %qD"
 msgstr "%Htidak dapat mengekspand penginisialisasi untuk anggota %<%D%>"
 
-#: cp/parser.c:14418 cp/pt.c:24255
+#: cp/parser.c:14415 cp/pt.c:24333
 #, fuzzy, gcc-internal-format
 #| msgid "static declaration of %q+D follows non-static declaration"
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "deklarasi statis dari %q+D mengikuti deklarasi bukan statis"
 
-#: cp/parser.c:14430 cp/pt.c:24267
+#: cp/parser.c:14427 cp/pt.c:24345
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
 
-#: cp/parser.c:14482
+#: cp/parser.c:14479
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr "anachronistic gaya-lama kelas dasar penginisialisasi"
 
-#: cp/parser.c:14552
+#: cp/parser.c:14549
 #, fuzzy, gcc-internal-format
 #| msgid "%Hkeyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr "%Hkata kunci %<typename%> tidak diijinkan dalam konteks ini (sebuah anggota terkualifikasi secara implisit adalah sebuah tipe)"
 
-#: cp/parser.c:14927
+#: cp/parser.c:14924
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr ""
 
-#: cp/parser.c:14933
+#: cp/parser.c:14930
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier"
 msgid "expected suffix identifier"
 msgstr "diduga pengidentifikasi"
 
-#: cp/parser.c:14942
+#: cp/parser.c:14939
 #, fuzzy, gcc-internal-format
 #| msgid "expected a string after %<#pragma message%>"
 msgid "expected empty string after %<operator%> keyword"
 msgstr "diduga sebuah string setelah %<#pragma message%>"
 
-#: cp/parser.c:14948
+#: cp/parser.c:14945
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands in binary operation"
 msgid "invalid encoding prefix in literal operator"
 msgstr "operan tidak valid dalam operasi binary"
 
-#: cp/parser.c:14975
+#: cp/parser.c:14972
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected operator"
@@ -51563,69 +51607,69 @@
 msgstr "operan tidak terduga"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:15020
+#: cp/parser.c:15017
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "kata kunci %<export%> tidak terimplementasi, dan akan diabaikan"
 
-#: cp/parser.c:15190
+#: cp/parser.c:15187
 #, fuzzy, gcc-internal-format
 #| msgid "invalid constraints for operand"
 msgid "invalid constrained type parameter"
 msgstr "batasan untuk operan tidak valid"
 
-#: cp/parser.c:15198
+#: cp/parser.c:15195
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "cv-qualified type parameter"
 msgstr "tipe argumen tidak valid"
 
-#: cp/parser.c:15283
+#: cp/parser.c:15280
 #, gcc-internal-format
 msgid "variadic constraint introduced without %<...%>"
 msgstr ""
 
-#: cp/parser.c:15347
+#: cp/parser.c:15344
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%> in conversion operator"
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "penggunaan tidak valid dari %<auto%> dalam operator konversi"
 
-#: cp/parser.c:15582 cp/parser.c:15668 cp/parser.c:21694
+#: cp/parser.c:15579 cp/parser.c:15665 cp/parser.c:21691
 #, fuzzy, gcc-internal-format
 #| msgid "%Htemplate parameter pack %qD cannot have a default argument"
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "%Htemplate parameter pack %qD tidak dapat memiliki sebuah argumen baku"
 
-#: cp/parser.c:15586 cp/parser.c:15672
+#: cp/parser.c:15583 cp/parser.c:15669
 #, fuzzy, gcc-internal-format
 #| msgid "%Htemplate parameter packs cannot have default arguments"
 msgid "template parameter packs cannot have default arguments"
 msgstr "%Htemplate parameter pack tidak dapat memiliki argumen baku"
 
-#: cp/parser.c:15738
+#: cp/parser.c:15735
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected template-id"
 msgstr "diduga pernyataan"
 
-#: cp/parser.c:15798
+#: cp/parser.c:15795
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "%<<::%> tidak dapat berawal sebuah daftar template argumen"
 
-#: cp/parser.c:15802
+#: cp/parser.c:15799
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr "%<<:%> adalah sebuah penyebutan alternatif untuk %<[%>. Masukan spasi diantara %<<%> dan %<::%>"
 
-#: cp/parser.c:15806
+#: cp/parser.c:15803
 #, fuzzy, gcc-internal-format
 #| msgid "(if you use %<-fpermissive%> G++ will accept your code)"
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr "(jika anda menggunakan %<-fpermissive%> G++ akan menerima kode anda)"
 
-#: cp/parser.c:15924
+#: cp/parser.c:15921
 #, fuzzy, gcc-internal-format
 #| msgid "%Hparse error in template argument list"
 msgid "parse error in template argument list"
@@ -51632,7 +51676,7 @@
 msgstr "%Hparse error dalam daftar argumen template"
 
 #. The name does not name a template.
-#: cp/parser.c:15992 cp/parser.c:16122 cp/parser.c:16337
+#: cp/parser.c:15989 cp/parser.c:16119 cp/parser.c:16334
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected template-name"
@@ -51639,333 +51683,333 @@
 msgstr "diduga pernyataan"
 
 #. Explain what went wrong.
-#: cp/parser.c:16038
+#: cp/parser.c:16035
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnon-template %qD used as template"
 msgid "non-template %qD used as template"
 msgstr "%Hbukan-template %qD digunakan sebagai template"
 
-#: cp/parser.c:16040
+#: cp/parser.c:16037
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr "gunakan %<%T::template %D%> untuk mengindikasikan bahwa ini adalah template"
 
-#: cp/parser.c:16189
+#: cp/parser.c:16186
 #, fuzzy, gcc-internal-format
 #| msgid "%Hexpected parameter pack before %<...%>"
 msgid "expected parameter pack before %<...%>"
 msgstr "%Hdiduga parameter pack sebelum %<...%>"
 
-#: cp/parser.c:16298 cp/parser.c:16316 cp/parser.c:16483
+#: cp/parser.c:16295 cp/parser.c:16313 cp/parser.c:16480
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected template-argument"
 msgstr "diduga pernyataan"
 
-#: cp/parser.c:16458
+#: cp/parser.c:16455
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "invalid non-type template argument"
 msgstr "tipe argumen tidak valid"
 
-#: cp/parser.c:16585
+#: cp/parser.c:16582
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type %qT"
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "eksplisit instantiation dari tipe bukan template %qT"
 
-#: cp/parser.c:16589
+#: cp/parser.c:16586
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type %qT"
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "eksplisit instantiation dari tipe bukan template %qT"
 
-#: cp/parser.c:16648
+#: cp/parser.c:16645
 #, fuzzy, gcc-internal-format
 #| msgid "%Htemplate specialization with C linkage"
 msgid "template specialization with C linkage"
 msgstr "%Hspesialisasi template dengan C linkage"
 
-#: cp/parser.c:16869
+#: cp/parser.c:16866
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "expected type specifier"
 msgstr "diduga penspesifikasi deklarasi"
 
-#: cp/parser.c:17053
+#: cp/parser.c:17050
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:17059
+#: cp/parser.c:17056
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:17064
+#: cp/parser.c:17061
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -fconcepts"
 msgstr ""
 
-#: cp/parser.c:17209
+#: cp/parser.c:17206
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "expected template-id for type"
 msgstr "Diduga tipe ekspresi"
 
-#: cp/parser.c:17278
+#: cp/parser.c:17275
 #, fuzzy, gcc-internal-format
 #| msgid "Expected name"
 msgid "expected type-name"
 msgstr "Diduga nama"
 
-#: cp/parser.c:17631
+#: cp/parser.c:17628
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr ""
 
-#: cp/parser.c:17854
+#: cp/parser.c:17851
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "deklarasi %qD tidak mendeklarasikan apapun"
 
-#: cp/parser.c:17942
+#: cp/parser.c:17939
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "atribut diabaikan di tipe uninstantiasi"
 
-#: cp/parser.c:17946
+#: cp/parser.c:17943
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "atribut diabaikan di template instantiation"
 
-#: cp/parser.c:17951
+#: cp/parser.c:17948
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr "atribut diabaikan di elaborated type penspesifikasi yang tidak memforward sebuah deklarasi"
 
-#: cp/parser.c:18085
+#: cp/parser.c:18082
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%qD is an enumeration template"
 msgstr "%qD bukan sebuah template fungsi"
 
-#: cp/parser.c:18096
+#: cp/parser.c:18093
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qT"
 msgid "%qD does not name an enumeration in %qT"
 msgstr "%qD bukan sebuah anggota dari %qT"
 
-#: cp/parser.c:18111
+#: cp/parser.c:18108
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<namespace%> definition is not allowed here"
 msgid "unnamed scoped enum is not allowed"
 msgstr "%H%<namespace%> definisi tidak diijinkan disini"
 
-#: cp/parser.c:18166
+#: cp/parser.c:18163
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<;%> or %<{%>"
 msgstr "diduga %<,%> atau %<,%>"
 
-#: cp/parser.c:18215
+#: cp/parser.c:18212
 #, fuzzy, gcc-internal-format
 #| msgid "Enable automatic template instantiation"
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "Aktifkan instantiation template otomatis"
 
-#: cp/parser.c:18229
+#: cp/parser.c:18226
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfriend declaration does not name a class or function"
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "%Hdeklarasi friend tidak bernama sebuah kelas atau fungsi"
 
-#: cp/parser.c:18241 cp/parser.c:23070
+#: cp/parser.c:18238 cp/parser.c:23067
 #, fuzzy, gcc-internal-format
 #| msgid "%Hdeclaration of %qD in namespace %qD which does not enclose %qD"
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "%Hdeklarasi dari %qD dalam namespace %qD yang tidak dilingkupi %qD"
 
-#: cp/parser.c:18246 cp/parser.c:23075
+#: cp/parser.c:18243 cp/parser.c:23072
 #, fuzzy, gcc-internal-format
 #| msgid "%Hdeclaration of %qD in %qD which does not enclose %qD"
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "%Hdeklarasi dari %qD dalam %qD yang tidak dilingkup %qD"
 
-#: cp/parser.c:18258 cp/parser.c:23089
+#: cp/parser.c:18255 cp/parser.c:23086
 #, fuzzy, gcc-internal-format
 #| msgid "%Hextra qualification not allowed"
 msgid "extra qualification not allowed"
 msgstr "%Hekstra pengkualifikasi diabaikan"
 
-#: cp/parser.c:18282
+#: cp/parser.c:18279
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "multiple definisi dari %q#T"
 
-#: cp/parser.c:18295
+#: cp/parser.c:18292
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids incrementing an enum"
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO C++ melarang menaikkan sebuah enum"
 
-#: cp/parser.c:18315
+#: cp/parser.c:18312
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:18318
+#: cp/parser.c:18315
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:18497
+#: cp/parser.c:18494
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qD is not a namespace-name"
 msgid "%qD is not a namespace-name"
 msgstr "%H%qD bukan sebuah nama namespace"
 
-#: cp/parser.c:18503
+#: cp/parser.c:18500
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected namespace-name"
 msgstr "diduga nama class"
 
-#: cp/parser.c:18570
+#: cp/parser.c:18567
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "nested namespace definitions only available with -std=c++17 or -std=gnu++17"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:18578
+#: cp/parser.c:18575
 #, gcc-internal-format
 msgid "nested namespace name required"
 msgstr ""
 
-#: cp/parser.c:18583
+#: cp/parser.c:18580
 #, gcc-internal-format
 msgid "namespace name required"
 msgstr ""
 
-#: cp/parser.c:18587
+#: cp/parser.c:18584
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<namespace%> definition is not allowed here"
 msgid "a nested namespace definition cannot have attributes"
 msgstr "%H%<namespace%> definisi tidak diijinkan disini"
 
-#: cp/parser.c:18590
+#: cp/parser.c:18587
 #, fuzzy, gcc-internal-format
 #| msgid "Warn when an inlined function cannot be inlined"
 msgid "a nested namespace definition cannot be inline"
 msgstr "Peringatkan ketika sebuah fungsi inline tidak dapat diinline"
 
-#: cp/parser.c:18597
+#: cp/parser.c:18594
 #, fuzzy, gcc-internal-format
 #| msgid "use of namespace %qD as expression"
 msgid "namespace %qD entered"
 msgstr "penggunaan dari namespace %qD  sebagai ekspresi"
 
-#: cp/parser.c:18652
+#: cp/parser.c:18649
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<namespace%> definition is not allowed here"
 msgid "%<namespace%> definition is not allowed here"
 msgstr "%H%<namespace%> definisi tidak diijinkan disini"
 
-#: cp/parser.c:18803
+#: cp/parser.c:18800
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "pack expansion in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:18818
+#: cp/parser.c:18815
 #, fuzzy, gcc-internal-format
 #| msgid "%Ha template-id may not appear in a using-declaration"
 msgid "a template-id may not appear in a using-declaration"
 msgstr "%Hsebuah template-id mungkin tidak muncul dalam sebuah using deklarasi"
 
-#: cp/parser.c:18865
+#: cp/parser.c:18862
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "comma-separated list in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:18875
+#: cp/parser.c:18872
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:18940
+#: cp/parser.c:18937
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in alias template declarations"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:19106
+#: cp/parser.c:19103
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:19493
+#: cp/parser.c:19490
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<namespace%> definition is not allowed here"
 msgid "a function-definition is not allowed here"
 msgstr "%H%<namespace%> definisi tidak diijinkan disini"
 
-#: cp/parser.c:19504
+#: cp/parser.c:19501
 #, fuzzy, gcc-internal-format
 #| msgid "%Han asm-specification is not allowed on a function-definition"
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr "%Hsebuah spesifikasi asm tidak diijinkan dalam sebuah definisi fungsi"
 
-#: cp/parser.c:19508
+#: cp/parser.c:19505
 #, fuzzy, gcc-internal-format
 #| msgid "%Hattributes are not allowed on a function-definition"
 msgid "attributes are not allowed on a function-definition"
 msgstr "%Hatribut tidak diijinkan dalam sebuah definisi fungsi"
 
-#: cp/parser.c:19559
+#: cp/parser.c:19556
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
 #. Anything else is an error.
-#: cp/parser.c:19598 cp/parser.c:21906
+#: cp/parser.c:19595 cp/parser.c:21903
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier"
 msgid "expected initializer"
 msgstr "diduga pengidentifikasi"
 
-#: cp/parser.c:19679
+#: cp/parser.c:19676
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinitializer provided for function"
 msgid "initializer provided for function"
 msgstr "%Hpenginisialisasi disediakan untuk fungsi"
 
-#: cp/parser.c:19713
+#: cp/parser.c:19710
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "atribut setelah tanda kurung penginisialisasi diabaikan"
 
-#: cp/parser.c:19727
+#: cp/parser.c:19724
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared as inline"
 msgid "non-function %qD declared as implicit template"
 msgstr "fungsi %q+D redeklarasi sebagai inline"
 
-#: cp/parser.c:20169
+#: cp/parser.c:20166
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "array bound bukan sebuah konstanta integer"
 
-#: cp/parser.c:20295
+#: cp/parser.c:20292
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type %qT"
 msgid "cannot define member of dependent typedef %qT"
 msgstr "membuat penunjuk ke anggota referensi tipe %qT"
 
-#: cp/parser.c:20299
+#: cp/parser.c:20296
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<%T::%E%> is not a type"
 msgid "%<%T::%E%> is not a type"
@@ -51975,19 +52019,19 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:20328
+#: cp/parser.c:20325
 #, fuzzy, gcc-internal-format
 #| msgid "invalid function declaration"
 msgid "invalid declarator"
 msgstr "deklarasi fungsi tidak valid"
 
-#: cp/parser.c:20336
+#: cp/parser.c:20333
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid use of constructor as a template"
 msgid "invalid use of constructor as a template"
 msgstr "%Hpenggunaan tidak valid dari konstruktor sebagai sebuah template"
 
-#: cp/parser.c:20338
+#: cp/parser.c:20335
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr "penggunaan %<%T::%D%> daripada %<%T::%D%> untuk menamai konstruktor dalam sebuah nama berkualifikasi"
@@ -51994,438 +52038,438 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:20410
+#: cp/parser.c:20407
 #, fuzzy, gcc-internal-format
 #| msgid "invalid function declaration"
 msgid "qualified-id in declaration"
 msgstr "deklarasi fungsi tidak valid"
 
-#: cp/parser.c:20435
+#: cp/parser.c:20432
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "expected declarator"
 msgstr "diduga penspesifikasi deklarasi"
 
-#: cp/parser.c:20554
+#: cp/parser.c:20551
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qD is a namespace"
 msgid "%qD is a namespace"
 msgstr "%H%qD adalah sebuah namespace"
 
-#: cp/parser.c:20556
+#: cp/parser.c:20553
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "membuat penunjuk ke anggota dari tipe bukan kelas %qT"
 
-#: cp/parser.c:20577
+#: cp/parser.c:20574
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected ptr-operator"
 msgstr "operan tidak terduga"
 
-#: cp/parser.c:20638
+#: cp/parser.c:20635
 #, fuzzy, gcc-internal-format
 #| msgid "%Hduplicate cv-qualifier"
 msgid "duplicate cv-qualifier"
 msgstr "%Hduplikasi cv kualifikasi"
 
-#: cp/parser.c:20692
+#: cp/parser.c:20689
 #, fuzzy, gcc-internal-format
 #| msgid "multiple inline callers"
 msgid "multiple ref-qualifiers"
 msgstr "multiple pemanggil inline"
 
-#: cp/parser.c:20729
+#: cp/parser.c:20726
 #, gcc-internal-format
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr ""
 
-#: cp/parser.c:20787
+#: cp/parser.c:20784
 #, fuzzy, gcc-internal-format
 #| msgid "%Hduplicate cv-qualifier"
 msgid "duplicate virt-specifier"
 msgstr "%Hduplikasi cv kualifikasi"
 
-#: cp/parser.c:21025
+#: cp/parser.c:21022
 #, fuzzy, gcc-internal-format
 #| msgid "missing makefile target after %qs"
 msgid "missing template arguments after %qT"
 msgstr "hilang target makefile setelah %qs"
 
-#: cp/parser.c:21031 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2090
+#: cp/parser.c:21028 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2093
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qD"
 msgid "invalid use of %qT"
 msgstr "penggunaan tidak valid dari %qD"
 
-#: cp/parser.c:21052
+#: cp/parser.c:21049
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in template arguments"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:21057
+#: cp/parser.c:21054
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%> in conversion operator"
 msgid "invalid use of %<auto%> in template argument"
 msgstr "penggunaan tidak valid dari %<auto%> dalam operator konversi"
 
-#: cp/parser.c:21145
+#: cp/parser.c:21142
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier"
 msgid "expected type-specifier"
 msgstr "diduga pengidentifikasi"
 
-#: cp/parser.c:21429
+#: cp/parser.c:21426
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<...%>"
 msgid "expected %<,%> or %<...%>"
 msgstr "diduga %<:%> atau %<...%>"
 
-#: cp/parser.c:21504
+#: cp/parser.c:21501
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in parameter types"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:21678
+#: cp/parser.c:21675
 #, fuzzy, gcc-internal-format
 #| msgid "%Hdefault arguments are only permitted for function parameters"
 msgid "default arguments are only permitted for function parameters"
 msgstr "%Hargumen baku hanya diijinkan untuk parameter fungsi"
 
-#: cp/parser.c:21696
+#: cp/parser.c:21693
 #, fuzzy, gcc-internal-format
 #| msgid "%H%sparameter pack %qD cannot have a default argument"
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "%H%s parameter pack %qD tidak dapat memiliki sebuah argumen baku"
 
-#: cp/parser.c:21702
+#: cp/parser.c:21699
 #, fuzzy, gcc-internal-format
 #| msgid "%Htemplate parameter pack cannot have a default argument"
 msgid "template parameter pack cannot have a default argument"
 msgstr "%Htemplate parameter pack tidak dapat memiliki sebuah argumen baku"
 
-#: cp/parser.c:21704
+#: cp/parser.c:21701
 #, fuzzy, gcc-internal-format
 #| msgid "%H%sparameter pack cannot have a default argument"
 msgid "parameter pack cannot have a default argument"
 msgstr "%H%s parameter pack tidak dapat memiliki sebuah argumen baku"
 
-#: cp/parser.c:22131
+#: cp/parser.c:22128
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "C++ designated initializers only available with -std=c++2a or -std=gnu++2a"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:22151
+#: cp/parser.c:22148
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr "ISO C++ tidak mengijinkan designated penginisialisasi"
 
-#: cp/parser.c:22189
+#: cp/parser.c:22186
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C++ tidak mengijinkan designated penginisialisasi"
 
-#: cp/parser.c:22203
+#: cp/parser.c:22200
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr ""
 
-#: cp/parser.c:22228
+#: cp/parser.c:22225
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "%<...%> not allowed in designated initializer list"
 msgstr "ISO C++ tidak mengijinkan designated penginisialisasi"
 
-#: cp/parser.c:22266
+#: cp/parser.c:22263
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr ""
 
-#: cp/parser.c:22322 cp/parser.c:22448
+#: cp/parser.c:22319 cp/parser.c:22445
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected class-name"
 msgstr "diduga nama class"
 
-#: cp/parser.c:22650
+#: cp/parser.c:22647
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "expected %<;%> after class definition"
 msgstr "%q+D dideklarasikan inline setelah definisinya"
 
-#: cp/parser.c:22653
+#: cp/parser.c:22650
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "expected %<;%> after struct definition"
 msgstr "%q+D dideklarasikan inline setelah definisinya"
 
-#: cp/parser.c:22656
+#: cp/parser.c:22653
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected junk after function declaration at %C"
 msgid "expected %<;%> after union definition"
 msgstr "Tidak terduga sampah setelah deklarasi fungsi di %C"
 
-#: cp/parser.c:23012
+#: cp/parser.c:23009
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<{%> or %<:%>"
 msgstr "diduga %<,%> atau %<,%>"
 
-#: cp/parser.c:23023
+#: cp/parser.c:23020
 #, fuzzy, gcc-internal-format
 #| msgid "cannot find file for class %s"
 msgid "cannot specify %<override%> for a class"
 msgstr "tidak dapat menemukan berkas untuk class %s"
 
-#: cp/parser.c:23031
+#: cp/parser.c:23028
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:23038
+#: cp/parser.c:23035
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfriend declaration does not name a class or function"
 msgid "qualified name does not name a class"
 msgstr "%Hdeklarasi friend tidak bernama sebuah kelas atau fungsi"
 
-#: cp/parser.c:23050
+#: cp/parser.c:23047
 #, fuzzy, gcc-internal-format
 #| msgid "%Hkeyword %<typename%> not allowed outside of templates"
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr "%Hkata kunci %<typename%> tidak diijinkan diluar dari templates"
 
-#: cp/parser.c:23056
+#: cp/parser.c:23053
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid class name in declaration of %qD"
 msgid "invalid class name in declaration of %qD"
 msgstr "%Hnama kelas tidak valid dalam deklarasi dari %qD"
 
-#: cp/parser.c:23114
+#: cp/parser.c:23111
 #, fuzzy, gcc-internal-format
 #| msgid "%Han explicit specialization must be preceded by %<template <>%>"
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "%Hsebuah eksplisit spesialisasi harus diawali oleh %<template <>%>"
 
-#: cp/parser.c:23146
+#: cp/parser.c:23143
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfunction template %qD redeclared as a class template"
 msgid "function template %qD redeclared as a class template"
 msgstr "%Htemplate fungsi %qD redeklarasikan sebagai sebuah template kelas"
 
-#: cp/parser.c:23182
+#: cp/parser.c:23179
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr ""
 
-#: cp/parser.c:23241
+#: cp/parser.c:23238
 #, fuzzy, gcc-internal-format
 #| msgid "%Hprevious definition of %q+#T"
 msgid "previous definition of %q#T"
 msgstr "%Hdefinisi sebelumnya dari %q+#T"
 
-#: cp/parser.c:23331 cp/parser.c:28499
+#: cp/parser.c:23328 cp/parser.c:28496
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected class-key"
 msgstr "diduga nama class"
 
-#: cp/parser.c:23355
+#: cp/parser.c:23352
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:23359
+#: cp/parser.c:23356
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<class%> or %<typename%>"
 msgstr "diduga %<,%> atau %<,%>"
 
-#: cp/parser.c:23605
+#: cp/parser.c:23602
 #, fuzzy, gcc-internal-format
 #| msgid "%Ha class-key must be used when declaring a friend"
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr "%Hsebuah class-key harus digunakan ketikan mendeklarasikan sebuah friend"
 
-#: cp/parser.c:23623
+#: cp/parser.c:23620
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfriend declaration does not name a class or function"
 msgid "friend declaration does not name a class or function"
 msgstr "%Hdeklarasi friend tidak bernama sebuah kelas atau fungsi"
 
-#: cp/parser.c:23641
+#: cp/parser.c:23638
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:23738
+#: cp/parser.c:23735
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "default member initializers for bit-fields only available with -std=c++2a or -std=gnu++2a"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:23745
+#: cp/parser.c:23742
 #, gcc-internal-format
 msgid "default member initializer for unnamed bit-field"
 msgstr ""
 
-#: cp/parser.c:23758
+#: cp/parser.c:23755
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr ""
 
-#: cp/parser.c:23903
+#: cp/parser.c:23900
 #, fuzzy, gcc-internal-format
 #| msgid "%Hpure-specifier on function-definition"
 msgid "pure-specifier on function-definition"
 msgstr "%Hpenspesifikasi pure di definisi fungsi"
 
-#: cp/parser.c:23923
+#: cp/parser.c:23920
 #, gcc-internal-format
 msgid "extra %<;%> after in-class function definition"
 msgstr ""
 
-#: cp/parser.c:23970
+#: cp/parser.c:23967
 #, fuzzy, gcc-internal-format
 #| msgid "%<[*]%> not in a declaration"
 msgid "stray %<,%> at end of member declaration"
 msgstr "%<[*]%> tidak dalam sebuah deklarasi"
 
-#: cp/parser.c:23984
+#: cp/parser.c:23981
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<(%> or end of line"
 msgid "expected %<;%> at end of member declaration"
 msgstr "diduga %<(%> atau akhir dari baris"
 
-#: cp/parser.c:24058
+#: cp/parser.c:24055
 #, fuzzy, gcc-internal-format
 #| msgid "invalid AE type specified (%s)\n"
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr "tipe AE yang dispesifikasikan (%s) tidak valid\n"
 
-#: cp/parser.c:24093
+#: cp/parser.c:24090
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<namespace%> definition is not allowed here"
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "%H%<namespace%> definisi tidak diijinkan disini"
 
-#: cp/parser.c:24223
+#: cp/parser.c:24220
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr ""
 
-#: cp/parser.c:24243
+#: cp/parser.c:24240
 #, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr ""
 
-#: cp/parser.c:24267
+#: cp/parser.c:24264
 #, fuzzy, gcc-internal-format
 #| msgid "%Hkeyword %<typename%> not allowed outside of templates"
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "%Hkata kunci %<typename%> tidak diijinkan diluar dari templates"
 
-#: cp/parser.c:24270
+#: cp/parser.c:24267
 #, fuzzy, gcc-internal-format
 #| msgid "%Hkeyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "%Hkata kunci %<typename%> tidak diijinkan dalam konteks ini (kelas dasar  adalah sebuah tipe implisit)"
 
-#: cp/parser.c:24364 cp/parser.c:24442
+#: cp/parser.c:24361 cp/parser.c:24439
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in an exception-specification"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:24450
+#: cp/parser.c:24447
 #, fuzzy, gcc-internal-format
 #| msgid "due to different exception specifications"
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "karena perbedaan eksepsi spesifikasi"
 
-#: cp/parser.c:24456
+#: cp/parser.c:24453
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr ""
 
-#: cp/parser.c:24500
+#: cp/parser.c:24497
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%> in conversion operator"
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "penggunaan tidak valid dari %<auto%> dalam operator konversi"
 
-#: cp/parser.c:24539
+#: cp/parser.c:24536
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:24650
+#: cp/parser.c:24647
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in exception-declarations"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:25203
+#: cp/parser.c:25200
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr "%s atribut konflik dengan %s atribut di %L"
 
-#: cp/parser.c:25217
+#: cp/parser.c:25214
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier or %<(%>"
 msgid "expected an identifier for the attribute name"
 msgstr "diduga pengidentifikasi atau %<(%>"
 
-#: cp/parser.c:25301
+#: cp/parser.c:25298
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:25305
+#: cp/parser.c:25302
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:25342
+#: cp/parser.c:25339
 #, fuzzy, gcc-internal-format
 #| msgid "%Hexpected parameter pack before %<...%>"
 msgid "expected attribute before %<...%>"
 msgstr "%Hdiduga parameter pack sebelum %<...%>"
 
-#: cp/parser.c:25403
+#: cp/parser.c:25400
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "attribute using prefix only available with -std=c++17 or -std=gnu++17"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:25721
+#: cp/parser.c:25718
 #, gcc-internal-format
 msgid "%<requires%> only available with -fconcepts"
 msgstr ""
 
-#: cp/parser.c:25753
+#: cp/parser.c:25750
 #, gcc-internal-format
 msgid "a requires expression cannot appear outside a template"
 msgstr ""
 
-#: cp/parser.c:26467
+#: cp/parser.c:26464
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:26472
+#: cp/parser.c:26469
 #, fuzzy, gcc-internal-format
 #| msgid "invalid redeclaration of %q+D"
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "redeklarasi tidak valid dari %q+D"
 
-#: cp/parser.c:26476
+#: cp/parser.c:26473
 #, fuzzy, gcc-internal-format
 #| msgid "%Htoo few template-parameter-lists"
 msgid "too few template-parameter-lists"
@@ -52435,469 +52479,469 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:26483
+#: cp/parser.c:26480
 #, fuzzy, gcc-internal-format
 #| msgid "%Htoo many template-parameter-lists"
 msgid "too many template-parameter-lists"
 msgstr "%Hterlalu banyak template-parameter-lists"
 
-#: cp/parser.c:26832
+#: cp/parser.c:26829
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnamed return values are no longer supported"
 msgid "named return values are no longer supported"
 msgstr "%Hnilai kembali bernama tidak lagi didukung"
 
-#: cp/parser.c:26991
+#: cp/parser.c:26988
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr ""
 
-#: cp/parser.c:26996
+#: cp/parser.c:26993
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr ""
 
-#: cp/parser.c:27066
+#: cp/parser.c:27063
 #, fuzzy, gcc-internal-format
 #| msgid "Use media instructions"
 msgid "empty introduction-list"
 msgstr "Gunakan instruksi media"
 
-#: cp/parser.c:27090
+#: cp/parser.c:27087
 #, fuzzy, gcc-internal-format
 #| msgid "no matching template for %qD found"
 msgid "no matching concept for template-introduction"
 msgstr "template tidak cocok untuk %qD yang ditemukan"
 
-#: cp/parser.c:27112
+#: cp/parser.c:27109
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid declaration of member template in local class"
 msgid "invalid declaration of member template in local class"
 msgstr "%Hdeklarasi tidak valid dari anggota template dalam kelas lokal"
 
-#: cp/parser.c:27121
+#: cp/parser.c:27118
 #, fuzzy, gcc-internal-format
 #| msgid "%Htemplate with C linkage"
 msgid "template with C linkage"
 msgstr "%Htemplate dengan C linkage"
 
-#: cp/parser.c:27141
+#: cp/parser.c:27138
 #, fuzzy, gcc-internal-format
 #| msgid "invalid base-class specification"
 msgid "invalid explicit specialization"
 msgstr "spesifikasi kelas dasar tidak valid"
 
-#: cp/parser.c:27245
+#: cp/parser.c:27242
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %q#D"
 msgid "template declaration of %<typedef%>"
 msgstr "template deklarasi dari %q#D"
 
-#: cp/parser.c:27296
+#: cp/parser.c:27293
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "a class template declaration must not declare anything else"
 msgstr "redeklarasi tidak mendeklarasikan apapun"
 
-#: cp/parser.c:27342
+#: cp/parser.c:27339
 #, fuzzy, gcc-internal-format
 #| msgid "%Hexplicit template specialization cannot have a storage class"
 msgid "explicit template specialization cannot have a storage class"
 msgstr "%Heksplisit template spesialisasi tidak dapat memiliki sebuah kelas penyimpanan"
 
-#: cp/parser.c:27650
+#: cp/parser.c:27647
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<>>%> should be %<> >%> within a nested template argument list"
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%H%<>>%> seharusnya %<> >%> didalam sebuah daftar argumen template nested"
 
-#: cp/parser.c:27663
+#: cp/parser.c:27660
 #, fuzzy, gcc-internal-format
 #| msgid "%Hspurious %<>>%>, use %<>%> to terminate a template argument list"
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "%Hspurious %<>>%>, gunakan %<>%> untuk mengakhiri sebuah daftar argumen template"
 
-#: cp/parser.c:27958
+#: cp/parser.c:27955
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:28118
+#: cp/parser.c:28115
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid use of %qD in linkage specification"
 msgid "invalid use of %qD in linkage specification"
 msgstr "%Hpenggunaan tidak valid dari %qD dalam spesifikasi linkage"
 
-#: cp/parser.c:28133
+#: cp/parser.c:28130
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<__thread%> before %qD"
 msgid "%<__thread%> before %qD"
 msgstr "%H%<__thread%> sebelum %qD"
 
-#: cp/parser.c:28267
+#: cp/parser.c:28264
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ 1998 tidak mendukung %<long long%>"
 
-#: cp/parser.c:28275
+#: cp/parser.c:28272
 #, fuzzy, gcc-internal-format
 #| msgid "both %<_Sat%> and %<char%> in declaration specifiers"
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "baik %<_Sat%> dan %<char%> dalam penspesifikasi deklarasi"
 
-#: cp/parser.c:28280
+#: cp/parser.c:28277
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %qE"
 msgid "duplicate %qD"
 msgstr "duplikasi %qE"
 
-#: cp/parser.c:28304
+#: cp/parser.c:28301
 #, fuzzy, gcc-internal-format
 #| msgid "%Hduplicate %qs"
 msgid "duplicate %qs"
 msgstr "%Hduplikasi %qs"
 
-#: cp/parser.c:28356
+#: cp/parser.c:28353
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<new%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:28359
+#: cp/parser.c:28356
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<delete%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:28362
+#: cp/parser.c:28359
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<return%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:28368
+#: cp/parser.c:28365
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<extern%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:28371
+#: cp/parser.c:28368
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected %<static_assert%>"
 msgstr "diduga pernyataan"
 
-#: cp/parser.c:28374
+#: cp/parser.c:28371
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<decltype%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:28377
+#: cp/parser.c:28374
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<operator%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:28380
+#: cp/parser.c:28377
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<class%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:28383
+#: cp/parser.c:28380
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<template%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:28386
+#: cp/parser.c:28383
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<namespace%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:28389
+#: cp/parser.c:28386
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<using%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:28392
+#: cp/parser.c:28389
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<asm%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:28395
+#: cp/parser.c:28392
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<try%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:28398
+#: cp/parser.c:28395
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<catch%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:28401
+#: cp/parser.c:28398
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<throw%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:28404
+#: cp/parser.c:28401
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<__label__%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:28407
+#: cp/parser.c:28404
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@try%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:28410
+#: cp/parser.c:28407
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@synchronized%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:28413
+#: cp/parser.c:28410
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@throw%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:28416
+#: cp/parser.c:28413
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.c:28419
+#: cp/parser.c:28416
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<__transaction_relaxed%>"
 msgstr "diduga %<none%> atau %<shared%>"
 
-#: cp/parser.c:28451
+#: cp/parser.c:28448
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<::%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:28463
+#: cp/parser.c:28460
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<...%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:28466
+#: cp/parser.c:28463
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<*%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:28469
+#: cp/parser.c:28466
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<~%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:28475
+#: cp/parser.c:28472
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<...%>"
 msgid "expected %<:%> or %<::%>"
 msgstr "diduga %<:%> atau %<...%>"
 
-#: cp/parser.c:28502
+#: cp/parser.c:28499
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "diduga %<,%>, %<,%> atau %<}%>"
 
-#: cp/parser.c:28772
+#: cp/parser.c:28769
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "%qs tag digunakan dalam penamaan %q#T"
 
-#: cp/parser.c:28777
+#: cp/parser.c:28774
 #, fuzzy, gcc-internal-format
 #| msgid "%q+T has a previous declaration here"
 msgid "%q#T was previously declared here"
 msgstr "%q+T telah dideklarasikan sebelumnya disini"
 
-#: cp/parser.c:28798
+#: cp/parser.c:28795
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qD redeclared with different access"
 msgid "%qD redeclared with different access"
 msgstr "%H%qD redeklarasi dengan akses berbeda"
 
-#: cp/parser.c:28819
+#: cp/parser.c:28816
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<template%> (as a disambiguator) is only allowed within templates"
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "%H%<template%> (sebagai sebuah disambiguator) hanya diijinkan dalam templates"
 
-#: cp/parser.c:29062
+#: cp/parser.c:29059
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfile ends in default argument"
 msgid "file ends in default argument"
 msgstr "%Hberkas berakhir dalam argumen baku"
 
-#: cp/parser.c:29303 cp/parser.c:30620 cp/parser.c:30808
+#: cp/parser.c:29300 cp/parser.c:30617 cp/parser.c:30805
 #, fuzzy, gcc-internal-format
 #| msgid "%Hmisplaced %<@%D%> Objective-C++ construct"
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "%Hsalah tempat %<@%D%> Objective-C++ konstruk"
 
-#: cp/parser.c:29372
+#: cp/parser.c:29369
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr ""
 
-#: cp/parser.c:29442
+#: cp/parser.c:29439
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:29473
+#: cp/parser.c:29470
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<@encode%> must specify a type as an argument"
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "%H%<@encode%> harus menspesifikasikan sebuah tipe sebagai sebuah argumen"
 
-#: cp/parser.c:29883
+#: cp/parser.c:29880
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid Objective-C++ selector name"
 msgid "invalid Objective-C++ selector name"
 msgstr "%Hpemilih nama Objective-C++ tidak valid"
 
-#: cp/parser.c:29958 cp/parser.c:29976
+#: cp/parser.c:29955 cp/parser.c:29973
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "objective-c++ method declaration is expected"
 msgstr "diduga penspesifikasi deklarasi"
 
-#: cp/parser.c:29970 cp/parser.c:30035
+#: cp/parser.c:29967 cp/parser.c:30032
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsection attribute cannot be specified for local variables"
 msgid "method attributes must be specified at the end"
 msgstr "%J atribut daerah tidak dapat dispesifikasikan untuk variabel lokal"
 
-#: cp/parser.c:30078
+#: cp/parser.c:30075
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:30284 cp/parser.c:30291 cp/parser.c:30298
+#: cp/parser.c:30281 cp/parser.c:30288 cp/parser.c:30295
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type for iteration variable %qE"
 msgid "invalid type for instance variable"
 msgstr "tipe tidak valid untuk iterasi variabel %qE"
 
-#: cp/parser.c:30413
+#: cp/parser.c:30410
 #, fuzzy, gcc-internal-format
 #| msgid "%Hidentifier expected after %<@protocol%>"
 msgid "identifier expected after %<@protocol%>"
 msgstr "%Hpengidentifikasi diduga setelah %<@protocol%>"
 
-#: cp/parser.c:30585
+#: cp/parser.c:30582
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:30592
+#: cp/parser.c:30589
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored for %qE"
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "%qE atribut diabaikan untuk %qE"
 
-#: cp/parser.c:30867 cp/parser.c:30874 cp/parser.c:30881
+#: cp/parser.c:30864 cp/parser.c:30871 cp/parser.c:30878
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "invalid type for property"
 msgstr "tipe argumen tidak valid"
 
-#: cp/parser.c:32011
+#: cp/parser.c:32008
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<wait%> expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/parser.c:32724
+#: cp/parser.c:32721
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid reduction-identifier"
 msgstr "penginisialisasi tidak valid"
 
-#: cp/parser.c:34911
+#: cp/parser.c:34908
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr "inisialisasi berkurung tidak diijinkan dalam loop OpenMP %<for%>"
 
-#: cp/parser.c:35231 cp/pt.c:16392
+#: cp/parser.c:35228 cp/pt.c:16414
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "iterasi variabel %qD seharusnya bukan reduksi"
 
-#: cp/parser.c:35316
+#: cp/parser.c:35313
 #, fuzzy, gcc-internal-format
 #| msgid "not enough DO loops for collapsed !$OMP DO at %L"
 msgid "not enough for loops to collapse"
 msgstr "tidak cukup DO loops untuk kolaps !$OMP DO di %L"
 
-#: cp/parser.c:37521
+#: cp/parser.c:37518
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer clause"
 msgstr "penginisialisasi tidak valid"
 
-#: cp/parser.c:37549
+#: cp/parser.c:37546
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "expected id-expression (arguments)"
 msgstr "diduga ekspresi"
 
-#: cp/parser.c:37561
+#: cp/parser.c:37558
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:37662
+#: cp/parser.c:37659
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in declare reduction type list"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:37682 cp/semantics.c:5405
+#: cp/parser.c:37679 cp/semantics.c:5408
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37687 cp/semantics.c:5414
+#: cp/parser.c:37684 cp/semantics.c:5417
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37690 cp/pt.c:12944 cp/semantics.c:5420
+#: cp/parser.c:37687 cp/pt.c:12966 cp/semantics.c:5423
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37693 cp/semantics.c:5426
+#: cp/parser.c:37690 cp/semantics.c:5429
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:38047
+#: cp/parser.c:38044
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:38057
+#: cp/parser.c:38054
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qD does not refer to a namespace scope function"
@@ -52904,51 +52948,51 @@
 msgstr "%qD bukan sebuah anggota dari fungsi template"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:38392
+#: cp/parser.c:38389
 #, gcc-internal-format
 msgid "atomic_cancel"
 msgstr ""
 
-#: cp/parser.c:38435 cp/semantics.c:8575
+#: cp/parser.c:38432 cp/semantics.c:8578
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:38437 cp/semantics.c:8577
+#: cp/parser.c:38434 cp/semantics.c:8580
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:38631
+#: cp/parser.c:38628
 #, fuzzy, gcc-internal-format
 #| msgid "%Hjunk at end of %<#pragma GCC pch_preprocess%>"
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "%Hsampah diakhir dari %<#pragma GCC pch_preprocess%>"
 
-#: cp/parser.c:38927
+#: cp/parser.c:38924
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "#pragma GCC optimize tidak diikuti didalam fungsi"
 
-#: cp/parser.c:38959
+#: cp/parser.c:38956
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC option is not allowed inside functions"
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr "#pragma GCC option tidak diijinkan didalam fungsi"
 
-#: cp/parser.c:39039
+#: cp/parser.c:39036
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "inter-module optimisasi tidak diimplementasikan untuk C++"
 
-#: cp/parser.c:39295
+#: cp/parser.c:39292
 #, fuzzy, gcc-internal-format
 #| msgid "%Htemplates may not be %<virtual%>"
 msgid "implicit templates may not be %<virtual%>"
 msgstr "%Htemplate mungkin bukan %<virtual%>"
 
-#: cp/parser.c:39351
+#: cp/parser.c:39348
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
@@ -53039,7 +53083,7 @@
 msgid "specialization of %qD after instantiation"
 msgstr "spesialisasi dari %qD setelah instansiasi"
 
-#: cp/pt.c:1954 cp/semantics.c:5274
+#: cp/pt.c:1954 cp/semantics.c:5277
 #, fuzzy, gcc-internal-format
 #| msgid "%s %+#D"
 msgid "%s %#qD"
@@ -53221,118 +53265,118 @@
 msgid "argument to __integer_pack must be between 0 and %d"
 msgstr "Argumen dari ACOS di %L harus berada diantara -1 dan 1"
 
-#: cp/pt.c:3942
+#: cp/pt.c:3955
 #, fuzzy, gcc-internal-format
 #| msgid "base initializer expansion %<%T%> contains no parameter packs"
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr "ekspansi penginisialisasi dasar %<%T%> berisi parameter packs"
 
-#: cp/pt.c:4010
+#: cp/pt.c:4023
 #, fuzzy, gcc-internal-format
 #| msgid "expansion pattern %<%T%> contains no argument packs"
 msgid "expansion pattern %qT contains no argument packs"
 msgstr "pola ekspansi %<%T%> berisi tidak ada argumen packs"
 
-#: cp/pt.c:4012
+#: cp/pt.c:4025
 #, fuzzy, gcc-internal-format
 #| msgid "expansion pattern %<%E%> contains no argument packs"
 msgid "expansion pattern %qE contains no argument packs"
 msgstr "pola ekspansi %<%E%> berisi tidak ada argumen packs"
 
-#: cp/pt.c:4063
+#: cp/pt.c:4077
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr "parameter packs tidak diekspan dengan %<...%>:"
 
-#: cp/pt.c:4080 cp/pt.c:4835
+#: cp/pt.c:4094 cp/pt.c:4849
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
 
-#: cp/pt.c:4082
+#: cp/pt.c:4096
 #, gcc-internal-format
 msgid "        <anonymous>"
 msgstr "        <anonymous>"
 
-#: cp/pt.c:4208
+#: cp/pt.c:4222
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr "deklarasi dari %q+D membayangi sebuah parameter"
 
-#: cp/pt.c:4211
+#: cp/pt.c:4225
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of %q+#D shadows template parameter"
 msgstr "deklarasi dari %q+D membayangi sebuah parameter"
 
-#: cp/pt.c:4213
+#: cp/pt.c:4227
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter type %qT declared %<friend%>"
 msgid "template parameter %qD declared here"
 msgstr "tipe parameter template %qT dideklarasikan %<friend%>"
 
-#: cp/pt.c:4771
+#: cp/pt.c:4785
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of non-template %qT"
 msgid "specialization of variable concept %q#D"
 msgstr "spesialisasi eksplisit dari bukan-template %qT"
 
-#: cp/pt.c:4830
+#: cp/pt.c:4844
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "template parameters not deducible in partial specialization:"
 msgstr "parameter template tidak digunakan dalam spesialisasi partial:"
 
-#: cp/pt.c:4854
+#: cp/pt.c:4868
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr "partial spesialisasi %qT tidak menspesialisasikan argumen template apapun"
 
-#: cp/pt.c:4858
+#: cp/pt.c:4872
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:4862 cp/pt.c:4873
+#: cp/pt.c:4876 cp/pt.c:4887
 #, gcc-internal-format
 msgid "primary template here"
 msgstr ""
 
-#: cp/pt.c:4870
+#: cp/pt.c:4884
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:4885
+#: cp/pt.c:4899
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "partial specialization %qD is not more specialized than"
 msgstr "partial spesialisasi %qT tidak menspesialisasikan argumen template apapun"
 
-#: cp/pt.c:4887
+#: cp/pt.c:4901
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of template %q#D"
 msgid "primary template %qD"
 msgstr "deklarasi dari template %q#D"
 
-#: cp/pt.c:4934
+#: cp/pt.c:4948
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr "parameter pack argumen %qE harus berada di akhir dari daftar argumen template"
 
-#: cp/pt.c:4937
+#: cp/pt.c:4951
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr "parameter pack argumen %qT harus berada di akhir dari daftar argumen template"
 
-#: cp/pt.c:4958
+#: cp/pt.c:4972
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr "template argumen %qE melibatkan parameter template"
 
-#: cp/pt.c:5004
+#: cp/pt.c:5018
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT of template argument %qE depends on template parameter(s)"
 msgid "type %qT of template argument %qE depends on a template parameter"
@@ -53340,19 +53384,19 @@
 msgstr[0] "tipe %qT dari template argumen %qE tergantung di parameter template"
 msgstr[1] "tipe %qT dari template argumen %qE tergantung di parameter template"
 
-#: cp/pt.c:5066
+#: cp/pt.c:5080
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "template class instantiation ambigu untuk %q#T"
 
-#: cp/pt.c:5070
+#: cp/pt.c:5084
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %qD after instantiation"
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "spesialisasi dari %qD setelah instansiasi"
 
-#: cp/pt.c:5247
+#: cp/pt.c:5261
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "tidak ada argumen baku untuk %qD"
@@ -53360,53 +53404,53 @@
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5269
+#: cp/pt.c:5283
 #, fuzzy, gcc-internal-format
 #| msgid "parameter pack %qE must be at the end of the template parameter list"
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "parameter pack %qE harus berada di akhir dari daftar parameter template"
 
-#: cp/pt.c:5305
+#: cp/pt.c:5319
 #, fuzzy, gcc-internal-format
 #| msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "argumen baku tidak diijinkan dalam deklarasi dari spesialisasi template friend %qD"
 
-#: cp/pt.c:5308
+#: cp/pt.c:5322
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "parameter template tidak digunakan dalam spesialisasi partial:"
 
-#: cp/pt.c:5311
+#: cp/pt.c:5325
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/pt.c:5314
+#: cp/pt.c:5328
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters not used in partial specialization:"
 msgid "default template arguments may not be used in partial specializations"
 msgstr "parameter template tidak digunakan dalam spesialisasi partial:"
 
-#: cp/pt.c:5317 cp/pt.c:5375
+#: cp/pt.c:5331 cp/pt.c:5389
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for parameter of type %qT has type %qT"
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "argumen baku untuk parameter dari tipe %qT memiliki tipe %qT"
 
-#: cp/pt.c:5489
+#: cp/pt.c:5503
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD declared void"
 msgid "template %qD declared"
 msgstr "parameter %qD dideklarasikan void"
 
-#: cp/pt.c:5496
+#: cp/pt.c:5510
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "template kelas tanpa sebuah nama"
 
-#: cp/pt.c:5504
+#: cp/pt.c:5518
 #, fuzzy, gcc-internal-format
 #| msgid "non-member function %qD cannot have cv-qualifier"
 msgid "member template %qD may not have virt-specifiers"
@@ -53417,58 +53461,58 @@
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5526
+#: cp/pt.c:5540
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "deklarasi template dari %qD tidak valid"
 
-#: cp/pt.c:5669
+#: cp/pt.c:5683
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "definisi template dari bukan template %q#D"
 
-#: cp/pt.c:5712
+#: cp/pt.c:5726
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "diduga %d tingkat dari parm template untuk %q#D, diperoleh %d"
 
-#: cp/pt.c:5726
+#: cp/pt.c:5740
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "diperoleh %d parameter template untuk %q#D"
 
-#: cp/pt.c:5729
+#: cp/pt.c:5743
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "diperoleh %d parameter template untuk %q#T"
 
-#: cp/pt.c:5731
+#: cp/pt.c:5745
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  tetapi %d dibutuhkan"
 
-#: cp/pt.c:5752
+#: cp/pt.c:5766
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "template argumen ke %qD tidak cocok dengan template asli %qD"
 
-#: cp/pt.c:5755
+#: cp/pt.c:5769
 #, fuzzy, gcc-internal-format
 #| msgid "use template<> for an explicit specialization"
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "gunakan template<> untuk spesialisasi eksplisit"
 
-#: cp/pt.c:5882
+#: cp/pt.c:5896
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT bukan sebuah tipe template"
 
-#: cp/pt.c:5895
+#: cp/pt.c:5909
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "penspesifikasi template tidak dispesifikasikan dalam deklarasi dari %qD"
 
-#: cp/pt.c:5906
+#: cp/pt.c:5920
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "redeclared with %d template parameter(s)"
 msgid "redeclared with %d template parameter"
@@ -53476,7 +53520,7 @@
 msgstr[0] "redeklarasikan dengan %d parameter template"
 msgstr[1] "redeklarasikan dengan %d parameter template"
 
-#: cp/pt.c:5910
+#: cp/pt.c:5924
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D used %d template parameter(s)"
 msgid "previous declaration %qD used %d template parameter"
@@ -53484,12 +53528,12 @@
 msgstr[0] "deklarasi sebelumnya %q+D digunakan %d parameter template"
 msgstr[1] "deklarasi sebelumnya %q+D digunakan %d parameter template"
 
-#: cp/pt.c:5947
+#: cp/pt.c:5961
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "parameter template %q+#D"
 
-#: cp/pt.c:5948
+#: cp/pt.c:5962
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "redeklarasikan disini sebagai %q#D"
@@ -53498,132 +53542,132 @@
 #.
 #. A template-parameter may not be given default arguments
 #. by two different declarations in the same scope.
-#: cp/pt.c:5958
+#: cp/pt.c:5972
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "redefinisi dari argumen baku untuk %q#D"
 
-#: cp/pt.c:5960
+#: cp/pt.c:5974
 #, fuzzy, gcc-internal-format
 #| msgid "%Joriginal definition appeared here"
 msgid "original definition appeared here"
 msgstr "%J definisi asli muncul disini"
 
-#: cp/pt.c:5988
+#: cp/pt.c:6002
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qF throws different exceptions"
 msgid "redeclaration %q#D with different constraints"
 msgstr "deklarasi dari %qF throws exceptions berbeda"
 
-#: cp/pt.c:5991
+#: cp/pt.c:6005
 #, fuzzy, gcc-internal-format
 #| msgid "%Joriginal definition appeared here"
 msgid "original declaration appeared here"
 msgstr "%J definisi asli muncul disini"
 
-#: cp/pt.c:6250 cp/pt.c:6318
+#: cp/pt.c:6264 cp/pt.c:6332
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT"
 
-#: cp/pt.c:6253
+#: cp/pt.c:6267
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr "ini harus berupa alamat dari sebuah fungsi dengan hubungan eksternal"
 
-#: cp/pt.c:6256
+#: cp/pt.c:6270
 #, fuzzy, gcc-internal-format
 #| msgid "it must be the address of a function with external linkage"
 msgid "it must be the name of a function with external linkage"
 msgstr "ini harus berupa alamat dari sebuah fungsi dengan hubungan eksternal"
 
-#: cp/pt.c:6268
+#: cp/pt.c:6282
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT karena objek %qD bukan eksternal linkage"
 
-#: cp/pt.c:6272
+#: cp/pt.c:6286
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%qE bukan sebuah argumen template yang valid dari tipe %qT karena %qD tidak memiliki eksternal linkage"
 
-#: cp/pt.c:6321
+#: cp/pt.c:6335
 #, fuzzy, gcc-internal-format
 #| msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "(sebuah penunjuk ke anggota hanya dapat dibentuk dengan %<&%E%>)"
 
-#: cp/pt.c:6323
+#: cp/pt.c:6337
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a member of %qT"
 msgid "because it is a member of %qT"
 msgstr "%qT bukan sebuah anggota dari %qT"
 
-#: cp/pt.c:6383
+#: cp/pt.c:6397
 #, fuzzy, gcc-internal-format
 #| msgid "got %d template parameters for %q#D"
 msgid "  couldn't deduce template parameter %qD"
 msgstr "diperoleh %d parameter template untuk %q#D"
 
-#: cp/pt.c:6392
+#: cp/pt.c:6406
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.c:6401
+#: cp/pt.c:6415
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between types %qT and %qT"
 msgid "  mismatched types %qT and %qT"
 msgstr "perbandingan diantara tipe %qT dan %qT"
 
-#: cp/pt.c:6410
+#: cp/pt.c:6424
 #, fuzzy, gcc-internal-format
 #| msgid "%Htemplate parameter pack %qD cannot have a default argument"
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr "%Htemplate parameter pack %qD tidak dapat memiliki sebuah argumen baku"
 
-#: cp/pt.c:6421
+#: cp/pt.c:6435
 #, fuzzy, gcc-internal-format
 #| msgid "template arguments to %qD do not match original template %qD"
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "template argumen ke %qD tidak cocok dengan template asli %qD"
 
-#: cp/pt.c:6431
+#: cp/pt.c:6445
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "  %qE is not equivalent to %qE"
 msgstr "%qs tidak valid untuk %qs"
 
-#: cp/pt.c:6440
+#: cp/pt.c:6454
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:6452
+#: cp/pt.c:6466
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.c:6456
+#: cp/pt.c:6470
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.c:6467
+#: cp/pt.c:6481
 #, fuzzy, gcc-internal-format
 #| msgid "partial specialization %qT does not specialize any template arguments"
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "partial spesialisasi %qT tidak menspesialisasikan argumen template apapun"
 
-#: cp/pt.c:6478
+#: cp/pt.c:6492
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT"
 msgid "  member function type %qT is not a valid template argument"
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT"
 
-#: cp/pt.c:6490
+#: cp/pt.c:6504
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
@@ -53630,324 +53674,324 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/pt.c:6521
+#: cp/pt.c:6535
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert type %qT to type %qT"
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "tidak dapat mengubah tipe %qT ke tipe %qT"
 
-#: cp/pt.c:6534
+#: cp/pt.c:6548
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is an ambiguous base of %qT"
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "%qT adalah sebuah dasar ambigu dari %qT"
 
-#: cp/pt.c:6538
+#: cp/pt.c:6552
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not derived from type %qT"
 msgid "  %qT is not derived from %qT"
 msgstr "tipe %qT tidak diturunkan dari tipe %qT"
 
-#: cp/pt.c:6549
+#: cp/pt.c:6563
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.c:6559
+#: cp/pt.c:6573
 #, fuzzy, gcc-internal-format
 #| msgid "cannot decrement a pointer to incomplete type %qT"
 msgid "  can't deduce a template for %qT from non-template type %qT"
 msgstr "tidak dapat mengurangi penunjuk ke tipe tidak lengkap %qT"
 
-#: cp/pt.c:6569
+#: cp/pt.c:6583
 #, fuzzy, gcc-internal-format
 #| msgid "argument of type %qT does not match %qT"
 msgid "  template argument %qE does not match %qE"
 msgstr "argumen dari tipe %qT tidak cocok dengan %qT"
 
-#: cp/pt.c:6609
+#: cp/pt.c:6623
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT karena string literal tidak dapat digunakan dalam konteks ini"
 
-#: cp/pt.c:6758
+#: cp/pt.c:6772
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT"
 msgid "in template argument for type %qT"
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT"
 
-#: cp/pt.c:6772
+#: cp/pt.c:6786
 #, fuzzy, gcc-internal-format
 #| msgid "accumulator is not a constant integer"
 msgid "template argument %qE for type %qT not a constant integer"
 msgstr "akumulator bukan sebuah konstanta integer"
 
-#: cp/pt.c:6833
+#: cp/pt.c:6847
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qD bukan sebuah template argumen yang valid karena %qD bukan sebuah variabel, bukan alamat dari sebuah variabel"
 
-#: cp/pt.c:6841
+#: cp/pt.c:6855
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qD bukan sebuah template argumen yang valid karena %qD bukan sebuah variabel, bukan alamat dari sebuah variabel"
 
-#: cp/pt.c:6857
+#: cp/pt.c:6871
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "%qE bukan sebuah argumen template yang valid dari tipe %qT karena %qE bukan sebuah variabel"
 
-#: cp/pt.c:6864
+#: cp/pt.c:6878
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr "%qE bukan sebuah argumen template yang valid dari tipe %qT karena %qD tidak memiliki eksternal linkage"
 
-#: cp/pt.c:6873
+#: cp/pt.c:6887
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE bukan sebuah argumen template yang valid dari tipe %qT karena %qE bukan sebuah variabel"
 
-#: cp/pt.c:6888
+#: cp/pt.c:6902
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT"
 msgid "the address of %qD is not a valid template argument"
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT"
 
-#: cp/pt.c:6897
+#: cp/pt.c:6911
 #, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6904
+#: cp/pt.c:6918
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "%qE bukan sebuah argumen template yang valid dari tipe %qT karena %qD tidak memiliki eksternal linkage"
 
-#: cp/pt.c:6933
+#: cp/pt.c:6947
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "%qE bukan sebuah template argumen yang valid untuk tipe %qT karena konflik dalam cv kualifikasi"
 
-#: cp/pt.c:6941
+#: cp/pt.c:6955
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT karena ini bukan sebuah lvalue"
 
-#: cp/pt.c:6959
+#: cp/pt.c:6973
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is a non-constant expression"
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%qE bukan sebuah template argumen yang valid untuk tipe %qT karena ini bukan sebuah ekspresi konstan"
 
-#: cp/pt.c:6975
+#: cp/pt.c:6989
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgid "%qE is not a valid template argument for type %qT because it is not an object with linkage"
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT karena ini bukan sebuah lvalue"
 
-#: cp/pt.c:6986
+#: cp/pt.c:7000
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "%qE is not a valid template argument for type %qT because object %qD does not have linkage"
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT karena objek %qD bukan eksternal linkage"
 
-#: cp/pt.c:7036
+#: cp/pt.c:7050
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT karena ini adalah sebuah penunjuk"
 
-#: cp/pt.c:7038
+#: cp/pt.c:7052
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "lebih baik coba gunakan %qE"
 
-#: cp/pt.c:7092
+#: cp/pt.c:7106
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT karena ini dari tipe %qT"
 
-#: cp/pt.c:7654
+#: cp/pt.c:7668
 #, fuzzy, gcc-internal-format
 #| msgid "Conflict in attributes of function argument at %C"
 msgid "ignoring attributes on template argument %qT"
 msgstr "Konflik dalam atribut dari argumen fungsi di %C"
 
-#: cp/pt.c:7670
+#: cp/pt.c:7684
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes applied to %qT after definition"
 msgid "ignoring attributes in template argument %qE"
 msgstr "mengabaikan atribut yang diaplikasikan ke %qT setelah definisi"
 
-#: cp/pt.c:7805
+#: cp/pt.c:7819
 #, fuzzy, gcc-internal-format
 #| msgid "name of class shadows template template parameter %qD"
 msgid "injected-class-name %qD used as template template argument"
 msgstr "nama dari template kelas bayangan parameter template %qD"
 
-#: cp/pt.c:7834
+#: cp/pt.c:7848
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid use of destructor %qD as a type"
 msgid "invalid use of destructor %qE as a type"
 msgstr "%Hpenggunaan tidak valid dari desktruktor %qD memiliki sebuah tipe"
 
-#: cp/pt.c:7839
+#: cp/pt.c:7853
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "merefer ke sebuah anggota tipe dari sebuah parameter template, gunakan %<typename %E%>"
 
-#: cp/pt.c:7855 cp/pt.c:7877 cp/pt.c:7931
+#: cp/pt.c:7869 cp/pt.c:7891 cp/pt.c:7945
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "tipe/nilai tidak cocok di argumen %d dalam daftar parameter template untuk %qD"
 
-#: cp/pt.c:7860
+#: cp/pt.c:7874
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  diduga sebuah konstanta dari tipe %qT, diperoleh %qT"
 
-#: cp/pt.c:7865
+#: cp/pt.c:7879
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  diduga sebuah template kelas, diperoleh %qE"
 
-#: cp/pt.c:7868
+#: cp/pt.c:7882
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  diduga sebuah tipe, diperoleh %qE"
 
-#: cp/pt.c:7882
+#: cp/pt.c:7896
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  diduga sebuah tipe, diperoleh %qT"
 
-#: cp/pt.c:7885
+#: cp/pt.c:7899
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  diduga sebuah template kelas, diperoleh %qT"
 
-#: cp/pt.c:7935
+#: cp/pt.c:7949
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a template of type %qD, got %qD"
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  diduga sebuah template dari tipe %qD, diperoleh %qD"
 
-#: cp/pt.c:7949
+#: cp/pt.c:7963
 #, fuzzy, gcc-internal-format
 #| msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "tipe/nilai tidak cocok di argumen %d dalam daftar parameter template untuk %qD"
 
-#: cp/pt.c:7952
+#: cp/pt.c:7966
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a type, got %qE"
 msgid "  expected %qD but got %qD"
 msgstr "  diduga sebuah tipe, diperoleh %qE"
 
-#: cp/pt.c:8012
+#: cp/pt.c:8026
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert template argument %qE to %qT"
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "tidak dapat mengubah argumen template %qE ke %qT"
 
-#: cp/pt.c:8149 cp/pt.c:8465
+#: cp/pt.c:8163 cp/pt.c:8479
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "template argumen %d tidak valid"
 
-#: cp/pt.c:8164 cp/pt.c:8298
+#: cp/pt.c:8178 cp/pt.c:8312
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "jumlah dari argumen template salah (%d, seharusnya %d)"
 
-#: cp/pt.c:8294
+#: cp/pt.c:8308
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "jumlah dari argumen template salah (%d, seharusnya %d)"
 
-#: cp/pt.c:8303
+#: cp/pt.c:8317
 #, fuzzy, gcc-internal-format
 #| msgid "provided for %q+D"
 msgid "provided for %qD"
 msgstr "disediakan untuk %q+D"
 
-#: cp/pt.c:8328
+#: cp/pt.c:8342
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:8332
+#: cp/pt.c:8346
 #, fuzzy, gcc-internal-format
 #| msgid "default argument given for parameter %d of %q#D"
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "argumen baku diberikan untuk parameter %d dari %q#D"
 
-#: cp/pt.c:8431
+#: cp/pt.c:8445
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:9054
+#: cp/pt.c:9068
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%q#D is not a function template"
 msgstr "%qD bukan sebuah template fungsi"
 
-#: cp/pt.c:9221
+#: cp/pt.c:9235
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "tipe bukan template %qT digunakan sebuah sebuah template"
 
-#: cp/pt.c:9223
+#: cp/pt.c:9237
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "untuk deklarasi template %q+D"
 
-#: cp/pt.c:9346
+#: cp/pt.c:9360
 #, fuzzy, gcc-internal-format
 #| msgid "internal consistency failure"
 msgid "template constraint failure"
 msgstr "kegagalan konsistensi internal"
 
-#: cp/pt.c:9697
+#: cp/pt.c:9718
 #, fuzzy, gcc-internal-format
 #| msgid "use of %qs in template"
 msgid "use of invalid variable template %qE"
 msgstr "penggunaan dari %qs dalam template"
 
-#: cp/pt.c:10125
+#: cp/pt.c:10148
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating %qD"
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr "kedalaman template instantiation melebihi maksimal dari %d (gunakan -ftemplate-depth-NN untuk meningkatkan maksimal) instantiating %qD"
 
-#: cp/pt.c:11202
+#: cp/pt.c:11225
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in union"
 msgid "flexible array member %qD in union"
 msgstr "%J anggota array fleksibel dalam union"
 
-#: cp/pt.c:11691
+#: cp/pt.c:11713
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:12160
+#: cp/pt.c:12182
 #, fuzzy, gcc-internal-format
 #| msgid "mismatched argument pack lengths while expanding %<%T%>"
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr "panjang argumen pack tidak cocok akan diekspan %<%T%>"
 
-#: cp/pt.c:12163
+#: cp/pt.c:12185
 #, fuzzy, gcc-internal-format
 #| msgid "mismatched argument pack lengths while expanding %<%E%>"
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr "panjang argumen pack tidak cocok ketika mengekspan %<%E%>"
 
-#: cp/pt.c:12747
+#: cp/pt.c:12769
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for %q#D"
 msgid "  when instantiating default argument for call to %qD"
@@ -53966,288 +54010,288 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:13708
+#: cp/pt.c:13730
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "variabel %qD memiliki tipe fungsi"
 
-#: cp/pt.c:13881
+#: cp/pt.c:13903
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "tipe parameter %qT tidak valid"
 
-#: cp/pt.c:13883
+#: cp/pt.c:13905
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "dalam deklarasi %q+D"
 
-#: cp/pt.c:14001
+#: cp/pt.c:14023
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "fungsi mengembalikan sebuah array"
 
-#: cp/pt.c:14003
+#: cp/pt.c:14025
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "fungsi mengembalikan sebuah fungsi"
 
-#: cp/pt.c:14043
+#: cp/pt.c:14065
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "membuat penunjuk ke anggota fungsi dari tipe bukan kelas %qT"
 
-#: cp/pt.c:14637
+#: cp/pt.c:14659
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "membentuk referensi ke void"
 
-#: cp/pt.c:14639
+#: cp/pt.c:14661
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type %qT"
 msgid "forming pointer to reference type %qT"
 msgstr "membentuk %s ke tipe referensi %qT"
 
-#: cp/pt.c:14641
+#: cp/pt.c:14663
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type %qT"
 msgid "forming reference to reference type %qT"
 msgstr "membentuk %s ke tipe referensi %qT"
 
-#: cp/pt.c:14654
+#: cp/pt.c:14676
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %s to qualified function type %qT"
 msgid "forming pointer to qualified function type %qT"
 msgstr "tidak dapat mendeklarasikan %s untuk fungsi yang dikualifikasikan dengan tipe %qT"
 
-#: cp/pt.c:14657
+#: cp/pt.c:14679
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %s to qualified function type %qT"
 msgid "forming reference to qualified function type %qT"
 msgstr "tidak dapat mendeklarasikan %s untuk fungsi yang dikualifikasikan dengan tipe %qT"
 
-#: cp/pt.c:14705
+#: cp/pt.c:14727
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "membuat penunjuk ke anggota dari tipe bukan kelas %qT"
 
-#: cp/pt.c:14711
+#: cp/pt.c:14733
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "membuat penunjuk ke anggota referensi tipe %qT"
 
-#: cp/pt.c:14717
+#: cp/pt.c:14739
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "membuat penunjuk ke anggota dari tipe void"
 
-#: cp/pt.c:14783
+#: cp/pt.c:14805
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "membuat array dari %qT"
 
-#: cp/pt.c:14816
+#: cp/pt.c:14838
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT bukan sebuah tipe class, struct, atau union"
 
-#: cp/pt.c:14853
+#: cp/pt.c:14875
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT meresolf ke %qT, yang bukan sebuah tipe enumerasi"
 
-#: cp/pt.c:14861
+#: cp/pt.c:14883
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr "%qT meresolf ke %qT, yang bukan sebuah tipe class"
 
-#: cp/pt.c:14925
+#: cp/pt.c:14947
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.c:15000
+#: cp/pt.c:15022
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "penggunaan dari %qs dalam template"
 
-#: cp/pt.c:15178
+#: cp/pt.c:15200
 #, fuzzy, gcc-internal-format
 #| msgid "qualified type %qT does not match destructor name ~%qT"
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "tipe kualifikasi %qT tidak cocok dengan nama destruktor ~%qT"
 
-#: cp/pt.c:15193
+#: cp/pt.c:15215
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "dependent-name %qE diparse sebagai sebuah bukan-tipe, tetapi instantiation menghasilkan sebuah tipe"
 
-#: cp/pt.c:15195
+#: cp/pt.c:15217
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "katakan %<typename %E%> jika sebuah tipe adalah berarti"
 
-#: cp/pt.c:15394
+#: cp/pt.c:15416
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "menggunakan field tidak valid %qD"
 
-#: cp/pt.c:15883 cp/pt.c:17386
+#: cp/pt.c:15905 cp/pt.c:17408
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "penggunaan tidak valid dari ekspresi ekspansi pack"
 
-#: cp/pt.c:15887 cp/pt.c:17390
+#: cp/pt.c:15909 cp/pt.c:17412
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "gunakan %<...%> untuk mengekspan argumen pack"
 
-#: cp/pt.c:18334
+#: cp/pt.c:18371
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:18362
+#: cp/pt.c:18399
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:18367
+#: cp/pt.c:18404
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.c:18370
+#: cp/pt.c:18407
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr ""
 
-#: cp/pt.c:18375
+#: cp/pt.c:18412
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE undeclared here (not in a function)"
 msgid "%qD declared here, later in the translation unit"
 msgstr "%H%qE tidak dideklarasikan disini (bukan dalam sebuah fungsi)"
 
-#: cp/pt.c:18712
+#: cp/pt.c:18752
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT bukan sebuah class atau namespace"
 
-#: cp/pt.c:18715
+#: cp/pt.c:18755
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD bukan sebuah class atau namespace"
 
-#: cp/pt.c:19026
+#: cp/pt.c:19066
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is/uses anonymous type"
 msgid "%qT is/uses unnamed type"
 msgstr "%qT adalah/menggunakan tipe anonymous"
 
-#: cp/pt.c:19028
+#: cp/pt.c:19068
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "argumen template untuk %qD menggunakan tipe lokal %qT"
 
-#: cp/pt.c:19038
+#: cp/pt.c:19078
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT adalah sebuah tipe variabel termodifikasi"
 
-#: cp/pt.c:19053
+#: cp/pt.c:19093
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "ekspresi integral %qE bukan konstan"
 
-#: cp/pt.c:19071
+#: cp/pt.c:19111
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  mencoba untuk instantiate %qD"
 
-#: cp/pt.c:22972
+#: cp/pt.c:23050
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#T"
 msgstr "template class instantiation ambigu untuk %q#T"
 
-#: cp/pt.c:22974
+#: cp/pt.c:23052
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#D"
 msgstr "template class instantiation ambigu untuk %q#T"
 
-#: cp/pt.c:22980
+#: cp/pt.c:23058
 #, fuzzy
 #| msgid "%s %+#D"
 msgid "%s %#qS"
 msgstr "%s %+#D"
 
-#: cp/pt.c:23004 cp/pt.c:23091
+#: cp/pt.c:23082 cp/pt.c:23169
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "instantiation eksplisit dari bukan-template %q#D"
 
-#: cp/pt.c:23023
+#: cp/pt.c:23101
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD bukan sebuah anggota data statis dari sebuah template class"
 
-#: cp/pt.c:23029 cp/pt.c:23086
+#: cp/pt.c:23107 cp/pt.c:23164
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "template tidak cocok untuk %qD yang ditemukan"
 
-#: cp/pt.c:23034
+#: cp/pt.c:23112
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "tipe %qT untuk instantiation eksplisit %qD tidak cocok dengan tipe yang dideklarasikan %qT"
 
-#: cp/pt.c:23042
+#: cp/pt.c:23120
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "eksplisit instantiation dari %q#D"
 
-#: cp/pt.c:23078
+#: cp/pt.c:23156
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "duplikasi eksplisit instantiation dari %q#D"
 
-#: cp/pt.c:23101 cp/pt.c:23187
+#: cp/pt.c:23179 cp/pt.c:23265
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ 1998 melarang penggunaan dari %<extern%> di instantiation eksplisit"
 
-#: cp/pt.c:23106 cp/pt.c:23204
+#: cp/pt.c:23184 cp/pt.c:23282
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "class penyimpanan %qD diaplikasikan ke template instantiation"
 
-#: cp/pt.c:23163
+#: cp/pt.c:23241
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template %q#D"
 msgid "explicit instantiation of non-class template %qD"
 msgstr "instantiation eksplisit dari bukan-template %q#D"
 
-#: cp/pt.c:23165
+#: cp/pt.c:23243
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "eksplisit instantiation dari tipe bukan template %qT"
 
-#: cp/pt.c:23174
+#: cp/pt.c:23252
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "eksplisit instantiation dari %q#T sebelum definisi dari template"
 
-#: cp/pt.c:23192
+#: cp/pt.c:23270
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ melarang penggunaan dari %qE di instantiasi eksplisit"
 
-#: cp/pt.c:23238
+#: cp/pt.c:23316
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "duplikasi instansiasi eksplisit dari %q#T"
 
-#: cp/pt.c:23536
+#: cp/pt.c:23614
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "exception specification of %qD depends on itself"
@@ -54260,119 +54304,119 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:23842
+#: cp/pt.c:23920
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "eksplisit instansiasi dari %qD tetapi tidak ada definisi yang tersedia"
 
-#: cp/pt.c:24043
+#: cp/pt.c:24121
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth-NN to increase the maximum)"
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr "kedalaman template instansiasi melebihi maksimal dari %d instantiating %q+D, kemungkinan dari pembuatan tabel virtual (gunakan -ftemplate-depth-NN untuk meningkatkan maksimal)"
 
-#: cp/pt.c:24418
+#: cp/pt.c:24496
 #, fuzzy, gcc-internal-format
 #| msgid "using template type parameter %qT after %qs"
 msgid "invalid template non-type parameter"
 msgstr "menggunakan parameter tipe template %qT setelah %qs"
 
-#: cp/pt.c:24420
+#: cp/pt.c:24498
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a valid type for a template constant parameter"
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T bukan sebuah tipe valid untuk sebuah parameter template konstan"
 
-#: cp/pt.c:25723
+#: cp/pt.c:25802
 #, fuzzy, gcc-internal-format
 #| msgid "%Hkeyword %<typename%> not allowed outside of templates"
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "%Hkata kunci %<typename%> tidak diijinkan diluar dari templates"
 
-#: cp/pt.c:25961
+#: cp/pt.c:26040
 #, fuzzy, gcc-internal-format
 #| msgid "deducing auto from brace-enclosed initializer list requires #include <initializer_list>"
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr "deduksi auto dari daftar penginisialisasi dikurung membutuhkan #include <daftar_penginisialisasi>"
 
-#: cp/pt.c:26440
+#: cp/pt.c:26519
 #, fuzzy, gcc-internal-format
 #| msgid "%qD used without template parameters"
 msgid "non-class template %qT used without template arguments"
 msgstr "%qD digunakan tanpa parameter template"
 
-#: cp/pt.c:26586
+#: cp/pt.c:26665
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:26593
+#: cp/pt.c:26672
 #, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr ""
 
-#: cp/pt.c:26607
+#: cp/pt.c:26686
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "class template argument deduction failed:"
 msgstr "template argumen %d tidak valid"
 
-#: cp/pt.c:26614
+#: cp/pt.c:26693
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "fungsi tidak dipertimbangkan untuk inlining"
 
-#: cp/pt.c:26676
+#: cp/pt.c:26755
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:26679
+#: cp/pt.c:26758
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:26711
+#: cp/pt.c:26790
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/pt.c:26746
+#: cp/pt.c:26825
 #, fuzzy, gcc-internal-format
 #| msgid "unable to deduce %qT from %qE"
 msgid "unable to deduce lambda return type from %qE"
 msgstr "tidak dapat mendeduksi %qT dari %qE"
 
-#: cp/pt.c:26748
+#: cp/pt.c:26827
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "tidak dapat mendeduksi %qT dari %qE"
 
-#: cp/pt.c:26781
+#: cp/pt.c:26860
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:26785
+#: cp/pt.c:26864
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "insn tidak memenuhi batasannya:"
 
-#: cp/pt.c:26789
+#: cp/pt.c:26868
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "insn tidak memenuhi batasannya:"
 
-#: cp/pt.c:26793
+#: cp/pt.c:26872
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "insn tidak memenuhi batasannya:"
 
-#: cp/pt.c:26912
+#: cp/pt.c:26991
 #, fuzzy, gcc-internal-format
 #| msgid "use of %qs in template"
 msgid "invalid use of %qT in template argument"
@@ -54432,85 +54476,85 @@
 msgid "cannot dynamic_cast %qE (of type %q#T) to type %q#T (%s)"
 msgstr "tidak dapat dynamic_cast %qE (dari tipe %q#T) ke tipe %q#T (%s)"
 
-#: cp/search.c:240
+#: cp/search.c:243
 #, gcc-internal-format
 msgid "%qT is an ambiguous base of %qT"
 msgstr "%qT adalah sebuah dasar ambigu dari %qT"
 
-#: cp/search.c:256
+#: cp/search.c:259
 #, gcc-internal-format
 msgid "%qT is an inaccessible base of %qT"
 msgstr "%qT adalah sebuah dasar tidak dapat diakses dari %qT"
 
-#: cp/search.c:1905
+#: cp/search.c:1908
 #, fuzzy, gcc-internal-format
 #| msgid "invalid covariant return type for %q+#D"
 msgid "invalid covariant return type for %q#D"
 msgstr "tipe kembali covarian tidak valid untuk %q+#D"
 
-#: cp/search.c:1907 cp/search.c:1922 cp/search.c:1928 cp/search.c:1957
+#: cp/search.c:1910 cp/search.c:1925 cp/search.c:1931 cp/search.c:1960
 #, fuzzy, gcc-internal-format
 #| msgid "overriding deleted function %q+D"
 msgid "overridden function is %q#D"
 msgstr "overriding fungsi terhapus %q+D"
 
-#: cp/search.c:1920
+#: cp/search.c:1923
 #, gcc-internal-format
 msgid "invalid covariant return type for %q+#D"
 msgstr "tipe kembali covarian tidak valid untuk %q+#D"
 
-#: cp/search.c:1926
+#: cp/search.c:1929
 #, gcc-internal-format
 msgid "conflicting return type specified for %q+#D"
 msgstr "tipe kembali konflik dispesifikasikan untuk %q+#D"
 
-#: cp/search.c:1942
+#: cp/search.c:1945
 #, gcc-internal-format
 msgid "looser throw specifier for %q+#F"
 msgstr "looser throw penspesifikasi untuk %q+#F"
 
-#: cp/search.c:1944
+#: cp/search.c:1947
 #, fuzzy, gcc-internal-format
 #| msgid "overriding deleted function %q+D"
 msgid "overridden function is %q#F"
 msgstr "overriding fungsi terhapus %q+D"
 
-#: cp/search.c:1955
+#: cp/search.c:1958
 #, gcc-internal-format
 msgid "conflicting type attributes specified for %q+#D"
 msgstr "konflik atribut tipe dispesifikasikan untuk %q+#D"
 
-#: cp/search.c:1972
+#: cp/search.c:1975
 #, fuzzy, gcc-internal-format
 #| msgid "%qD was declared %<extern%> and later %<static%>"
 msgid "%qD declared %<transaction_safe_dynamic%>"
 msgstr "%qD telah dideklarasikan %<extern%> dan kemudian %<static%>"
 
-#: cp/search.c:1974
+#: cp/search.c:1977
 #, fuzzy, gcc-internal-format
 #| msgid "variable %q+D declared %<inline%>"
 msgid "overriding %qD declared %<transaction_safe%>"
 msgstr "variabel %q+D dideklarasikan %<inline%>"
 
-#: cp/search.c:1981
+#: cp/search.c:1984
 #, fuzzy, gcc-internal-format
 #| msgid "overriding non-deleted function %q+D"
 msgid "deleted function %q+D overriding non-deleted function"
 msgstr "overriding fungsi tidak terhapus %q+D"
 
-#: cp/search.c:1984 cp/search.c:1992 cp/search.c:2000
+#: cp/search.c:1987 cp/search.c:1995 cp/search.c:2003
 #, fuzzy, gcc-internal-format
 #| msgid "overriding deleted function %q+D"
 msgid "overridden function is %qD"
 msgstr "overriding fungsi terhapus %q+D"
 
-#: cp/search.c:1989
+#: cp/search.c:1992
 #, fuzzy, gcc-internal-format
 #| msgid "non-deleted function %q+D"
 msgid "non-deleted function %q+D overriding deleted function"
 msgstr "fungsi tidak terhapus %q+D"
 
-#: cp/search.c:1998
+#: cp/search.c:2001
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "virtual function %q+D overriding final function"
@@ -54518,12 +54562,12 @@
 
 #. A static member function cannot match an inherited
 #. virtual member function.
-#: cp/search.c:2082
+#: cp/search.c:2085
 #, gcc-internal-format
 msgid "%q+#D cannot be declared"
 msgstr "%q+#D tidak dapat dideklarasikan"
 
-#: cp/search.c:2083
+#: cp/search.c:2086
 #, gcc-internal-format
 msgid "  since %q+#D declared in base class"
 msgstr "  karena %q+#D dideklarasikan dalam kelas dasar"
@@ -54565,159 +54609,159 @@
 msgid "invalid use of member %qD in static member function"
 msgstr "penggunaan tidak valid dari anggota %q+D dalam anggota fungsi statis"
 
-#: cp/semantics.c:2153
+#: cp/semantics.c:2156
 #, gcc-internal-format
 msgid "a statement expression is an insufficient context for overload resolution"
 msgstr ""
 
-#: cp/semantics.c:2540
+#: cp/semantics.c:2543
 #, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr "argumen ke destruktor tidak diijinkan"
 
-#: cp/semantics.c:2622
+#: cp/semantics.c:2625
 #, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr "%<this%> tidak tersedia untuk anggota fungsi static"
 
-#: cp/semantics.c:2624
+#: cp/semantics.c:2627
 #, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr "penggunaan tidak valid dari %<this%> dalam fungsi bukan anggota"
 
-#: cp/semantics.c:2626
+#: cp/semantics.c:2629
 #, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr "penggunaan tidak valid ari %<this%> di tingkat paling atas"
 
-#: cp/semantics.c:2648
+#: cp/semantics.c:2651
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "tidak valid pengkualifikasi lingkup dalam nama pseudo-destruktor"
 
-#: cp/semantics.c:2656 cp/typeck.c:2604
+#: cp/semantics.c:2659 cp/typeck.c:2604
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "tipe kualifikasi %qT tidak cocok dengan nama destruktor ~%qT"
 
-#: cp/semantics.c:2678
+#: cp/semantics.c:2681
 #, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr "%qE bukan dari tipe %qT"
 
-#: cp/semantics.c:2751
+#: cp/semantics.c:2754
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr "compound literal dari tipe bukan-objek %qT"
 
-#: cp/semantics.c:2892
+#: cp/semantics.c:2895
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr "tipe parameter template harus menggunakan kata kunci %<class%> atau %<typename%>"
 
-#: cp/semantics.c:2942
+#: cp/semantics.c:2945
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr "penggunaan tidak valid dari tipe %qT sebagai nilai baku untuk sebuah parameter template"
 
-#: cp/semantics.c:2945
+#: cp/semantics.c:2948
 #, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr "argumen baku tidak valid untuk sebuah parameter template template"
 
-#: cp/semantics.c:2962
+#: cp/semantics.c:2965
 #, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr "definisi dari %q#T didalam daftar parameter template"
 
-#: cp/semantics.c:2993
+#: cp/semantics.c:2996
 #, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr "definisi tidak valid dari tipe pengkualifikasi %qT"
 
-#: cp/semantics.c:3263
+#: cp/semantics.c:3266
 #, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "spesifikasi kelas dasar tidak valid"
 
-#: cp/semantics.c:3423
+#: cp/semantics.c:3426
 #, fuzzy, gcc-internal-format
 #| msgid "protected member %q+#D in anonymous union"
 msgid "cannot capture member %qD of anonymous union"
 msgstr "anggota terproteksi %q+#D dalam union anonymous"
 
-#: cp/semantics.c:3443 cp/semantics.c:9269
+#: cp/semantics.c:3446 cp/semantics.c:9272
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a type"
 msgid "%qD is not captured"
 msgstr "%qD bukan sebuah tipe"
 
-#: cp/semantics.c:3448
+#: cp/semantics.c:3451
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.c:3450
+#: cp/semantics.c:3453
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.c:3462
+#: cp/semantics.c:3465
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<auto%> variable from containing function"
 msgid "use of local variable with automatic storage from containing function"
 msgstr "penggunaan dari variabel %<auto%> dari fungsi yang berisi"
 
-#: cp/semantics.c:3464
+#: cp/semantics.c:3467
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<auto%> variable from containing function"
 msgid "use of parameter from containing function"
 msgstr "penggunaan dari variabel %<auto%> dari fungsi yang berisi"
 
-#: cp/semantics.c:3596
+#: cp/semantics.c:3599
 #, fuzzy, gcc-internal-format
 #| msgid "alloc_size parameter outside range"
 msgid "use of parameter outside function body"
 msgstr "alloc_size parameter diluar dari jangkauan"
 
-#: cp/semantics.c:3606
+#: cp/semantics.c:3609
 #, fuzzy, gcc-internal-format
 #| msgid "mismatched arguments"
 msgid "missing template arguments"
 msgstr "argumen tidak cocok"
 
-#: cp/semantics.c:3633
+#: cp/semantics.c:3636
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr "parameter template %qD dari tipe %qT tidak diijinkan dalam sebuah ekspresi konstanta integral karena ini bukan tipe integral atau enumerasi"
 
-#: cp/semantics.c:3664
+#: cp/semantics.c:3667
 #, gcc-internal-format
 msgid "use of namespace %qD as expression"
 msgstr "penggunaan dari namespace %qD  sebagai ekspresi"
 
-#: cp/semantics.c:3669
+#: cp/semantics.c:3672
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr "penggunaan dari template class %qT sebagai ekspresi"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:3675
+#: cp/semantics.c:3678
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "permintaan untuk anggota %qD adalah ambigu dalam multiple inheritance lattice"
 
-#: cp/semantics.c:3702
+#: cp/semantics.c:3705
 #, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "%qD tidak dapat muncul dalam sebuah ekspresi konstan"
 
-#: cp/semantics.c:3841
+#: cp/semantics.c:3844
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "tipe dari %qE tidak dikenal"
 
-#: cp/semantics.c:3870
+#: cp/semantics.c:3873
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a template type"
 msgid "%qT is not an enumeration type"
@@ -54724,478 +54768,494 @@
 msgstr "%qT bukan sebuah tipe template"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4009
+#: cp/semantics.c:4012
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specifiers invalid in parameter declarations"
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr "penspesifikasi kelas penyimpanan dalam parameter deklarasi"
 
-#: cp/semantics.c:4038
+#: cp/semantics.c:4041
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr "tidak dapat mengaplikasikan %<offsetof%> ke destruktor %<~%T%>"
 
-#: cp/semantics.c:4052
+#: cp/semantics.c:4055
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "tidak dapat mengaplikasikan %<offsetof%> ke anggota fungsi %qD"
 
-#: cp/semantics.c:4056
+#: cp/semantics.c:4059
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply %<offsetof%> to member function %qD"
 msgid "cannot apply %<offsetof%> to member function"
 msgstr "tidak dapat mengaplikasikan %<offsetof%> ke anggota fungsi %qD"
 
-#: cp/semantics.c:4061
+#: cp/semantics.c:4064
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply %<offsetof%> to member function %qD"
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr "tidak dapat mengaplikasikan %<offsetof%> ke anggota fungsi %qD"
 
-#: cp/semantics.c:4072
+#: cp/semantics.c:4075
 #, gcc-internal-format
 msgid "offsetof within non-standard-layout type %qT is conditionally-supported"
 msgstr ""
 
-#: cp/semantics.c:4583 cp/semantics.c:6069 cp/semantics.c:6140
-#: cp/semantics.c:6183 cp/semantics.c:6533 cp/semantics.c:6632
-#: cp/semantics.c:6775
+#: cp/semantics.c:4586 cp/semantics.c:6072 cp/semantics.c:6143
+#: cp/semantics.c:6186 cp/semantics.c:6536 cp/semantics.c:6635
+#: cp/semantics.c:6778
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5271
+#: cp/semantics.c:5274
 #, fuzzy, gcc-internal-format
 #| msgid "reference to %qD is ambiguous"
 msgid "user defined reduction lookup is ambiguous"
 msgstr "referensi ke %qD adalah ambigu"
 
-#: cp/semantics.c:5544
+#: cp/semantics.c:5547
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: cp/semantics.c:5592
+#: cp/semantics.c:5595
 #, fuzzy, gcc-internal-format
 #| msgid "%qE has invalid type for %<reduction%>"
 msgid "%qE has const type for %<reduction%>"
 msgstr "%qE memiliki tipe tidak valid untuk %<reduction%>"
 
-#: cp/semantics.c:5707
+#: cp/semantics.c:5710
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:5941
+#: cp/semantics.c:5944
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5955
+#: cp/semantics.c:5958
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5977
+#: cp/semantics.c:5980
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "linear step expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.c:6080
+#: cp/semantics.c:6083
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD bukan sebuah variabel dalam clause %qs"
 
-#: cp/semantics.c:6152
+#: cp/semantics.c:6155
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "%qD bukan sebuah variabel dalam clause %<firstprivate%>"
 
-#: cp/semantics.c:6195
+#: cp/semantics.c:6198
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "%qD bukan sebuah variabel dalam clause %<lastprivate%>"
 
-#: cp/semantics.c:6240
+#: cp/semantics.c:6243
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<gang%> static expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.c:6254
+#: cp/semantics.c:6257
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<gang%> static value must be positive"
 msgstr "%<num_threads%> nilai harus positif"
 
-#: cp/semantics.c:6288
+#: cp/semantics.c:6291
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<gang%> num expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.c:6291
+#: cp/semantics.c:6294
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<vector%> length expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.c:6295
+#: cp/semantics.c:6298
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<worker%> num expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.c:6317
+#: cp/semantics.c:6320
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<gang%> num value must be positive"
 msgstr "%<num_threads%> nilai harus positif"
 
-#: cp/semantics.c:6321
+#: cp/semantics.c:6324
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<vector%> length value must be positive"
 msgstr "%<num_threads%> nilai harus positif"
 
-#: cp/semantics.c:6326
+#: cp/semantics.c:6329
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<worker%> num value must be positive"
 msgstr "%<num_threads%> nilai harus positif"
 
-#: cp/semantics.c:6376
+#: cp/semantics.c:6379
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr "schedule chunk ukuran ekspresi harus integral"
 
-#: cp/semantics.c:6406
+#: cp/semantics.c:6409
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%qs length expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.c:6419
+#: cp/semantics.c:6422
 #, fuzzy, gcc-internal-format
 #| msgid "%Hcollapse argument needs positive constant integer expression"
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "%Hkolaps argumen membutuhkan konstanta positif integer ekspresi"
 
-#: cp/semantics.c:6438
+#: cp/semantics.c:6441
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<async%> expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.c:6466
+#: cp/semantics.c:6469
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<thread_limit%> expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.c:6495
+#: cp/semantics.c:6498
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<device%> id must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.c:6516
+#: cp/semantics.c:6519
 #, fuzzy, gcc-internal-format
 #| msgid "schedule chunk size expression must be integral"
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr "schedule chunk ukuran ekspresi harus integral"
 
-#: cp/semantics.c:6543
+#: cp/semantics.c:6546
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qD bukan sebuah variabel dalam clause %qs"
 
-#: cp/semantics.c:6557
+#: cp/semantics.c:6560
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:6563
+#: cp/semantics.c:6566
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr "%qD muncul lebih dari sekali dalam data clauses"
 
-#: cp/semantics.c:6576
+#: cp/semantics.c:6579
 #, fuzzy, gcc-internal-format
 #| msgid "schedule chunk size expression must be integral"
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr "schedule chunk ukuran ekspresi harus integral"
 
-#: cp/semantics.c:6625
+#: cp/semantics.c:6628
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr "%qD bukan sebuah variabel dalam clause %qs"
 
-#: cp/semantics.c:6910
+#: cp/semantics.c:6913
 #, fuzzy, gcc-internal-format
 #| msgid "reimplementation of class %qs"
 msgid "template %qE in clause %qs"
 msgstr "reimplementasi dari class %qs"
 
-#: cp/semantics.c:6914
+#: cp/semantics.c:6917
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6979
+#: cp/semantics.c:6982
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<grainsize%> expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.c:7008
+#: cp/semantics.c:7011
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<priority%> expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.c:7037
+#: cp/semantics.c:7040
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<num_tasks%> expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.c:7066
+#: cp/semantics.c:7069
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:7105
+#: cp/semantics.c:7108
 #, fuzzy, gcc-internal-format
 #| msgid "%<tree%> is not defined as a pointer type"
 msgid "%<tile%> argument needs integral type"
 msgstr "%<tree%> tidak didefinisikan sebagai sebuah tipe pointer"
 
-#: cp/semantics.c:7524
+#: cp/semantics.c:7527
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr "%<threadprivate%> %qD bukan berkas, namespace atau blok scope variabel"
 
-#: cp/semantics.c:7538
+#: cp/semantics.c:7541
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "%<threadprivate%> %qE direktif tidak dalam definisi %qT"
 
-#: cp/semantics.c:7743
+#: cp/semantics.c:7746
 #, fuzzy, gcc-internal-format
 #| msgid "%Hdifference between %qE and %qD does not have integer type"
 msgid "difference between %qE and %qD does not have integer type"
 msgstr "%Hperbedaan antara %qE dan %qD tidak memiliki tipe integer"
 
-#: cp/semantics.c:8171
+#: cp/semantics.c:8174
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid type for iteration variable %qE"
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr "%Htipe tidak valid untuk iterasi variabel %qE"
 
-#: cp/semantics.c:8398 cp/semantics.c:8408
+#: cp/semantics.c:8401 cp/semantics.c:8411
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.c:8702
+#: cp/semantics.c:8705
 #, fuzzy, gcc-internal-format
 #| msgid "static assertion failed: %E"
 msgid "static assertion failed"
 msgstr "static assertion gagal: %E"
 
-#: cp/semantics.c:8704
+#: cp/semantics.c:8707
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "static assertion failed: %E"
 msgid "static assertion failed: %s"
 msgstr "static assertion gagal: %E"
 
-#: cp/semantics.c:8709
+#: cp/semantics.c:8712
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "kondisi bukan konstan untuk assertion static"
 
-#: cp/semantics.c:8739
+#: cp/semantics.c:8742
 #, gcc-internal-format
 msgid "argument to decltype must be an expression"
 msgstr "argumen ke decltype harus berupa sebuah ekspresi"
 
-#: cp/semantics.c:8767
+#: cp/semantics.c:8770
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "decltype cannot resolve address of overloaded function"
 msgstr "%s tidak dapat meresolf alamat dari fungsi overloaded"
 
-#: cp/semantics.c:9308
+#: cp/semantics.c:9311
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "operan tangan-kiri dari ekspresi koma tidak memiliki efek"
 
-#: cp/semantics.c:9361
+#: cp/semantics.c:9364
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %qE involves template parameter(s)"
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "template argumen %qE melibatkan parameter template"
 
-#: cp/semantics.c:9363
+#: cp/semantics.c:9366
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:9381
+#: cp/semantics.c:9384
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %<__builtin_return_address%>"
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "argumen ke %<__builtin_return_address%> tidak didukung"
 
-#: cp/tree.c:1276
+#: cp/tree.c:1295
 #, gcc-internal-format
 msgid "%qV qualifiers cannot be applied to %qT"
 msgstr "%qV kualifier tidak dapat diaplikasikan ke %qT"
 
-#: cp/tree.c:1788
+#: cp/tree.c:1807
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "lambda-expression in a constant expression"
 msgstr "Tipe buruk dalam ekspresi konstanta"
 
-#: cp/tree.c:1792
+#: cp/tree.c:1811
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "statement-expression in a constant expression"
 msgstr "Tipe buruk dalam ekspresi konstanta"
 
-#: cp/tree.c:4050
+#: cp/tree.c:4083
 #, gcc-internal-format
-msgid "the calling convention for %qT changes in -fabi-version=12 (GCC 8)"
+msgid "-fabi-version=13 (GCC 8.2) fixes the calling convention for %qT, which was accidentally changed in 8.1"
 msgstr ""
 
-#: cp/tree.c:4055
+#: cp/tree.c:4087
 #, gcc-internal-format
+msgid "-fabi-version=12 (GCC 8.1) accidentally changes the calling convention for %qT"
+msgstr ""
+
+#: cp/tree.c:4090
+#, fuzzy, gcc-internal-format
+#| msgid "%q+D declared here"
+msgid " declared here"
+msgstr "%q+D dideklarasikan disini"
+
+#: cp/tree.c:4094
+#, gcc-internal-format
+msgid "the calling convention for %qT changes in -fabi-version=13 (GCC 8.2)"
+msgstr ""
+
+#: cp/tree.c:4096
+#, gcc-internal-format
 msgid " because all of its copy and move constructors are deleted"
 msgstr ""
 
-#: cp/tree.c:4416
+#: cp/tree.c:4464
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to function types"
 msgid "%qE attribute applied to %qD with void return type"
 msgstr "atribut %qs hanya berlaku ke fungsi tipe"
 
-#: cp/tree.c:4423
+#: cp/tree.c:4471
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr "%qE atribut hanya dapat diaplikasikan ke definisi class"
 
-#: cp/tree.c:4475
+#: cp/tree.c:4523
 #, gcc-internal-format
 msgid "requested init_priority is not an integer constant"
 msgstr "permintaan init_priority bukan sebuah konstanta integer"
 
-#: cp/tree.c:4497
+#: cp/tree.c:4545
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr "hanya dapat menggunakan atribut %qE di definisi lingkup-berkas dari objek dari tipe class"
 
-#: cp/tree.c:4505
+#: cp/tree.c:4553
 #, gcc-internal-format
 msgid "requested init_priority is out of range"
 msgstr "permintaan init_priority diluar dari jangkauan"
 
-#: cp/tree.c:4515
+#: cp/tree.c:4563
 #, gcc-internal-format
 msgid "requested init_priority is reserved for internal use"
 msgstr "permintaan init_priority disimpan untuk penggunaan internal"
 
-#: cp/tree.c:4526
+#: cp/tree.c:4574
 #, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr "atribut %qE tidak didukung di platform ini"
 
-#: cp/tree.c:4553
+#: cp/tree.c:4601
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as %s"
 msgid "redeclaration of %qD adds abi tag %qE"
 msgstr "deklarasi dari %qD sebagai %s"
 
-#: cp/tree.c:4573
+#: cp/tree.c:4621
 #, fuzzy, gcc-internal-format
 #| msgid "%qD attribute requires a single NTBS argument"
 msgid "the %qE attribute requires arguments"
 msgstr "%qD atribut membutuhkan sebuah argumen NTBS tunggal"
 
-#: cp/tree.c:4584
+#: cp/tree.c:4632
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "argumen dari atribut %qs bukan sebuah konstanta string"
 
-#: cp/tree.c:4597 cp/tree.c:4610
+#: cp/tree.c:4645 cp/tree.c:4658
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "argumen dari atribut %qs bukan sebuah konstanta string"
 
-#: cp/tree.c:4599
+#: cp/tree.c:4647
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a valid declarator"
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "%<%T::%D%> bukan sebuah deklarator yang valid"
 
-#: cp/tree.c:4612
+#: cp/tree.c:4660
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a valid declarator"
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "%<%T::%D%> bukan sebuah deklarator yang valid"
 
-#: cp/tree.c:4636
+#: cp/tree.c:4684
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "%qE atribut diabaikan dalam tipe bukan-class"
 
-#: cp/tree.c:4642
+#: cp/tree.c:4690
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes applied to %qT after definition"
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "mengabaikan atribut yang diaplikasikan ke %qT setelah definisi"
 
-#: cp/tree.c:4649
+#: cp/tree.c:4697
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes applied to %qT after definition"
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "mengabaikan atribut yang diaplikasikan ke %qT setelah definisi"
 
-#: cp/tree.c:4656
+#: cp/tree.c:4704
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes applied to %qT after definition"
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "mengabaikan atribut yang diaplikasikan ke %qT setelah definisi"
 
-#: cp/tree.c:4678
+#: cp/tree.c:4726
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qE attribute applies only to functions"
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "atribut %J%qE berlaku hanya untuk fungsi"
 
-#: cp/tree.c:4684
+#: cp/tree.c:4732
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute applied to %s %s at %L"
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "%s atribut diaplikasikan ke %s %s di %L"
 
-#: cp/tree.c:5440
+#: cp/tree.c:5488
 #, fuzzy, gcc-internal-format
 #| msgid "array bound is not an integer constant"
 msgid "zero as null pointer constant"
 msgstr "array bound bukan sebuah konstanta integer"
 
-#: cp/tree.c:5453
+#: cp/tree.c:5501
 #, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr "pemeriksaan lang_*: gagal dalam %s, di %s:%d"
@@ -56394,114 +56454,114 @@
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "tidak dapat menginisialisasi kumpulan dari tipe %qT dengan sebuah kompound literal"
 
-#: cp/typeck2.c:1496 cp/typeck2.c:1523
+#: cp/typeck2.c:1499 cp/typeck2.c:1526
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "hilang penginisialisasi untuk anggota %qD"
 
-#: cp/typeck2.c:1504
+#: cp/typeck2.c:1507
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "anggota %qD referensi tidak terinisialisasi"
 
-#: cp/typeck2.c:1511
+#: cp/typeck2.c:1514
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD is uninitialized reference"
 msgid "member %qD with uninitialized reference fields"
 msgstr "anggota %qD referensi tidak terinisialisasi"
 
-#: cp/typeck2.c:1587
+#: cp/typeck2.c:1590
 #, fuzzy, gcc-internal-format
 #| msgid "prototype for %q#D does not match any in class %qT"
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "prototipe untuk %q#D tidak cocok dengan kelas apapun %qT"
 
-#: cp/typeck2.c:1660
+#: cp/typeck2.c:1663
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "tidak ada field %qD ditemukan dalam union sedang diinisialisasi"
 
-#: cp/typeck2.c:1671
+#: cp/typeck2.c:1674
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "nilai indeks daripada nama field dalam union penginisialisasi"
 
-#: cp/typeck2.c:1858
+#: cp/typeck2.c:1861
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "penunjuk circular delegasi terdeteksi"
 
-#: cp/typeck2.c:1872
+#: cp/typeck2.c:1875
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "operan dasar dari %<->%> memiliki tipe bukan penunjuk %qT"
 
-#: cp/typeck2.c:1898
+#: cp/typeck2.c:1901
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "hasil dari %<operator->()%> menghasilkan hasil bukan penunjuk"
 
-#: cp/typeck2.c:1900
+#: cp/typeck2.c:1903
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "operan dasar dari %<->%> bukan sebuah penunjuk"
 
-#: cp/typeck2.c:1927
+#: cp/typeck2.c:1930
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE tidak dapat digunakan sebagai sebuah anggota penunjuk, karena ini adalah tipe %qT"
 
-#: cp/typeck2.c:1936
+#: cp/typeck2.c:1939
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "tidak dapat mengaplikasikan anggota penunjuk %qE ke %qE, yang dari tipe bukan class %qT"
 
-#: cp/typeck2.c:1958
+#: cp/typeck2.c:1961
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "penunjuk ke anggota tipe %qT tidak kompatibel dengan tipe objek %qT"
 
-#: cp/typeck2.c:2018
+#: cp/typeck2.c:2021
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "penunjuk ke anggota fungsi digunakan dalam aritmetik"
 
-#: cp/typeck2.c:2029
+#: cp/typeck2.c:2032
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "penunjuk ke anggota fungsi digunakan dalam aritmetik"
 
-#: cp/typeck2.c:2037
+#: cp/typeck2.c:2040
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++2a"
 msgstr ""
 
-#: cp/typeck2.c:2080
+#: cp/typeck2.c:2083
 #, fuzzy, gcc-internal-format
 #| msgid "invalid cast to function type %qT"
 msgid "functional cast to array type %qT"
 msgstr "cast ke fungsi tipe %qT tidak valid"
 
-#: cp/typeck2.c:2096
+#: cp/typeck2.c:2099
 #, fuzzy, gcc-internal-format
 #| msgid "got %d template parameters for %q#T"
 msgid "cannot deduce template arguments for %qT from ()"
 msgstr "diperoleh %d parameter template untuk %q#T"
 
-#: cp/typeck2.c:2114
+#: cp/typeck2.c:2117
 #, fuzzy, gcc-internal-format
 #| msgid "invalid value-initialization of reference types"
 msgid "invalid value-initialization of reference type"
 msgstr "nilai-inisialisasi dari referensi tidak valid"
 
-#: cp/typeck2.c:2341
+#: cp/typeck2.c:2344
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "panggilan ke fungsi %qD yang melemparkan tipe tidak lengkap %q#T"
 
-#: cp/typeck2.c:2344
+#: cp/typeck2.c:2347
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "panggilan ke fungsi yang melemparkan tipe tidak lengkap %q#T"
@@ -56732,11 +56792,11 @@
 msgstr "Referensi array di %C tidak dapat memiliki lebih dari %d dimensi"
 
 #: fortran/array.c:221 fortran/array.c:661 fortran/check.c:2849
-#: fortran/check.c:5222 fortran/check.c:5260 fortran/check.c:5302
-#: fortran/check.c:5329 fortran/check.c:5529 fortran/match.c:1821
+#: fortran/check.c:5225 fortran/check.c:5263 fortran/check.c:5305
+#: fortran/check.c:5332 fortran/check.c:5532 fortran/match.c:1821
 #: fortran/match.c:3174 fortran/match.c:3516 fortran/match.c:3712
-#: fortran/simplify.c:2909 fortran/simplify.c:2939 fortran/simplify.c:5764
-#: fortran/simplify.c:7658
+#: fortran/simplify.c:2909 fortran/simplify.c:2939 fortran/simplify.c:5769
+#: fortran/simplify.c:7663
 #, gcc-internal-format
 msgid "Coarrays disabled at %C, use %<-fcoarray=%> to enable"
 msgstr ""
@@ -56882,126 +56942,132 @@
 msgid "DO-iterator %qs at %L is inside iterator of the same name"
 msgstr "DO-iterator '%s' di %L adalah didalam iterator dari nama yang sama"
 
-#: fortran/array.c:1073 fortran/array.c:1255
+#: fortran/array.c:1073 fortran/array.c:1264
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in array constructor at %C"
 msgstr "Sintaks error dalam konstruksi array di %C"
 
-#: fortran/array.c:1129
+#: fortran/array.c:1105
 #, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "ENTRY statement at %C cannot appear in a contained procedure"
+msgid "NULL() at %C cannot appear in an array constructor"
+msgstr "pernyataan MASUKAN di %C tidak dapat muncul dalam sebuah prosedur terkontain"
+
+#: fortran/array.c:1138
+#, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: [...] style array constructors at %C"
 msgid "[...] style array constructors at %C"
 msgstr "Fortran 2003: [...] gaya array konstruktor di %C"
 
-#: fortran/array.c:1149
+#: fortran/array.c:1158
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: Array constructor including type specification at %C"
 msgid "Array constructor including type specification at %C"
 msgstr "Fortran 2003: Array konstruktor termasuk tipe spesifikasi di %C"
 
-#: fortran/array.c:1155 fortran/match.c:4148
+#: fortran/array.c:1164 fortran/match.c:4148
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Type-spec at %L cannot contain a deferred type parameter"
 msgstr "Array '%s' di %L tidak dapat memiliki sebuah bentuk deferred"
 
-#: fortran/array.c:1163
+#: fortran/array.c:1172
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-spec at %L cannot contain an asterisk for a type parameter"
 msgstr ""
 
-#: fortran/array.c:1181
+#: fortran/array.c:1190
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty array constructor at %C is not allowed"
 msgstr "Konstruktor array kosong di %C tidak diperbolehkan"
 
-#: fortran/array.c:1218 fortran/array.c:1228
+#: fortran/array.c:1227 fortran/array.c:1237
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "incompatible type for argument %d of %qE"
 msgid "Incompatible typespec for array element at %L"
 msgstr "tipe tidak kompatibel untuk argumen %d dari %qE"
 
-#: fortran/array.c:1302
+#: fortran/array.c:1311
 #, gcc-internal-format, gfc-internal-format
 msgid "Element in %s array constructor at %L is %s"
 msgstr "Elemen dalam %s array konstruktor di %L adalah %s"
 
-#: fortran/array.c:1633
+#: fortran/array.c:1642
 #, gcc-internal-format, gfc-internal-format
 msgid "Iterator step at %L cannot be zero"
 msgstr "Langkah iterasi di %L tidak dapat nol"
 
-#: fortran/array.c:1770
+#: fortran/array.c:1779
 #, fuzzy, gcc-internal-format
 #| msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit.   See -fmax-array-constructor option"
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit.   See %<-fmax-array-constructor%> option"
 msgstr "Jumlah dari elemen dalam konstruktor array di %L membutuhkan sebuah peningkatan dari batas atas %d yang diijinkan. Lihat pilihan -fmax-array-constructor"
 
-#: fortran/array.c:1940
+#: fortran/array.c:1949
 #, gcc-internal-format, gfc-internal-format
 msgid "AC-IMPLIED-DO initial expression references control variable at %L"
 msgstr ""
 
-#: fortran/array.c:1947
+#: fortran/array.c:1956
 #, gcc-internal-format, gfc-internal-format
 msgid "AC-IMPLIED-DO final expression references control variable at %L"
 msgstr ""
 
-#: fortran/array.c:1954
+#: fortran/array.c:1963
 #, gcc-internal-format, gfc-internal-format
 msgid "AC-IMPLIED-DO step expression references control variable at %L"
 msgstr ""
 
-#: fortran/array.c:1966
+#: fortran/array.c:1975
 #, gcc-internal-format, gfc-internal-format
 msgid "Array constructor value at %L shall not be unlimited polymorphic [F2008: C4106]"
 msgstr ""
 
-#: fortran/array.c:2055
+#: fortran/array.c:2067
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Different CHARACTER lengths (%d/%d) in array constructor at %L"
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor at %L"
 msgstr "Pajang KARAKTER berbeda (%d/%d) dalam konstruktor array di %L"
 
-#: fortran/array.c:2174
+#: fortran/array.c:2186
 #, gcc-internal-format
 msgid "spec_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2233
+#: fortran/array.c:2245
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2237
+#: fortran/array.c:2249
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad array reference at %L"
 msgid "Bad array dimension at %L"
 msgstr "Referensi array buruk di %L"
 
-#: fortran/array.c:2264 fortran/data.c:552 fortran/data.c:571
-#: fortran/data.c:585 fortran/data.c:714
+#: fortran/array.c:2276 fortran/data.c:563 fortran/data.c:582
+#: fortran/data.c:596 fortran/data.c:725
 #, fuzzy, gcc-internal-format
 #| msgid "gimplification failed"
 msgid "Simplification error"
 msgstr "gimplification gagal"
 
-#: fortran/array.c:2376
+#: fortran/array.c:2388
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimen_type"
 msgstr ""
 
-#: fortran/array.c:2427
+#: fortran/array.c:2439
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2472
+#: fortran/array.c:2484
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad EXPR_ARRAY expr"
 msgstr ""
 
-#: fortran/array.c:2620
+#: fortran/array.c:2632
 #, gcc-internal-format
 msgid "gfc_find_array_ref(): No ref found"
 msgstr ""
@@ -57060,7 +57126,7 @@
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or PROCEDURE"
 msgstr "'%s' argumen dari '%s' intrinsik di %L harus berupa INTEGER atau PROSEDUR"
 
-#: fortran/check.c:205 fortran/check.c:6658
+#: fortran/check.c:205 fortran/check.c:6661
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a constant"
 msgid "%qs argument of %qs intrinsic at %L must be a constant"
@@ -57194,7 +57260,7 @@
 msgid "Unequal character lengths (%ld/%ld) in %s at %L"
 msgstr "Panjang karakter tidak sama (%ld/%ld) dalam %s di %L"
 
-#: fortran/check.c:946 fortran/check.c:6602
+#: fortran/check.c:946 fortran/check.c:6605
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' and '%s' arguments of '%s' intrinsic at %L must have the same type"
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have the same type"
@@ -57452,9 +57518,9 @@
 msgstr "'%s' argumen dari '%s' intrinsik di %L harus berupa tingkat 1 atau 2"
 
 #: fortran/check.c:1939 fortran/check.c:2525 fortran/check.c:2628
-#: fortran/check.c:2835 fortran/check.c:2880 fortran/check.c:4256
-#: fortran/check.c:4390 fortran/check.c:4445 fortran/check.c:5515
-#: fortran/check.c:5644
+#: fortran/check.c:2835 fortran/check.c:2880 fortran/check.c:4259
+#: fortran/check.c:4393 fortran/check.c:4448 fortran/check.c:5518
+#: fortran/check.c:5647
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: '%s' intrinsic with KIND argument at %L"
 msgid "%qs intrinsic with KIND argument at %L"
@@ -57682,7 +57748,7 @@
 msgid "NULL intrinsic with allocatable MOLD at %L"
 msgstr ""
 
-#: fortran/check.c:3768 fortran/check.c:5591
+#: fortran/check.c:3768 fortran/check.c:5594
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be of a kind not wider than the default kind (%d)"
 msgid "%qs argument of %qs intrinsic at %L must provide at least as many elements as there are .TRUE. values in %qs (%ld/%d)"
@@ -57706,407 +57772,407 @@
 msgid "%qs argument of %qs intrinsic at %L must not be a subobject of %qs"
 msgstr "'%s' argumen dari '%s' intrinsik di %L tidak boleh berupa subobjek dari '%s'"
 
-#: fortran/check.c:3901
+#: fortran/check.c:3904
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a variable"
 msgid "The argument of the RANK intrinsic at %L must be a data object"
 msgstr "'%s' argumen dari '%s' intrinsik di %L harus berupa sebuah variabel"
 
-#: fortran/check.c:4005
+#: fortran/check.c:4008
 #, fuzzy, gcc-internal-format
 #| msgid "'shape' argument of 'reshape' intrinsic at %L must be an array of constant size"
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L must be an array of constant size"
 msgstr "'shape' argumen dari 'reshape' intrinsik di %L harus berupa sebuah array dari konstantaukuran"
 
-#: fortran/check.c:4015
+#: fortran/check.c:4018
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be %s"
 msgid "%qs argument of %qs intrinsic at %L is empty"
 msgstr "'%s' argumen dari '%s' intrinsik di %L harus berupa %s"
 
-#: fortran/check.c:4022
+#: fortran/check.c:4025
 #, fuzzy, gcc-internal-format
 #| msgid "'shape' argument of 'reshape' intrinsic at %L has more than %d elements"
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L has more than %d elements"
 msgstr "'shape' argumen dari 'reshape' intrinsik di %L memiliki lebih dari %d elemen"
 
-#: fortran/check.c:4039
+#: fortran/check.c:4042
 #, fuzzy, gcc-internal-format
 #| msgid "'a%d' argument of '%s' intrinsic at %L must be %s(%d)"
 msgid "%qs argument of %qs intrinsic at %L has negative element (%d)"
 msgstr "'a%d' argumen dari '%s' intrinsik di %L harus berupa %s(%d)"
 
-#: fortran/check.c:4071
+#: fortran/check.c:4074
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Second argument of NEAREST at %L shall not be zero"
 msgid "Element %d of actual argument of RESHAPE at %L cannot be negative"
 msgstr "Argumen kedua dari NEAREST di %L tidak boleh berupa nol"
 
-#: fortran/check.c:4109
+#: fortran/check.c:4112
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be of rank %d"
 msgid "%qs argument of %qs intrinsic at %L has wrong number of elements (%d/%d)"
 msgstr "'%s' argumen dari '%s' intrinsik di %L harus dari tingkat %d"
 
-#: fortran/check.c:4127
+#: fortran/check.c:4130
 #, fuzzy, gcc-internal-format
 #| msgid "'dim' argument of %s intrinsic at %L is not a valid dimension index"
 msgid "%qs argument of %qs intrinsic at %L has out-of-range dimension (%d)"
 msgstr "'dim' argumen dari %s intrinsik di %L bukan sebuah dimensi indeks valid"
 
-#: fortran/check.c:4136
+#: fortran/check.c:4139
 #, fuzzy, gcc-internal-format
 #| msgid "'dim' argument of %s intrinsic at %L is not a valid dimension index"
 msgid "%qs argument of %qs intrinsic at %L has invalid permutation of dimensions (dimension %qd duplicated)"
 msgstr "'dim' argumen dari %s intrinsik di %L bukan sebuah dimensi indeks valid"
 
-#: fortran/check.c:4172
+#: fortran/check.c:4175
 #, gcc-internal-format, gfc-internal-format
 msgid "Without padding, there are not enough elements in the intrinsic RESHAPE source at %L to match the shape"
 msgstr "Tanpa padding, disana tidak cukup elemen dalam sumber intrinsik RESHAPE di %L untuk cocok dengan shape"
 
-#: fortran/check.c:4189 fortran/check.c:4208
+#: fortran/check.c:4192 fortran/check.c:4211
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be %s"
 msgid "%qs argument of %qs intrinsic at %L cannot be of type %s"
 msgstr "'%s' argumen dari '%s' intrinsik di %L harus berupa %s"
 
-#: fortran/check.c:4199 fortran/check.c:4218
+#: fortran/check.c:4202 fortran/check.c:4221
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a numeric type"
 msgid "%qs argument of %qs intrinsic at %L must be of an extensible type"
 msgstr "'%s' argumen dari '%s' intrinsik di %L harus berupa tipe numerik"
 
-#: fortran/check.c:4317
+#: fortran/check.c:4320
 #, gcc-internal-format
 msgid "SELECTED_REAL_KIND with neither %<P%> nor %<R%> argument at %L"
 msgstr ""
 
-#: fortran/check.c:4348
+#: fortran/check.c:4351
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: '%s' intrinsic with KIND argument at %L"
 msgid "%qs intrinsic with RADIX argument at %L"
 msgstr "Fortran 2003: '%s' intrinsik dengan JENIS argumen di %L"
 
-#: fortran/check.c:4383
+#: fortran/check.c:4386
 #, fuzzy, gcc-internal-format
 #| msgid "'source' argument of 'shape' intrinsic at %L must not be an assumed size array"
 msgid "%<source%> argument of %<shape%> intrinsic at %L must not be an assumed size array"
 msgstr "'source' argumen dari 'shape' intrinsik di %L tidak boleh sebuah ukuran arrayyang diasumsikan"
 
-#: fortran/check.c:4460 fortran/check.c:6641
+#: fortran/check.c:4463 fortran/check.c:6644
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a scalar"
 msgid "%qs argument of %qs intrinsic at %L shall not be a procedure"
 msgstr "'%s' argumen dari '%s' intrinsik di %L harus berupa sebuah skalar"
 
-#: fortran/check.c:4473 fortran/check.c:4612 fortran/check.c:6633
+#: fortran/check.c:4476 fortran/check.c:4615 fortran/check.c:6636
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L cannot be INTENT(IN)"
 msgid "%qs argument of %qs intrinsic at %L shall not be TYPE(*)"
 msgstr "'%s' argumen dari '%s' intrinsik di %L tidak dapat berupa INTENT(IN)"
 
-#: fortran/check.c:4484 fortran/check.c:4624
+#: fortran/check.c:4487 fortran/check.c:4627
 #, fuzzy, gcc-internal-format
 #| msgid "'source' argument of 'shape' intrinsic at %L must not be an assumed size array"
 msgid "%qs argument of %qs intrinsic at %L shall not be an assumed-size array"
 msgstr "'source' argumen dari 'shape' intrinsik di %L tidak boleh sebuah ukuran arrayyang diasumsikan"
 
-#: fortran/check.c:4554
+#: fortran/check.c:4557
 #, gcc-internal-format
 msgid "is_c_interoperable(): gfc_simplify_expr failed"
 msgstr ""
 
-#: fortran/check.c:4603
+#: fortran/check.c:4606
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a non-derived type"
 msgid "%qs argument of %qs intrinsic at %L must be an interoperable data entity: %s"
 msgstr "'%s' argumen dari '%s' intrinsik di %L harus berupa tipe bukan-turunan"
 
-#: fortran/check.c:4642
+#: fortran/check.c:4645
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_1 at %L to C_ASSOCIATED shall have the type TYPE(C_PTR) or TYPE(C_FUNPTR)"
 msgstr ""
 
-#: fortran/check.c:4656
+#: fortran/check.c:4659
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_2 at %L to C_ASSOCIATED shall have the same type as C_PTR_1: %s instead of %s"
 msgstr ""
 
-#: fortran/check.c:4680
+#: fortran/check.c:4683
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_POINTER shall have the type TYPE(C_PTR)"
 msgstr ""
 
-#: fortran/check.c:4692
+#: fortran/check.c:4695
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument dim at %L must be scalar"
 msgid "Argument FPTR at %L to C_F_POINTER must be a pointer"
 msgstr "Argumen dim di %L harus berupa skalar"
 
-#: fortran/check.c:4699
+#: fortran/check.c:4702
 #, gcc-internal-format, gfc-internal-format
 msgid "FPTR argument at %L to C_F_POINTER shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:4706
+#: fortran/check.c:4709
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:4713
+#: fortran/check.c:4716
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected SHAPE argument at %L to C_F_POINTER with scalar FPTR"
 msgstr ""
 
-#: fortran/check.c:4719
+#: fortran/check.c:4722
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected SHAPE argument to C_F_POINTER with array FPTR at %L"
 msgstr ""
 
-#: fortran/check.c:4738
+#: fortran/check.c:4741
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FIELD argument at %L of UNPACK must have the same rank as MASK or be a scalar"
 msgid "SHAPE argument at %L to C_F_POINTER must have the same size as the RANK of FPTR"
 msgstr "argumen FIELD di %L dari UNPACK harus memiliki tingkat sama seperti MASK atau berupa sebuah skalar"
 
-#: fortran/check.c:4748
+#: fortran/check.c:4751
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic FPTR at %L to C_F_POINTER"
 msgstr ""
 
-#: fortran/check.c:4753
+#: fortran/check.c:4756
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array FPTR at %L to C_F_POINTER: %s"
 msgstr ""
 
-#: fortran/check.c:4769
+#: fortran/check.c:4772
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_PROCPOINTER shall have the type TYPE(C_FUNPTR)"
 msgstr ""
 
-#: fortran/check.c:4781
+#: fortran/check.c:4784
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall be a procedure pointer"
 msgstr ""
 
-#: fortran/check.c:4788
+#: fortran/check.c:4791
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:4794
+#: fortran/check.c:4797
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure pointer at %L to C_F_PROCPOINTER"
 msgstr ""
 
-#: fortran/check.c:4808
+#: fortran/check.c:4811
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:4823
+#: fortran/check.c:4826
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L has no IMPLICIT type"
 msgid "Function result %qs at %L is invalid as X argument to C_FUNLOC"
 msgstr "Hasil fungsi '%s' di %L tidak memiliki tipe IMPLISIT"
 
-#: fortran/check.c:4831
+#: fortran/check.c:4834
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall be a procedure or a procedure pointer"
 msgstr ""
 
-#: fortran/check.c:4837
+#: fortran/check.c:4840
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "User operator procedure '%s' at %L must be a FUNCTION"
 msgid "Noninteroperable procedure at %L to C_FUNLOC"
 msgstr "Prosedur operator pengguna '%s' di %L harus berupa sebuah FUNGSI"
 
-#: fortran/check.c:4851
+#: fortran/check.c:4854
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:4857
+#: fortran/check.c:4860
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Second argument of NEAREST at %L shall not be zero"
 msgid "X argument at %L to C_LOC shall not be polymorphic"
 msgstr "Argumen kedua dari NEAREST di %L tidak boleh berupa nol"
 
-#: fortran/check.c:4868
+#: fortran/check.c:4871
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Component at %C must have the POINTER attribute"
 msgid "Argument X at %L to C_LOC shall have either the POINTER or the TARGET attribute"
 msgstr "Komponen di %C harus memiliki sebuah atribut PENUNJUK"
 
-#: fortran/check.c:4876
+#: fortran/check.c:4879
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall be not be a zero-sized string"
 msgstr ""
 
-#: fortran/check.c:4885
+#: fortran/check.c:4888
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument at %L to C_LOC shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:4892
+#: fortran/check.c:4895
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array at %L as argument to C_LOC: %s"
 msgstr ""
 
-#: fortran/check.c:4903
+#: fortran/check.c:4906
 #, gcc-internal-format, gfc-internal-format
 msgid "Array of interoperable type at %L to C_LOC which is nonallocatable and neither assumed size nor explicit size"
 msgstr ""
 
-#: fortran/check.c:4908
+#: fortran/check.c:4911
 #, gcc-internal-format, gfc-internal-format
 msgid "Array section at %L to C_LOC"
 msgstr ""
 
-#: fortran/check.c:4936
+#: fortran/check.c:4939
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing arguments to %s intrinsic at %L"
 msgid "non double precision REAL argument to %s intrinsic at %L"
 msgstr "Hilang argumen ke %s intrinsik di %L"
 
-#: fortran/check.c:4949
+#: fortran/check.c:4952
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be less than rank %d"
 msgid "%qs argument of %qs intrinsic at %L must be less than rank %d"
 msgstr "'%s' argumen dari '%s' intrinsik di %L harus lebih kecil dari tingkat %d"
 
-#: fortran/check.c:4968
+#: fortran/check.c:4971
 #, fuzzy, gcc-internal-format
 #| msgid "'dim' argument of %s intrinsic at %L is not a valid dimension index"
 msgid "%qs argument of %qs intrinsic at %L is not a valid dimension index"
 msgstr "'dim' argumen dari %s intrinsik di %L bukan sebuah dimensi indeks valid"
 
-#: fortran/check.c:5231
+#: fortran/check.c:5234
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "%s argument to IMAGE_INDEX must be a rank one array at %L"
 msgstr "Aktual argumen untuk '%s' harus berupa sebuah penunjuk di %L"
 
-#: fortran/check.c:5242
+#: fortran/check.c:5245
 #, gcc-internal-format, gfc-internal-format
 msgid "The number of array elements of the SUB argument to IMAGE_INDEX at %L shall be %d (corank) not %d"
 msgstr ""
 
-#: fortran/check.c:5275
+#: fortran/check.c:5278
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to NUM_IMAGES at %L"
 msgstr ""
 
-#: fortran/check.c:5288
+#: fortran/check.c:5291
 #, gcc-internal-format, gfc-internal-format
 msgid "FAILED= argument to NUM_IMAGES at %L"
 msgstr ""
 
-#: fortran/check.c:5312
+#: fortran/check.c:5315
 #, gcc-internal-format, gfc-internal-format
 msgid "TEAM argument at %L to the intrinsic TEAM_NUMBER shall be of type TEAM_TYPE"
 msgstr ""
 
-#: fortran/check.c:5338
+#: fortran/check.c:5341
 #, gcc-internal-format, gfc-internal-format
 msgid "DIM argument without COARRAY argument not allowed for THIS_IMAGE intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:5345
+#: fortran/check.c:5348
 #, gcc-internal-format, gfc-internal-format
 msgid "The DISTANCE argument may not be specified together with the COARRAY or DIM argument in intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:5356
+#: fortran/check.c:5359
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk in formal argument list at %C"
 msgid "Unexpected DIM argument with noncoarray argument at %L"
 msgstr "Tidak teduga sampah dalam daftar argumen formal di %C"
 
-#: fortran/check.c:5374
+#: fortran/check.c:5377
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to THIS_IMAGE at %L"
 msgstr ""
 
-#: fortran/check.c:5454
+#: fortran/check.c:5457
 #, fuzzy, gcc-internal-format
 #| msgid "'MOLD' argument of 'TRANSFER' intrinsic at %L must not be %s"
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L must not be %s"
 msgstr "'MOLD' argumen dari 'TRANSFER' intrinsik di %L tidak boleh berupa %s"
 
-#: fortran/check.c:5483
+#: fortran/check.c:5486
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic TRANSFER at %L has partly undefined result: source size %ld < result size %ld"
 msgstr "Intrinsik TRANSFER di %L memiliki hasil tidak terdefinisi sebagian: ukuran sumber %ld < ukuran hasil %ld"
 
-#: fortran/check.c:5605
+#: fortran/check.c:5608
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be the same kind as '%s'"
 msgid "%qs argument of %qs intrinsic at %L must have the same rank as %qs or be a scalar"
 msgstr "'%s' argumen dari '%s' intrinsik di %L harus berupa jenis sama dengan '%s'"
 
-#: fortran/check.c:5618
+#: fortran/check.c:5621
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' and '%s' arguments of '%s' intrinsic at %L must have the same type"
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have identical shape."
 msgstr "'%s' dan '%s' argumen dari '%s' intrinsik di %L harus memiliki tipe yang sama"
 
-#: fortran/check.c:5861 fortran/check.c:5893
+#: fortran/check.c:5864 fortran/check.c:5896
 #, fuzzy, gcc-internal-format
 #| msgid "Size of '%s' argument of '%s' intrinsic at %L too small (%i/%i)"
 msgid "Size of %qs argument of %qs intrinsic at %L too small (%i/%i)"
 msgstr "Ukuran dari '%s' argumen dari '%s' intrinsik di %L terlalu kecil (%i/%i)"
 
-#: fortran/check.c:5901
+#: fortran/check.c:5904
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many arguments to %s at %L"
 msgstr "Terlalu banyak argumen ke %s di %L"
 
-#: fortran/check.c:5919
+#: fortran/check.c:5922
 #, gcc-internal-format
 msgid "fe_runtime_error string must be null terminated"
 msgstr ""
 
-#: fortran/check.c:5931
+#: fortran/check.c:5934
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "fe_runtime_error: Wrong number of arguments (%d instead of %d)"
 msgstr "jumlah dari argumen template salah (%d, seharusnya %d)"
 
-#: fortran/check.c:5971
+#: fortran/check.c:5974
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:5990
+#: fortran/check.c:5993
 #, gcc-internal-format, gfc-internal-format
 msgid "Real COUNT_RATE argument to SYSTEM_CLOCK at %L"
 msgstr ""
 
-#: fortran/check.c:6000
+#: fortran/check.c:6003
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT_RATE argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:6017
+#: fortran/check.c:6020
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT_MAX argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:6234
+#: fortran/check.c:6237
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be of a kind not wider than the default kind (%d)"
 msgid "%qs argument of %qs intrinsic at %L must be of a kind not wider than the default kind (%d)"
 msgstr "'%s' argumen dari '%s' intrinsik di %L harus berupa sebuah jenis tidak lebih lebar dari jenis baku (%d)"
 
-#: fortran/check.c:6586 fortran/check.c:6594
+#: fortran/check.c:6589 fortran/check.c:6597
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be INTEGER or LOGICAL"
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or LOGICAL"
 msgstr "'%s' argumen dari '%s' intrinsik di %L harus berupa INTEGER atau LOGIKAL"
 
-#: fortran/check.c:6625
+#: fortran/check.c:6628
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic function NULL at %L cannot be an actual argument to STORAGE_SIZE, because it returns a disassociated pointer"
 msgstr ""
@@ -58118,7 +58184,7 @@
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:727 fortran/decl.c:3636 fortran/decl.c:10066
+#: fortran/class.c:727 fortran/decl.c:3655 fortran/decl.c:10091
 #, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr ""
@@ -58146,46 +58212,52 @@
 msgid "non-constant array in DATA statement %L"
 msgstr "bukan-konstanta array dalam pernyataan DATA %L"
 
-#: fortran/data.c:137
+#: fortran/data.c:140
 #, gcc-internal-format, gfc-internal-format
 msgid "failure to simplify substring reference in DATA statement at %L"
 msgstr "gagal untuk menyederhanakan referensi substring dalam laporan DATA di %L"
 
-#: fortran/data.c:170
+#: fortran/data.c:173
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "initialization string truncated to match variable at %L"
 msgid "Unused initialization string at %L because variable has zero length"
 msgstr "inisialisasi dari string terpotong untuk mencocokan dengan variabel di %L"
 
-#: fortran/data.c:176
+#: fortran/data.c:179
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "initialization string truncated to match variable at %L"
 msgid "Initialization string at %L was truncated to fit the variable (%ld/%ld)"
 msgstr "inisialisasi dari string terpotong untuk mencocokan dengan variabel di %L"
 
-#: fortran/data.c:265
+#: fortran/data.c:268
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L already is initialized at %L"
 msgid "%qs at %L already is initialized at %L"
 msgstr "'%s' di %L telah terinisialisasi di %L"
 
-#: fortran/data.c:289
+#: fortran/data.c:292
 #, gcc-internal-format, gfc-internal-format
 msgid "Data element below array lower bound at %L"
 msgstr "Elemen data dibawah array batas bawah di %L"
 
-#: fortran/data.c:306 fortran/data.c:395
+#: fortran/data.c:309 fortran/data.c:398
 #, gcc-internal-format, gfc-internal-format
 msgid "Data element above array upper bound at %L"
 msgstr "Elemen data diatas array batas atas di %L"
 
-#: fortran/data.c:336 fortran/data.c:505
+#: fortran/data.c:339 fortran/data.c:496
 #, fuzzy, gcc-internal-format
 #| msgid "Extension: re-initialization of '%s' at %L"
 msgid "re-initialization of %qs at %L"
 msgstr "Ekstensi: reinisialisasi dari '%s' di %L"
 
-#: fortran/data.c:727
+#: fortran/data.c:515
+#, fuzzy, gcc-internal-format
+#| msgid "Variable '%s' at %C with an initializer already appears in a DATA statement"
+msgid "Nonpointer object %qs with default initialization shall not appear in a DATA statement at %L"
+msgstr "Variabel '%s' di %C dengan sebuah penginisialisasi telah muncul dalam sebuah pernyataan DATA"
+
+#: fortran/data.c:738
 #, gcc-internal-format
 msgid "TODO: Vector sections in data statements"
 msgstr ""
@@ -58214,863 +58286,863 @@
 msgid "Invalid initializer %s in Data statement at %C"
 msgstr "Penginisialisasi %c tidak valid dalam pernyataan DATA di %C"
 
-#: fortran/decl.c:536
+#: fortran/decl.c:537
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C is not allowed in a PURE procedure"
 msgstr "inisialisasi di %C tidak diperbolehkan dalam sebuah prosedur PURE"
 
-#: fortran/decl.c:573
+#: fortran/decl.c:574
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgid "DATA statement at %C cannot appear within an INTERFACE"
 msgstr "pernyataan MASUKAN di %C tidak dapat muncul dalam sebuah ANTAR-MUKA"
 
-#: fortran/decl.c:597
+#: fortran/decl.c:598
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid initializer %s in Data statement at %C"
 msgid "Invalid substring in data-implied-do at %L in DATA statement"
 msgstr "Penginisialisasi %c tidak valid dalam pernyataan DATA di %C"
 
-#: fortran/decl.c:619
+#: fortran/decl.c:620
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %C is not allowed in a PURE procedure"
 msgstr "pernyataan DATA di %C tidak diperbolehkan dalam sebuah prosedur PURE"
 
-#: fortran/decl.c:664
+#: fortran/decl.c:662
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Old-style initialization at %C"
 msgid "Empty old style initializer list at %C"
 msgstr "Ekstensi: Gaya-lama inisialisasi di %C"
 
-#: fortran/decl.c:684
+#: fortran/decl.c:671
 #, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "Array component of structure at %C must have an explicit shape"
+msgid "Array in initializer list at %L must have an explicit shape"
+msgstr "Struktur komponen array di %C harus memiliki sebuah bentuk eksplisit"
+
+#: fortran/decl.c:694
+#, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "extra elements in scalar initializer"
 msgid "Repeat spec invalid in scalar initializer at %C"
 msgstr "kelebihan elemen dalam penginisialisasi skalar"
 
-#: fortran/decl.c:689
+#: fortran/decl.c:699
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Cray pointer at %C must be an integer"
 msgid "Repeat spec must be an integer at %C"
 msgstr "Penunjuk Cray di %C harus berupa sebuah integer"
 
-#: fortran/decl.c:698
+#: fortran/decl.c:710
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected alternate return label at %C"
 msgid "Expected data constant after repeat spec at %C"
 msgstr "Diduga alternatif label kembali di %C"
 
-#: fortran/decl.c:729
+#: fortran/decl.c:742
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected scalar initialization expression at %C"
 msgid "End of scalar initializer expected at %C"
 msgstr "Didugak ekspresi inisialisasi skalar di %C"
 
-#: fortran/decl.c:758
+#: fortran/decl.c:773
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "nonconstant array index in initializer"
-msgid "Expected constant array-spec in initializer list at %L"
-msgstr "indeks array bukan konstan dalam penginisialisasi"
-
-#: fortran/decl.c:767
-#, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "excess elements in array initializer"
 msgid "Not enough elements in array initializer at %C"
 msgstr "kelebihan elemen dalam array penginisialisasi"
 
-#: fortran/decl.c:769
+#: fortran/decl.c:775
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "excess elements in array initializer"
 msgid "Too many elements in array initializer at %C"
 msgstr "kelebihan elemen dalam array penginisialisasi"
 
-#: fortran/decl.c:790
+#: fortran/decl.c:795
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in OpenMP variable list at %C"
 msgid "Syntax error in old style initializer list at %C"
 msgstr "Sintaks error dalam daftar variabel OpenMP di %C"
 
-#: fortran/decl.c:812
+#: fortran/decl.c:821
 #, gcc-internal-format, gfc-internal-format
 msgid "The assumed-rank array at %C shall not have a codimension"
 msgstr ""
 
-#: fortran/decl.c:876
+#: fortran/decl.c:885
 #, gcc-internal-format, gfc-internal-format
 msgid "Sum of array rank %d and corank %d at %C exceeds maximum allowed dimensions of %d"
 msgstr ""
 
-#: fortran/decl.c:900
+#: fortran/decl.c:909
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad INTENT specification at %C"
 msgstr "Spesifikasi INTENT buruk di %C"
 
-#: fortran/decl.c:921
+#: fortran/decl.c:930
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "using template type parameter %qT after %qs"
 msgid "deferred type parameter at %C"
 msgstr "menggunakan parameter tipe template %qT setelah %qs"
 
-#: fortran/decl.c:1004 fortran/resolve.c:11705
+#: fortran/decl.c:1013 fortran/resolve.c:11725
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
 
-#: fortran/decl.c:1030
+#: fortran/decl.c:1039
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid character in name at %C"
 msgid "Old-style character length at %C"
 msgstr "Karakter tidak valid dalam nama di %C"
 
-#: fortran/decl.c:1061
+#: fortran/decl.c:1070
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in character length specification at %C"
 msgstr "Sintaks error dalam spesifikasi panjang karakter di %C"
 
-#: fortran/decl.c:1212 fortran/decl.c:1217 fortran/decl.c:1266
+#: fortran/decl.c:1221 fortran/decl.c:1226 fortran/decl.c:1275
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %C is already defined at %L"
 msgid "Procedure %qs at %C is already defined at %L"
 msgstr "Prosedur '%s' di %C telah terdefinisi di %L"
 
-#: fortran/decl.c:1222
+#: fortran/decl.c:1231
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %C is already defined at %L"
 msgid "Contained procedure %qs at %C clashes with procedure defined at %L"
 msgstr "Prosedur '%s' di %C telah terdefinisi di %L"
 
-#: fortran/decl.c:1231
+#: fortran/decl.c:1240
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is already defined as a generic interface at %L"
 msgid "Name %qs at %C is already defined as a generic interface at %L"
 msgstr "Nama '%s' di %C telah terdefinisi sebagai sebuah antar-muka umum di %L"
 
-#: fortran/decl.c:1244
+#: fortran/decl.c:1253
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %C has an explicit interface and must not have attributes declared at %L"
 msgid "Procedure %qs at %C has an explicit interface from a previous declaration"
 msgstr "Prosedur '%s' di %C memiliki sebuah antar-muka eksplisit dan tidak boleh memiliki atribut terdeklarasi di %L"
 
-#: fortran/decl.c:1257
+#: fortran/decl.c:1266
 #, gcc-internal-format
 msgid "Procedure %qs defined in interface body at %L clashes with internal procedure defined at %C"
 msgstr ""
 
-#: fortran/decl.c:1335
+#: fortran/decl.c:1344
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L must have the BIND(C) attribute to be C interoperable"
 msgid "Procedure %qs at %L must have the BIND(C) attribute to be C interoperable"
 msgstr "Prosedur '%s' di %L harus memiliki atribut BIND(C) supaya C interoperable"
 
-#: fortran/decl.c:1362
+#: fortran/decl.c:1371
 #, fuzzy, gcc-internal-format
 #| msgid "Type '%s' at %L is a parameter to the BIND(C)  procedure '%s' but is not C interoperable because derived type '%s' is not C interoperable"
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because derived type %qs is not C interoperable"
 msgstr "Tipe '%s' di %L adalah sebuah parameter ke BIND(C) prosedur '%s' tetapi bukan C interoperable karena tipe turunan '%s' bukan C interoperable"
 
-#: fortran/decl.c:1369
+#: fortran/decl.c:1378
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L is a parameter to the BIND(C) procedure '%s' but may not be C interoperable"
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because it is polymorphic"
 msgstr "Variabel '%s' di %L adalah sebuah parameter ke prosedur BIND(C) '%s' tetapi mungkintidak C interoperable"
 
-#: fortran/decl.c:1376
+#: fortran/decl.c:1385
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L is a parameter to the BIND(C) procedure '%s' but may not be C interoperable"
 msgid "Variable %qs at %L is a dummy argument of the BIND(C) procedure %qs but may not be C interoperable"
 msgstr "Variabel '%s' di %L adalah sebuah parameter ke prosedur BIND(C) '%s' tetapi mungkintidak C interoperable"
 
-#: fortran/decl.c:1391
+#: fortran/decl.c:1400
 #, fuzzy, gcc-internal-format
 #| msgid "Character argument '%s' at %L must be length 1 because procedure '%s' is BIND(C)"
 msgid "Character argument %qs at %L must be length 1 because procedure %qs is BIND(C)"
 msgstr "Argumen karakter '%s' di %L harus memiliki panjang 1 karena prosedur '%s' adalah BIND(C)"
 
-#: fortran/decl.c:1404
+#: fortran/decl.c:1413
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot have the ALLOCATABLE attribute because procedure '%s' is BIND(C)"
 msgid "Variable %qs at %L with ALLOCATABLE attribute in procedure %qs with BIND(C)"
 msgstr "Variabel '%s' di %L tidak dapat memiliki atribut ALLOCATABLE karena prosedur '%s' adalah BIND(C)"
 
-#: fortran/decl.c:1412
+#: fortran/decl.c:1421
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot have the POINTER attribute because procedure '%s' is BIND(C)"
 msgid "Variable %qs at %L with POINTER attribute in procedure %qs with BIND(C)"
 msgstr "Variabel '%s' di %L tidak dapat memiliki atribut PENUNJUK karena prosedur '%s' adalah BIND(C)"
 
-#: fortran/decl.c:1421
+#: fortran/decl.c:1430
 #, gcc-internal-format
 msgid "Scalar variable %qs at %L with POINTER or ALLOCATABLE in procedure %qs with BIND(C) is not yet supported"
 msgstr ""
 
-#: fortran/decl.c:1430
+#: fortran/decl.c:1439
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot have the OPTIONAL attribute because procedure '%s' is BIND(C)"
 msgid "Variable %qs at %L cannot have both the OPTIONAL and the VALUE attribute because procedure %qs is BIND(C)"
 msgstr "Variabel '%s' di %L tidak dapat memiliki atribut OPSIONAL karena prosedur '%s' adalah BIND(C)"
 
-#: fortran/decl.c:1437
+#: fortran/decl.c:1446
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot have the OPTIONAL attribute because procedure '%s' is BIND(C)"
 msgid "Variable %qs at %L with OPTIONAL attribute in procedure %qs which is BIND(C)"
 msgstr "Variabel '%s' di %L tidak dapat memiliki atribut OPSIONAL karena prosedur '%s' adalah BIND(C)"
 
-#: fortran/decl.c:1448
+#: fortran/decl.c:1457
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed-shape array '%s' at %L cannot be an argument to the procedure '%s' at %L because the procedure is BIND(C)"
 msgid "Assumed-shape array %qs at %L as dummy argument to the BIND(C) procedure %qs at %L"
 msgstr "Bentuk-diasumsikan array '%s' di %L tidak dapat berupa sebuah argumen ke prosedur '%s' di %L karena prosedur adalah BIND(C)"
 
-#: fortran/decl.c:1516
+#: fortran/decl.c:1525
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L cannot have a type"
 msgid "Symbol %qs at %C also declared as a type at %L"
 msgstr "Simbol '%s' di %L tidak dapat memiliki sebuah tipe"
 
-#: fortran/decl.c:1575
+#: fortran/decl.c:1584
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' in common block '%s' at %C must be declared with a C interoperable kind since common block '%s' is BIND(C)"
 msgid "Variable %qs in common block %qs at %C must be declared with a C interoperable kind since common block %qs is BIND(C)"
 msgstr "Variabel '%s' dalam blok umum '%s' di %C harus terdeklarasi dengan sebuah jenis C interoperable karena blok umum '%s' adalah BIND(C)"
 
-#: fortran/decl.c:1615
+#: fortran/decl.c:1624
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument must be a constant"
 msgid "CHARACTER length must be a constant at %L"
 msgstr "argumen harus berupa sebuah konstanta"
 
-#: fortran/decl.c:1630
+#: fortran/decl.c:1639
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CHARACTER expression at %L is being truncated (%d/%d)"
 msgid "CHARACTER expression at %L is being truncated (%ld/%ld)"
 msgstr "ekspresi KARAKTER di %L terpotong (%d/%d)"
 
-#: fortran/decl.c:1638
+#: fortran/decl.c:1647
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The CHARACTER elements of the array constructor at %L must have the same length (%d/%d)"
 msgid "The CHARACTER elements of the array constructor at %L must have the same length (%ld/%ld)"
 msgstr "Elemen KARAKTER dari konstruktor array di %L harus memiliki panjang yang sama (%d/%d)"
 
-#: fortran/decl.c:1729
+#: fortran/decl.c:1738
 #, fuzzy, gcc-internal-format
 #| msgid "Initializer not allowed for PARAMETER '%s' at %C"
 msgid "Initializer not allowed for PARAMETER %qs at %C"
 msgstr "Penginisialisasi tidak diperbolehkan untuk PARAMETER '%s' di %C"
 
-#: fortran/decl.c:1739
+#: fortran/decl.c:1748
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER at %L is missing an initializer"
 msgstr "PARAMETER di %L hilang sebuah penginisialisasi"
 
-#: fortran/decl.c:1749
+#: fortran/decl.c:1758
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %C with an initializer already appears in a DATA statement"
 msgid "Variable %qs at %C with an initializer already appears in a DATA statement"
 msgstr "Variabel '%s' di %C dengan sebuah penginisialisasi telah muncul dalam sebuah pernyataan DATA"
 
-#: fortran/decl.c:1792
+#: fortran/decl.c:1801
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot initialize parameter array at %L with variable length elements"
 msgstr ""
 
-#: fortran/decl.c:1861
+#: fortran/decl.c:1870
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot initialize multi-dimensional array with initializer"
 msgid "Can't initialize implied-shape array at %L with scalar"
 msgstr "tidak dapat menginisialisasi array multidimensi dengan penginisialisasi"
 
-#: fortran/decl.c:1896
+#: fortran/decl.c:1905
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in data declaration at %C"
 msgid "Non-constant lower bound in implied-shape declaration at %L"
 msgstr "Sintaks error dalam deklarasi data di %C"
 
-#: fortran/decl.c:1982 fortran/decl.c:1989
+#: fortran/decl.c:1991 fortran/decl.c:1998
 #, gcc-internal-format, gfc-internal-format
 msgid "Component at %C must have the POINTER attribute"
 msgstr "Komponen di %C harus memiliki sebuah atribut PENUNJUK"
 
-#: fortran/decl.c:1998
+#: fortran/decl.c:2007
 #, gcc-internal-format
 msgid "Component %qs with CLASS at %C must be allocatable or pointer"
 msgstr ""
 
-#: fortran/decl.c:2007
+#: fortran/decl.c:2016
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr "Komponen array dari struktur di %C harus memiliki bentuk eksplisit atau deffered"
 
-#: fortran/decl.c:2031 fortran/symbol.c:2230
+#: fortran/decl.c:2040 fortran/symbol.c:2244
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C already declared at %L"
 msgid "Component %qs at %C already declared at %L"
 msgstr "Komponen '%s' di %C telah dideklarasikan di %L"
 
-#: fortran/decl.c:2079
+#: fortran/decl.c:2088
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer array component of structure at %C must have a deferred shape"
 msgstr "Komponen penunjuk array dari struktur di %C harus memilki sebuah bentuk deffered"
 
-#: fortran/decl.c:2088
+#: fortran/decl.c:2097
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component of structure at %C must have a deferred shape"
 msgstr "Komponen dapat dialokasikan dari struktur di %C harus memiliki sebuah bentuk deffered"
 
-#: fortran/decl.c:2097
+#: fortran/decl.c:2106
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have an explicit shape"
 msgstr "Struktur komponen array di %C harus memiliki sebuah bentuk eksplisit"
 
-#: fortran/decl.c:2114
+#: fortran/decl.c:2123
 #, fuzzy, gcc-internal-format
 #| msgid "a parameter list with an ellipsis can%'t match an empty parameter name list declaration"
 msgid "Type parameter %qs at %C has no corresponding entry in the type parameter name list at %L"
 msgstr "sebuah daftar parameter dengan sebuah ellipsis tidak dapat cocok dengan sebuah parameter kosong deklarasi daftar nama"
 
-#: fortran/decl.c:2171
+#: fortran/decl.c:2180
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C is ambiguous"
 msgstr "inisialisasi NULL() di %C adalah ambigu"
 
-#: fortran/decl.c:2188
+#: fortran/decl.c:2197
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "NULL() initialization at %C is ambiguous"
 msgid "NULL() initialization at %C may not have MOLD"
 msgstr "inisialisasi NULL() di %C adalah ambigu"
 
-#: fortran/decl.c:2205
+#: fortran/decl.c:2214
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of pointer at %C is not allowed in a PURE procedure"
 msgstr "Inisialisasi dari pointer di %C tidak diperbolehkan dalam prosedur PURE"
 
-#: fortran/decl.c:2226
+#: fortran/decl.c:2235
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Old-style initialization at %C"
 msgid "Error in pointer initialization at %C"
 msgstr "Ekstensi: Gaya-lama inisialisasi di %C"
 
-#: fortran/decl.c:2233
+#: fortran/decl.c:2242
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Old-style initialization at %C"
 msgid "non-NULL pointer initialization at %C"
 msgstr "Ekstensi: Gaya-lama inisialisasi di %C"
 
-#: fortran/decl.c:2256
+#: fortran/decl.c:2265
 #, gcc-internal-format
 msgid "RESULT variable %qs at %L prohibits FUNCTION name %qs at %C from appearing in a specification statement"
 msgstr ""
 
-#: fortran/decl.c:2318
+#: fortran/decl.c:2327
 #, gcc-internal-format
 msgid "%qs not allowed outside STRUCTURE at %C"
 msgstr ""
 
-#: fortran/decl.c:2320
+#: fortran/decl.c:2329
 #, gcc-internal-format
 msgid "%qs at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr ""
 
-#: fortran/decl.c:2327
+#: fortran/decl.c:2336
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "%qs entity cannot have attributes at %C"
 msgstr "%s atribut konflik dengan %s atribut di %L"
 
-#: fortran/decl.c:2367
+#: fortran/decl.c:2376
 #, gcc-internal-format
 msgid "Non-PARAMETER symbol %qs at %L can't be implied-shape"
 msgstr ""
 
-#: fortran/decl.c:2377
+#: fortran/decl.c:2386
 #, gcc-internal-format, gfc-internal-format
 msgid "Implied-shape array at %L"
 msgstr ""
 
-#: fortran/decl.c:2422
+#: fortran/decl.c:2431
 #, gcc-internal-format, gfc-internal-format
 msgid "Explicit shaped array with nonconstant bounds at %C"
 msgstr ""
 
-#: fortran/decl.c:2501
+#: fortran/decl.c:2510
 #, gcc-internal-format
 msgid "%qs at %C is a redefinition of the declaration in the corresponding interface for MODULE PROCEDURE %qs"
 msgstr ""
 
-#: fortran/decl.c:2512
+#: fortran/decl.c:2521
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "%qs entity cannot have an initializer at %C"
 msgstr "Dummy '%s' di %L tidak dapat memiliki sebuah penginisialisasi"
 
-#: fortran/decl.c:2538 fortran/decl.c:8369
+#: fortran/decl.c:2547 fortran/decl.c:8388
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr "Duplikasi spesifikasi array untuk Cray pointee di %C"
 
-#: fortran/decl.c:2546
+#: fortran/decl.c:2555
 #, gcc-internal-format
 msgid "Couldn't set pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:2609
+#: fortran/decl.c:2618
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Old-style initialization at %C"
 msgid "Old-style initialization at %C"
 msgstr "Ekstensi: Gaya-lama inisialisasi di %C"
 
-#: fortran/decl.c:2617
+#: fortran/decl.c:2626
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid value-initialization of reference types"
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr "nilai-inisialisasi dari referensi tidak valid"
 
-#: fortran/decl.c:2630
+#: fortran/decl.c:2639
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Old-style initialization at %C"
 msgid "Syntax error in old style initialization of %s at %C"
 msgstr "Ekstensi: Gaya-lama inisialisasi di %C"
 
-#: fortran/decl.c:2650 fortran/decl.c:6661
+#: fortran/decl.c:2659 fortran/decl.c:6680
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr "Inisialisasi di %C bukan sebuah variabel penunjuk"
 
-#: fortran/decl.c:2663
+#: fortran/decl.c:2672
 #, fuzzy, gcc-internal-format
 #| msgid "Pointer initialization at %C requires '=>', not '='"
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr "Inisialisasi dari penunjuk di %C membutuhkan '=>', bukan '='"
 
-#: fortran/decl.c:2672 fortran/decl.c:10240
+#: fortran/decl.c:2681 fortran/decl.c:10265
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr "Diduga sebuah ekspresi inisialisasi di %C"
 
-#: fortran/decl.c:2679
+#: fortran/decl.c:2688
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr "Inisialisasi dari variabel di %C tidak diperbolehkan alam prosedur PURE"
 
-#: fortran/decl.c:2696
+#: fortran/decl.c:2705
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr "Inisialisasi dari komponen dapat dialokasikan di %C tidak diperbolehkan"
 
-#: fortran/decl.c:2710
+#: fortran/decl.c:2719
 #, gcc-internal-format, gfc-internal-format
 msgid "The component with KIND or LEN attribute at %C does not not appear in the type parameter list at %L"
 msgstr ""
 
-#: fortran/decl.c:2718
+#: fortran/decl.c:2727
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C that appears in the type parameter list at %L has neither the KIND nor LEN attribute"
 msgstr ""
 
-#: fortran/decl.c:2726
+#: fortran/decl.c:2735
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The pointer component '%s' of '%s' at %L is a type that has not been declared"
 msgid "The component at %C which is a type parameter must be a scalar"
 msgstr "Komponen penunjuk '%s' dari '%s' di %L adalah sebuah tipe yang belum pernah dideklarasikan"
 
-#: fortran/decl.c:2789 fortran/decl.c:2825
+#: fortran/decl.c:2798 fortran/decl.c:2834
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr "Tipe deklarasi gaya-lama %s*%d tidak didukung di %C"
 
-#: fortran/decl.c:2831
+#: fortran/decl.c:2840
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr "Tipe deklarasi tidak-baku %s*%d di %C"
 
-#: fortran/decl.c:2890 fortran/decl.c:2967
+#: fortran/decl.c:2899 fortran/decl.c:2976
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis at %C"
 msgstr "Hilang paranthesis kanan di %C"
 
-#: fortran/decl.c:2903 fortran/decl.c:3038
+#: fortran/decl.c:2912 fortran/decl.c:3047
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr "Diduga ekspresi inisialisasi di %C"
 
-#: fortran/decl.c:2911 fortran/decl.c:3044
+#: fortran/decl.c:2920 fortran/decl.c:3053
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr "Didugak ekspresi inisialisasi skalar di %C"
 
-#: fortran/decl.c:2941 fortran/decl.c:3657
+#: fortran/decl.c:2950 fortran/decl.c:3676
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr "Jenis %d tidak didukung untuk tipe %s di %C"
 
-#: fortran/decl.c:2954
+#: fortran/decl.c:2963
 #, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr "Jenis tipe parameter C adalah untuk tipe %s tetapi tipe di %L adalah %s"
 
-#: fortran/decl.c:2965
+#: fortran/decl.c:2974
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr "Hilang paranthesis kanan atau koma di %C"
 
-#: fortran/decl.c:3070
+#: fortran/decl.c:3079
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr "Jenis %d tidak didukung untuk KARAKTER di %C"
 
-#: fortran/decl.c:3202
+#: fortran/decl.c:3211
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr "Sintaks error dalam deklarasi KARAKTER di %C"
 
-#: fortran/decl.c:3291
+#: fortran/decl.c:3310
 #, gcc-internal-format, gfc-internal-format
 msgid "RECORD at %C is an extension, enable it with -fdec-structure"
 msgstr ""
 
-#: fortran/decl.c:3304
+#: fortran/decl.c:3323
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected after RECORD at %C"
 msgstr ""
 
-#: fortran/decl.c:3417
+#: fortran/decl.c:3436
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C cannot contain both ASSUMED and DEFERRED parameters"
 msgstr ""
 
-#: fortran/decl.c:3441
+#: fortran/decl.c:3460
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C does not contain enough parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3465
+#: fortran/decl.c:3484
 #, fuzzy, gcc-internal-format
 #| msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgid "The derived parameter %qs at %C does not have a default value"
 msgstr "parameter pertama dari %<operator new%> tidak dapat memiliki sebuah argumen baku"
 
-#: fortran/decl.c:3497
+#: fortran/decl.c:3516
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression at %L must be of INTEGER type, found %s"
 msgid "The parameter expression at %C must be of INTEGER type and not %s type"
 msgstr "Ekspresi di %L harus berupa tipe INTEGER, ditemukan %s"
 
-#: fortran/decl.c:3525
+#: fortran/decl.c:3544
 #, gcc-internal-format
 msgid "The KIND parameter %qs at %C cannot either be ASSUMED or DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:3532
+#: fortran/decl.c:3551
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L is a variable, which does not reduce to a constant expression"
 msgid "The value for the KIND parameter %qs at %C does not reduce to a constant expression"
 msgstr "Array '%s' di %L bukan sebuah variabel, yang tidak mereduksi ke sebuah ekspresi konstanta"
 
-#: fortran/decl.c:3547
+#: fortran/decl.c:3566
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C contains too many parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3556
+#: fortran/decl.c:3575
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "reference to %qD is ambiguous"
 msgid "Parameterized derived type at %C is ambiguous"
 msgstr "referensi ke %qD adalah ambigu"
 
-#: fortran/decl.c:3819
+#: fortran/decl.c:3838
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: BYTE type at %C"
 msgid "BYTE type at %C"
 msgstr "Ekstensi: BYTE tipe di %C"
 
-#: fortran/decl.c:3824
+#: fortran/decl.c:3843
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr "tipe BYTE digunakan di %C tidak tersedia dalam mesin target"
 
-#: fortran/decl.c:3846
+#: fortran/decl.c:3865
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "By-value argument at %L is not allowed in this context"
 msgid "Assumed type at %C is not allowed for components"
 msgstr "Argumen dengan nilai di %L tidak diperbolehkan dalam konteks ini"
 
-#: fortran/decl.c:3849
+#: fortran/decl.c:3868
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr ""
 
-#: fortran/decl.c:3872 fortran/decl.c:3903 fortran/decl.c:3932
-#: fortran/decl.c:4216
+#: fortran/decl.c:3891 fortran/decl.c:3922 fortran/decl.c:3951
+#: fortran/decl.c:4235
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr ""
 
-#: fortran/decl.c:3928
+#: fortran/decl.c:3947
 #, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr ""
 
-#: fortran/decl.c:3971 fortran/decl.c:4107 fortran/decl.c:4119
-#: fortran/decl.c:4133 fortran/decl.c:4611 fortran/decl.c:4619
+#: fortran/decl.c:3990 fortran/decl.c:4126 fortran/decl.c:4138
+#: fortran/decl.c:4152 fortran/decl.c:4630 fortran/decl.c:4638
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C is ambiguous"
 msgid "Type name %qs at %C is ambiguous"
 msgstr "Tipe nama '%s' di %C adalah ambigu"
 
-#: fortran/decl.c:4066
+#: fortran/decl.c:4085
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected CASE statement at %C"
 msgid "CLASS statement at %C"
 msgstr "Diduga pernyataan CASE di %C"
 
-#: fortran/decl.c:4148
+#: fortran/decl.c:4167
 #, gcc-internal-format
 msgid "Type name %qs at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr ""
 
-#: fortran/decl.c:4287
+#: fortran/decl.c:4306
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr "Duplikasi pernyataan IMPLISIT NONE di %C"
 
-#: fortran/decl.c:4296
+#: fortran/decl.c:4315
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr ""
 
-#: fortran/decl.c:4355
+#: fortran/decl.c:4374
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr "Hilang jangkauan karakter dalam IMPLISIT di %C"
 
-#: fortran/decl.c:4401
+#: fortran/decl.c:4420
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr "Huruf harus dalam urutan alphabet dalam pernyataan IMPLISIT di %C"
 
-#: fortran/decl.c:4454
+#: fortran/decl.c:4473
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "SAVE statement at %C follows blanket SAVE statement"
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr "pernyataan SAVE di %C mengikuti blanket pernyataan SAVE"
 
-#: fortran/decl.c:4464
+#: fortran/decl.c:4483
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr "Pernyataan IMPLISIT kosong di %C"
 
-#: fortran/decl.c:4570
+#: fortran/decl.c:4589
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr "pernyataan IMPOR di %C hanya diijinkan di sebuah tubuh ANTAR-MUKA"
 
-#: fortran/decl.c:4577
+#: fortran/decl.c:4596
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgid "F2008: C1210 IMPORT statement at %C is not permitted in a module procedure interface body"
 msgstr "pernyataan IMPOR di %C hanya diijinkan di sebuah tubuh ANTAR-MUKA"
 
-#: fortran/decl.c:4582
+#: fortran/decl.c:4601
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "IMPORT statement at %C"
 msgstr "Pernyataan IMPLISIT kosong di %C"
 
-#: fortran/decl.c:4596
+#: fortran/decl.c:4615
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr "Diduga daftar dari entiti bernama di %C"
 
-#: fortran/decl.c:4625
+#: fortran/decl.c:4644
 #, fuzzy, gcc-internal-format
 #| msgid "Cannot IMPORT '%s' from host scoping unit at %C - does not exist."
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr "Tidak dapat IMPOR '%s' dari satuan host scoping di %C - tidak ada."
 
-#: fortran/decl.c:4632
+#: fortran/decl.c:4651
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' is already IMPORTed from host scoping unit at %C."
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr "'%s' telah ter-IMPOR dari satuan host scoping di %C."
 
-#: fortran/decl.c:4673
+#: fortran/decl.c:4692
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IMPORT statement at %C"
 msgstr "Sintaks error dalam pernyataan IMPOR di %C"
 
-#: fortran/decl.c:5010
+#: fortran/decl.c:5029
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing dimension specification at %C"
 msgid "Missing codimension specification at %C"
 msgstr "Hilang spesifikasi dimensi di %C"
 
-#: fortran/decl.c:5012
+#: fortran/decl.c:5031
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr "Hilang spesifikasi dimensi di %C"
 
-#: fortran/decl.c:5107
+#: fortran/decl.c:5126
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr "Duplikasi %s atribut di %L"
 
-#: fortran/decl.c:5124
+#: fortran/decl.c:5143
 #, gcc-internal-format
 msgid "%s at %L is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:5141
+#: fortran/decl.c:5160
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ALLOCATABLE attribute at %C in a TYPE definition"
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr "Fortran 2003: atribut DAPAT DIALOKASIKAN di %C dalam sebuah definisi TIPE"
 
-#: fortran/decl.c:5150
+#: fortran/decl.c:5169
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: Attribute %s at %L in a TYPE definition"
 msgid "KIND attribute at %C in a TYPE definition"
 msgstr "Fortran 2003: Atribut %s di %L dalam sebuah definisi TIPE"
 
-#: fortran/decl.c:5158
+#: fortran/decl.c:5177
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be INTEGER"
 msgstr ""
 
-#: fortran/decl.c:5165
+#: fortran/decl.c:5184
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5174
+#: fortran/decl.c:5193
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ALLOCATABLE attribute at %C in a TYPE definition"
 msgid "LEN attribute at %C in a TYPE definition"
 msgstr "Fortran 2003: atribut DAPAT DIALOKASIKAN di %C dalam sebuah definisi TIPE"
 
-#: fortran/decl.c:5182
+#: fortran/decl.c:5201
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Components in TYPE at %C must precede CONTAINS"
 msgid "Component with LEN attribute at %C must be INTEGER"
 msgstr "Komponen dalam TYPE di %C harus mengawali CONTAINS"
 
-#: fortran/decl.c:5189
+#: fortran/decl.c:5208
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5198
+#: fortran/decl.c:5217
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr "Atribut di %L tidak diijinkan dalam sebuah definisi TIPE"
 
-#: fortran/decl.c:5216
+#: fortran/decl.c:5235
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: Attribute %s at %L in a TYPE definition"
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr "Fortran 2003: Atribut %s di %L dalam sebuah definisi TIPE"
 
-#: fortran/decl.c:5226
+#: fortran/decl.c:5245
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr "%s atribut di %L tidak diperbolehka diluar dari bagian spesifikasi dari sebuah modul"
 
-#: fortran/decl.c:5236
+#: fortran/decl.c:5255
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "Attribute at %L is not allowed outside a TYPE definition"
 msgstr "Atribut di %L tidak diijinkan dalam sebuah definisi TIPE"
 
-#: fortran/decl.c:5249
+#: fortran/decl.c:5268
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5260
+#: fortran/decl.c:5279
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5315 fortran/decl.c:8673
+#: fortran/decl.c:5334 fortran/decl.c:8692
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr "TERPROTEKSI di %C hanya diperbolehkan dalam bagian spesifikasi dari modul"
 
-#: fortran/decl.c:5321
+#: fortran/decl.c:5340
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: PROTECTED attribute at %C"
 msgid "PROTECTED attribute at %C"
 msgstr "Fortran 2003: atribut TERPROTEKSI di %C"
 
-#: fortran/decl.c:5355
+#: fortran/decl.c:5374
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: VALUE attribute at %C"
 msgid "VALUE attribute at %C"
 msgstr "Fortran 2003: atribut NILAI di %C"
 
-#: fortran/decl.c:5362
+#: fortran/decl.c:5381
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: VOLATILE attribute at %C"
 msgid "VOLATILE attribute at %C"
 msgstr "Fortran 2003: atribut VOLATILE di %C"
 
-#: fortran/decl.c:5369
+#: fortran/decl.c:5388
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr ""
 
-#: fortran/decl.c:5410
+#: fortran/decl.c:5429
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr "Multiple pengidentifikasi disediakan dengan penspesifikasi NAMA= tunggal di %C"
 
-#: fortran/decl.c:5508
+#: fortran/decl.c:5527
 #, fuzzy, gcc-internal-format
 #| msgid "Implicitly declared BIND(C) function '%s' at %L may not be C interoperable"
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr "secara implisit terdeklarasi fungsi BIND(C) '%s' di %L mungkin tidak C interoperable"
 
-#: fortran/decl.c:5530
+#: fortran/decl.c:5549
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' in common block '%s' at %L may not be a C interoperable kind though common block '%s' is BIND(C)"
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr "Variabel '%s' dalam blok umum '%s' di %L mungkin tidak berupa jenis C dapat berinteroperasi melalui blok umum '%s' adalah BIND(C)"
 
-#: fortran/decl.c:5539
+#: fortran/decl.c:5558
 #, fuzzy, gcc-internal-format
 #| msgid "Type declaration '%s' at %L is not C interoperable but it is BIND(C)"
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr "Tipe deklarasi '%s' di %L bukan C interoperable tetapi ini adalah BIND(C)"
 
-#: fortran/decl.c:5543
+#: fortran/decl.c:5562
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L may not be a C interoperable kind but it is bind(c)"
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr "Variabel '%s' di %L mungkin bukan sebuah jenis C interoperable tetapi ini adalah bind(c)"
 
-#: fortran/decl.c:5555
+#: fortran/decl.c:5574
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' in common block '%s' at %L cannot be declared with BIND(C) since it is not a global"
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr "Variabel '%s' dalam blok umum '%s' di %L tidak dapat dideklarasikan dengan BIND(C)karena ini bukan sebuah global"
 
-#: fortran/decl.c:5569
+#: fortran/decl.c:5588
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr "Variabel '%s' di %L tidak dapat memiliki dua atribut PENUNJUK dan BIND(C)"
 
-#: fortran/decl.c:5577
+#: fortran/decl.c:5596
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr "Variabel '%s' di %L tidak dapat memiliki dua atribut DAPAT DIALOKASIKAN dan BIND(C)"
 
-#: fortran/decl.c:5589
+#: fortran/decl.c:5608
 #, fuzzy, gcc-internal-format
 #| msgid "Return type of BIND(C) function '%s' at %L cannot be an array"
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr "Tipe kembali dari fungsi BIND(C) '%s' di %L tidak dapat berupa sebuah array"
 
-#: fortran/decl.c:5597
+#: fortran/decl.c:5616
 #, fuzzy, gcc-internal-format
 #| msgid "Return type of BIND(C) function '%s' at %L cannot be a character string"
 msgid "Return type of BIND(C) function %qs at %L cannot be a character string"
@@ -59078,363 +59150,363 @@
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:5608
+#: fortran/decl.c:5627
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L is marked PRIVATE but has been given the binding label '%s'"
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr "Simbol '%s' di %L ditandai PRIVATE tetapi telah diberikan level binding '%s'"
 
-#: fortran/decl.c:5682
+#: fortran/decl.c:5701
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr "Dibutuhkan baik entiti atau nama blok umum untuk pernyataan spesifikasi atribut di %C"
 
-#: fortran/decl.c:5727
+#: fortran/decl.c:5746
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr "Hilang entiti atau nama blok umum untuk pernyataan spesifikasi atribut di %C"
 
-#: fortran/decl.c:5734
+#: fortran/decl.c:5753
 #, fuzzy, gcc-internal-format
 #| msgid "missing number"
 msgid "Missing symbol"
 msgstr "hilang angka"
 
-#: fortran/decl.c:5763
+#: fortran/decl.c:5782
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "BIND(C) statement at %C"
 msgstr "Pernyataan IMPLISIT kosong di %C"
 
-#: fortran/decl.c:5850
+#: fortran/decl.c:5869
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr "Tipe turunan di %C belum pernah didefinisikan sebelumnya jadi tidak dapat muncul dalam sebuah tipe definisi turunan"
 
-#: fortran/decl.c:5892
+#: fortran/decl.c:5911
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in data declaration at %C"
 msgid "Syntax error in anonymous structure declaration at %C"
 msgstr "Sintaks error dalam deklarasi data di %C"
 
-#: fortran/decl.c:5901
+#: fortran/decl.c:5920
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr "Sintaks error dalam deklarasi data di %C"
 
-#: fortran/decl.c:5951
+#: fortran/decl.c:5970
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C"
 msgstr ""
 
-#: fortran/decl.c:5996
+#: fortran/decl.c:6015
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "procedure name = %s"
 msgid "IMPURE procedure at %C"
 msgstr "nama prosedur = %s"
 
-#: fortran/decl.c:6008
+#: fortran/decl.c:6027
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr ""
 
-#: fortran/decl.c:6054
+#: fortran/decl.c:6073
 #, gcc-internal-format, gfc-internal-format
 msgid "ELEMENTAL prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6061
+#: fortran/decl.c:6080
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6068
+#: fortran/decl.c:6087
 #, gcc-internal-format, gfc-internal-format
 msgid "RECURSIVE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6134 fortran/primary.c:1820
+#: fortran/decl.c:6153 fortran/primary.c:1820
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected alternate return label at %C"
 msgid "Alternate-return argument at %C"
 msgstr "Diduga alternatif label kembali di %C"
 
-#: fortran/decl.c:6140 fortran/decl.c:6148
+#: fortran/decl.c:6159 fortran/decl.c:6167
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unused parameter '%s' declared at %L"
 msgid "A parameter name is required at %C"
 msgstr "Parameter '%s' tidak digunakan dideklarasikan di %L"
 
-#: fortran/decl.c:6188
+#: fortran/decl.c:6207
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is the name of the procedure"
 msgid "Name %qs at %C is the name of the procedure"
 msgstr "Nama '%s' di %C adalah nama dari prosedur"
 
-#: fortran/decl.c:6201
+#: fortran/decl.c:6220
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected another dimension in array declaration at %C"
 msgid "Expected parameter list in type declaration at %C"
 msgstr "Diduga dimensi lain dalam deklarasi array di %C"
 
-#: fortran/decl.c:6204
+#: fortran/decl.c:6223
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr "Tidak teduga sampah dalam daftar argumen formal di %C"
 
-#: fortran/decl.c:6222
+#: fortran/decl.c:6241
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate symbol '%s' in formal argument list at %C"
 msgid "Duplicate name %qs in parameter list at %C"
 msgstr "Duplikasi simbol '%s dalam daftar argumen formal di %C"
 
-#: fortran/decl.c:6225
+#: fortran/decl.c:6244
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate symbol '%s' in formal argument list at %C"
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr "Duplikasi simbol '%s dalam daftar argumen formal di %C"
 
-#: fortran/decl.c:6264
+#: fortran/decl.c:6283
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in MODULE PROCEDURE formal argument names (%s/%s) at %C"
 msgstr ""
 
-#: fortran/decl.c:6270
+#: fortran/decl.c:6289
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in number of MODULE PROCEDURE formal arguments at %C"
 msgstr ""
 
-#: fortran/decl.c:6309
+#: fortran/decl.c:6328
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr "variabel RESULT di %C harus berbeda dari nama fungsi"
 
-#: fortran/decl.c:6386
+#: fortran/decl.c:6405
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr "Tidak terduga sampah setelah deklarasi fungsi di %C"
 
-#: fortran/decl.c:6396 fortran/decl.c:7494
+#: fortran/decl.c:6415 fortran/decl.c:7513
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: BIND(C) attribute at %L may not be specified for an internal procedure"
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr "Fortran 2008: BIND(C) atribut di %L mungkin tidak dispesifikasikan untuk sebuah prosedur internal"
 
-#: fortran/decl.c:6600
+#: fortran/decl.c:6619
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr "atribut BIND(C) di %C membutuhkan sebuah antar-muka dengan BIND(C)"
 
-#: fortran/decl.c:6607
+#: fortran/decl.c:6626
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr "prosedur BIND(C) dengan NAMA mungkin tidak memiliki atribut PENUNJUK di %C"
 
-#: fortran/decl.c:6613
+#: fortran/decl.c:6632
 #, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr "Prosedur dummy di %C mungkin tidak memiliki atribut BIND(C) dengan NAMA"
 
-#: fortran/decl.c:6636
+#: fortran/decl.c:6655
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type name '%s' at %C already has a basic type of %s"
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr "Nama tipe turunan '%s' di %C telah memiliki sebuah tipe dasar dari %s"
 
-#: fortran/decl.c:6682 fortran/decl.c:6870 fortran/decl.c:10723
+#: fortran/decl.c:6701 fortran/decl.c:6889 fortran/decl.c:10748
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr "Sintaks error dalam pernyataan PROSEDUR di %C"
 
-#: fortran/decl.c:6731 fortran/decl.c:10623
+#: fortran/decl.c:6750 fortran/decl.c:10648
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '::' after binding-attributes at %C"
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr "Diduga '::' setelah atribut binding di %C"
 
-#: fortran/decl.c:6738
+#: fortran/decl.c:6757
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr ""
 
-#: fortran/decl.c:6742
+#: fortran/decl.c:6761
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid procedure pointer assignment at %L"
 msgid "Procedure pointer component at %C"
 msgstr "Penempatan penunjuk prosedur tidak valid di %L"
 
-#: fortran/decl.c:6814
+#: fortran/decl.c:6833
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in structure constructor at %C"
 msgid "Syntax error in procedure pointer component at %C"
 msgstr "Sintaks error dalam struktur konstruktor di %C"
 
-#: fortran/decl.c:6832
+#: fortran/decl.c:6851
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr "PROSEDUR di %C harus berupa sebuah antar-muka umum"
 
-#: fortran/decl.c:6841 fortran/decl.c:9392
+#: fortran/decl.c:6860 fortran/decl.c:9411
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in PROCEDURE statement at %C"
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr "Sintaks error dalam pernyataan PROSEDUR di %C"
 
-#: fortran/decl.c:6911
+#: fortran/decl.c:6930
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: PROCEDURE statement at %C"
 msgid "PROCEDURE statement at %C"
 msgstr "Fortran 2003: pernyataan PROSEDUR di %C"
 
-#: fortran/decl.c:6983
+#: fortran/decl.c:7002
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr "Diduga daftar argumen formal dalam definisi fungsi di %C"
 
-#: fortran/decl.c:7007 fortran/decl.c:7011 fortran/decl.c:7266
-#: fortran/decl.c:7270 fortran/decl.c:7462 fortran/decl.c:7466
-#: fortran/symbol.c:1875
+#: fortran/decl.c:7026 fortran/decl.c:7030 fortran/decl.c:7285
+#: fortran/decl.c:7289 fortran/decl.c:7481 fortran/decl.c:7485
+#: fortran/symbol.c:1889
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr "atribut BIND(C) di %L hanya dapat digunakan untuk variabel atau blok umum"
 
-#: fortran/decl.c:7164
+#: fortran/decl.c:7183
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "ENTRY statement at %C"
 msgstr "Pernyataan IMPLISIT kosong di %C"
 
-#: fortran/decl.c:7173
+#: fortran/decl.c:7192
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr "pernyataan MASUKAN di %C tidak dapat muncul dalam sebuah APLIKASI"
 
-#: fortran/decl.c:7176
+#: fortran/decl.c:7195
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr "pernyataan MASUKAN di %C tidak dapat muncul dalam sebuah MODUL"
 
-#: fortran/decl.c:7179
+#: fortran/decl.c:7198
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgid "ENTRY statement at %C cannot appear within a SUBMODULE"
 msgstr "pernyataan MASUKAN di %C tidak dapat muncul dalam sebuah MODUL"
 
-#: fortran/decl.c:7182
+#: fortran/decl.c:7201
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr "pernyataan MASUKAN di %C tidak dapat muncul didalam sebuah DATA BLOK"
 
-#: fortran/decl.c:7186 fortran/decl.c:7231
+#: fortran/decl.c:7205 fortran/decl.c:7250
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr "pernyataan MASUKAN di %C tidak dapat muncul dalam sebuah ANTAR-MUKA"
 
-#: fortran/decl.c:7190
+#: fortran/decl.c:7209
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgid "ENTRY statement at %C cannot appear within a STRUCTURE block"
 msgstr "pernyataan MASUKAN di %C tidak dapat muncul didalam sebuah blok SELECT"
 
-#: fortran/decl.c:7194
+#: fortran/decl.c:7213
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr "pernyataan MASUKAN di %C tidak dapat muncul didalam sebuah blok TIPE TURUNAN"
 
-#: fortran/decl.c:7198
+#: fortran/decl.c:7217
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr "pernyataan MASUKAN di %C tidak dapat muncul didalam sebuah blok IF-THEN"
 
-#: fortran/decl.c:7203
+#: fortran/decl.c:7222
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr "pernnyataan MASUKAN di %C tidak dapat muncul didalam sebuah blok DO"
 
-#: fortran/decl.c:7207
+#: fortran/decl.c:7226
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr "pernyataan MASUKAN di %C tidak dapat muncul didalam sebuah blok SELECT"
 
-#: fortran/decl.c:7211
+#: fortran/decl.c:7230
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr "pernyataan MASUKAN di %C tidak dapat muncul didalam sebuah blok FORALL"
 
-#: fortran/decl.c:7215
+#: fortran/decl.c:7234
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr "pernyataan MASUKAN di %C tidak dapat muncul didalam sebuah blok WHERE"
 
-#: fortran/decl.c:7219
+#: fortran/decl.c:7238
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr "pernyataan MASUKAN di %C tidak dapat muncul didalam sebuah subprogram terkontain"
 
-#: fortran/decl.c:7223
+#: fortran/decl.c:7242
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected END statement at %C"
 msgid "Unexpected ENTRY statement at %C"
 msgstr "Tidak terduga pernyataan END di %C"
 
-#: fortran/decl.c:7244
+#: fortran/decl.c:7263
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr "pernyataan MASUKAN di %C tidak dapat muncul dalam sebuah prosedur terkontain"
 
-#: fortran/decl.c:7295 fortran/decl.c:7501
+#: fortran/decl.c:7314 fortran/decl.c:7520
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr "Hilang parantheses yang dibutuhkan sebelum BIND(C) di %C"
 
-#: fortran/decl.c:7563 fortran/decl.c:7570
+#: fortran/decl.c:7582 fortran/decl.c:7589
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid C name in NAME= specifier at %C"
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr "Nama C tidak valid dalam penspesifikasi NAMA= di %C"
 
-#: fortran/decl.c:7610
+#: fortran/decl.c:7629
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr "Sintaks error dalam penspesifikasi NAMA= untuk binding label di %C"
 
-#: fortran/decl.c:7626
+#: fortran/decl.c:7645
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASYNCHRONOUS= specifier at %L must be an initialization expression"
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr "ASYNCHRONOUS= penspesifikasi di %L harus berupa ekspresi inisialisasi"
 
-#: fortran/decl.c:7634
+#: fortran/decl.c:7653
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr ""
 
-#: fortran/decl.c:7653
+#: fortran/decl.c:7672
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing closing paren for binding label at %C"
 msgstr "Hilang penutup paren untuk binding label di %C"
 
-#: fortran/decl.c:7659
+#: fortran/decl.c:7678
 #, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr "Tidak ada nama binding diijinkan dalam BIND(C) di %C"
 
-#: fortran/decl.c:7665
+#: fortran/decl.c:7684
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr "Untuk prosedur dummy %s, tidak ada nama binding diijinkan dalam BIND(C) di %C"
 
-#: fortran/decl.c:7694
+#: fortran/decl.c:7713
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr "NAMA tidak diijinkan dalam BIND(C) untuk ANTAR-MUKA ABSTRAK di %C"
 
-#: fortran/decl.c:7939
+#: fortran/decl.c:7958
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr "Tidak terduga pernyataan END di %C"
 
-#: fortran/decl.c:7948
+#: fortran/decl.c:7967
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement at %C cannot follow %s statement at %L"
 msgid "END statement instead of %s statement at %L"
@@ -59441,670 +59513,676 @@
 msgstr "pernyataan %s di %C tidak dapat mengikuti pernyataan %s di %L"
 
 #. We would have required END [something].
-#: fortran/decl.c:7957
+#: fortran/decl.c:7976
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr "pernyataan %s tidak terduga di %L"
 
-#: fortran/decl.c:7968
+#: fortran/decl.c:7987
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting %s statement at %C"
 msgid "Expecting %s statement at %L"
 msgstr "Diduga pernyataan %s di %C"
 
-#: fortran/decl.c:7988
+#: fortran/decl.c:8007
 #, fuzzy, gcc-internal-format
 #| msgid "Expected block name of '%s' in %s statement at %C"
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr "Diduga nama blok dari '%s' dalam pernyataan %s di %C"
 
-#: fortran/decl.c:8005
+#: fortran/decl.c:8024
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr "Diduga nama berakhir di %C"
 
-#: fortran/decl.c:8019 fortran/decl.c:8027
+#: fortran/decl.c:8038 fortran/decl.c:8046
 #, fuzzy, gcc-internal-format
 #| msgid "Expected label '%s' for %s statement at %C"
 msgid "Expected label %qs for %s statement at %C"
 msgstr "Diduga label '%s' untuk pernyataan %s di %C"
 
-#: fortran/decl.c:8126
+#: fortran/decl.c:8145
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr "Hilang spesifikasi array di %L dalam pernyataan DIMENSI"
 
-#: fortran/decl.c:8134
+#: fortran/decl.c:8153
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Dimensions specified for %s at %L after its initialisation"
 msgid "Dimensions specified for %s at %L after its initialization"
 msgstr "Dimensi dipesifikasikan untuk %s di %L setelah inisialisasinya"
 
-#: fortran/decl.c:8142
+#: fortran/decl.c:8161
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing array specification at %L in DIMENSION statement"
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr "Hilang spesifikasi array di %L dalam pernyataan DIMENSI"
 
-#: fortran/decl.c:8151
+#: fortran/decl.c:8170
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr "Spesifikasi array harus deferred di %L"
 
-#: fortran/decl.c:8249
+#: fortran/decl.c:8268
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr "Karakter tidak terduda dalam daftar variabel di %C"
 
-#: fortran/decl.c:8286
+#: fortran/decl.c:8305
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "Expected %<(%> at %C"
 msgstr "Diduga '(' di %C"
 
-#: fortran/decl.c:8300 fortran/decl.c:8340
+#: fortran/decl.c:8319 fortran/decl.c:8359
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr "Diduga nama variabel di %C"
 
-#: fortran/decl.c:8316
+#: fortran/decl.c:8335
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C must be an integer"
 msgstr "Penunjuk Cray di %C harus berupa sebuah integer"
 
-#: fortran/decl.c:8320
+#: fortran/decl.c:8339
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr "Penunjuk Cray di %C memiliki %d bytes ketelitian; alamat memori membutuhkan %d bytes"
 
-#: fortran/decl.c:8326
+#: fortran/decl.c:8345
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr "Diduga \",\" di %C"
 
-#: fortran/decl.c:8365
+#: fortran/decl.c:8384
 #, gcc-internal-format
 msgid "Couldn't set Cray pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:8389
+#: fortran/decl.c:8408
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr "Diduga \")\" di %C"
 
-#: fortran/decl.c:8401
+#: fortran/decl.c:8420
 #, fuzzy, gcc-internal-format
 #| msgid "Expected \",\" or end of statement at %C"
 msgid "Expected %<,%> or end of statement at %C"
 msgstr "Diduga \",\" atau akhir dari pernyataan di %C"
 
-#: fortran/decl.c:8427
+#: fortran/decl.c:8446
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:8459
+#: fortran/decl.c:8478
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:8478
+#: fortran/decl.c:8497
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer declaration at %C requires -fcray-pointer flag"
 msgstr "Deklarasi penunjuk cray di %C membutuhkan pilihan -fcray-pointer"
 
-#: fortran/decl.c:8517
+#: fortran/decl.c:8536
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Empty IMPLICIT statement at %C"
 msgid "CONTIGUOUS statement at %C"
 msgstr "Pernyataan IMPLISIT kosong di %C"
 
-#: fortran/decl.c:8623
+#: fortran/decl.c:8642
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr "Spesifikasi akses dari operator %s di %C telah dispesifikasikan"
 
-#: fortran/decl.c:8640
+#: fortran/decl.c:8659
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr "Spesifikasi akses dari operator .%s.  di %C telah dispesifikasikan"
 
-#: fortran/decl.c:8679
+#: fortran/decl.c:8698
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: PROTECTED statement at %C"
 msgid "PROTECTED statement at %C"
 msgstr "Fortran 2003: pernyataan TERPROTEKSI di %C"
 
-#: fortran/decl.c:8717
+#: fortran/decl.c:8736
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr "Sintaks error dalam pernyataan TERPROTEKSI di %C"
 
-#: fortran/decl.c:8741
+#: fortran/decl.c:8760
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr "pernyataan PRIVATE di %C hanya diperbolehkan dalam bagian spesifikasi dari sebuah modul"
 
-#: fortran/decl.c:8778
+#: fortran/decl.c:8797
 #, gcc-internal-format, gfc-internal-format
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr "pernyataan PUBLIK di %C hanya diperbolehkan dalam bagian spesifikasi dari sebuah modul"
 
-#: fortran/decl.c:8806
+#: fortran/decl.c:8825
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr "Nama variabel diduga di %C dalam pernyataan PARAMETER"
 
-#: fortran/decl.c:8813
+#: fortran/decl.c:8832
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr "Diduga tanda = dalam pernyataan PARAMETER di %C"
 
-#: fortran/decl.c:8819
+#: fortran/decl.c:8838
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr "Diduga ekspresi di %C dalam pernyataan PARAMETER"
 
-#: fortran/decl.c:8839
+#: fortran/decl.c:8858
 #, gcc-internal-format, gfc-internal-format
 msgid "Initializing already initialized variable at %C"
 msgstr "Inisialisasi variabel  yang telah diinisialisasi di %C"
 
 #. With legacy PARAMETER statements, don't expect a terminating ')'.
-#: fortran/decl.c:8864
+#: fortran/decl.c:8883
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER without '()' at %C"
 msgstr ""
 
-#: fortran/decl.c:8880
+#: fortran/decl.c:8899
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr "Karakter tidak terduga dalam pernyataan PARAMETER di %C"
 
-#: fortran/decl.c:8899 fortran/decl.c:8955
+#: fortran/decl.c:8918 fortran/decl.c:8974
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:8934
+#: fortran/decl.c:8953
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected variable in READ statement at %C"
 msgid "Expected entity-list in AUTOMATIC statement at %C"
 msgstr "Diduga variabel dalam pernyataan BACA di %C"
 
-#: fortran/decl.c:8941
+#: fortran/decl.c:8960
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in VOLATILE statement at %C"
 msgid "Syntax error in AUTOMATIC statement at %C"
 msgstr "Sintaks error dalam pernyataan VOLATILE di %C"
 
-#: fortran/decl.c:8990
+#: fortran/decl.c:9009
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected variable in READ statement at %C"
 msgid "Expected entity-list in STATIC statement at %C"
 msgstr "Diduga variabel dalam pernyataan BACA di %C"
 
-#: fortran/decl.c:8997
+#: fortran/decl.c:9016
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in STATIC statement at %C"
 msgstr "Sintaks error dalam pernyataan SAVE di %C"
 
-#: fortran/decl.c:9016
+#: fortran/decl.c:9035
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr "Blanket pernyataan SAVE di %C mengikuti pernyataan SAVE sebelumnya"
 
-#: fortran/decl.c:9027
+#: fortran/decl.c:9046
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr "pernyataan SAVE di %C mengikuti blanket pernyataan SAVE"
 
-#: fortran/decl.c:9073
+#: fortran/decl.c:9092
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr "Sintaks error dalam pernyataan SAVE di %C"
 
-#: fortran/decl.c:9087
+#: fortran/decl.c:9106
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:9091
+#: fortran/decl.c:9110
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: VALUE statement at %C"
 msgid "VALUE statement at %C"
 msgstr "Fortran 2003: pernyataan NILAI di %C"
 
-#: fortran/decl.c:9129
+#: fortran/decl.c:9148
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VALUE statement at %C"
 msgstr "Sintaks error dalam pernyataan NILAI di %C"
 
-#: fortran/decl.c:9141
+#: fortran/decl.c:9160
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: VOLATILE statement at %C"
 msgid "VOLATILE statement at %C"
 msgstr "Fortran 2003: pernyataan VOLATILE di %C"
 
-#: fortran/decl.c:9168
+#: fortran/decl.c:9187
 #, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr ""
 
-#: fortran/decl.c:9193
+#: fortran/decl.c:9212
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr "Sintaks error dalam pernyataan VOLATILE di %C"
 
-#: fortran/decl.c:9205
+#: fortran/decl.c:9224
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate SEQUENCE statement at %C"
 msgid "ASYNCHRONOUS statement at %C"
 msgstr "Duplikasi pernyataan SEQUENCE di %C"
 
-#: fortran/decl.c:9249
+#: fortran/decl.c:9268
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in VALUE statement at %C"
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr "Sintaks error dalam pernyataan NILAI di %C"
 
-#: fortran/decl.c:9274
+#: fortran/decl.c:9293
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Junk after PROCEDURE declaration at %C"
 msgid "MODULE PROCEDURE declaration at %C"
 msgstr "Sampah setelah deklarasi PROCEDURE di %C"
 
-#: fortran/decl.c:9367
+#: fortran/decl.c:9386
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr "PROSEDUR MODUL di %C harus dalam sebuah antar-muka modul umum"
 
-#: fortran/decl.c:9425
+#: fortran/decl.c:9444
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Intrinsic procedure '%s' not allowed in PROCEDURE statement at %C"
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr "Prosedur intrinsik '%s' tidak diperbolehkan dalam pernyataan PROSEDUR di %C"
 
-#: fortran/decl.c:9474
+#: fortran/decl.c:9493
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr "Ambigu simbol dalam definisi TIPE di %C"
 
-#: fortran/decl.c:9483
+#: fortran/decl.c:9502
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C has already been host associated"
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr "Simbol '%s' di %C telah diassosiasikan host"
 
-#: fortran/decl.c:9489
+#: fortran/decl.c:9508
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' in EXTENDS expression at %C is not a derived type"
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr "'%s' dalam ekspresi EXTENDS di %C bukan sebuah tipe turunan"
 
-#: fortran/decl.c:9496
+#: fortran/decl.c:9515
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' cannot be extended at %C because it is BIND(C)"
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr "'%s' tidak dapat diekstensikan di %C karena ini adalah BIND(C)"
 
-#: fortran/decl.c:9503
+#: fortran/decl.c:9522
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' cannot be extended at %C because it is a SEQUENCE type"
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr "'%s' tidak dapat diekstensikan di %C karena ini adalah tipe SEQUENCE"
 
-#: fortran/decl.c:9526
+#: fortran/decl.c:9545
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr "Tipe turunan di %C hanya dapat berupa PRIVATE dalam bagian spesifikasi dari sebuah modul"
 
-#: fortran/decl.c:9538
+#: fortran/decl.c:9557
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr "Tipe turunan di %C hanya dapat berupa PUBLIK dalam bagian spesifikasi dari sebuah modul"
 
-#: fortran/decl.c:9559
+#: fortran/decl.c:9578
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ABSTRACT type '%s' used at %L"
 msgid "ABSTRACT type at %C"
 msgstr "tipe ABSTRAK '%s' digunakan di %L"
 
-#: fortran/decl.c:9605
+#: fortran/decl.c:9624
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate construct label '%s' at %C"
 msgid "Failed to create structure type '%s' at %C"
 msgstr "Duplikasi konstruksi label '%s' di %C"
 
-#: fortran/decl.c:9611
+#: fortran/decl.c:9630
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type definition of '%s' at %C has already been defined"
 msgid "Type definition of %qs at %C was already defined at %L"
 msgstr "Definisi tipe turunan dari '%s' di %C telah terdefinisi"
 
-#: fortran/decl.c:9658
+#: fortran/decl.c:9677
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after ELSE statement at %C"
 msgid "Junk after MAP statement at %C"
 msgstr "Tidak terduga sampah setelah pernyataan ELSE di %C"
 
-#: fortran/decl.c:9691
+#: fortran/decl.c:9710
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after ELSE statement at %C"
 msgid "Junk after UNION statement at %C"
 msgstr "Tidak terduga sampah setelah pernyataan ELSE di %C"
 
-#: fortran/decl.c:9726
+#: fortran/decl.c:9745
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr ""
 
-#: fortran/decl.c:9740
+#: fortran/decl.c:9759
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after function declaration at %C"
 msgid "Structure name expected in non-nested structure declaration at %C"
 msgstr "Tidak terduga sampah setelah deklarasi fungsi di %C"
 
-#: fortran/decl.c:9758
+#: fortran/decl.c:9777
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected CASE statement at %C"
 msgid "Junk after non-nested STRUCTURE statement at %C"
 msgstr "Diduga pernyataan CASE di %C"
 
-#: fortran/decl.c:9765
+#: fortran/decl.c:9784
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C cannot be the same as an intrinsic type"
 msgid "Structure name %qs at %C cannot be the same as an intrinsic type"
 msgstr "Nama tipe '%s' di %C tidak dapat sama seperti sebuah tipe intrinsic"
 
-#: fortran/decl.c:9926
+#: fortran/decl.c:9947
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr "Diduga :: dalam definisi TIPE di %C"
 
-#: fortran/decl.c:9954
+#: fortran/decl.c:9975
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C cannot be the same as an intrinsic type"
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr "Nama tipe '%s' di %C tidak dapat sama seperti sebuah tipe intrinsic"
 
-#: fortran/decl.c:9964
+#: fortran/decl.c:9986
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type name '%s' at %C already has a basic type of %s"
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr "Nama tipe turunan '%s' di %C telah memiliki sebuah tipe dasar dari %s"
 
-#: fortran/decl.c:9981
+#: fortran/decl.c:9989
 #, fuzzy, gcc-internal-format
+#| msgid "Derived type name '%s' at %C already has a basic type of %s"
+msgid "Derived type name %qs at %C already has a basic type"
+msgstr "Nama tipe turunan '%s' di %C telah memiliki sebuah tipe dasar dari %s"
+
+#: fortran/decl.c:10006
+#, fuzzy, gcc-internal-format
 #| msgid "Derived type definition of '%s' at %C has already been defined"
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr "Definisi tipe turunan dari '%s' di %C telah terdefinisi"
 
-#: fortran/decl.c:10042
+#: fortran/decl.c:10067
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Junk after PROCEDURE declaration at %C"
 msgid "Garbage after PARAMETERIZED TYPE declaration at %C"
 msgstr "Sampah setelah deklarasi PROCEDURE di %C"
 
-#: fortran/decl.c:10126
+#: fortran/decl.c:10151
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr "Cray Pointee di %C tidak dapat diasumsikan bentuk array"
 
-#: fortran/decl.c:10146
+#: fortran/decl.c:10171
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ENUM and ENUMERATOR at %C"
 msgid "ENUM and ENUMERATOR at %C"
 msgstr "Fortran 2003: ENUM dan ENUMERATOR di %C"
 
-#: fortran/decl.c:10178
+#: fortran/decl.c:10203
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr "Enumerator melebihi tipe integer C di %C"
 
-#: fortran/decl.c:10257
+#: fortran/decl.c:10282
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr "ENUMERATOR %L tidak diinisialisasi dengan ekspresi integer"
 
-#: fortran/decl.c:10305
+#: fortran/decl.c:10330
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr "pernyataan definisi ENUM diduga sebelum %C"
 
-#: fortran/decl.c:10341
+#: fortran/decl.c:10366
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr "Sintaks error dalam definisi ENUMERATOR di %C"
 
-#: fortran/decl.c:10388 fortran/decl.c:10403
+#: fortran/decl.c:10413 fortran/decl.c:10428
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate access-specifier at %C"
 msgstr "Duplikasi penspesifikasi akses di %C"
 
-#: fortran/decl.c:10423
+#: fortran/decl.c:10448
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr "Binding atribut telah menspesifikasikan passing, tidak legal NOPASS di %C"
 
-#: fortran/decl.c:10443
+#: fortran/decl.c:10468
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr "Binding atribut telah menspesifikasikan passing, tidak legal PASS di %C"
 
-#: fortran/decl.c:10470
+#: fortran/decl.c:10495
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate %s attribute at %L"
 msgid "Duplicate POINTER attribute at %C"
 msgstr "Duplikasi %s atribut di %L"
 
-#: fortran/decl.c:10488
+#: fortran/decl.c:10513
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr "Duplikasi NON_OVERRIDABLE di %C"
 
-#: fortran/decl.c:10504
+#: fortran/decl.c:10529
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate NON_OVERRIDABLE at %C"
 msgid "Duplicate DEFERRED at %C"
 msgstr "Duplikasi NON_OVERRIDABLE di %C"
 
-#: fortran/decl.c:10517
+#: fortran/decl.c:10542
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected access-specifier at %C"
 msgstr "Diduga penspesifikasi akses di %C"
 
-#: fortran/decl.c:10519
+#: fortran/decl.c:10544
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr "Diduga atribut binding di %C"
 
-#: fortran/decl.c:10527
+#: fortran/decl.c:10552
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED can't both appear at %C"
 msgstr ""
 
-#: fortran/decl.c:10539
+#: fortran/decl.c:10564
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:10581
+#: fortran/decl.c:10606
 #, gcc-internal-format
 msgid "Interface-name expected after %<(%> at %C"
 msgstr ""
 
-#: fortran/decl.c:10587
+#: fortran/decl.c:10612
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "%<)%> expected at %C"
 msgstr "Diduga '(' di %C"
 
-#: fortran/decl.c:10607
+#: fortran/decl.c:10632
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in NAME= specifier for binding label at %C"
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr "Sintaks error dalam penspesifikasi NAMA= untuk binding label di %C"
 
-#: fortran/decl.c:10612
+#: fortran/decl.c:10637
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PROCEDURE(interface) at %C is not yet implemented"
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr "PROCEDUR(antar-muka) di %C belum diimplementasikan"
 
-#: fortran/decl.c:10635
+#: fortran/decl.c:10660
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr "Diduga nama binding di %C"
 
-#: fortran/decl.c:10639
+#: fortran/decl.c:10664
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Junk after PROCEDURE declaration at %C"
 msgid "PROCEDURE list at %C"
 msgstr "Sampah setelah deklarasi PROCEDURE di %C"
 
-#: fortran/decl.c:10651
+#: fortran/decl.c:10676
 #, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:10657
+#: fortran/decl.c:10682
 #, fuzzy, gcc-internal-format
 #| msgid "'::' needed in PROCEDURE binding with explicit target at %C"
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr "'::' diperlukan dalam binding PROCEDUR dengan target eksplisit di %C"
 
-#: fortran/decl.c:10667
+#: fortran/decl.c:10692
 #, fuzzy, gcc-internal-format
 #| msgid "Expected binding target after '=>' at %C"
 msgid "Expected binding target after %<=>%> at %C"
 msgstr "Diduga binding target setelah '=>' di %C"
 
-#: fortran/decl.c:10684
+#: fortran/decl.c:10709
 #, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr ""
 
-#: fortran/decl.c:10695
+#: fortran/decl.c:10720
 #, fuzzy, gcc-internal-format
 #| msgid "There's already a procedure with binding name '%s' for the derived type '%s' at %C"
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr "Telah ada sebuah prosedur dengan nama binding '%s' untuk tipe turunan '%s' di %C"
 
-#: fortran/decl.c:10746
+#: fortran/decl.c:10771
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr "GENERIC di %C harus berada didalam sebuah tipe turunan CONTAINS"
 
-#: fortran/decl.c:10766
+#: fortran/decl.c:10791
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '::' at %C"
 msgid "Expected %<::%> at %C"
 msgstr "Diduga '::' di %C"
 
-#: fortran/decl.c:10778
+#: fortran/decl.c:10803
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected generic name at %C"
 msgid "Expected generic name or operator descriptor at %C"
 msgstr "Diduga nama generik di %C"
 
-#: fortran/decl.c:10799
+#: fortran/decl.c:10824
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid form of PROGRAM statement at %C"
 msgid "Malformed GENERIC statement at %C"
 msgstr "Form tidak valid dari pernyataan APLIKASI di %C"
 
-#: fortran/decl.c:10810
+#: fortran/decl.c:10835
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "Expected %<=>%> at %C"
 msgstr "Diduga '(' di %C"
 
-#: fortran/decl.c:10846
+#: fortran/decl.c:10871
 #, fuzzy, gcc-internal-format
 #| msgid "There's already a non-generic procedure with binding name '%s' for the derived type '%s' at %C"
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr "Telah ada sebuah prosedur bukan generik dengan nama binding '%s' untuk tipe turunan '%s' di %C"
 
-#: fortran/decl.c:10854
+#: fortran/decl.c:10879
 #, fuzzy, gcc-internal-format
 #| msgid "Binding at %C must have the same access as already defined binding '%s'"
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr "Binding di %C harus memiliki akses sama seperti telah didefinisikan binding '%s'"
 
-#: fortran/decl.c:10902
+#: fortran/decl.c:10927
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr "Diduga nama binding spesifik di %C"
 
-#: fortran/decl.c:10912
+#: fortran/decl.c:10937
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' already defined as specific binding for the generic '%s' at %C"
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr "'%s' telah didefinisikan sebagai binding spesifik untuk generik '%s' di %C"
 
-#: fortran/decl.c:10930
+#: fortran/decl.c:10955
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr "Sampah setelah binding GENERIC di %C"
 
-#: fortran/decl.c:10965
+#: fortran/decl.c:10990
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr "deklarasi FINAL di %C harus berada didalam sebuah tipe turunan daerah CONTAINS"
 
-#: fortran/decl.c:10976
+#: fortran/decl.c:11001
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr "Deklarasi tipe turunan dengan FINAL di %C harus berada dalam spesifikasi dari sebuah MODULE"
 
-#: fortran/decl.c:10998
+#: fortran/decl.c:11023
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr "Kosong FINAL di %C"
 
-#: fortran/decl.c:11005
+#: fortran/decl.c:11030
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr "Diduga nama prosedur modul di %C"
 
-#: fortran/decl.c:11015
+#: fortran/decl.c:11040
 #, fuzzy, gcc-internal-format
 #| msgid "Expected \",\" at %C"
 msgid "Expected %<,%> at %C"
 msgstr "Diduga \",\" di %C"
 
-#: fortran/decl.c:11021
+#: fortran/decl.c:11046
 #, fuzzy, gcc-internal-format
 #| msgid "Unknown procedure name \"%s\" at %C"
 msgid "Unknown procedure name %qs at %C"
 msgstr "Nama prosedur tidak dikenal \"%s\" di %C"
 
-#: fortran/decl.c:11034
+#: fortran/decl.c:11059
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is already defined as FINAL procedure!"
 msgid "%qs at %C is already defined as FINAL procedure"
 msgstr "'%s' di %C telah didefinisikan sebagai prosedur FINAL!"
 
-#: fortran/decl.c:11104
+#: fortran/decl.c:11129
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected characters in PARAMETER statement at %C"
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr "Karakter tidak terduga dalam pernyataan PARAMETER di %C"
 
-#: fortran/decl.c:11150
+#: fortran/decl.c:11175
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in VALUE statement at %C"
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr "Sintaks error dalam pernyataan NILAI di %C"
 
-#: fortran/decl.c:11170
+#: fortran/decl.c:11195
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive requires a non-negative integral constant less than or equal to %u at %C"
 msgstr ""
 
-#: fortran/decl.c:11184
+#: fortran/decl.c:11209
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in FORALL iterator at %C"
 msgid "Syntax error in !GCC$ UNROLL directive at %C"
@@ -60470,31 +60548,31 @@
 msgid "BOZ literal at %L used to initialize non-integer variable %qs"
 msgstr "Ekstensi: BOZ literal di %L digunakan untuk menginisialisasi variabel bukan-integer '%s'"
 
-#: fortran/expr.c:3369 fortran/resolve.c:10197
+#: fortran/expr.c:3369 fortran/resolve.c:10210
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: BOZ literal at %L outside a DATA statement and outside INT/REAL/DBLE/CMPLX"
 msgid "BOZ literal at %L outside a DATA statement and outside INT/REAL/DBLE/CMPLX"
 msgstr "Ekstensi: BOZ literal di %L diluar sebuah pernyataan DATA dan diluar INT/REAL/DBLE/CMPLX"
 
-#: fortran/expr.c:3380 fortran/resolve.c:10208
+#: fortran/expr.c:3380 fortran/resolve.c:10221
 #, fuzzy, gcc-internal-format
 #| msgid "BOZ literal at %L is bitwise transferred non-integer symbol '%s'"
 msgid "BOZ literal at %L is bitwise transferred non-integer symbol %qs"
 msgstr "BOZ literal di %L adalah bitwise dapat ditransfer bukan-integer simbol '%s'"
 
-#: fortran/expr.c:3388 fortran/resolve.c:10217
+#: fortran/expr.c:3388 fortran/resolve.c:10230
 #, fuzzy, gcc-internal-format
 #| msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option -fno-range-check"
 msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "Aritmetik underflow dari bit-wise dipindahkan BOZ di %L. Pemeriksaan ini dapat dinon-aktifkan dengan pilihan -fno-range-check"
 
-#: fortran/expr.c:3392 fortran/resolve.c:10221
+#: fortran/expr.c:3392 fortran/resolve.c:10234
 #, fuzzy, gcc-internal-format
 #| msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option -fno-range-check"
 msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "Aritmetik overflow dari bit-wise dipindahkan BOZ di %L. Pemeriksaan ini dapat dinonaktifkan dengan pilihan -fno-range-check"
 
-#: fortran/expr.c:3396 fortran/resolve.c:10225
+#: fortran/expr.c:3396 fortran/resolve.c:10238
 #, fuzzy, gcc-internal-format
 #| msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option -fno-range-check"
 msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
@@ -60505,162 +60583,162 @@
 msgid "The assignment to a KIND or LEN component of a parameterized type at %L is not allowed"
 msgstr ""
 
-#: fortran/expr.c:3426
+#: fortran/expr.c:3429
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible types in DATA statement at %L; attempted conversion of %s to %s"
 msgstr "Tipe tidak kompatibel dalam pernyataan DATA di %L; dicoba mengubah %s ke %s"
 
-#: fortran/expr.c:3465
+#: fortran/expr.c:3468
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is not a POINTER at %L"
 msgstr "Penempatan target penunjuk bukan sebuah PENUNJUK di %L"
 
-#: fortran/expr.c:3473
+#: fortran/expr.c:3476
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgid "%qs in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgstr "'%s' dalam penempatan penunjuk di %L tidak dapat berupa sebuah nilai-kiri karena iniadalah sebuah prosedur"
 
-#: fortran/expr.c:3496
+#: fortran/expr.c:3499
 #, fuzzy, gcc-internal-format
 #| msgid "Expected bounds specification for '%s' at %L"
 msgid "Expected bounds specification for %qs at %L"
 msgstr "Diduga spesifikasi terikat untuk '%s' di %L"
 
-#: fortran/expr.c:3501
+#: fortran/expr.c:3504
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: Bounds specification for '%s' in pointer assignment at %L"
 msgid "Bounds specification for %qs in pointer assignment at %L"
 msgstr "Fortran 2003: Spesifikasi terikat untuk '%s' dalam penempatan penunjuk di %L"
 
-#: fortran/expr.c:3514
+#: fortran/expr.c:3517
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower bound has to be present at %L"
 msgstr ""
 
-#: fortran/expr.c:3520
+#: fortran/expr.c:3523
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "stack size must not be greater than 64k"
 msgid "Stride must not be present at %L"
 msgstr "ukuran stack harus lebih besar  dari 64k"
 
-#: fortran/expr.c:3532
+#: fortran/expr.c:3535
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the upper bounds must be specified at %L"
 msgstr ""
 
-#: fortran/expr.c:3558
+#: fortran/expr.c:3561
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "External object '%s' at %L may not have an initializer"
 msgid "Pointer object at %L shall not have a coindex"
 msgstr "Objek eksternal '%s' di %L tidak boleh memiliki sebuah penginisialisasi"
 
-#: fortran/expr.c:3579
+#: fortran/expr.c:3582
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure pointer assignment at %L"
 msgstr "Penempatan penunjuk prosedur tidak valid di %L"
 
-#: fortran/expr.c:3603
+#: fortran/expr.c:3606
 #, fuzzy, gcc-internal-format
 #| msgid "Abstract interface '%s' is invalid in procedure pointer assignment at %L"
 msgid "Function result %qs is invalid as proc-target in procedure pointer assignment at %L"
 msgstr "Antarmuka abstrak '%s' tidak valid dalam penempatan penunjuk prosedur di %L"
 
-#: fortran/expr.c:3612
+#: fortran/expr.c:3615
 #, fuzzy, gcc-internal-format
 #| msgid "Abstract interface '%s' is invalid in procedure pointer assignment at %L"
 msgid "Abstract interface %qs is invalid in procedure pointer assignment at %L"
 msgstr "Antarmuka abstrak '%s' tidak valid dalam penempatan penunjuk prosedur di %L"
 
-#: fortran/expr.c:3622
+#: fortran/expr.c:3625
 #, fuzzy, gcc-internal-format
 #| msgid "Abstract interface '%s' is invalid in procedure pointer assignment at %L"
 msgid "Statement function %qs is invalid in procedure pointer assignment at %L"
 msgstr "Antarmuka abstrak '%s' tidak valid dalam penempatan penunjuk prosedur di %L"
 
-#: fortran/expr.c:3628
+#: fortran/expr.c:3631
 #, fuzzy, gcc-internal-format
 #| msgid "Abstract interface '%s' is invalid in procedure pointer assignment at %L"
 msgid "Internal procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "Antarmuka abstrak '%s' tidak valid dalam penempatan penunjuk prosedur di %L"
 
-#: fortran/expr.c:3635
+#: fortran/expr.c:3638
 #, fuzzy, gcc-internal-format
 #| msgid "Abstract interface '%s' is invalid in procedure pointer assignment at %L"
 msgid "Intrinsic %qs at %L is invalid in procedure pointer assignment"
 msgstr "Antarmuka abstrak '%s' tidak valid dalam penempatan penunjuk prosedur di %L"
 
-#: fortran/expr.c:3643
+#: fortran/expr.c:3646
 #, fuzzy, gcc-internal-format
 #| msgid "Abstract interface '%s' is invalid in procedure pointer assignment at %L"
 msgid "Nonintrinsic elemental procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "Antarmuka abstrak '%s' tidak valid dalam penempatan penunjuk prosedur di %L"
 
-#: fortran/expr.c:3666
+#: fortran/expr.c:3669
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in the procedure pointer assignment at %L: mismatch in the calling convention"
 msgstr ""
 
-#: fortran/expr.c:3719
+#: fortran/expr.c:3722
 #, fuzzy, gcc-internal-format
 #| msgid "Abstract interface '%s' is invalid in procedure pointer assignment at %L"
 msgid "Interface mismatch in procedure pointer assignment at %L: %qs is not a subroutine"
 msgstr "Antarmuka abstrak '%s' tidak valid dalam penempatan penunjuk prosedur di %L"
 
-#: fortran/expr.c:3729 fortran/expr.c:3744
+#: fortran/expr.c:3732 fortran/expr.c:3747
 #, fuzzy, gcc-internal-format
 #| msgid "Expected a procedure for argument '%s' at %L"
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr "Diduga sebuah prosedur untuk argumen '%s' di %L"
 
-#: fortran/expr.c:3735 fortran/expr.c:3750 fortran/resolve.c:2566
+#: fortran/expr.c:3738 fortran/expr.c:3753 fortran/resolve.c:2566
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate interface declaration for class %qs"
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr "duplikasi deklarasi antar-muka untuk class %qs"
 
-#: fortran/expr.c:3762
+#: fortran/expr.c:3765
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid procedure pointer assignment at %L"
 msgid "Interface mismatch in procedure pointer assignment at %L: %s"
 msgstr "Penempatan penunjuk prosedur tidak valid di %L"
 
-#: fortran/expr.c:3771
+#: fortran/expr.c:3774
 #, gcc-internal-format
 msgid "Procedure pointer target %qs at %L must be either an intrinsic, host or use associated, referenced or have the EXTERNAL attribute"
 msgstr ""
 
-#: fortran/expr.c:3788
+#: fortran/expr.c:3791
 #, gcc-internal-format, gfc-internal-format
 msgid "Data-pointer-object at %L must be unlimited polymorphic, or of a type with the BIND or SEQUENCE attribute, to be compatible with an unlimited polymorphic target"
 msgstr ""
 
-#: fortran/expr.c:3793
+#: fortran/expr.c:3796
 #, gcc-internal-format, gfc-internal-format
 msgid "Different types in pointer assignment at %L; attempted assignment of %s to %s"
 msgstr "Tipe berbeda dalam penempatan penunjuk di %L; mencoba penempatan dari %s ke %s"
 
-#: fortran/expr.c:3802
+#: fortran/expr.c:3805
 #, gcc-internal-format, gfc-internal-format
 msgid "Different kind type parameters in pointer assignment at %L"
 msgstr "Jenis parameter berbeda dalam penempatan penunjuk di %L"
 
-#: fortran/expr.c:3809
+#: fortran/expr.c:3812
 #, gcc-internal-format, gfc-internal-format
 msgid "Different ranks in pointer assignment at %L"
 msgstr "Tingkat berbeda dalam penempatan penunjuk di %L"
 
-#: fortran/expr.c:3828
+#: fortran/expr.c:3831
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is smaller than size of the pointer (%ld < %ld) at %L"
 msgstr ""
 
-#: fortran/expr.c:3841
+#: fortran/expr.c:3844
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target must be rank 1 or simply contiguous at %L"
 msgstr ""
 
-#: fortran/expr.c:3845
+#: fortran/expr.c:3848
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Pointer assignment target is not a POINTER at %L"
 msgid "Rank remapping target is not rank 1 at %L"
@@ -60669,156 +60747,161 @@
 #. The test above might need to be extend when F08, Note 5.4 has to be
 #. interpreted in the way that target and pointer with the same coindex
 #. are allowed.
-#: fortran/expr.c:3877 fortran/expr.c:3925
+#: fortran/expr.c:3880 fortran/expr.c:3928
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components"
 msgid "Data target at %L shall not have a coindex"
 msgstr "Elemen pemindahan data di %L tidak dapat memiliki komponen PENUNJUK"
 
-#: fortran/expr.c:3880
+#: fortran/expr.c:3883
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr "Pemilihan ekspresi dalam pernyataan GOTO yang terhitung di %L harus berupa sebuah ekspresi integer skalar"
 
-#: fortran/expr.c:3888
+#: fortran/expr.c:3891
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr "Target penempatan penunjun baik bukan TARGET ataupun PENUNJUN di %L"
 
-#: fortran/expr.c:3895
+#: fortran/expr.c:3898
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr "Target buruk dalam penempatan penunjuk dalam prosedur PURE di %L"
 
-#: fortran/expr.c:3904
+#: fortran/expr.c:3907
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr "Penempatan penunjuk dengan subscrip vektori di rhs di %L"
 
-#: fortran/expr.c:3912
+#: fortran/expr.c:3915
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr "Target penempatan penunjuk memiliki atribut PROTECTED di %L"
 
-#: fortran/expr.c:3936
+#: fortran/expr.c:3939
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to contiguous pointer from non-contiguous target at %L"
 msgstr ""
 
-#: fortran/expr.c:3975
+#: fortran/expr.c:3978
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr ""
 
-#: fortran/expr.c:4051 fortran/resolve.c:1452
+#: fortran/expr.c:4054 fortran/resolve.c:1452
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr "Argumen dari prosedur FINAL di %L harus berupa DAPAT-DIALOKASIKAN"
 
-#: fortran/expr.c:4057
+#: fortran/expr.c:4060
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Component at %C must have the POINTER attribute"
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr "Komponen di %C harus memiliki sebuah atribut PENUNJUK"
 
-#: fortran/expr.c:4072 fortran/resolve.c:1458
+#: fortran/expr.c:4075 fortran/resolve.c:1458
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Component at %C must have the POINTER attribute"
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr "Komponen di %C harus memiliki sebuah atribut PENUNJUK"
 
-#: fortran/expr.c:4084
+#: fortran/expr.c:4087
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr ""
 
-#: fortran/expr.c:5512
+#: fortran/expr.c:4557
+#, gcc-internal-format
+msgid "generate_isocbinding_initializer(): bad iso_c_binding type, expected %<c_ptr%> or %<c_funptr%>"
+msgstr ""
+
+#: fortran/expr.c:5568
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: Noninteger exponent in an initialization expression at %L"
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr "Fortran 2003: eksponen bukan integer dalam sebuah ekspresi inisialisasi di %L"
 
-#: fortran/expr.c:5520
+#: fortran/expr.c:5576
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5528
+#: fortran/expr.c:5584
 #, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5537
+#: fortran/expr.c:5593
 #, fuzzy, gcc-internal-format
 #| msgid "Argument to '%s' at %L is not a variable"
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr "Argumen ke '%s' di %L bukan sebuah variabel"
 
-#: fortran/expr.c:5548
+#: fortran/expr.c:5604
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5557
+#: fortran/expr.c:5613
 #, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5570
+#: fortran/expr.c:5626
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5583
+#: fortran/expr.c:5639
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5613
+#: fortran/expr.c:5669
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5621
+#: fortran/expr.c:5677
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5634
+#: fortran/expr.c:5690
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' cannot appear in the expression at %L"
 msgid "Variable %qs is PROTECTED and can not appear in a pointer association context (%s) at %L"
 msgstr "Variabel '%s' tidak dapat muncul dalam ekspresi di %L"
 
-#: fortran/expr.c:5642
+#: fortran/expr.c:5698
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5654
+#: fortran/expr.c:5710
 #, fuzzy, gcc-internal-format
 #| msgid "Variable %s cannot be assigned in PURE procedure at %C"
 msgid "Variable %qs can not appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr "Variabel %s tidak dapat ditempatkan dalam prosedur PURE di %C"
 
-#: fortran/expr.c:5713
+#: fortran/expr.c:5769
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:5717
+#: fortran/expr.c:5773
 #, gcc-internal-format
 msgid "%qs at %L associated to expression can not be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:5728
+#: fortran/expr.c:5784
 #, gcc-internal-format
 msgid "Associate-name %qs can not appear in a variable definition context (%s) at %L because its target at %L can not, either"
 msgstr ""
 
-#: fortran/expr.c:5770
+#: fortran/expr.c:5826
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr ""
@@ -60828,24 +60911,24 @@
 msgid "can't open input file: %s"
 msgstr "tidak dapat membuka berkas masukan: %s"
 
-#: fortran/frontend-passes.c:190
+#: fortran/frontend-passes.c:192
 #, fuzzy, gcc-internal-format
 #| msgid "in statement"
 msgid "No location in statement"
 msgstr "dalam pernyataan"
 
-#: fortran/frontend-passes.c:205
+#: fortran/frontend-passes.c:207
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected exponent in expression at %C"
 msgid "No location in expression near %L"
 msgstr "Diduga eksponen dalam ekspresi di %C"
 
-#: fortran/frontend-passes.c:409
+#: fortran/frontend-passes.c:414
 #, gcc-internal-format
 msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
-#: fortran/frontend-passes.c:817 fortran/trans-array.c:1182
+#: fortran/frontend-passes.c:822 fortran/trans-array.c:1182
 #: fortran/trans-array.c:6440 fortran/trans-array.c:7864
 #: fortran/trans-intrinsic.c:7307
 #, gcc-internal-format, gfc-internal-format
@@ -60852,76 +60935,76 @@
 msgid "Creating array temporary at %L"
 msgstr "Membuat array sementara di %L"
 
-#: fortran/frontend-passes.c:842 fortran/frontend-passes.c:846
+#: fortran/frontend-passes.c:847 fortran/frontend-passes.c:851
 #, fuzzy, gcc-internal-format
 #| msgid "Return value of function '%s' at %L not set"
 msgid "Removing call to function %qs at %L"
 msgstr "Nilai kembali dari fungsi '%s' di %L tidak diset"
 
-#: fortran/frontend-passes.c:1273 fortran/frontend-passes.c:1312
+#: fortran/frontend-passes.c:1278 fortran/frontend-passes.c:1317
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "bad expression"
 msgstr "diduga ekspresi"
 
-#: fortran/frontend-passes.c:1308
+#: fortran/frontend-passes.c:1313
 #, gcc-internal-format
 msgid "bad op"
 msgstr ""
 
-#: fortran/frontend-passes.c:2161
+#: fortran/frontend-passes.c:2166
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands in gimple comparison"
 msgid "illegal OP in optimize_comparison"
 msgstr "operan tidak valid dalam perbandingan gimple"
 
-#: fortran/frontend-passes.c:2407
+#: fortran/frontend-passes.c:2412
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgid "Variable %qs at %L set to undefined value inside loop  beginning at %L as INTENT(OUT) argument to subroutine %qs"
 msgstr "Variabel '%s' di %C tidak dapat diredefinisi didalam loop berawal di %L"
 
-#: fortran/frontend-passes.c:2414
+#: fortran/frontend-passes.c:2419
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to subroutine %qs"
 msgstr "Variabel '%s' di %C tidak dapat diredefinisi didalam loop berawal di %L"
 
-#: fortran/frontend-passes.c:2637 fortran/frontend-passes.c:2661
+#: fortran/frontend-passes.c:2642 fortran/frontend-passes.c:2666
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgid "Array reference at %L out of bounds (%ld < %ld) in loop beginning at %L"
 msgstr "Referensi array di %L diluar dari jangkauan (%ld < %ld) dalam dimensi %d"
 
-#: fortran/frontend-passes.c:2646 fortran/frontend-passes.c:2670
+#: fortran/frontend-passes.c:2651 fortran/frontend-passes.c:2675
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgid "Array reference at %L out of bounds (%ld > %ld) in loop beginning at %L"
 msgstr "Referensi array di %L diluar dari jangkauan (%ld > %ld) dalam dimensi %d"
 
-#: fortran/frontend-passes.c:2730
+#: fortran/frontend-passes.c:2735
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgid "Variable %qs at %L set to undefined value inside loop beginning at %L as INTENT(OUT) argument to function %qs"
 msgstr "Variabel '%s' di %C tidak dapat diredefinisi didalam loop berawal di %L"
 
-#: fortran/frontend-passes.c:2736
+#: fortran/frontend-passes.c:2741
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr "Variabel '%s' di %C tidak dapat diredefinisi didalam loop berawal di %L"
 
-#: fortran/frontend-passes.c:3128 fortran/trans-expr.c:1581
+#: fortran/frontend-passes.c:3133 fortran/trans-expr.c:1581
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr ""
 
-#: fortran/frontend-passes.c:3637
+#: fortran/frontend-passes.c:3642
 #, gcc-internal-format
 msgid "Scalarization using DIMEN_RANGE unimplemented"
 msgstr ""
 
-#: fortran/frontend-passes.c:4429
+#: fortran/frontend-passes.c:4434
 #, gcc-internal-format, gfc-internal-format
 msgid "Interchanging loops at %L"
 msgstr ""
@@ -61049,12 +61132,12 @@
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "Argumen kedua dari penempatan didefinisikan di %L harus berupa INTENT(IN)"
 
-#: fortran/interface.c:970 fortran/resolve.c:16351
+#: fortran/interface.c:970 fortran/resolve.c:16378
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "Argumen pertama dari antar-muka operator di %L harus berupa INTENT(IN)"
 
-#: fortran/interface.c:977 fortran/resolve.c:16369
+#: fortran/interface.c:977 fortran/resolve.c:16396
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "Argumen kedua dari antar-muka operator di %L harus berupa INTENT(IN)"
@@ -62398,7 +62481,7 @@
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.c:3369 fortran/resolve.c:14263
+#: fortran/io.c:3369 fortran/resolve.c:14283
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' in namelist '%s' at %L cannot have ALLOCATABLE components"
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
@@ -62576,7 +62659,7 @@
 msgid "Integer too large at %C"
 msgstr "Integer terlalu besar di %C"
 
-#: fortran/match.c:580 fortran/parse.c:1132
+#: fortran/match.c:580 fortran/parse.c:1136
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many digits in statement label at %C"
 msgstr "Terlalu banyak digit dalam pernyataan label di %C"
@@ -63411,62 +63494,62 @@
 msgid "Expected block name %qs of SELECT construct at %C"
 msgstr "Diduga nama dari SELECT CASE konstruk di %C"
 
-#: fortran/match.c:6186
+#: fortran/match.c:6201
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in PROTECTED statement at %C"
 msgid "parse error in SELECT TYPE statement at %C"
 msgstr "Sintaks error dalam pernyataan TERPROTEKSI di %C"
 
-#: fortran/match.c:6211
+#: fortran/match.c:6226
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr ""
 
-#: fortran/match.c:6249
+#: fortran/match.c:6264
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr "Diduga pernyataan CASE di %C"
 
-#: fortran/match.c:6301
+#: fortran/match.c:6316
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CASE-specification at %C"
 msgid "Syntax error in CASE specification at %C"
 msgstr "Sintaks error dalam spesifikasi CASE di %C"
 
-#: fortran/match.c:6319
+#: fortran/match.c:6334
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected END statement at %C"
 msgid "Unexpected TYPE IS statement at %C"
 msgstr "Tidak terduga pernyataan END di %C"
 
-#: fortran/match.c:6351
+#: fortran/match.c:6366
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr ""
 
-#: fortran/match.c:6362
+#: fortran/match.c:6377
 #, gcc-internal-format, gfc-internal-format
 msgid "All the LEN type parameters in the TYPE IS statement at %C must be ASSUMED"
 msgstr ""
 
-#: fortran/match.c:6373
+#: fortran/match.c:6388
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CASE-specification at %C"
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr "Sintaks error dalam spesifikasi CASE di %C"
 
-#: fortran/match.c:6449
+#: fortran/match.c:6464
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CASE-specification at %C"
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr "Sintaks error dalam spesifikasi CASE di %C"
 
-#: fortran/match.c:6572
+#: fortran/match.c:6587
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr "pernyataan ELSEWHERE di %C tidak terenklose dalam blok WHERE"
 
-#: fortran/match.c:6610
+#: fortran/match.c:6625
 #, fuzzy, gcc-internal-format
 #| msgid "Label '%s' at %C doesn't match WHERE label '%s'"
 msgid "Label %qs at %C doesn't match WHERE label %qs"
@@ -63631,204 +63714,204 @@
 msgid "mio_array_ref(): Unknown array ref"
 msgstr ""
 
-#: fortran/module.c:3716
+#: fortran/module.c:3718
 #, gcc-internal-format, gfc-internal-format
 msgid "Namelist %s cannot be renamed by USE association to %s"
 msgstr "Daftar-nama %s tidak dapat diubah namanya dengan assosiasi USE ke %s"
 
-#: fortran/module.c:4832
+#: fortran/module.c:4834
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4835
+#: fortran/module.c:4837
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:5029
+#: fortran/module.c:5031
 #, gcc-internal-format
 msgid "%qs of module %qs, imported at %C, is also the name of the current program unit"
 msgstr ""
 
-#: fortran/module.c:5381
+#: fortran/module.c:5383
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' referenced at %L not found in module '%s'"
 msgid "Symbol %qs referenced at %L not found in module %qs"
 msgstr "Simbol '%s' direferensikan di %L tidak ditemukan dalam modul '%s'"
 
-#: fortran/module.c:5388
+#: fortran/module.c:5390
 #, fuzzy, gcc-internal-format
 #| msgid "User operator '%s' referenced at %L not found in module '%s'"
 msgid "User operator %qs referenced at %L not found in module %qs"
 msgstr "Operator pengguna '%s' direferensikan di %L tidak ditemukan dalam modul '%s'"
 
-#: fortran/module.c:5393
+#: fortran/module.c:5395
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic operator '%s' referenced at %L not found in module '%s'"
 msgid "Intrinsic operator %qs referenced at %L not found in module %qs"
 msgstr "Operator intrinsik '%s' direferensikan di %L tidak ditemukan dalam modul '%s'"
 
-#: fortran/module.c:5628
+#: fortran/module.c:5630
 #, gcc-internal-format
 msgid "write_symbol(): bad module symbol %qs"
 msgstr ""
 
-#: fortran/module.c:5961
+#: fortran/module.c:5963
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr ""
 
-#: fortran/module.c:6148
+#: fortran/module.c:6150
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open module file '%s' for writing at %C: %s"
 msgid "Can't open module file %qs for writing at %C: %s"
 msgstr "Tidak dapat membuka berkas modul '%s' untuk menulis di %C: %s"
 
-#: fortran/module.c:6169
+#: fortran/module.c:6171
 #, fuzzy, gcc-internal-format
 #| msgid "Error writing module file '%s' for writing: %s"
 msgid "Error writing module file %qs for writing: %s"
 msgstr "Error menulis berkas modul '%s' untuk menulis: %s"
 
-#: fortran/module.c:6180
+#: fortran/module.c:6182
 #, fuzzy, gcc-internal-format
 #| msgid "Can't delete module file '%s': %s"
 msgid "Can't delete module file %qs: %s"
 msgstr "tidak dapat menghapus berkas modul '%s': %s"
 
-#: fortran/module.c:6183
+#: fortran/module.c:6185
 #, fuzzy, gcc-internal-format
 #| msgid "Can't rename module file '%s' to '%s': %s"
 msgid "Can't rename module file %qs to %qs: %s"
 msgstr "tidak dapat mengubah nama berkas modul '%s' ke '%s': %s"
 
-#: fortran/module.c:6189
+#: fortran/module.c:6191
 #, fuzzy, gcc-internal-format
 #| msgid "Can't delete temporary module file '%s': %s"
 msgid "Can't delete temporary module file %qs: %s"
 msgstr "Tidak dapat menghapus berkas modul sementara '%s': %s"
 
-#: fortran/module.c:6246
+#: fortran/module.c:6248
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' already declared"
 msgid "Symbol %qs at %C already declared"
 msgstr "Simbol '%s' telah terdeklarasi"
 
-#: fortran/module.c:6317
+#: fortran/module.c:6319
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr ""
 
-#: fortran/module.c:6425 fortran/module.c:6769
+#: fortran/module.c:6427 fortran/module.c:6771
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' referenced at %L not found in module '%s'"
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr "Simbol '%s' direferensikan di %L tidak ditemukan dalam modul '%s'"
 
-#: fortran/module.c:6553
+#: fortran/module.c:6555
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr "Simbol '%s' direferensikan di %L tidak ditemukan dalam modul intrinsik ISO_C_BINDING"
 
-#: fortran/module.c:6574 fortran/module.c:6607 fortran/module.c:6649
+#: fortran/module.c:6576 fortran/module.c:6609 fortran/module.c:6651
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' already declared"
 msgid "Symbol %qs already declared"
 msgstr "Simbol '%s' telah terdeklarasi"
 
-#: fortran/module.c:6754
+#: fortran/module.c:6756
 #, fuzzy, gcc-internal-format
 #| msgid "Use of intrinsic module '%s' at %C conflicts with non-intrinsic module name used previously"
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr "Penggunaan daro modul intrinsik '%s' di %C konflik dengan tidak-intrinsik nama modul digunakan sebelumnya"
 
-#: fortran/module.c:6776
+#: fortran/module.c:6778
 #, fuzzy, gcc-internal-format
 #| msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %s"
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr "Penggunaan dari NUMERIC_STORAGE_SIZE konstanta bernama dari modul intrinsik ISO_FORTRAN_ENV di %L adalah tidak kompatibel dengan pilihan %s"
 
-#: fortran/module.c:6844
+#: fortran/module.c:6846
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr "Penggunaan dari NUMERIC_STORAGE_SIZE konstanta bernama dari modul intrinsik ISO_FORTRAN_ENV di %C adalah tidak kompatibel dengan pilihan %s"
 
-#: fortran/module.c:6898
+#: fortran/module.c:6900
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr "Simbol '%s' direferensikan di %L tidak ditemukan dalam modul intrinsik ISO_FORTRAN_ENV"
 
-#: fortran/module.c:6924
+#: fortran/module.c:6926
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement at %C is not within a loop"
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr "pernyataan %s di %C tidak dalam jangkauan sebuah loop"
 
-#: fortran/module.c:6953
+#: fortran/module.c:6955
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ISO_FORTRAN_ENV intrinsic module at %C"
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr "Fortran 2003: ISO_FORTRAN_ENV modul intrinsik di %C"
 
-#: fortran/module.c:6965
+#: fortran/module.c:6967
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ISO_C_BINDING module at %C"
 msgid "ISO_C_BINDING module at %C"
 msgstr "Fortran 2003: ISO_C_BINDING modul di %C"
 
-#: fortran/module.c:6978
+#: fortran/module.c:6980
 #, fuzzy, gcc-internal-format
 #| msgid "Can't find an intrinsic module named '%s' at %C"
 msgid "Can't find an intrinsic module named %qs at %C"
 msgstr "Tidak dapat menemukan modul intrinsik bernama '%s' di %C"
 
-#: fortran/module.c:6984
+#: fortran/module.c:6986
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr ""
 
-#: fortran/module.c:6990
+#: fortran/module.c:6992
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr ""
 
-#: fortran/module.c:6996
+#: fortran/module.c:6998
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr ""
 
-#: fortran/module.c:7006
+#: fortran/module.c:7008
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open module file '%s' for reading at %C: %s"
 msgid "Can't open module file %qs for reading at %C: %s"
 msgstr "Tidak dapat membuka berkas modul '%s' untuk pembacaan di %C: %s"
 
-#: fortran/module.c:7009
+#: fortran/module.c:7011
 #, gcc-internal-format
 msgid "Module file %qs has not been generated, either because the module does not contain a MODULE PROCEDURE or there is an error in the module."
 msgstr ""
 
-#: fortran/module.c:7020
+#: fortran/module.c:7022
 #, fuzzy, gcc-internal-format
 #| msgid "Use of non-intrinsic module '%s' at %C conflicts with intrinsic module name used previously"
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr "Penggunaan dari modul tidak intrinsik '%s' di %C konflik dengan nama modul intrinsik yang digunakan sebelumnya"
 
-#: fortran/module.c:7043
+#: fortran/module.c:7045
 #, fuzzy, gcc-internal-format
 #| msgid "File '%s' opened at %C is not a GFORTRAN module file"
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr "Berkas '%s' dibuka di %C bukan sebuah berkas modul GFORTRAN"
 
-#: fortran/module.c:7051
+#: fortran/module.c:7053
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr ""
 
-#: fortran/module.c:7066
+#: fortran/module.c:7068
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Can't USE the same module we're building!"
 msgid "Can't USE the same %smodule we're building"
@@ -63835,7 +63918,7 @@
 msgstr "Tidak dapat MENGGUNAKAN module yang sama yang sedang kita buat!"
 
 #: fortran/openmp.c:296 fortran/openmp.c:397 fortran/openmp.c:692
-#: fortran/openmp.c:3167
+#: fortran/openmp.c:3166
 #, gcc-internal-format, gfc-internal-format
 msgid "COMMON block /%s/ not found at %C"
 msgstr "blok COMMON /%s/  tidak ditemukan di %C"
@@ -63920,536 +64003,536 @@
 #: fortran/openmp.c:2180
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid third argument of IBITS at %L"
-msgid "Invalid argument to !$ACC WAIT at %L"
+msgid "Invalid argument to !$ACC WAIT at %C"
 msgstr "Argumen ketiga dari IBITS di %L tidak valid"
 
-#: fortran/openmp.c:2188
+#: fortran/openmp.c:2187
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "NUM_THREADS clause at %L requires a scalar INTEGER expression"
 msgid "WAIT clause at %L requires a scalar INTEGER expression"
 msgstr "NUM_THREADS clause di %L membutuhkan sebuah ekspresi skalar INTEGER"
 
-#: fortran/openmp.c:2221
+#: fortran/openmp.c:2220
 #, gcc-internal-format, gfc-internal-format
 msgid "ACC CACHE directive must be inside of loop %C"
 msgstr ""
 
-#: fortran/openmp.c:2252
+#: fortran/openmp.c:2251
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for typename"
 msgid "Multiple loop axes specified for routine"
 msgstr "class penyimpanan dispesifikasikan untuk nama tipe"
 
-#: fortran/openmp.c:2278
+#: fortran/openmp.c:2277
 #, gcc-internal-format, gfc-internal-format
 msgid "Only the !$ACC ROUTINE form without list is allowed in interface block at %C"
 msgstr ""
 
-#: fortran/openmp.c:2306
+#: fortran/openmp.c:2305
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$ACC ROUTINE ( NAME ) at %C, invalid function name %s"
 msgstr ""
 
-#: fortran/openmp.c:2315
+#: fortran/openmp.c:2314
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in !$OMP THREADPRIVATE list at %C"
 msgid "Syntax error in !$ACC ROUTINE ( NAME ) at %C"
 msgstr "Sintaks error dalam daftar THREADPRIVATE !$OMP di %C"
 
-#: fortran/openmp.c:2322
+#: fortran/openmp.c:2321
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$ACC ROUTINE ( NAME ) at %C, expecting ')' after NAME"
 msgstr ""
 
-#: fortran/openmp.c:2457 fortran/openmp.c:2481
+#: fortran/openmp.c:2456 fortran/openmp.c:2480
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after ELSE statement at %C"
 msgid "Unexpected junk after $OMP CRITICAL statement at %C"
 msgstr "Tidak terduga sampah setelah pernyataan ELSE di %C"
 
-#: fortran/openmp.c:2548
+#: fortran/openmp.c:2547
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after ELSE statement at %C"
 msgid "Unexpected junk after $OMP FLUSH statement at %C"
 msgstr "Tidak terduga sampah setelah pernyataan ELSE di %C"
 
-#: fortran/openmp.c:2942 fortran/openmp.c:6225
+#: fortran/openmp.c:2941 fortran/openmp.c:6230
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined %s !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2946 fortran/openmp.c:6229
+#: fortran/openmp.c:2945 fortran/openmp.c:6234
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2951
+#: fortran/openmp.c:2950
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2953
+#: fortran/openmp.c:2952
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2973
+#: fortran/openmp.c:2972
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after ELSE statement at %C"
 msgid "Unexpected junk after !$OMP DECLARE REDUCTION at %C"
 msgstr "Tidak terduga sampah setelah pernyataan ELSE di %C"
 
-#: fortran/openmp.c:3010
+#: fortran/openmp.c:3009
 #, gcc-internal-format, gfc-internal-format
 msgid "Only the !$OMP DECLARE TARGET form without clauses is allowed in interface block at %C"
 msgstr ""
 
-#: fortran/openmp.c:3025
+#: fortran/openmp.c:3024
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after ELSE statement at %C"
 msgid "Unexpected junk after !$OMP DECLARE TARGET at %C"
 msgstr "Tidak terduga sampah setelah pernyataan ELSE di %C"
 
-#: fortran/openmp.c:3048
+#: fortran/openmp.c:3047
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Threadprivate variable at %C is an element of a COMMON block"
 msgid "OMP DECLARE TARGET variable at %L is an element of a COMMON block"
 msgstr "Variabel threadprivate di %C bukan sebuah elemen dari sebuah blok COMMON"
 
-#: fortran/openmp.c:3053
+#: fortran/openmp.c:3052
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET variable at %L previously mentioned in LINK clause and later in TO clause"
 msgstr ""
 
-#: fortran/openmp.c:3059
+#: fortran/openmp.c:3058
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET variable at %L previously mentioned in TO clause and later in LINK clause"
 msgstr ""
 
-#: fortran/openmp.c:3063
+#: fortran/openmp.c:3062
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable at %L mentioned multiple times in clauses of the same OMP DECLARE TARGET directive"
 msgstr ""
 
-#: fortran/openmp.c:3078
+#: fortran/openmp.c:3077
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET COMMON at %L previously mentioned in LINK clause and later in TO clause"
 msgstr ""
 
-#: fortran/openmp.c:3084
+#: fortran/openmp.c:3083
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET COMMON at %L previously mentioned in TO clause and later in LINK clause"
 msgstr ""
 
-#: fortran/openmp.c:3088
+#: fortran/openmp.c:3087
 #, gcc-internal-format, gfc-internal-format
 msgid "COMMON at %L mentioned multiple times in clauses of the same OMP DECLARE TARGET directive"
 msgstr ""
 
-#: fortran/openmp.c:3115
+#: fortran/openmp.c:3114
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in !$OMP THREADPRIVATE list at %C"
 msgid "Syntax error in !$OMP DECLARE TARGET list at %C"
 msgstr "Sintaks error dalam daftar THREADPRIVATE !$OMP di %C"
 
-#: fortran/openmp.c:3147
+#: fortran/openmp.c:3146
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate variable at %C is an element of a COMMON block"
 msgstr "Variabel threadprivate di %C bukan sebuah elemen dari sebuah blok COMMON"
 
-#: fortran/openmp.c:3184
+#: fortran/openmp.c:3183
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after ELSE statement at %C"
 msgid "Unexpected junk after OMP THREADPRIVATE at %C"
 msgstr "Tidak terduga sampah setelah pernyataan ELSE di %C"
 
-#: fortran/openmp.c:3191
+#: fortran/openmp.c:3190
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$OMP THREADPRIVATE list at %C"
 msgstr "Sintaks error dalam daftar THREADPRIVATE !$OMP di %C"
 
-#: fortran/openmp.c:3405
+#: fortran/openmp.c:3404
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after ELSE statement at %C"
 msgid "Unexpected junk after TASKWAIT clause at %C"
 msgstr "Tidak terduga sampah setelah pernyataan ELSE di %C"
 
-#: fortran/openmp.c:3419
+#: fortran/openmp.c:3418
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after ELSE statement at %C"
 msgid "Unexpected junk after TASKYIELD clause at %C"
 msgstr "Tidak terduga sampah setelah pernyataan ELSE di %C"
 
-#: fortran/openmp.c:3478
+#: fortran/openmp.c:3477
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after ELSE statement at %C"
 msgid "Unexpected junk after $OMP WORKSHARE statement at %C"
 msgstr "Tidak terduga sampah setelah pernyataan ELSE di %C"
 
-#: fortran/openmp.c:3492
+#: fortran/openmp.c:3491
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after ELSE statement at %C"
 msgid "Unexpected junk after $OMP MASTER statement at %C"
 msgstr "Tidak terduga sampah setelah pernyataan ELSE di %C"
 
-#: fortran/openmp.c:3551
+#: fortran/openmp.c:3550
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after ELSE IF statement at %C"
 msgid "Unexpected junk after $OMP ATOMIC statement at %C"
 msgstr "Tidak terduga sampah setelah pernyataan ELSE IF di %C"
 
-#: fortran/openmp.c:3578
+#: fortran/openmp.c:3577
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after ELSE statement at %C"
 msgid "Unexpected junk after $OMP BARRIER statement at %C"
 msgstr "Tidak terduga sampah setelah pernyataan ELSE di %C"
 
-#: fortran/openmp.c:3592
+#: fortran/openmp.c:3591
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after ELSE statement at %C"
 msgid "Unexpected junk after $OMP TASKGROUP statement at %C"
 msgstr "Tidak terduga sampah setelah pernyataan ELSE di %C"
 
-#: fortran/openmp.c:3642
+#: fortran/openmp.c:3641
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after ELSE IF statement at %C"
 msgid "Unexpected junk after $OMP CANCELLATION POINT statement at %C"
 msgstr "Tidak terduga sampah setelah pernyataan ELSE IF di %C"
 
-#: fortran/openmp.c:3662
+#: fortran/openmp.c:3661
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after ELSE statement at %C"
 msgid "Unexpected junk after NOWAIT clause at %C"
 msgstr "Tidak terduga sampah setelah pernyataan ELSE di %C"
 
-#: fortran/openmp.c:3704
+#: fortran/openmp.c:3703
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "NUM_THREADS clause at %L requires a scalar INTEGER expression"
 msgid "%s clause at %L requires a scalar INTEGER expression"
 msgstr "NUM_THREADS clause di %L membutuhkan sebuah ekspresi skalar INTEGER"
 
-#: fortran/openmp.c:3715
+#: fortran/openmp.c:3714
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in CASE statement at %L must be of type %s"
 msgid "INTEGER expression of %s clause at %L must be positive"
 msgstr "Ekspresi dalam pernyataan CASE di %L harus berupa tipe %s"
 
-#: fortran/openmp.c:3726
+#: fortran/openmp.c:3725
 #, gcc-internal-format, gfc-internal-format
 msgid "INTEGER expression of %s clause at %L must be non-negative"
 msgstr ""
 
-#: fortran/openmp.c:3737
+#: fortran/openmp.c:3736
 #, fuzzy, gcc-internal-format
 #| msgid "POINTER object '%s' in %s clause at %L"
 msgid "POINTER object %qs of derived type in %s clause at %L"
 msgstr "objek PENUNJUK '%s' dalam %s clause di %L"
 
-#: fortran/openmp.c:3740
+#: fortran/openmp.c:3739
 #, fuzzy, gcc-internal-format
 #| msgid "Cray pointer '%s' in %s clause at %L"
 msgid "Cray pointer object %qs of derived type in %s clause at %L"
 msgstr "Cray penunjuk '%s' dalam clause %s di %L"
 
-#: fortran/openmp.c:3743
+#: fortran/openmp.c:3742
 #, fuzzy, gcc-internal-format
 #| msgid "Cray pointee '%s' in %s clause at %L"
 msgid "Cray pointee object %qs of derived type in %s clause at %L"
 msgstr "Cray pointee '%s' dalam %s clause di %L"
 
-#: fortran/openmp.c:3749 fortran/openmp.c:4687
+#: fortran/openmp.c:3748 fortran/openmp.c:4686
 #, fuzzy, gcc-internal-format
 #| msgid "POINTER object '%s' in %s clause at %L"
 msgid "POINTER object %qs of polymorphic type in %s clause at %L"
 msgstr "objek PENUNJUK '%s' dalam %s clause di %L"
 
-#: fortran/openmp.c:3754
+#: fortran/openmp.c:3753
 #, fuzzy, gcc-internal-format
 #| msgid "Cray pointer '%s' in %s clause at %L"
 msgid "Cray pointer object %qs of polymorphic type in %s clause at %L"
 msgstr "Cray penunjuk '%s' dalam clause %s di %L"
 
-#: fortran/openmp.c:3759
+#: fortran/openmp.c:3758
 #, fuzzy, gcc-internal-format
 #| msgid "Cray pointee '%s' in %s clause at %L"
 msgid "Cray pointee object %qs of polymorphic type in %s clause at %L"
 msgstr "Cray pointee '%s' dalam %s clause di %L"
 
-#: fortran/openmp.c:3769 fortran/openmp.c:4385 fortran/openmp.c:4490
+#: fortran/openmp.c:3768 fortran/openmp.c:4384 fortran/openmp.c:4489
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed size array '%s' in %s clause at %L"
 msgid "Assumed size array %qs in %s clause at %L"
 msgstr "Ukuran array yang diasumsikan '%s' dalam %s clause di %L"
 
-#: fortran/openmp.c:3772
+#: fortran/openmp.c:3771
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed size array '%s' in %s clause at %L"
 msgid "Assumed rank array %qs in %s clause at %L"
 msgstr "Ukuran array yang diasumsikan '%s' dalam %s clause di %L"
 
-#: fortran/openmp.c:3776
+#: fortran/openmp.c:3775
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed size array '%s' in %s clause at %L"
 msgid "Noncontiguous deferred shape array %qs in %s clause at %L"
 msgstr "Ukuran array yang diasumsikan '%s' dalam %s clause di %L"
 
-#: fortran/openmp.c:3784
+#: fortran/openmp.c:3783
 #, fuzzy, gcc-internal-format
 #| msgid "POINTER object '%s' in %s clause at %L"
 msgid "ALLOCATABLE object %qs of derived type in %s clause at %L"
 msgstr "objek PENUNJUK '%s' dalam %s clause di %L"
 
-#: fortran/openmp.c:3789
+#: fortran/openmp.c:3788
 #, fuzzy, gcc-internal-format
 #| msgid "POINTER object '%s' in %s clause at %L"
 msgid "ALLOCATABLE object %qs of polymorphic type in %s clause at %L"
 msgstr "objek PENUNJUK '%s' dalam %s clause di %L"
 
-#: fortran/openmp.c:3801 fortran/openmp.c:4480
+#: fortran/openmp.c:3800 fortran/openmp.c:4479
 #, fuzzy, gcc-internal-format
 #| msgid "POINTER object '%s' in %s clause at %L"
 msgid "POINTER object %qs in %s clause at %L"
 msgstr "objek PENUNJUK '%s' dalam %s clause di %L"
 
-#: fortran/openmp.c:3806 fortran/openmp.c:4691
+#: fortran/openmp.c:3805 fortran/openmp.c:4690
 #, fuzzy, gcc-internal-format
 #| msgid "Cray pointer '%s' in %s clause at %L"
 msgid "Cray pointer object %qs in %s clause at %L"
 msgstr "Cray penunjuk '%s' dalam clause %s di %L"
 
-#: fortran/openmp.c:3811 fortran/openmp.c:4694
+#: fortran/openmp.c:3810 fortran/openmp.c:4693
 #, fuzzy, gcc-internal-format
 #| msgid "Cray pointee '%s' in %s clause at %L"
 msgid "Cray pointee object %qs in %s clause at %L"
 msgstr "Cray pointee '%s' dalam %s clause di %L"
 
-#: fortran/openmp.c:3816 fortran/openmp.c:4682
+#: fortran/openmp.c:3815 fortran/openmp.c:4681
 #, fuzzy, gcc-internal-format
 #| msgid "POINTER object '%s' in %s clause at %L"
 msgid "ALLOCATABLE object %qs in %s clause at %L"
 msgstr "objek PENUNJUK '%s' dalam %s clause di %L"
 
-#: fortran/openmp.c:3819
+#: fortran/openmp.c:3818
 #, fuzzy, gcc-internal-format
 #| msgid "POINTER object '%s' in %s clause at %L"
 msgid "VALUE object %qs in %s clause at %L"
 msgstr "objek PENUNJUK '%s' dalam %s clause di %L"
 
-#: fortran/openmp.c:3862
+#: fortran/openmp.c:3861
 #, gcc-internal-format, gfc-internal-format
 msgid "Implicitly declared function %s used in !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:3911
+#: fortran/openmp.c:3910
 #, gcc-internal-format, gfc-internal-format
 msgid "Implicitly declared subroutine %s used in !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:3944
+#: fortran/openmp.c:3943
 #, gcc-internal-format, gfc-internal-format
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:3952 fortran/openmp.c:3963 fortran/resolve.c:10028
-#: fortran/resolve.c:11295
+#: fortran/openmp.c:3951 fortran/openmp.c:3962 fortran/resolve.c:10041
+#: fortran/resolve.c:11315
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "IF clause di %L membutuhkan sebuah ekspresi skalara LOGIKAL"
 
-#: fortran/openmp.c:3967
+#: fortran/openmp.c:3966
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause without modifier at %L used together with IF clauses with modifiers"
 msgstr ""
 
-#: fortran/openmp.c:4044
+#: fortran/openmp.c:4043
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause modifier %s at %L not appropriate for the current OpenMP construct"
 msgstr ""
 
-#: fortran/openmp.c:4054
+#: fortran/openmp.c:4053
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgid "FINAL clause at %L requires a scalar LOGICAL expression"
 msgstr "IF clause di %L membutuhkan sebuah ekspresi skalara LOGIKAL"
 
-#: fortran/openmp.c:4064
+#: fortran/openmp.c:4063
 #, gcc-internal-format, gfc-internal-format
 msgid "SCHEDULE clause's chunk_size at %L requires a scalar INTEGER expression"
 msgstr "SCHEDULE clause chunk_size di %L membutuhkan sebuah ekspresi skalar INTEGER"
 
-#: fortran/openmp.c:4069
+#: fortran/openmp.c:4068
 #, gcc-internal-format, gfc-internal-format
 msgid "INTEGER expression of SCHEDULE clause's chunk_size at %L must be positive"
 msgstr ""
 
-#: fortran/openmp.c:4084
+#: fortran/openmp.c:4083
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' has not been assigned a target label at %L"
 msgid "Variable %qs is not a dummy argument at %L"
 msgstr "Variabel '%s' belum pernah ditempatkan sebuah label target di %L"
 
-#: fortran/openmp.c:4116
+#: fortran/openmp.c:4115 fortran/openmp.c:5998
 #, fuzzy, gcc-internal-format
 #| msgid "Object '%s' is not a variable at %L"
 msgid "Object %qs is not a variable at %L"
 msgstr "Objek '%s' bukan sebuah variabel di %L"
 
-#: fortran/openmp.c:4132 fortran/openmp.c:4143 fortran/openmp.c:4151
-#: fortran/openmp.c:4162 fortran/openmp.c:4174 fortran/openmp.c:4189
-#: fortran/openmp.c:6023
+#: fortran/openmp.c:4131 fortran/openmp.c:4142 fortran/openmp.c:4150
+#: fortran/openmp.c:4161 fortran/openmp.c:4173 fortran/openmp.c:4188
+#: fortran/openmp.c:6028
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' present on multiple clauses at %L"
 msgid "Symbol %qs present on multiple clauses at %L"
 msgstr "Simbol '%s' ada dalam multiple clause di %L"
 
-#: fortran/openmp.c:4196
+#: fortran/openmp.c:4195
 #, gcc-internal-format
 msgid "Array %qs is not permitted in reduction at %L"
 msgstr ""
 
-#: fortran/openmp.c:4209
+#: fortran/openmp.c:4208
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' present on multiple clauses at %L"
 msgid "Symbol %qs present on both FROM and TO clauses at %L"
 msgstr "Simbol '%s' ada dalam multiple clause di %L"
 
-#: fortran/openmp.c:4231
+#: fortran/openmp.c:4230
 #, fuzzy, gcc-internal-format
 #| msgid "Non-THREADPRIVATE object '%s' in COPYIN clause at %L"
 msgid "Non-THREADPRIVATE object %qs in COPYIN clause at %L"
 msgstr "Bukan-THREADPRIVATE objek '%s' dalam clause COPYIN di %L"
 
-#: fortran/openmp.c:4239
+#: fortran/openmp.c:4238
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed size array '%s' in COPYPRIVATE clause at %L"
 msgid "Assumed size array %qs in COPYPRIVATE clause at %L"
 msgstr "Ukuran array diasumsikan '%s' dalam clause COPYPRIVATE di %L"
 
-#: fortran/openmp.c:4242
+#: fortran/openmp.c:4241
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed size array '%s' in COPYPRIVATE clause at %L"
 msgid "INTENT(IN) POINTER %qs in COPYPRIVATE clause at %L"
 msgstr "Ukuran array diasumsikan '%s' dalam clause COPYPRIVATE di %L"
 
-#: fortran/openmp.c:4250
+#: fortran/openmp.c:4249
 #, fuzzy, gcc-internal-format
 #| msgid "THREADPRIVATE object '%s' in SHARED clause at %L"
 msgid "THREADPRIVATE object %qs in SHARED clause at %L"
 msgstr "objek THREADPRIVATE '%s' dalam clause SHARED di %L"
 
-#: fortran/openmp.c:4253
+#: fortran/openmp.c:4252
 #, fuzzy, gcc-internal-format
 #| msgid "Cray pointee '%s' in SHARED clause at %L"
 msgid "Cray pointee %qs in SHARED clause at %L"
 msgstr "Cray pointee '%s' dalam SHARED clause di %L"
 
-#: fortran/openmp.c:4256
+#: fortran/openmp.c:4255
 #, fuzzy, gcc-internal-format
 #| msgid "THREADPRIVATE object '%s' in SHARED clause at %L"
 msgid "ASSOCIATE name %qs in SHARED clause at %L"
 msgstr "objek THREADPRIVATE '%s' dalam clause SHARED di %L"
 
-#: fortran/openmp.c:4271
+#: fortran/openmp.c:4270
 #, gcc-internal-format
 msgid "%qs in ALIGNED clause must be POINTER, ALLOCATABLE, Cray pointer or C_PTR at %L"
 msgstr ""
 
-#: fortran/openmp.c:4283
+#: fortran/openmp.c:4282
 #, fuzzy, gcc-internal-format
 #| msgid "%Hcollapse argument needs positive constant integer expression"
 msgid "%qs in ALIGNED clause at %L requires a scalar positive constant integer alignment expression"
 msgstr "%Hkolaps argumen membutuhkan konstanta positif integer ekspresi"
 
-#: fortran/openmp.c:4302
+#: fortran/openmp.c:4301
 #, gcc-internal-format, gfc-internal-format
 msgid "SINK dependence type only allowed on ORDERED directive at %L"
 msgstr ""
 
-#: fortran/openmp.c:4306
+#: fortran/openmp.c:4305
 #, gcc-internal-format, gfc-internal-format
 msgid "DEPEND SINK used together with DEPEND SOURCE on the same construct at %L"
 msgstr ""
 
-#: fortran/openmp.c:4316
+#: fortran/openmp.c:4315
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "accumulator is not a constant integer"
 msgid "SINK addend not a constant integer at %L"
 msgstr "akumulator bukan sebuah konstanta integer"
 
-#: fortran/openmp.c:4322
+#: fortran/openmp.c:4321
 #, gcc-internal-format, gfc-internal-format
 msgid "Only SOURCE or SINK dependence types are allowed on ORDERED directive at %L"
 msgstr ""
 
-#: fortran/openmp.c:4333 fortran/openmp.c:4354
+#: fortran/openmp.c:4332 fortran/openmp.c:4353
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' in %s statement at %C is not a loop name"
 msgid "%qs in %s clause at %L is not a proper array section"
 msgstr "Nama '%s' dalam pernyataan %s di %C bukan sebuah nama loop"
 
-#: fortran/openmp.c:4337
+#: fortran/openmp.c:4336
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Cray pointee '%s' in %s clause at %L"
 msgid "Coarrays not supported in %s clause at %L"
 msgstr "Cray pointee '%s' dalam %s clause di %L"
 
-#: fortran/openmp.c:4346
+#: fortran/openmp.c:4345
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed size array '%s' in %s clause at %L"
 msgid "Stride should not be specified for array section in %s clause at %L"
 msgstr "Ukuran array yang diasumsikan '%s' dalam %s clause di %L"
 
-#: fortran/openmp.c:4367
+#: fortran/openmp.c:4366
 #, gcc-internal-format
 msgid "%qs in DEPEND clause at %L is a zero size array section"
 msgstr ""
 
-#: fortran/openmp.c:4403
+#: fortran/openmp.c:4402
 #, gcc-internal-format, gfc-internal-format
 msgid "TARGET%s with map-type other than TO, FROM, TOFROM, or ALLOC on MAP clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4419
+#: fortran/openmp.c:4418
 #, gcc-internal-format, gfc-internal-format
 msgid "TARGET ENTER DATA with map-type other than TO, or ALLOC on MAP clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4434
+#: fortran/openmp.c:4433
 #, gcc-internal-format, gfc-internal-format
 msgid "TARGET EXIT DATA with map-type other than FROM, RELEASE, or DELETE on MAP clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4450 fortran/openmp.c:4466
+#: fortran/openmp.c:4449 fortran/openmp.c:4465
 #, fuzzy, gcc-internal-format
 #| msgid "THREADPRIVATE object '%s' in %s clause at %L"
 msgid "THREADPRIVATE object %qs in %s clause at %L"
 msgstr "THREADPRIVATE objek '%s' dalam clause %s di %L"
 
-#: fortran/openmp.c:4453 fortran/openmp.c:4469
+#: fortran/openmp.c:4452 fortran/openmp.c:4468
 #, fuzzy, gcc-internal-format
 #| msgid "Cray pointee '%s' in %s clause at %L"
 msgid "Cray pointee %qs in %s clause at %L"
 msgstr "Cray pointee '%s' dalam %s clause di %L"
 
-#: fortran/openmp.c:4472
+#: fortran/openmp.c:4471
 #, fuzzy, gcc-internal-format
 #| msgid "POINTER object '%s' in %s clause at %L"
 msgid "ASSOCIATE name %qs in %s clause at %L"
 msgstr "objek PENUNJUK '%s' dalam %s clause di %L"
 
-#: fortran/openmp.c:4477
+#: fortran/openmp.c:4476
 #, fuzzy, gcc-internal-format
 #| msgid "Cray pointer '%s' in %s clause at %L"
 msgid "Procedure pointer %qs in %s clause at %L"
 msgstr "Cray penunjuk '%s' dalam clause %s di %L"
 
-#: fortran/openmp.c:4483
+#: fortran/openmp.c:4482
 #, fuzzy, gcc-internal-format
 #| msgid "Cray pointer '%s' in %s clause at %L"
 msgid "Cray pointer %qs in %s clause at %L"
 msgstr "Cray penunjuk '%s' dalam clause %s di %L"
 
-#: fortran/openmp.c:4493
+#: fortran/openmp.c:4492
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' in %s clause is used in NAMELIST statement at %L"
 msgid "Variable %qs in %s clause is used in NAMELIST statement at %L"
@@ -64456,418 +64539,418 @@
 msgstr "Variabel '%s' dalam clause %s digunakan dalam pernyataan NAMELIST di %L"
 
 #. case OMP_LIST_REDUCTION:
-#: fortran/openmp.c:4503
+#: fortran/openmp.c:4502
 #, fuzzy, gcc-internal-format
 #| msgid "POINTER object '%s' in %s clause at %L"
 msgid "INTENT(IN) POINTER %qs in %s clause at %L"
 msgstr "objek PENUNJUK '%s' dalam %s clause di %L"
 
-#: fortran/openmp.c:4596
+#: fortran/openmp.c:4595
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP DECLARE REDUCTION %s not found for type %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:4622
+#: fortran/openmp.c:4621
 #, gcc-internal-format, gfc-internal-format
 msgid "LINEAR clause modifier used on DO or SIMD construct at %L"
 msgstr ""
 
-#: fortran/openmp.c:4627
+#: fortran/openmp.c:4626
 #, gcc-internal-format, gfc-internal-format
 msgid "LINEAR clause specified together with ORDERED clause with argument at %L"
 msgstr ""
 
-#: fortran/openmp.c:4632
+#: fortran/openmp.c:4631
 #, fuzzy, gcc-internal-format
 #| msgid "%s REDUCTION variable '%s' must be INTEGER at %L"
 msgid "LINEAR variable %qs must be INTEGER at %L"
 msgstr "%s REDUKSI variabel '%s' harus berupa INTEGER di %L"
 
-#: fortran/openmp.c:4637
+#: fortran/openmp.c:4636
 #, gcc-internal-format
 msgid "LINEAR dummy argument %qs with VALUE attribute with %s modifier at %L"
 msgstr ""
 
-#: fortran/openmp.c:4648
+#: fortran/openmp.c:4647
 #, fuzzy, gcc-internal-format
 #| msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgid "%qs in LINEAR clause at %L requires a scalar integer linear-step expression"
 msgstr "IF clause di %L membutuhkan sebuah ekspresi skalara LOGIKAL"
 
-#: fortran/openmp.c:4665
+#: fortran/openmp.c:4664
 #, gcc-internal-format
 msgid "%qs in LINEAR clause at %L requires a constant integer linear-step expression or dummy argument specified in UNIFORM clause"
 msgstr ""
 
-#: fortran/openmp.c:4699
+#: fortran/openmp.c:4698
 #, gcc-internal-format
 msgid "%s clause variable %qs at %L is neither a POINTER nor an array"
 msgstr ""
 
-#: fortran/openmp.c:4731
+#: fortran/openmp.c:4730
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "SCHEDULE clause's chunk_size at %L requires a scalar INTEGER expression"
 msgid "DIST_SCHEDULE clause's chunk_size at %L requires a scalar INTEGER expression"
 msgstr "SCHEDULE clause chunk_size di %L membutuhkan sebuah ekspresi skalar INTEGER"
 
-#: fortran/openmp.c:4763
+#: fortran/openmp.c:4762
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Incompatible ranks in %s (%d and %d) at %L"
 msgid "Incompatible use of TILE and COLLAPSE at %L"
 msgstr "Tingkat tidak kompatibel dalam %s (%d dan %d) di %L"
 
-#: fortran/openmp.c:4765
+#: fortran/openmp.c:4764
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE dependence type only allowed on ORDERED directive at %L"
 msgstr ""
 
-#: fortran/openmp.c:4778
+#: fortran/openmp.c:4777
 #, gcc-internal-format, gfc-internal-format
 msgid "%s must contain at least one MAP clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4875
+#: fortran/openmp.c:4874
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected exponent in expression at %C"
 msgid "unexpected !$OMP ATOMIC expression at %L"
 msgstr "Diduga eksponen dalam ekspresi di %C"
 
-#: fortran/openmp.c:4904
+#: fortran/openmp.c:4903
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC statement must set a scalar variable of intrinsic type at %L"
 msgstr "!$OMP ATOMIC pernyataan harus diset ke sebuah variabel skalar dari tipe intrinsik di %L"
 
-#: fortran/openmp.c:4929
+#: fortran/openmp.c:4928
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "!$OMP ATOMIC statement must set a scalar variable of intrinsic type at %L"
 msgid "!$OMP ATOMIC READ statement must read from a scalar variable of intrinsic type at %L"
 msgstr "!$OMP ATOMIC pernyataan harus diset ke sebuah variabel skalar dari tipe intrinsik di %L"
 
-#: fortran/openmp.c:4934
+#: fortran/openmp.c:4933
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "expr in !$OMP ATOMIC assignment var = var op expr must be scalar and cannot reference var at %L"
 msgid "expr in !$OMP ATOMIC WRITE assignment var = expr must be scalar and cannot reference var at %L"
 msgstr "expr dalam !$OMP ATOMIC assignment var = var op expr harus berupa skalar dan tidak dapat bereferensi var di %L"
 
-#: fortran/openmp.c:4956 fortran/openmp.c:5247
+#: fortran/openmp.c:4955 fortran/openmp.c:5246
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "!$OMP ATOMIC statement must set a scalar variable of intrinsic type at %L"
 msgid "!$OMP ATOMIC CAPTURE capture statement must read from a scalar variable of intrinsic type at %L"
 msgstr "!$OMP ATOMIC pernyataan harus diset ke sebuah variabel skalar dari tipe intrinsik di %L"
 
-#: fortran/openmp.c:4971
+#: fortran/openmp.c:4970
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "!$OMP ATOMIC statement must set a scalar variable of intrinsic type at %L"
 msgid "!$OMP ATOMIC CAPTURE update statement must set a scalar variable of intrinsic type at %L"
 msgstr "!$OMP ATOMIC pernyataan harus diset ke sebuah variabel skalar dari tipe intrinsik di %L"
 
-#: fortran/openmp.c:4978 fortran/openmp.c:5254
+#: fortran/openmp.c:4977 fortran/openmp.c:5253
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE capture statement reads from different variable than update statement writes into at %L"
 msgstr ""
 
-#: fortran/openmp.c:4994
+#: fortran/openmp.c:4993
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC with ALLOCATABLE variable at %L"
 msgstr ""
 
-#: fortran/openmp.c:5036
+#: fortran/openmp.c:5035
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "!$OMP ATOMIC assignment operator must be +, *, -, /, .AND., .OR., .EQV. or .NEQV. at %L"
 msgid "!$OMP ATOMIC assignment operator must be binary +, *, -, /, .AND., .OR., .EQV. or .NEQV. at %L"
 msgstr "!$OMP ATOMIC assignmen operator harus berupa +, *, -, /, .AND., .OR., .EQV. atau .NEQV. di %L"
 
-#: fortran/openmp.c:5084
+#: fortran/openmp.c:5083
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment must be var = var op expr or var = expr op var at %L"
 msgstr "!$OMP ATOMIC assignmen harus berupa var = var op expr atau var = expr op var di %L"
 
-#: fortran/openmp.c:5098
+#: fortran/openmp.c:5097
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC var = var op expr not mathematically equivalent to var = var op (expr) at %L"
 msgstr "!$OMP ATOMIC var = var op expr tidak seacra matematik sama ekuivalen ke var = var op (expr) di %L"
 
-#: fortran/openmp.c:5130
+#: fortran/openmp.c:5129
 #, gcc-internal-format, gfc-internal-format
 msgid "expr in !$OMP ATOMIC assignment var = var op expr must be scalar and cannot reference var at %L"
 msgstr "expr dalam !$OMP ATOMIC assignment var = var op expr harus berupa skalar dan tidak dapat bereferensi var di %L"
 
-#: fortran/openmp.c:5154
+#: fortran/openmp.c:5153
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment intrinsic IAND, IOR or IEOR must have two arguments at %L"
 msgstr "!$OMP ATOMIC assignmen intrinsik IAND, IOR, atau IEOR harus memiliki dua argumen di %L"
 
-#: fortran/openmp.c:5161
+#: fortran/openmp.c:5160
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment intrinsic must be MIN, MAX, IAND, IOR or IEOR at %L"
 msgstr "!$OMP ATOMIC assignmen intrinsik harus berupa MIN, MAX, IAND, IOR atau IEOR di %L"
 
-#: fortran/openmp.c:5178
+#: fortran/openmp.c:5177
 #, fuzzy, gcc-internal-format
 #| msgid "!$OMP ATOMIC intrinsic arguments except one must not reference '%s' at %L"
 msgid "!$OMP ATOMIC intrinsic arguments except one must not reference %qs at %L"
 msgstr "!$OMP ATOMIC intrinsik argumen kecuali satu tidak boleh mereferensi '%s' di %L"
 
-#: fortran/openmp.c:5185
+#: fortran/openmp.c:5184
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC intrinsic arguments must be scalar at %L"
 msgstr "!$OMP ATOMIC intrinsik argumen harus berupa skalar di %L"
 
-#: fortran/openmp.c:5193
+#: fortran/openmp.c:5192
 #, fuzzy, gcc-internal-format
 #| msgid "First or last !$OMP ATOMIC intrinsic argument must be '%s' at %L"
 msgid "First or last !$OMP ATOMIC intrinsic argument must be %qs at %L"
 msgstr "Pertama atau terakhir !$OMP ATOMIC intrinsik argumen harus berupa '%s' di %L"
 
-#: fortran/openmp.c:5211
+#: fortran/openmp.c:5210
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment must have an operator or intrinsic on right hand side at %L"
 msgstr "!$OMP ATOMIC assignmen harus memiliki sebuah operator atau instrinsik di tangan sebelah kanan di %L"
 
-#: fortran/openmp.c:5225
+#: fortran/openmp.c:5224
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "!$OMP ATOMIC statement must set a scalar variable of intrinsic type at %L"
 msgid "!$OMP ATOMIC CAPTURE capture statement must set a scalar variable of intrinsic type at %L"
 msgstr "!$OMP ATOMIC pernyataan harus diset ke sebuah variabel skalar dari tipe intrinsik di %L"
 
-#: fortran/openmp.c:5544
+#: fortran/openmp.c:5543
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "!$OMP DO cannot be a DO WHILE or DO without loop control at %L"
 msgid "%s cannot be a DO WHILE or DO without loop control at %L"
 msgstr "!$OMP DO tidak dapat berupa sebuah DO WHILE atau DO tanpa pengontrol loop di %L"
 
-#: fortran/openmp.c:5550
+#: fortran/openmp.c:5549
 #, gcc-internal-format, gfc-internal-format
 msgid "%s cannot be a DO CONCURRENT loop at %L"
 msgstr ""
 
-#: fortran/openmp.c:5556
+#: fortran/openmp.c:5555
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "!$OMP DO iteration variable must be of type integer at %L"
 msgid "%s iteration variable must be of type integer at %L"
 msgstr "!$OMP DO variabel iterasi harus berupa tipe integer di %L"
 
-#: fortran/openmp.c:5560
+#: fortran/openmp.c:5559
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "!$OMP DO iteration variable must not be THREADPRIVATE at %L"
 msgid "%s iteration variable must not be THREADPRIVATE at %L"
 msgstr "!$OMP DO variabel iterasi tidak boleh berupa THREADPRIVATE di %L"
 
-#: fortran/openmp.c:5573
+#: fortran/openmp.c:5572
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "!$OMP DO iteration variable present on clause other than PRIVATE or LASTPRIVATE at %L"
 msgid "%s iteration variable present on clause other than PRIVATE or LASTPRIVATE at %L"
 msgstr "!$OMP DO variabel iterasi ada dalam clause selain dari PRIVATE atau LASTPRIVATE di %L"
 
-#: fortran/openmp.c:5577
+#: fortran/openmp.c:5576
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "!$OMP DO iteration variable present on clause other than PRIVATE or LASTPRIVATE at %L"
 msgid "%s iteration variable present on clause other than LASTPRIVATE at %L"
 msgstr "!$OMP DO variabel iterasi ada dalam clause selain dari PRIVATE atau LASTPRIVATE di %L"
 
-#: fortran/openmp.c:5581
+#: fortran/openmp.c:5580
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "!$OMP DO iteration variable present on clause other than PRIVATE or LASTPRIVATE at %L"
 msgid "%s iteration variable present on clause other than LINEAR at %L"
 msgstr "!$OMP DO variabel iterasi ada dalam clause selain dari PRIVATE atau LASTPRIVATE di %L"
 
-#: fortran/openmp.c:5599
+#: fortran/openmp.c:5598
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "!$OMP DO collapsed loops don't form rectangular iteration space at %L"
 msgid "%s collapsed loops don't form rectangular iteration space at %L"
 msgstr "!$OMP DO collapsed loops tidak membentuk iterasi ruang rectangular di %L"
 
-#: fortran/openmp.c:5611
+#: fortran/openmp.c:5610
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "collapsed !$OMP DO loops not perfectly nested at %L"
 msgid "collapsed %s loops not perfectly nested at %L"
 msgstr "kolaps !$OMP DO loops tidak secara sempurna nested di %L"
 
-#: fortran/openmp.c:5620 fortran/openmp.c:5628
+#: fortran/openmp.c:5619 fortran/openmp.c:5627
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "not enough DO loops for collapsed !$OMP DO at %L"
 msgid "not enough DO loops for collapsed %s at %L"
 msgstr "tidak cukup DO loops untuk kolaps !$OMP DO di %L"
 
-#: fortran/openmp.c:5712 fortran/openmp.c:5725
+#: fortran/openmp.c:5711 fortran/openmp.c:5724
 #, gcc-internal-format, gfc-internal-format
 msgid "The %s directive cannot be specified within a %s region at %L"
 msgstr ""
 
-#: fortran/openmp.c:5744
+#: fortran/openmp.c:5743
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "!$OMP DO cannot be a DO WHILE or DO without loop control at %L"
 msgid "!$ACC LOOP cannot be a DO WHILE or DO without loop control at %L"
 msgstr "!$OMP DO tidak dapat berupa sebuah DO WHILE atau DO tanpa pengontrol loop di %L"
 
-#: fortran/openmp.c:5750
+#: fortran/openmp.c:5749
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "!$OMP DO iteration variable must be of type integer at %L"
 msgid "!$ACC LOOP iteration variable must be of type integer at %L"
 msgstr "!$OMP DO variabel iterasi harus berupa tipe integer di %L"
 
-#: fortran/openmp.c:5766
+#: fortran/openmp.c:5765
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "!$OMP DO collapsed loops don't form rectangular iteration space at %L"
 msgid "!$ACC LOOP %s loops don't form rectangular iteration space at %L"
 msgstr "!$OMP DO collapsed loops tidak membentuk iterasi ruang rectangular di %L"
 
-#: fortran/openmp.c:5778
+#: fortran/openmp.c:5777
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "collapsed !$OMP DO loops not perfectly nested at %L"
 msgid "%s !$ACC LOOP loops not perfectly nested at %L"
 msgstr "kolaps !$OMP DO loops tidak secara sempurna nested di %L"
 
-#: fortran/openmp.c:5788 fortran/openmp.c:5797
+#: fortran/openmp.c:5787 fortran/openmp.c:5796
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "not enough DO loops for collapsed !$OMP DO at %L"
 msgid "not enough DO loops for %s !$ACC LOOP at %L"
 msgstr "tidak cukup DO loops untuk kolaps !$OMP DO di %L"
 
-#: fortran/openmp.c:5812 fortran/openmp.c:5819
+#: fortran/openmp.c:5811 fortran/openmp.c:5818
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s in PARALLEL region doesn't allow %s arguments at %L"
 msgstr ""
 
-#: fortran/openmp.c:5841
+#: fortran/openmp.c:5840
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside another loop parallelized across gangs at %L"
 msgstr ""
 
-#: fortran/openmp.c:5845 fortran/openmp.c:5849
+#: fortran/openmp.c:5844 fortran/openmp.c:5848
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside loop parallelized across workers at %L"
 msgstr ""
 
-#: fortran/openmp.c:5856
+#: fortran/openmp.c:5855
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across workers at %L"
 msgstr ""
 
-#: fortran/openmp.c:5860
+#: fortran/openmp.c:5859
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across vectors at %L"
 msgstr ""
 
-#: fortran/openmp.c:5866
+#: fortran/openmp.c:5865
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across vectors is not allowed inside another loop parallelized across vectors at %L"
 msgstr ""
 
-#: fortran/openmp.c:5878
+#: fortran/openmp.c:5877
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgid "Clause SEQ conflicts with INDEPENDENT at %L"
 msgstr "INTENT (%s) konfliks dengan INTENT(%s) di %L"
 
-#: fortran/openmp.c:5880
+#: fortran/openmp.c:5879
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "Clause SEQ conflicts with GANG at %L"
 msgstr "%s atribut konflik dengan %s atribut di %L"
 
-#: fortran/openmp.c:5882
+#: fortran/openmp.c:5881
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with WORKER at %L"
 msgstr ""
 
-#: fortran/openmp.c:5884
+#: fortran/openmp.c:5883
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgid "Clause SEQ conflicts with VECTOR at %L"
 msgstr "INTENT (%s) konfliks dengan INTENT(%s) di %L"
 
-#: fortran/openmp.c:5886
+#: fortran/openmp.c:5885
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "Clause SEQ conflicts with AUTO at %L"
 msgstr "%s atribut konflik dengan %s atribut di %L"
 
-#: fortran/openmp.c:5891
+#: fortran/openmp.c:5890
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "Clause AUTO conflicts with GANG at %L"
 msgstr "%s atribut konflik dengan %s atribut di %L"
 
-#: fortran/openmp.c:5893
+#: fortran/openmp.c:5892
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with WORKER at %L"
 msgstr ""
 
-#: fortran/openmp.c:5895
+#: fortran/openmp.c:5894
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgid "Clause AUTO conflicts with VECTOR at %L"
 msgstr "INTENT (%s) konfliks dengan INTENT(%s) di %L"
 
-#: fortran/openmp.c:5899
+#: fortran/openmp.c:5898
 #, gcc-internal-format, gfc-internal-format
 msgid "Tiled loop cannot be parallelized across gangs, workers and vectors at the same time at %L"
 msgstr ""
 
-#: fortran/openmp.c:5934
+#: fortran/openmp.c:5933
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "LOGICAL operands are required in expression at %L"
 msgid "TILE requires constant expression at %L"
 msgstr "operan LOGICAL dibutuhkan dalam ekspresi di %L"
 
-#: fortran/openmp.c:5999
+#: fortran/openmp.c:6004
 #, fuzzy, gcc-internal-format
 #| msgid "POINTER object '%s' in %s clause at %L"
 msgid "PARAMETER object %qs is not allowed at %L"
 msgstr "objek PENUNJUK '%s' dalam %s clause di %L"
 
-#: fortran/openmp.c:6006
+#: fortran/openmp.c:6011
 #, gcc-internal-format
 msgid "Array sections: %qs not allowed in !$ACC DECLARE at %L"
 msgstr ""
 
-#: fortran/openmp.c:6133
+#: fortran/openmp.c:6138
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP TARGET UPDATE at %L requires at least one TO or FROM clause"
 msgstr ""
 
-#: fortran/openmp.c:6155
+#: fortran/openmp.c:6160
 #, gcc-internal-format
 msgid "!$OMP DECLARE SIMD should refer to containing procedure %qs at %L"
 msgstr ""
 
-#: fortran/openmp.c:6179
+#: fortran/openmp.c:6184
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_PRIV or OMP_ORIG used in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6187
+#: fortran/openmp.c:6192
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_OUT or OMP_IN used in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6216
+#: fortran/openmp.c:6221
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid operator for !$OMP DECLARE REDUCTION %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:6238
+#: fortran/openmp.c:6243
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER length in !$OMP DECLARE REDUCTION %s not constant at %L"
 msgstr ""
 
-#: fortran/openmp.c:6254
+#: fortran/openmp.c:6259
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6269
+#: fortran/openmp.c:6274
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6279
+#: fortran/openmp.c:6284
 #, gcc-internal-format, gfc-internal-format
 msgid "One of actual subroutine arguments in INITIALIZER clause of !$OMP DECLARE REDUCTION must be OMP_PRIV at %L"
 msgstr ""
 
-#: fortran/openmp.c:6287
+#: fortran/openmp.c:6292
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing INITIALIZER clause for !$OMP DECLARE REDUCTION of derived type without default initializer at %L"
 msgstr ""
@@ -64994,533 +65077,533 @@
 msgid "Unclassifiable statement at %C"
 msgstr "Pernyataan tidak terklasifikasi di %C"
 
-#: fortran/parse.c:629
+#: fortran/parse.c:631
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "OpenMP directives at %C may not appear in PURE or ELEMENTAL procedures"
 msgid "OpenACC directives at %C may not appear in PURE procedures"
 msgstr "Direktif OpenMP di %C tidak boleh muncul dalam prosedur PURE atau ELEMENTAL"
 
-#: fortran/parse.c:705
+#: fortran/parse.c:707
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unclassifiable OpenMP directive at %C"
 msgid "Unclassifiable OpenACC directive at %C"
 msgstr "Direktif OpenMP tidak terklasifikasi di %C"
 
-#: fortran/parse.c:831 fortran/parse.c:1040
+#: fortran/parse.c:835 fortran/parse.c:1044
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "OpenMP directives at %C may not appear in PURE or ELEMENTAL procedures"
 msgid "OpenMP directives other than SIMD or DECLARE TARGET at %C may not appear in PURE or ELEMENTAL procedures"
 msgstr "Direktif OpenMP di %C tidak boleh muncul dalam prosedur PURE atau ELEMENTAL"
 
-#: fortran/parse.c:1024
+#: fortran/parse.c:1028
 #, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable OpenMP directive at %C"
 msgstr "Direktif OpenMP tidak terklasifikasi di %C"
 
-#: fortran/parse.c:1076
+#: fortran/parse.c:1080
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unclassifiable OpenMP directive at %C"
 msgid "Unclassifiable GCC directive at %C"
 msgstr "Direktif OpenMP tidak terklasifikasi di %C"
 
-#: fortran/parse.c:1135 fortran/parse.c:1362
+#: fortran/parse.c:1139 fortran/parse.c:1366
 #, gcc-internal-format, gfc-internal-format
 msgid "Zero is not a valid statement label at %C"
 msgstr "Nol adalah bukan pernyataan label yang valid di %C"
 
-#: fortran/parse.c:1142 fortran/parse.c:1354
+#: fortran/parse.c:1146 fortran/parse.c:1358
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-numeric character in statement label at %C"
 msgstr "Karakter tidak-numerik dalam label pernyataan di %C"
 
-#: fortran/parse.c:1154 fortran/parse.c:1403
+#: fortran/parse.c:1158 fortran/parse.c:1407
 #, gcc-internal-format, gfc-internal-format
 msgid "Semicolon at %C needs to be preceded by statement"
 msgstr "Semikolon di %C melebihi pernyatan yang mengawalinya"
 
-#: fortran/parse.c:1161 fortran/parse.c:1418
+#: fortran/parse.c:1165 fortran/parse.c:1422
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Ignoring statement label in empty statement at %C"
 msgid "Statement label without statement at %L"
 msgstr "mengabaikan label pernyataan dalam pernyataan kosong di %C"
 
-#: fortran/parse.c:1224 fortran/parse.c:1405
+#: fortran/parse.c:1228 fortran/parse.c:1409
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Semicolon at %C needs to be preceded by statement"
 msgid "Fortran 2008: Semicolon at %C without preceding statement"
 msgstr "Semikolon di %C melebihi pernyatan yang mengawalinya"
 
-#: fortran/parse.c:1247 fortran/parse.c:1381
+#: fortran/parse.c:1251 fortran/parse.c:1385
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad continuation line at %C"
 msgstr "Baris kelanjutan buruk di %C"
 
-#: fortran/parse.c:1679
+#: fortran/parse.c:1683
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT statement at %L does not have a statement label"
 msgstr "pernyataan FORMAT di %L tidak memiliki sebuah label pernyataan"
 
-#: fortran/parse.c:2435
+#: fortran/parse.c:2439
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_ascii_statement(): Bad statement code"
 msgstr "gfc_trans_code(): Pernyataan kode buruk"
 
-#: fortran/parse.c:2577
+#: fortran/parse.c:2581
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement at %C"
 msgstr "Tidak terduga pernyataan %s di %C"
 
-#: fortran/parse.c:2732
+#: fortran/parse.c:2736
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot follow %s statement at %L"
 msgstr "pernyataan %s di %C tidak dapat mengikuti pernyataan %s di %L"
 
-#: fortran/parse.c:2749
+#: fortran/parse.c:2753
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of file in '%s'"
 msgid "Unexpected end of file in %qs"
 msgstr "Tidak terduga akhir dari berkas dalam '%s'"
 
-#: fortran/parse.c:2784
+#: fortran/parse.c:2788
 #, fuzzy, gcc-internal-format
 #| msgid "Derived-type '%s' with SEQUENCE must not have a CONTAINS section at %C"
 msgid "Derived-type %qs with SEQUENCE must not have a CONTAINS section at %C"
 msgstr "Tipe-turunan '%s' dengan SEQUENCE harus tidak memiliki sebuah bagian CONTAINS di %C"
 
-#: fortran/parse.c:2787
+#: fortran/parse.c:2791
 #, fuzzy, gcc-internal-format
 #| msgid "Derived-type '%s' with BIND(C) must not have a CONTAINS section at %C"
 msgid "Derived-type %qs with BIND(C) must not have a CONTAINS section at %C"
 msgstr "Tipe-turunan '%s' dengan BIND(C) harus tidak memiliki sebuah bagian CONTAINS di %C"
 
-#: fortran/parse.c:2807
+#: fortran/parse.c:2811
 #, gcc-internal-format, gfc-internal-format
 msgid "Components in TYPE at %C must precede CONTAINS"
 msgstr "Komponen dalam TYPE di %C harus mengawali CONTAINS"
 
-#: fortran/parse.c:2811
+#: fortran/parse.c:2815
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003:  Type-bound procedure at %C"
 msgid "Type-bound procedure at %C"
 msgstr "Fortran 2003:  Prosedur Tipe-bound di %C"
 
-#: fortran/parse.c:2819
+#: fortran/parse.c:2823
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Junk after GENERIC binding at %C"
 msgid "GENERIC binding at %C"
 msgstr "Sampah setelah binding GENERIC di %C"
 
-#: fortran/parse.c:2827
+#: fortran/parse.c:2831
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003:  FINAL procedure declaration at %C"
 msgid "FINAL procedure declaration at %C"
 msgstr "Fortran 2003:  Deklarasi prosedur FINAL di %C"
 
-#: fortran/parse.c:2839
+#: fortran/parse.c:2843
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: Derived type definition at %C with empty CONTAINS section"
 msgid "Derived type definition at %C with empty CONTAINS section"
 msgstr "Fortran 2008: Definisi tipe turunan di %C dengan daerah CONTAINS kosong"
 
-#: fortran/parse.c:2849 fortran/parse.c:3304
+#: fortran/parse.c:2853 fortran/parse.c:3308
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement in TYPE at %C must be inside a MODULE"
 msgstr "pernyataan PRIVATE dalam TYPE di %C harus berada didalam sebuah MODUL"
 
-#: fortran/parse.c:2856
+#: fortran/parse.c:2860
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede procedure bindings"
 msgstr "pernyataan PRIVATE di %C harus mengawali prosedur bindings"
 
-#: fortran/parse.c:2863 fortran/parse.c:3317
+#: fortran/parse.c:2867 fortran/parse.c:3321
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PRIVATE statement at %C"
 msgstr "Duplikasi pernyataan PRIVATE di %C"
 
-#: fortran/parse.c:2873
+#: fortran/parse.c:2877
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede CONTAINS"
 msgstr "pernyataan SEQUENCE di %C harus mengawali CONTAINS"
 
-#: fortran/parse.c:2877
+#: fortran/parse.c:2881
 #, gcc-internal-format, gfc-internal-format
 msgid "Already inside a CONTAINS block at %C"
 msgstr "Telah berada didalam sebuah blok CONTAINS di %C"
 
-#: fortran/parse.c:2996
+#: fortran/parse.c:3000
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s at %L of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray, which is not possible as the component has the pointer attribute"
 msgstr ""
 
-#: fortran/parse.c:3002
+#: fortran/parse.c:3006
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer component %s at %L has a noncoarray subcomponent of type LOCK_TYPE, which must have a codimension or be a subcomponent of a coarray"
 msgstr ""
 
-#: fortran/parse.c:3007
+#: fortran/parse.c:3011
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Allocatable component of structure at %C must have a deferred shape"
 msgid "Allocatable component %s at %L of type LOCK_TYPE must have a codimension"
 msgstr "Komponen dapat dialokasikan dari struktur di %C harus memiliki sebuah bentuk deffered"
 
-#: fortran/parse.c:3011
+#: fortran/parse.c:3015
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L must have a codimension as it has a noncoarray subcomponent of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/parse.c:3016
+#: fortran/parse.c:3020
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as already a coarray subcomponent exists)"
 msgstr ""
 
-#: fortran/parse.c:3023
+#: fortran/parse.c:3027
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as %s at %L has a codimension or a coarray subcomponent)"
 msgstr ""
 
-#: fortran/parse.c:3033
+#: fortran/parse.c:3037
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s at %L of type EVENT_TYPE must have a codimension or be a subcomponent of a coarray, which is not possible as the component has the pointer attribute"
 msgstr ""
 
-#: fortran/parse.c:3039
+#: fortran/parse.c:3043
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer component %s at %L has a noncoarray subcomponent of type EVENT_TYPE, which must have a codimension or be a subcomponent of a coarray"
 msgstr ""
 
-#: fortran/parse.c:3044
+#: fortran/parse.c:3048
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Allocatable component of structure at %C must have a deferred shape"
 msgid "Allocatable component %s at %L of type EVENT_TYPE must have a codimension"
 msgstr "Komponen dapat dialokasikan dari struktur di %C harus memiliki sebuah bentuk deffered"
 
-#: fortran/parse.c:3048
+#: fortran/parse.c:3052
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L must have a codimension as it has a noncoarray subcomponent of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/parse.c:3053
+#: fortran/parse.c:3057
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as already a coarray subcomponent exists)"
 msgstr ""
 
-#: fortran/parse.c:3060
+#: fortran/parse.c:3064
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as %s at %L has a codimension or a coarray subcomponent)"
 msgstr ""
 
-#: fortran/parse.c:3112
+#: fortran/parse.c:3116
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to create map component '%s'"
 msgstr ""
 
-#: fortran/parse.c:3145
+#: fortran/parse.c:3149
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "failed to find class '%s'"
 msgid "failed to create union component '%s'"
 msgstr "gagal untuk menemukan class '%s'"
 
-#: fortran/parse.c:3200
+#: fortran/parse.c:3204
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in data declaration at %C"
 msgid "Syntax error in nested structure declaration at %C"
 msgstr "Sintaks error dalam deklarasi data di %C"
 
-#: fortran/parse.c:3287
+#: fortran/parse.c:3291
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside CONTAINS"
 msgstr "deklarasi FINAL di %C harus berada didalam CONTAINS"
 
-#: fortran/parse.c:3295
+#: fortran/parse.c:3299
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: Derived type definition at %C without components"
 msgid "Derived type definition at %C without components"
 msgstr "Fortran 2003: Definisi tipe turunan di %C tanpa komponen"
 
-#: fortran/parse.c:3311
+#: fortran/parse.c:3315
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede structure components"
 msgstr "pernyataan PRIVATE di %C harus mengawali struktur komponen"
 
-#: fortran/parse.c:3328
+#: fortran/parse.c:3332
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede structure components"
 msgstr "pernyataan SEQUENCE di %C harus mengawali struktur komponen"
 
-#: fortran/parse.c:3334
+#: fortran/parse.c:3338
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE attribute at %C already specified in TYPE statement"
 msgstr "atribut SEQUENCE di %C telah dispesifikasikan dalam pernyataan TIPE"
 
-#: fortran/parse.c:3339
+#: fortran/parse.c:3343
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SEQUENCE statement at %C"
 msgstr "Duplikasi pernyataan SEQUENCE di %C"
 
-#: fortran/parse.c:3349
+#: fortran/parse.c:3353
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003:  CONTAINS block in derived type definition at %C"
 msgid "CONTAINS block in derived type definition at %C"
 msgstr "Fortran 2003: blok CONTAINS dalam definisi turunan di %C"
 
-#: fortran/parse.c:3407
+#: fortran/parse.c:3411
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM declaration at %C has no ENUMERATORS"
 msgstr "deklarasi ENUM di %C tidak memiliki ENUMERASI"
 
-#: fortran/parse.c:3494
+#: fortran/parse.c:3498
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in INTERFACE block at %C"
 msgstr "Tidak terduga pernyataan %s dalam ANTAR-MUKA blok di %C"
 
-#: fortran/parse.c:3518
+#: fortran/parse.c:3522
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' of ABSTRACT INTERFACE at %C cannot be the same as an intrinsic type"
 msgid "Name %qs of ABSTRACT INTERFACE at %C cannot be the same as an intrinsic type"
 msgstr "Nama '%s' dari ANTAR-MUKA ABSTRAK di %C tidak dapat sama dengan sebuah tipe intrinsik"
 
-#: fortran/parse.c:3552
+#: fortran/parse.c:3556
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement at %C in INTERFACE body"
 msgstr "Tidak terduga pernyataan %s di %C dalam tubuh ANTAR-MUKA"
 
-#: fortran/parse.c:3570
+#: fortran/parse.c:3574
 #, fuzzy, gcc-internal-format
 #| msgid "INTERFACE procedure '%s' at %L has the same name as the enclosing procedure"
 msgid "INTERFACE procedure %qs at %L has the same name as the enclosing procedure"
 msgstr "prosedur ANTAR-MUKA '%s' di %L memiliki nama sama dengan prosedur yang melingkupinya"
 
-#: fortran/parse.c:3700
+#: fortran/parse.c:3704
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement not allowed in PURE procedure at %C"
 msgid "%s statement is not allowed inside of BLOCK at %C"
 msgstr "pernyataan %s tidak diperbolehkan dalam prosedur PURE di %C"
 
-#: fortran/parse.c:3732
+#: fortran/parse.c:3736
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement not allowed in PURE procedure at %C"
 msgid "%s statement is not allowed inside of BLOCK DATA at %C"
 msgstr "pernyataan %s tidak diperbolehkan dalam prosedur PURE di %C"
 
-#: fortran/parse.c:3822
+#: fortran/parse.c:3826
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement must appear in a MODULE"
 msgstr "pernyataan %s harus muncul dalam sebuah MODUL"
 
-#: fortran/parse.c:3830
+#: fortran/parse.c:3834
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C follows another accessibility specification"
 msgstr "pernyataan %s di %C mengikuti spesifikasi aksesbiliti lain"
 
-#: fortran/parse.c:3882
+#: fortran/parse.c:3886
 #, fuzzy, gcc-internal-format
 #| msgid "Bad kind expression for function '%s' at %L"
 msgid "Bad kind expression for function %qs at %L"
 msgstr "Jenis ekspresi buruk untuk fungsi '%s' di %L"
 
-#: fortran/parse.c:3886
+#: fortran/parse.c:3890
 #, fuzzy, gcc-internal-format
 #| msgid "The type for function '%s' at %L is not accessible"
 msgid "The type for function %qs at %L is not accessible"
 msgstr "Tipe dari fungsi '%s' di %L tidak dapat diakses"
 
-#: fortran/parse.c:3946
+#: fortran/parse.c:3950
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C follows previous unmasked ELSEWHERE"
 msgstr "pernyataan ELSEWHERE di %C mengikuti tidak bertopen ELSEWHERE"
 
-#: fortran/parse.c:3968
+#: fortran/parse.c:3972
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in WHERE block at %C"
 msgstr "Tidak terduga pernyataan %s dalam blok WHERE di %C"
 
-#: fortran/parse.c:4027
+#: fortran/parse.c:4031
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in FORALL block at %C"
 msgstr "Tidak terduga pernyataan %s dalam blok FORALL di %C"
 
-#: fortran/parse.c:4078
+#: fortran/parse.c:4082
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSE IF statement at %C cannot follow ELSE statement at %L"
 msgstr "pernyataan ELSE IF di %C tidak dapat mengikuti pernyataan ELSE di %L"
 
-#: fortran/parse.c:4096
+#: fortran/parse.c:4100
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ELSE statements at %L and %C"
 msgstr "Duplikasi pernyataan ELSE di %L dan %C"
 
-#: fortran/parse.c:4157
+#: fortran/parse.c:4161
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected a CASE or END SELECT statement following SELECT CASE at %C"
 msgstr "Diduga sebuah pernyataan CASE atau END SELECT mengikuti SELECT CASE di %C"
 
-#: fortran/parse.c:4241
+#: fortran/parse.c:4245
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected a CASE or END SELECT statement following SELECT CASE at %C"
 msgid "Expected TYPE IS, CLASS IS or END SELECT statement following SELECT TYPE at %C"
 msgstr "Diduga sebuah pernyataan CASE atau END SELECT mengikuti SELECT CASE di %C"
 
-#: fortran/parse.c:4303
+#: fortran/parse.c:4307
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgid "Variable %qs at %C cannot be redefined inside loop beginning at %L"
 msgstr "Variabel '%s' di %C tidak dapat diredefinisi didalam loop berawal di %L"
 
-#: fortran/parse.c:4336
+#: fortran/parse.c:4340
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is within another block"
 msgstr "Akhir dari pernyataan bukan blok DO di %C adalah didalam blok lain"
 
-#: fortran/parse.c:4346
+#: fortran/parse.c:4350
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is interwoven with another DO loop"
 msgstr "Akhir dari pernyataan bukan blok DO di %C adalah interwoven dengan DO loop lainnya"
 
-#: fortran/parse.c:4372
+#: fortran/parse.c:4376
 #, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL block inside of OpenACC region at %C"
 msgstr ""
 
-#: fortran/parse.c:4373
+#: fortran/parse.c:4377
 #, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL block inside of OpenMP region at %C"
 msgstr ""
 
-#: fortran/parse.c:4399
+#: fortran/parse.c:4403
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Statement label in ENDDO at %C doesn't match DO label"
 msgid "Statement label in END CRITICAL at %C does not match CRITICAL label"
 msgstr "Pernyataan label dalam ENDDO di %C tidak cocok dengan label DO"
 
-#: fortran/parse.c:4468
+#: fortran/parse.c:4472
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Line truncated at %C"
 msgid "BLOCK construct at %C"
 msgstr "Baris terpotong di %C"
 
-#: fortran/parse.c:4502
+#: fortran/parse.c:4506
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSOCIATE construct at %C"
 msgstr ""
 
-#: fortran/parse.c:4690
+#: fortran/parse.c:4694
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label in ENDDO at %C doesn't match DO label"
 msgstr "Pernyataan label dalam ENDDO di %C tidak cocok dengan label DO"
 
-#: fortran/parse.c:4706
+#: fortran/parse.c:4710
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "named block DO at %L requires matching ENDDO name"
 msgid "Named block DO at %L requires matching ENDDO name"
 msgstr "blok bernama DO di %L membutuhkan nama ENDDO yang sama"
 
-#: fortran/parse.c:4897
+#: fortran/parse.c:4901
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing !$OMP END ATOMIC after !$OMP ATOMIC CAPTURE at %C"
 msgstr ""
 
-#: fortran/parse.c:4913 fortran/parse.c:4972
+#: fortran/parse.c:4917 fortran/parse.c:4976
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Already inside a CONTAINS block at %C"
 msgid "OpenACC directive inside of CRITICAL block at %C"
 msgstr "Telah berada didalam sebuah blok CONTAINS di %C"
 
-#: fortran/parse.c:4947
+#: fortran/parse.c:4951
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting %s statement at %C"
 msgid "Expecting %s at %C"
 msgstr "Diduga pernyataan %s di %C"
 
-#: fortran/parse.c:4991
+#: fortran/parse.c:4995
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "Expected DO loop at %C"
 msgstr "Diduga '(' di %C"
 
-#: fortran/parse.c:5011
+#: fortran/parse.c:5015
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant !$ACC END LOOP at %C"
 msgstr ""
 
-#: fortran/parse.c:5225
+#: fortran/parse.c:5229
 #, gcc-internal-format, gfc-internal-format
 msgid "Name after !$omp critical and !$omp end critical does not match at %C"
 msgstr "Nama setelah !$omp kritis dan !$omp akhir kritis tidak cocok di %C"
 
-#: fortran/parse.c:5283
+#: fortran/parse.c:5287
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot terminate a non-block DO loop"
 msgstr "pernyataan %s di %C tidak dapat mengakhiri sebuah bukan blok DO loop"
 
-#: fortran/parse.c:5297
+#: fortran/parse.c:5301
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORMAT statement at %L does not have a statement label"
 msgid "DATA statement at %C after the first executable statement"
 msgstr "pernyataan FORMAT di %L tidak memiliki sebuah label pernyataan"
 
-#: fortran/parse.c:5423
+#: fortran/parse.c:5427
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive does not commence a loop at %C"
 msgstr ""
 
-#: fortran/parse.c:5538
+#: fortran/parse.c:5542
 #, fuzzy, gcc-internal-format
 #| msgid "Contained procedure '%s' at %C is already ambiguous"
 msgid "Contained procedure %qs at %C is already ambiguous"
 msgstr "Prosedur berisi '%s' di %C telah ambigu"
 
-#: fortran/parse.c:5595
+#: fortran/parse.c:5599
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in CONTAINS section at %C"
 msgstr "Tidak terduga pernyataan %s dalam daerah CONTAINS di %C"
 
-#: fortran/parse.c:5620
+#: fortran/parse.c:5624
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: CONTAINS statement without FUNCTION or SUBROUTINE statement at %C"
 msgid "CONTAINS statement without FUNCTION or SUBROUTINE statement at %L"
 msgstr "Fortran 2008: pernyataan CONTAINS tanpa pernyataan FUNCTION atau SUBROUTINE di %C"
 
-#: fortran/parse.c:5732
+#: fortran/parse.c:5736
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS statement at %C is already in a contained program unit"
 msgstr "pernyataan CONTAINS di %C telah berada dalam satuan aplikasi terisi"
 
-#: fortran/parse.c:5784
+#: fortran/parse.c:5788
 #, fuzzy, gcc-internal-format
 #| msgid "Global name '%s' at %L is already being used as a %s at %L"
 msgid "Global binding name %qs at %L is already being used as a %s at %L"
 msgstr "Nama global '%s' di %L telah digunakan sebuah sebuah %s di %L"
 
-#: fortran/parse.c:5788
+#: fortran/parse.c:5792
 #, fuzzy, gcc-internal-format
 #| msgid "Global name '%s' at %L is already being used as a %s at %L"
 msgid "Global name %qs at %L is already being used as a %s at %L"
 msgstr "Nama global '%s' di %L telah digunakan sebuah sebuah %s di %L"
 
-#: fortran/parse.c:5794
+#: fortran/parse.c:5798
 #, fuzzy, gcc-internal-format
 #| msgid "Global name '%s' at %L is already being used as a %s at %L"
 msgid "Global binding name %qs at %L is already being used at %L"
 msgstr "Nama global '%s' di %L telah digunakan sebuah sebuah %s di %L"
 
-#: fortran/parse.c:5797
+#: fortran/parse.c:5801
 #, fuzzy, gcc-internal-format
 #| msgid "Global name '%s' at %L is already being used as a %s at %L"
 msgid "Global name %qs at %L is already being used at %L"
 msgstr "Nama global '%s' di %L telah digunakan sebuah sebuah %s di %L"
 
-#: fortran/parse.c:5819
+#: fortran/parse.c:5823
 #, gcc-internal-format, gfc-internal-format
 msgid "Blank BLOCK DATA at %C conflicts with prior BLOCK DATA at %L"
 msgstr "BLOK DATA kosong di %C konflik dengan BLOK DATA sebelumnya di %L"
 
-#: fortran/parse.c:5845
+#: fortran/parse.c:5849
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in BLOCK DATA at %C"
 msgstr "Tidak terduga pernyataan %s dalam BLOK DATA di %C"
 
-#: fortran/parse.c:5949
+#: fortran/parse.c:5953
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in MODULE at %C"
 msgstr "Tidak terduga pernyataan %s dalam MODUL di %C"
@@ -65528,7 +65611,7 @@
 #. If we see a duplicate main program, shut down.  If the second
 #. instance is an implied main program, i.e. data decls or executable
 #. statements, we're in for lots of errors.
-#: fortran/parse.c:6333
+#: fortran/parse.c:6337
 #, gcc-internal-format, gfc-internal-format
 msgid "Two main PROGRAMs at %L and %C"
 msgstr "Dua APLIKASI utama di %L dan %C"
@@ -66368,7 +66451,7 @@
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr "Bukan prosedur REKURSIF '%s' di %L mungkin memanggil dirinya sendiri secara rekursif. Deklarasikan itu secara RECURSIVE atau gunakan -frecursive"
 
-#: fortran/resolve.c:1893 fortran/resolve.c:9560 fortran/resolve.c:11225
+#: fortran/resolve.c:1893 fortran/resolve.c:9573 fortran/resolve.c:11245
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "Label %d direferensikan di %L tidak pernah terdefinisi"
@@ -66494,7 +66577,7 @@
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "Fungsi '%s' di %L tidak memiliki tipe IMPLISIT"
 
-#: fortran/resolve.c:2905 fortran/resolve.c:16283
+#: fortran/resolve.c:2905 fortran/resolve.c:16310
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Function %qs at %L has no IMPLICIT type"
@@ -66635,205 +66718,205 @@
 msgid "logical_to_bitwise(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:4059
+#: fortran/resolve.c:4065
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:4229 fortran/resolve.c:4252
+#: fortran/resolve.c:4235 fortran/resolve.c:4258
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:4347
+#: fortran/resolve.c:4353
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Referensi array di %L diluar dari jangkauan (%ld < %ld) dalam dimensi %d"
 
-#: fortran/resolve.c:4352
+#: fortran/resolve.c:4358
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr "Referensi array di %L diluar dari jangkauan (%ld < %ld) dalam dimensi %d"
 
-#: fortran/resolve.c:4362
+#: fortran/resolve.c:4368
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Referensi array di %L diluar dari jangkauan (%ld > %ld) dalam dimensi %d"
 
-#: fortran/resolve.c:4367
+#: fortran/resolve.c:4373
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr "Referensi array di %L diluar dari jangkauan (%ld > %ld) dalam dimensi %d"
 
-#: fortran/resolve.c:4387
+#: fortran/resolve.c:4393
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr "Tidak legal stride dari nol di %L"
 
-#: fortran/resolve.c:4404
+#: fortran/resolve.c:4410
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Referensi array bawah di %L diluar dari jangkauan (%ld < %ld) dalam dimensi %d"
 
-#: fortran/resolve.c:4412
+#: fortran/resolve.c:4418
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Referensi array bawah di %L diluar dari jangkauan (%ld > %ld) dalam dimensi %d"
 
-#: fortran/resolve.c:4428
+#: fortran/resolve.c:4434
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Referensi array atas di %L diluar dari jangkauan (%ld < %ld) dalam dimensi %d"
 
-#: fortran/resolve.c:4437
+#: fortran/resolve.c:4443
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Referensi array atas di %L diluar dari jangkauan (%ld > %ld) dalam dimensi %d"
 
-#: fortran/resolve.c:4453
+#: fortran/resolve.c:4459
 #, fuzzy, gcc-internal-format
 #| msgid "subscript missing in array reference"
 msgid "check_dimension(): Bad array reference"
 msgstr "subscrip hilang dalam referensi array"
 
-#: fortran/resolve.c:4476
+#: fortran/resolve.c:4482
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr "Jangkauan paling kanan ats dari daerah ukuran array yang diasumsikan tidak dispesifikasikan di %L"
 
-#: fortran/resolve.c:4486
+#: fortran/resolve.c:4492
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr "Tingkat tidak cocok dalam referensi array di %L (%d/%d)"
 
-#: fortran/resolve.c:4494
+#: fortran/resolve.c:4500
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr "Tingkat tidak cocok dalam referensi array di %L (%d/%d)"
 
-#: fortran/resolve.c:4510
+#: fortran/resolve.c:4516
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "index in dimension %d is out of bounds at %L"
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr "indeks dalam dimensi %d diluar dari jangkauan di %L"
 
-#: fortran/resolve.c:4538
+#: fortran/resolve.c:4544
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr "Indeks array di %L harus berupa skalar"
 
-#: fortran/resolve.c:4544
+#: fortran/resolve.c:4550
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr "Indeks array di %L harus berupa tipe INTEGER, ditemukan %s"
 
-#: fortran/resolve.c:4550
+#: fortran/resolve.c:4556
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: REAL array index at %L"
 msgid "REAL array index at %L"
 msgstr "Ekstensi: indeks array RIL di %L"
 
-#: fortran/resolve.c:4589
+#: fortran/resolve.c:4595
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr "Argumen dim di %L harus berupa skalar"
 
-#: fortran/resolve.c:4596
+#: fortran/resolve.c:4602
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr "Argumen dim di %L harus berupa tipe INTEGER"
 
-#: fortran/resolve.c:4641
+#: fortran/resolve.c:4647
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr ""
 
-#: fortran/resolve.c:4652
+#: fortran/resolve.c:4658
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.c:4663
+#: fortran/resolve.c:4669
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.c:4706
+#: fortran/resolve.c:4712
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr "Indeks array di %L adalah sebuah array dari tingkat %d"
 
-#: fortran/resolve.c:4804
+#: fortran/resolve.c:4810
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr "Indeks awal substring di %L harus berupa tipe INTEGER"
 
-#: fortran/resolve.c:4811
+#: fortran/resolve.c:4817
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr "Indeks awal substring di %L harus berupa skalar"
 
-#: fortran/resolve.c:4820
+#: fortran/resolve.c:4826
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr "Indeks awal substring di %L lebih kecil dari satu"
 
-#: fortran/resolve.c:4833
+#: fortran/resolve.c:4839
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr "Indeks akhir substring di %L harus berupa tipe INTEGER"
 
-#: fortran/resolve.c:4840
+#: fortran/resolve.c:4846
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr "Indeks akhir substring di %L harus berupa skalar"
 
-#: fortran/resolve.c:4850
+#: fortran/resolve.c:4856
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr "Indeks akhir substring di %L melebihi panjang string"
 
-#: fortran/resolve.c:4860
+#: fortran/resolve.c:4866
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Substring end index at %L must be scalar"
 msgid "Substring end index at %L is too large"
 msgstr "Indeks akhir substring di %L harus berupa skalar"
 
-#: fortran/resolve.c:5013
+#: fortran/resolve.c:5019
 #, fuzzy, gcc-internal-format
 #| msgid "Bad array reference at %L"
 msgid "resolve_ref(): Bad array reference"
 msgstr "Referensi array buruk di %L"
 
-#: fortran/resolve.c:5027
+#: fortran/resolve.c:5033
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr "Komponen ke bagian kanan dari referensi dengan tingkat bukan-nol harus tidak memiliki atribut PENUNJUK di %L"
 
-#: fortran/resolve.c:5037
+#: fortran/resolve.c:5043
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr "Komponen ke bagian kanan dari referensi dengan tingkat bukan-nol harus tidak memiliki atribut DAPAT DIALOKASIKAN di %L"
 
-#: fortran/resolve.c:5056
+#: fortran/resolve.c:5062
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr "Dua atau lebih referensi bagian dengan tingkat bukan-nol tidak boleh dispesifikasikan di %L"
 
-#: fortran/resolve.c:5154
+#: fortran/resolve.c:5160
 #, gcc-internal-format
 msgid "expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.c:5236
+#: fortran/resolve.c:5242
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr ""
 
-#: fortran/resolve.c:5246
+#: fortran/resolve.c:5252
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
@@ -66843,12 +66926,12 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5256
+#: fortran/resolve.c:5262
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5271
+#: fortran/resolve.c:5277
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
@@ -66858,66 +66941,66 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5281
+#: fortran/resolve.c:5287
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5292
+#: fortran/resolve.c:5298
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5301
+#: fortran/resolve.c:5307
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Intrinsic subroutine '%s' at %L shall not have a type specifier"
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr "Intrinsik subroutine '%s' di %L tidak boleh memiliki sebuah penspesifikasi tipe"
 
-#: fortran/resolve.c:5316
+#: fortran/resolve.c:5322
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Intrinsic subroutine '%s' at %L shall not have a type specifier"
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr "Intrinsik subroutine '%s' di %L tidak boleh memiliki sebuah penspesifikasi tipe"
 
-#: fortran/resolve.c:5478
+#: fortran/resolve.c:5484
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s', used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr "Variabel '%s', digunakan dalam sebuah ekspresi spesifikasi, direferensikan di %L sebelum pernyataan MASUKAN dimana ini adalah sebuah parameter"
 
-#: fortran/resolve.c:5483
+#: fortran/resolve.c:5489
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' is used at %L before the ENTRY statement in which it is a parameter"
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr "Variabel '%s' digunakan di %L sebelum pernyataan MASUKAN dimana ini adalah sebuah parameter"
 
-#: fortran/resolve.c:5553
+#: fortran/resolve.c:5559
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.c:5566
+#: fortran/resolve.c:5572
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.c:5919
+#: fortran/resolve.c:5925
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "Objek yang dilewatkan di %L harus berupa skalar"
 
-#: fortran/resolve.c:5926
+#: fortran/resolve.c:5932
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5961
+#: fortran/resolve.c:5967
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5970
+#: fortran/resolve.c:5976
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument '%s' of elemental procedure at %L must be scalar"
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
@@ -66924,222 +67007,222 @@
 msgstr "Argumen '%s' dari prosedur elemental di %L harus berupa skalar"
 
 #. Nothing matching found!
-#: fortran/resolve.c:6158
+#: fortran/resolve.c:6164
 #, fuzzy, gcc-internal-format
 #| msgid "Found no matching specific binding for the call to the GENERIC '%s' at %L"
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr "Tidak ditemukan pengikatan spesifik yang cocok untuk panggilan ke GENERIC '%s' di %L"
 
-#: fortran/resolve.c:6185
+#: fortran/resolve.c:6191
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L should be a SUBROUTINE"
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "'%s' di %L seharusnya berupa sebuah SUBROUTINE"
 
-#: fortran/resolve.c:6236
+#: fortran/resolve.c:6242
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L should be a FUNCTION"
 msgid "%qs at %L should be a FUNCTION"
 msgstr "'%s' di %L seharusnya berupa sebuah FUNGSI"
 
-#: fortran/resolve.c:6786
+#: fortran/resolve.c:6792
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "Diduga tipe ekspresi"
 
-#: fortran/resolve.c:6812
+#: fortran/resolve.c:6818
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s di %L harus berupa sebuah skalar"
 
-#: fortran/resolve.c:6822
+#: fortran/resolve.c:6828
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Deleted feature: %s at %L must be integer"
 msgid "%s at %L must be integer"
 msgstr "Featur terhapus: %s di %L harus berupa integer"
 
-#: fortran/resolve.c:6826 fortran/resolve.c:6833
+#: fortran/resolve.c:6832 fortran/resolve.c:6839
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s di %L harus berupa INTEGER"
 
-#: fortran/resolve.c:6875
+#: fortran/resolve.c:6881
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "Ekspresi step dalam loop DO di %L tidak dapat berupa nol"
 
-#: fortran/resolve.c:6911
+#: fortran/resolve.c:6917
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.c:6928
+#: fortran/resolve.c:6934
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.c:6934
+#: fortran/resolve.c:6940
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.c:6995
+#: fortran/resolve.c:7001
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "FORALL nama-indeks di %L harus berupa sebuah skalar INTEGER"
 
-#: fortran/resolve.c:7000
+#: fortran/resolve.c:7006
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "FORALL awal ekspresi di %L harus berupa sebuah skalar INTEGER"
 
-#: fortran/resolve.c:7007
+#: fortran/resolve.c:7013
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "FORALL akhir ekspresi di %L harus berupa sebuah skalar INTEGER"
 
-#: fortran/resolve.c:7015
+#: fortran/resolve.c:7021
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "FORALL stride ekspresi di %L harus berupa sebuah skalar %s"
 
-#: fortran/resolve.c:7020
+#: fortran/resolve.c:7026
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "FORALL stride ekspresi di %L tidak dapat berupa nol"
 
-#: fortran/resolve.c:7033
+#: fortran/resolve.c:7039
 #, fuzzy, gcc-internal-format
 #| msgid "FORALL index '%s' may not appear in triplet specification at %L"
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "FORALL indeks '%s' mungkin tidak muncul dalam spesifikasi triplet di %L"
 
-#: fortran/resolve.c:7136 fortran/resolve.c:7428
+#: fortran/resolve.c:7142 fortran/resolve.c:7434
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in ALLOCATE statement at %L must be ALLOCATABLE or a POINTER"
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "Ekspresi dalam pernyataan ALOKASI di %L harus berupa DAPAT DIALOKASIKAN atau sebuah PENUNJUK"
 
-#: fortran/resolve.c:7144 fortran/resolve.c:7393
+#: fortran/resolve.c:7150 fortran/resolve.c:7399
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7250
+#: fortran/resolve.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7281
+#: fortran/resolve.c:7287
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.c:7439
+#: fortran/resolve.c:7445
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.c:7451
+#: fortran/resolve.c:7457
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.c:7465
+#: fortran/resolve.c:7471
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7480
+#: fortran/resolve.c:7486
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7493
+#: fortran/resolve.c:7499
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.c:7511
+#: fortran/resolve.c:7517
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.c:7592 fortran/resolve.c:7607
+#: fortran/resolve.c:7598 fortran/resolve.c:7613
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "Spesifikasi array dibutuhkan dalam pernyatan ALOKASI di %L"
 
-#: fortran/resolve.c:7599
+#: fortran/resolve.c:7605
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array specification required in ALLOCATE statement at %L"
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "Spesifikasi array dibutuhkan dalam pernyatan ALOKASI di %L"
 
-#: fortran/resolve.c:7622
+#: fortran/resolve.c:7628
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array specification required in ALLOCATE statement at %L"
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "Spesifikasi array dibutuhkan dalam pernyatan ALOKASI di %L"
 
-#: fortran/resolve.c:7649
+#: fortran/resolve.c:7655
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "Spesifikasi array buruk dalam pernyataan ALOKASI di %L"
 
-#: fortran/resolve.c:7668
+#: fortran/resolve.c:7674
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr "'%s' tidak boleh muncul dalam spesifikasi array di %L dalam pernyataan ALOKASI yang sama dimana ini sendiri dialokasikan"
 
-#: fortran/resolve.c:7683
+#: fortran/resolve.c:7689
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad array specification in ALLOCATE statement at %L"
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr "Spesifikasi array buruk dalam pernyataan ALOKASI di %L"
 
-#: fortran/resolve.c:7694
+#: fortran/resolve.c:7700
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad array specification in ALLOCATE statement at %L"
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "Spesifikasi array buruk dalam pernyataan ALOKASI di %L"
 
-#: fortran/resolve.c:7726
+#: fortran/resolve.c:7732
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "pernyataan ASSIGN di %L membutuhkan sebuah skalar baku variabel INTEGER"
 
-#: fortran/resolve.c:7749
+#: fortran/resolve.c:7755
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "Label di %L tidak dalam blok yang sama seperti pernyataan GOTO di %L"
 
-#: fortran/resolve.c:7760
+#: fortran/resolve.c:7766
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.c:7771
+#: fortran/resolve.c:7782
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "UNIT specification at %L must be an INTEGER expression or a CHARACTER variable"
-msgid "Errmsg-variable at %L must be a scalar CHARACTER variable"
-msgstr "spesifikasi SATUAN di %L harus berupa sebuah ekspresi INTEGER atau sebuah KARAKTER variabel"
+#| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
+msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
+msgstr "pernyataan ASSIGN di %L membutuhkan sebuah skalar baku variabel INTEGER"
 
-#: fortran/resolve.c:7794
+#: fortran/resolve.c:7805
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:7824
+#: fortran/resolve.c:7835
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.c:7830 fortran/resolve.c:7836
+#: fortran/resolve.c:7841 fortran/resolve.c:7847
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -67148,257 +67231,257 @@
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8064
+#: fortran/resolve.c:8075
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "CASE label di %L overlaps dengan CASE label di %L"
 
-#: fortran/resolve.c:8115
+#: fortran/resolve.c:8126
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "Ekspresi dalam pernyataan CASE di %L harus berupa tipe %s"
 
-#: fortran/resolve.c:8126
+#: fortran/resolve.c:8137
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "Ekspresi dalam pernyataan CASE di %L harus berupa tipe %d"
 
-#: fortran/resolve.c:8139
+#: fortran/resolve.c:8150
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "Ekspresi dalam pernyataan CASE di %L harus berupa skalar"
 
-#: fortran/resolve.c:8185
+#: fortran/resolve.c:8196
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "Pemilihan ekspresi dalam pernyataan GOTO yang terhitung di %L harus berupa sebuah ekspresi integer skalar"
 
-#: fortran/resolve.c:8204
+#: fortran/resolve.c:8215
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "Argumen dari pernyataan SELECT di %L tidak dapat berupa %s"
 
-#: fortran/resolve.c:8214
+#: fortran/resolve.c:8225
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "Argumen dari pernyataan SELECT di %L harus berupa sebuah ekspresi skalar"
 
-#: fortran/resolve.c:8232 fortran/resolve.c:8240
+#: fortran/resolve.c:8243 fortran/resolve.c:8251
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in CASE statement at %L must be of type %s"
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "Ekspresi dalam pernyataan CASE di %L harus berupa tipe %s"
 
-#: fortran/resolve.c:8302 fortran/resolve.c:8873
+#: fortran/resolve.c:8313 fortran/resolve.c:8884
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "KASUS BAKU di %L tidak dapat diikuti oleh sebuah KASUS BAKU kedua di %L"
 
-#: fortran/resolve.c:8328
+#: fortran/resolve.c:8339
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "Jangkauan logikal dalam pernyataan CASE di %L tidak diperbolehkan"
 
-#: fortran/resolve.c:8340
+#: fortran/resolve.c:8351
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "constant logical value in CASE statement is repeated at %L"
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "nilai logikan konstan dalam pernyataan CASE diulang di %L"
 
-#: fortran/resolve.c:8355
+#: fortran/resolve.c:8366
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "Spesifikasi jangkauan di %L tidak pernah cocok"
 
-#: fortran/resolve.c:8458
+#: fortran/resolve.c:8469
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "Logikal SELECT CASE blok di %L memiliki lebih dari dua kasus"
 
-#: fortran/resolve.c:8518
+#: fortran/resolve.c:8529
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Iterator step at %L cannot be zero"
 msgid "Selector at %L cannot be NULL()"
 msgstr "Langkah iterasi di %L tidak dapat nol"
 
-#: fortran/resolve.c:8523
+#: fortran/resolve.c:8534
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Selector at %L has no type"
 msgstr "Fungsi '%s' di %L tidak memiliki tipe IMPLISIT"
 
-#: fortran/resolve.c:8545
+#: fortran/resolve.c:8556
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.c:8556
+#: fortran/resolve.c:8567
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:8763
+#: fortran/resolve.c:8774
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in EQUIVALENCE statement at %L"
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "Sintaks error dalam pernyataan EKUIVALEN di %L"
 
-#: fortran/resolve.c:8783 fortran/resolve.c:8795
+#: fortran/resolve.c:8794 fortran/resolve.c:8806
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Deleted feature: %s at %L must be integer"
 msgid "Selector at %L must not be coindexed"
 msgstr "Featur terhapus: %s di %L harus berupa integer"
 
-#: fortran/resolve.c:8824
+#: fortran/resolve.c:8835
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CASE label at %L overlaps with CASE label at %L"
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "CASE label di %L overlaps dengan CASE label di %L"
 
-#: fortran/resolve.c:8836
+#: fortran/resolve.c:8847
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %L is empty"
 msgid "Derived type %qs at %L must be extensible"
 msgstr "Tipe turunan '%s' di %L adalah kosong"
 
-#: fortran/resolve.c:8848
+#: fortran/resolve.c:8859
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %L is empty"
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "Tipe turunan '%s' di %L adalah kosong"
 
-#: fortran/resolve.c:8851
+#: fortran/resolve.c:8862
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected %s statement at %C"
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "Tidak terduga pernyataan %s di %C"
 
-#: fortran/resolve.c:8861
+#: fortran/resolve.c:8872
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.c:9108
+#: fortran/resolve.c:9119
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9204
+#: fortran/resolve.c:9215
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid context for NULL() pointer at %%L"
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "Konteks tidak valid untuk penunjuk NULL() di %%L"
 
-#: fortran/resolve.c:9257
+#: fortran/resolve.c:9268
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Interface '%s' of procedure '%s' at %L must be explicit"
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "Antar-muka '%s' dari prosedur '%s' di %L harus berupa eksplisit"
 
-#: fortran/resolve.c:9267
+#: fortran/resolve.c:9278
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9280
+#: fortran/resolve.c:9291
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components"
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "Elemen pemindahan data di %L tidak dapat memiliki komponen PENUNJUK"
 
-#: fortran/resolve.c:9289
+#: fortran/resolve.c:9300
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have POINTER components"
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "Elemen pemindahan data di %L tidak dapat memiliki komponen PENUNJUK"
 
-#: fortran/resolve.c:9296
+#: fortran/resolve.c:9307
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have ALLOCATABLE components"
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "Elemen pemindahan data di %L tidak dapat memiliki komponen DAPAT DIALOKASIKAN"
 
-#: fortran/resolve.c:9307
+#: fortran/resolve.c:9318
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "Elemen pemindahan data di %L tidak dapat memiliki komponen PRIVATE"
 
-#: fortran/resolve.c:9313
+#: fortran/resolve.c:9324
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Data transfer element at %L cannot have PRIVATE components"
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr "Elemen pemindahan data di %L tidak dapat memiliki komponen PRIVATE"
 
-#: fortran/resolve.c:9328
+#: fortran/resolve.c:9339
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "Elemen pemindahan data di %L tidak dapat berupa sebuah referensi lengkap ke sebuah array yang ukurannya diasumsikan"
 
-#: fortran/resolve.c:9388
+#: fortran/resolve.c:9399
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "FORALL nama-indeks di %L harus berupa sebuah skalar INTEGER"
 
-#: fortran/resolve.c:9398
+#: fortran/resolve.c:9409
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:9402
+#: fortran/resolve.c:9413
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "By-value argument at %L cannot be an array or an array section"
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "Argumen dengan nilai di %L tidak dapat berupa sebuah array atau sebuah daerah array"
 
-#: fortran/resolve.c:9405
+#: fortran/resolve.c:9416
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "By-value argument at %L cannot be an array or an array section"
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "Argumen dengan nilai di %L tidak dapat berupa sebuah array atau sebuah daerah array"
 
-#: fortran/resolve.c:9412 fortran/resolve.c:9533
+#: fortran/resolve.c:9423 fortran/resolve.c:9545
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "pernyataan ASSIGN di %L membutuhkan sebuah skalar baku variabel INTEGER"
 
-#: fortran/resolve.c:9424 fortran/resolve.c:9540
+#: fortran/resolve.c:9435 fortran/resolve.c:9553
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "pernyataan ASSIGN di %L membutuhkan sebuah skalar baku variabel INTEGER"
 
-#: fortran/resolve.c:9436
+#: fortran/resolve.c:9447
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument dim at %L must be scalar"
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "Argumen dim di %L harus berupa skalar"
 
-#: fortran/resolve.c:9449
+#: fortran/resolve.c:9460
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "NUM_THREADS clause at %L requires a scalar INTEGER expression"
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "NUM_THREADS clause di %L membutuhkan sebuah ekspresi skalar INTEGER"
 
-#: fortran/resolve.c:9510
+#: fortran/resolve.c:9521
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "Argumen dari pernyataan SELECT di %L harus berupa sebuah ekspresi skalar"
 
-#: fortran/resolve.c:9514 fortran/resolve.c:9524
+#: fortran/resolve.c:9525 fortran/resolve.c:9535
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of ACOS at %L must be between -1 and 1"
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "Argumen dari ACOS di %L harus berada diantara -1 dan 1"
 
-#: fortran/resolve.c:9567
+#: fortran/resolve.c:9580
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "Pernyataan di %L bukan sebuah pernyataan pencabangan target yang valid untuk sebuah pernyataan percabangan di %L"
 
-#: fortran/resolve.c:9577
+#: fortran/resolve.c:9590
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr "Cabang di %L bisa menyebabkan sebuah loop tak terhingga"
@@ -67405,12 +67488,12 @@
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:9594 fortran/resolve.c:9617
+#: fortran/resolve.c:9607 fortran/resolve.c:9630
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.c:9598 fortran/resolve.c:9623
+#: fortran/resolve.c:9611 fortran/resolve.c:9636
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -67418,113 +67501,113 @@
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:9638
+#: fortran/resolve.c:9651
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "Label di %L tidak dalam blok yang sama seperti pernyataan GOTO di %L"
 
-#: fortran/resolve.c:9710
+#: fortran/resolve.c:9723
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "DIMANA mask di %L memiliki bentuk tidak konsisten"
 
-#: fortran/resolve.c:9726
+#: fortran/resolve.c:9739
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "penempatan target WHERE di %L memiliki bentuk tidak konsisten"
 
-#: fortran/resolve.c:9734 fortran/resolve.c:9821
+#: fortran/resolve.c:9747 fortran/resolve.c:9834
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr "penempatan bukan-ELEMEN didefinisikan-pengguna dalam WHERE di %L"
 
-#: fortran/resolve.c:9744 fortran/resolve.c:9831
+#: fortran/resolve.c:9757 fortran/resolve.c:9844
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "Pernyataan didalam WHERE di %L tidak didukung"
 
-#: fortran/resolve.c:9775
+#: fortran/resolve.c:9788
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "Penempatan ke sebuah indeks variabel FORALL di %L"
 
-#: fortran/resolve.c:9784
+#: fortran/resolve.c:9797
 #, fuzzy, gcc-internal-format
 #| msgid "The FORALL with index '%s' is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "FORALL dengan indeks '%s' tidak digunakan di sisi kiri dari penempatan di %L dan jadi mungkin menyebabkan penempatan berulang di objek ini"
 
-#: fortran/resolve.c:9949
+#: fortran/resolve.c:9962
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "FORALL nama-indeks di %L harus berupa sebuah skalar INTEGER"
 
-#: fortran/resolve.c:9959
+#: fortran/resolve.c:9972
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "Sebuah konstruks FORALL luar telah memiliki sebuah indeks dengan nama ini %L"
 
-#: fortran/resolve.c:10036
+#: fortran/resolve.c:10049
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "WHERE/ELSEWHERE clause di %L membutuhkan sebuah array LOGIKAL"
 
-#: fortran/resolve.c:10138
+#: fortran/resolve.c:10151
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:10251
+#: fortran/resolve.c:10264
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CHARACTER expression will be truncated in assignment (%d/%d) at %L"
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr "Ekspresi KARAKTER akan dipotong dalam penempatan (%d/%d) di %L"
 
-#: fortran/resolve.c:10283
+#: fortran/resolve.c:10296
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The impure variable at %L is assigned to a derived type variable with a POINTER component in a PURE procedure (12.6)"
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "Variabel impure di %L ditempatkan ke sebuah tipe variabel turunan dengan sebuah komponen PENUNJUK dalam sebuah prosedur PURE (12.6)"
 
-#: fortran/resolve.c:10288
+#: fortran/resolve.c:10301
 #, gcc-internal-format, gfc-internal-format
 msgid "The impure variable at %L is assigned to a derived type variable with a POINTER component in a PURE procedure (12.6)"
 msgstr "Variabel impure di %L ditempatkan ke sebuah tipe variabel turunan dengan sebuah komponen PENUNJUK dalam sebuah prosedur PURE (12.6)"
 
-#: fortran/resolve.c:10298
+#: fortran/resolve.c:10311
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assignment to a FORALL index variable at %L"
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "Penempatan ke sebuah indeks variabel FORALL di %L"
 
-#: fortran/resolve.c:10330
+#: fortran/resolve.c:10343
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:10334
+#: fortran/resolve.c:10347
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assignment to a FORALL index variable at %L"
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "Penempatan ke sebuah indeks variabel FORALL di %L"
 
-#: fortran/resolve.c:10339
+#: fortran/resolve.c:10352
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.c:10346
+#: fortran/resolve.c:10359
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr ""
 
-#: fortran/resolve.c:10357
+#: fortran/resolve.c:10370
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:10663
+#: fortran/resolve.c:10683
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
@@ -67531,73 +67614,73 @@
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:10905
+#: fortran/resolve.c:10925
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid procedure pointer assignment at %L"
 msgid "Pointer procedure assignment at %L"
 msgstr "Penempatan penunjuk prosedur tidak valid di %L"
 
-#: fortran/resolve.c:10917
+#: fortran/resolve.c:10937
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr ""
 
-#: fortran/resolve.c:11157
+#: fortran/resolve.c:11177
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgstr "pernyataan GOTO ASSIGNED di %L membutuhkan sebuah variabel INTEGER"
 
-#: fortran/resolve.c:11160
+#: fortran/resolve.c:11180
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' has not been assigned a target label at %L"
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "Variabel '%s' belum pernah ditempatkan sebuah label target di %L"
 
-#: fortran/resolve.c:11171
+#: fortran/resolve.c:11191
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "Pernyataan RETURN alternatif di %L membutuhkan sebuah SKALAR-INTEGER return penspesifikasi"
 
-#: fortran/resolve.c:11233
+#: fortran/resolve.c:11253
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "pernyataan ASSIGN di %L membutuhkan sebuah skalar baku variabel INTEGER"
 
-#: fortran/resolve.c:11278
+#: fortran/resolve.c:11298
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Invalid NULL at %L"
 msgstr "Jenis tidak valid untuk %s di %L"
 
-#: fortran/resolve.c:11282
+#: fortran/resolve.c:11302
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Arithmetic IF statement at %L requires a numeric expression"
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr "Pernyataan aritmetik IF di %L membutuhkan sebuah ekspresi numerik"
 
-#: fortran/resolve.c:11339
+#: fortran/resolve.c:11359
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:11344
+#: fortran/resolve.c:11364
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "Kondisi keluar dari loop DO WHILE di %L harus berupa sebuah ekspresi skalar LOGIKAL"
 
-#: fortran/resolve.c:11428
+#: fortran/resolve.c:11448
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL mask clause at %L requires a LOGICAL expression"
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "FORALL mask clause di %L membutuhkan sebuah ekspresi LOGIKAL"
 
-#: fortran/resolve.c:11507
+#: fortran/resolve.c:11527
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_trans_code(): Pernyataan kode buruk"
 
-#: fortran/resolve.c:11617
+#: fortran/resolve.c:11637
 #, fuzzy, gcc-internal-format
 #| msgid "Binding label '%s' at %L collides with the global entity '%s' at %L"
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
@@ -67605,7 +67688,7 @@
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:11630
+#: fortran/resolve.c:11650
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr ""
@@ -67613,64 +67696,64 @@
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:11647
+#: fortran/resolve.c:11667
 #, fuzzy, gcc-internal-format
 #| msgid "Binding label '%s' at %L collides with the global entity '%s' at %L"
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "Binding label '%s' di %L collides dengan global entity '%s' di %L"
 
-#: fortran/resolve.c:11732
+#: fortran/resolve.c:11752
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "String length at %L is too large"
 msgstr "ukuran dari array %qs adalah terlalu besar"
 
-#: fortran/resolve.c:11961
+#: fortran/resolve.c:11981
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable array '%s' at %L must have a deferred shape"
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "Array dapat dialokasikan '%s' di %L harus memiliki sebuah bentuk deferred"
 
-#: fortran/resolve.c:11965
+#: fortran/resolve.c:11985
 #, fuzzy, gcc-internal-format
 #| msgid "Scalar object '%s' at %L may not be ALLOCATABLE"
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "Objek skalar '%s' di %L mungkin tidak dapat DIALOKASIKAN"
 
-#: fortran/resolve.c:11973
+#: fortran/resolve.c:11993
 #, fuzzy, gcc-internal-format
 #| msgid "Array pointer '%s' at %L must have a deferred shape"
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "Penunjuk array '%s' di %L harus memiliki sebuah bentuk deffered"
 
-#: fortran/resolve.c:11983
+#: fortran/resolve.c:12003
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "Array '%s' di %L tidak dapat memiliki sebuah bentuk deferred"
 
-#: fortran/resolve.c:11998
+#: fortran/resolve.c:12018
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.c:12010
+#: fortran/resolve.c:12030
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.c:12041
+#: fortran/resolve.c:12061
 #, fuzzy, gcc-internal-format
 #| msgid "The type '%s' cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr "Tipe '%s' tidak dapat host assosiasi di %L karena ini diblok dengan sebuah objek tidak kompatibel dari nama sama yang dideklarasikan di %L"
 
-#: fortran/resolve.c:12063
+#: fortran/resolve.c:12083
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
 
-#: fortran/resolve.c:12090
+#: fortran/resolve.c:12110
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
@@ -67677,999 +67760,1005 @@
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12131
+#: fortran/resolve.c:12151
 #, fuzzy, gcc-internal-format
 #| msgid "The module or main program array '%s' at %L must have constant shape"
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "Modul atau array aplikasi utama '%s' di %L harus memiliki bentuk konstan"
 
-#: fortran/resolve.c:12150
+#: fortran/resolve.c:12170
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "Entity dengan panjang karakter diasumsikan di %L harus berupa sebuah argumen dummy atau sebuah PARAMETER"
 
-#: fortran/resolve.c:12171
+#: fortran/resolve.c:12191
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "%qs at %L must have constant character length in this context"
 msgstr "'%s' di %L harus memiliki panjang karakter konstan dalam konteks ini"
 
-#: fortran/resolve.c:12178
+#: fortran/resolve.c:12198
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "'%s' di %L harus memiliki panjang karakter konstan dalam konteks ini"
 
-#: fortran/resolve.c:12225
+#: fortran/resolve.c:12245
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable '%s' at %L cannot have an initializer"
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "Dapat dialokasikan '%s' di %L tidak dapat memiliki sebuah penginisialisasi"
 
-#: fortran/resolve.c:12228
+#: fortran/resolve.c:12248
 #, fuzzy, gcc-internal-format
 #| msgid "External '%s' at %L cannot have an initializer"
 msgid "External %qs at %L cannot have an initializer"
 msgstr "Eksternal '%s' di %L tidak dapat memiliki sebuah penginisialisasi"
 
-#: fortran/resolve.c:12232
+#: fortran/resolve.c:12252
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "Dummy '%s' di %L tidak dapat memiliki sebuah penginisialisasi"
 
-#: fortran/resolve.c:12235
+#: fortran/resolve.c:12255
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L cannot have an initializer"
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "Intrinsik '%s' di %L tidak dapat memiliki sebuah penginisialisasi"
 
-#: fortran/resolve.c:12238
+#: fortran/resolve.c:12258
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L cannot have an initializer"
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "Hasil fungsi '%s' di %L tidak dapat memiliki sebuah penginisialisasi"
 
-#: fortran/resolve.c:12241
+#: fortran/resolve.c:12261
 #, fuzzy, gcc-internal-format
 #| msgid "Automatic array '%s' at %L cannot have an initializer"
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "Array otomatis '%s' di %L tidak dapat memiliki sebuah penginisialisasi"
 
-#: fortran/resolve.c:12283
+#: fortran/resolve.c:12303
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "in %s, at %s:%d"
 msgid "%s at %L"
 msgstr "dalam %s, di %s:%d"
 
-#: fortran/resolve.c:12310
+#: fortran/resolve.c:12330
 #, fuzzy, gcc-internal-format
 #| msgid "Character-valued statement function '%s' at %L must have constant length"
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "Pernyataan fungsi nilai-karakter '%s' di %L harus memiliki panjang konstant"
 
-#: fortran/resolve.c:12332
+#: fortran/resolve.c:12352
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: '%s' is of a PRIVATE type and cannot be a dummy argument of '%s', which is PUBLIC at %L"
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "Fortran 2003: '%s' adalah sebuah tipe PRIVATE dan tidak dapat berupa sebuah argumen dummy dari '%s', yang mana ini adalah PUBLIK di %L"
 
-#: fortran/resolve.c:12354
+#: fortran/resolve.c:12374
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: Procedure '%s' in PUBLIC interface '%s' at %L takes dummy arguments of '%s' which is PRIVATE"
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr "Fortran 2003: Prosedur '%s' dalam antar-muka PUBLIK '%s' di %L memakai argumen dummy dari '%s' dimana ini adalah PRIVATE"
 
-#: fortran/resolve.c:12372
+#: fortran/resolve.c:12392
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L cannot have an initializer"
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "Fungsi '%s' di %L tidak dapat memiliki sebuah penginisialisasi"
 
-#: fortran/resolve.c:12381
+#: fortran/resolve.c:12401
 #, fuzzy, gcc-internal-format
 #| msgid "External object '%s' at %L may not have an initializer"
 msgid "External object %qs at %L may not have an initializer"
 msgstr "Objek eksternal '%s' di %L tidak boleh memiliki sebuah penginisialisasi"
 
-#: fortran/resolve.c:12389
+#: fortran/resolve.c:12409
 #, fuzzy, gcc-internal-format
 #| msgid "ELEMENTAL function '%s' at %L must have a scalar result"
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "Fungsi ELEMEN '%s' di %L harus memiliki sebuah hasil skalar"
 
-#: fortran/resolve.c:12399
+#: fortran/resolve.c:12419
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' at %L is not allowed as an actual argument"
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "Pernyataan fungsi '%s' di %L tidak diperbolehkan sebagai argumen aktual"
 
-#: fortran/resolve.c:12418
+#: fortran/resolve.c:12438
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be array-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "Fungsi KARAKTER(*) '%s' di %L tidak dapat bernilai-array"
 
-#: fortran/resolve.c:12422
+#: fortran/resolve.c:12442
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pointer-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "Fungsi KARAKTER(*) '%s' di %L tidak dapat bernilai-penunjuk"
 
-#: fortran/resolve.c:12426
+#: fortran/resolve.c:12446
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "Fungsi KARAKTER(*) '%s' di %L tidak dapat pure"
 
-#: fortran/resolve.c:12430
+#: fortran/resolve.c:12450
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be recursive"
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "Fungsi KARAKTER(*) '%s' di %L tidak dapat rekursif"
 
-#: fortran/resolve.c:12443
+#: fortran/resolve.c:12463
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "Fungsi KARAKTER(*) '%s' di %L tidak dapat pure"
 
-#: fortran/resolve.c:12452
+#: fortran/resolve.c:12472
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' in %s at %L has no explicit interface"
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "Prosedur '%s' dalam %s di %L tidak memiliki antar-muka eksplisit"
 
-#: fortran/resolve.c:12458
+#: fortran/resolve.c:12478
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy procedure '%s' at %C cannot have a generic interface"
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "Prosedur dummy '%s' di %C tidak dapat memiliki sebuah antar-muka umum"
 
-#: fortran/resolve.c:12470
+#: fortran/resolve.c:12490
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:12527
+#: fortran/resolve.c:12547
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with SAVE attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "atribut PROSEDUR konflik dengan atribut SAVE dalam '%s' di %L"
 
-#: fortran/resolve.c:12533
+#: fortran/resolve.c:12553
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with INTENT attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "atribut PROSEDUR konflik dengan atribut INTENT dalam '%s' di %L"
 
-#: fortran/resolve.c:12539
+#: fortran/resolve.c:12559
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "atribut PROSEDUR konflik dengan atribut NAMELIST dalam '%s' di %L"
 
-#: fortran/resolve.c:12547
+#: fortran/resolve.c:12567
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with INTENT attribute in '%s' at %L"
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "atribut PROSEDUR konflik dengan atribut INTENT dalam '%s' di %L"
 
-#: fortran/resolve.c:12553
+#: fortran/resolve.c:12573
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.c:12596
+#: fortran/resolve.c:12616
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12604
+#: fortran/resolve.c:12624
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12612
+#: fortran/resolve.c:12632
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12621
+#: fortran/resolve.c:12641
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.c:12705
+#: fortran/resolve.c:12725
 #, fuzzy, gcc-internal-format
 #| msgid "FINAL procedure '%s' at %L is not a SUBROUTINE"
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "Prosedur FINAL '%s' di %L bukan sebuah SUBROUTINE"
 
-#: fortran/resolve.c:12714
+#: fortran/resolve.c:12734
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "Prosedur FINAL di %L harus memiliki tepat satu argumen"
 
-#: fortran/resolve.c:12723
+#: fortran/resolve.c:12743
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of FINAL procedure at %L must be of type '%s'"
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "Argumen dari prosedur FINAL di %L harus berupa tipe '%s'"
 
-#: fortran/resolve.c:12731
+#: fortran/resolve.c:12751
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "argumen dari prosedur FINAL di %L harus berupa sebuah PENUNJUK"
 
-#: fortran/resolve.c:12737
+#: fortran/resolve.c:12757
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "Argumen dari prosedur FINAL di %L harus berupa DAPAT-DIALOKASIKAN"
 
-#: fortran/resolve.c:12743
+#: fortran/resolve.c:12763
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "Argumen dari prosedur FINAL di %L tidak boleh berupa OPSIONAL"
 
-#: fortran/resolve.c:12751
+#: fortran/resolve.c:12771
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "Argumen dari prosedur FINAL di %L harus berupa INTENT(OUT)"
 
-#: fortran/resolve.c:12760
+#: fortran/resolve.c:12780
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "Prosedur FINAL bukan skalar di %L seharusnya memiliki diasumsikan argumen bentuk"
 
-#: fortran/resolve.c:12782
+#: fortran/resolve.c:12802
 #, fuzzy, gcc-internal-format
 #| msgid "FINAL procedure '%s' declared at %L has the same rank (%d) as '%s'"
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "prosedur FINAL '%s' dideklarasikan di %L memiliki tingkat yang sama (%d) seperti '%s'"
 
-#: fortran/resolve.c:12819
+#: fortran/resolve.c:12839
 #, fuzzy, gcc-internal-format
 #| msgid "Only array FINAL procedures declared for derived type '%s' defined at %L, suggest also scalar one"
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr "Hanya array prosedur FINAL dideklarasikan untuk tipe turunan '%s' didefinisikan di %L, disarankan juga skalar satu"
 
-#: fortran/resolve.c:12859
+#: fortran/resolve.c:12879
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' and '%s' can't be mixed FUNCTION/SUBROUTINE for GENERIC '%s' at %L"
 msgid "%qs and %qs can't be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr "'%s' dan '%s' tidak dapat dicampurkan FUNCTION/SUBROUTINE untuk GENERIC '%s' di %L"
 
-#: fortran/resolve.c:12895
+#: fortran/resolve.c:12915
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' and '%s' for GENERIC '%s' at %L are ambiguous"
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr "'%s' dan '%s' untuk GENERIC '%s' di %L adalah ambigu"
 
-#: fortran/resolve.c:12954
+#: fortran/resolve.c:12974
 #, fuzzy, gcc-internal-format
 #| msgid "Undefined specific binding '%s' as target of GENERIC '%s' at %L"
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr "Tidak terdefinisi pengikatan spesifik '%s' sebagai target dari GENERIC '%s' di %L"
 
-#: fortran/resolve.c:12966
+#: fortran/resolve.c:12986
 #, fuzzy, gcc-internal-format
 #| msgid "GENERIC '%s' at %L must target a specific binding, '%s' is GENERIC, too"
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr "GENERIC '%s' di %L harus target sebuah pengikatan spesifik, '%s' adalah GENERIC, juga"
 
-#: fortran/resolve.c:12994
+#: fortran/resolve.c:13014
 #, fuzzy, gcc-internal-format
 #| msgid "GENERIC '%s' at %L can't overwrite specific binding with the same name"
 msgid "GENERIC %qs at %L can't overwrite specific binding with the same name"
 msgstr "GENERIC '%s' di %L tidak dapat overwrite pengikatan spesifik dengan nama sama"
 
-#: fortran/resolve.c:13050
+#: fortran/resolve.c:13070
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L can't be NOPASS"
 msgstr ""
 
-#: fortran/resolve.c:13242
+#: fortran/resolve.c:13262
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' must be a module procedure or an external procedure with an explicit interface at %L"
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "'%s' harus berupa sebuah prosedur modul atau sebuah prosedur eksternal dengan sebuah antar-muka eksplisit di %L"
 
-#: fortran/resolve.c:13284
+#: fortran/resolve.c:13304
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' with PASS(%s) at %L has no argument '%s'"
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "Prosedur '%s' dengan PASS(%s) di %L tidak memiliki argumen '%s'"
 
-#: fortran/resolve.c:13298
+#: fortran/resolve.c:13318
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' with PASS at %L must have at least one argument"
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "Prosedur '%s' dengan PASS di %L harus memiliki paling tidak satu argumen"
 
-#: fortran/resolve.c:13312 fortran/resolve.c:13778
+#: fortran/resolve.c:13332 fortran/resolve.c:13798
 #, fuzzy, gcc-internal-format
 #| msgid "Polymorphic entities are not yet implemented, non-polymorphic passed-object dummy argument of '%s' at %L accepted"
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "entiti polymorphic belum diimplementasikan, bukan polymorphic objek argumen dummy dilewatkan dari '%s' di %L diterima"
 
-#: fortran/resolve.c:13320
+#: fortran/resolve.c:13340
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L must be of the derived-type '%s'"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "Argumen '%s' dari '%s' dengan PASS(%s) di %L harus berupa tipe turunan '%s'"
 
-#: fortran/resolve.c:13329
+#: fortran/resolve.c:13349
 #, fuzzy, gcc-internal-format
 #| msgid "Passed-object at %L must be scalar"
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "Objek yang dilewatkan di %L harus berupa skalar"
 
-#: fortran/resolve.c:13335
+#: fortran/resolve.c:13355
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be ALLOCATABLE"
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "'%s' argumen dari '%s' intrinsik di %L harus berupa DAPAT-DIALOKASIKAN"
 
-#: fortran/resolve.c:13341
+#: fortran/resolve.c:13361
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a POINTER"
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "'%s' argumen dari '%s' instrinsik di %L harus berupa sebuah PENUNJUK"
 
-#: fortran/resolve.c:13370
+#: fortran/resolve.c:13390
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L has the same name as a component of '%s'"
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "Prosedur '%s' di %L memiliki nama sama sebagai sebuah komponen dari '%s'"
 
-#: fortran/resolve.c:13380
+#: fortran/resolve.c:13400
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L has the same name as an inherited component of '%s'"
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "Prosedur '%s' di %L memiliki nama sama seperti sebuah komponen turunan dari '%s'"
 
-#: fortran/resolve.c:13472
+#: fortran/resolve.c:13492
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.c:13574
+#: fortran/resolve.c:13594
 #, fuzzy, gcc-internal-format
 #| msgid "Array pointer '%s' at %L must have a deferred shape"
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "Penunjuk array '%s' di %L harus memiliki sebuah bentuk deffered"
 
-#: fortran/resolve.c:13583
+#: fortran/resolve.c:13603
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13593
+#: fortran/resolve.c:13613
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.c:13602
+#: fortran/resolve.c:13622
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.c:13613
+#: fortran/resolve.c:13633
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ICHAR at %L must be of length one"
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "Argumen dari ICHAR di %L harus berupa panjang satu"
 
-#: fortran/resolve.c:13711
+#: fortran/resolve.c:13731
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' with PASS(%s) at %L has no argument '%s'"
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "Prosedur '%s' dengan PASS(%s) di %L tidak memiliki argumen '%s'"
 
-#: fortran/resolve.c:13725
+#: fortran/resolve.c:13745
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' with PASS at %L must have at least one argument"
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "Prosedur '%s' dengan PASS di %L harus memiliki paling tidak satu argumen"
 
-#: fortran/resolve.c:13741
+#: fortran/resolve.c:13761
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L must be of the derived-type '%s'"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "Argumen '%s' dari '%s' dengan PASS(%s) di %L harus berupa tipe turunan '%s'"
 
-#: fortran/resolve.c:13751
+#: fortran/resolve.c:13771
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L must be of the derived-type '%s'"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "Argumen '%s' dari '%s' dengan PASS(%s) di %L harus berupa tipe turunan '%s'"
 
-#: fortran/resolve.c:13760
+#: fortran/resolve.c:13780
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of elemental procedure at %L cannot have the POINTER attribute"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "Argumen '%s' dari prosedur elemental di %L tidak dapat memiliki atribut POINTER"
 
-#: fortran/resolve.c:13769
+#: fortran/resolve.c:13789
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be ALLOCATABLE"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "'%s' argumen dari '%s' intrinsik di %L harus berupa DAPAT-DIALOKASIKAN"
 
-#: fortran/resolve.c:13811
+#: fortran/resolve.c:13831
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' of '%s' at %L has the same name as an inherited type-bound procedure"
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "Komponen '%s' dari '%s' di %L memiliki nama sama dengan prosedur yang melingkupinya"
 
-#: fortran/resolve.c:13824
+#: fortran/resolve.c:13844
 #, fuzzy, gcc-internal-format
 #| msgid "Character length of component '%s' needs to be a constant specification expression at %L"
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "Panjang karakter dari komponen '%s' butuh untuk menjadi sebuah ekspresi spesifikasi konstan di %L"
 
-#: fortran/resolve.c:13835
+#: fortran/resolve.c:13855
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13868
+#: fortran/resolve.c:13888
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: the component '%s' is a PRIVATE type and cannot be a component of '%s', which is PUBLIC at %L"
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "Fortran 2003: Komponen '%s' adalah sebuah tipe PRIVATE dan tidak dapat berupa sebuah komponen dari '%s', yang mana adalah PUBLIK di %L"
 
-#: fortran/resolve.c:13876
+#: fortran/resolve.c:13896
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.c:13885
+#: fortran/resolve.c:13905
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "Komponen %s dari tipe URUTAN dideklarasikan di %L tidak dapat memiliki atribut URUTAN"
 
-#: fortran/resolve.c:13903 fortran/resolve.c:13915
+#: fortran/resolve.c:13923 fortran/resolve.c:13935
 #, fuzzy, gcc-internal-format
 #| msgid "The pointer component '%s' of '%s' at %L is a type that has not been declared"
 msgid "The pointer component %qs of %qs at %L is a type that has not been declared"
 msgstr "Komponen penunjuk '%s' dari '%s' di %L adalah sebuah tipe yang belum pernah dideklarasikan"
 
-#: fortran/resolve.c:13989
+#: fortran/resolve.c:14009
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Conflict in attributes of function argument at %C"
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "Konflik dalam atribut dari argumen fungsi di %C"
 
-#: fortran/resolve.c:14034
+#: fortran/resolve.c:14054
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.c:14047
+#: fortran/resolve.c:14067
 #, fuzzy, gcc-internal-format
 #| msgid "Non-extensible derived-type '%s' at %L must not be ABSTRACT"
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "Bukan ekstensible tipe turunan '%s' di %L tidak boleh berupa ABSTRACT"
 
-#: fortran/resolve.c:14111
+#: fortran/resolve.c:14131
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14144
+#: fortran/resolve.c:14164
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.c:14216
+#: fortran/resolve.c:14236
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed size array '%s' in namelist '%s' at %C is not allowed"
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "Ukuran array yang diasumsikan '%s' dalam daftar nama '%s' di %C tidak diperbolehkan"
 
-#: fortran/resolve.c:14222
+#: fortran/resolve.c:14242
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST array object '%s' must not have assumed shape in namelist '%s' at %L"
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "NAMELIST array objek '%s' tidak boleh memiliki bentuk yang diasumsikan dalam daftar-nama '%s' di %L"
 
-#: fortran/resolve.c:14228
+#: fortran/resolve.c:14248
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST array object '%s' must have constant shape in namelist '%s' at %L"
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "NAMELIST array objek '%s' harus memiliki bentuk konstan dalam daftar-nama '%s' di %L"
 
-#: fortran/resolve.c:14236
+#: fortran/resolve.c:14256
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST array object '%s' must have constant shape in namelist '%s' at %L"
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "NAMELIST array objek '%s' harus memiliki bentuk konstan dalam daftar-nama '%s' di %L"
 
-#: fortran/resolve.c:14253
+#: fortran/resolve.c:14273
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' was declared PRIVATE and cannot be member of PUBLIC namelist '%s' at %L"
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "NAMELIST objek '%s' telah dideklarasikan PRIVATE dan tidak dapat berupa anggota dari PUBLIK namelist '%s' di %L"
 
-#: fortran/resolve.c:14275
+#: fortran/resolve.c:14295
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' has use-associated PRIVATE components and cannot be member of namelist '%s' at %L"
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "NAMELIST objek '%s' memiliki use-associated komponen PRIVATE dan tidak dapat berupa anggota dari daftar-nama '%s' di %L"
 
-#: fortran/resolve.c:14286
+#: fortran/resolve.c:14306
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' has PRIVATE components and cannot be a member of PUBLIC namelist '%s' at %L"
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "NAMELIST objek '%s' meemiliki komponen PRIVATE dan tidak dapat berupa anggota dari PUBLIK daftar-nama '%s' di %L"
 
-#: fortran/resolve.c:14313
+#: fortran/resolve.c:14333
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "atribut PROSEDUR konflik dengan atribut NAMELIST dalam '%s' di %L"
 
-#: fortran/resolve.c:14337
+#: fortran/resolve.c:14357
 #, fuzzy, gcc-internal-format
 #| msgid "Parameter array '%s' at %L cannot be automatic or of deferred shape"
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "Parameter array '%s' di %L tidak dapat berupa otomatis atau bentuk deferred"
 
-#: fortran/resolve.c:14353
+#: fortran/resolve.c:14373
 #, fuzzy, gcc-internal-format
 #| msgid "Implicitly typed PARAMETER '%s' at %L doesn't match a later IMPLICIT type"
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "Tipe PARAMETER secara implisit '%s' di %L tidak cocok dengan tipe IMPLISIT kemudian"
 
-#: fortran/resolve.c:14364
+#: fortran/resolve.c:14384
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "Tipe turunan tidak kompatibel dalam PARAMETER di %L"
 
-#: fortran/resolve.c:14372
+#: fortran/resolve.c:14392
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "Variabel '%s' di %L tidak dapat memiliki dua atribut PENUNJUK dan BIND(C)"
 
-#: fortran/resolve.c:14423
+#: fortran/resolve.c:14443
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr ""
 
-#: fortran/resolve.c:14434
+#: fortran/resolve.c:14454
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.c:14441
+#: fortran/resolve.c:14461
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.c:14480
+#: fortran/resolve.c:14500
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:14544
+#: fortran/resolve.c:14564
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PROCEDURE attribute conflicts with INTENT attribute in '%s' at %L"
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "atribut PROSEDUR konflik dengan atribut INTENT dalam '%s' di %L"
 
-#: fortran/resolve.c:14547
+#: fortran/resolve.c:14567
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PROCEDURE attribute conflicts with INTENT attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "atribut PROSEDUR konflik dengan atribut INTENT dalam '%s' di %L"
 
-#: fortran/resolve.c:14643
+#: fortran/resolve.c:14663
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:14664
+#: fortran/resolve.c:14684
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad specification for assumed size array at %C"
 msgid "Bad specification for assumed size array at %L"
 msgstr "Spesifikasi buruk untuk diasumsikan ukuran array di %C"
 
-#: fortran/resolve.c:14677
+#: fortran/resolve.c:14697
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "Ukuran array yang diasumsikan di %L harus berupa sebuah argumen dummy"
 
-#: fortran/resolve.c:14680
+#: fortran/resolve.c:14700
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "Bentuk array yang diasumsikan di %L harus berupa sebuah argumen dummy"
 
-#: fortran/resolve.c:14688
+#: fortran/resolve.c:14708
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "Bentuk array yang diasumsikan di %L harus berupa sebuah argumen dummy"
 
-#: fortran/resolve.c:14695
+#: fortran/resolve.c:14715
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:14708
+#: fortran/resolve.c:14728
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "Simbol di %L bukan sebuah variabel DUMMY"
 
-#: fortran/resolve.c:14714
+#: fortran/resolve.c:14734
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "'%s' di %L tidak dapat memiliki VALUE atribut karena ini bukan sebuah argumen dummy"
 
-#: fortran/resolve.c:14724
+#: fortran/resolve.c:14744
 #, fuzzy, gcc-internal-format
 #| msgid "Character dummy variable '%s' at %L with VALUE attribute must have constant length"
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "Karakter dummy variabel '%s' di %L dengan atribut NILAI harus memiliki panjang konstant"
 
-#: fortran/resolve.c:14733
+#: fortran/resolve.c:14753
 #, fuzzy, gcc-internal-format
 #| msgid "C interoperable character dummy variable '%s' at %L with VALUE attribute must have length one"
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "C interoperable karakter dummy variabel '%s' di %L dengan atribut NILAI harus memiliki panjang satu"
 
-#: fortran/resolve.c:14746 fortran/resolve.c:14923
+#: fortran/resolve.c:14766 fortran/resolve.c:14943
 #, fuzzy, gcc-internal-format
 #| msgid "The derived type '%s' at %L is of type '%s', which has not been defined"
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "Tipe turunana '%s' di %L adalah tipe '%s',  yang mana belum didefinisikan"
 
-#: fortran/resolve.c:14760
+#: fortran/resolve.c:14780
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14769
+#: fortran/resolve.c:14789
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:14778
+#: fortran/resolve.c:14798
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Variabel '%s' di %L tidak dapat memiliki dua atribut DAPAT DIALOKASIKAN dan BIND(C)"
 
-#: fortran/resolve.c:14786
+#: fortran/resolve.c:14806
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "Variabel '%s' di %L tidak dapat memiliki dua atribut PENUNJUK dan BIND(C)"
 
-#: fortran/resolve.c:14793
+#: fortran/resolve.c:14813
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:14813
+#: fortran/resolve.c:14833
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array '%s' at %L is not permitted in an initialization expression"
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "Diasumsikan bentuk array '%s' di %L tidak diijinkan dalam sebuah ekspresi inisialisasi"
 
-#: fortran/resolve.c:14820
+#: fortran/resolve.c:14840
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Variabel '%s' di %L tidak dapat memiliki dua atribut DAPAT DIALOKASIKAN dan BIND(C)"
 
-#: fortran/resolve.c:14827
+#: fortran/resolve.c:14847
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "Variabel '%s' di %L tidak dapat memiliki dua atribut PENUNJUK dan BIND(C)"
 
-#: fortran/resolve.c:14834
+#: fortran/resolve.c:14854
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:14860
+#: fortran/resolve.c:14880
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr "Variabel '%s' di %L tidak dapat berupa BIND(C) karena ini bukan sebuah blok UMUM atau dideklarasikan dalam tingkat cakupan modul"
 
-#: fortran/resolve.c:14870
+#: fortran/resolve.c:14890
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "Argumen dari %s di %L harus berupa panjang satu"
 
-#: fortran/resolve.c:14949
+#: fortran/resolve.c:14969
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: PUBLIC %s '%s' at %L of PRIVATE derived type '%s'"
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "Fortran 2003: PUBLIK %s '%s' di %L dari tipe turunan '%s' PRIVATE"
 
-#: fortran/resolve.c:14964
+#: fortran/resolve.c:14984
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14977
+#: fortran/resolve.c:14997
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14995
+#: fortran/resolve.c:15015
 #, fuzzy, gcc-internal-format
 #| msgid "The INTENT(OUT) dummy argument '%s' at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "INTENT(OUT) dummy argumen '%s' di %L adalah UKURAN DIASUMSIKAN dan jadi tidak dapat memiliki sebuah penginisialisasi baku"
 
-#: fortran/resolve.c:15007
+#: fortran/resolve.c:15027
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "Dummy argumen '%s' di %L tidak dapat berupa INTENT(OUT)"
 
-#: fortran/resolve.c:15016
+#: fortran/resolve.c:15036
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "Dummy argumen '%s' di %L tidak dapat berupa INTENT(OUT)"
 
-#: fortran/resolve.c:15028
+#: fortran/resolve.c:15048
 #, fuzzy, gcc-internal-format
 #| msgid "By-value argument at %L cannot be an array or an array section"
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "Argumen dengan nilai di %L tidak dapat berupa sebuah array atau sebuah daerah array"
 
-#: fortran/resolve.c:15037
+#: fortran/resolve.c:15057
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15049
+#: fortran/resolve.c:15069
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15065
+#: fortran/resolve.c:15085
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15073
+#: fortran/resolve.c:15093
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "Array '%s' di %L tidak dapat memiliki sebuah bentuk deferred"
 
-#: fortran/resolve.c:15080
+#: fortran/resolve.c:15100
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable array '%s' at %L must have a deferred shape"
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "Array dapat dialokasikan '%s' di %L harus memiliki sebuah bentuk deferred"
 
-#: fortran/resolve.c:15092
+#: fortran/resolve.c:15112
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.c:15101
+#: fortran/resolve.c:15121
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy procedure at %L not allowed in ELEMENTAL procedure"
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "Prosedur dummy di %L tidak diperbolehkan dalam prosedur ELEMENTAL"
 
-#: fortran/resolve.c:15117
+#: fortran/resolve.c:15137
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15123
+#: fortran/resolve.c:15143
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15148
+#: fortran/resolve.c:15168
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist %s cannot be renamed by USE association to %s"
 msgid "Namelist %qs can not be an argument to subroutine or function at %L"
 msgstr "Daftar-nama %s tidak dapat diubah namanya dengan assosiasi USE ke %s"
 
-#: fortran/resolve.c:15218
+#: fortran/resolve.c:15238
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "Threadprivate di %L bukan SAVEd"
 
-#: fortran/resolve.c:15229
+#: fortran/resolve.c:15249
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:15333
+#: fortran/resolve.c:15353
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:15339
+#: fortran/resolve.c:15359
 #, fuzzy, gcc-internal-format
 #| msgid "BLOCK DATA element '%s' at %L must be in COMMON"
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "DATA BLOK elemen '%s' di %L harus berupa dalam COMMON"
 
-#: fortran/resolve.c:15345
+#: fortran/resolve.c:15365
 #, fuzzy, gcc-internal-format
 #| msgid "DATA array '%s' at %L must be specified in a previous declaration"
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "DATA array '%s' di %L harus dispesifikasikan dalam sebuah deklarasi sebelumnya"
 
-#: fortran/resolve.c:15354
+#: fortran/resolve.c:15374
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "Dummy '%s' di %L tidak dapat memiliki sebuah penginisialisasi"
 
-#: fortran/resolve.c:15368
+#: fortran/resolve.c:15388
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:15414
+#: fortran/resolve.c:15434
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "Daerah array tidak konstant di %L dalam pernyataan DATA"
 
-#: fortran/resolve.c:15427
+#: fortran/resolve.c:15447
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "pernyataan DATA di %L memiliki lebih variabel daripada nilai"
 
-#: fortran/resolve.c:15526
+#: fortran/resolve.c:15546
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15534
+#: fortran/resolve.c:15554
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15542
+#: fortran/resolve.c:15562
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15667
+#: fortran/resolve.c:15687
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "pernyataan DATA di %L memiliki lebih banyak nilai daripada variabel"
 
-#: fortran/resolve.c:15832
+#: fortran/resolve.c:15852
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "Label %d di %L didefinisikan tetapi tidak digunakan"
 
-#: fortran/resolve.c:15838
+#: fortran/resolve.c:15858
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "Label %d di %L didefinisikan tetapi tidak dapat digunakan"
 
-#: fortran/resolve.c:15922
+#: fortran/resolve.c:15942
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "Tipe variabel turunan '%s' di %L harus memiliki atribut URUTAN untuk menjadi sebuah objek EKUIVALEN"
 
-#: fortran/resolve.c:15931
+#: fortran/resolve.c:15951
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "Tipe variabel turunan '%s' di %L tidak dapat memiliki komponen DAPAT DIALOKASIKAN untuk menjadi sebuah objek EKUIVALEN"
 
-#: fortran/resolve.c:15939
+#: fortran/resolve.c:15959
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "Tipe variabel turunan '%s' di %L dengan inisialisasi baku tidak dapat berada dalam EKUIVALEN dengan sebuah variabel dalam COMMON"
 
-#: fortran/resolve.c:15955
+#: fortran/resolve.c:15975
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "Tipe variabel turunan '%s' di %L dengan komponen penunjuk tidak dapat berupa sebuah objek EKUIVALEN"
 
-#: fortran/resolve.c:16058
+#: fortran/resolve.c:16078
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "Sintaks error dalam pernyataan EKUIVALEN di %L"
 
-#: fortran/resolve.c:16073
+#: fortran/resolve.c:16093
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr "Baik semua atau kosong dari objek dalam EKUIVALEN set di %L yang memiliki atribut TERPROTEKSI"
 
-#: fortran/resolve.c:16098
+#: fortran/resolve.c:16118
 #, fuzzy, gcc-internal-format
 #| msgid "Common block member '%s' at %L cannot be an EQUIVALENCE object in the pure procedure '%s'"
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "Anggota blok umum '%s' di %L tidak dapat berupa sebuah objek EKUIVALEN dalam prosedur pure '%s'"
 
-#: fortran/resolve.c:16107
+#: fortran/resolve.c:16127
 #, fuzzy, gcc-internal-format
 #| msgid "Named constant '%s' at %L cannot be an EQUIVALENCE object"
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Konstanta bernama '%s' di %L tidak dapat berupa sebuah objek EKUIVALEN"
 
-#: fortran/resolve.c:16180
+#: fortran/resolve.c:16200
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "Array '%s' di %L dengan cakupan tidak-konstan tidak dapat berupa sebuah objek EKUIVALEN"
 
-#: fortran/resolve.c:16191
+#: fortran/resolve.c:16211
 #, fuzzy, gcc-internal-format
 #| msgid "Structure component '%s' at %L cannot be an EQUIVALENCE object"
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Komponen struktur '%s' di %L tidak dapat berupa sebuah objek EKUIVALEN"
 
-#: fortran/resolve.c:16202
+#: fortran/resolve.c:16222
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "Substring di %L memiliki panjang nol"
 
-#: fortran/resolve.c:16293
+#: fortran/resolve.c:16253
 #, fuzzy, gcc-internal-format
+#| msgid "Different character lengths in pointer assignment at %L"
+msgid "Self reference in character length expression for %qs at %L"
+msgstr "Panjang karakter berbeda dalam penempatan penunjuk di %L"
+
+#: fortran/resolve.c:16320
+#, fuzzy, gcc-internal-format
 #| msgid "PUBLIC function '%s' at %L cannot be of PRIVATE type '%s'"
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "Fungsi PUBLIK '%s' di %L tidak dapat berupa tipe PRIVATE '%s'"
 
-#: fortran/resolve.c:16306
+#: fortran/resolve.c:16333
 #, fuzzy, gcc-internal-format
 #| msgid "ENTRY '%s' at %L has no IMPLICIT type"
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "MASUKAN '%s' di %L tidak memiliki tipe IMPLISIT"
 
-#: fortran/resolve.c:16326
+#: fortran/resolve.c:16353
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must be a FUNCTION"
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "Prosedur operator pengguna '%s' di %L harus berupa sebuah FUNGSI"
 
-#: fortran/resolve.c:16336
+#: fortran/resolve.c:16363
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L cannot be assumed character length"
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "Prosedur operator pengguna '%s' di %L tidak dapat berupa panjang karakter diasumsikan"
 
-#: fortran/resolve.c:16344
+#: fortran/resolve.c:16371
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "Prosedur operator pengguna '%s' di %L harus memiliki paling tida satu argumen"
 
-#: fortran/resolve.c:16358
+#: fortran/resolve.c:16385
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "Argumen pertama dari antar-muka operator di %L tidak dapat berupa pilihanonal"
 
-#: fortran/resolve.c:16376
+#: fortran/resolve.c:16403
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "Argumen kedua dari antar-muka operator di %L tidak dapat berupa pilihanonal"
 
-#: fortran/resolve.c:16383
+#: fortran/resolve.c:16410
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "Antar-muka operator di %L harus memiliki, paling tidak, dua argumen"
 
-#: fortran/resolve.c:16461
+#: fortran/resolve.c:16488
 #, fuzzy, gcc-internal-format
 #| msgid "Contained procedure '%s' at %L of a PURE procedure must also be PURE"
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
@@ -69010,19 +69099,13 @@
 msgid "simplify_min_max(): Bad type in arglist"
 msgstr ""
 
-#. Result is processor-dependent.
-#: fortran/simplify.c:5472
-#, gcc-internal-format, gfc-internal-format
-msgid "Second argument MOD at %L is zero"
-msgstr "Argumen kedua MOD di %L adalah nol"
+#: fortran/simplify.c:5470 fortran/simplify.c:5478
+#, fuzzy, gcc-internal-format
+#| msgid "Second argument of NEAREST at %L shall not be zero"
+msgid "Argument %qs of MOD at %L shall not be zero"
+msgstr "Argumen kedua dari NEAREST di %L tidak boleh berupa nol"
 
-#. Result is processor-dependent.
-#: fortran/simplify.c:5483
-#, gcc-internal-format, gfc-internal-format
-msgid "Second argument of MOD at %L is zero"
-msgstr "Argumen kedua dari MOD di %L adalah nol"
-
-#: fortran/simplify.c:5494
+#: fortran/simplify.c:5484
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_simplify_mod(): Bad arguments"
@@ -69031,103 +69114,103 @@
 #. Result is processor-dependent. This processor just opts
 #. to not handle it at all.
 #. Result is processor-dependent.
-#: fortran/simplify.c:5520 fortran/simplify.c:5532
+#: fortran/simplify.c:5525 fortran/simplify.c:5537
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of MODULO at %L is zero"
 msgstr "Argumen kedua dari MODULE di %L adalah nol"
 
-#: fortran/simplify.c:5552
+#: fortran/simplify.c:5557
 #, gcc-internal-format
 msgid "gfc_simplify_modulo(): Bad arguments"
 msgstr ""
 
-#: fortran/simplify.c:5600
+#: fortran/simplify.c:5605
 #, gcc-internal-format, gfc-internal-format
 msgid "Result of NEAREST is NaN at %L"
 msgstr "Hasil dari NEAREST adalah NaN di %L"
 
-#: fortran/simplify.c:6081
+#: fortran/simplify.c:6086
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative at %L"
 msgstr "Argumen NCOPIES dari REPEAT intrinsik adalah negatif di %L"
 
-#: fortran/simplify.c:6137
+#: fortran/simplify.c:6142
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument NCOPIES of REPEAT intrinsic is too large at %L"
 msgstr "Argumen NCOPIES dari REPEAT intrinsik adalah terlalu besar di %L"
 
-#: fortran/simplify.c:6174
+#: fortran/simplify.c:6179
 #, gcc-internal-format, gfc-internal-format
 msgid "Evaluation of string longer than 2**28 at %L deferred to runtime, expect bugs"
 msgstr ""
 
-#: fortran/simplify.c:6302
+#: fortran/simplify.c:6307
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Integer too large at %C"
 msgid "Reshaped array too large at %C"
 msgstr "Integer terlalu besar di %C"
 
-#: fortran/simplify.c:6416
+#: fortran/simplify.c:6421
 #, gcc-internal-format, gfc-internal-format
 msgid "Result of SCALE overflows its kind at %L"
 msgstr "Hasil dari overflow SKALA jenisnya di %L"
 
-#: fortran/simplify.c:6995
+#: fortran/simplify.c:7000
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "Bad type in gfc_simplify_sign"
 msgstr "Tipe buruk dalam ekspresi konstanta"
 
-#: fortran/simplify.c:7024
+#: fortran/simplify.c:7029
 #, gcc-internal-format
 msgid "in gfc_simplify_sin(): Bad type"
 msgstr ""
 
-#: fortran/simplify.c:7151 fortran/simplify.c:7431
+#: fortran/simplify.c:7156 fortran/simplify.c:7436
 #, gcc-internal-format
 msgid "Failure getting length of a constant array."
 msgstr ""
 
-#: fortran/simplify.c:7161
+#: fortran/simplify.c:7166
 #, fuzzy, gcc-internal-format
 #| msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit.   See -fmax-array-constructor option"
 msgid "The number of elements (%d) in the array constructor at %L requires an increase of the allowed %d upper limit.  See %<-fmax-array-constructor%> option."
 msgstr "Jumlah dari elemen dalam konstruktor array di %L membutuhkan sebuah peningkatan dari batas atas %d yang diijinkan. Lihat pilihan -fmax-array-constructor"
 
-#: fortran/simplify.c:7227
+#: fortran/simplify.c:7232
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Finalization at %L is not yet implemented"
 msgid "Simplification of SPREAD at %C not yet implemented"
 msgstr "Finalisasi di %L belum diimplementasikan"
 
-#: fortran/simplify.c:7251
+#: fortran/simplify.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SQRT at %L has a negative value"
 msgstr "Argumen dari SQRT di %L memiliki sebuah nilai negatif"
 
-#: fortran/simplify.c:7267
+#: fortran/simplify.c:7272
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid second argument of IBSET at %L"
 msgid "invalid argument of SQRT at %L"
 msgstr "Argumen kedua dari IBSET di %L tidak valid"
 
-#: fortran/simplify.c:7598
+#: fortran/simplify.c:7603
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY lower bound is %ld)"
 msgstr ""
 
-#: fortran/simplify.c:7621
+#: fortran/simplify.c:7626
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY upper bound is %ld)"
 msgstr ""
 
-#: fortran/simplify.c:7993
+#: fortran/simplify.c:7998
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_conv_constant_to_tree(): invalid type: %s"
 msgid "gfc_convert_constant(): Unexpected type"
 msgstr "gfc_conv_constant_to_tree(): tipe tidak valid: %s"
 
-#: fortran/simplify.c:8078
+#: fortran/simplify.c:8083
 #, fuzzy, gcc-internal-format
 #| msgid "Character '%s' in string at %L cannot be converted into character kind %d"
 msgid "Character %qs in string at %L cannot be converted into character kind %d"
@@ -69242,7 +69325,7 @@
 msgid "BIND(C) applied to %s %s at %L"
 msgstr "BIND(C) diaplikasikan ke %s %s di %L"
 
-#: fortran/symbol.c:901 fortran/symbol.c:912 fortran/symbol.c:1762
+#: fortran/symbol.c:901 fortran/symbol.c:912 fortran/symbol.c:1776
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute conflicts with %s attribute at %L"
 msgstr "%s atribut konflik dengan %s atribut di %L"
@@ -69321,19 +69404,25 @@
 msgid "Duplicate VOLATILE attribute specified at %L"
 msgstr "Duplikasi atribut VOLATILE dispesifikasikan di %L"
 
-#: fortran/symbol.c:1367
+#: fortran/symbol.c:1360
 #, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "SAVE attribute at %L cannot be specified in a PURE procedure"
+msgid "VOLATILE attribute at %L cannot be specified in a PURE procedure"
+msgstr "atribut SAVE di %L tidak dapat dispesifikasikan dalam sebuah prosedur PURE"
+
+#: fortran/symbol.c:1381
+#, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate VALUE attribute specified at %L"
 msgid "Duplicate ASYNCHRONOUS attribute specified at %L"
 msgstr "Duplikasi atribut NILAI dispesifikasikan di %L"
 
-#: fortran/symbol.c:1758
+#: fortran/symbol.c:1772
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute of '%s' conflicts with %s attribute at %L"
 msgid "%s attribute of %qs conflicts with %s attribute at %L"
 msgstr "%s atribut dari '%s' konflik dengan %s atribut di %L"
 
-#: fortran/symbol.c:1794
+#: fortran/symbol.c:1808
 #, gcc-internal-format, gfc-internal-format
 msgid ""
 "%s procedure at %L is already declared as %s procedure. \n"
@@ -69340,162 +69429,162 @@
 "F2008: A pointer function assignment is ambiguous if it is the first executable statement after the specification block. Please add any other kind of executable statement before it. FIXME"
 msgstr ""
 
-#: fortran/symbol.c:1802
+#: fortran/symbol.c:1816
 #, gcc-internal-format, gfc-internal-format
 msgid "%s procedure at %L is already declared as %s procedure"
 msgstr "%s prosedur di %L telah dideklarasikan sebagai %s prosedur"
 
-#: fortran/symbol.c:1837
+#: fortran/symbol.c:1851
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgstr "INTENT (%s) konfliks dengan INTENT(%s) di %L"
 
-#: fortran/symbol.c:1861
+#: fortran/symbol.c:1875
 #, gcc-internal-format, gfc-internal-format
 msgid "ACCESS specification at %L was already specified"
 msgstr "Spesifikasi AKSES di %L telah dispesifikasikan"
 
-#: fortran/symbol.c:1878
+#: fortran/symbol.c:1892
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate BIND attribute specified at %L"
 msgstr "Duplikasi atribut BIND dispesifikasikan di %L"
 
-#: fortran/symbol.c:1885
+#: fortran/symbol.c:1899
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid " BIND(C)"
 msgid "BIND(C) at %L"
 msgstr " BIND(C)"
 
-#: fortran/symbol.c:1901
+#: fortran/symbol.c:1915
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate EXTENDS attribute specified at %L"
 msgstr "Duplikasi atribut EXTENDS dispesifikasikan di %L"
 
-#: fortran/symbol.c:1905
+#: fortran/symbol.c:1919
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: EXTENDS at %L"
 msgid "EXTENDS at %L"
 msgstr "Fortran 2003: EXTENDS di %L"
 
-#: fortran/symbol.c:1931
+#: fortran/symbol.c:1945
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L already has an explicit interface"
 msgid "Symbol %qs at %L already has an explicit interface"
 msgstr "Simbol '%s' di %L telah memiliki sebuah antar-muka eksplisit"
 
-#: fortran/symbol.c:1938
+#: fortran/symbol.c:1952
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L has attributes specified outside its INTERFACE body"
 msgid "%qs at %L has attributes specified outside its INTERFACE body"
 msgstr "'%s' di %L memiliki atribut dispesifikasikan diluar dari badan ANTAR-MUKA-nya"
 
-#: fortran/symbol.c:1976
+#: fortran/symbol.c:1990
 #, gcc-internal-format
 msgid "Symbol %qs at %L conflicts with symbol from module %qs, use-associated at %L"
 msgstr ""
 
-#: fortran/symbol.c:1980
+#: fortran/symbol.c:1994
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %C already has a type of %s"
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr "Fungsi '%s' di %C telah memiliki sebuah tipe dari %s"
 
-#: fortran/symbol.c:1987
+#: fortran/symbol.c:2001
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L has the same name as a component of '%s'"
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr "Prosedur '%s' di %L memiliki nama sama sebagai sebuah komponen dari '%s'"
 
-#: fortran/symbol.c:1999
+#: fortran/symbol.c:2013
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L cannot have a type"
 msgid "Symbol %qs at %L cannot have a type"
 msgstr "Simbol '%s' di %L tidak dapat memiliki sebuah tipe"
 
-#: fortran/symbol.c:2242
+#: fortran/symbol.c:2256
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C already in the parent type at %L"
 msgid "Component %qs at %C already in the parent type at %L"
 msgstr "Komponen '%s' di %C telah berada dalam tipe induknya di %L"
 
-#: fortran/symbol.c:2327
+#: fortran/symbol.c:2341
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C is ambiguous"
 msgid "Symbol %qs at %C is ambiguous"
 msgstr "Simbol '%s' di %C adalah ambigu"
 
-#: fortran/symbol.c:2359
+#: fortran/symbol.c:2373
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %C is being used before it is defined"
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr "Tipe turunan '%s' di %C sedang digunakan sebelum itu didefinisikan"
 
-#: fortran/symbol.c:2508
+#: fortran/symbol.c:2522
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C is a PRIVATE component of '%s'"
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr "Komponen '%s' di %C adalah sebuah komponen PRIVATE dari '%s'"
 
-#: fortran/symbol.c:2529
+#: fortran/symbol.c:2543
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is not a member of the '%s' structure"
 msgid "%qs at %C is not a member of the %qs structure; did you mean %qs?"
 msgstr "'%s' di %C bukan sebuah anggota dari struktur '%s'"
 
-#: fortran/symbol.c:2533
+#: fortran/symbol.c:2547
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %C is not a member of the '%s' structure"
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr "'%s' di %C bukan sebuah anggota dari struktur '%s'"
 
-#: fortran/symbol.c:2697
+#: fortran/symbol.c:2711
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr "Duplikasi pernyataan label %d di %L dan %L"
 
-#: fortran/symbol.c:2708
+#: fortran/symbol.c:2722
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr "Label %d di %C telah direferensikan sebagai target percabangan"
 
-#: fortran/symbol.c:2718
+#: fortran/symbol.c:2732
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr "Label %d di %C telah direferensikan sebagai sebuah format label"
 
-#: fortran/symbol.c:2724
+#: fortran/symbol.c:2738
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:2766
+#: fortran/symbol.c:2780
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr "Label %d di %C sebelumnya digunakan sebagai sebuah FORMAT label"
 
-#: fortran/symbol.c:2775
+#: fortran/symbol.c:2789
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr "Label %d di %C sebelumnya digunakan sebagai target percabangan"
 
-#: fortran/symbol.c:2781
+#: fortran/symbol.c:2795
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected terminating name at %C"
 msgid "Shared DO termination label %d at %C"
 msgstr "Diduga nama berakhir di %C"
 
-#: fortran/symbol.c:3110
+#: fortran/symbol.c:3124
 #, gcc-internal-format
 msgid "new_symbol(): Symbol name too long"
 msgstr ""
 
-#: fortran/symbol.c:3135
+#: fortran/symbol.c:3149
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is an ambiguous reference to '%s' from module '%s'"
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr "Nama '%s' di C adalah sebuah referensi ambigu ke '%s' dari module '%s'"
 
-#: fortran/symbol.c:3138
+#: fortran/symbol.c:3152
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is an ambiguous reference to '%s' from current program unit"
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
@@ -69502,71 +69591,71 @@
 msgstr "Nama '%s' di %C adalah sebuah referensi ambigu ke '%s' dari satuan aplikasi sekarang"
 
 #. Symbol is from another namespace.
-#: fortran/symbol.c:3381
+#: fortran/symbol.c:3395
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C has already been host associated"
 msgid "Symbol %qs at %C has already been host associated"
 msgstr "Simbol '%s' di %C telah diassosiasikan host"
 
-#: fortran/symbol.c:4397
+#: fortran/symbol.c:4411
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr ""
 
-#: fortran/symbol.c:4410
+#: fortran/symbol.c:4424
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' declared at %L must have the BIND attribute to be C interoperable"
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr "Tipe turunan '%s' dideklarasikan di %L harus memiliki atribut BIND ke Cinteroperable"
 
-#: fortran/symbol.c:4428
+#: fortran/symbol.c:4442
 #, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr ""
 
-#: fortran/symbol.c:4449
+#: fortran/symbol.c:4463
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type '%s' at %L"
 msgid "Component %qs at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr "Komponen '%s' di %L tidak dapat memiliki atribut PENUNJUK karena ini sebuah anggota tari BIND(C) tipe turunan '%s' di %L"
 
-#: fortran/symbol.c:4459
+#: fortran/symbol.c:4473
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type '%s' at %L"
 msgid "Procedure pointer component %qs at %L cannot be a member of the BIND(C) derived type %qs at %L"
 msgstr "Komponen '%s' di %L tidak dapat memiliki atribut PENUNJUK karena ini sebuah anggota tari BIND(C) tipe turunan '%s' di %L"
 
-#: fortran/symbol.c:4470
+#: fortran/symbol.c:4484
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type '%s' at %L"
 msgid "Component %qs at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr "Komponen '%s' di %L tidak dapat memiliki atribut DAPAT DIALOKASIKAN karena ini sebuah anggota dari tipe turunan BIND(C) '%s' di %L"
 
-#: fortran/symbol.c:4509
+#: fortran/symbol.c:4523
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' in derived type '%s' at %L may not be C interoperable, even though derived type '%s' is BIND(C)"
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr "Komponen '%s' dalam tipe turunan '%s' di %L mungkin tidak C interoperabel, walaupun melalui tipe turunan '%s' adalah BIND(C)"
 
-#: fortran/symbol.c:4519
+#: fortran/symbol.c:4533
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' in derived type '%s' at %L may not be C interoperable"
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr "Komponen '%s' dalam tipe turunan '%s' di %L mungkin tidak C interoperabel"
 
-#: fortran/symbol.c:4533
+#: fortran/symbol.c:4547
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %L cannot be declared with both PRIVATE and BIND(C) attributes"
 msgid "Derived type %qs at %L cannot be declared with both PRIVATE and BIND(C) attributes"
 msgstr "Tipe turunan '%s' di %L tidak dapat dideklarasikan dengan baik atribut PRIVATE dan BIND(C)"
 
-#: fortran/symbol.c:4541
+#: fortran/symbol.c:4555
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type '%s' at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr "Tipe turunan '%s' di %L tidak dapat memiliki urutan atribut karena ini adalah BIND(C)"
 
-#: fortran/symbol.c:5018 fortran/symbol.c:5023
+#: fortran/symbol.c:5032 fortran/symbol.c:5037
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' is used before it is typed at %L"
 msgid "Symbol %qs is used before it is typed at %L"
@@ -69618,7 +69707,7 @@
 msgid "Creating array temporary at %L for argument %qs"
 msgstr "Membuat array sementara di %L untuk argumen '%s'"
 
-#: fortran/trans-array.c:10693
+#: fortran/trans-array.c:10724
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr "tipe ekspresi buruk selama walk (%d)"
@@ -69846,12 +69935,12 @@
 msgid "%<dim%> argument of %s intrinsic at %L is not a valid dimension index"
 msgstr "'dim' argumen dari %s intrinsik di %L bukan sebuah dimensi indeks valid"
 
-#: fortran/trans-intrinsic.c:10572 fortran/trans-stmt.c:1050
+#: fortran/trans-intrinsic.c:10574 fortran/trans-stmt.c:1050
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, the event component of derived type at %L is not yet supported"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:10579
+#: fortran/trans-intrinsic.c:10581
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "environment variable \"%s\" not defined"
 msgid "The event variable at %L shall not be coindexed"
@@ -69894,7 +69983,7 @@
 msgid "Sorry, only support for integer kind %d implemented for image-set at %L"
 msgstr ""
 
-#: fortran/trans-stmt.c:3346
+#: fortran/trans-stmt.c:3343
 #, fuzzy, gcc-internal-format
 #| msgid "gfc_trans_code(): Bad statement code"
 msgid "gfc_trans_select(): Bad type for case expr."
@@ -70040,7 +70129,7 @@
 msgid "two or more sections for %s"
 msgstr "dua atau lebih tipe data dalam deklarasi dari %qs"
 
-#: lto/lto-partition.c:516
+#: lto/lto-partition.c:570
 #, gcc-internal-format
 msgid "min partition size cannot be greater than max partition size"
 msgstr ""
@@ -70195,64 +70284,64 @@
 msgid "Cannot read %s"
 msgstr "tidak dapat membuka %s"
 
-#: lto/lto.c:2369
+#: lto/lto.c:2337
 #, gcc-internal-format
 msgid "lto_obj_file_open() failed"
 msgstr ""
 
-#: lto/lto.c:2394
+#: lto/lto.c:2362
 #, fuzzy, gcc-internal-format
 #| msgid "pex_init failed"
 msgid "waitpid failed"
 msgstr "pex_init gagal"
 
-#: lto/lto.c:2397
+#: lto/lto.c:2365
 #, fuzzy, gcc-internal-format
 #| msgid "renaming .rpo file"
 msgid "streaming subprocess failed"
 msgstr "mengubah nama berkas .rpo"
 
-#: lto/lto.c:2400
+#: lto/lto.c:2368
 #, gcc-internal-format
 msgid "streaming subprocess was killed by signal"
 msgstr ""
 
-#: lto/lto.c:2476
+#: lto/lto.c:2445
 #, gcc-internal-format
 msgid "no LTRANS output list filename provided"
 msgstr ""
 
-#: lto/lto.c:2564
+#: lto/lto.c:2525
 #, fuzzy, gcc-internal-format
 #| msgid "opening output file %s: %m"
 msgid "opening LTRANS output list %s: %m"
 msgstr "membuka berkas keluaran %s: %m"
 
-#: lto/lto.c:2570
+#: lto/lto.c:2532
 #, fuzzy, gcc-internal-format
 #| msgid "when writing output to %s: %m"
 msgid "writing to LTRANS output list %s: %m"
 msgstr "ketika menulis keluaran ke %s: %m"
 
-#: lto/lto.c:2581
+#: lto/lto.c:2542
 #, fuzzy, gcc-internal-format
 #| msgid "opening output file %s: %m"
 msgid "closing LTRANS output list %s: %m"
 msgstr "membuka berkas keluaran %s: %m"
 
-#: lto/lto.c:2833
+#: lto/lto.c:2794
 #, fuzzy, gcc-internal-format
 #| msgid "could not open response file %s"
 msgid "could not open symbol resolution file: %m"
 msgstr "tidak dapat membuka berkas response %s"
 
-#: lto/lto.c:2954
+#: lto/lto.c:2915
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing braces around initializer for %qT"
 msgid "missing resolution data for %s"
 msgstr "hilang kurung diantara penginisialisasi untuk %qT"
 
-#: lto/lto.c:2986
+#: lto/lto.c:2947
 #, gcc-internal-format
 msgid "errors during merging of translation units"
 msgstr ""
@@ -72578,6 +72667,9 @@
 #~ msgid "Set the target VM version"
 #~ msgstr "Set versi target VM"
 
+#~ msgid "Warn if the loop cannot be optimized due to nontrivial assumptions."
+#~ msgstr "Peringatkan jika loop tidak dapat dioptimasi karena asumsi tidak trivial."
+
 #~ msgid "Warn about constructs not instrumented by -fmudflap"
 #~ msgstr "Peringatkan ketika konstruks tidak diinstrumentasikan oleh -fmudflap"
 
@@ -74183,9 +74275,6 @@
 #~ msgid "Array PUT of intrinsic %s is too small (%i/%i) at %L"
 #~ msgstr "Array PUT dari intrinsik %s terlalu kecil (%i/%i) di %L"
 
-#~ msgid "Different character lengths in pointer assignment at %L"
-#~ msgstr "Panjang karakter berbeda dalam penempatan penunjuk di %L"
-
 #~ msgid "Reference to ENTRY '%s' at %L is recursive, but procedure '%s' is not declared as RECURSIVE"
 #~ msgstr "Referensi ke MASUKAN '%s' di %L adalah rekursif, tetapi prosedur '%s' tidak dideklarasikan sebagai REKURSIF"
 
Index: gcc/po/fi.po
===================================================================
--- gcc/po/fi.po	(.../tags/gcc_8_2_0_release)
+++ gcc/po/fi.po	(.../branches/gcc-8-branch)
@@ -32,7 +32,7 @@
 msgstr ""
 "Project-Id-Version: gcc 6.1-b20160131\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2018-05-01 20:30+0000\n"
+"POT-Creation-Date: 2018-07-25 14:25+0000\n"
 "PO-Revision-Date: 2016-02-06 01:01+0200\n"
 "Last-Translator: Lauri Nurmi <lanurmi@iki.fi>\n"
 "Language-Team: Finnish <translation-team-fi@lists.sourceforge.net>\n"
@@ -66,12 +66,12 @@
 msgid "[cannot find %s]"
 msgstr "lähdetiedostoa %s ei löydy"
 
-#: collect2.c:1557
+#: collect2.c:1585
 #, fuzzy, c-format
 msgid "collect2 version %s\n"
 msgstr "gcc-versio %s %s\n"
 
-#: collect2.c:1664
+#: collect2.c:1692
 #, c-format
 msgid "%d constructor found\n"
 msgid_plural "%d constructors found\n"
@@ -78,7 +78,7 @@
 msgstr[0] "löytyi %d muodostin\n"
 msgstr[1] "löytyi %d muodostinta\n"
 
-#: collect2.c:1668
+#: collect2.c:1696
 #, c-format
 msgid "%d destructor found\n"
 msgid_plural "%d destructors found\n"
@@ -85,7 +85,7 @@
 msgstr[0] "löytyi %d hajotin\n"
 msgstr[1] "löytyi %d hajotinta\n"
 
-#: collect2.c:1672
+#: collect2.c:1700
 #, c-format
 msgid "%d frame table found\n"
 msgid_plural "%d frame tables found\n"
@@ -92,12 +92,12 @@
 msgstr[0] "löytyi %d kehystaulu\n"
 msgstr[1] "löytyi %d kehystaulua\n"
 
-#: collect2.c:1836
+#: collect2.c:1864
 #, fuzzy, c-format
 msgid "[Leaving %s]\n"
 msgstr "%s[%u]: Poistutaan hakemistosta ”%s”\n"
 
-#: collect2.c:2068
+#: collect2.c:2094
 #, c-format
 msgid ""
 "\n"
@@ -104,7 +104,7 @@
 "write_c_file - output name is %s, prefix is %s\n"
 msgstr ""
 
-#: collect2.c:2584
+#: collect2.c:2610
 #, c-format
 msgid ""
 "\n"
@@ -127,7 +127,7 @@
 msgid "%s: some warnings being treated as errors"
 msgstr "%s: varoitus: ei lukuoikeuksia tiedostoon ”%s”\n"
 
-#: diagnostic.c:324 input.c:222 input.c:1834 c-family/c-opts.c:1377
+#: diagnostic.c:324 input.c:222 input.c:1834 c-family/c-opts.c:1392
 #: fortran/cpp.c:576 fortran/error.c:1008 fortran/error.c:1028
 msgid "<built-in>"
 msgstr "<sisäinen>"
@@ -221,13 +221,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:4164 config/arc/arc.c:5784 config/i386/i386.c:17302
+#: final.c:4164 config/arc/arc.c:5775 config/i386/i386.c:17305
 #: config/pdp11/pdp11.c:1715
 #, c-format
 msgid "floating constant misused"
 msgstr "liukulukuvakiota käytetty väärin"
 
-#: final.c:4222 config/arc/arc.c:5881 config/i386/i386.c:17393
+#: final.c:4222 config/arc/arc.c:5872 config/i386/i386.c:17396
 #: config/pdp11/pdp11.c:1756
 #, c-format
 msgid "invalid expression as operand"
@@ -1223,7 +1223,7 @@
 msgid "GCSE disabled"
 msgstr "[ei käytössä]"
 
-#: gimple-ssa-isolate-paths.c:542 c/c-typeck.c:10240
+#: gimple-ssa-isolate-paths.c:542 c/c-typeck.c:10245
 #, gcc-internal-format
 msgid "function returns address of local variable"
 msgstr "funktio palauttaa osoitteen paikalliseen muuttujaan"
@@ -1536,7 +1536,7 @@
 msgid "options enabled: "
 msgstr "käyttöön otetut valitsimet: "
 
-#: tree-diagnostic.c:299 c/c-decl.c:5419 c/c-typeck.c:7259 cp/error.c:1042
+#: tree-diagnostic.c:299 c/c-decl.c:5439 c/c-typeck.c:7264 cp/error.c:1042
 #: c-family/c-pretty-print.c:413
 #, gcc-internal-format
 msgid "<anonymous>"
@@ -3022,64 +3022,64 @@
 msgstr "pituusmääre strfmon-muotoilussa"
 
 #. Handle deferred options from command-line.
-#: c-family/c-opts.c:1402 fortran/cpp.c:590
+#: c-family/c-opts.c:1417 fortran/cpp.c:590
 msgid "<command-line>"
 msgstr "<komentorivi>"
 
-#: config/aarch64/aarch64.c:6613
+#: config/aarch64/aarch64.c:6629
 #, fuzzy, c-format
 msgid "unsupported operand for code '%c'"
 msgstr "fr30_print_operand: tuntematon koodi"
 
-#: config/aarch64/aarch64.c:6624 config/aarch64/aarch64.c:6640
-#: config/aarch64/aarch64.c:6652 config/aarch64/aarch64.c:6663
-#: config/aarch64/aarch64.c:6673 config/aarch64/aarch64.c:6694
-#: config/aarch64/aarch64.c:6764 config/aarch64/aarch64.c:6775
-#: config/aarch64/aarch64.c:6789 config/aarch64/aarch64.c:7011
-#: config/aarch64/aarch64.c:7029
+#: config/aarch64/aarch64.c:6640 config/aarch64/aarch64.c:6656
+#: config/aarch64/aarch64.c:6668 config/aarch64/aarch64.c:6679
+#: config/aarch64/aarch64.c:6689 config/aarch64/aarch64.c:6710
+#: config/aarch64/aarch64.c:6780 config/aarch64/aarch64.c:6791
+#: config/aarch64/aarch64.c:6805 config/aarch64/aarch64.c:7027
+#: config/aarch64/aarch64.c:7045
 #, fuzzy, c-format
 msgid "invalid operand for '%%%c'"
 msgstr "virheellinen const_double-operandi"
 
-#: config/aarch64/aarch64.c:6709 config/aarch64/aarch64.c:6720
-#: config/aarch64/aarch64.c:6871 config/aarch64/aarch64.c:6882
+#: config/aarch64/aarch64.c:6725 config/aarch64/aarch64.c:6736
+#: config/aarch64/aarch64.c:6887 config/aarch64/aarch64.c:6898
 #, fuzzy, c-format
 msgid "invalid vector constant"
 msgstr "virheellinen rotate-käsky"
 
-#: config/aarch64/aarch64.c:6732 config/aarch64/aarch64.c:6744
-#: config/aarch64/aarch64.c:6755
+#: config/aarch64/aarch64.c:6748 config/aarch64/aarch64.c:6760
+#: config/aarch64/aarch64.c:6771
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6823 config/arm/arm.c:22704
+#: config/aarch64/aarch64.c:6839 config/arm/arm.c:22704
 #, c-format
 msgid "missing operand"
 msgstr "puuttuva operandi"
 
-#: config/aarch64/aarch64.c:6908
+#: config/aarch64/aarch64.c:6924
 #, fuzzy, c-format
 msgid "invalid constant"
 msgstr "virheellinen rotate-käsky"
 
-#: config/aarch64/aarch64.c:6911
+#: config/aarch64/aarch64.c:6927
 #, fuzzy, c-format
 msgid "invalid operand"
 msgstr "muotomerkkijonolla on epäkelpo operandinumero"
 
-#: config/aarch64/aarch64.c:7040 config/aarch64/aarch64.c:7045
+#: config/aarch64/aarch64.c:7056 config/aarch64/aarch64.c:7061
 #, fuzzy, c-format
 msgid "invalid operand prefix '%%%c'"
 msgstr "virheellinen etuliite ”0b” liukulukuvakiolle"
 
-#: config/aarch64/aarch64.c:7062
+#: config/aarch64/aarch64.c:7078
 #, fuzzy, c-format
 msgid "invalid address mode"
 msgstr "virheellinen %%G-tila"
 
-#: config/alpha/alpha.c:5125 config/i386/i386.c:18558
-#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21798
+#: config/alpha/alpha.c:5125 config/i386/i386.c:18561
+#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21875
 #: config/sparc/sparc.c:9290
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
@@ -3096,7 +3096,7 @@
 msgstr "virheellinen %%r-arvo"
 
 #: config/alpha/alpha.c:5223 config/ia64/ia64.c:5534
-#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21506
+#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21583
 #: config/xtensa/xtensa.c:2429
 #, c-format
 msgid "invalid %%R value"
@@ -3103,13 +3103,13 @@
 msgstr "virheellinen %%R-arvo"
 
 #: config/alpha/alpha.c:5229 config/powerpcspe/powerpcspe.c:23933
-#: config/rs6000/rs6000.c:21426 config/xtensa/xtensa.c:2396
+#: config/rs6000/rs6000.c:21503 config/xtensa/xtensa.c:2396
 #, c-format
 msgid "invalid %%N value"
 msgstr "virheellinen %%N-arvo"
 
 #: config/alpha/alpha.c:5237 config/powerpcspe/powerpcspe.c:23961
-#: config/rs6000/rs6000.c:21454
+#: config/rs6000/rs6000.c:21531
 #, c-format
 msgid "invalid %%P value"
 msgstr "virheellinen %%P-arvo"
@@ -3140,7 +3140,7 @@
 msgstr "virheellinen %%U-arvo"
 
 #: config/alpha/alpha.c:5323 config/powerpcspe/powerpcspe.c:24021
-#: config/rs6000/rs6000.c:21514
+#: config/rs6000/rs6000.c:21591
 #, c-format
 msgid "invalid %%s value"
 msgstr "virheellinen %%s-arvo"
@@ -3151,7 +3151,7 @@
 msgstr "virheellinen %%C-arvo"
 
 #: config/alpha/alpha.c:5371 config/powerpcspe/powerpcspe.c:23797
-#: config/rs6000/rs6000.c:21290
+#: config/rs6000/rs6000.c:21367
 #, c-format
 msgid "invalid %%E value"
 msgstr "virheellinen %%E-arvo"
@@ -3162,7 +3162,7 @@
 msgstr "uudelleensijoitusvirhe"
 
 #: config/alpha/alpha.c:5405 config/cr16/cr16.c:1569
-#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21803
+#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21880
 #: config/spu/spu.c:1458
 #, c-format
 msgid "invalid %%xn code"
@@ -3173,58 +3173,58 @@
 msgid "invalid operand address"
 msgstr "PRINT_OPERAND_ADDRESS, null-osoitin"
 
-#: config/arc/arc.c:3810
+#: config/arc/arc.c:3808
 #, c-format
 msgid "invalid operand to %%Z code"
 msgstr "virheellinen %%Z-operandi"
 
-#: config/arc/arc.c:3818
+#: config/arc/arc.c:3816
 #, c-format
 msgid "invalid operand to %%z code"
 msgstr "virheellinen %%Z-operandi"
 
-#: config/arc/arc.c:3826
+#: config/arc/arc.c:3824
 #, fuzzy, c-format
 #| msgid "invalid operand to %%Z code"
 msgid "invalid operands to %%c code"
 msgstr "virheellinen %%Z-operandi"
 
-#: config/arc/arc.c:3834
+#: config/arc/arc.c:3832
 #, c-format
 msgid "invalid operand to %%M code"
 msgstr "virheellinen %%M-operandi"
 
-#: config/arc/arc.c:3842 config/m32r/m32r.c:2100
+#: config/arc/arc.c:3840 config/m32r/m32r.c:2100
 #, fuzzy, c-format
 msgid "invalid operand to %%p code"
 msgstr "fr30_print_operand: tunnistamaton %%p-koodi"
 
-#: config/arc/arc.c:3853 config/m32r/m32r.c:2093
+#: config/arc/arc.c:3851 config/m32r/m32r.c:2093
 #, fuzzy, c-format
 msgid "invalid operand to %%s code"
 msgstr "fr30_print_operand: virheellinen %%x-koodi"
 
-#: config/arc/arc.c:4001 config/m32r/m32r.c:2126
+#: config/arc/arc.c:3999 config/m32r/m32r.c:2126
 #, c-format
 msgid "invalid operand to %%R code"
 msgstr "virheellinen %%R-operandi"
 
-#: config/arc/arc.c:4077 config/m32r/m32r.c:2149
+#: config/arc/arc.c:4075 config/m32r/m32r.c:2149
 #, c-format
 msgid "invalid operand to %%H/%%L code"
 msgstr "virheellinen %%H/%%L-operandi"
 
-#: config/arc/arc.c:4145 config/m32r/m32r.c:2220
+#: config/arc/arc.c:4143 config/m32r/m32r.c:2220
 #, c-format
 msgid "invalid operand to %%U code"
 msgstr "virheellinen %%U-operandi"
 
-#: config/arc/arc.c:4157
+#: config/arc/arc.c:4155
 #, c-format
 msgid "invalid operand to %%V code"
 msgstr "virheellinen %%V-operandi"
 
-#: config/arc/arc.c:4214
+#: config/arc/arc.c:4212
 #, c-format
 msgid "invalid operand to %%O code"
 msgstr "virheellinen %%O-operandi"
@@ -3231,18 +3231,18 @@
 
 #. Unknown flag.
 #. Undocumented flag.
-#: config/arc/arc.c:4240 config/epiphany/epiphany.c:1305
-#: config/m32r/m32r.c:2247 config/nds32/nds32.c:3079 config/sparc/sparc.c:9569
+#: config/arc/arc.c:4238 config/epiphany/epiphany.c:1305
+#: config/m32r/m32r.c:2247 config/nds32/nds32.c:3080 config/sparc/sparc.c:9569
 #, fuzzy, c-format
 msgid "invalid operand output code"
 msgstr "fr30_print_operand: virheellinen %%x-koodi"
 
-#: config/arc/arc.c:5869
+#: config/arc/arc.c:5860
 #, fuzzy, c-format
 msgid "invalid UNSPEC as operand: %d"
 msgstr "virheellinen lauseke kohdemuuttujana"
 
-#: config/arc/arc.c:6158 config/cris/cris.c:2568
+#: config/arc/arc.c:6149 config/cris/cris.c:2568
 #, fuzzy
 msgid "unrecognized supposed constant"
 msgstr "tunnistamaton rekisterinimi %qs"
@@ -3278,7 +3278,7 @@
 #: config/arm/arm.c:22685 config/arm/arm.c:22692 config/bfin/bfin.c:1441
 #: config/bfin/bfin.c:1448 config/bfin/bfin.c:1455 config/bfin/bfin.c:1462
 #: config/bfin/bfin.c:1471 config/bfin/bfin.c:1478 config/bfin/bfin.c:1485
-#: config/bfin/bfin.c:1492 config/nds32/nds32.c:3098
+#: config/bfin/bfin.c:1492 config/nds32/nds32.c:3099
 #, fuzzy, c-format
 msgid "invalid operand for code '%c'"
 msgstr "fr30_print_operand: virheellinen %%x-koodi"
@@ -3651,98 +3651,98 @@
 msgid "bad output_condmove_single operand"
 msgstr ""
 
-#: config/i386/i386.c:17387
+#: config/i386/i386.c:17390
 #, fuzzy, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "virheellinen const_double-operandi"
 
-#: config/i386/i386.c:17925
+#: config/i386/i386.c:17928
 #, fuzzy, c-format
 #| msgid "invalid use of %<restrict%>"
 msgid "invalid use of register '%s'"
 msgstr "epäkelpo %<restrict%>-avainsanan käyttö"
 
-#: config/i386/i386.c:17930
+#: config/i386/i386.c:17933
 #, fuzzy, c-format
 msgid "invalid use of asm flag output"
 msgstr "virheellinen lvalue asm-tulosteessa %d"
 
-#: config/i386/i386.c:18160
+#: config/i386/i386.c:18163
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr "fr30_print_operand: virheellinen %%x-koodi"
 
-#: config/i386/i386.c:18195
+#: config/i386/i386.c:18198
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr "fr30_print_operand: virheellinen %%x-koodi"
 
-#: config/i386/i386.c:18264
+#: config/i386/i386.c:18267
 #, fuzzy, c-format
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/i386/i386.c:18269
+#: config/i386/i386.c:18272
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'Z'"
 msgstr "fr30_print_operand: virheellinen %%x-koodi"
 
-#: config/i386/i386.c:18346
+#: config/i386/i386.c:18349
 #, fuzzy, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "fr30_print_operand: virheellinen %%F-koodi"
 
-#: config/i386/i386.c:18425
+#: config/i386/i386.c:18428
 #, fuzzy, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "fr30_print_operand: virheellinen %%x-koodi"
 
-#: config/i386/i386.c:18443
+#: config/i386/i386.c:18446
 #, fuzzy, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "fr30_print_operand: virheellinen %%x-koodi"
 
-#: config/i386/i386.c:18456
+#: config/i386/i386.c:18459
 #, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr ""
 
-#: config/i386/i386.c:18471
+#: config/i386/i386.c:18474
 #, fuzzy, c-format
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr "fr30_print_operand: virheellinen %%F-koodi"
 
-#: config/i386/i386.c:18499
+#: config/i386/i386.c:18502
 #, fuzzy, c-format
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr "fr30_print_operand: virheellinen %%F-koodi"
 
-#: config/i386/i386.c:18517
+#: config/i386/i386.c:18520
 #, fuzzy, c-format
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr "fr30_print_operand: virheellinen %%F-koodi"
 
-#: config/i386/i386.c:18540
+#: config/i386/i386.c:18543
 #, fuzzy, c-format
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "fr30_print_operand: virheellinen %%F-koodi"
 
-#: config/i386/i386.c:18626
+#: config/i386/i386.c:18629
 #, fuzzy, c-format
 msgid "invalid operand code '%c'"
 msgstr "fr30_print_operand: virheellinen %%x-koodi"
 
-#: config/i386/i386.c:18688
+#: config/i386/i386.c:18691
 #, fuzzy, c-format
 msgid "invalid constraints for operand"
 msgstr "virheellinen lauseke kohdemuuttujana"
 
-#: config/i386/i386.c:18738
+#: config/i386/i386.c:18741
 #, fuzzy, c-format
 msgid "invalid vector immediate"
 msgstr "Muotoillun tulosteen hallinta:"
 
-#: config/i386/i386.c:29572
+#: config/i386/i386.c:29575
 #, fuzzy
 msgid "unknown insn mode"
 msgstr "tuntematon move-käsky:"
@@ -3784,7 +3784,7 @@
 msgstr "virheellinen %%P-operandi"
 
 #: config/iq2000/iq2000.c:3185 config/powerpcspe/powerpcspe.c:23951
-#: config/rs6000/rs6000.c:21444
+#: config/rs6000/rs6000.c:21521
 #, c-format
 msgid "invalid %%p value"
 msgstr "virheellinen %%p-arvo"
@@ -3843,7 +3843,7 @@
 msgstr "halutaan rekisterimuuttujan %qD osoite"
 
 #: config/m32r/m32r.c:2350 config/m32r/m32r.c:2365
-#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33292
+#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33348
 msgid "bad address"
 msgstr "virheellinen osoite"
 
@@ -3967,195 +3967,195 @@
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4411 config/rs6000/rs6000.c:4258
+#: config/powerpcspe/powerpcspe.c:4411 config/rs6000/rs6000.c:4278
 msgid "-maltivec=le not allowed for big-endian targets"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4423 config/rs6000/rs6000.c:4273
+#: config/powerpcspe/powerpcspe.c:4423 config/rs6000/rs6000.c:4293
 #, fuzzy
 msgid "-mvsx requires hardware floating point"
 msgstr "Älä käytä laitteistoliukulukuja"
 
-#: config/powerpcspe/powerpcspe.c:4431 config/rs6000/rs6000.c:4281
+#: config/powerpcspe/powerpcspe.c:4431 config/rs6000/rs6000.c:4301
 msgid "-mvsx and -mpaired are incompatible"
 msgstr "-mvsx ja -mpaired ovat yhteensopimattomat"
 
-#: config/powerpcspe/powerpcspe.c:4433 config/rs6000/rs6000.c:4283
+#: config/powerpcspe/powerpcspe.c:4433 config/rs6000/rs6000.c:4303
 msgid "-mvsx needs indexed addressing"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4438 config/rs6000/rs6000.c:4288
+#: config/powerpcspe/powerpcspe.c:4438 config/rs6000/rs6000.c:4308
 msgid "-mvsx and -mno-altivec are incompatible"
 msgstr "-mvsx ja -mno-altivec ovat yhteensopimattomat"
 
-#: config/powerpcspe/powerpcspe.c:4440 config/rs6000/rs6000.c:4290
+#: config/powerpcspe/powerpcspe.c:4440 config/rs6000/rs6000.c:4310
 #, fuzzy
 msgid "-mno-altivec disables vsx"
 msgstr "-mvsx ja -mno-altivec ovat yhteensopimattomat"
 
-#: config/powerpcspe/powerpcspe.c:4648 config/rs6000/rs6000.c:4416
+#: config/powerpcspe/powerpcspe.c:4648 config/rs6000/rs6000.c:4436
 #, fuzzy
 #| msgid "--resource requires -o"
 msgid "-mquad-memory requires 64-bit mode"
 msgstr "valitsin --resource vaatii valitsimen -o"
 
-#: config/powerpcspe/powerpcspe.c:4651 config/rs6000/rs6000.c:4419
+#: config/powerpcspe/powerpcspe.c:4651 config/rs6000/rs6000.c:4439
 msgid "-mquad-memory-atomic requires 64-bit mode"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4663 config/rs6000/rs6000.c:4431
+#: config/powerpcspe/powerpcspe.c:4663 config/rs6000/rs6000.c:4451
 msgid "-mquad-memory is not available in little endian mode"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4735 config/rs6000/rs6000.c:4512
+#: config/powerpcspe/powerpcspe.c:4735 config/rs6000/rs6000.c:4532
 #, fuzzy
 #| msgid "--resource requires -o"
 msgid "-mtoc-fusion requires 64-bit"
 msgstr "valitsin --resource vaatii valitsimen -o"
 
-#: config/powerpcspe/powerpcspe.c:4742 config/rs6000/rs6000.c:4519
+#: config/powerpcspe/powerpcspe.c:4742 config/rs6000/rs6000.c:4539
 msgid "-mtoc-fusion requires medium/large code model"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10915
+#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10947
 #, fuzzy
 msgid "bad move"
 msgstr "Siirrä alas"
 
-#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21087
+#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21164
 #, fuzzy
 msgid "Bad 128-bit move"
 msgstr "Käytä 128-bittistä long double -tyyppiä"
 
-#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21278
+#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21355
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%e value"
 msgstr "virheellinen %%E-arvo"
 
-#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21299
+#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21376
 #, c-format
 msgid "invalid %%f value"
 msgstr "virheellinen %%f-arvo"
 
-#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21308
+#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21385
 #, c-format
 msgid "invalid %%F value"
 msgstr "virheellinen %%F-arvo"
 
-#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21317
+#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21394
 #, c-format
 msgid "invalid %%G value"
 msgstr "virheellinen %%G-arvo"
 
-#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21352
+#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21429
 #, c-format
 msgid "invalid %%j code"
 msgstr "virheellinen %%j-koodi"
 
-#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21362
+#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21439
 #, c-format
 msgid "invalid %%J code"
 msgstr "virheellinen %%J-koodi"
 
-#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21372
+#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21449
 #, c-format
 msgid "invalid %%k value"
 msgstr "virheellinen %%k-arvo"
 
-#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21387
+#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21464
 #: config/xtensa/xtensa.c:2415
 #, c-format
 msgid "invalid %%K value"
 msgstr "virheellinen %%K-arvo"
 
-#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21434
+#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21511
 #, c-format
 msgid "invalid %%O value"
 msgstr "virheellinen %%O-arvo"
 
-#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21481
+#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21558
 #, c-format
 msgid "invalid %%q value"
 msgstr "virheellinen %%q-arvo"
 
-#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21534
+#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21611
 #, c-format
 msgid "invalid %%T value"
 msgstr "virheellinen %%T-arvo"
 
-#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21546
+#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21623
 #, c-format
 msgid "invalid %%u value"
 msgstr "virheellinen %%u-arvo"
 
-#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21560
+#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21637
 #: config/xtensa/xtensa.c:2384
 #, c-format
 msgid "invalid %%v value"
 msgstr "virheellinen %%v-arvo"
 
-#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21627
+#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21704
 #: config/xtensa/xtensa.c:2436
 #, c-format
 msgid "invalid %%x value"
 msgstr "virheellinen %%x-arvo"
 
-#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21747
+#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21824
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22282
+#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22359
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22288
+#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22365
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22294
+#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22371
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36572
+#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36628
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "AltiVec-argumentti välitetty funktiolle, jolla ei ole prototyyppiä"
 
-#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38739
+#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38795
 msgid "Could not generate addis value for fusion"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38809
+#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38865
 msgid "Unable to generate load/store offset for fusion"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38908
+#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38964
 #, fuzzy
 msgid "Bad GPR fusion"
 msgstr "Virheelliset merkit"
 
-#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39126
+#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39182
 msgid "emit_fusion_p9_load, bad reg #1"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39172
+#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39228
 msgid "emit_fusion_p9_load, bad reg #2"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39175
+#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39231
 msgid "emit_fusion_p9_load not MEM"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39213
+#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39269
 msgid "emit_fusion_p9_store, bad reg #1"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39259
+#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39315
 msgid "emit_fusion_p9_store, bad reg #2"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39262
+#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39318
 msgid "emit_fusion_p9_store not MEM"
 msgstr ""
 
@@ -4546,14 +4546,14 @@
 #: c/gimple-parser.c:188 c/gimple-parser.c:197 c/gimple-parser.c:226
 #: c/gimple-parser.c:1375 c/gimple-parser.c:1404 c/gimple-parser.c:1484
 #: c/gimple-parser.c:1511 c/c-parser.c:3204 c/c-parser.c:9967
-#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27841
-#: cp/parser.c:28430
+#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27838
+#: cp/parser.c:28427
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "”)” oli odotus"
 
 #: c/c-parser.c:2431 c/c-parser.c:7573 c/c-parser.c:8015 c/c-parser.c:8058
-#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27839 cp/parser.c:28448
+#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27836 cp/parser.c:28445
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "”)” oli odotus"
@@ -4568,7 +4568,7 @@
 #: c/gimple-parser.c:821 c/gimple-parser.c:837 c/gimple-parser.c:853
 #: c/gimple-parser.c:880 c/gimple-parser.c:915 c/gimple-parser.c:1038
 #: c/gimple-parser.c:1209 c/gimple-parser.c:1220 c/gimple-parser.c:1342
-#: c/gimple-parser.c:1441 cp/parser.c:28478
+#: c/gimple-parser.c:1441 cp/parser.c:28475
 #, fuzzy, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "”)” oli odotus"
@@ -4576,7 +4576,7 @@
 #: c/c-parser.c:3824 c/c-parser.c:4733 c/c-parser.c:4769 c/c-parser.c:6441
 #: c/c-parser.c:8125 c/c-parser.c:8983 c/c-parser.c:9127 c/c-parser.c:11588
 #: c/c-parser.c:18220 c/c-parser.c:18222 c/gimple-parser.c:1015
-#: cp/parser.c:28442
+#: cp/parser.c:28439
 #, fuzzy, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "”)” oli odotus"
@@ -4591,7 +4591,7 @@
 #: c/c-parser.c:17792 c/gimple-parser.c:363 c/gimple-parser.c:811
 #: c/gimple-parser.c:873 c/gimple-parser.c:911 c/gimple-parser.c:1198
 #: c/gimple-parser.c:1339 c/gimple-parser.c:1438 c/c-parser.c:11911
-#: cp/parser.c:28433
+#: cp/parser.c:28430
 #, fuzzy, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "”)” oli odotus"
@@ -4598,7 +4598,7 @@
 
 #: c/c-parser.c:4903 c/c-parser.c:10310 c/c-parser.c:16212 c/c-parser.c:18449
 #: c/gimple-parser.c:141 c/gimple-parser.c:1444 c/c-parser.c:3018
-#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18155 cp/parser.c:28439
+#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18152 cp/parser.c:28436
 #, fuzzy, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "”)” oli odotus"
@@ -4608,13 +4608,13 @@
 #: c/c-parser.c:12351 c/c-parser.c:12493 c/c-parser.c:12864 c/c-parser.c:12957
 #: c/c-parser.c:13566 c/c-parser.c:17636 c/c-parser.c:17695
 #: c/gimple-parser.c:431 c/gimple-parser.c:1492 c/gimple-parser.c:1519
-#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28472 cp/parser.c:29597
-#: cp/parser.c:32279
+#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28469 cp/parser.c:29594
+#: cp/parser.c:32276
 #, fuzzy, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "”)” oli odotus"
 
-#: c/c-parser.c:5974 cp/parser.c:28365
+#: c/c-parser.c:5974 cp/parser.c:28362
 #, fuzzy, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "odotettiin %<,%> tai %<;%>"
@@ -4624,18 +4624,18 @@
 msgid "expected %<.%>"
 msgstr "”)” oli odotus"
 
-#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30172
-#: cp/parser.c:30246
+#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30169
+#: cp/parser.c:30243
 #, fuzzy, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "odotettiin %<(%> tai rivin loppu"
 
-#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28457
+#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28454
 #, fuzzy, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "”)” oli odotus"
 
-#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28481
+#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28478
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "odotettiin %<,%> tai %<;%>"
@@ -4643,32 +4643,32 @@
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15190 c/c-parser.c:15234 c/c-parser.c:15466 c/c-parser.c:15701
 #: c/c-parser.c:17833 c/gimple-parser.c:286 c/c-parser.c:4792
-#: cp/parser.c:28460
+#: cp/parser.c:28457
 #, fuzzy, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "”)” oli odotus"
 
-#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28436
-#: cp/parser.c:30389
+#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28433
+#: cp/parser.c:30386
 #, fuzzy, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "”)” oli odotus"
 
-#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35674
+#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35671
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "odotettiin merkkijonoa ilmaisun %<#pragma message%> jälkeen"
 
-#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28445 cp/parser.c:31535
+#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28442 cp/parser.c:31532
 #, fuzzy, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "”)” oli odotus"
 
-#: c/c-typeck.c:7847
+#: c/c-typeck.c:7852
 msgid "(anonymous)"
 msgstr "(nimetön)"
 
-#: c/gimple-parser.c:795 cp/parser.c:15791 cp/parser.c:28454
+#: c/gimple-parser.c:795 cp/parser.c:15788 cp/parser.c:28451
 #, fuzzy, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "”)” oli odotus"
@@ -4945,11 +4945,11 @@
 msgid "%r%s:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr "%qs:n esittely taulukollisena tyhjiä alkioita"
 
-#: cp/pt.c:1949 cp/semantics.c:5268
+#: cp/pt.c:1949 cp/semantics.c:5271
 msgid "candidates are:"
 msgstr "ehdokkaat ovat:"
 
-#: cp/pt.c:1951 cp/pt.c:22975
+#: cp/pt.c:1951 cp/pt.c:23053
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "ehdokas on:"
@@ -5004,27 +5004,27 @@
 msgid "source type is not polymorphic"
 msgstr "lähde ei ole osoitin"
 
-#: cp/typeck.c:6083 c/c-typeck.c:4261
+#: cp/typeck.c:6083 c/c-typeck.c:4266
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "unaariselle miinus-operaatiolle annettu väärä tyyppiargumentti"
 
-#: cp/typeck.c:6084 c/c-typeck.c:4248
+#: cp/typeck.c:6084 c/c-typeck.c:4253
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "unaariselle plus-operaatiolle annettu väärä tyyppiargumentti"
 
-#: cp/typeck.c:6111 c/c-typeck.c:4302
+#: cp/typeck.c:6111 c/c-typeck.c:4307
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "bittikomplementille annettu väärä tyyppiargumentti"
 
-#: cp/typeck.c:6128 c/c-typeck.c:4310
+#: cp/typeck.c:6128 c/c-typeck.c:4315
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "abs-funktiolle annettu väärä tyyppiargumentti"
 
-#: cp/typeck.c:6140 c/c-typeck.c:4322
+#: cp/typeck.c:6140 c/c-typeck.c:4327
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "konjugaatiolle annettu väärä tyyppiargumentti"
@@ -5301,82 +5301,82 @@
 msgid "Expected attribute bit name"
 msgstr "odotettiin %<=%>, %<,%>, %<;%>, %<asm%> tai %<__attribute__%>"
 
-#: fortran/module.c:3223
+#: fortran/module.c:3225
 #, fuzzy
 msgid "Expected integer string"
 msgstr "odotettiin merkkijonoliteraalia"
 
-#: fortran/module.c:3227
+#: fortran/module.c:3229
 #, fuzzy
 msgid "Error converting integer"
 msgstr "muunnos tyypistä %qT tyyppiin %qT"
 
-#: fortran/module.c:3249
+#: fortran/module.c:3251
 #, fuzzy
 msgid "Expected real string"
 msgstr "odotettiin merkkijonoliteraalia"
 
-#: fortran/module.c:3474
+#: fortran/module.c:3476
 #, fuzzy
 msgid "Expected expression type"
 msgstr "odotettiin lauseketta"
 
-#: fortran/module.c:3554
+#: fortran/module.c:3556
 #, fuzzy
 msgid "Bad operator"
 msgstr "  eikä %<operator=(const %T&)%>"
 
-#: fortran/module.c:3671
+#: fortran/module.c:3673
 #, fuzzy
 msgid "Bad type in constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: fortran/module.c:7038
+#: fortran/module.c:7040
 #, fuzzy
 msgid "Unexpected end of module"
 msgstr "Odottamaton END-lause kohdassa %C"
 
-#: fortran/parse.c:1757
+#: fortran/parse.c:1761
 #, fuzzy
 msgid "arithmetic IF"
 msgstr "%<void *%>-tyyppistä osoitinta käytetty laskutoimituksessa"
 
-#: fortran/parse.c:1766
+#: fortran/parse.c:1770
 #, fuzzy
 msgid "attribute declaration"
 msgstr "%<[*]%> ei ole esittelyssä"
 
-#: fortran/parse.c:1802
+#: fortran/parse.c:1806
 #, fuzzy
 msgid "data declaration"
 msgstr "Syntaksivirhe data-esittelyssä kohdassa %C"
 
-#: fortran/parse.c:1820
+#: fortran/parse.c:1824
 #, fuzzy
 msgid "derived type declaration"
 msgstr "tyhjä esittely"
 
-#: fortran/parse.c:1947
+#: fortran/parse.c:1951
 #, fuzzy
 msgid "block IF"
 msgstr "lohkolaite"
 
-#: fortran/parse.c:1956
+#: fortran/parse.c:1960
 #, fuzzy
 msgid "implied END DO"
 msgstr "syötteen loppu"
 
-#: fortran/parse.c:2050 fortran/resolve.c:11199
+#: fortran/parse.c:2054 fortran/resolve.c:11219
 #, fuzzy
 msgid "assignment"
 msgstr "Eri tyypit osoitinsijoituksessa kohdassa %L; yritettiin tyypin %s sijoitusta tyyppiin %s"
 
-#: fortran/parse.c:2053 fortran/resolve.c:11250 fortran/resolve.c:11253
+#: fortran/parse.c:2057 fortran/resolve.c:11270 fortran/resolve.c:11273
 #, fuzzy
 msgid "pointer assignment"
 msgstr "Rajapintatäsmäämättömyys proseduuriosoitinsijoituksessa kohdassa %L: %s"
 
-#: fortran/parse.c:2071
+#: fortran/parse.c:2075
 #, fuzzy
 msgid "simple IF"
 msgstr ""
@@ -5497,116 +5497,121 @@
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:3878
+#: fortran/resolve.c:3879
 #, c-format
+msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
+msgstr ""
+
+#: fortran/resolve.c:3884
+#, c-format
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3893
+#: fortran/resolve.c:3899
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3926
+#: fortran/resolve.c:3932
 #, c-format
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3949
+#: fortran/resolve.c:3955
 #, fuzzy, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr "pilkkuoperaattori #if:in operandissa"
 
-#: fortran/resolve.c:3963
+#: fortran/resolve.c:3969
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr ""
 
-#: fortran/resolve.c:4015
+#: fortran/resolve.c:4021
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr ""
 
-#: fortran/resolve.c:4021
+#: fortran/resolve.c:4027
 #, c-format
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4034
+#: fortran/resolve.c:4040
 #, fuzzy, c-format
 #| msgid "<unknown operator>"
 msgid "Unknown operator %%<%s%%> at %%L; did you mean '%s'?"
 msgstr "tuntematon binäärioperaattori"
 
-#: fortran/resolve.c:4037
+#: fortran/resolve.c:4043
 #, fuzzy, c-format
 #| msgid "<unknown operator>"
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr "tuntematon binäärioperaattori"
 
-#: fortran/resolve.c:4040
+#: fortran/resolve.c:4046
 #, c-format
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:4044
+#: fortran/resolve.c:4050
 #, c-format
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4132
+#: fortran/resolve.c:4138
 #, fuzzy, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "Yhteensopimattomat tasot %d ja %d sijoituksessa kohdassa %L"
 
-#: fortran/resolve.c:6849
+#: fortran/resolve.c:6855
 msgid "Loop variable"
 msgstr "Silmukkamuuttuja"
 
-#: fortran/resolve.c:6853
+#: fortran/resolve.c:6859
 #, fuzzy
 msgid "iterator variable"
 msgstr "Syntaksivirhe iteraattorissa kohdassa %C"
 
-#: fortran/resolve.c:6857
+#: fortran/resolve.c:6863
 msgid "Start expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:6861
+#: fortran/resolve.c:6867
 #, fuzzy
 msgid "End expression in DO loop"
 msgstr "Ennenaikainen säännöllisen lausekkeen loppu"
 
-#: fortran/resolve.c:6865
+#: fortran/resolve.c:6871
 #, fuzzy
 msgid "Step expression in DO loop"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/resolve.c:7150 fortran/resolve.c:7153
+#: fortran/resolve.c:7156 fortran/resolve.c:7159
 #, fuzzy
 msgid "DEALLOCATE object"
 msgstr "EI OBJEKTIA\n"
 
-#: fortran/resolve.c:7525 fortran/resolve.c:7528
+#: fortran/resolve.c:7531 fortran/resolve.c:7534
 #, fuzzy
 msgid "ALLOCATE object"
 msgstr "EI OBJEKTIA\n"
 
-#: fortran/resolve.c:7720 fortran/resolve.c:9417
+#: fortran/resolve.c:7726 fortran/resolve.c:9428
 #, fuzzy
 msgid "STAT variable"
 msgstr "tiedoston tilan lukeminen epäonnistui"
 
-#: fortran/resolve.c:7764 fortran/resolve.c:9429
+#: fortran/resolve.c:7770 fortran/resolve.c:9440
 #, fuzzy
 msgid "ERRMSG variable"
 msgstr "%qD ei ole muuttuja"
 
-#: fortran/resolve.c:9219
+#: fortran/resolve.c:9230
 #, fuzzy
 msgid "item in READ"
 msgstr "Soita numero"
 
-#: fortran/resolve.c:9441
+#: fortran/resolve.c:9452
 #, fuzzy
 msgid "ACQUIRED_LOCK variable"
 msgstr "uutta arkistoa ei voi lukita"
@@ -5640,7 +5645,7 @@
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:10154
+#: fortran/trans-expr.c:10157
 #, fuzzy
 msgid "Assignment of scalar to unallocated array"
 msgstr "virheellinen taulukkosijoitus"
@@ -5650,12 +5655,12 @@
 msgid "Unequal character lengths (%ld/%ld) in %s"
 msgstr "Erisuuret merkkipituudet (%ld/%ld) merkkijonossa %s kohdassa %L"
 
-#: fortran/trans-intrinsic.c:8088
+#: fortran/trans-intrinsic.c:8090
 #, fuzzy, c-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative (its value is %ld)"
 msgstr "%<__builtin_args_info%>-funktion argumentin pitää olla vakio"
 
-#: fortran/trans-intrinsic.c:8120
+#: fortran/trans-intrinsic.c:8122
 msgid "Argument NCOPIES of REPEAT intrinsic is too large"
 msgstr ""
 
@@ -5677,16 +5682,16 @@
 msgid "Invalid image number %d in SYNC IMAGES"
 msgstr ""
 
-#: fortran/trans-stmt.c:2180
+#: fortran/trans-stmt.c:2177
 msgid "Loop iterates infinitely"
 msgstr ""
 
-#: fortran/trans-stmt.c:2200 fortran/trans-stmt.c:2456
+#: fortran/trans-stmt.c:2197 fortran/trans-stmt.c:2453
 #, fuzzy
 msgid "Loop variable has been modified"
 msgstr "Tiedostoa ”%s” on muokattu sen avaamisen jälkeen."
 
-#: fortran/trans-stmt.c:2309
+#: fortran/trans-stmt.c:2306
 #, fuzzy
 msgid "DO step value is zero"
 msgstr "Odotettiin askelarvoa iteraattorissa kohdassa %C"
@@ -6328,10 +6333,10 @@
 msgid "Allow dollar signs in entity names."
 msgstr ""
 
-#: fortran/lang.opt:485 config/alpha/alpha.opt:31 common.opt:783
-#: common.opt:985 common.opt:989 common.opt:993 common.opt:997 common.opt:1532
-#: common.opt:1588 common.opt:1712 common.opt:1716 common.opt:1946
-#: common.opt:2116 common.opt:2792
+#: fortran/lang.opt:485 config/alpha/alpha.opt:31 common.opt:649
+#: common.opt:783 common.opt:989 common.opt:993 common.opt:997 common.opt:1001
+#: common.opt:1536 common.opt:1592 common.opt:1716 common.opt:1720
+#: common.opt:1950 common.opt:2120 common.opt:2796
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr ""
 
@@ -6560,12 +6565,12 @@
 msgstr ""
 
 #: fortran/lang.opt:751 c-family/c.opt:1356 c-family/c.opt:1384
-#: c-family/c.opt:1634 config/pa/pa.opt:42 config/pa/pa.opt:70 common.opt:1154
-#: common.opt:1333 common.opt:1408 common.opt:1676 common.opt:1799
-#: common.opt:2169 common.opt:2205 common.opt:2298 common.opt:2302
-#: common.opt:2407 common.opt:2498 common.opt:2506 common.opt:2514
-#: common.opt:2522 common.opt:2623 common.opt:2675 common.opt:2755
-#: common.opt:2893 common.opt:2897 common.opt:2901 common.opt:2905
+#: c-family/c.opt:1634 config/pa/pa.opt:42 config/pa/pa.opt:70 common.opt:1158
+#: common.opt:1337 common.opt:1412 common.opt:1680 common.opt:1803
+#: common.opt:2173 common.opt:2209 common.opt:2302 common.opt:2306
+#: common.opt:2411 common.opt:2502 common.opt:2510 common.opt:2518
+#: common.opt:2526 common.opt:2627 common.opt:2679 common.opt:2759
+#: common.opt:2897 common.opt:2901 common.opt:2905 common.opt:2909
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr ""
 
@@ -6626,7 +6631,7 @@
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:220 c-family/c.opt:224
 #: c-family/c.opt:236 c-family/c.opt:1855 c-family/c.opt:1863 brig/lang.opt:39
-#: config/darwin.opt:56 common.opt:338 common.opt:341 common.opt:3046
+#: config/darwin.opt:56 common.opt:338 common.opt:341 common.opt:3050
 #, c-format
 msgid "missing filename after %qs"
 msgstr "tiedostonimi puuttuu %qs:n jälkeen"
@@ -7303,7 +7308,7 @@
 #: c-family/c.opt:1525 c-family/c.opt:1528 c-family/c.opt:1569
 #: c-family/c.opt:1704 c-family/c.opt:1731 c-family/c.opt:1771
 #: c-family/c.opt:1802 c-family/c.opt:1806 c-family/c.opt:1822
-#: config/ia64/ia64.opt:167 config/ia64/ia64.opt:170 c-family/c-opts.c:434
+#: config/ia64/ia64.opt:167 config/ia64/ia64.opt:170 c-family/c-opts.c:432
 #, gcc-internal-format
 msgid "switch %qs is no longer supported"
 msgstr "valitsin %qs ei ole enää tuettu"
@@ -15681,10 +15686,6 @@
 msgid "Warn if dereferencing a NULL pointer may lead to erroneous or undefined behavior."
 msgstr ""
 
-#: common.opt:649
-msgid "Warn if the loop cannot be optimized due to nontrivial assumptions."
-msgstr ""
-
 #: common.opt:656
 msgid "Warn about some C++ One Definition Rule violations during link time optimization."
 msgstr ""
@@ -15892,1810 +15893,1810 @@
 msgid "-dumpdir <dir>\tSet the directory name to be used for dumps."
 msgstr ""
 
-#: common.opt:946
+#: common.opt:950
 msgid "The version of the C++ ABI in use."
 msgstr "Käytössä olevan C++-ABIn versio."
 
-#: common.opt:950
+#: common.opt:954
 msgid "Aggressively optimize loops using language constraints."
 msgstr ""
 
-#: common.opt:954
+#: common.opt:958
 msgid "Align the start of functions."
 msgstr "Kohdista funktioiden alut."
 
-#: common.opt:964
+#: common.opt:968
 msgid "Align labels which are only reached by jumping."
 msgstr ""
 
-#: common.opt:971
+#: common.opt:975
 #, fuzzy
 msgid "Align all labels."
 msgstr "useita default-nimikkeitä samassa switch-lauseessa"
 
-#: common.opt:978
+#: common.opt:982
 msgid "Align the start of loops."
 msgstr "Kohdista silmukoiden alut."
 
-#: common.opt:1001
+#: common.opt:1005
 #, fuzzy
 msgid "Select what to sanitize."
 msgstr "Mikä on Crowdin?"
 
-#: common.opt:1005
+#: common.opt:1009
 #, fuzzy
 msgid "Select type of coverage sanitization."
 msgstr "Mikä on Crowdin?"
 
-#: common.opt:1009
+#: common.opt:1013
 msgid "-fasan-shadow-offset=<number>\tUse custom shadow memory offset."
 msgstr ""
 
-#: common.opt:1013
+#: common.opt:1017
 msgid "-fsanitize-sections=<sec1,sec2,...>\tSanitize global variables in user-defined sections."
 msgstr ""
 
-#: common.opt:1018
+#: common.opt:1022
 msgid "After diagnosing undefined behavior attempt to continue execution."
 msgstr ""
 
-#: common.opt:1022
+#: common.opt:1026
 msgid "This switch is deprecated; use -fsanitize-recover= instead."
 msgstr ""
 
-#: common.opt:1029
+#: common.opt:1033
 msgid "Use trap instead of a library function for undefined behavior sanitization."
 msgstr ""
 
-#: common.opt:1033
+#: common.opt:1037
 msgid "Generate unwind tables that are exact at each instruction boundary."
 msgstr ""
 
-#: common.opt:1037
+#: common.opt:1041
 #, fuzzy
 msgid "Generate auto-inc/dec instructions."
 msgstr "Käytä AltiVec-käskyjä"
 
-#: common.opt:1041
+#: common.opt:1045
 msgid "Use sample profile information for call graph node weights. The default profile file is fbdata.afdo in 'pwd'."
 msgstr ""
 
-#: common.opt:1046
+#: common.opt:1050
 msgid "Use sample profile information for call graph node weights. The profile file is specified in the argument."
 msgstr ""
 
-#: common.opt:1055
+#: common.opt:1059
 #, fuzzy
 msgid "Generate code to check bounds before indexing arrays."
 msgstr "Käytä AltiVec-käskyjä"
 
-#: common.opt:1059
+#: common.opt:1063
 msgid "Replace add, compare, branch with branch on count register."
 msgstr ""
 
-#: common.opt:1063
+#: common.opt:1067
 msgid "Use profiling information for branch probabilities."
 msgstr ""
 
-#: common.opt:1067
+#: common.opt:1071
 msgid "Perform branch target load optimization before prologue / epilogue threading."
 msgstr ""
 
-#: common.opt:1071
+#: common.opt:1075
 msgid "Perform branch target load optimization after prologue / epilogue threading."
 msgstr ""
 
-#: common.opt:1075
+#: common.opt:1079
 msgid "Restrict target load migration not to re-use registers in any basic block."
 msgstr ""
 
-#: common.opt:1079
+#: common.opt:1083
 msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions."
 msgstr ""
 
-#: common.opt:1083
+#: common.opt:1087
 msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls."
 msgstr ""
 
-#: common.opt:1090
+#: common.opt:1094
 msgid "Save registers around function calls."
 msgstr ""
 
-#: common.opt:1094
+#: common.opt:1098
 msgid "This switch is deprecated; do not use."
 msgstr "Tämä valitsin on vanhentunut; älä käytä."
 
-#: common.opt:1098
+#: common.opt:1102
 msgid "Check the return value of new in C++."
 msgstr "Tarkista C++:n new’n paluuarvo."
 
-#: common.opt:1102 common.opt:1106
+#: common.opt:1106 common.opt:1110
 msgid "Perform internal consistency checkings."
 msgstr ""
 
-#: common.opt:1110
+#: common.opt:1114
 #, fuzzy
 #| msgid "Enable function profiling."
 msgid "Enable code hoisting."
 msgstr "Ota käyttöön funktioprofilointi."
 
-#: common.opt:1114
+#: common.opt:1118
 msgid "Looks for opportunities to reduce stack adjustments and stack references."
 msgstr ""
 
-#: common.opt:1118
+#: common.opt:1122
 #, fuzzy
 #| msgid "%qD is used uninitialized in this function"
 msgid "Do not put uninitialized globals in the common section."
 msgstr "%qD:a käytetään alustamattomana tässä funktiossa"
 
-#: common.opt:1126
+#: common.opt:1130
 msgid "-fcompare-debug[=<opts>]\tCompile with and without e.g. -gtoggle, and compare the final-insns dump."
 msgstr ""
 
-#: common.opt:1130
+#: common.opt:1134
 msgid "Run only the second compilation of -fcompare-debug."
 msgstr ""
 
-#: common.opt:1134
+#: common.opt:1138
 msgid "Perform comparison elimination after register allocation has finished."
 msgstr ""
 
-#: common.opt:1138
+#: common.opt:1142
 msgid "Do not perform optimizations increasing noticeably stack usage."
 msgstr ""
 
-#: common.opt:1142
+#: common.opt:1146
 msgid "Perform a register copy-propagation optimization pass."
 msgstr ""
 
-#: common.opt:1146
+#: common.opt:1150
 msgid "Perform cross-jumping optimization."
 msgstr ""
 
-#: common.opt:1150
+#: common.opt:1154
 msgid "When running CSE, follow jumps to their targets."
 msgstr ""
 
-#: common.opt:1158
+#: common.opt:1162
 msgid "Omit range reduction step when performing complex division."
 msgstr ""
 
-#: common.opt:1162
+#: common.opt:1166
 msgid "Complex multiplication and division follow Fortran rules."
 msgstr ""
 
-#: common.opt:1166
+#: common.opt:1170
 msgid "Place data items into their own section."
 msgstr ""
 
-#: common.opt:1170
+#: common.opt:1174
 msgid "List all available debugging counters with their limits and counts."
 msgstr ""
 
-#: common.opt:1174
+#: common.opt:1178
 msgid "-fdbg-cnt=<counter>:<limit>[,<counter>:<limit>,...]\tSet the debug counter limit."
 msgstr ""
 
-#: common.opt:1178
+#: common.opt:1182
 msgid "-fdebug-prefix-map=<old>=<new> Map one directory name to another in debug information."
 msgstr ""
 
-#: common.opt:1182
+#: common.opt:1186
 msgid "-ffile-prefix-map=<old>=<new> Map one directory name to another in compilation result."
 msgstr ""
 
-#: common.opt:1186
+#: common.opt:1190
 msgid "Output .debug_types section when using DWARF v4 debuginfo."
 msgstr ""
 
-#: common.opt:1192
+#: common.opt:1196
 msgid "Defer popping functions args from stack until later."
 msgstr ""
 
-#: common.opt:1196
+#: common.opt:1200
 msgid "Attempt to fill delay slots of branch instructions."
 msgstr ""
 
-#: common.opt:1200
+#: common.opt:1204
 msgid "Delete dead instructions that may throw exceptions."
 msgstr ""
 
-#: common.opt:1204
+#: common.opt:1208
 msgid "Delete useless null pointer checks."
 msgstr ""
 
-#: common.opt:1208
+#: common.opt:1212
 msgid "Stream extra data to support more aggressive devirtualization in LTO local transformation mode."
 msgstr ""
 
-#: common.opt:1212
+#: common.opt:1216
 #, fuzzy
 msgid "Perform speculative devirtualization."
 msgstr "Suorita uusille äänitetyille tiedotteille:"
 
-#: common.opt:1216
+#: common.opt:1220
 msgid "Try to convert virtual calls to direct ones."
 msgstr ""
 
-#: common.opt:1220
+#: common.opt:1224
 msgid "-fdiagnostics-show-location=[once|every-line]\tHow often to emit source location at the beginning of line-wrapped diagnostics."
 msgstr ""
 
-#: common.opt:1237
+#: common.opt:1241
 msgid "Show the source line with a caret indicating the column."
 msgstr ""
 
-#: common.opt:1245
+#: common.opt:1249
 #, fuzzy
 msgid "-fdiagnostics-color=[never|always|auto]\tColorize diagnostics."
 msgstr "     --color[=<milloin>]  väritä tuloste (auto, always tai never)\n"
 
-#: common.opt:1265
+#: common.opt:1269
 msgid "Print fix-it hints in machine-readable form."
 msgstr ""
 
-#: common.opt:1269
+#: common.opt:1273
 msgid "Print fix-it hints to stderr in unified diff format."
 msgstr ""
 
-#: common.opt:1273
+#: common.opt:1277
 msgid "Amend appropriate diagnostic messages with the command line option that controls them."
 msgstr ""
 
-#: common.opt:1277
+#: common.opt:1281
 msgid "-fdisable-[tree|rtl|ipa]-<pass>=range1+range2 disables an optimization pass."
 msgstr ""
 
-#: common.opt:1281
+#: common.opt:1285
 msgid "-fenable-[tree|rtl|ipa]-<pass>=range1+range2 enables an optimization pass."
 msgstr ""
 
-#: common.opt:1285
+#: common.opt:1289
 msgid "-fdump-<type>\tDump various compiler internals to a file."
 msgstr ""
 
-#: common.opt:1292
+#: common.opt:1296
 msgid "-fdump-final-insns=filename\tDump to filename the insns at the end of translation."
 msgstr ""
 
-#: common.opt:1296
+#: common.opt:1300
 msgid "-fdump-go-spec=filename\tWrite all declarations to file as Go code."
 msgstr ""
 
-#: common.opt:1300
+#: common.opt:1304
 msgid "Suppress output of addresses in debugging dumps."
 msgstr ""
 
-#: common.opt:1304
+#: common.opt:1308
 msgid "Collect and dump debug information into temporary file if ICE in C/C++ compiler occurred."
 msgstr ""
 
-#: common.opt:1309
+#: common.opt:1313
 msgid "Dump detailed information on GCC's internal representation of source code locations."
 msgstr ""
 
-#: common.opt:1313
+#: common.opt:1317
 #, fuzzy
 msgid "Dump optimization passes."
 msgstr "%s: virheellinen ylikirjoituskertojen määrä"
 
-#: common.opt:1317
+#: common.opt:1321
 msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps."
 msgstr ""
 
-#: common.opt:1321
+#: common.opt:1325
 msgid "Suppress output of previous and next insn numbers in debugging dumps."
 msgstr ""
 
-#: common.opt:1325
+#: common.opt:1329
 msgid "Enable CFI tables via GAS assembler directives."
 msgstr "Ota käyttöön CFI-taulut GAS-assembler-direktiivien kautta"
 
-#: common.opt:1329
+#: common.opt:1333
 #, fuzzy
 msgid "Perform early inlining."
 msgstr "Suorita uusille äänitetyille tiedotteille:"
 
-#: common.opt:1337
+#: common.opt:1341
 msgid "Perform interprocedural reduction of aggregates."
 msgstr ""
 
-#: common.opt:1341
+#: common.opt:1345
 msgid "Perform unused symbol elimination in debug info."
 msgstr ""
 
-#: common.opt:1345
+#: common.opt:1349
 msgid "Perform unused type elimination in debug info."
 msgstr ""
 
-#: common.opt:1349
+#: common.opt:1353
 msgid "Do not suppress C++ class debug information."
 msgstr ""
 
-#: common.opt:1353
+#: common.opt:1357
 #, fuzzy
 #| msgid "Enable exception handling"
 msgid "Enable exception handling."
 msgstr "Käytä poikkeustenkäsittelyä"
 
-#: common.opt:1357
+#: common.opt:1361
 msgid "Perform a number of minor, expensive optimizations."
 msgstr ""
 
-#: common.opt:1361
+#: common.opt:1365
 msgid "-fexcess-precision=[fast|standard]\tSpecify handling of excess floating-point precision."
 msgstr ""
 
-#: common.opt:1364
+#: common.opt:1368
 #, fuzzy, c-format
 msgid "unknown excess precision style %qs"
 msgstr "tuntematon konetila %qs"
 
-#: common.opt:1376
+#: common.opt:1380
 msgid "-fpermitted-flt-eval-methods=[c11|ts-18661]\tSpecify which values of FLT_EVAL_METHOD are permitted."
 msgstr ""
 
-#: common.opt:1379
+#: common.opt:1383
 #, c-format
 msgid "unknown specification for the set of FLT_EVAL_METHOD values to permit %qs"
 msgstr ""
 
-#: common.opt:1392
+#: common.opt:1396
 msgid "Output lto objects containing both the intermediate language and binary output."
 msgstr ""
 
-#: common.opt:1396
+#: common.opt:1400
 msgid "Assume no NaNs or infinities are generated."
 msgstr ""
 
-#: common.opt:1400
+#: common.opt:1404
 msgid "-ffixed-<register>\tMark <register> as being unavailable to the compiler."
 msgstr ""
 
-#: common.opt:1404
+#: common.opt:1408
 msgid "Don't allocate floats and doubles in extended-precision registers."
 msgstr ""
 
-#: common.opt:1412
+#: common.opt:1416
 msgid "Perform a forward propagation pass on RTL."
 msgstr ""
 
-#: common.opt:1416
+#: common.opt:1420
 msgid "-ffp-contract=[off|on|fast]\tPerform floating-point expression contraction."
 msgstr ""
 
-#: common.opt:1419
+#: common.opt:1423
 #, fuzzy, c-format
 msgid "unknown floating point contraction style %qs"
 msgstr "tuntematon konetila %qs"
 
-#: common.opt:1433
+#: common.opt:1437
 msgid "Allow built-in functions ceil, floor, round, trunc to raise \"inexact\" exceptions."
 msgstr ""
 
-#: common.opt:1440
+#: common.opt:1444
 msgid "Allow function addresses to be held in registers."
 msgstr ""
 
-#: common.opt:1444
+#: common.opt:1448
 #, fuzzy
 #| msgid "for each function it appears in.)"
 msgid "Place each function into its own section."
 msgstr "ensimmäinen käyttökerta kussakin funktiossa.)"
 
-#: common.opt:1448
+#: common.opt:1452
 msgid "Perform global common subexpression elimination."
 msgstr ""
 
-#: common.opt:1452
+#: common.opt:1456
 msgid "Perform enhanced load motion during global common subexpression elimination."
 msgstr ""
 
-#: common.opt:1456
+#: common.opt:1460
 msgid "Perform store motion after global common subexpression elimination."
 msgstr ""
 
-#: common.opt:1460
+#: common.opt:1464
 msgid "Perform redundant load after store elimination in global common subexpression elimination."
 msgstr ""
 
-#: common.opt:1465
+#: common.opt:1469
 msgid "Perform global common subexpression elimination after register allocation has finished."
 msgstr ""
 
-#: common.opt:1482
+#: common.opt:1486
 msgid "-fgnat-encodings=[all|gdb|minimal]\tSelect the balance between GNAT encodings and standard DWARF emitted in the debug information"
 msgstr ""
 
-#: common.opt:1487
+#: common.opt:1491
 msgid "Enable in and out of Graphite representation."
 msgstr ""
 
-#: common.opt:1491
+#: common.opt:1495
 msgid "Enable Graphite Identity transformation."
 msgstr ""
 
-#: common.opt:1495
+#: common.opt:1499
 #, fuzzy
 msgid "Enable hoisting adjacent loads to encourage generating conditional move instructions."
 msgstr "ehtolausekkeessa ei-lvalue-taulukko"
 
-#: common.opt:1504
+#: common.opt:1508
 msgid "Mark all loops as parallel."
 msgstr "Merkitse kaikki silmukat rinnakkaisiksi."
 
-#: common.opt:1508 common.opt:1516 common.opt:2587
+#: common.opt:1512 common.opt:1520 common.opt:2591
 msgid "Enable loop nest transforms.  Same as -floop-nest-optimize."
 msgstr ""
 
-#: common.opt:1512
+#: common.opt:1516
 #, fuzzy
 msgid "Enable loop interchange on trees."
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: common.opt:1520
+#: common.opt:1524
 msgid "Perform unroll-and-jam on loops."
 msgstr ""
 
-#: common.opt:1524
+#: common.opt:1528
 msgid "Enable support for GNU transactional memory."
 msgstr ""
 
-#: common.opt:1528
+#: common.opt:1532
 msgid "Use STB_GNU_UNIQUE if supported by the assembler."
 msgstr ""
 
-#: common.opt:1536
+#: common.opt:1540
 #, fuzzy
 msgid "Enable the loop nest optimizer."
 msgstr "Käytä AltiVec-käskyjä"
 
-#: common.opt:1540
+#: common.opt:1544
 msgid "Force bitfield accesses to match their type width."
 msgstr ""
 
-#: common.opt:1544
+#: common.opt:1548
 msgid "Merge adjacent stores."
 msgstr ""
 
-#: common.opt:1548
+#: common.opt:1552
 msgid "Enable guessing of branch probabilities."
 msgstr ""
 
-#: common.opt:1556
+#: common.opt:1560
 #, fuzzy
 msgid "Process #ident directives."
 msgstr "Älä luo #line-direktiivejä"
 
-#: common.opt:1560
+#: common.opt:1564
 msgid "Perform conversion of conditional jumps to branchless equivalents."
 msgstr ""
 
-#: common.opt:1564
+#: common.opt:1568
 msgid "Perform conversion of conditional jumps to conditional execution."
 msgstr ""
 
-#: common.opt:1568
+#: common.opt:1572
 msgid "-fstack-reuse=[all|named_vars|none]\tSet stack reuse level for local variables."
 msgstr ""
 
-#: common.opt:1571
+#: common.opt:1575
 #, fuzzy, c-format
 msgid "unknown Stack Reuse Level %qs"
 msgstr "tuntematon konetila %qs"
 
-#: common.opt:1584
+#: common.opt:1588
 msgid "Convert conditional jumps in innermost loops to branchless equivalents."
 msgstr ""
 
-#: common.opt:1596
+#: common.opt:1600
 #, fuzzy
 #| msgid "Do not generate #line directives"
 msgid "Do not generate .size directives."
 msgstr "Älä luo #line-direktiivejä"
 
-#: common.opt:1600
+#: common.opt:1604
 #, fuzzy
 msgid "Perform indirect inlining."
 msgstr "Käytä epäsuoria kutsuja"
 
-#: common.opt:1606
+#: common.opt:1610
 msgid "Enable inlining of function declared \"inline\", disabling disables all inlining."
 msgstr ""
 
-#: common.opt:1610
+#: common.opt:1614
 #, fuzzy
 msgid "Integrate functions into their callers when code size is known not to grow."
 msgstr "jäsenfunktio-osoitinta käytetty laskutoimituksessa"
 
-#: common.opt:1614
+#: common.opt:1618
 #, fuzzy
 msgid "Integrate functions not declared \"inline\" into their callers when profitable."
 msgstr "jäsenfunktio-osoitinta käytetty laskutoimituksessa"
 
-#: common.opt:1618
+#: common.opt:1622
 #, fuzzy
 msgid "Integrate functions only required by their single caller."
 msgstr "jäsenfunktio-osoitinta käytetty laskutoimituksessa"
 
-#: common.opt:1625
+#: common.opt:1629
 msgid "-finline-limit=<number>\tLimit the size of inlined functions to <number>."
 msgstr ""
 
-#: common.opt:1629
+#: common.opt:1633
 msgid "Inline __atomic operations when a lock free instruction sequence is available."
 msgstr ""
 
-#: common.opt:1636
+#: common.opt:1640
 msgid "-fcf-protection=[full|branch|return|none]\tInstrument functions with checks to verify jump/call/return control-flow transfer instructions have valid targets."
 msgstr ""
 
-#: common.opt:1640
+#: common.opt:1644
 #, fuzzy, c-format
 msgid "unknown Control-Flow Protection Level %qs"
 msgstr "tuntematon konetila %qs"
 
-#: common.opt:1656
+#: common.opt:1660
 msgid "Instrument function entry and exit with profiling calls."
 msgstr ""
 
-#: common.opt:1660
+#: common.opt:1664
 msgid "-finstrument-functions-exclude-function-list=name,...  Do not instrument listed functions."
 msgstr ""
 
-#: common.opt:1664
+#: common.opt:1668
 msgid "-finstrument-functions-exclude-file-list=filename,...  Do not instrument functions listed in files."
 msgstr ""
 
-#: common.opt:1668
+#: common.opt:1672
 msgid "Perform interprocedural constant propagation."
 msgstr ""
 
-#: common.opt:1672
+#: common.opt:1676
 msgid "Perform cloning to make Interprocedural constant propagation stronger."
 msgstr ""
 
-#: common.opt:1680
+#: common.opt:1684
 msgid "Perform interprocedural bitwise constant propagation."
 msgstr ""
 
-#: common.opt:1684
+#: common.opt:1688
 msgid "Perform interprocedural profile propagation."
 msgstr ""
 
-#: common.opt:1688
+#: common.opt:1692
 msgid "Perform interprocedural points-to analysis."
 msgstr ""
 
-#: common.opt:1692
+#: common.opt:1696
 #, fuzzy
 msgid "Discover pure and const functions."
 msgstr "epäkelpo tallennusluokka funktiolle %qs"
 
-#: common.opt:1696
+#: common.opt:1700
 msgid "Perform Identical Code Folding for functions and read-only variables."
 msgstr ""
 
-#: common.opt:1700
+#: common.opt:1704
 msgid "Perform Identical Code Folding for functions."
 msgstr ""
 
-#: common.opt:1704
+#: common.opt:1708
 msgid "Perform Identical Code Folding for variables."
 msgstr ""
 
-#: common.opt:1708
+#: common.opt:1712
 msgid "Discover readonly and non addressable static variables."
 msgstr ""
 
-#: common.opt:1720
+#: common.opt:1724
 msgid "Perform IPA Value Range Propagation."
 msgstr ""
 
-#: common.opt:1724
+#: common.opt:1728
 msgid "-fira-algorithm=[CB|priority]\tSet the used IRA algorithm."
 msgstr ""
 
-#: common.opt:1727
+#: common.opt:1731
 #, c-format
 msgid "unknown IRA algorithm %qs"
 msgstr ""
 
-#: common.opt:1737
+#: common.opt:1741
 msgid "-fira-region=[one|all|mixed]\tSet regions for IRA."
 msgstr ""
 
-#: common.opt:1740
+#: common.opt:1744
 #, c-format
 msgid "unknown IRA region %qs"
 msgstr ""
 
-#: common.opt:1753
+#: common.opt:1757
 msgid "Use IRA based register pressure calculation in RTL hoist optimizations."
 msgstr ""
 
-#: common.opt:1758
+#: common.opt:1762
 msgid "Use IRA based register pressure calculation in RTL loop optimizations."
 msgstr ""
 
-#: common.opt:1763
+#: common.opt:1767
 msgid "Share slots for saving different hard registers."
 msgstr ""
 
-#: common.opt:1767
+#: common.opt:1771
 msgid "Share stack slots for spilled pseudo-registers."
 msgstr ""
 
-#: common.opt:1771
+#: common.opt:1775
 msgid "-fira-verbose=<number>\tControl IRA's level of diagnostic messages."
 msgstr ""
 
-#: common.opt:1775
+#: common.opt:1779
 msgid "Optimize induction variables on trees."
 msgstr ""
 
-#: common.opt:1779
+#: common.opt:1783
 #, fuzzy
 msgid "Use jump tables for sufficiently large switch statements."
 msgstr "nimike yhdyslauseen lopussa"
 
-#: common.opt:1783
+#: common.opt:1787
 msgid "Generate code for functions even if they are fully inlined."
 msgstr ""
 
-#: common.opt:1787
+#: common.opt:1791
 msgid "Generate code for static functions even if they are never called."
 msgstr ""
 
-#: common.opt:1791
+#: common.opt:1795
 msgid "Emit static const variables even if they are not used."
 msgstr ""
 
-#: common.opt:1795
+#: common.opt:1799
 msgid "Give external symbols a leading underscore."
 msgstr ""
 
-#: common.opt:1803
+#: common.opt:1807
 msgid "Do CFG-sensitive rematerialization in LRA."
 msgstr ""
 
-#: common.opt:1807
+#: common.opt:1811
 msgid "Enable link-time optimization."
 msgstr ""
 
-#: common.opt:1811
+#: common.opt:1815
 msgid "Link-time optimization with number of parallel jobs or jobserver."
 msgstr ""
 
-#: common.opt:1814
+#: common.opt:1818
 #, fuzzy, c-format
 msgid "unknown LTO partitioning model %qs"
 msgstr "tuntematon konetila %qs"
 
-#: common.opt:1833
+#: common.opt:1837
 msgid "Specify the algorithm to partition symbols and vars at linktime."
 msgstr ""
 
-#: common.opt:1838
+#: common.opt:1842
 msgid "-flto-compression-level=<number>\tUse zlib compression level <number> for IL."
 msgstr ""
 
-#: common.opt:1842
+#: common.opt:1846
 msgid "Merge C++ types using One Definition Rule."
 msgstr ""
 
-#: common.opt:1846
+#: common.opt:1850
 msgid "Report various link-time optimization statistics."
 msgstr ""
 
-#: common.opt:1850
+#: common.opt:1854
 msgid "Report various link-time optimization statistics for WPA only."
 msgstr ""
 
-#: common.opt:1854
+#: common.opt:1858
 #, fuzzy
 #| msgid "Recognize built-in functions"
 msgid "Set errno after built-in math functions."
 msgstr "Tunnista sisäiset funktiot"
 
-#: common.opt:1858
+#: common.opt:1862
 msgid "-fmax-errors=<number>\tMaximum number of errors to report."
 msgstr ""
 
-#: common.opt:1862
+#: common.opt:1866
 #, fuzzy
 msgid "Report on permanent memory allocation."
 msgstr "Muistinvarausvirhe"
 
-#: common.opt:1866
+#: common.opt:1870
 msgid "Report on permanent memory allocation in WPA only."
 msgstr ""
 
-#: common.opt:1873
+#: common.opt:1877
 msgid "Attempt to merge identical constants and constant variables."
 msgstr ""
 
-#: common.opt:1877
+#: common.opt:1881
 msgid "Attempt to merge identical constants across compilation units."
 msgstr ""
 
-#: common.opt:1881
+#: common.opt:1885
 msgid "Attempt to merge identical debug strings across compilation units."
 msgstr ""
 
-#: common.opt:1885
+#: common.opt:1889
 msgid "-fmessage-length=<number>\tLimit diagnostics to <number> characters per line.  0 suppresses line-wrapping."
 msgstr ""
 
-#: common.opt:1889
+#: common.opt:1893
 msgid "Perform SMS based modulo scheduling before the first scheduling pass."
 msgstr ""
 
-#: common.opt:1893
+#: common.opt:1897
 msgid "Perform SMS based modulo scheduling with register moves allowed."
 msgstr ""
 
-#: common.opt:1897
+#: common.opt:1901
 msgid "Move loop invariant computations out of loops."
 msgstr ""
 
-#: common.opt:1901
+#: common.opt:1905
 msgid "Use the RTL dead code elimination pass."
 msgstr ""
 
-#: common.opt:1905
+#: common.opt:1909
 msgid "Use the RTL dead store elimination pass."
 msgstr ""
 
-#: common.opt:1909
+#: common.opt:1913
 msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling."
 msgstr ""
 
-#: common.opt:1913
+#: common.opt:1917
 msgid "Support synchronous non-call exceptions."
 msgstr ""
 
-#: common.opt:1916
+#: common.opt:1920
 #, fuzzy, c-format
 #| msgid "assertion missing after %qs"
 msgid "options or targets missing after %qs"
 msgstr "makron nimi puuttuu %qs:n jälkeen"
 
-#: common.opt:1917
+#: common.opt:1921
 msgid "-foffload=<targets>=<options>  Specify offloading targets and options for them."
 msgstr ""
 
-#: common.opt:1921
+#: common.opt:1925
 msgid "-foffload-abi=[lp64|ilp32]     Set the ABI to use in an offload compiler."
 msgstr ""
 
-#: common.opt:1924
+#: common.opt:1928
 #, fuzzy, c-format
 msgid "unknown offload ABI %qs"
 msgstr "tuntematon konetila %qs"
 
-#: common.opt:1934
+#: common.opt:1938
 msgid "When possible do not generate stack frames."
 msgstr ""
 
-#: common.opt:1938
+#: common.opt:1942
 #, fuzzy
 msgid "Enable all optimization info dumps on stderr."
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: common.opt:1942
+#: common.opt:1946
 msgid "-fopt-info[-<type>=filename]\tDump compiler optimization details."
 msgstr ""
 
-#: common.opt:1950
+#: common.opt:1954
 msgid "Optimize sibling and tail recursive calls."
 msgstr ""
 
-#: common.opt:1954
+#: common.opt:1958
 #, fuzzy
 msgid "Perform partial inlining."
 msgstr "Onnistui osittain"
 
-#: common.opt:1958 common.opt:1962
+#: common.opt:1962 common.opt:1966
 msgid "Report on memory allocation before interprocedural optimization."
 msgstr ""
 
-#: common.opt:1966
+#: common.opt:1970
 msgid "Pack structure members together without holes."
 msgstr ""
 
-#: common.opt:1970
+#: common.opt:1974
 msgid "-fpack-struct=<number>\tSet initial maximum structure member alignment."
 msgstr ""
 
-#: common.opt:1974
+#: common.opt:1978
 msgid "Return small aggregates in memory, not registers."
 msgstr ""
 
-#: common.opt:1978
+#: common.opt:1982
 #, fuzzy
 msgid "Perform loop peeling."
 msgstr "continue-lause silmukan ulkopuolella"
 
-#: common.opt:1982
+#: common.opt:1986
 #, fuzzy
 msgid "Enable machine specific peephole optimizations."
 msgstr "Käytä AltiVec-käskyjä"
 
-#: common.opt:1986
+#: common.opt:1990
 msgid "Enable an RTL peephole pass before sched2."
 msgstr ""
 
-#: common.opt:1990
+#: common.opt:1994
 #, fuzzy
 msgid "Generate position-independent code if possible (large mode)."
 msgstr "parametrilla %P on vaillinainen tyyppi %qT"
 
-#: common.opt:1994
+#: common.opt:1998
 #, fuzzy
 msgid "Generate position-independent code for executables if possible (large mode)."
 msgstr "parametrilla %P on vaillinainen tyyppi %qT"
 
-#: common.opt:1998
+#: common.opt:2002
 #, fuzzy
 msgid "Generate position-independent code if possible (small mode)."
 msgstr "parametrilla %P on vaillinainen tyyppi %qT"
 
-#: common.opt:2002
+#: common.opt:2006
 #, fuzzy
 msgid "Generate position-independent code for executables if possible (small mode)."
 msgstr "parametrilla %P on vaillinainen tyyppi %qT"
 
-#: common.opt:2006
+#: common.opt:2010
 msgid "Use PLT for PIC calls (-fno-plt: load the address from GOT at call site)."
 msgstr ""
 
-#: common.opt:2010
+#: common.opt:2014
 msgid "Specify a plugin to load."
 msgstr "Anna ladattava liitännäinen."
 
-#: common.opt:2014
+#: common.opt:2018
 msgid "-fplugin-arg-<name>-<key>[=<value>]\tSpecify argument <key>=<value> for plugin <name>."
 msgstr ""
 
-#: common.opt:2018
+#: common.opt:2022
 msgid "Run predictive commoning optimization."
 msgstr ""
 
-#: common.opt:2022
+#: common.opt:2026
 msgid "Generate prefetch instructions, if available, for arrays in loops."
 msgstr ""
 
-#: common.opt:2026
+#: common.opt:2030
 #, fuzzy
 #| msgid "Enable function profiling"
 msgid "Enable basic program profiling code."
 msgstr "Ota käyttöön funktioprofilointi"
 
-#: common.opt:2030
+#: common.opt:2034
 #, fuzzy
 msgid "Generate absolute source path names for gcov."
 msgstr "virheellinen versionumero ”%s”"
 
-#: common.opt:2034
+#: common.opt:2038
 msgid "Insert arc-based program profiling code."
 msgstr ""
 
-#: common.opt:2038
+#: common.opt:2042
 msgid "Set the top-level directory for storing the profile data. The default is 'pwd'."
 msgstr ""
 
-#: common.opt:2043
+#: common.opt:2047
 msgid "Enable correction of flow inconsistent profile data input."
 msgstr ""
 
-#: common.opt:2047
+#: common.opt:2051
 msgid "-fprofile-update=[single|atomic|prefer-atomic]\tSet the profile update method."
 msgstr ""
 
-#: common.opt:2050
+#: common.opt:2054
 #, fuzzy, c-format
 msgid "unknown profile update method %qs"
 msgstr "tuntematon konetila %qs"
 
-#: common.opt:2063
+#: common.opt:2067
 msgid "Enable common options for generating profile info for profile feedback directed optimizations."
 msgstr ""
 
-#: common.opt:2067
+#: common.opt:2071
 msgid "Enable common options for generating profile info for profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr ""
 
-#: common.opt:2071
+#: common.opt:2075
 msgid "Enable common options for performing profile feedback directed optimizations."
 msgstr ""
 
-#: common.opt:2075
+#: common.opt:2079
 msgid "Enable common options for performing profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr ""
 
-#: common.opt:2079
+#: common.opt:2083
 msgid "Insert code to profile values of expressions."
 msgstr ""
 
-#: common.opt:2083
+#: common.opt:2087
 #, fuzzy
 msgid "Report on consistency of profile."
 msgstr "Profiilissa on päättämätön kommentti"
 
-#: common.opt:2087
+#: common.opt:2091
 msgid "Enable function reordering that improves code placement."
 msgstr ""
 
-#: common.opt:2091
+#: common.opt:2095
 #, fuzzy
 #| msgid "interrupt function must have no arguments"
 msgid "Insert NOP instructions at each function entry."
 msgstr "keskeytysfunktiolla ei saa olla argumentteja"
 
-#: common.opt:2098
+#: common.opt:2102
 msgid "-frandom-seed=<string>\tMake compile reproducible using <string>."
 msgstr ""
 
-#: common.opt:2108
+#: common.opt:2112
 msgid "Record gcc command line switches in the object file."
 msgstr ""
 
-#: common.opt:2112
+#: common.opt:2116
 msgid "Return small aggregates in registers."
 msgstr ""
 
-#: common.opt:2120
+#: common.opt:2124
 msgid "Tell DSE that the storage for a C++ object is dead when the constructor starts and when the destructor finishes."
 msgstr ""
 
-#: common.opt:2128
+#: common.opt:2132
 msgid "Relief of register pressure through live range shrinkage."
 msgstr ""
 
-#: common.opt:2132
+#: common.opt:2136
 msgid "Perform a register renaming optimization pass."
 msgstr ""
 
-#: common.opt:2136
+#: common.opt:2140
 msgid "Perform a target dependent instruction fusion optimization pass."
 msgstr ""
 
-#: common.opt:2140
+#: common.opt:2144
 msgid "Reorder basic blocks to improve code placement."
 msgstr ""
 
-#: common.opt:2144
+#: common.opt:2148
 msgid "-freorder-blocks-algorithm=[simple|stc]\tSet the used basic block reordering algorithm."
 msgstr ""
 
-#: common.opt:2147
+#: common.opt:2151
 #, c-format
 msgid "unknown basic block reordering algorithm %qs"
 msgstr ""
 
-#: common.opt:2157
+#: common.opt:2161
 msgid "Reorder basic blocks and partition into hot and cold sections."
 msgstr ""
 
-#: common.opt:2161
+#: common.opt:2165
 msgid "Reorder functions to improve code placement."
 msgstr ""
 
-#: common.opt:2165
+#: common.opt:2169
 msgid "Add a common subexpression elimination pass after loop optimizations."
 msgstr ""
 
-#: common.opt:2173
+#: common.opt:2177
 msgid "Disable optimizations that assume default FP rounding behavior."
 msgstr ""
 
-#: common.opt:2177
+#: common.opt:2181
 msgid "Enable scheduling across basic blocks."
 msgstr ""
 
-#: common.opt:2181
+#: common.opt:2185
 msgid "Enable register pressure sensitive insn scheduling."
 msgstr ""
 
-#: common.opt:2185
+#: common.opt:2189
 msgid "Allow speculative motion of non-loads."
 msgstr ""
 
-#: common.opt:2189
+#: common.opt:2193
 msgid "Allow speculative motion of some loads."
 msgstr ""
 
-#: common.opt:2193
+#: common.opt:2197
 msgid "Allow speculative motion of more loads."
 msgstr ""
 
-#: common.opt:2197
+#: common.opt:2201
 msgid "-fsched-verbose=<number>\tSet the verbosity level of the scheduler."
 msgstr ""
 
-#: common.opt:2201
+#: common.opt:2205
 msgid "If scheduling post reload, do superblock scheduling."
 msgstr ""
 
-#: common.opt:2209
+#: common.opt:2213
 #, fuzzy
 #| msgid "Use registers for argument passing"
 msgid "Reschedule instructions before register allocation."
 msgstr "Käytä rekistereitä argumenttien välittämiseen"
 
-#: common.opt:2213
+#: common.opt:2217
 #, fuzzy
 #| msgid "Use registers for argument passing"
 msgid "Reschedule instructions after register allocation."
 msgstr "Käytä rekistereitä argumenttien välittämiseen"
 
-#: common.opt:2220
+#: common.opt:2224
 msgid "Schedule instructions using selective scheduling algorithm."
 msgstr ""
 
-#: common.opt:2224
+#: common.opt:2228
 msgid "Run selective scheduling after reload."
 msgstr ""
 
-#: common.opt:2228
+#: common.opt:2232
 msgid "Run self-tests, using the given path to locate test files."
 msgstr ""
 
-#: common.opt:2232
+#: common.opt:2236
 msgid "Perform software pipelining of inner loops during selective scheduling."
 msgstr ""
 
-#: common.opt:2236
+#: common.opt:2240
 msgid "Perform software pipelining of outer loops during selective scheduling."
 msgstr ""
 
-#: common.opt:2240
+#: common.opt:2244
 msgid "Reschedule pipelined regions without pipelining."
 msgstr ""
 
-#: common.opt:2244
+#: common.opt:2248
 msgid "Allow interposing function (or variables) by ones with different semantics (or initializer) respectively by dynamic linker."
 msgstr ""
 
-#: common.opt:2250
+#: common.opt:2254
 msgid "Allow premature scheduling of queued insns."
 msgstr ""
 
-#: common.opt:2254
+#: common.opt:2258
 msgid "-fsched-stalled-insns=<number>\tSet number of queued insns that can be prematurely scheduled."
 msgstr ""
 
-#: common.opt:2262
+#: common.opt:2266
 msgid "Set dependence distance checking in premature scheduling of queued insns."
 msgstr ""
 
-#: common.opt:2266
+#: common.opt:2270
 msgid "-fsched-stalled-insns-dep=<number>\tSet dependence distance checking in premature scheduling of queued insns."
 msgstr ""
 
-#: common.opt:2270
+#: common.opt:2274
 msgid "Enable the group heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2274
+#: common.opt:2278
 msgid "Enable the critical path heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2278
+#: common.opt:2282
 #, fuzzy
 msgid "Enable the speculative instruction heuristic in the scheduler."
 msgstr "Ota käyttöön RX FPU-käskyjen käyttö."
 
-#: common.opt:2282
+#: common.opt:2286
 msgid "Enable the rank heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2286
+#: common.opt:2290
 #, fuzzy
 msgid "Enable the last instruction heuristic in the scheduler."
 msgstr "Ota käyttöön RX FPU-käskyjen käyttö."
 
-#: common.opt:2290
+#: common.opt:2294
 msgid "Enable the dependent count heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2294
+#: common.opt:2298
 msgid "Access data in the same section from shared anchor points."
 msgstr ""
 
-#: common.opt:2306
+#: common.opt:2310
 msgid "Turn on Redundant Extensions Elimination pass."
 msgstr ""
 
-#: common.opt:2310
+#: common.opt:2314
 msgid "Show column numbers in diagnostics, when available.  Default on."
 msgstr ""
 
-#: common.opt:2314
+#: common.opt:2318
 msgid "Emit function prologues only before parts of the function that need it, rather than at the top of the function."
 msgstr ""
 
-#: common.opt:2319
+#: common.opt:2323
 msgid "Shrink-wrap parts of the prologue and epilogue separately."
 msgstr ""
 
-#: common.opt:2323
+#: common.opt:2327
 msgid "Disable optimizations observable by IEEE signaling NaNs."
 msgstr ""
 
-#: common.opt:2327
+#: common.opt:2331
 msgid "Disable floating point optimizations that ignore the IEEE signedness of zero."
 msgstr ""
 
-#: common.opt:2331
+#: common.opt:2335
 #, fuzzy
 #| msgid "overflow in implicit constant conversion"
 msgid "Convert floating point constants to single precision constants."
 msgstr "ylivuoto implisiittisessä vakiomuunnoksessa"
 
-#: common.opt:2335
+#: common.opt:2339
 msgid "Split lifetimes of induction variables when loops are unrolled."
 msgstr ""
 
-#: common.opt:2339
+#: common.opt:2343
 msgid "Generate discontiguous stack frames."
 msgstr ""
 
-#: common.opt:2343
+#: common.opt:2347
 msgid "Split wide types into independent registers."
 msgstr ""
 
-#: common.opt:2347
+#: common.opt:2351
 msgid "Enable backward propagation of use properties at the SSA level."
 msgstr ""
 
-#: common.opt:2351
+#: common.opt:2355
 msgid "Optimize conditional patterns using SSA PHI nodes."
 msgstr ""
 
-#: common.opt:2355
+#: common.opt:2359
 msgid "Optimize amount of stdarg registers saved to stack at start of function."
 msgstr ""
 
-#: common.opt:2359
+#: common.opt:2363
 msgid "Apply variable expansion when loops are unrolled."
 msgstr ""
 
-#: common.opt:2363
+#: common.opt:2367
 msgid "-fstack-check=[no|generic|specific]\tInsert stack checking code into the program."
 msgstr ""
 
-#: common.opt:2367
+#: common.opt:2371
 msgid "Insert stack checking code into the program.  Same as -fstack-check=specific."
 msgstr ""
 
-#: common.opt:2371
+#: common.opt:2375
 msgid "Insert code to probe each page of stack space as it is allocated to protect from stack-clash style attacks."
 msgstr ""
 
-#: common.opt:2379
+#: common.opt:2383
 msgid "-fstack-limit-register=<register>\tTrap if the stack goes past <register>."
 msgstr ""
 
-#: common.opt:2383
+#: common.opt:2387
 msgid "-fstack-limit-symbol=<name>\tTrap if the stack goes past symbol <name>."
 msgstr ""
 
-#: common.opt:2387
+#: common.opt:2391
 #, fuzzy
 #| msgid "Enable saturation instructions"
 msgid "Use propolice as a stack protection method."
 msgstr "Ota käyttöön saturation-käskyt"
 
-#: common.opt:2391
+#: common.opt:2395
 msgid "Use a stack protection method for every function."
 msgstr ""
 
-#: common.opt:2395
+#: common.opt:2399
 msgid "Use a smart stack protection method for certain functions."
 msgstr ""
 
-#: common.opt:2399
+#: common.opt:2403
 #, fuzzy
 msgid "Use stack protection method only for functions with the stack_protect attribute."
 msgstr "epäkelpo osoitintila %qs"
 
-#: common.opt:2403
+#: common.opt:2407
 msgid "Output stack usage information on a per-function basis."
 msgstr ""
 
-#: common.opt:2415
+#: common.opt:2419
 msgid "Assume strict aliasing rules apply."
 msgstr ""
 
-#: common.opt:2419
+#: common.opt:2423
 #, fuzzy
 #| msgid "Treat missing header files as generated files"
 msgid "Treat signed overflow as undefined.  Negated as -fwrapv -fwrapv-pointer."
 msgstr "Käsittele puuttuvia otsikkotiedostoja luotavina tiedostoina"
 
-#: common.opt:2423
+#: common.opt:2427
 msgid "Implement __atomic operations via libcalls to legacy __sync functions."
 msgstr ""
 
-#: common.opt:2427
+#: common.opt:2431
 #, fuzzy
 msgid "Check for syntax errors, then stop."
 msgstr "Tarkasta käännöksen virheet"
 
-#: common.opt:2431
+#: common.opt:2435
 msgid "Create data files needed by \"gcov\"."
 msgstr ""
 
-#: common.opt:2435
+#: common.opt:2439
 msgid "Perform jump threading optimizations."
 msgstr ""
 
-#: common.opt:2439
+#: common.opt:2443
 msgid "Report the time taken by each compiler pass."
 msgstr ""
 
-#: common.opt:2443
+#: common.opt:2447
 msgid "Record times taken by sub-phases separately."
 msgstr ""
 
-#: common.opt:2447
+#: common.opt:2451
 msgid "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tSet the default thread-local storage code generation model."
 msgstr ""
 
-#: common.opt:2450
+#: common.opt:2454
 #, fuzzy, c-format
 msgid "unknown TLS model %qs"
 msgstr "tls_model-argumentti ei ole merkkijono"
 
-#: common.opt:2466
+#: common.opt:2470
 msgid "Reorder top level functions, variables, and asms."
 msgstr ""
 
-#: common.opt:2470
+#: common.opt:2474
 msgid "Perform superblock formation via tail duplication."
 msgstr ""
 
-#: common.opt:2474
+#: common.opt:2478
 msgid "For targets that normally need trampolines for nested functions, always generate them instead of using descriptors."
 msgstr ""
 
-#: common.opt:2482
+#: common.opt:2486
 #, fuzzy
 msgid "Assume floating-point operations can trap."
 msgstr "Käytä ohjelmistoliukulukuja"
 
-#: common.opt:2486
+#: common.opt:2490
 msgid "Trap for signed overflow in addition, subtraction and multiplication."
 msgstr ""
 
-#: common.opt:2490
+#: common.opt:2494
 #, fuzzy
 msgid "Enable SSA-CCP optimization on trees."
 msgstr "ehtolausekkeessa ei-lvalue-taulukko"
 
-#: common.opt:2494
+#: common.opt:2498
 #, fuzzy
 msgid "Enable SSA-BIT-CCP optimization on trees."
 msgstr "ehtolausekkeessa ei-lvalue-taulukko"
 
-#: common.opt:2502
+#: common.opt:2506
 #, fuzzy
 msgid "Enable loop header copying on trees."
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: common.opt:2510
+#: common.opt:2514
 msgid "Enable SSA coalescing of user variables."
 msgstr ""
 
-#: common.opt:2518
+#: common.opt:2522
 #, fuzzy
 msgid "Enable copy propagation on trees."
 msgstr "ehtolausekkeessa ei-lvalue-taulukko"
 
-#: common.opt:2526
+#: common.opt:2530
 #, fuzzy
 msgid "Transform condition stores into unconditional ones."
 msgstr "ehtolausekkeessa ei-lvalue-taulukko"
 
-#: common.opt:2530
+#: common.opt:2534
 msgid "Perform conversions of switch initializations."
 msgstr ""
 
-#: common.opt:2534
+#: common.opt:2538
 #, fuzzy
 msgid "Enable SSA dead code elimination optimization on trees."
 msgstr "ehtolausekkeessa ei-lvalue-taulukko"
 
-#: common.opt:2538
+#: common.opt:2542
 #, fuzzy
 msgid "Enable dominator optimizations."
 msgstr "moduulienvälisiä optimointeja ei ole toteutettu C++:lle"
 
-#: common.opt:2542
+#: common.opt:2546
 #, fuzzy
 msgid "Enable tail merging on trees."
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: common.opt:2546
+#: common.opt:2550
 #, fuzzy
 msgid "Enable dead store elimination."
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: common.opt:2550
+#: common.opt:2554
 #, fuzzy
 msgid "Enable forward propagation on trees."
 msgstr "ehtolausekkeessa ei-lvalue-taulukko"
 
-#: common.opt:2554
+#: common.opt:2558
 #, fuzzy
 msgid "Enable Full Redundancy Elimination (FRE) on trees."
 msgstr "ehtolausekkeessa ei-lvalue-taulukko"
 
-#: common.opt:2558
+#: common.opt:2562
 #, fuzzy
 msgid "Enable string length optimizations on trees."
 msgstr "ehtolausekkeessa ei-lvalue-taulukko"
 
-#: common.opt:2562
+#: common.opt:2566
 msgid "Detect paths that trigger erroneous or undefined behavior due to dereferencing a null pointer.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
-#: common.opt:2568
+#: common.opt:2572
 msgid "Detect paths that trigger erroneous or undefined behavior due to a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
-#: common.opt:2575
+#: common.opt:2579
 #, fuzzy
 msgid "Enable loop distribution on trees."
 msgstr "ehtolausekkeessa ei-lvalue-taulukko"
 
-#: common.opt:2579
+#: common.opt:2583
 msgid "Enable loop distribution for patterns transformed into a library call."
 msgstr ""
 
-#: common.opt:2583
+#: common.opt:2587
 #, fuzzy
 msgid "Enable loop invariant motion on trees."
 msgstr "ehtolausekkeessa ei-lvalue-taulukko"
 
-#: common.opt:2591
+#: common.opt:2595
 msgid "Create canonical induction variables in loops."
 msgstr ""
 
-#: common.opt:2595
+#: common.opt:2599
 #, fuzzy
 msgid "Enable loop optimizations on tree level."
 msgstr "ehtolausekkeessa ei-lvalue-taulukko"
 
-#: common.opt:2599
+#: common.opt:2603
 #, fuzzy
 msgid "-ftree-parallelize-loops=<number>\tEnable automatic parallelization of loops."
 msgstr "Käytä auto_maattisisennystä"
 
-#: common.opt:2603
+#: common.opt:2607
 #, fuzzy
 msgid "Enable hoisting loads from conditional pointers."
 msgstr "ehtolausekkeessa ei-lvalue-taulukko"
 
-#: common.opt:2607
+#: common.opt:2611
 #, fuzzy
 msgid "Enable SSA-PRE optimization on trees."
 msgstr "ehtolausekkeessa ei-lvalue-taulukko"
 
-#: common.opt:2611
+#: common.opt:2615
 msgid "In SSA-PRE optimization on trees, enable partial-partial redundancy elimination."
 msgstr ""
 
-#: common.opt:2615
+#: common.opt:2619
 msgid "Perform function-local points-to analysis on trees."
 msgstr ""
 
-#: common.opt:2619
+#: common.opt:2623
 #, fuzzy
 msgid "Enable reassociation on tree level."
 msgstr "ehtolausekkeessa ei-lvalue-taulukko"
 
-#: common.opt:2627
+#: common.opt:2631
 #, fuzzy
 msgid "Enable SSA code sinking on trees."
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: common.opt:2631
+#: common.opt:2635
 msgid "Perform straight-line strength reduction."
 msgstr ""
 
-#: common.opt:2635
+#: common.opt:2639
 msgid "Perform scalar replacement of aggregates."
 msgstr ""
 
-#: common.opt:2639
+#: common.opt:2643
 msgid "Replace temporary expressions in the SSA->normal pass."
 msgstr ""
 
-#: common.opt:2643
+#: common.opt:2647
 msgid "Perform live range splitting during the SSA->normal pass."
 msgstr ""
 
-#: common.opt:2647
+#: common.opt:2651
 msgid "Perform Value Range Propagation on trees."
 msgstr ""
 
-#: common.opt:2651
+#: common.opt:2655
 msgid "Split paths leading to loop backedges."
 msgstr ""
 
-#: common.opt:2655
+#: common.opt:2659
 msgid "Assume common declarations may be overridden with ones with a larger trailing array."
 msgstr ""
 
-#: common.opt:2660
+#: common.opt:2664
 msgid "Compile whole compilation unit at a time."
 msgstr ""
 
-#: common.opt:2664
+#: common.opt:2668
 msgid "Perform loop unrolling when iteration count is known."
 msgstr ""
 
-#: common.opt:2668
+#: common.opt:2672
 msgid "Perform loop unrolling for all loops."
 msgstr ""
 
-#: common.opt:2679
+#: common.opt:2683
 msgid "Allow optimization for floating-point arithmetic which may change the result of the operation due to rounding."
 msgstr ""
 
-#: common.opt:2684
+#: common.opt:2688
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr ""
 
-#: common.opt:2692
+#: common.opt:2696
 msgid "Allow math optimizations that may violate IEEE or ISO standards."
 msgstr ""
 
-#: common.opt:2696
+#: common.opt:2700
 #, fuzzy
 msgid "Perform loop unswitching."
 msgstr "continue-lause silmukan ulkopuolella"
 
-#: common.opt:2700
+#: common.opt:2704
 #, fuzzy
 msgid "Perform loop splitting."
 msgstr "continue-lause silmukan ulkopuolella"
 
-#: common.opt:2704
+#: common.opt:2708
 #, fuzzy
 #| msgid "Enable exception handling"
 msgid "Just generate unwind tables for exception handling."
 msgstr "Käytä poikkeustenkäsittelyä"
 
-#: common.opt:2708
+#: common.opt:2712
 msgid "Use the bfd linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2712
+#: common.opt:2716
 msgid "Use the gold linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2724
+#: common.opt:2728
 #, fuzzy
 msgid "Perform variable tracking."
 msgstr "Suorita uusille äänitetyille tiedotteille:"
 
-#: common.opt:2732
+#: common.opt:2736
 msgid "Perform variable tracking by annotating assignments."
 msgstr ""
 
-#: common.opt:2738
+#: common.opt:2742
 msgid "Toggle -fvar-tracking-assignments."
 msgstr ""
 
-#: common.opt:2746
+#: common.opt:2750
 msgid "Perform variable tracking and also tag variables that are uninitialized."
 msgstr ""
 
-#: common.opt:2751
+#: common.opt:2755
 #, fuzzy
 msgid "Enable vectorization on trees."
 msgstr "Ota käyttöön moniydintuki"
 
-#: common.opt:2759
+#: common.opt:2763
 #, fuzzy
 msgid "Enable loop vectorization on trees."
 msgstr "ehtolausekkeessa ei-lvalue-taulukko"
 
-#: common.opt:2763
+#: common.opt:2767
 #, fuzzy
 msgid "Enable basic block vectorization (SLP) on trees."
 msgstr "ehtolausekkeessa ei-lvalue-taulukko"
 
-#: common.opt:2767
+#: common.opt:2771
 msgid "Specifies the cost model for vectorization. -fvect-cost-model=[unlimited|dynamic|cheap]\tSpecifies the cost model for vectorization."
 msgstr ""
 
-#: common.opt:2772
+#: common.opt:2776
 #, fuzzy
 msgid "-fsimd-cost-model=[unlimited|dynamic|cheap]\tSpecifies the vectorization cost model for code marked with a simd directive."
 msgstr "Käytä AltiVec-käskyjä"
 
-#: common.opt:2775
+#: common.opt:2779
 #, fuzzy, c-format
 msgid "unknown vectorizer cost model %qs"
 msgstr "tuntematon konetila %qs"
 
-#: common.opt:2788
+#: common.opt:2792
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr ""
 
-#: common.opt:2796
+#: common.opt:2800
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr ""
 
-#: common.opt:2806
+#: common.opt:2810
 msgid "Add extra commentary to assembler output."
 msgstr ""
 
-#: common.opt:2810
+#: common.opt:2814
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility."
 msgstr ""
 
-#: common.opt:2813
+#: common.opt:2817
 #, fuzzy, c-format
 msgid "unrecognized visibility value %qs"
 msgstr "tunnistamaton rekisterinimi %qs"
 
-#: common.opt:2829
+#: common.opt:2833
 msgid "Validate vtable pointers before using them."
 msgstr ""
 
-#: common.opt:2832
+#: common.opt:2836
 #, fuzzy, c-format
 #| msgid "(near initialization for %qs)"
 msgid "unknown vtable verify initialization priority %qs"
 msgstr "(%qs:n alustuksen lähistöllä)"
 
-#: common.opt:2845
+#: common.opt:2849
 msgid "Output vtable verification counters."
 msgstr ""
 
-#: common.opt:2849
+#: common.opt:2853
 msgid "Output vtable verification pointer sets information."
 msgstr ""
 
-#: common.opt:2853
+#: common.opt:2857
 msgid "Use expression value profiles in optimizations."
 msgstr ""
 
-#: common.opt:2857
+#: common.opt:2861
 msgid "Construct webs and split unrelated uses of single variable."
 msgstr ""
 
-#: common.opt:2861
+#: common.opt:2865
 #, fuzzy
 msgid "Enable conditional dead code elimination for builtin calls."
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: common.opt:2865
+#: common.opt:2869
 msgid "Perform whole program optimizations."
 msgstr ""
 
-#: common.opt:2869
+#: common.opt:2873
 #, fuzzy
 #| msgid "Treat missing header files as generated files"
 msgid "Assume pointer overflow wraps around."
 msgstr "Käsittele puuttuvia otsikkotiedostoja luotavina tiedostoina"
 
-#: common.opt:2873
+#: common.opt:2877
 msgid "Assume signed arithmetic overflow wraps around."
 msgstr ""
 
-#: common.opt:2877
+#: common.opt:2881
 #, fuzzy
 #| msgid "%qD is used uninitialized in this function"
 msgid "Put zero initialized data in the bss section."
 msgstr "%qD:a käytetään alustamattomana tässä funktiossa"
 
-#: common.opt:2881
+#: common.opt:2885
 msgid "Generate debug information in default format."
 msgstr "Tuota vianjäljitystietoja oletusmuodossa."
 
-#: common.opt:2885
+#: common.opt:2889
 msgid "Assume assembler support for (DWARF2+) .loc directives"
 msgstr ""
 
-#: common.opt:2889
+#: common.opt:2893
 msgid "Assume assembler support for view in (DWARF2+) .loc directives"
 msgstr ""
 
-#: common.opt:2892 common.opt:2896 common.opt:2900 common.opt:2904
+#: common.opt:2896 common.opt:2900 common.opt:2904 common.opt:2908
 #, fuzzy, c-format
 #| msgid "switch %qs is no longer supported"
 msgid "switch %qs no longer supported"
 msgstr "valitsin %qs ei ole enää tuettu"
 
-#: common.opt:2909
+#: common.opt:2913
 msgid "Record DW_AT_decl_column and DW_AT_call_column in DWARF."
 msgstr ""
 
-#: common.opt:2913
+#: common.opt:2917
 #, fuzzy
 #| msgid "Generate debug information in extended STABS format"
 msgid "Generate debug information in default version of DWARF format."
 msgstr "Tuota vianjäljitystietoja laajennetussa STABS-muodossa"
 
-#: common.opt:2917
+#: common.opt:2921
 #, fuzzy
 #| msgid "Generate debug information in XCOFF format"
 msgid "Generate debug information in DWARF v2 (or later) format."
 msgstr "Tuota vianjäljitystietoja XCOFF-muodossa"
 
-#: common.opt:2921
+#: common.opt:2925
 #, fuzzy
 #| msgid "Generate debug information in extended STABS format"
 msgid "Generate debug information in default extended format."
 msgstr "Tuota vianjäljitystietoja laajennetussa STABS-muodossa"
 
-#: common.opt:2925
+#: common.opt:2929
 #, fuzzy
 msgid "Generate extended entry point information for inlined functions"
 msgstr "indeksoitu arvo on osoitin funktioon"
 
-#: common.opt:2929
+#: common.opt:2933
 msgid "Compute locview reset points based on insn length estimates"
 msgstr ""
 
-#: common.opt:2937
+#: common.opt:2941
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:2941
+#: common.opt:2945
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:2945
+#: common.opt:2949
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr ""
 
-#: common.opt:2949
+#: common.opt:2953
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr ""
 
-#: common.opt:2953
+#: common.opt:2957
 #, fuzzy
 #| msgid "Generate debug information in VMS format"
 msgid "Generate debug information in separate .dwo files."
 msgstr "Tuota vianjäljitystietoja VMS-muodossa"
 
-#: common.opt:2957
+#: common.opt:2961
 #, fuzzy
 #| msgid "Generate debug information in VMS format"
 msgid "Generate debug information in STABS format."
 msgstr "Tuota vianjäljitystietoja laajennetussa STABS-muodossa"
 
-#: common.opt:2961
+#: common.opt:2965
 #, fuzzy
 #| msgid "Generate debug information in extended STABS format"
 msgid "Generate debug information in extended STABS format."
 msgstr "Tuota vianjäljitystietoja laajennetussa STABS-muodossa"
 
-#: common.opt:2965
+#: common.opt:2969
 msgid "Emit progressive recommended breakpoint locations."
 msgstr ""
 
-#: common.opt:2969
+#: common.opt:2973
 msgid "Don't emit DWARF additions beyond selected version."
 msgstr ""
 
-#: common.opt:2973
+#: common.opt:2977
 #, fuzzy
 #| msgid "Generate debug information in VMS format"
 msgid "Toggle debug information generation."
 msgstr "Tuota vianjäljitystietoja VMS-muodossa"
 
-#: common.opt:2977
+#: common.opt:2981
 msgid "Augment variable location lists with progressive views."
 msgstr ""
 
-#: common.opt:2984
+#: common.opt:2988
 msgid "Generate debug information in VMS format."
 msgstr "Tuota vianjäljitystietoja VMS-muodossa."
 
-#: common.opt:2988
+#: common.opt:2992
 msgid "Generate debug information in XCOFF format."
 msgstr "Tuota vianjäljitystietoja XCOFF-muodossa."
 
-#: common.opt:2992
+#: common.opt:2996
 #, fuzzy
 #| msgid "Generate debug information in XCOFF format"
 msgid "Generate debug information in extended XCOFF format."
 msgstr "Tuota vianjäljitystietoja XCOFF-muodossa"
 
-#: common.opt:3010
+#: common.opt:3014
 #, fuzzy
 #| msgid "Generate isel instructions"
 msgid "Generate compressed debug sections."
 msgstr "Tuota vianjäljitystietoja VMS-muodossa"
 
-#: common.opt:3014
+#: common.opt:3018
 #, fuzzy
 #| msgid "Generate isel instructions"
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>."
 msgstr "Tuota isel-käskyjä"
 
-#: common.opt:3021
+#: common.opt:3025
 #, fuzzy
 #| msgid "-isysroot <dir>\tSet <dir> to be the system root directory"
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory."
 msgstr "-isysroot <hakemisto>\tAseta <hakemisto> järjestelmän juurihakemistoksi"
 
-#: common.opt:3025
+#: common.opt:3029
 #, fuzzy
 #| msgid "-isysroot <dir>\tSet <dir> to be the system root directory"
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory."
 msgstr "-isysroot <hakemisto>\tAseta <hakemisto> järjestelmän juurihakemistoksi"
 
-#: common.opt:3047
+#: common.opt:3051
 #, fuzzy
 msgid "-o <file>\tPlace output into <file>."
 msgstr "  -o <tiedosto>            Ohjaa tuloste <tiedostoon>\n"
 
-#: common.opt:3051
+#: common.opt:3055
 msgid "Enable function profiling."
 msgstr "Ota käyttöön funktioprofilointi."
 
-#: common.opt:3061
+#: common.opt:3065
 msgid "Like -pedantic but issue them as errors."
 msgstr ""
 
-#: common.opt:3101
+#: common.opt:3105
 msgid "Do not display functions compiled or elapsed time."
 msgstr ""
 
-#: common.opt:3133
+#: common.opt:3137
 #, fuzzy
 #| msgid "Enable debug output"
 msgid "Enable verbose output."
 msgstr "ohjaa monisanainen tuloste TIEDostoon"
 
-#: common.opt:3137
+#: common.opt:3141
 #, fuzzy
 #| msgid "Display the compiler's version"
 msgid "Display the compiler's version."
 msgstr "  --version                Näytä kääntäjän versiotiedot\n"
 
-#: common.opt:3141
+#: common.opt:3145
 msgid "Suppress warnings."
 msgstr "Vaienna varoitukset."
 
-#: common.opt:3151
+#: common.opt:3155
 msgid "Create a shared library."
 msgstr "Luo jaettu kirjasto."
 
-#: common.opt:3196
+#: common.opt:3200
 #, fuzzy
 #| msgid "Don't create a position independent executable."
 msgid "Don't create a dynamically linked position independent executable."
 msgstr "Älä luo paikkariippumatonta suoritettavaa tiedostoa."
 
-#: common.opt:3200
+#: common.opt:3204
 #, fuzzy
 #| msgid "Create a position independent executable"
 msgid "Create a dynamically linked position independent executable."
 msgstr "Luo paikkariippumaton suoritettava tiedosto"
 
-#: common.opt:3204
+#: common.opt:3208
 #, fuzzy
 #| msgid "Create a position independent executable"
 msgid "Create a static position independent executable."
 msgstr "Luo paikkariippumaton suoritettava tiedosto"
 
-#: common.opt:3211
+#: common.opt:3215
 msgid "Use caller save register across calls if possible."
 msgstr ""
 
-#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:598 cp/cvt.c:1308
+#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:599 cp/cvt.c:1308
 #: cp/cvt.c:1561
 #, gcc-internal-format
 msgid "value computed is not used"
@@ -17727,7 +17728,7 @@
 msgstr "odotettiin %qT, mutta argumentti on tyyppiä %qT"
 
 #: go/gofrontend/expressions.cc:4331 c/c-parser.c:13477 c/c-parser.c:13484
-#: cp/parser.c:33264 cp/parser.c:33271
+#: cp/parser.c:33261 cp/parser.c:33268
 #, fuzzy, gcc-internal-format
 msgid "expected integer"
 msgstr "odotettiin kokonaislukulauseketta"
@@ -18205,14 +18206,14 @@
 msgid "ignoring attribute %qE because it conflicts with attribute %qs"
 msgstr "%qE-attribuutti on ristiriidassa attribuutin %s kanssa"
 
-#: attribs.c:449 c-family/c-attribs.c:1894 cp/decl.c:13690 cp/friend.c:302
-#: cp/tree.c:4559
+#: attribs.c:449 c-family/c-attribs.c:1905 cp/decl.c:13714 cp/friend.c:302
+#: cp/tree.c:4607
 #, fuzzy, gcc-internal-format
 msgid "previous declaration here"
 msgstr "%q+D:lla on edellinen esittely täällä"
 
 #. Warn about and ignore all others for now, but store them.
-#: attribs.c:564 c-family/c-attribs.c:2717 objc/objc-act.c:4963
+#: attribs.c:564 c-family/c-attribs.c:2728 objc/objc-act.c:4963
 #: objc/objc-act.c:6932 objc/objc-act.c:8119 objc/objc-act.c:8170
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute directive ignored"
@@ -18231,17 +18232,17 @@
 #. This is a c++11 attribute that appertains to a
 #. type-specifier, outside of the definition of, a class
 #. type.  Ignore it.
-#: attribs.c:590 cp/decl.c:10999
+#: attribs.c:590 cp/decl.c:11023
 #, gcc-internal-format
 msgid "attribute ignored"
 msgstr "attribuuttia ei huomioida"
 
-#: attribs.c:592 cp/decl.c:11000
+#: attribs.c:592 cp/decl.c:11024
 #, fuzzy, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr "%qE-attribuuttia ei huomioida %qT-tyyppiselle kentälle"
 
-#: attribs.c:610 c-family/c-attribs.c:3219
+#: attribs.c:610 c-family/c-attribs.c:3230
 #, gcc-internal-format
 msgid "%qE attribute does not apply to types"
 msgstr "%qE-attribuutti ei päde tyyppeihin"
@@ -18257,40 +18258,40 @@
 msgstr "%qs-attribuuttia ei huomioida ei-luokkatyypeille"
 
 #: attribs.c:691 attribs.c:1622 attribs.c:1632 attribs.c:1642
-#: c-family/c-attribs.c:540 c-family/c-attribs.c:559 c-family/c-attribs.c:577
-#: c-family/c-attribs.c:607 c-family/c-attribs.c:628 c-family/c-attribs.c:649
-#: c-family/c-attribs.c:690 c-family/c-attribs.c:717 c-family/c-attribs.c:733
-#: c-family/c-attribs.c:750 c-family/c-attribs.c:766 c-family/c-attribs.c:792
-#: c-family/c-attribs.c:807 c-family/c-attribs.c:835 c-family/c-attribs.c:852
-#: c-family/c-attribs.c:870 c-family/c-attribs.c:893 c-family/c-attribs.c:931
-#: c-family/c-attribs.c:954 c-family/c-attribs.c:971 c-family/c-attribs.c:1000
-#: c-family/c-attribs.c:1021 c-family/c-attribs.c:1042
-#: c-family/c-attribs.c:1069 c-family/c-attribs.c:1099
-#: c-family/c-attribs.c:1136 c-family/c-attribs.c:1189
-#: c-family/c-attribs.c:1255 c-family/c-attribs.c:1313
-#: c-family/c-attribs.c:1402 c-family/c-attribs.c:1432
-#: c-family/c-attribs.c:1483 c-family/c-attribs.c:1998
-#: c-family/c-attribs.c:2035 c-family/c-attribs.c:2096
-#: c-family/c-attribs.c:2152 c-family/c-attribs.c:2230
-#: c-family/c-attribs.c:2312 c-family/c-attribs.c:2371
-#: c-family/c-attribs.c:2390 c-family/c-attribs.c:2498
-#: c-family/c-attribs.c:2514 c-family/c-attribs.c:2530
-#: c-family/c-attribs.c:2551 c-family/c-attribs.c:2608
-#: c-family/c-attribs.c:2635 c-family/c-attribs.c:2690
-#: c-family/c-attribs.c:2870 c-family/c-attribs.c:2891
-#: c-family/c-attribs.c:3004 c-family/c-attribs.c:3031
-#: c-family/c-attribs.c:3221 c-family/c-attribs.c:3239
-#: c-family/c-attribs.c:3262 c-family/c-attribs.c:3301
-#: c-family/c-attribs.c:3383 c-family/c-attribs.c:3439
-#: c-family/c-attribs.c:3455 c-family/c-attribs.c:3549
-#: c-family/c-common.c:5600 config/darwin.c:2072 config/arm/arm.c:6868
+#: c-family/c-attribs.c:547 c-family/c-attribs.c:566 c-family/c-attribs.c:584
+#: c-family/c-attribs.c:614 c-family/c-attribs.c:635 c-family/c-attribs.c:656
+#: c-family/c-attribs.c:697 c-family/c-attribs.c:728 c-family/c-attribs.c:744
+#: c-family/c-attribs.c:761 c-family/c-attribs.c:777 c-family/c-attribs.c:803
+#: c-family/c-attribs.c:818 c-family/c-attribs.c:846 c-family/c-attribs.c:863
+#: c-family/c-attribs.c:881 c-family/c-attribs.c:904 c-family/c-attribs.c:942
+#: c-family/c-attribs.c:965 c-family/c-attribs.c:982 c-family/c-attribs.c:1011
+#: c-family/c-attribs.c:1032 c-family/c-attribs.c:1053
+#: c-family/c-attribs.c:1080 c-family/c-attribs.c:1110
+#: c-family/c-attribs.c:1147 c-family/c-attribs.c:1200
+#: c-family/c-attribs.c:1266 c-family/c-attribs.c:1324
+#: c-family/c-attribs.c:1413 c-family/c-attribs.c:1443
+#: c-family/c-attribs.c:1494 c-family/c-attribs.c:2009
+#: c-family/c-attribs.c:2046 c-family/c-attribs.c:2107
+#: c-family/c-attribs.c:2163 c-family/c-attribs.c:2241
+#: c-family/c-attribs.c:2323 c-family/c-attribs.c:2382
+#: c-family/c-attribs.c:2401 c-family/c-attribs.c:2509
+#: c-family/c-attribs.c:2525 c-family/c-attribs.c:2541
+#: c-family/c-attribs.c:2562 c-family/c-attribs.c:2619
+#: c-family/c-attribs.c:2646 c-family/c-attribs.c:2701
+#: c-family/c-attribs.c:2881 c-family/c-attribs.c:2902
+#: c-family/c-attribs.c:3015 c-family/c-attribs.c:3042
+#: c-family/c-attribs.c:3232 c-family/c-attribs.c:3250
+#: c-family/c-attribs.c:3273 c-family/c-attribs.c:3312
+#: c-family/c-attribs.c:3394 c-family/c-attribs.c:3450
+#: c-family/c-attribs.c:3466 c-family/c-attribs.c:3560
+#: c-family/c-common.c:5598 config/darwin.c:2072 config/arm/arm.c:6868
 #: config/arm/arm.c:6896 config/arm/arm.c:6913 config/avr/avr.c:9698
-#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6497
-#: config/i386/i386.c:41520 config/ia64/ia64.c:788
-#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33056
-#: config/spu/spu.c:3743 ada/gcc-interface/utils.c:6244
-#: ada/gcc-interface/utils.c:6261 ada/gcc-interface/utils.c:6277
-#: ada/gcc-interface/utils.c:6303 brig/brig-lang.c:476 lto/lto-lang.c:283
+#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6500
+#: config/i386/i386.c:41514 config/ia64/ia64.c:788
+#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33112
+#: config/spu/spu.c:3743 ada/gcc-interface/utils.c:6249
+#: ada/gcc-interface/utils.c:6266 ada/gcc-interface/utils.c:6282
+#: ada/gcc-interface/utils.c:6308 brig/brig-lang.c:476 lto/lto-lang.c:283
 #, gcc-internal-format
 msgid "%qE attribute ignored"
 msgstr "%qE-attribuuttia ei huomioida"
@@ -18661,90 +18662,105 @@
 msgid "%Kattempt to free a non-heap object"
 msgstr ""
 
-#: calls.c:1434
+#: calls.c:1291 file-prefix-map.c:50
 #, fuzzy, gcc-internal-format
+msgid "invalid argument %qs to %qs"
+msgstr "argumentti %qd ei ole vakio"
+
+#: calls.c:1452
+#, fuzzy, gcc-internal-format
 #| msgid "Argument of %s function at %L is negative"
 msgid "%Kargument %i value %qE is negative"
 msgstr "Funktion %s argumentti kohdassa %L on negatiivinen"
 
-#: calls.c:1452
+#: calls.c:1470
 #, fuzzy, gcc-internal-format
 msgid "%Kargument %i value is zero"
 msgstr "%<__builtin_prefetch%>-funktion toinen argumentti on epäkelpo; käytetään nollaa"
 
-#: calls.c:1469
+#: calls.c:1487
 #, gcc-internal-format
 msgid "%Kargument %i value %qE exceeds maximum object size %E"
 msgstr ""
 
-#: calls.c:1483
+#: calls.c:1501
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of %s function at %L is negative"
 msgid "%Kargument %i range [%E, %E] is negative"
 msgstr "Funktion %s argumentti kohdassa %L on negatiivinen"
 
-#: calls.c:1490
+#: calls.c:1508
 #, gcc-internal-format
 msgid "%Kargument %i range [%E, %E] exceeds maximum object size %E"
 msgstr ""
 
-#: calls.c:1520
+#: calls.c:1538
 #, gcc-internal-format
 msgid "%Kproduct %<%E * %E%> of arguments %i and %i exceeds %<SIZE_MAX%>"
 msgstr ""
 
-#: calls.c:1526
+#: calls.c:1544
 #, gcc-internal-format
 msgid "%Kproduct %<%E * %E%> of arguments %i and %i exceeds maximum object size %E"
 msgstr ""
 
-#: calls.c:1537 calls.c:1540
+#: calls.c:1555 calls.c:1558
 #, fuzzy, gcc-internal-format
 msgid "argument %i in the range [%E, %E]"
 msgstr "kohdistuksen pitää olla kahden potenssi, ei %d"
 
-#: calls.c:1551
+#: calls.c:1569
 #, fuzzy, gcc-internal-format
 msgid "in a call to built-in allocation function %qD"
 msgstr "%qD on tavallisesti ei-staattinen funktio"
 
-#: calls.c:1554
+#: calls.c:1572
 #, fuzzy, gcc-internal-format
 msgid "in a call to allocation function %qD declared here"
 msgstr "muuttuja %qD esitelty %<inline%>:ksi"
 
-#: calls.c:1711
+#: calls.c:1835
 #, gcc-internal-format
-msgid "%qD argument %i declared attribute %<nonstring%> is smaller than the specified bound %E"
+msgid "%qD argument %i declared attribute %<nonstring%> is smaller than the specified bound %wu"
 msgstr ""
 
-#: calls.c:1716
+#: calls.c:1841
+#, gcc-internal-format
+msgid "%qD argument %i declared attribute %<nonstring%> is smaller than the specified bound [%E, %E]"
+msgstr ""
+
+#: calls.c:1847
+#, gcc-internal-format
+msgid "%qD argument %i declared attribute %<nonstring%> may be smaller than the specified bound [%E, %E]"
+msgstr ""
+
+#: calls.c:1857
 #, fuzzy, gcc-internal-format
 msgid "%qD argument %i declared attribute %<nonstring%>"
 msgstr "parametriksi ei voida esitellä %<constexpr%>:ksi"
 
-#: calls.c:1721
+#: calls.c:1862
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared here"
 msgid "argument %qD declared here"
 msgstr "%qD esiteltiin täällä"
 
-#: calls.c:1735
+#: calls.c:1876
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot tail-call: %s"
 msgstr "lähdetiedostoa %s ei löydy"
 
-#: calls.c:3365
+#: calls.c:3506
 #, gcc-internal-format
 msgid "function call has aggregate value"
 msgstr ""
 
-#: calls.c:4059
+#: calls.c:4200
 #, fuzzy, gcc-internal-format
 msgid "passing too large argument on stack"
 msgstr "blocks-argumentti on liian suuri, maksimi on %llu"
 
-#: cfgexpand.c:1665 function.c:1002 varasm.c:2231
+#: cfgexpand.c:1665 function.c:1002 varasm.c:2242
 #, gcc-internal-format
 msgid "size of variable %q+D is too large"
 msgstr "muuttujan %q+D koko on liian suuri"
@@ -19320,237 +19336,237 @@
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr ""
 
-#: cgraph.c:3051
+#: cgraph.c:3056
 #, fuzzy, gcc-internal-format
 msgid "caller edge count invalid"
 msgstr "oikealle siirron lukumäärä on negatiivinen"
 
-#: cgraph.c:3135
+#: cgraph.c:3140
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr ""
 
-#: cgraph.c:3142
+#: cgraph.c:3147
 #, gcc-internal-format
 msgid "cgraph count invalid"
 msgstr ""
 
-#: cgraph.c:3147
+#: cgraph.c:3152
 #, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr ""
 
-#: cgraph.c:3152
+#: cgraph.c:3157
 #, fuzzy, gcc-internal-format
 msgid "local symbols must be defined"
 msgstr "%s: kenttä ”%s” ei saa olla määritelty"
 
-#: cgraph.c:3157
+#: cgraph.c:3162
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr ""
 
-#: cgraph.c:3162
+#: cgraph.c:3167
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr ""
 
-#: cgraph.c:3167
+#: cgraph.c:3172
 #, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr ""
 
-#: cgraph.c:3174
+#: cgraph.c:3179
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for indirect edge from %s"
 msgstr ""
 
-#: cgraph.c:3181
+#: cgraph.c:3186
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr ""
 
-#: cgraph.c:3196
+#: cgraph.c:3201
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr ""
 
-#: cgraph.c:3206
+#: cgraph.c:3211
 #, fuzzy, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr "Väärä taikaluku --- RESERVED_13"
 
-#: cgraph.c:3211
+#: cgraph.c:3216
 #, fuzzy, gcc-internal-format
 msgid "multiple inline callers"
 msgstr "parametri %q+D esitelty %<inline%>:ksi"
 
-#: cgraph.c:3218
+#: cgraph.c:3223
 #, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr ""
 
-#: cgraph.c:3239
+#: cgraph.c:3244
 #, fuzzy, gcc-internal-format
 msgid "caller edge count does not match BB count"
 msgstr "oikealle siirron lukumäärä on negatiivinen"
 
-#: cgraph.c:3261
+#: cgraph.c:3266
 #, gcc-internal-format
 msgid "indirect call count does not match BB count"
 msgstr ""
 
-#: cgraph.c:3272
+#: cgraph.c:3277
 #, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr ""
 
-#: cgraph.c:3277
+#: cgraph.c:3282
 #, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr ""
 
-#: cgraph.c:3289
+#: cgraph.c:3294
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr ""
 
-#: cgraph.c:3301
+#: cgraph.c:3306
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr ""
 
-#: cgraph.c:3307
+#: cgraph.c:3312
 #, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr ""
 
-#: cgraph.c:3312
+#: cgraph.c:3317
 #, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr ""
 
-#: cgraph.c:3317
+#: cgraph.c:3322
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr ""
 
-#: cgraph.c:3329
+#: cgraph.c:3334
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr ""
 
-#: cgraph.c:3337
+#: cgraph.c:3342
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr ""
 
-#: cgraph.c:3342
+#: cgraph.c:3347
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr ""
 
-#: cgraph.c:3349
+#: cgraph.c:3354
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr ""
 
-#: cgraph.c:3358
+#: cgraph.c:3363
 #, gcc-internal-format
 msgid "Instrumentation clone does not reference original node"
 msgstr ""
 
-#: cgraph.c:3365
+#: cgraph.c:3370
 #, fuzzy, gcc-internal-format
 msgid "Not instrumented node has non-NULL original declaration"
 msgstr "%J%qD:n lohko on ristiriidassa edellisen esittelyn kanssa"
 
-#: cgraph.c:3375
+#: cgraph.c:3380
 #, fuzzy, gcc-internal-format
 msgid "Instrumented node has wrong original declaration"
 msgstr "%J%qD:n lohko on ristiriidassa edellisen esittelyn kanssa"
 
-#: cgraph.c:3393
+#: cgraph.c:3398
 #, gcc-internal-format
 msgid "Node has more than one chkp reference"
 msgstr ""
 
-#: cgraph.c:3398
+#: cgraph.c:3403
 #, gcc-internal-format
 msgid "Wrong node is referenced with chkp reference"
 msgstr ""
 
-#: cgraph.c:3406
+#: cgraph.c:3411
 #, gcc-internal-format
 msgid "Analyzed node has no reference to instrumented version"
 msgstr ""
 
-#: cgraph.c:3420
+#: cgraph.c:3425
 #, gcc-internal-format
 msgid "Alias chain for instrumented node is broken"
 msgstr ""
 
-#: cgraph.c:3429
+#: cgraph.c:3434
 #, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3434
+#: cgraph.c:3439
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3439
+#: cgraph.c:3444
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr ""
 
-#: cgraph.c:3445
+#: cgraph.c:3450
 #, gcc-internal-format
 msgid "Instrumentation thunk has wrong edge callee"
 msgstr ""
 
-#: cgraph.c:3481
+#: cgraph.c:3486
 #, fuzzy, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr "Stmt-sisäkkäistysvirhe."
 
-#: cgraph.c:3489
+#: cgraph.c:3494
 #, fuzzy, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr "tyhjä esittely"
 
-#: cgraph.c:3498
+#: cgraph.c:3503
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr ""
 
-#: cgraph.c:3508
+#: cgraph.c:3513
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr ""
 
-#: cgraph.c:3518
+#: cgraph.c:3523
 #, fuzzy, gcc-internal-format
 msgid "reference to dead statement"
 msgstr "lauseella ei ole vaikutusta"
 
-#: cgraph.c:3531
+#: cgraph.c:3536
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3543
+#: cgraph.c:3548
 #, gcc-internal-format, gfc-internal-format
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3554
+#: cgraph.c:3559
 #, fuzzy, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr "symtab_node::verify epäonnistui"
 
-#: cgraph.c:3661 varpool.c:306
+#: cgraph.c:3666 varpool.c:306
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s: section %s is missing"
 msgstr "%s: osaa ”%.*s” ei tunneta"
@@ -19581,12 +19597,12 @@
 msgstr "%qs-attribuuttia ei huomioida %qs:lle"
 
 #. include_self=
-#: cgraphunit.c:981 c/c-decl.c:11282
+#: cgraphunit.c:981 c/c-decl.c:11302
 #, fuzzy, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "nimike %q+D määritelty mutta käytettämättä"
 
-#: cgraphunit.c:983 c/c-decl.c:11291
+#: cgraphunit.c:983 c/c-decl.c:11311
 #, fuzzy, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "sisäkkäinen funktio %q+D esitelty mutta ei koskaan määritelty"
@@ -19703,12 +19719,12 @@
 msgid "cannot find '%s'"
 msgstr "lähdetiedostoa %s ei löydy"
 
-#: collect-utils.c:183 collect2.c:2361 collect2.c:2560 gcc.c:3080 gcc.c:6856
+#: collect-utils.c:183 collect2.c:2387 collect2.c:2586 gcc.c:3080 gcc.c:6856
 #, fuzzy, gcc-internal-format
 msgid "pex_init failed: %m"
 msgstr "cap_init epäonnistui"
 
-#: collect-utils.c:192 collect2.c:2370 collect2.c:2568 gcc.c:8498
+#: collect-utils.c:192 collect2.c:2396 collect2.c:2594 gcc.c:8498
 #, gcc-internal-format
 msgid "%s: %m"
 msgstr "%s: %m"
@@ -19718,7 +19734,7 @@
 msgid "COLLECT_LTO_WRAPPER must be set"
 msgstr "COLLECT_GCC-ympäristömuuttujan on oltava asetettuna"
 
-#: collect2.c:966 gcc.c:7382 lto-wrapper.c:1666
+#: collect2.c:969 gcc.c:7382 lto-wrapper.c:1692
 #: config/i386/intelmic-mkoffload.c:556 config/nvptx/mkoffload.c:405
 #, fuzzy, gcc-internal-format
 msgid "atexit failed"
@@ -19726,87 +19742,87 @@
 " EPÄONNISTUI\n"
 "\n"
 
-#: collect2.c:1064
+#: collect2.c:1067
 #, gcc-internal-format
 msgid "no arguments"
 msgstr "ei argumentteja"
 
-#: collect2.c:1303 opts.c:904
+#: collect2.c:1311 opts.c:904
 #, fuzzy, gcc-internal-format
 msgid "LTO support has not been enabled in this configuration"
 msgstr "#pragma redefine_extname ei ole tuettu tällä kohteella"
 
-#: collect2.c:1344
+#: collect2.c:1352
 #, fuzzy, gcc-internal-format
 msgid "can't open %s: %m"
 msgstr "Hakemistoa %s ei voi avata"
 
-#: collect2.c:1450
+#: collect2.c:1472
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown demangling style '%s'"
 msgstr "Tuntematon (%s)"
 
-#: collect2.c:1546 collect2.c:1729 collect2.c:1769
+#: collect2.c:1574 collect2.c:1757 collect2.c:1797
 #, gcc-internal-format
 msgid "fopen %s: %m"
 msgstr "fopen %s: %m"
 
-#: collect2.c:1549 collect2.c:1734 collect2.c:1772
+#: collect2.c:1577 collect2.c:1762 collect2.c:1800
 #, gcc-internal-format
 msgid "fclose %s: %m"
 msgstr "fclose %s: %m"
 
-#: collect2.c:2335
+#: collect2.c:2361
 #, fuzzy, gcc-internal-format
 msgid "cannot find 'nm'"
 msgstr "ei löydetä protokollaesittelyä %qE:lle"
 
-#: collect2.c:2383
+#: collect2.c:2409
 #, fuzzy, gcc-internal-format
 msgid "can't open nm output: %m"
 msgstr "ei voida avata ldd-tulostetta"
 
-#: collect2.c:2467
+#: collect2.c:2493
 #, gcc-internal-format, gfc-internal-format
 msgid "init function found in object %s"
 msgstr ""
 
-#: collect2.c:2478
+#: collect2.c:2504
 #, gcc-internal-format, gfc-internal-format
 msgid "fini function found in object %s"
 msgstr ""
 
-#: collect2.c:2535
+#: collect2.c:2561
 #, fuzzy, gcc-internal-format
 msgid "cannot find 'ldd'"
 msgstr "ei löydetä protokollaesittelyä %qE:lle"
 
-#: collect2.c:2581
+#: collect2.c:2607
 #, fuzzy, gcc-internal-format
 msgid "can't open ldd output: %m"
 msgstr "ei voida avata ldd-tulostetta"
 
-#: collect2.c:2599
+#: collect2.c:2625
 #, gcc-internal-format, gfc-internal-format
 msgid "dynamic dependency %s not found"
 msgstr "dynaamista riippuvuutta %s ei löytynyt"
 
-#: collect2.c:2611
+#: collect2.c:2637
 #, gcc-internal-format, gfc-internal-format
 msgid "unable to open dynamic dependency '%s'"
 msgstr "ei voida avata dynaamista riippuvuutta ”%s”"
 
-#: collect2.c:2765
+#: collect2.c:2791
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: not a COFF file"
 msgstr "%s: ei ole COFF-tiedosto"
 
-#: collect2.c:2930
+#: collect2.c:2961
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: cannot open as COFF file"
 msgstr "%s: ei voida avata COFF-tiedostona"
 
-#: collect2.c:2989
+#: collect2.c:3020
 #, gcc-internal-format, gfc-internal-format
 msgid "library lib%s not found"
 msgstr "kirjastoa lib%s ei löytynyt"
@@ -20016,12 +20032,12 @@
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr ""
 
-#: dwarf2out.c:10901
+#: dwarf2out.c:10909
 #, gcc-internal-format
 msgid "-gdwarf-6 is output as version 5 with incompatibilities"
 msgstr ""
 
-#: dwarf2out.c:14415
+#: dwarf2out.c:14423
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
@@ -20141,11 +20157,6 @@
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr "%Kkutsu kohteeseen %qs esitelty attribuuttivaroituksella: %s"
 
-#: file-prefix-map.c:50
-#, fuzzy, gcc-internal-format
-msgid "invalid argument %qs to %qs"
-msgstr "argumentti %qd ei ole vakio"
-
 #: final.c:1868
 #, gcc-internal-format
 msgid "the frame size of %wd bytes is larger than %wd bytes"
@@ -20166,42 +20177,42 @@
 msgid "large fixed-point constant implicitly truncated to fixed-point type"
 msgstr "suuri kokonaisluku implisiittisesti katkaistu etumerkittömäksi tyypiksi"
 
-#: fold-const.c:4151 fold-const.c:4161
+#: fold-const.c:4157 fold-const.c:4167
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d due to width of bit-field"
 msgstr "vertailu on aina %d johtuen bittikentän leveydestä"
 
-#: fold-const.c:5478 tree-ssa-reassoc.c:2374 tree-ssa-reassoc.c:3214
+#: fold-const.c:5484 tree-ssa-reassoc.c:2379 tree-ssa-reassoc.c:3219
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
 
-#: fold-const.c:5928 fold-const.c:5942
+#: fold-const.c:5934 fold-const.c:5948
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr "vertailu on aina %d johtuen bittikentän leveydestä"
 
-#: fold-const.c:6085
+#: fold-const.c:6091
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr ""
 
-#: fold-const.c:6090
+#: fold-const.c:6096
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr ""
 
-#: fold-const.c:8310
+#: fold-const.c:8316
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr ""
 
-#: fold-const.c:8710
+#: fold-const.c:8716
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr ""
 
-#: fold-const.c:12063
+#: fold-const.c:12069
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr ""
@@ -20211,7 +20222,7 @@
 msgid "total size of local objects too large"
 msgstr "paikallisten objektien kokonaiskoko on liian suuri"
 
-#: function.c:1776 gimplify.c:6270
+#: function.c:1776 gimplify.c:6273
 #, fuzzy, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr "virheellinen ”asm”: "
@@ -20521,7 +20532,7 @@
 msgid "%s: linker input file unused because linking not done"
 msgstr ""
 
-#: gcc.c:8420 c-family/c-opts.c:770
+#: gcc.c:8420 c-family/c-opts.c:768
 #, gcc-internal-format
 msgid "cannot use %<-%> as input filename for a precompiled header"
 msgstr ""
@@ -20759,7 +20770,7 @@
 msgid "%G%qD destination unchanged after copying no bytes"
 msgstr ""
 
-#: gimple-fold.c:2052 tree-ssa-strlen.c:2050
+#: gimple-fold.c:2052 tree-ssa-strlen.c:2074
 msgid "%G%qD specified bound %E equals destination size"
 msgstr ""
 
@@ -20781,12 +20792,12 @@
 msgid "null pointer dereference"
 msgstr "PRINT_OPERAND null-osoitin"
 
-#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12451
-#: tree.c:12488 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10147
-#: c/c-typeck.c:10164 c/gimple-parser.c:1616 c/gimple-parser.c:1624
+#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12455
+#: tree.c:12492 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10152
+#: c/c-typeck.c:10169 c/gimple-parser.c:1616 c/gimple-parser.c:1624
 #: cp/call.c:6493 cp/call.c:8098 cp/constexpr.c:820 cp/constexpr.c:2309
-#: cp/cvt.c:1015 cp/cvt.c:1042 cp/decl.c:7334 cp/decl2.c:5256 cp/pt.c:8334
-#: cp/semantics.c:1836 cp/semantics.c:4053 cp/typeck.c:1700 cp/typeck.c:1895
+#: cp/cvt.c:1015 cp/cvt.c:1042 cp/decl.c:7355 cp/decl2.c:5246 cp/pt.c:8348
+#: cp/semantics.c:1836 cp/semantics.c:4056 cp/typeck.c:1700 cp/typeck.c:1895
 #: cp/typeck.c:3837
 #, gcc-internal-format
 msgid "declared here"
@@ -20797,27 +20808,27 @@
 msgid "nonnull argument %qD compared to NULL"
 msgstr "annettu NULL funktion %2$qD ei-osoitinargumenttina %1$P"
 
-#: gimple-ssa-sprintf.c:2517 gimple-ssa-sprintf.c:2637
+#: gimple-ssa-sprintf.c:2555 gimple-ssa-sprintf.c:2675
 #, gcc-internal-format
 msgid "%qE output may be truncated before the last format character"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2519 gimple-ssa-sprintf.c:2639
+#: gimple-ssa-sprintf.c:2557 gimple-ssa-sprintf.c:2677
 #, gcc-internal-format
 msgid "%qE output truncated before the last format character"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2522 gimple-ssa-sprintf.c:2642
+#: gimple-ssa-sprintf.c:2560 gimple-ssa-sprintf.c:2680
 #, gcc-internal-format
 msgid "%qE may write a terminating nul past the end of the destination"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2524 gimple-ssa-sprintf.c:2644
+#: gimple-ssa-sprintf.c:2562 gimple-ssa-sprintf.c:2682
 #, gcc-internal-format
 msgid "%qE writing a terminating nul past the end of the destination"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2534
+#: gimple-ssa-sprintf.c:2572
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size %wu"
@@ -20824,7 +20835,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.c:2541
+#: gimple-ssa-sprintf.c:2579
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size %wu"
@@ -20831,7 +20842,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.c:2548
+#: gimple-ssa-sprintf.c:2586
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size %wu"
@@ -20838,67 +20849,67 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.c:2559
+#: gimple-ssa-sprintf.c:2597
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2562
+#: gimple-ssa-sprintf.c:2600
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2564
+#: gimple-ssa-sprintf.c:2602
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2576
+#: gimple-ssa-sprintf.c:2614
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2579
+#: gimple-ssa-sprintf.c:2617
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2582
+#: gimple-ssa-sprintf.c:2620
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2591
+#: gimple-ssa-sprintf.c:2629
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2594
+#: gimple-ssa-sprintf.c:2632
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2597
+#: gimple-ssa-sprintf.c:2635
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2606
+#: gimple-ssa-sprintf.c:2644
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2609
+#: gimple-ssa-sprintf.c:2647
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2611
+#: gimple-ssa-sprintf.c:2649
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2653
+#: gimple-ssa-sprintf.c:2691
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size between %wu and %wu"
@@ -20905,7 +20916,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.c:2660
+#: gimple-ssa-sprintf.c:2698
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size between %wu and %wu"
@@ -20912,7 +20923,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.c:2668
+#: gimple-ssa-sprintf.c:2706
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size between %wu and %wu"
@@ -20919,102 +20930,102 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.c:2680
+#: gimple-ssa-sprintf.c:2718
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2683
+#: gimple-ssa-sprintf.c:2721
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2686
+#: gimple-ssa-sprintf.c:2724
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2699
+#: gimple-ssa-sprintf.c:2737
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2702
+#: gimple-ssa-sprintf.c:2740
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2705
+#: gimple-ssa-sprintf.c:2743
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2715
+#: gimple-ssa-sprintf.c:2753
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2718
+#: gimple-ssa-sprintf.c:2756
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2721
+#: gimple-ssa-sprintf.c:2759
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2730
+#: gimple-ssa-sprintf.c:2768
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2733
+#: gimple-ssa-sprintf.c:2771
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2736
+#: gimple-ssa-sprintf.c:2774
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2825
+#: gimple-ssa-sprintf.c:2863
 #, gcc-internal-format
 msgid "%<%.*s%> directive argument is null"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2890
+#: gimple-ssa-sprintf.c:2928
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes exceeds minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2897
+#: gimple-ssa-sprintf.c:2935
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may exceed minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2900
+#: gimple-ssa-sprintf.c:2938
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes exceeds minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2929
+#: gimple-ssa-sprintf.c:2967
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2936
+#: gimple-ssa-sprintf.c:2974
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2939
+#: gimple-ssa-sprintf.c:2977
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may cause result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2949
+#: gimple-ssa-sprintf.c:2987
 #, gcc-internal-format
 msgid "assuming directive output of %wu byte"
 msgid_plural "assuming directive output of %wu bytes"
@@ -21021,78 +21032,78 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.c:2956
+#: gimple-ssa-sprintf.c:2994
 #, fuzzy, gcc-internal-format
 msgid "directive argument %qE"
 msgstr "Funktion %s argumentti kohdassa %L on negatiivinen"
 
-#: gimple-ssa-sprintf.c:2958
+#: gimple-ssa-sprintf.c:2996
 #, fuzzy, gcc-internal-format
 msgid "directive argument in the range [%E, %E]"
 msgstr "%s odottaa kokonaislukuliteraalia väliltä [%d, %d]."
 
-#: gimple-ssa-sprintf.c:2962
+#: gimple-ssa-sprintf.c:3000
 #, gcc-internal-format
 msgid "using the range [%E, %E] for directive argument"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2982
+#: gimple-ssa-sprintf.c:3020
 #, gcc-internal-format
 msgid "%qE output %wu byte into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2983
+#: gimple-ssa-sprintf.c:3021
 #, gcc-internal-format
 msgid "%qE output %wu bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2987
+#: gimple-ssa-sprintf.c:3025
 #, gcc-internal-format
 msgid "%qE output between %wu and %wu bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2992
+#: gimple-ssa-sprintf.c:3030
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes (assuming %wu) into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2997
+#: gimple-ssa-sprintf.c:3035
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3368
+#: gimple-ssa-sprintf.c:3406
 #, gcc-internal-format
 msgid "%<%.*s%> directive width out of range"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3402
+#: gimple-ssa-sprintf.c:3440
 #, gcc-internal-format
 msgid "%<%.*s%> directive precision out of range"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3893
+#: gimple-ssa-sprintf.c:3931
 #, gcc-internal-format
 msgid "specified bound %wu exceeds maximum object size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3899
+#: gimple-ssa-sprintf.c:3937
 #, gcc-internal-format
 msgid "specified bound %wu exceeds %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3949
+#: gimple-ssa-sprintf.c:3987
 #, fuzzy, gcc-internal-format
 #| msgid "null pointer"
 msgid "null destination pointer"
 msgstr "nollaosoitin"
 
-#: gimple-ssa-sprintf.c:3966
+#: gimple-ssa-sprintf.c:4004
 #, gcc-internal-format
 msgid "specified bound %wu exceeds the size %wu of the destination object"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3978
+#: gimple-ssa-sprintf.c:4016
 #, fuzzy, gcc-internal-format
 #| msgid "%s in format string at %L"
 msgid "null format string"
@@ -21310,10 +21321,10 @@
 msgstr ""
 
 #: gimple-ssa-warn-restrict.c:1678 c/c-decl.c:3603 c/c-decl.c:3874
-#: c/c-typeck.c:8345 cp/class.c:1346 cp/class.c:3098 cp/decl.c:3979
-#: cp/decl.c:10753 cp/decl.c:11151 cp/decl.c:11160 cp/friend.c:384
+#: c/c-typeck.c:8350 cp/class.c:1346 cp/class.c:3102 cp/decl.c:3979
+#: cp/decl.c:10777 cp/decl.c:11175 cp/decl.c:11184 cp/friend.c:384
 #: cp/friend.c:393 cp/parser.c:3275 cp/parser.c:3372 cp/parser.c:3422
-#: cp/parser.c:6327 cp/parser.c:21027
+#: cp/parser.c:6330 cp/parser.c:21024
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD esitelty täällä"
@@ -21385,207 +21396,207 @@
 msgid "using result of function returning %<void%>"
 msgstr "%<return%> arvon kanssa voidin palauttavassa funktiossa"
 
-#: gimplify.c:6128
+#: gimplify.c:6131
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid lvalue in asm output %d"
 msgstr "virheellinen lvalue asm-tulosteessa %d"
 
-#: gimplify.c:6271
+#: gimplify.c:6274
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr ""
 
-#: gimplify.c:6311 gimplify.c:6320
+#: gimplify.c:6314 gimplify.c:6323
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr ""
 
-#: gimplify.c:6928
+#: gimplify.c:6931
 #, fuzzy, gcc-internal-format
 msgid "threadprivate variable %qE used in target region"
 msgstr "sisäkkäisessä funktiossa käytetty rekisterimuuttujaa %qD"
 
-#: gimplify.c:6930
+#: gimplify.c:6933
 #, fuzzy, gcc-internal-format
 msgid "enclosing target region"
 msgstr "# Ei kohde:"
 
-#: gimplify.c:6942
+#: gimplify.c:6945
 #, fuzzy, gcc-internal-format
 msgid "threadprivate variable %qE used in untied task"
 msgstr "sisäkkäisessä funktiossa käytetty rekisterimuuttujaa %qD"
 
-#: gimplify.c:6944
+#: gimplify.c:6947
 #, gcc-internal-format
 msgid "enclosing task"
 msgstr ""
 
-#: gimplify.c:7016
+#: gimplify.c:7019
 #, fuzzy, gcc-internal-format
 msgid "%qE not specified in enclosing %qs"
 msgstr "%qs määritelty parametrille %qE"
 
-#: gimplify.c:7018
+#: gimplify.c:7021
 #, fuzzy, gcc-internal-format
 #| msgid "close: %s"
 msgid "enclosing %qs"
 msgstr "          %s"
 
-#: gimplify.c:7143
+#: gimplify.c:7146
 #, fuzzy, gcc-internal-format
 msgid "%qE not specified in enclosing OpenACC %qs construct"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: gimplify.c:7145
+#: gimplify.c:7148
 #, gcc-internal-format
 msgid "enclosing OpenACC %qs construct"
 msgstr ""
 
-#: gimplify.c:7198
+#: gimplify.c:7201
 #, gcc-internal-format
 msgid "%qE with %<link%> clause used in %<routine%> function"
 msgstr ""
 
-#: gimplify.c:7206
+#: gimplify.c:7209
 #, fuzzy, gcc-internal-format
 #| msgid "%qE undeclared (first use in this function)"
 msgid "%qE requires a %<declare%> directive for use in a %<routine%> function"
 msgstr "%qE esittelemättä (ensimmäinen käyttökerta tässä funktiossa)"
 
-#: gimplify.c:7272 gimplify.c:7872
+#: gimplify.c:7275 gimplify.c:7875
 #, fuzzy, gcc-internal-format
 #| msgid "variable %q+D declared %<inline%>"
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr "muuttuja %qD esitelty %<inline%>:ksi"
 
-#: gimplify.c:7293
+#: gimplify.c:7296
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr ""
 
-#: gimplify.c:7411 gimplify.c:7443
+#: gimplify.c:7414 gimplify.c:7446
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE is predetermined linear"
 msgstr "virheellinen tyyppi iterointimuuttujalle %qE"
 
-#: gimplify.c:7414
+#: gimplify.c:7417
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should be private"
 msgstr "virheellinen tyyppi iterointimuuttujalle %qE"
 
-#: gimplify.c:7428
+#: gimplify.c:7431
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be firstprivate"
 msgstr "virheellinen tyyppi iterointimuuttujalle %qE"
 
-#: gimplify.c:7431
+#: gimplify.c:7434
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be reduction"
 msgstr "virheellinen tyyppi iterointimuuttujalle %qE"
 
-#: gimplify.c:7434
+#: gimplify.c:7437
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be linear"
 msgstr "virheellinen tyyppi iterointimuuttujalle %qE"
 
-#: gimplify.c:7437
+#: gimplify.c:7440
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be lastprivate"
 msgstr "virheellinen tyyppi iterointimuuttujalle %qE"
 
-#: gimplify.c:7440
+#: gimplify.c:7443
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be private"
 msgstr "virheellinen tyyppi iterointimuuttujalle %qE"
 
-#: gimplify.c:7742
+#: gimplify.c:7745
 #, gcc-internal-format
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr ""
 
-#: gimplify.c:7949
+#: gimplify.c:7952
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr ""
 
-#: gimplify.c:8160
+#: gimplify.c:8163
 #, gcc-internal-format
 msgid "%qE appears more than once in map clauses"
 msgstr ""
 
-#: gimplify.c:8464
+#: gimplify.c:8467
 #, fuzzy, gcc-internal-format
 #| msgid "local variable %qD may not appear in this context"
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr "paikallinen muuttuja %qD ei voi esiintyä tässä yhteydessä"
 
-#: gimplify.c:8484
+#: gimplify.c:8487
 #, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr ""
 
-#: gimplify.c:8510
+#: gimplify.c:8513
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<operator%>"
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr "odotettiin %<operator%>"
 
-#: gimplify.c:8775
+#: gimplify.c:8778
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr ""
 
-#: gimplify.c:8808
+#: gimplify.c:8811
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:9000
+#: gimplify.c:9003
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:9051
+#: gimplify.c:9054
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr ""
 
-#: gimplify.c:9133
+#: gimplify.c:9136
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to present_or_copy"
 msgstr ""
 
-#: gimplify.c:9278
+#: gimplify.c:9281
 #, fuzzy, gcc-internal-format
 msgid "invalid private reduction on %qE"
 msgstr "%qD ei ole malli"
 
-#: gimplify.c:11103 omp-low.c:2791
+#: gimplify.c:11106 omp-low.c:2791
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: gimplify.c:11121
+#: gimplify.c:11124
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr ""
 
-#: gimplify.c:11134
+#: gimplify.c:11137
 #, fuzzy, gcc-internal-format
 msgid "number of variables in %<depend(sink)%> clause does not match number of iteration variables"
 msgstr "argumenttien määrä ei vastaa prototyyppiä"
 
-#: gimplify.c:11147
+#: gimplify.c:11150
 #, gcc-internal-format
 msgid "more than one %<depend(source)%> clause on an %<ordered%> construct"
 msgstr ""
 
-#: gimplify.c:11158
+#: gimplify.c:11161
 #, gcc-internal-format
 msgid "%<depend(source)%> clause specified together with %<depend(sink:)%> clauses on the same construct"
 msgstr ""
 
-#: gimplify.c:12393
+#: gimplify.c:12396
 #, fuzzy, gcc-internal-format
 msgid "gimplification failed"
 msgstr ""
@@ -21592,17 +21603,17 @@
 " EPÄONNISTUI\n"
 "\n"
 
-#: gimplify.c:12936
+#: gimplify.c:12939
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr "%qT muunnetaan tyypiksi %qT, kun se viedään %<...%>:n läpi"
 
-#: gimplify.c:12941
+#: gimplify.c:12944
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr "(eli kannattaisi antaa %qT eikä %qT funktiolle %<va_arg%>)"
 
-#: gimplify.c:12948
+#: gimplify.c:12951
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr "jos tämä koodi saavutetaan, ohjelma keskeytyy"
@@ -22087,47 +22098,47 @@
 msgid "Max. number of generated reload insns per insn is achieved (%d)\n"
 msgstr ""
 
-#: lto-cgraph.c:1294
+#: lto-cgraph.c:1296
 #, gcc-internal-format, gfc-internal-format
 msgid "bytecode stream: found multiple instances of cgraph node with uid %d"
 msgstr ""
 
-#: lto-cgraph.c:1472
+#: lto-cgraph.c:1474
 #, gcc-internal-format
 msgid "bytecode stream: no caller found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1478
+#: lto-cgraph.c:1480
 #, gcc-internal-format
 msgid "bytecode stream: no callee found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1552
+#: lto-cgraph.c:1554
 #, gcc-internal-format
 msgid "bytecode stream: found empty cgraph node"
 msgstr ""
 
-#: lto-cgraph.c:1730
+#: lto-cgraph.c:1732
 #, gcc-internal-format, gfc-internal-format
 msgid "At most %i profile runs is supported. Perhaps corrupted profile?"
 msgstr ""
 
-#: lto-cgraph.c:1817
+#: lto-cgraph.c:1819
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Profile information in %s corrupted"
 msgstr "”%s” ei ole oikea profiilidatatiedosto ”%s”:lle"
 
-#: lto-cgraph.c:1855
+#: lto-cgraph.c:1857
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO cgraph in %s"
 msgstr "lähdetiedostoa %s ei löydy"
 
-#: lto-cgraph.c:1865
+#: lto-cgraph.c:1867
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO section refs in %s"
 msgstr "%J%qD:lle ei ole aiempaa esittelyä"
 
-#: lto-cgraph.c:1946
+#: lto-cgraph.c:1948
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid offload table in %s"
 msgstr "Taulukkotyyppi      : %s\n"
@@ -22199,85 +22210,91 @@
 msgid "bytecode stream in file %qs generated with LTO version %d.%d instead of the expected %d.%d"
 msgstr ""
 
-#: lto-wrapper.c:117
+#: lto-wrapper.c:118
 #, fuzzy, gcc-internal-format
 #| msgid "deleting LTRANS file %s"
 msgid "deleting LTRANS file %s: %m"
 msgstr "*** [%s] Poistetaan tiedosto ”%s”"
 
-#: lto-wrapper.c:154
+#: lto-wrapper.c:155
 #, gcc-internal-format
 msgid "malformed COLLECT_GCC_OPTIONS"
 msgstr "vääränmuotoinen COLLECT_GCC_OPTIONS"
 
-#: lto-wrapper.c:308
+#: lto-wrapper.c:309
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Option %s with different values"
 msgstr "%q+D:n virheellinen uudelleenesittely"
 
-#: lto-wrapper.c:392
+#: lto-wrapper.c:393
 #, gcc-internal-format, gfc-internal-format
 msgid "Option %s not used consistently in all LTO input files"
 msgstr ""
 
-#: lto-wrapper.c:832
+#: lto-wrapper.c:833
 #, gcc-internal-format, gfc-internal-format
 msgid "problem with building target image for %s\n"
 msgstr ""
 
-#: lto-wrapper.c:852
+#: lto-wrapper.c:853
 #, fuzzy, gcc-internal-format
 #| msgid "no input files"
 msgid "reading input file"
 msgstr "Virhe luettaessa syötetiedostoa %s"
 
-#: lto-wrapper.c:857
+#: lto-wrapper.c:858
 #, fuzzy, gcc-internal-format
 msgid "writing output file"
 msgstr "kirjoitettaessa tulostetta tiedostoon %s: %m"
 
-#: lto-wrapper.c:889
+#: lto-wrapper.c:890
 #, gcc-internal-format
 msgid "installation error, can't find crtoffloadtable.o"
 msgstr ""
 
-#: lto-wrapper.c:1000 lto-wrapper.c:1012
+#: lto-wrapper.c:1001 lto-wrapper.c:1013
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s: %s"
 msgid "%s: %s\n"
 msgstr "%s: %s"
 
-#: lto-wrapper.c:1056
+#: lto-wrapper.c:1064
 #, gcc-internal-format
 msgid "environment variable COLLECT_GCC must be set"
 msgstr "COLLECT_GCC-ympäristömuuttujan on oltava asetettuna"
 
-#: lto-wrapper.c:1060 config/nvptx/mkoffload.c:363
+#: lto-wrapper.c:1068 config/nvptx/mkoffload.c:363
 #, gcc-internal-format
 msgid "environment variable COLLECT_GCC_OPTIONS must be set"
 msgstr "COLLECT_GCC_OPTIONS-ympäristömuuttujan on oltava asetettuna"
 
-#: lto-wrapper.c:1229 lto-wrapper.c:1285
+#: lto-wrapper.c:1237 lto-wrapper.c:1293
 #, fuzzy, gcc-internal-format
 msgid "cannot open %s: %m"
 msgstr "Hakemistoa %s ei voi avata"
 
-#: lto-wrapper.c:1232 lto-wrapper.c:1291
+#: lto-wrapper.c:1240 lto-wrapper.c:1299
 #, fuzzy, gcc-internal-format
 #| msgid "can%'t read %s: %m"
 msgid "cannot read %s: %m"
 msgstr "ei voi lukea tiedostoa %s: %m"
 
-#: lto-wrapper.c:1259
+#: lto-wrapper.c:1267
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid format of %s"
 msgstr "Virheellinen tiedostotoiminto: %s"
 
-#: lto-wrapper.c:1482
+#: lto-wrapper.c:1491
 #, gcc-internal-format
 msgid "fopen: %s: %m"
 msgstr "fopen: %s: %m"
 
+#: lto-wrapper.c:1508
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "Could not open output file '%s'\n"
+msgid "Corrupted ltrans output file %s"
+msgstr "Tulostiedoston ”%s” avaaminen epäonnistui\n"
+
 #: multiple_target.c:76
 #, fuzzy, gcc-internal-format
 msgid "the call requires ifunc, which is not supported by this target"
@@ -22636,12 +22653,12 @@
 msgid "unrecognized argument in option %qs"
 msgstr "tuntematon komentorivivalitsin %qs"
 
-#: opts-common.c:1198 config/i386/i386.c:3206
+#: opts-common.c:1198 config/i386/i386.c:3209
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "Kelvolliset argumentit:"
 
-#: opts-common.c:1201 config/i386/i386.c:3209
+#: opts-common.c:1201 config/i386/i386.c:3212
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "Kelvolliset argumentit:"
@@ -23235,22 +23252,22 @@
 msgid "output operand %d must use %<&%> constraint"
 msgstr ""
 
-#: regcprop.c:1187
+#: regcprop.c:1193
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad next_regno for empty chain (%u)"
 msgstr ""
 
-#: regcprop.c:1199
+#: regcprop.c:1205
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: Loop in regno chain (%u)"
 msgstr ""
 
-#: regcprop.c:1202
+#: regcprop.c:1208
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad oldest_regno (%u)"
 msgstr ""
 
-#: regcprop.c:1214
+#: regcprop.c:1220
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Non-empty reg in chain (%s %u %i)"
 msgstr ""
@@ -23294,7 +23311,7 @@
 msgstr "sisäkkäisessä funktiossa käytetty globaalia rekisterimuuttujaa %qD"
 
 #: reginfo.c:789 config/powerpcspe/powerpcspe.c:32259
-#: config/rs6000/rs6000.c:29453
+#: config/rs6000/rs6000.c:29530
 #, fuzzy, gcc-internal-format
 msgid "conflicts with %qD"
 msgstr "nimellä %qD"
@@ -23540,154 +23557,159 @@
 msgid "function symbol is not function"
 msgstr "funktion palauttava funktio"
 
-#: symtab.c:1006
+#: symtab.c:1005
+#, gcc-internal-format
+msgid "inconsistent `ifunc' attribute"
+msgstr ""
+
+#: symtab.c:1013
 #, fuzzy, gcc-internal-format
 msgid "variable symbol is not variable"
 msgstr "%qD ei ole muuttuja"
 
-#: symtab.c:1012
+#: symtab.c:1019
 #, fuzzy, gcc-internal-format
 msgid "node has unknown type"
 msgstr "tiedostolla %s on tuntematon tiedostotyyppi"
 
-#: symtab.c:1021
+#: symtab.c:1028
 #, gcc-internal-format
 msgid "node not found node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.c:1029
+#: symtab.c:1036
 #, gcc-internal-format
 msgid "node differs from node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.c:1038
+#: symtab.c:1045
 #, gcc-internal-format
 msgid "assembler name hash list corrupted"
 msgstr ""
 
-#: symtab.c:1051
+#: symtab.c:1058
 #, gcc-internal-format
 msgid "node not found in symtab assembler name hash"
 msgstr ""
 
-#: symtab.c:1058
+#: symtab.c:1065
 #, gcc-internal-format
 msgid "double linked list of assembler names corrupted"
 msgstr ""
 
-#: symtab.c:1063
+#: symtab.c:1070
 #, fuzzy, gcc-internal-format
 msgid "node has body_removed but is definition"
 msgstr "ei-muuttujan %qD esittely %<for%>-silmukan alkuesittelyssä"
 
-#: symtab.c:1068
+#: symtab.c:1075
 #, fuzzy, gcc-internal-format
 msgid "node is analyzed but it is not a definition"
 msgstr "ei-muuttujan %qD esittely %<for%>-silmukan alkuesittelyssä"
 
-#: symtab.c:1073
+#: symtab.c:1080
 #, fuzzy, gcc-internal-format
 msgid "node is alias but not implicit alias"
 msgstr "maa-asetustojen aliastiedostoa ”%s” ei löydy"
 
-#: symtab.c:1078
+#: symtab.c:1085
 #, fuzzy, gcc-internal-format
 #| msgid "old-style function definition"
 msgid "node is alias but not definition"
 msgstr "maa-asetustojen aliastiedostoa ”%s” ei löydy"
 
-#: symtab.c:1083
+#: symtab.c:1090
 #, gcc-internal-format
 msgid "node is weakref but not an transparent_alias"
 msgstr ""
 
-#: symtab.c:1088
+#: symtab.c:1095
 #, fuzzy, gcc-internal-format
 #| msgid "old-style function definition"
 msgid "node is transparent_alias but not an alias"
 msgstr "maa-asetustojen aliastiedostoa ”%s” ei löydy"
 
-#: symtab.c:1097
+#: symtab.c:1104
 #, gcc-internal-format
 msgid "node is in same_comdat_group list but has no comdat_group"
 msgstr ""
 
-#: symtab.c:1102
+#: symtab.c:1109
 #, gcc-internal-format
 msgid "same_comdat_group list across different groups"
 msgstr ""
 
-#: symtab.c:1107
+#: symtab.c:1114
 #, gcc-internal-format
 msgid "mixing different types of symbol in same comdat groups is not supported"
 msgstr ""
 
-#: symtab.c:1112
+#: symtab.c:1119
 #, gcc-internal-format
 msgid "node is alone in a comdat group"
 msgstr ""
 
-#: symtab.c:1119
+#: symtab.c:1126
 #, gcc-internal-format
 msgid "same_comdat_group is not a circular list"
 msgstr ""
 
-#: symtab.c:1134
+#: symtab.c:1141
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local symbol referred to by %s outside its comdat"
 msgstr ""
 
-#: symtab.c:1144
+#: symtab.c:1151
 #, gcc-internal-format
 msgid "implicit_section flag is set but section isn't"
 msgstr ""
 
-#: symtab.c:1151
+#: symtab.c:1158
 #, gcc-internal-format
 msgid "Both section and comdat group is set"
 msgstr ""
 
-#: symtab.c:1163
+#: symtab.c:1170
 #, fuzzy, gcc-internal-format
 msgid "Alias and target's section differs"
 msgstr "Sama kuin --help=target"
 
-#: symtab.c:1170
+#: symtab.c:1177
 #, gcc-internal-format
 msgid "Alias and target's comdat groups differs"
 msgstr ""
 
-#: symtab.c:1185
+#: symtab.c:1192
 #, gcc-internal-format
 msgid "Transparent alias and target's assembler names differs"
 msgstr ""
 
-#: symtab.c:1193
+#: symtab.c:1200
 #, fuzzy, gcc-internal-format
 msgid "Chained transparent aliases"
 msgstr "unionista ei voi tehdä läpinäkyvää"
 
-#: symtab.c:1216 symtab.c:1253
+#: symtab.c:1223 symtab.c:1260
 #, gcc-internal-format
 msgid "symtab_node::verify failed"
 msgstr "symtab_node::verify epäonnistui"
 
-#: symtab.c:1249
+#: symtab.c:1256
 #, gcc-internal-format
 msgid "Two symbols with same comdat_group are not linked by the same_comdat_group list."
 msgstr ""
 
-#: symtab.c:1658
+#: symtab.c:1665
 #, fuzzy, gcc-internal-format
 msgid "function %q+D part of alias cycle"
 msgstr "%Jsisäänrakennettu funktio %qD esitelty ei-funktiona"
 
-#: symtab.c:1660
+#: symtab.c:1667
 #, fuzzy, gcc-internal-format
 msgid "variable %q+D part of alias cycle"
 msgstr "muuttujalla %qD on funktiotyyppi"
 
-#: symtab.c:1688
+#: symtab.c:1695
 #, gcc-internal-format
 msgid "section of alias %q+D must match section of its target"
 msgstr ""
@@ -24493,7 +24515,7 @@
 msgid "the first argument of a VEC_COND_EXPR must be of a boolean vector type of the same number of elements as the result"
 msgstr ""
 
-#: tree-cfg.c:4395 c/c-typeck.c:5212
+#: tree-cfg.c:4395 c/c-typeck.c:5217
 #, gcc-internal-format
 msgid "type mismatch in conditional expression"
 msgstr "ehtolausekkeessa on tyyppiristiriita"
@@ -24843,22 +24865,22 @@
 msgid "missing edge %i->%i"
 msgstr "”I”-lippu"
 
-#: tree-cfg.c:9379
+#: tree-cfg.c:9388
 #, gcc-internal-format
 msgid "%<noreturn%> function does return"
 msgstr "%<noreturn%>-funktio palaa"
 
-#: tree-cfg.c:9400 tree-cfg.c:9432
+#: tree-cfg.c:9409 tree-cfg.c:9441
 #, gcc-internal-format
 msgid "control reaches end of non-void function"
 msgstr "ei-void-tyyppisen funktion loppu saavutettu"
 
-#: tree-cfg.c:9498 cp/cvt.c:1039
+#: tree-cfg.c:9507 cp/cvt.c:1039
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgstr "%qD:n paluuarvoa ei huomioida, esitelty attribuutilla warn_unused_result"
 
-#: tree-cfg.c:9503 cp/cvt.c:1046
+#: tree-cfg.c:9512 cp/cvt.c:1046
 #, gcc-internal-format
 msgid "ignoring return value of function declared with attribute warn_unused_result"
 msgstr "attribuutilla warn_unused_result esitellyn funktion paluuarvoa ei huomioida"
@@ -25125,47 +25147,47 @@
 msgid "stmt volatile flag not up-to-date"
 msgstr ""
 
-#: tree-ssa-strlen.c:1975
+#: tree-ssa-strlen.c:1999
 msgid "%G%qD output truncated before terminating nul copying %E byte from a string of the same length"
 msgid_plural "%G%qD output truncated before terminating nul copying %E bytes from a string of the same length"
 msgstr[0] ""
 msgstr[1] ""
 
-#: tree-ssa-strlen.c:1989
+#: tree-ssa-strlen.c:2013
 msgid "%G%qD output truncated copying %E byte from a string of length %wu"
 msgid_plural "%G%qD output truncated copying %E bytes from a string of length %wu"
 msgstr[0] ""
 msgstr[1] ""
 
-#: tree-ssa-strlen.c:1996
+#: tree-ssa-strlen.c:2020
 msgid "%G%qD output truncated copying between %wu and %wu bytes from a string of length %wu"
 msgstr ""
 
-#: tree-ssa-strlen.c:2008
+#: tree-ssa-strlen.c:2032
 msgid "%G%qD output may be truncated copying %E byte from a string of length %wu"
 msgid_plural "%G%qD output may be truncated copying %E bytes from a string of length %wu"
 msgstr[0] ""
 msgstr[1] ""
 
-#: tree-ssa-strlen.c:2015 tree-ssa-strlen.c:2029
+#: tree-ssa-strlen.c:2039 tree-ssa-strlen.c:2053
 msgid "%G%qD output may be truncated copying between %wu and %wu bytes from a string of length %wu"
 msgstr ""
 
-#: tree-ssa-strlen.c:2150
+#: tree-ssa-strlen.c:2174
 msgid "%G%qD output truncated before terminating nul copying as many bytes from a string as its length"
 msgstr ""
 
-#: tree-ssa-strlen.c:2156
+#: tree-ssa-strlen.c:2180
 msgid "%G%qD specified bound depends on the length of the source argument"
 msgstr ""
 
-#: tree-ssa-strlen.c:2163
+#: tree-ssa-strlen.c:2187
 #, fuzzy, gcc-internal-format
 #| msgid "length modifier"
 msgid "length computed here"
 msgstr "pituusmääre"
 
-#: tree-ssa-uninit.c:191 varasm.c:331
+#: tree-ssa-uninit.c:191 varasm.c:342
 #, gcc-internal-format
 msgid "%qD was declared here"
 msgstr "%qD esiteltiin täällä"
@@ -25340,27 +25362,27 @@
 msgid "target specific builtin not available"
 msgstr "Väärin muotoiltu kohdekohtainen muuttujamäärittely"
 
-#: tree-vect-generic.c:287
+#: tree-vect-generic.c:283
 #, gcc-internal-format
 msgid "vector operation will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-generic.c:290
+#: tree-vect-generic.c:286
 #, gcc-internal-format
 msgid "vector operation will be expanded in parallel"
 msgstr ""
 
-#: tree-vect-generic.c:341
+#: tree-vect-generic.c:337
 #, gcc-internal-format
 msgid "vector operation will be expanded with a single scalar operation"
 msgstr ""
 
-#: tree-vect-generic.c:941
+#: tree-vect-generic.c:937
 #, gcc-internal-format
 msgid "vector condition will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-generic.c:1373
+#: tree-vect-generic.c:1369
 #, gcc-internal-format
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr ""
@@ -25370,31 +25392,31 @@
 msgid "vectorization did not happen for a simd loop"
 msgstr ""
 
-#: tree-vrp.c:4930 tree-vrp.c:4974
+#: tree-vrp.c:4931 tree-vrp.c:4975
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is above array bounds"
 msgid "array subscript %E is above array bounds of %qT"
 msgstr "taulukon indeksi on taulukkorajojen yläpuolella"
 
-#: tree-vrp.c:4956
+#: tree-vrp.c:4957
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is outside array bounds"
 msgid "array subscript [%E, %E] is outside array bounds of %qT"
 msgstr "taulukon indeksi on taulukkorajojen ulkopuolella"
 
-#: tree-vrp.c:4988
+#: tree-vrp.c:4989
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is below array bounds"
 msgid "array subscript %E is below array bounds of %qT"
 msgstr "taulukon indeksi on taulukkorajojen alapuolella"
 
-#: tree-vrp.c:5046
+#: tree-vrp.c:5047
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is below array bounds"
 msgid "array subscript %wi is below array bounds of %qT"
 msgstr "taulukon indeksi on taulukkorajojen alapuolella"
 
-#: tree-vrp.c:5060
+#: tree-vrp.c:5061
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is above array bounds"
 msgid "array subscript %wu is above array bounds of %qT"
@@ -25410,94 +25432,94 @@
 msgid "side-effects element in no-side-effects CONSTRUCTOR"
 msgstr ""
 
-#: tree.c:7852
+#: tree.c:7856
 #, fuzzy, gcc-internal-format
 msgid "arrays of functions are not meaningful"
 msgstr "------ Semaforitaulukot --------\n"
 
-#: tree.c:8019
+#: tree.c:8023
 #, gcc-internal-format
 msgid "function return type cannot be function"
 msgstr "funktion paluuarvon tyyppi ei voi olla funktio"
 
-#: tree.c:9327 tree.c:9412 tree.c:9473
+#: tree.c:9331 tree.c:9416 tree.c:9477
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: %s, have %s in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9364
+#: tree.c:9368
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected none of %s, have %s in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9377
+#: tree.c:9381
 #, gcc-internal-format
 msgid "tree check: expected class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9426
+#: tree.c:9430
 #, gcc-internal-format
 msgid "tree check: did not expect class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9439
+#: tree.c:9443
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected omp_clause %s, have %s in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9499
+#: tree.c:9503
 #, gcc-internal-format
 msgid "tree check: expected tree that contains %qs structure, have %qs in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9513
+#: tree.c:9517
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_int_cst with %d elts in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9525
+#: tree.c:9529
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_vec with %d elts in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9538
+#: tree.c:9542
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of %s with %d operands in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9551
+#: tree.c:9555
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of omp_clause %s with %d operands in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:12446
+#: tree.c:12450
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is deprecated: %s"
 msgid "%qD is deprecated: %s"
 msgstr "%qE on vanhentunut: %s"
 
-#: tree.c:12449
+#: tree.c:12453
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is deprecated"
 msgid "%qD is deprecated"
 msgstr "%qE on vanhentunut"
 
-#: tree.c:12473 tree.c:12495
+#: tree.c:12477 tree.c:12499
 #, gcc-internal-format
 msgid "%qE is deprecated: %s"
 msgstr "%qE on vanhentunut: %s"
 
-#: tree.c:12476 tree.c:12498
+#: tree.c:12480 tree.c:12502
 #, gcc-internal-format
 msgid "%qE is deprecated"
 msgstr "%qE on vanhentunut"
 
-#: tree.c:12482 tree.c:12503
+#: tree.c:12486 tree.c:12507
 #, gcc-internal-format, gfc-internal-format
 msgid "type is deprecated: %s"
 msgstr "tyyppi on vanhentunut: %s"
 
-#: tree.c:12485 tree.c:12506
+#: tree.c:12489 tree.c:12510
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr "tyyppi on vanhentunut"
@@ -25522,243 +25544,243 @@
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.c:13043
+#: tree.c:13047
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "type variant differs by %s"
 msgstr "Tiedoston tyyppi eroaa"
 
-#: tree.c:13084
+#: tree.c:13088
 #, gcc-internal-format
 msgid "type variant has different TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13086
+#: tree.c:13090
 #, fuzzy, gcc-internal-format
 msgid "type variant's TYPE_SIZE_UNIT"
 msgstr "tyypillä %qT ei ole tunnettua kokoa"
 
-#: tree.c:13088
+#: tree.c:13092
 #, fuzzy, gcc-internal-format
 msgid "type's TYPE_SIZE_UNIT"
 msgstr "tyypillä %qT ei ole tunnettua kokoa"
 
-#: tree.c:13108
+#: tree.c:13112
 #, gcc-internal-format
 msgid "type variant with TYPE_ALIAS_SET_KNOWN_P"
 msgstr ""
 
-#: tree.c:13121
+#: tree.c:13125
 #, gcc-internal-format
 msgid "type variant has different TYPE_VFIELD"
 msgstr ""
 
-#: tree.c:13157
+#: tree.c:13161
 #, gcc-internal-format
 msgid "type variant has different TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13159
+#: tree.c:13163
 #, fuzzy, gcc-internal-format
 msgid "type variant's TYPE_BINFO"
 msgstr "paluutyyppi on vaillinainen tyyppi"
 
-#: tree.c:13161
+#: tree.c:13165
 #, fuzzy, gcc-internal-format
 msgid "type's TYPE_BINFO"
 msgstr "paluutyyppi on vaillinainen tyyppi"
 
-#: tree.c:13199
+#: tree.c:13203
 #, gcc-internal-format
 msgid "type variant has different TYPE_FIELDS"
 msgstr ""
 
-#: tree.c:13201
+#: tree.c:13205
 #, fuzzy, gcc-internal-format
 msgid "first mismatch is field"
 msgstr "tyyppitäsmäämättömyys taulukkoviitteessä"
 
-#: tree.c:13203
+#: tree.c:13207
 #, fuzzy, gcc-internal-format
 msgid "and field"
 msgstr "kentän leveys"
 
-#: tree.c:13220
+#: tree.c:13224
 #, gcc-internal-format
 msgid "type variant has different TREE_TYPE"
 msgstr ""
 
-#: tree.c:13222 tree.c:13233
+#: tree.c:13226 tree.c:13237
 #, fuzzy, gcc-internal-format
 msgid "type variant's TREE_TYPE"
 msgstr "paluutyyppi on vaillinainen tyyppi"
 
-#: tree.c:13224 tree.c:13235
+#: tree.c:13228 tree.c:13239
 #, fuzzy, gcc-internal-format
 msgid "type's TREE_TYPE"
 msgstr "paluutyyppi on vaillinainen tyyppi"
 
-#: tree.c:13231
+#: tree.c:13235
 #, fuzzy, gcc-internal-format
 msgid "type is not compatible with its variant"
 msgstr "funktiokutsu epäsopivan tyypin läpi"
 
-#: tree.c:13534
+#: tree.c:13538
 #, fuzzy, gcc-internal-format
 msgid "Main variant is not defined"
 msgstr "”%s” on määrittelemättä"
 
-#: tree.c:13539
+#: tree.c:13543
 #, gcc-internal-format
 msgid "TYPE_MAIN_VARIANT has different TYPE_MAIN_VARIANT"
 msgstr ""
 
-#: tree.c:13551
+#: tree.c:13555
 #, gcc-internal-format
 msgid "TYPE_CANONICAL has different TYPE_CANONICAL"
 msgstr ""
 
-#: tree.c:13569
+#: tree.c:13573
 #, gcc-internal-format
 msgid "TYPE_CANONICAL is not compatible"
 msgstr ""
 
-#: tree.c:13577
+#: tree.c:13581
 #, fuzzy, gcc-internal-format
 msgid "TYPE_MODE of TYPE_CANONICAL is not compatible"
 msgstr "funktiokutsu epäsopivan tyypin läpi"
 
-#: tree.c:13583
+#: tree.c:13587
 #, gcc-internal-format
 msgid "TYPE_CANONICAL of main variant is not main variant"
 msgstr ""
 
-#: tree.c:13599
+#: tree.c:13603
 #, gcc-internal-format
 msgid "TYPE_VFIELD is not FIELD_DECL nor TREE_LIST"
 msgstr ""
 
-#: tree.c:13609
+#: tree.c:13613
 #, fuzzy, gcc-internal-format
 msgid "TYPE_NEXT_PTR_TO is not POINTER_TYPE"
 msgstr "ei voi muuntaa osoitintyypiksi"
 
-#: tree.c:13619
+#: tree.c:13623
 #, fuzzy, gcc-internal-format
 msgid "TYPE_NEXT_REF_TO is not REFERENCE_TYPE"
 msgstr "tyyppitäsmäämättömyys komponenttiviitteessä"
 
-#: tree.c:13640
+#: tree.c:13644
 #, gcc-internal-format
 msgid "TYPE_BINFO is not TREE_BINFO"
 msgstr ""
 
-#: tree.c:13646
+#: tree.c:13650
 #, gcc-internal-format
 msgid "TYPE_BINFO type is not TYPE_MAIN_VARIANT"
 msgstr ""
 
-#: tree.c:13657
+#: tree.c:13661
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not record nor union"
 msgstr ""
 
-#: tree.c:13668
+#: tree.c:13672
 #, gcc-internal-format
 msgid "TYPE_OFFSET_BASETYPE is not record nor union"
 msgstr ""
 
-#: tree.c:13686
+#: tree.c:13690
 #, fuzzy, gcc-internal-format
 msgid "TYPE_ARRAY_MAX_SIZE not INTEGER_CST"
 msgstr "taulukon %qE koko ei ole kokonaislukutyyppiä"
 
-#: tree.c:13693
+#: tree.c:13697
 #, fuzzy, gcc-internal-format
 msgid "TYPE_MAX_VALUE_RAW non-NULL"
 msgstr "NULLin muunnos epäosoitintyypiksi"
 
-#: tree.c:13700
+#: tree.c:13704
 #, gcc-internal-format
 msgid "TYPE_LANG_SLOT_1 (binfo) field is non-NULL"
 msgstr ""
 
-#: tree.c:13716
+#: tree.c:13720
 #, gcc-internal-format
 msgid "Enum value is not CONST_DECL or INTEGER_CST"
 msgstr ""
 
-#: tree.c:13724
+#: tree.c:13728
 #, gcc-internal-format
 msgid "Enum value type is not INTEGER_TYPE nor convertible to the enum"
 msgstr ""
 
-#: tree.c:13731
+#: tree.c:13735
 #, gcc-internal-format
 msgid "Enum value name is not IDENTIFIER_NODE"
 msgstr ""
 
-#: tree.c:13741
+#: tree.c:13745
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qE has non-integer type"
 msgid "Array TYPE_DOMAIN is not integer type"
 msgstr "taulukkoindeksi alustimessa ei ole kokonaislukutyyppinen"
 
-#: tree.c:13750
+#: tree.c:13754
 #, fuzzy, gcc-internal-format
 msgid "TYPE_FIELDS defined in incomplete type"
 msgstr "paluutyyppi on vaillinainen tyyppi"
 
-#: tree.c:13772
+#: tree.c:13776
 #, gcc-internal-format
 msgid "Wrong tree in TYPE_FIELDS list"
 msgstr ""
 
-#: tree.c:13787
+#: tree.c:13791
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is %i while TYPE_CACHED_VALUES is %p"
 msgstr ""
 
-#: tree.c:13793
+#: tree.c:13797
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES is not TREE_VEC"
 msgstr ""
 
-#: tree.c:13806
+#: tree.c:13810
 #, gcc-internal-format
 msgid "wrong TYPE_CACHED_VALUES entry"
 msgstr ""
 
-#: tree.c:13819
+#: tree.c:13823
 #, gcc-internal-format
 msgid "TREE_PURPOSE is non-NULL in TYPE_ARG_TYPES list"
 msgstr ""
 
-#: tree.c:13825
+#: tree.c:13829
 #, gcc-internal-format
 msgid "Wrong entry in TYPE_ARG_TYPES list"
 msgstr ""
 
-#: tree.c:13832
+#: tree.c:13836
 #, gcc-internal-format
 msgid "TYPE_VALUES_RAW field is non-NULL"
 msgstr ""
 
-#: tree.c:13844
+#: tree.c:13848
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is set while it should not"
 msgstr ""
 
-#: tree.c:13850
+#: tree.c:13854
 #, gcc-internal-format
 msgid "TYPE_STRING_FLAG is set on wrong type code"
 msgstr ""
 
-#: tree.c:13860
+#: tree.c:13864
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not main variant"
 msgstr ""
 
-#: tree.c:13867
+#: tree.c:13871
 #, fuzzy, gcc-internal-format
 #| msgid "verify_gimple failed"
 msgid "verify_type failed"
@@ -25784,183 +25806,183 @@
 msgid "corrupted value profile: %s profile counter (%d out of %d) inconsistent with basic-block count (%d)"
 msgstr ""
 
-#: var-tracking.c:7166
+#: var-tracking.c:7184
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded with -fvar-tracking-assignments, retrying without"
 msgstr ""
 
-#: var-tracking.c:7170
+#: var-tracking.c:7188
 #, fuzzy, gcc-internal-format
 msgid "variable tracking size limit exceeded"
 msgstr "Tiedoston kokoraja ylitetty"
 
-#: varasm.c:326
+#: varasm.c:337
 #, fuzzy, gcc-internal-format
 msgid "%+qD causes a section type conflict with %qD"
 msgstr "Tuntematon (tyyppi = %d, bitit = %d)\n"
 
-#: varasm.c:329
+#: varasm.c:340
 #, fuzzy, gcc-internal-format
 msgid "section type conflict with %qD"
 msgstr "Tuntematon (tyyppi = %d, bitit = %d)\n"
 
-#: varasm.c:334
+#: varasm.c:345
 #, fuzzy, gcc-internal-format
 msgid "%+qD causes a section type conflict"
 msgstr "[OSIO...]"
 
-#: varasm.c:336
+#: varasm.c:347
 #, fuzzy, gcc-internal-format
 msgid "section type conflict"
 msgstr "[OSIO...]"
 
-#: varasm.c:1019
+#: varasm.c:1030
 #, fuzzy, gcc-internal-format
 msgid "alignment of %q+D is greater than maximum object file alignment %d"
 msgstr "%J%qD:n lohko on ristiriidassa edellisen esittelyn kanssa"
 
-#: varasm.c:1172
+#: varasm.c:1183
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is used uninitialized in this function"
 msgid "only zero initializers are allowed in section %qs"
 msgstr "%qD:a käytetään alustamattomana tässä funktiossa"
 
-#: varasm.c:1378 varasm.c:1387
+#: varasm.c:1389 varasm.c:1398
 #, fuzzy, gcc-internal-format
 msgid "register name not specified for %q+D"
 msgstr "kohdistusta ei voi määritellä %q+D:lle"
 
-#: varasm.c:1389
+#: varasm.c:1400
 #, fuzzy, gcc-internal-format
 msgid "invalid register name for %q+D"
 msgstr "%q+D:n virheellinen uudelleenesittely"
 
-#: varasm.c:1391
+#: varasm.c:1402
 #, gcc-internal-format
 msgid "data type of %q+D isn%'t suitable for a register"
 msgstr ""
 
-#: varasm.c:1394
+#: varasm.c:1405
 #, gcc-internal-format
 msgid "the register specified for %q+D cannot be accessed by the current target"
 msgstr ""
 
-#: varasm.c:1397
+#: varasm.c:1408
 #, gcc-internal-format
 msgid "the register specified for %q+D is not general enough to be used as a register variable"
 msgstr ""
 
-#: varasm.c:1400
+#: varasm.c:1411
 #, gcc-internal-format
 msgid "register specified for %q+D isn%'t suitable for data type"
 msgstr ""
 
-#: varasm.c:1410
+#: varasm.c:1421
 #, gcc-internal-format
 msgid "global register variable has initial value"
 msgstr ""
 
-#: varasm.c:1414
+#: varasm.c:1425
 #, gcc-internal-format
 msgid "optimization may eliminate reads and/or writes to register variables"
 msgstr ""
 
-#: varasm.c:1460
+#: varasm.c:1471
 #, gcc-internal-format
 msgid "register name given for non-register variable %q+D"
 msgstr ""
 
-#: varasm.c:1870
+#: varasm.c:1881
 #, gcc-internal-format
 msgid "Patchable function entry > size"
 msgstr ""
 
-#: varasm.c:2069
+#: varasm.c:2080
 #, gcc-internal-format
 msgid "thread-local COMMON data not implemented"
 msgstr ""
 
-#: varasm.c:2102
+#: varasm.c:2113
 #, gcc-internal-format
 msgid "requested alignment for %q+D is greater than implemented alignment of %wu"
 msgstr ""
 
-#: varasm.c:2205 c/c-decl.c:5027 c/c-parser.c:1534
+#: varasm.c:2216 c/c-decl.c:5027 c/c-parser.c:1534
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t known"
 msgstr "muuttujan %q+D koko muistissa ei ole tunnettu"
 
-#: varasm.c:4910
+#: varasm.c:4921
 #, gcc-internal-format
 msgid "initializer for integer/fixed-point value is too complicated"
 msgstr ""
 
-#: varasm.c:4915
+#: varasm.c:4926
 #, gcc-internal-format
 msgid "initializer for floating value is not a floating constant"
 msgstr "alustin liukulukuarvolle ei ole liukulukuvakio"
 
-#: varasm.c:5227
+#: varasm.c:5238
 #, gcc-internal-format
 msgid "invalid initial value for member %qE"
 msgstr "virheellinen alkuarvo jäsenelle %qE"
 
-#: varasm.c:5487
+#: varasm.c:5498
 #, fuzzy, gcc-internal-format
 msgid "%+qD declared weak after being used"
 msgstr "%J%qD esitelty avoimeksi kutsumisen jälkeen"
 
-#: varasm.c:5539
+#: varasm.c:5550
 #, fuzzy, gcc-internal-format
 msgid "weak declaration of %q+D being applied to a already existing, static definition"
 msgstr "%qs:n esittely taulukollisena funktioita"
 
-#: varasm.c:5575
+#: varasm.c:5586
 #, fuzzy, gcc-internal-format
 msgid "weak declaration of %q+D must be public"
 msgstr "%J%qD esitelty uudelleen ilman linkitystä"
 
-#: varasm.c:5579
+#: varasm.c:5590
 #, fuzzy, gcc-internal-format
 msgid "weak declaration of %q+D not supported"
 msgstr "esittelyssä %q+D"
 
-#: varasm.c:5608 varasm.c:5912
+#: varasm.c:5619 varasm.c:5926
 #, gcc-internal-format
 msgid "only weak aliases are supported in this configuration"
 msgstr ""
 
-#: varasm.c:5802
+#: varasm.c:5813
 #, gcc-internal-format
 msgid "weakref is not supported in this configuration"
 msgstr "weakref ei ole tuettu tässä konfiguraatiossa"
 
-#: varasm.c:5834
+#: varasm.c:5846
 #, fuzzy, gcc-internal-format
 msgid "ifunc is not supported on this target"
 msgstr "Ei ole tuettu"
 
-#: varasm.c:5892
+#: varasm.c:5904
 #, gcc-internal-format
 msgid "weakref %q+D ultimately targets itself"
 msgstr ""
 
-#: varasm.c:5894
+#: varasm.c:5906
 #, gcc-internal-format
 msgid "weakref %q+D must have static linkage"
 msgstr ""
 
-#: varasm.c:5901
+#: varasm.c:5913
 #, fuzzy, gcc-internal-format
 msgid "alias definitions not supported in this configuration"
 msgstr "weakref ei ole tuettu tässä konfiguraatiossa"
 
-#: varasm.c:5909
+#: varasm.c:5923
 #, fuzzy, gcc-internal-format
 msgid "ifunc is not supported in this configuration"
 msgstr "weakref ei ole tuettu tässä konfiguraatiossa"
 
-#: varasm.c:6127 config/sol2.c:159 config/i386/winnt.c:265
+#: varasm.c:6141 config/sol2.c:159 config/i386/winnt.c:265
 #, gcc-internal-format
 msgid "visibility attribute not supported in this configuration; ignored"
 msgstr ""
@@ -26036,476 +26058,482 @@
 msgid "bytecode stream: tag %s is not in the expected range [%s, %s]"
 msgstr ""
 
-#: c-family/c-attribs.c:529
+#: c-family/c-attribs.c:524
+#, fuzzy, gcc-internal-format
+#| msgid "%qE attribute ignored for %qE"
+msgid "%qE attribute ignored for type %qT"
+msgstr "%qE-attribuuttia ei huomioida %qE:lle"
+
+#: c-family/c-attribs.c:536
 #, gcc-internal-format
 msgid "%qE attribute ignored for field of type %qT"
 msgstr "%qE-attribuuttia ei huomioida %qT-tyyppiselle kentälle"
 
-#: c-family/c-attribs.c:696
+#: c-family/c-attribs.c:706
 #, fuzzy, gcc-internal-format
 #| msgid "visibility argument not a string"
 msgid "no_sanitize argument not a string"
 msgstr "näkyvyysargumentti ei ole merkkijono"
 
-#: c-family/c-attribs.c:826 ada/gcc-interface/utils.c:6235
+#: c-family/c-attribs.c:837 ada/gcc-interface/utils.c:6240
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "%qE attribute ignored due to conflict with attribute %qs"
 msgstr "%qE-attribuutti on ristiriidassa attribuutin %s kanssa"
 
-#: c-family/c-attribs.c:875
+#: c-family/c-attribs.c:886
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "%qE attribute ignored. Use -fcf-protection option to enable it"
 msgstr "%qE-attribuutti on ristiriidassa attribuutin %s kanssa"
 
-#: c-family/c-attribs.c:914 c-family/c-attribs.c:920 c-family/c-attribs.c:3388
-#: c-family/c-attribs.c:3423 c-family/c-attribs.c:3429
+#: c-family/c-attribs.c:925 c-family/c-attribs.c:931 c-family/c-attribs.c:3399
+#: c-family/c-attribs.c:3434 c-family/c-attribs.c:3440
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "%qE attribute ignored due to conflict with %qs attribute"
 msgstr "%qE-attribuutti on ristiriidassa attribuutin %s kanssa"
 
-#: c-family/c-attribs.c:976 brig/brig-lang.c:482 lto/lto-lang.c:288
+#: c-family/c-attribs.c:987 brig/brig-lang.c:482 lto/lto-lang.c:288
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute has no effect on unit local functions"
 msgstr "%J%qE-attribuutti soveltuu vain funktioihin"
 
-#: c-family/c-attribs.c:1130
+#: c-family/c-attribs.c:1141
 #, gcc-internal-format
 msgid "%qE attribute have effect only on public objects"
 msgstr "%qE-attribuutti vaikuttaa vain julkisiin objekteihin"
 
-#: c-family/c-attribs.c:1159
+#: c-family/c-attribs.c:1170
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to variables"
 msgid "%qE attribute only affects top level objects"
 msgstr "%qE-attribuutti pätee vain muuttujiin"
 
-#: c-family/c-attribs.c:1198 c-family/c-attribs.c:2682
+#: c-family/c-attribs.c:1209 c-family/c-attribs.c:2693
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute on function returning %<void%>"
 msgstr "%<return%> arvon kanssa voidin palauttavassa funktiossa"
 
-#: c-family/c-attribs.c:1221 c-family/c-pragma.c:419
+#: c-family/c-attribs.c:1232 c-family/c-pragma.c:419
 #, gcc-internal-format
 msgid "scalar_storage_order is not supported because endianness is not uniform"
 msgstr ""
 
-#: c-family/c-attribs.c:1238
+#: c-family/c-attribs.c:1249
 #, gcc-internal-format
 msgid "scalar_storage_order argument must be one of \"big-endian\" or \"little-endian\""
 msgstr ""
 
-#: c-family/c-attribs.c:1334
+#: c-family/c-attribs.c:1345
 #, fuzzy, gcc-internal-format
 msgid "destructor priorities are not supported"
 msgstr "Hajotin %qs"
 
-#: c-family/c-attribs.c:1336
+#: c-family/c-attribs.c:1347
 #, fuzzy, gcc-internal-format
 msgid "constructor priorities are not supported"
 msgstr "Muodostin %qs"
 
-#: c-family/c-attribs.c:1358
+#: c-family/c-attribs.c:1369
 #, gcc-internal-format, gfc-internal-format
 msgid "destructor priorities from 0 to %d are reserved for the implementation"
 msgstr ""
 
-#: c-family/c-attribs.c:1363
+#: c-family/c-attribs.c:1374
 #, gcc-internal-format, gfc-internal-format
 msgid "constructor priorities from 0 to %d are reserved for the implementation"
 msgstr ""
 
-#: c-family/c-attribs.c:1371
+#: c-family/c-attribs.c:1382
 #, gcc-internal-format, gfc-internal-format
 msgid "destructor priorities must be integers from 0 to %d inclusive"
 msgstr ""
 
-#: c-family/c-attribs.c:1374
+#: c-family/c-attribs.c:1385
 #, gcc-internal-format, gfc-internal-format
 msgid "constructor priorities must be integers from 0 to %d inclusive"
 msgstr ""
 
-#: c-family/c-attribs.c:1527
+#: c-family/c-attribs.c:1538
 #, fuzzy, gcc-internal-format
 msgid "unknown machine mode %qE"
 msgstr "%s on tarkoitettu tuntemattomalle koneelle %d.\n"
 
-#: c-family/c-attribs.c:1557
+#: c-family/c-attribs.c:1568
 #, fuzzy, gcc-internal-format
 msgid "specifying vector types with __attribute__ ((mode)) is deprecated"
 msgstr "vektorityyppien määrittäminen __attribute__ ((mode)) -tyyliin on paheksuttavaa"
 
-#: c-family/c-attribs.c:1560
+#: c-family/c-attribs.c:1571
 #, gcc-internal-format
 msgid "use __attribute__ ((vector_size)) instead"
 msgstr "käytä sen sijaan __attribute__ ((vector_size))"
 
-#: c-family/c-attribs.c:1569
+#: c-family/c-attribs.c:1580
 #, fuzzy, gcc-internal-format
 msgid "unable to emulate %qs"
 msgstr "superlohkon kirjoitus ei onnistu"
 
-#: c-family/c-attribs.c:1582
+#: c-family/c-attribs.c:1593
 #, gcc-internal-format
 msgid "invalid pointer mode %qs"
 msgstr "epäkelpo osoitintila %qs"
 
-#: c-family/c-attribs.c:1599
+#: c-family/c-attribs.c:1610
 #, gcc-internal-format
 msgid "signedness of type and machine mode %qs don%'t match"
 msgstr ""
 
-#: c-family/c-attribs.c:1610
+#: c-family/c-attribs.c:1621
 #, gcc-internal-format
 msgid "no data type for mode %qs"
 msgstr "ei tietotyyppiä tilalle %qs"
 
-#: c-family/c-attribs.c:1620
+#: c-family/c-attribs.c:1631
 #, gcc-internal-format
 msgid "cannot use mode %qs for enumeral types"
 msgstr "luetelluille tyypeille ei voi käyttää tilaa %qs"
 
-#: c-family/c-attribs.c:1647
+#: c-family/c-attribs.c:1658
 #, gcc-internal-format
 msgid "mode %qs applied to inappropriate type"
 msgstr "tilaa %qs sovellettu sopimattomaan tyyppiin"
 
-#: c-family/c-attribs.c:1669
+#: c-family/c-attribs.c:1680
 #, fuzzy, gcc-internal-format
 msgid "section attributes are not supported for this target"
 msgstr "%Jlohkoattribuutteja ei tueta tälle kohteelle"
 
-#: c-family/c-attribs.c:1675
+#: c-family/c-attribs.c:1686
 #, fuzzy, gcc-internal-format
 msgid "section attribute not allowed for %q+D"
 msgstr "pakattu attribuutti on tarpeeton %q+D:lle"
 
-#: c-family/c-attribs.c:1681
+#: c-family/c-attribs.c:1692
 #, fuzzy, gcc-internal-format
 msgid "section attribute argument not a string constant"
 msgstr "%qE-attribuutti tarvitsee merkkijonovakioargumentin"
 
-#: c-family/c-attribs.c:1690
+#: c-family/c-attribs.c:1701
 #, fuzzy, gcc-internal-format
 msgid "section attribute cannot be specified for local variables"
 msgstr "osoitealueattribuuttia ei voi määritellä paikallisille muuttujille"
 
-#: c-family/c-attribs.c:1700 config/bfin/bfin.c:4806 config/bfin/bfin.c:4857
+#: c-family/c-attribs.c:1711 config/bfin/bfin.c:4806 config/bfin/bfin.c:4857
 #: config/bfin/bfin.c:4883 config/bfin/bfin.c:4896
 #, fuzzy, gcc-internal-format
 msgid "section of %q+D conflicts with previous declaration"
 msgstr "on ristiriidassa %q+#D:n edellisen esittelyn kanssa"
 
-#: c-family/c-attribs.c:1708
+#: c-family/c-attribs.c:1719
 #, gcc-internal-format
 msgid "section of %q+D cannot be overridden"
 msgstr ""
 
-#: c-family/c-attribs.c:1773
+#: c-family/c-attribs.c:1784
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "requested alignment %d is larger than %d"
 msgstr "%s: kentän ”%s” arvot eivät saa olla suurempia kuin %d"
 
-#: c-family/c-attribs.c:1866
+#: c-family/c-attribs.c:1877
 #, gcc-internal-format
 msgid "alignment may not be specified for %q+D"
 msgstr "kohdistusta ei voi määritellä %q+D:lle"
 
-#: c-family/c-attribs.c:1886
+#: c-family/c-attribs.c:1897
 #, fuzzy, gcc-internal-format
 msgid "ignoring attribute %<%E (%u)%> because it conflicts with attribute %<%E (%u)%>"
 msgstr "Kaksoiskappale-%s-attribuutti määritelty kohdassa %L"
 
 #. Do not error out for attribute warn_if_not_aligned.
-#: c-family/c-attribs.c:1891 c-family/c-attribs.c:1920
+#: c-family/c-attribs.c:1902 c-family/c-attribs.c:1931
 #, gcc-internal-format
 msgid "alignment for %q+D must be at least %d"
 msgstr "kohdistuksen %q+D:lle pitää olla vähintään %d"
 
-#: c-family/c-attribs.c:1916
+#: c-family/c-attribs.c:1927
 #, gcc-internal-format
 msgid "alignment for %q+D was previously specified as %d and may not be decreased"
 msgstr ""
 
-#: c-family/c-attribs.c:1943
+#: c-family/c-attribs.c:1954
 #, fuzzy, gcc-internal-format
 #| msgid "alignment may not be specified for %q+D"
 msgid "%<warn_if_not_aligned%> may not be specified for %q+D"
 msgstr "kohdistusta ei voi määritellä %q+D:lle"
 
-#: c-family/c-attribs.c:1986
+#: c-family/c-attribs.c:1997
 #, fuzzy, gcc-internal-format
 msgid "inline function %q+D declared weak"
 msgstr "muuttuja %qD esitelty %<inline%>:ksi"
 
-#: c-family/c-attribs.c:1991
+#: c-family/c-attribs.c:2002
 #, fuzzy, gcc-internal-format
 msgid "indirect function %q+D cannot be declared weak"
 msgstr "sisäkkäinen funktio %qs esitelty %<extern%>:ksi"
 
-#: c-family/c-attribs.c:2015
+#: c-family/c-attribs.c:2026
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is only applicable on functions"
 msgstr "%qE-attribuutti pätee vain funktioihin"
 
-#: c-family/c-attribs.c:2046
+#: c-family/c-attribs.c:2057
 #, fuzzy, gcc-internal-format
 msgid "%q+D defined both normally and as %qE attribute"
 msgstr "%J%qD määritelty sekä tavallisesti että aliaksena"
 
-#: c-family/c-attribs.c:2054
+#: c-family/c-attribs.c:2065
 #, fuzzy, gcc-internal-format
 msgid "weak %q+D cannot be defined %qE"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: c-family/c-attribs.c:2071 c-family/c-attribs.c:2582
+#: c-family/c-attribs.c:2082 c-family/c-attribs.c:2593
 #, fuzzy, gcc-internal-format
 msgid "attribute %qE argument not a string"
 msgstr "%qE-attribuutti tarvitsee merkkijonovakioargumentin"
 
-#: c-family/c-attribs.c:2106
+#: c-family/c-attribs.c:2117
 #, fuzzy, gcc-internal-format
 msgid "%+qD declared alias after being used"
 msgstr "%J%qD esitelty avoimeksi kutsumisen jälkeen"
 
-#: c-family/c-attribs.c:2108
+#: c-family/c-attribs.c:2119
 #, fuzzy, gcc-internal-format
 msgid "%+qD declared ifunc after being used"
 msgstr "%J%qD esitelty avoimeksi kutsumisen jälkeen"
 
-#: c-family/c-attribs.c:2159
+#: c-family/c-attribs.c:2170
 #, fuzzy, gcc-internal-format
 msgid "indirect function %q+D cannot be declared weakref"
 msgstr "sisäkkäinen funktio %qs esitelty %<extern%>:ksi"
 
-#: c-family/c-attribs.c:2181
+#: c-family/c-attribs.c:2192
 #, gcc-internal-format
 msgid "weakref attribute must appear before alias attribute"
 msgstr "weakref-attribuutin täytyy esiintyä ennen alias-attribuuttia"
 
-#: c-family/c-attribs.c:2193
+#: c-family/c-attribs.c:2204
 #, fuzzy, gcc-internal-format
 msgid "%+qD declared weakref after being used"
 msgstr "%J%qD esitelty avoimeksi kutsumisen jälkeen"
 
-#: c-family/c-attribs.c:2217
+#: c-family/c-attribs.c:2228
 #, gcc-internal-format
 msgid "%qE attribute ignored on non-class types"
 msgstr "%qE-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: c-family/c-attribs.c:2223
+#: c-family/c-attribs.c:2234
 #, gcc-internal-format
 msgid "%qE attribute ignored because %qT is already defined"
 msgstr "%qE-attribuuttia ei huomioida koska %qT on jo määritelty"
 
-#: c-family/c-attribs.c:2236
+#: c-family/c-attribs.c:2247
 #, gcc-internal-format
 msgid "visibility argument not a string"
 msgstr "näkyvyysargumentti ei ole merkkijono"
 
-#: c-family/c-attribs.c:2248
+#: c-family/c-attribs.c:2259
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute ignored on types"
 msgstr "%qE-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: c-family/c-attribs.c:2264
+#: c-family/c-attribs.c:2275
 #, gcc-internal-format
 msgid "visibility argument must be one of \"default\", \"hidden\", \"protected\" or \"internal\""
 msgstr "näkyvyysargumentin tulee olla ”default”, ”hidden”, ”protected” tai ”internal”"
 
-#: c-family/c-attribs.c:2275
+#: c-family/c-attribs.c:2286
 #, gcc-internal-format
 msgid "%qD redeclared with different visibility"
 msgstr "%qD esitelty uudelleen eri näkyvyydellä"
 
-#: c-family/c-attribs.c:2278 c-family/c-attribs.c:2282
+#: c-family/c-attribs.c:2289 c-family/c-attribs.c:2293
 #, gcc-internal-format
 msgid "%qD was declared %qs which implies default visibility"
 msgstr "%qD esiteltiin tyyppinä %qs, mikä edellyttää oletusnäkyvyyttä"
 
-#: c-family/c-attribs.c:2320
+#: c-family/c-attribs.c:2331
 #, gcc-internal-format
 msgid "tls_model argument not a string"
 msgstr "tls_model-argumentti ei ole merkkijono"
 
-#: c-family/c-attribs.c:2333
+#: c-family/c-attribs.c:2344
 #, gcc-internal-format
 msgid "tls_model argument must be one of \"local-exec\", \"initial-exec\", \"local-dynamic\" or \"global-dynamic\""
 msgstr "tls_model-argumentin pitää olla ”local-exec”, ”initial-exec”, ”local-dynamic” tai ”global-dynamic”"
 
-#: c-family/c-attribs.c:2353 c-family/c-attribs.c:2656
-#: c-family/c-attribs.c:3497 config/m32c/m32c.c:2944
+#: c-family/c-attribs.c:2364 c-family/c-attribs.c:2667
+#: c-family/c-attribs.c:3508 config/m32c/m32c.c:2944
 #, gcc-internal-format
 msgid "%qE attribute applies only to functions"
 msgstr "%qE-attribuutti pätee vain funktioihin"
 
-#: c-family/c-attribs.c:2417
+#: c-family/c-attribs.c:2428
 #, gcc-internal-format
 msgid "alloc_size parameter outside range"
 msgstr "alloc_size-parametri ei ole sallitulla välillä"
 
-#: c-family/c-attribs.c:2443
+#: c-family/c-attribs.c:2454
 #, fuzzy, gcc-internal-format
 #| msgid "alloc_size parameter outside range"
 msgid "alloc_align parameter outside range"
 msgstr "alloc_size-parametri ei ole sallitulla välillä"
 
-#: c-family/c-attribs.c:2467
+#: c-family/c-attribs.c:2478
 #, fuzzy, gcc-internal-format
 msgid "assume_aligned parameter not integer constant"
 msgstr "pyydetty kohdistus ei ole vakio"
 
-#: c-family/c-attribs.c:2595
+#: c-family/c-attribs.c:2606
 #, gcc-internal-format
 msgid "only %<inbranch%> and %<notinbranch%> flags are allowed for %<__simd__%> attribute"
 msgstr ""
 
-#: c-family/c-attribs.c:2662 c-family/c-attribs.c:3503
+#: c-family/c-attribs.c:2673 c-family/c-attribs.c:3514
 #, gcc-internal-format
 msgid "can%'t set %qE attribute after definition"
 msgstr "ei voi asettaa %qE-attribuuttia määrittelyn jälkeen"
 
-#: c-family/c-attribs.c:2727
+#: c-family/c-attribs.c:2738
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute duplicated"
 msgstr "%qE-attribuuttia ei huomioida %qE:lle"
 
-#: c-family/c-attribs.c:2729
+#: c-family/c-attribs.c:2740
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute follows %qE"
 msgstr "%qE-attribuuttia ei huomioida %qE:lle"
 
-#: c-family/c-attribs.c:2828
+#: c-family/c-attribs.c:2839
 #, fuzzy, gcc-internal-format
 msgid "type was previously declared %qE"
 msgstr "%q+#D aiemmin esitelty täällä"
 
-#: c-family/c-attribs.c:2841 cp/class.c:4397
+#: c-family/c-attribs.c:2852 cp/class.c:4401
 #, fuzzy, gcc-internal-format
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
 msgstr "tallennusluokan voi antaa vain objekteille ja funktioille"
 
-#: c-family/c-attribs.c:2899
+#: c-family/c-attribs.c:2910
 #, fuzzy, gcc-internal-format
 msgid "%qE argument not an identifier"
 msgstr "tunniste %qE on ristiriidassa C++:n varatun sanan kanssa"
 
-#: c-family/c-attribs.c:2910
+#: c-family/c-attribs.c:2921
 #, fuzzy, gcc-internal-format
 msgid "%qD is not compatible with %qD"
 msgstr "%qD ei ole %qD:n jäsen"
 
-#: c-family/c-attribs.c:2913
+#: c-family/c-attribs.c:2924
 #, fuzzy, gcc-internal-format
 #| msgid "cleanup argument not a function"
 msgid "%qE argument is not a function"
 msgstr "%qE esitelty funktion palauttavana funktiona"
 
-#: c-family/c-attribs.c:2961
+#: c-family/c-attribs.c:2972
 #, fuzzy, gcc-internal-format
 msgid "deprecated message is not a string"
 msgstr "odotettiin merkkijonoa ilmaisun %<#pragma message%> jälkeen"
 
-#: c-family/c-attribs.c:3002
+#: c-family/c-attribs.c:3013
 #, gcc-internal-format
 msgid "%qE attribute ignored for %qE"
 msgstr "%qE-attribuuttia ei huomioida %qE:lle"
 
-#: c-family/c-attribs.c:3065
+#: c-family/c-attribs.c:3076
 #, gcc-internal-format
 msgid "invalid vector type for attribute %qE"
 msgstr "epäkelpo vektorityyppi attribuutille %qE"
 
-#: c-family/c-attribs.c:3071 ada/gcc-interface/utils.c:3896
+#: c-family/c-attribs.c:3082 ada/gcc-interface/utils.c:3899
 #, gcc-internal-format
 msgid "vector size not an integral multiple of component size"
 msgstr ""
 
-#: c-family/c-attribs.c:3077 ada/gcc-interface/utils.c:3903
+#: c-family/c-attribs.c:3088 ada/gcc-interface/utils.c:3906
 #, fuzzy, gcc-internal-format
 msgid "zero vector size"
 msgstr "nollan kokoinen taulukko %qD"
 
-#: c-family/c-attribs.c:3085
+#: c-family/c-attribs.c:3096
 #, gcc-internal-format
 msgid "number of components of the vector not a power of two"
 msgstr "vektorin komponenttien määrä ei ole kahden potenssi"
 
-#: c-family/c-attribs.c:3118 ada/gcc-interface/utils.c:6092
+#: c-family/c-attribs.c:3129 ada/gcc-interface/utils.c:6098
 #, gcc-internal-format
 msgid "nonnull attribute without arguments on a non-prototype"
 msgstr "ei-tyhjä attribuutti ilman argumentteja ei-prototyypissä"
 
-#: c-family/c-attribs.c:3137 ada/gcc-interface/utils.c:6106
+#: c-family/c-attribs.c:3148 ada/gcc-interface/utils.c:6112
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument has invalid operand number (argument %lu)"
 msgstr "ei-tyhjällä argumentilla on epäkelpo operandinumero (argumentti %lu)"
 
-#: c-family/c-attribs.c:3159 ada/gcc-interface/utils.c:6128
+#: c-family/c-attribs.c:3170 ada/gcc-interface/utils.c:6134
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument with out-of-range operand number (argument %lu, operand %lu)"
 msgstr "ei-tyhjällä argumentilla arvoalueen ylittävä operandinumero (argumentti %lu,operandi %lu)"
 
 # XXX
-#: c-family/c-attribs.c:3168 ada/gcc-interface/utils.c:6137
+#: c-family/c-attribs.c:3179 ada/gcc-interface/utils.c:6143
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument references non-pointer operand (argument %lu, operand %lu)"
 msgstr "ei-tyhjä argumentti viittaa ei-osoitinoperandiin (argumentti %lu, operandi %lu)"
 
-#: c-family/c-attribs.c:3208
+#: c-family/c-attribs.c:3219
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored for field of type %qT"
 msgid "%qE attribute ignored on objects of type %qT"
 msgstr "%qE-attribuuttia ei huomioida %qT-tyyppiselle kentälle"
 
-#: c-family/c-attribs.c:3216
+#: c-family/c-attribs.c:3227
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute does not apply to functions"
 msgstr "%qE-attribuutti pätee vain funktioihin"
 
-#: c-family/c-attribs.c:3273
+#: c-family/c-attribs.c:3284
 #, gcc-internal-format
 msgid "cleanup argument not an identifier"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: c-family/c-attribs.c:3280
+#: c-family/c-attribs.c:3291
 #, gcc-internal-format
 msgid "cleanup argument not a function"
 msgstr "puhdistusargumentti ei ole funktio"
 
-#: c-family/c-attribs.c:3317
+#: c-family/c-attribs.c:3328
 #, gcc-internal-format
 msgid "%qE attribute requires prototypes with named arguments"
 msgstr "%qE-attribuutti tarvitsee prototyyppejä, joilla nimettyjä argumentteja"
 
-#: c-family/c-attribs.c:3325
+#: c-family/c-attribs.c:3336
 #, gcc-internal-format
 msgid "%qE attribute only applies to variadic functions"
 msgstr "%qE-attribuutti soveltuu vain variadisiin funktioihin"
 
-#: c-family/c-attribs.c:3341 ada/gcc-interface/utils.c:6179
+#: c-family/c-attribs.c:3352 ada/gcc-interface/utils.c:6185
 #, gcc-internal-format
 msgid "requested position is not an integer constant"
 msgstr "haluttu sijainti ei ole kokonaislukuvakio"
 
-#: c-family/c-attribs.c:3349 ada/gcc-interface/utils.c:6186
+#: c-family/c-attribs.c:3360 ada/gcc-interface/utils.c:6192
 #, gcc-internal-format
 msgid "requested position is less than zero"
 msgstr "haluttu sijainti on pienempi kuin nolla"
 
-#: c-family/c-attribs.c:3404
+#: c-family/c-attribs.c:3415
 #, fuzzy, gcc-internal-format
 msgid "empty string in attribute %<target%>"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: c-family/c-attribs.c:3520
+#: c-family/c-attribs.c:3531
 #, fuzzy, gcc-internal-format
 msgid "returns_nonnull attribute on a function not returning a pointer"
 msgstr "%<return%> arvon kanssa voidin palauttavassa funktiossa"
 
-#: c-family/c-attribs.c:3535
+#: c-family/c-attribs.c:3546
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to function types"
 msgid "%qE attribute is only valid on %<struct%> type"
@@ -26552,13 +26580,13 @@
 msgstr ""
 
 # Tämä esiintynee esim. const char* → char* -muunnoksessa.
-#: c-family/c-common.c:1262 c-family/c-warn.c:1194
+#: c-family/c-common.c:1262 c-family/c-warn.c:1202
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT discards qualifiers"
 msgid "unsigned conversion from %qT to %qT changes value from %qE to %qE"
 msgstr "muunnos tyypistä %qT tyyppiin %qT ei säilytä tyyppimääreitä"
 
-#: c-family/c-common.c:1267 c-family/c-warn.c:1202
+#: c-family/c-common.c:1267 c-family/c-warn.c:1210
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "unsigned conversion from %qT to %qT changes the value of %qE"
@@ -26694,7 +26722,7 @@
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "ehdotetaan sulkeita totuusarvona käytetyn sijoituksen ympärille"
 
-#: c-family/c-common.c:3518 c/c-decl.c:4325 c/c-decl.c:6430 c/c-typeck.c:14177
+#: c-family/c-common.c:3518 c/c-decl.c:4325 c/c-decl.c:6450 c/c-typeck.c:14182
 #, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr "epäkelpo %<restrict%>-avainsanan käyttö"
@@ -26774,7 +26802,7 @@
 msgid "duplicate case value"
 msgstr "case-arvon kaksoiskappale"
 
-#: c-family/c-common.c:4867 c-family/c-warn.c:2216
+#: c-family/c-common.c:4867 c-family/c-warn.c:2225
 #, gcc-internal-format
 msgid "previously used here"
 msgstr "viimeksi käytetty täällä"
@@ -26820,196 +26848,196 @@
 msgid "missing sentinel in function call"
 msgstr "lopetusalkio puuttuu funktiokutsusta"
 
-#: c-family/c-common.c:5411
+#: c-family/c-common.c:5409
 #, gcc-internal-format, gfc-internal-format
 msgid "null argument where non-null required (argument %lu)"
 msgstr "tyhjä argumentti, vaikka ei-null vaaditaan (argumentti %lu)"
 
-#: c-family/c-common.c:5506 c-family/c-common.c:5553
+#: c-family/c-common.c:5504 c-family/c-common.c:5551
 #, fuzzy, gcc-internal-format
 msgid "bad option %qs to attribute %<optimize%>"
 msgstr "%s ei ole liitospiste tai virheellinen valitsin"
 
-#: c-family/c-common.c:5509 c-family/c-common.c:5557
+#: c-family/c-common.c:5507 c-family/c-common.c:5555
 #, fuzzy, gcc-internal-format
 msgid "bad option %qs to pragma %<optimize%>"
 msgstr "%s ei ole liitospiste tai virheellinen valitsin"
 
-#: c-family/c-common.c:5589
+#: c-family/c-common.c:5587
 #, gcc-internal-format
 msgid "%<fallthrough%> attribute specified multiple times"
 msgstr ""
 
-#: c-family/c-common.c:5593
+#: c-family/c-common.c:5591
 #, fuzzy, gcc-internal-format
 #| msgid "default argument specified for lambda parameter"
 msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr "oletusargumentti määritelty lambda-parametrille"
 
-#: c-family/c-common.c:5733 c-family/c-common.c:6485 c-family/c-common.c:6558
+#: c-family/c-common.c:5731 c-family/c-common.c:6477 c-family/c-common.c:6550
 #: c/c-typeck.c:3555
 #, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr "liian vähän argumentteja funktiolle %qE"
 
-#: c-family/c-common.c:5738 c-family/c-common.c:6584 c/c-typeck.c:3284
+#: c-family/c-common.c:5736 c-family/c-common.c:6576 c/c-typeck.c:3284
 #, gcc-internal-format
 msgid "too many arguments to function %qE"
 msgstr "liian monta argumenttia funktiolle %qE"
 
-#: c-family/c-common.c:5769
+#: c-family/c-common.c:5767
 #, fuzzy, gcc-internal-format
 #| msgid "third argument to %<__builtin_prefetch%> must be a constant"
 msgid "third argument to function %qE must be a constant integer"
 msgstr "%<__builtin_prefetch%>-funktion kolmannen argumentin pitää olla vakio"
 
-#: c-family/c-common.c:5794
+#: c-family/c-common.c:5792
 #, gcc-internal-format
 msgid "second argument to function %qE must be a constant integer power of 2 between %qi and %qu bits"
 msgstr ""
 
-#: c-family/c-common.c:5815 c-family/c-common.c:5859
+#: c-family/c-common.c:5813 c-family/c-common.c:5857
 #, gcc-internal-format
 msgid "non-floating-point argument in call to function %qE"
 msgstr "ei-liukulukuargumentti kutsussa funktiolle %qE"
 
-#: c-family/c-common.c:5838
+#: c-family/c-common.c:5836
 #, gcc-internal-format
 msgid "non-floating-point arguments in call to function %qE"
 msgstr "ei-liukulukuargumentteja kutsussa funktiolle %qE"
 
-#: c-family/c-common.c:5852
+#: c-family/c-common.c:5850
 #, gcc-internal-format
 msgid "non-const integer argument %u in call to function %qE"
 msgstr "ei-vakio kokonaiskulukuargumentti %u kutsussa funktiolle %qE"
 
-#: c-family/c-common.c:5872
+#: c-family/c-common.c:5870
 #, fuzzy, gcc-internal-format
 msgid "non-integer argument 3 in call to function %qE"
 msgstr "ei-vakio kokonaiskulukuargumentti %u kutsussa funktiolle %qE"
 
-#: c-family/c-common.c:5889 c-family/c-common.c:5925
+#: c-family/c-common.c:5887 c-family/c-common.c:5923
 #, fuzzy, gcc-internal-format
 msgid "argument %u in call to function %qE does not have integral type"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: c-family/c-common.c:5896
+#: c-family/c-common.c:5894
 #, fuzzy, gcc-internal-format
 msgid "argument 3 in call to function %qE does not have pointer to integral type"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: c-family/c-common.c:5902
+#: c-family/c-common.c:5900
 #, fuzzy, gcc-internal-format
 msgid "argument 3 in call to function %qE has pointer to enumerated type"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: c-family/c-common.c:5908
+#: c-family/c-common.c:5906
 #, fuzzy, gcc-internal-format
 msgid "argument 3 in call to function %qE has pointer to boolean type"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: c-family/c-common.c:5931
+#: c-family/c-common.c:5929
 #, fuzzy, gcc-internal-format
 msgid "argument 3 in call to function %qE has enumerated type"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: c-family/c-common.c:5937
+#: c-family/c-common.c:5935
 #, fuzzy, gcc-internal-format
 msgid "argument 3 in call to function %qE has boolean type"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: c-family/c-common.c:6184
+#: c-family/c-common.c:6183
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to static data member %qD"
 msgstr ""
 
-#: c-family/c-common.c:6189
+#: c-family/c-common.c:6188
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> when %<operator[]%> is overloaded"
 msgstr ""
 
-#: c-family/c-common.c:6196
+#: c-family/c-common.c:6195
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to a non constant address"
 msgstr ""
 
-#: c-family/c-common.c:6209
+#: c-family/c-common.c:6208
 #, gcc-internal-format
 msgid "attempt to take address of bit-field structure member %qD"
 msgstr ""
 
-#: c-family/c-common.c:6261
+#: c-family/c-common.c:6260
 #, gcc-internal-format
 msgid "index %E denotes an offset greater than size of %qT"
 msgstr ""
 
-#: c-family/c-common.c:6427 cp/init.c:3004 cp/init.c:3023
+#: c-family/c-common.c:6419 cp/init.c:3020 cp/init.c:3039
 #, gcc-internal-format
 msgid "size of array is too large"
 msgstr "taulukon koko on liian suuri"
 
-#: c-family/c-common.c:6517
+#: c-family/c-common.c:6509
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible type for argument %d of %qE"
 msgid "operand type %qT is incompatible with argument %d of %qE"
 msgstr "funktiolle %2$qE annettu argumentin %1$d tyyppi on yhteensopimaton"
 
-#: c-family/c-common.c:6651
+#: c-family/c-common.c:6643
 #, fuzzy, gcc-internal-format
 msgid "incorrect number of arguments to function %qE"
 msgstr "liian monta argumenttia funktiolle %qE"
 
-#: c-family/c-common.c:6665
+#: c-family/c-common.c:6657
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qE must be a non-void pointer type"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: c-family/c-common.c:6674
+#: c-family/c-common.c:6666
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a constant size type"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: c-family/c-common.c:6685
+#: c-family/c-common.c:6677
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a nonzero size object"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: c-family/c-common.c:6706
+#: c-family/c-common.c:6698
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must be a pointer type"
 msgstr "annettu yhteensopimatonta osoitintyyppiä oleva %d. argumentti funktiolle %qE"
 
-#: c-family/c-common.c:6714
+#: c-family/c-common.c:6706
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must be a pointer to a constant size type"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: c-family/c-common.c:6720
+#: c-family/c-common.c:6712
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a function"
 msgstr "annettu yhteensopimatonta osoitintyyppiä oleva %d. argumentti funktiolle %qE"
 
-#: c-family/c-common.c:6728
+#: c-family/c-common.c:6720
 #, fuzzy, gcc-internal-format
 msgid "size mismatch in argument %d of %qE"
 msgstr "funktiolle %2$qE annettu argumentin %1$d tyyppi on yhteensopimaton"
 
-#: c-family/c-common.c:6740
+#: c-family/c-common.c:6732
 #, fuzzy, gcc-internal-format
 msgid "non-integer memory model argument %d of %qE"
 msgstr "funktiolle %2$qE annettu argumentin %1$d tyyppi on yhteensopimaton"
 
-#: c-family/c-common.c:6753
+#: c-family/c-common.c:6745
 #, fuzzy, gcc-internal-format
 msgid "invalid memory model argument %d of %qE"
 msgstr "funktiolle %2$qE annettu argumentin %1$d tyyppi on yhteensopimaton"
 
-#: c-family/c-common.c:7672
+#: c-family/c-common.c:7664
 #, fuzzy, gcc-internal-format
 msgid "index value is out of bound"
 msgstr "Arvo sallitun välin ulkopuolella."
 
-#: c-family/c-common.c:7714 c-family/c-common.c:7763 c-family/c-common.c:7779
+#: c-family/c-common.c:7706 c-family/c-common.c:7755 c-family/c-common.c:7771
 #, fuzzy, gcc-internal-format
 msgid "conversion of scalar %qT to vector %qT involves truncation"
 msgstr "muunnos tyypistä %qT tyyppiin %qT on moniselitteinen"
@@ -27016,22 +27044,22 @@
 
 #. Reject arguments that are built-in functions with
 #. no library fallback.
-#: c-family/c-common.c:7867
+#: c-family/c-common.c:7859
 #, fuzzy, gcc-internal-format
 msgid "built-in function %qE must be directly called"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
 
-#: c-family/c-common.c:7889 c/c-decl.c:6177
+#: c-family/c-common.c:7881 c/c-decl.c:6197
 #, gcc-internal-format
 msgid "size of array %qE is too large"
 msgstr "taulukon %qE koko on liian suuri"
 
-#: c-family/c-common.c:7891 c/c-decl.c:6180
+#: c-family/c-common.c:7883 c/c-decl.c:6200
 #, gcc-internal-format
 msgid "size of unnamed array is too large"
 msgstr "nimettömän taulukon koko on liian suuri"
 
-#: c-family/c-common.c:7921
+#: c-family/c-common.c:7913
 #, gcc-internal-format
 msgid "environment variable SOURCE_DATE_EPOCH must expand to a non-negative integer less than or equal to %wd"
 msgstr ""
@@ -27563,7 +27591,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr ""
 
-#: c-family/c-omp.c:557 cp/semantics.c:8186
+#: c-family/c-omp.c:557 cp/semantics.c:8189
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "virheellinen tyyppi iterointimuuttujalle %qE"
@@ -27579,22 +27607,22 @@
 msgid "%qE is not initialized"
 msgstr "%qE:a ei ole alustettu"
 
-#: c-family/c-omp.c:599 cp/semantics.c:8076
+#: c-family/c-omp.c:599 cp/semantics.c:8079
 #, fuzzy, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "’(’ puuttuu predikaatin jäljestä"
 
-#: c-family/c-omp.c:704 cp/semantics.c:7732
+#: c-family/c-omp.c:704 cp/semantics.c:7735
 #, fuzzy, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "Muotoillun tulosteen hallinta:"
 
-#: c-family/c-omp.c:711 cp/semantics.c:8082
+#: c-family/c-omp.c:711 cp/semantics.c:8085
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "puuttuva kasvatuslauseke"
 
-#: c-family/c-omp.c:775 cp/semantics.c:7847
+#: c-family/c-omp.c:775 cp/semantics.c:7850
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "virheellinen kasvatuslauseke"
@@ -27652,113 +27680,128 @@
 msgid "%<-Wabi=1%> is not supported, using =2"
 msgstr "valitsin %qs ei ole enää tuettu"
 
-#: c-family/c-opts.c:612 fortran/cpp.c:350
+#: c-family/c-opts.c:610 fortran/cpp.c:350
 #, gcc-internal-format
 msgid "output filename specified twice"
 msgstr "tulostiedosto annettu kahdesti"
 
-#: c-family/c-opts.c:799
+#: c-family/c-opts.c:797
 #, gcc-internal-format
 msgid "-fexcess-precision=standard for C++"
 msgstr "-fexcess-precision=standard C++-kielelle"
 
-#: c-family/c-opts.c:834
+#: c-family/c-opts.c:832
 #, gcc-internal-format
 msgid "-fno-gnu89-inline is only supported in GNU99 or C99 mode"
 msgstr ""
 
-#: c-family/c-opts.c:880
+#: c-family/c-opts.c:878
 #, gcc-internal-format
 msgid "-Wformat-y2k ignored without -Wformat"
 msgstr "-Wformat-y2k jätetty huomiotta ilman valitsinta -Wformat"
 
-#: c-family/c-opts.c:882
+#: c-family/c-opts.c:880
 #, gcc-internal-format
 msgid "-Wformat-extra-args ignored without -Wformat"
 msgstr "-Wformat-extra-args jätetty huomiotta ilman valitsinta -Wformat"
 
-#: c-family/c-opts.c:884
+#: c-family/c-opts.c:882
 #, gcc-internal-format
 msgid "-Wformat-zero-length ignored without -Wformat"
 msgstr "-Wformat-zero-length jätetty huomiotta ilman valitsinta -Wformat"
 
-#: c-family/c-opts.c:886
+#: c-family/c-opts.c:884
 #, gcc-internal-format
 msgid "-Wformat-nonliteral ignored without -Wformat"
 msgstr "-Wformat-nonliteral jätetty huomiotta ilman valitsinta -Wformat"
 
-#: c-family/c-opts.c:888
+#: c-family/c-opts.c:886
 #, gcc-internal-format
 msgid "-Wformat-contains-nul ignored without -Wformat"
 msgstr "-Wformat-contains-nul jätetty huomiotta ilman valitsinta -Wformat"
 
-#: c-family/c-opts.c:890
+#: c-family/c-opts.c:888
 #, gcc-internal-format
 msgid "-Wformat-security ignored without -Wformat"
 msgstr "-Wformat-security jätetty huomiotta ilman valitsinta -Wformat"
 
-#: c-family/c-opts.c:928
+#: c-family/c-opts.c:918
 #, fuzzy, gcc-internal-format
 #| msgid "dwarf version %d is not supported"
 msgid "%<-fabi-compat-version=1%> is not supported, using =2"
 msgstr "dwarfin versio %d ei ole tuettu"
 
-#: c-family/c-opts.c:988
+#: c-family/c-opts.c:944
+#, gcc-internal-format
+msgid "-Wabi won't warn about anything"
+msgstr ""
+
+#: c-family/c-opts.c:946
+#, gcc-internal-format
+msgid "-Wabi warns about differences from the most up-to-date ABI, which is also used by default"
+msgstr ""
+
+#: c-family/c-opts.c:949
+#, gcc-internal-format
+msgid "use e.g. -Wabi=11 to warn about changes from GCC 7"
+msgstr ""
+
+#: c-family/c-opts.c:1003
 #, fuzzy, gcc-internal-format
 msgid "external TLS initialization functions not supported on this target"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: c-family/c-opts.c:1001
+#: c-family/c-opts.c:1016
 #, gcc-internal-format, gfc-internal-format
 msgid "too many filenames given.  Type %s --help for usage"
 msgstr "liian monta tiedostonimeä annettu.  Kirjoita %s --help nähdäksesi käyttöohjeen"
 
-#: c-family/c-opts.c:1016
+#: c-family/c-opts.c:1031
 #, gcc-internal-format
 msgid "opening output file %s: %m"
 msgstr "avataan tulostetiedosto %s: %m"
 
-#: c-family/c-opts.c:1036
+#: c-family/c-opts.c:1051
 #, gcc-internal-format, gfc-internal-format
 msgid "the \"%s\" debug format cannot be used with pre-compiled headers"
 msgstr ""
 
-#: c-family/c-opts.c:1190
+#: c-family/c-opts.c:1205
 #, gcc-internal-format
 msgid "opening dependency file %s: %m"
 msgstr "avataan riippuvuustiedosto %s: %m"
 
-#: c-family/c-opts.c:1201
+#: c-family/c-opts.c:1216
 #, gcc-internal-format
 msgid "closing dependency file %s: %m"
 msgstr "suljetaan riippuvuustiedosto %s: %m"
 
-#: c-family/c-opts.c:1204
+#: c-family/c-opts.c:1219
 #, gcc-internal-format
 msgid "when writing output to %s: %m"
 msgstr "kirjoitettaessa tulostetta tiedostoon %s: %m"
 
-#: c-family/c-opts.c:1284
+#: c-family/c-opts.c:1299
 #, gcc-internal-format
 msgid "to generate dependencies you must specify either -M or -MM"
 msgstr "muodostaaksesi riippuvuudet sinun täytyy antaa joko -M tai -MM"
 
-#: c-family/c-opts.c:1307
+#: c-family/c-opts.c:1322
 #, gcc-internal-format
 msgid "-MG may only be used with -M or -MM"
 msgstr ""
 
-#: c-family/c-opts.c:1340
+#: c-family/c-opts.c:1355
 #, gcc-internal-format
 msgid "-fdirectives-only is incompatible with -Wunused_macros"
 msgstr ""
 
-#: c-family/c-opts.c:1342
+#: c-family/c-opts.c:1357
 #, fuzzy, gcc-internal-format
 msgid "-fdirectives-only is incompatible with -traditional"
 msgstr "__COUNTER__ lavennettu direktiivin sisällä valitsimella -fdirectives-only"
 
-#: c-family/c-opts.c:1534
+#: c-family/c-opts.c:1549
 #, gcc-internal-format
 msgid "too late for # directive to set debug directory"
 msgstr "#-opastimen on liian myöhäistä asettaa vianjäljityshakemistoa"
@@ -28144,287 +28187,287 @@
 msgid "wrong type argument to %s"
 msgstr "abs-funktiolle annettu väärä tyyppiargumentti"
 
-#: c-family/c-warn.c:53 c-family/c-warn.c:66 cp/constexpr.c:1847
+#: c-family/c-warn.c:54 c-family/c-warn.c:67 cp/constexpr.c:1847
 #: cp/constexpr.c:4099
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: c-family/c-warn.c:93
+#: c-family/c-warn.c:94
 #, fuzzy, gcc-internal-format
 #| msgid "integer overflow in expression"
 msgid "integer overflow in expression %qE of type %qT results in %qE"
 msgstr "kokonaislukuylivuoto lausekkeessa"
 
-#: c-family/c-warn.c:95
+#: c-family/c-warn.c:96
 #, fuzzy, gcc-internal-format
 #| msgid "integer overflow in expression"
 msgid "integer overflow in expression of type %qT results in %qE"
 msgstr "kokonaislukuylivuoto lausekkeessa"
 
-#: c-family/c-warn.c:101
+#: c-family/c-warn.c:102
 #, fuzzy, gcc-internal-format
 #| msgid "floating point overflow in expression"
 msgid "floating point overflow in expression %qE of type %qT results in %qE"
 msgstr "liukulukuylivuoto lausekkeessa"
 
-#: c-family/c-warn.c:103
+#: c-family/c-warn.c:104
 #, fuzzy, gcc-internal-format
 #| msgid "floating point overflow in expression"
 msgid "floating point overflow in expression of type %qT results in %qE"
 msgstr "liukulukuylivuoto lausekkeessa"
 
-#: c-family/c-warn.c:109
+#: c-family/c-warn.c:110
 #, fuzzy, gcc-internal-format
 msgid "fixed-point overflow in expression %qE of type %qT results in %qE"
 msgstr "liukulukuylivuoto lausekkeessa"
 
-#: c-family/c-warn.c:111
+#: c-family/c-warn.c:112
 #, fuzzy, gcc-internal-format
 msgid "fixed-point overflow in expression of type %qT results in %qE"
 msgstr "liukulukuylivuoto lausekkeessa"
 
-#: c-family/c-warn.c:117
+#: c-family/c-warn.c:118
 #, fuzzy, gcc-internal-format
 #| msgid "vector overflow in expression"
 msgid "vector overflow in expression %qE of type %qT results in %qE"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: c-family/c-warn.c:119
+#: c-family/c-warn.c:120
 #, fuzzy, gcc-internal-format
 #| msgid "vector overflow in expression"
 msgid "vector overflow in expression of type %qT results in %qE"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: c-family/c-warn.c:126
+#: c-family/c-warn.c:127
 #, fuzzy, gcc-internal-format
 #| msgid "complex integer overflow in expression"
 msgid "complex integer overflow in expression %qE of type %qT results in %qE"
 msgstr "kompleksikokonaislukuylivuoto lausekkeessa"
 
-#: c-family/c-warn.c:128
+#: c-family/c-warn.c:129
 #, fuzzy, gcc-internal-format
 #| msgid "complex integer overflow in expression"
 msgid "complex integer overflow in expression of type %qT results in %qE"
 msgstr "kompleksikokonaislukuylivuoto lausekkeessa"
 
-#: c-family/c-warn.c:132
+#: c-family/c-warn.c:133
 #, fuzzy, gcc-internal-format
 #| msgid "complex floating point overflow in expression"
 msgid "complex floating point overflow in expression %qE of type %qT results in %qE"
 msgstr "kompleksiliukulukuylivuoto lausekkeessa"
 
-#: c-family/c-warn.c:134
+#: c-family/c-warn.c:135
 #, fuzzy, gcc-internal-format
 #| msgid "complex floating point overflow in expression"
 msgid "complex floating point overflow in expression of type %qT results in %qE"
 msgstr "kompleksiliukulukuylivuoto lausekkeessa"
 
-#: c-family/c-warn.c:216
+#: c-family/c-warn.c:217
 #, gcc-internal-format
 msgid "logical %<or%> applied to non-boolean constant"
 msgstr ""
 
-#: c-family/c-warn.c:219
+#: c-family/c-warn.c:220
 #, gcc-internal-format
 msgid "logical %<and%> applied to non-boolean constant"
 msgstr ""
 
-#: c-family/c-warn.c:289
+#: c-family/c-warn.c:290
 #, gcc-internal-format
 msgid "logical %<or%> of collectively exhaustive tests is always true"
 msgstr ""
 
-#: c-family/c-warn.c:293
+#: c-family/c-warn.c:294
 #, gcc-internal-format
 msgid "logical %<and%> of mutually exclusive tests is always false"
 msgstr ""
 
-#: c-family/c-warn.c:303
+#: c-family/c-warn.c:304
 #, fuzzy, gcc-internal-format
 msgid "logical %<or%> of equal expressions"
 msgstr "looginen"
 
-#: c-family/c-warn.c:306
+#: c-family/c-warn.c:307
 #, fuzzy, gcc-internal-format
 msgid "logical %<and%> of equal expressions"
 msgstr "looginen"
 
-#: c-family/c-warn.c:384
+#: c-family/c-warn.c:385
 #, fuzzy, gcc-internal-format
 msgid "bitwise comparison always evaluates to false"
 msgstr "vertailu ”etumerkitön lauseke < 0” on aina epätosi"
 
-#: c-family/c-warn.c:387
+#: c-family/c-warn.c:388
 #, fuzzy, gcc-internal-format
 msgid "bitwise comparison always evaluates to true"
 msgstr "vertailu ”etumerkitön lauseke >= 0” on aina tosi"
 
-#: c-family/c-warn.c:441
+#: c-family/c-warn.c:442
 #, fuzzy, gcc-internal-format
 msgid "self-comparison always evaluates to true"
 msgstr "vertailu ”etumerkitön lauseke >= 0” on aina tosi"
 
-#: c-family/c-warn.c:444
+#: c-family/c-warn.c:445
 #, fuzzy, gcc-internal-format
 msgid "self-comparison always evaluates to false"
 msgstr "vertailu ”etumerkitön lauseke < 0” on aina epätosi"
 
-#: c-family/c-warn.c:494
+#: c-family/c-warn.c:495
 #, gcc-internal-format
 msgid "logical not is only applied to the left hand side of comparison"
 msgstr ""
 
-#: c-family/c-warn.c:502
+#: c-family/c-warn.c:503
 #, gcc-internal-format
 msgid "add parentheses around left hand side expression to silence this warning"
 msgstr ""
 
-#: c-family/c-warn.c:636
+#: c-family/c-warn.c:637
 #, gcc-internal-format
 msgid "type-punning to incomplete type might break strict-aliasing rules"
 msgstr ""
 
-#: c-family/c-warn.c:654
+#: c-family/c-warn.c:655
 #, gcc-internal-format
 msgid "dereferencing type-punned pointer will break strict-aliasing rules"
 msgstr ""
 
-#: c-family/c-warn.c:662 c-family/c-warn.c:680
+#: c-family/c-warn.c:663 c-family/c-warn.c:681
 #, gcc-internal-format
 msgid "dereferencing type-punned pointer might break strict-aliasing rules"
 msgstr ""
 
-#: c-family/c-warn.c:803
+#: c-family/c-warn.c:811
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to use the size of the destination?"
 msgstr ""
 
-#: c-family/c-warn.c:834
+#: c-family/c-warn.c:842
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the destination; did you mean to remove the addressof?"
 msgstr ""
 
-#: c-family/c-warn.c:841
+#: c-family/c-warn.c:849
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the destination; did you mean to provide an explicit length?"
 msgstr ""
 
-#: c-family/c-warn.c:846
+#: c-family/c-warn.c:854
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the destination; did you mean to dereference it?"
 msgstr ""
 
-#: c-family/c-warn.c:858
+#: c-family/c-warn.c:866
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the destination; expected %qT or an explicit length"
 msgstr ""
 
-#: c-family/c-warn.c:874
+#: c-family/c-warn.c:882
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to remove the addressof?"
 msgstr ""
 
-#: c-family/c-warn.c:881
+#: c-family/c-warn.c:889
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to provide an explicit length?"
 msgstr ""
 
-#: c-family/c-warn.c:886
+#: c-family/c-warn.c:894
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to dereference it?"
 msgstr ""
 
-#: c-family/c-warn.c:898
+#: c-family/c-warn.c:906
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the source; expected %qT or an explicit length"
 msgstr ""
 
-#: c-family/c-warn.c:914
+#: c-family/c-warn.c:922
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the first source; did you mean to remove the addressof?"
 msgstr ""
 
-#: c-family/c-warn.c:921
+#: c-family/c-warn.c:929
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the first source; did you mean to provide an explicit length?"
 msgstr ""
 
-#: c-family/c-warn.c:926
+#: c-family/c-warn.c:934
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the first source; did you mean to dereference it?"
 msgstr ""
 
-#: c-family/c-warn.c:938
+#: c-family/c-warn.c:946
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the first source; expected %qT or an explicit length"
 msgstr ""
 
-#: c-family/c-warn.c:954
+#: c-family/c-warn.c:962
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the second source; did you mean to remove the addressof?"
 msgstr ""
 
-#: c-family/c-warn.c:961
+#: c-family/c-warn.c:969
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the second source; did you mean to provide an explicit length?"
 msgstr ""
 
-#: c-family/c-warn.c:966
+#: c-family/c-warn.c:974
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the second source; did you mean to dereference it?"
 msgstr ""
 
-#: c-family/c-warn.c:978
+#: c-family/c-warn.c:986
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the second source; expected %qT or an explicit length"
 msgstr ""
 
-#: c-family/c-warn.c:1007 c-family/c-warn.c:1014
+#: c-family/c-warn.c:1015 c-family/c-warn.c:1022
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter type %qT"
 msgid "%<_Atomic%>-qualified parameter type %qT of %q+D"
 msgstr "virheellinen parametrityyppi %qT"
 
-#: c-family/c-warn.c:1024
+#: c-family/c-warn.c:1032
 #, gcc-internal-format
 msgid "first argument of %q+D should be %<int%>"
 msgstr "%q+D:n ensimmäisen argumentin pitäisi olla %<int%>"
 
-#: c-family/c-warn.c:1033
+#: c-family/c-warn.c:1041
 #, gcc-internal-format
 msgid "second argument of %q+D should be %<char **%>"
 msgstr "%q+D:n toisen argumentin pitäisi olla %<char **%>"
 
-#: c-family/c-warn.c:1042
+#: c-family/c-warn.c:1050
 #, gcc-internal-format
 msgid "third argument of %q+D should probably be %<char **%>"
 msgstr "%q+D:n kolmannen argumentin pitäisi todennäköisesti olla %<char **%>"
 
-#: c-family/c-warn.c:1053
+#: c-family/c-warn.c:1061
 #, gcc-internal-format
 msgid "%q+D takes only zero or two arguments"
 msgstr "%q+D sallii vain nolla tai kaksi argumenttia"
 
-#: c-family/c-warn.c:1057
+#: c-family/c-warn.c:1065
 #, fuzzy, gcc-internal-format
 #| msgid "field %qE declared as a function"
 msgid "%q+D declared as variadic function"
 msgstr "sisäkkäinen funktio %q+D esitelty mutta ei koskaan määritelty"
 
-#: c-family/c-warn.c:1099
+#: c-family/c-warn.c:1107
 #, gcc-internal-format
 msgid "conversion to %qT from boolean expression"
 msgstr "muunnos tyyppiin %qT loogisesta lausekkeesta"
 
 # Tämä esiintynee esim. const char* → char* -muunnoksessa.
-#: c-family/c-warn.c:1117 c-family/c-warn.c:1192
+#: c-family/c-warn.c:1125 c-family/c-warn.c:1200
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT discards qualifiers"
 msgid "conversion from %qT to %qT changes value from %qE to %qE"
 msgstr "muunnos tyypistä %qT tyyppiin %qT ei säilytä tyyppimääreitä"
 
-#: c-family/c-warn.c:1121 c-family/c-warn.c:1200
+#: c-family/c-warn.c:1129 c-family/c-warn.c:1208
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "conversion from %qT to %qT changes the value of %qE"
@@ -28431,447 +28474,447 @@
 msgstr "muunnos tyypistä %qT tyyppiin %qT on moniselitteinen"
 
 # Tämä esiintynee esim. const char* → char* -muunnoksessa.
-#: c-family/c-warn.c:1141
+#: c-family/c-warn.c:1149
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT discards qualifiers"
 msgid "conversion from %qT to %qT discards imaginary component"
 msgstr "muunnos tyypistä %qT tyyppiin %qT ei säilytä tyyppimääreitä"
 
-#: c-family/c-warn.c:1153
+#: c-family/c-warn.c:1161
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %qT from %qT may alter its value"
 msgid "conversion from %qT to %qT may change value"
 msgstr "muunnos tyyppiin %qT tyypistä %qT saattaa muuttaa sen arvoa"
 
-#: c-family/c-warn.c:1213 c-family/c-warn.c:1230 c-family/c-warn.c:1247
+#: c-family/c-warn.c:1221 c-family/c-warn.c:1238 c-family/c-warn.c:1255
 #, fuzzy, gcc-internal-format
 msgid "overflow in conversion from %qT to %qT changes value from %qE to %qE"
 msgstr "muunnos tyypistä %qT tyyppiin %qT on moniselitteinen"
 
-#: c-family/c-warn.c:1218 c-family/c-warn.c:1235 c-family/c-warn.c:1252
+#: c-family/c-warn.c:1226 c-family/c-warn.c:1243 c-family/c-warn.c:1260
 #, fuzzy, gcc-internal-format
 #| msgid "narrowing conversion of %qE from %qT to %qT inside { }"
 msgid "overflow in conversion from %qT to %qT changes the value of %qE"
 msgstr "%qE:n kaventava muunnos tyypistä %qT tyyppiin %qT { }:n sisällä"
 
-#: c-family/c-warn.c:1282
+#: c-family/c-warn.c:1290
 #, gcc-internal-format
 msgid "case value %qs not in enumerated type"
 msgstr "case-arvo %qs ei ole luetellussa tyypissä"
 
-#: c-family/c-warn.c:1287
+#: c-family/c-warn.c:1295
 #, gcc-internal-format
 msgid "case value %qs not in enumerated type %qT"
 msgstr "case-arvo %qs ei ole luetellussa tyypissä %qT"
 
-#: c-family/c-warn.c:1348
+#: c-family/c-warn.c:1356
 #, gcc-internal-format
 msgid "switch missing default case"
 msgstr "switch-lauseesta puuttuu default-tapaus"
 
-#: c-family/c-warn.c:1393
+#: c-family/c-warn.c:1401
 #, gcc-internal-format
 msgid "switch condition has boolean value"
 msgstr ""
 
-#: c-family/c-warn.c:1466
+#: c-family/c-warn.c:1474
 #, gcc-internal-format
 msgid "enumeration value %qE not handled in switch"
 msgstr "lueteltua arvoa %qE ei käsitellä switch-lauseessa"
 
-#: c-family/c-warn.c:1494
+#: c-family/c-warn.c:1502
 #, gcc-internal-format
 msgid "the omitted middle operand in ?: will always be %<true%>, suggest explicit middle operand"
 msgstr ""
 
-#: c-family/c-warn.c:1515
+#: c-family/c-warn.c:1523
 #, fuzzy, gcc-internal-format
 msgid "assignment of member %qD in read-only object"
 msgstr "sijoitus kirjoitussuojattuun jäseneen %qD"
 
-#: c-family/c-warn.c:1517
+#: c-family/c-warn.c:1525
 #, fuzzy, gcc-internal-format
 msgid "increment of member %qD in read-only object"
 msgstr "kirjoitussuojatun jäsenen %qD kasvatus"
 
-#: c-family/c-warn.c:1519
+#: c-family/c-warn.c:1527
 #, fuzzy, gcc-internal-format
 msgid "decrement of member %qD in read-only object"
 msgstr "kirjoitussuojatun jäsenen %qD vähennys"
 
-#: c-family/c-warn.c:1521
+#: c-family/c-warn.c:1529
 #, fuzzy, gcc-internal-format
 msgid "member %qD in read-only object used as %<asm%> output"
 msgstr "kirjoitussuojattua sijaintia %qE käytetään %<asm%>-tulosteena"
 
-#: c-family/c-warn.c:1525
+#: c-family/c-warn.c:1533
 #, gcc-internal-format
 msgid "assignment of read-only member %qD"
 msgstr "sijoitus kirjoitussuojattuun jäseneen %qD"
 
-#: c-family/c-warn.c:1526
+#: c-family/c-warn.c:1534
 #, gcc-internal-format
 msgid "increment of read-only member %qD"
 msgstr "kirjoitussuojatun jäsenen %qD kasvatus"
 
-#: c-family/c-warn.c:1527
+#: c-family/c-warn.c:1535
 #, gcc-internal-format
 msgid "decrement of read-only member %qD"
 msgstr "kirjoitussuojatun jäsenen %qD vähennys"
 
-#: c-family/c-warn.c:1528
+#: c-family/c-warn.c:1536
 #, fuzzy, gcc-internal-format
 msgid "read-only member %qD used as %<asm%> output"
 msgstr "kirjoitussuojattua sijaintia %qE käytetään %<asm%>-tulosteena"
 
-#: c-family/c-warn.c:1532
+#: c-family/c-warn.c:1540
 #, gcc-internal-format
 msgid "assignment of read-only variable %qD"
 msgstr "sijoitus kirjoitussuojattuun muuttujaan %qD"
 
-#: c-family/c-warn.c:1533
+#: c-family/c-warn.c:1541
 #, gcc-internal-format
 msgid "increment of read-only variable %qD"
 msgstr "kirjoitussuojatun muuttujan %qD kasvatus"
 
-#: c-family/c-warn.c:1534
+#: c-family/c-warn.c:1542
 #, gcc-internal-format
 msgid "decrement of read-only variable %qD"
 msgstr "kirjoitussuojatun muuttujan %qD vähennys"
 
-#: c-family/c-warn.c:1535
+#: c-family/c-warn.c:1543
 #, fuzzy, gcc-internal-format
 msgid "read-only variable %qD used as %<asm%> output"
 msgstr "kirjoitussuojattua sijaintia %qE käytetään %<asm%>-tulosteena"
 
-#: c-family/c-warn.c:1538
+#: c-family/c-warn.c:1546
 #, gcc-internal-format
 msgid "assignment of read-only parameter %qD"
 msgstr "sijoitus kirjoitussuojattuun parametriin %qD"
 
-#: c-family/c-warn.c:1539
+#: c-family/c-warn.c:1547
 #, gcc-internal-format
 msgid "increment of read-only parameter %qD"
 msgstr "kirjoitussuojatun parametrin %qD kasvatus"
 
-#: c-family/c-warn.c:1540
+#: c-family/c-warn.c:1548
 #, gcc-internal-format
 msgid "decrement of read-only parameter %qD"
 msgstr "kirjoitussuojatun parametrin %qD vähennys"
 
-#: c-family/c-warn.c:1541
+#: c-family/c-warn.c:1549
 #, fuzzy, gcc-internal-format
 msgid "read-only parameter %qD use as %<asm%> output"
 msgstr "kirjoitussuojattua parametria %qD käytetään %<asm%>-tulosteena"
 
-#: c-family/c-warn.c:1546
+#: c-family/c-warn.c:1554
 #, gcc-internal-format
 msgid "assignment of read-only named return value %qD"
 msgstr "sijoitus kirjoitussuojattuun nimettyyn paluuarvoon %qD"
 
-#: c-family/c-warn.c:1548
+#: c-family/c-warn.c:1556
 #, gcc-internal-format
 msgid "increment of read-only named return value %qD"
 msgstr "kirjoitussuojatun nimetyn paluuarvon %qD kasvatus"
 
-#: c-family/c-warn.c:1550
+#: c-family/c-warn.c:1558
 #, gcc-internal-format
 msgid "decrement of read-only named return value %qD"
 msgstr "kirjoitussuojatun nimetyn paluuarvon %qD vähennys"
 
-#: c-family/c-warn.c:1552
+#: c-family/c-warn.c:1560
 #, fuzzy, gcc-internal-format
 msgid "read-only named return value %qD used as %<asm%>output"
 msgstr "kirjoitussuojattua muuttujaa %qD käytetään %<asm%>-tulosteena"
 
-#: c-family/c-warn.c:1557
+#: c-family/c-warn.c:1565
 #, gcc-internal-format
 msgid "assignment of function %qD"
 msgstr "funktion %qD sijoitus"
 
-#: c-family/c-warn.c:1558
+#: c-family/c-warn.c:1566
 #, gcc-internal-format
 msgid "increment of function %qD"
 msgstr "funktion %qD kasvatus"
 
-#: c-family/c-warn.c:1559
+#: c-family/c-warn.c:1567
 #, gcc-internal-format
 msgid "decrement of function %qD"
 msgstr "funktion %qD vähennys"
 
-#: c-family/c-warn.c:1560
+#: c-family/c-warn.c:1568
 #, fuzzy, gcc-internal-format
 msgid "function %qD used as %<asm%> output"
 msgstr "%qD:a käytetään alustamattomana tässä funktiossa"
 
-#: c-family/c-warn.c:1563 c/c-typeck.c:4762
+#: c-family/c-warn.c:1571 c/c-typeck.c:4767
 #, gcc-internal-format
 msgid "assignment of read-only location %qE"
 msgstr "kirjoitussuojatun sijainnin %qE sijoitus"
 
-#: c-family/c-warn.c:1564 c/c-typeck.c:4765
+#: c-family/c-warn.c:1572 c/c-typeck.c:4770
 #, gcc-internal-format
 msgid "increment of read-only location %qE"
 msgstr "kirjoitussuojatun sijainnin %qE kasvatus"
 
-#: c-family/c-warn.c:1565 c/c-typeck.c:4768
+#: c-family/c-warn.c:1573 c/c-typeck.c:4773
 #, gcc-internal-format
 msgid "decrement of read-only location %qE"
 msgstr "kirjoitussuojatun sijainnin %qE vähennys"
 
-#: c-family/c-warn.c:1566
+#: c-family/c-warn.c:1574
 #, gcc-internal-format
 msgid "read-only location %qE used as %<asm%> output"
 msgstr "kirjoitussuojattua sijaintia %qE käytetään %<asm%>-tulosteena"
 
 # XXX
-#: c-family/c-warn.c:1580
+#: c-family/c-warn.c:1588
 #, gcc-internal-format
 msgid "lvalue required as left operand of assignment"
 msgstr "sijoituksen vasemman operandin on oltava lvalue"
 
-#: c-family/c-warn.c:1583
+#: c-family/c-warn.c:1591
 #, fuzzy, gcc-internal-format
 msgid "lvalue required as increment operand"
 msgstr "sijoituksen vasemman operandin on oltava lvalue"
 
-#: c-family/c-warn.c:1586
+#: c-family/c-warn.c:1594
 #, fuzzy, gcc-internal-format
 msgid "lvalue required as decrement operand"
 msgstr "sijoituksen vasemman operandin on oltava lvalue"
 
-#: c-family/c-warn.c:1589
+#: c-family/c-warn.c:1597
 #, fuzzy, gcc-internal-format
 msgid "lvalue required as unary %<&%> operand"
 msgstr "sijoituksen vasemman operandin on oltava lvalue"
 
-#: c-family/c-warn.c:1592
+#: c-family/c-warn.c:1600
 #, fuzzy, gcc-internal-format
 msgid "lvalue required in asm statement"
 msgstr "virheellinen lvalue asm-tulosteessa %d"
 
-#: c-family/c-warn.c:1609
+#: c-family/c-warn.c:1617
 #, fuzzy, gcc-internal-format
 msgid "invalid type argument (have %qT)"
 msgstr "virheellinen parametrityyppi %qT"
 
-#: c-family/c-warn.c:1613
+#: c-family/c-warn.c:1621
 #, fuzzy, gcc-internal-format
 msgid "invalid type argument of array indexing (have %qT)"
 msgstr "virheellinen %qs-tyyppiargumentti (pitäisi olla %qT)"
 
-#: c-family/c-warn.c:1618
+#: c-family/c-warn.c:1626
 #, fuzzy, gcc-internal-format
 msgid "invalid type argument of unary %<*%> (have %qT)"
 msgstr "virheellinen %qs-tyyppiargumentti (pitäisi olla %qT)"
 
-#: c-family/c-warn.c:1623
+#: c-family/c-warn.c:1631
 #, fuzzy, gcc-internal-format
 msgid "invalid type argument of %<->%> (have %qT)"
 msgstr "odotettiin %qT, mutta argumentti on tyyppiä %qT"
 
-#: c-family/c-warn.c:1628
+#: c-family/c-warn.c:1636
 #, fuzzy, gcc-internal-format
 msgid "invalid type argument of %<->*%> (have %qT)"
 msgstr "odotettiin %qT, mutta argumentti on tyyppiä %qT"
 
-#: c-family/c-warn.c:1633
+#: c-family/c-warn.c:1641
 #, fuzzy, gcc-internal-format
 msgid "invalid type argument of implicit conversion (have %qT)"
 msgstr "virheellinen %qs-tyyppiargumentti (pitäisi olla %qT)"
 
-#: c-family/c-warn.c:1654
+#: c-family/c-warn.c:1662
 #, gcc-internal-format
 msgid "array subscript has type %<char%>"
 msgstr "taulukon indeksin tyyppi on %<char%>"
 
-#: c-family/c-warn.c:1689 c-family/c-warn.c:1692
+#: c-family/c-warn.c:1697 c-family/c-warn.c:1700
 #, gcc-internal-format
 msgid "suggest parentheses around %<+%> inside %<<<%>"
 msgstr "ehdotetaan sulkeita %<+%>:n ympärille %<<<%>:n sisällä"
 
-#: c-family/c-warn.c:1695 c-family/c-warn.c:1698
+#: c-family/c-warn.c:1703 c-family/c-warn.c:1706
 #, gcc-internal-format
 msgid "suggest parentheses around %<-%> inside %<<<%>"
 msgstr "ehdotetaan sulkeita %<-%>:n ympärille %<<<%>:n sisällä"
 
-#: c-family/c-warn.c:1704 c-family/c-warn.c:1707
+#: c-family/c-warn.c:1712 c-family/c-warn.c:1715
 #, gcc-internal-format
 msgid "suggest parentheses around %<+%> inside %<>>%>"
 msgstr "ehdotetaan sulkeita %<+%>:n ympärille %<>>%>:n sisällä"
 
-#: c-family/c-warn.c:1710 c-family/c-warn.c:1713
+#: c-family/c-warn.c:1718 c-family/c-warn.c:1721
 #, gcc-internal-format
 msgid "suggest parentheses around %<-%> inside %<>>%>"
 msgstr "ehdotetaan sulkeita %<-%>:n ympärille %<>>%>:n sisällä"
 
-#: c-family/c-warn.c:1719 c-family/c-warn.c:1722
+#: c-family/c-warn.c:1727 c-family/c-warn.c:1730
 #, gcc-internal-format
 msgid "suggest parentheses around %<&&%> within %<||%>"
 msgstr "ehdotetaan sulkeita %<&&%>:n ympärille %<||%>:n sisällä"
 
-#: c-family/c-warn.c:1729 c-family/c-warn.c:1733
+#: c-family/c-warn.c:1737 c-family/c-warn.c:1741
 #, gcc-internal-format
 msgid "suggest parentheses around arithmetic in operand of %<|%>"
 msgstr "ehdotetaan sulkeita lausekkeen ympärille %<|%>:n operandissa"
 
-#: c-family/c-warn.c:1737 c-family/c-warn.c:1740
+#: c-family/c-warn.c:1745 c-family/c-warn.c:1748
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<|%>"
 msgstr "ehdotetaan sulkeita vertailun ympärille %<|%>:n operandissa"
 
-#: c-family/c-warn.c:1745
+#: c-family/c-warn.c:1753
 #, fuzzy, gcc-internal-format
 msgid "suggest parentheses around operand of %<!%> or change %<|%> to %<||%> or %<!%> to %<~%>"
 msgstr "ehdotetaan sulkeita lausekkeen ympärille %<|%>:n operandissa"
 
-#: c-family/c-warn.c:1753 c-family/c-warn.c:1757
+#: c-family/c-warn.c:1761 c-family/c-warn.c:1765
 #, gcc-internal-format
 msgid "suggest parentheses around arithmetic in operand of %<^%>"
 msgstr "ehdotetaan sulkeita lausekkeen ympärille %<^%>:n operandissa"
 
-#: c-family/c-warn.c:1761 c-family/c-warn.c:1764
+#: c-family/c-warn.c:1769 c-family/c-warn.c:1772
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<^%>"
 msgstr "ehdotetaan sulkeita vertailun ympärille %<^%>:n operandissa"
 
-#: c-family/c-warn.c:1770 c-family/c-warn.c:1773
+#: c-family/c-warn.c:1778 c-family/c-warn.c:1781
 #, gcc-internal-format
 msgid "suggest parentheses around %<+%> in operand of %<&%>"
 msgstr "ehdotetaan sulkeita %<+%>:n ympärille %<&%>:n operandissa"
 
-#: c-family/c-warn.c:1776 c-family/c-warn.c:1779
+#: c-family/c-warn.c:1784 c-family/c-warn.c:1787
 #, gcc-internal-format
 msgid "suggest parentheses around %<-%> in operand of %<&%>"
 msgstr "ehdotetaan sulkeita %<-%>:n ympärille %<&%>:n operandissa"
 
-#: c-family/c-warn.c:1783 c-family/c-warn.c:1786
+#: c-family/c-warn.c:1791 c-family/c-warn.c:1794
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<&%>"
 msgstr "ehdotetaan sulkeita vertailun ympärille %<&%>:n operandissa"
 
-#: c-family/c-warn.c:1791
+#: c-family/c-warn.c:1799
 #, fuzzy, gcc-internal-format
 msgid "suggest parentheses around operand of %<!%> or change %<&%> to %<&&%> or %<!%> to %<~%>"
 msgstr "ehdotetaan sulkeita lausekkeen ympärille %<|%>:n operandissa"
 
-#: c-family/c-warn.c:1798 c-family/c-warn.c:1801
+#: c-family/c-warn.c:1806 c-family/c-warn.c:1809
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<==%>"
 msgstr "ehdotetaan sulkeita vertailun ympärille %<==%>:n operandissa"
 
-#: c-family/c-warn.c:1806 c-family/c-warn.c:1809
+#: c-family/c-warn.c:1814 c-family/c-warn.c:1817
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<!=%>"
 msgstr "ehdotetaan sulkeita vertailun ympärille %<!=%>:n operandissa"
 
-#: c-family/c-warn.c:1819 c-family/c-warn.c:1825
+#: c-family/c-warn.c:1827 c-family/c-warn.c:1833
 #, gcc-internal-format
 msgid "comparisons like %<X<=Y<=Z%> do not have their mathematical meaning"
 msgstr "%<X<=Y<=Z%> -tyylisillä vertailuilla on eri merkitys kuin matematiikassa"
 
-#: c-family/c-warn.c:1841
+#: c-family/c-warn.c:1849
 #, gcc-internal-format
 msgid "label %q+D defined but not used"
 msgstr "nimike %q+D määritelty mutta käytettämättä"
 
-#: c-family/c-warn.c:1843
+#: c-family/c-warn.c:1851
 #, gcc-internal-format
 msgid "label %q+D declared but not defined"
 msgstr "nimike %qD esitelty muttei määritelty"
 
-#: c-family/c-warn.c:1866
+#: c-family/c-warn.c:1874
 #, gcc-internal-format
 msgid "division by zero"
 msgstr "jako nollalla"
 
-#: c-family/c-warn.c:1886
+#: c-family/c-warn.c:1894
 #, gcc-internal-format
 msgid "%<memset%> used with constant zero length parameter; this could be due to transposed parameters"
 msgstr ""
 
-#: c-family/c-warn.c:1909
+#: c-family/c-warn.c:1918
 #, gcc-internal-format
 msgid "%<memset%> used with length equal to number of elements without multiplication by element size"
 msgstr ""
 
-#: c-family/c-warn.c:1948 c/c-typeck.c:11499 c/c-typeck.c:11667
+#: c-family/c-warn.c:1957 c/c-typeck.c:11504 c/c-typeck.c:11672
 #: cp/typeck.c:5048
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr "tyyppien %qT ja %qT välinen vertailu"
 
-#: c-family/c-warn.c:1998
+#: c-family/c-warn.c:2007
 #, gcc-internal-format
 msgid "comparison of integer expressions of different signedness: %qT and %qT"
 msgstr ""
 
-#: c-family/c-warn.c:2051
+#: c-family/c-warn.c:2060
 #, gcc-internal-format
 msgid "promoted ~unsigned is always non-zero"
 msgstr ""
 
-#: c-family/c-warn.c:2054
+#: c-family/c-warn.c:2063
 #, fuzzy, gcc-internal-format
 msgid "comparison of promoted ~unsigned with constant"
 msgstr "vertailu ”etumerkitön lauseke >= 0” on aina tosi"
 
-#: c-family/c-warn.c:2064
+#: c-family/c-warn.c:2073
 #, fuzzy, gcc-internal-format
 msgid "comparison of promoted ~unsigned with unsigned"
 msgstr "vertailu ”etumerkitön lauseke >= 0” on aina tosi"
 
-#: c-family/c-warn.c:2118
+#: c-family/c-warn.c:2127
 #, fuzzy, gcc-internal-format
 #| msgid "unused parameter %q+D"
 msgid "unused parameter %qD"
 msgstr "käyttämätön muuttuja %q+D"
 
-#: c-family/c-warn.c:2180
+#: c-family/c-warn.c:2189
 #, fuzzy, gcc-internal-format
 msgid "typedef %qD locally defined but not used"
 msgstr "%Jnimike %qD määritelty, mutta ei käytetty"
 
 # XXX
-#: c-family/c-warn.c:2215
+#: c-family/c-warn.c:2224
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<const%>"
 msgid "duplicated %<if%> condition"
 msgstr "kaksinkertainen viestitunniste"
 
-#: c-family/c-warn.c:2244
+#: c-family/c-warn.c:2253
 #, fuzzy, gcc-internal-format
 msgid "optimization attribute on %qD follows definition but the attribute doesn%'t match"
 msgstr "%J%qD esitelty attribuutilla noinline, edellinen esittely on avoin "
 
-#: c-family/c-warn.c:2254
+#: c-family/c-warn.c:2261
 #, fuzzy, gcc-internal-format
 msgid "inline declaration of %qD follows declaration with attribute %qs"
 msgstr "%J%qD esitelty avoimeksi, edellinen esittely sisältää attribuutin noinline"
 
-#: c-family/c-warn.c:2259
+#: c-family/c-warn.c:2266
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q+D with attribute %qs follows inline declaration"
 msgstr "%J%qD esitelty attribuutilla noinline, edellinen esittely on avoin "
 
-#: c-family/c-warn.c:2306
+#: c-family/c-warn.c:2313
 #, gcc-internal-format
 msgid "result of %qE requires %u bits to represent, but %qT only has %u bits"
 msgstr ""
 
-#: c-family/c-warn.c:2344 c-family/c-warn.c:2368
+#: c-family/c-warn.c:2351 c-family/c-warn.c:2375
 #, fuzzy, gcc-internal-format
 #| msgid "comparison of unsigned expression < 0 is always false"
 msgid "comparison of constant %qE with boolean expression is always false"
 msgstr "vertailu ”etumerkitön lauseke < 0” on aina epätosi"
 
-#: c-family/c-warn.c:2347 c-family/c-warn.c:2365
+#: c-family/c-warn.c:2354 c-family/c-warn.c:2372
 #, fuzzy, gcc-internal-format
 #| msgid "comparison of unsigned expression >= 0 is always true"
 msgid "comparison of constant %qE with boolean expression is always true"
 msgstr "vertailu ”etumerkitön lauseke >= 0” on aina tosi"
 
-#: c-family/c-warn.c:2415
+#: c-family/c-warn.c:2422
 #, fuzzy
 msgid "passing argument %i to restrict-qualified parameter aliases with argument %Z"
 msgid_plural "passing argument %i to restrict-qualified parameter aliases with arguments %Z"
@@ -28878,17 +28921,17 @@
 msgstr[0] "sijoitus hylkää kohdeosoitintyypin määreitä"
 msgstr[1] "sijoitus hylkää kohdeosoitintyypin määreitä"
 
-#: c-family/c-warn.c:2480 c/c-typeck.c:5288 cp/call.c:5365
+#: c-family/c-warn.c:2487 c/c-typeck.c:5293 cp/call.c:5365
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr ""
 
-#: c-family/c-warn.c:2586
+#: c-family/c-warn.c:2593
 #, gcc-internal-format
 msgid "macro expands to multiple statements"
 msgstr ""
 
-#: c-family/c-warn.c:2587
+#: c-family/c-warn.c:2594
 #, gcc-internal-format
 msgid "some parts of macro expansion are not guarded by this %qs clause"
 msgstr ""
@@ -28903,7 +28946,7 @@
 msgid "too many input files"
 msgstr "liikaa syötetiedostoja"
 
-#: common/config/aarch64/aarch64-common.c:319 config/aarch64/aarch64.c:10686
+#: common/config/aarch64/aarch64-common.c:319 config/aarch64/aarch64.c:10702
 #, fuzzy, gcc-internal-format
 msgid "unknown value %qs for -mcpu"
 msgstr "tuntematon cc_attr-arvo"
@@ -28934,13 +28977,13 @@
 msgstr ""
 
 #: common/config/arm/arm-common.c:322 common/config/arm/arm-common.c:376
-#: common/config/arm/arm-common.c:423 config/aarch64/aarch64.c:10639
+#: common/config/arm/arm-common.c:423 config/aarch64/aarch64.c:10655
 #, fuzzy, gcc-internal-format
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr "Kelvolliset argumentit:"
 
 #: common/config/arm/arm-common.c:325 common/config/arm/arm-common.c:379
-#: common/config/arm/arm-common.c:426 config/aarch64/aarch64.c:10642
+#: common/config/arm/arm-common.c:426 config/aarch64/aarch64.c:10658
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s"
 msgstr "Kelvolliset argumentit:"
@@ -29420,12 +29463,12 @@
 msgid "profiler support for VxWorks"
 msgstr "profilointituki VxWorksille"
 
-#: config/aarch64/aarch64-builtins.c:1109 config/arm/arm-builtins.c:2262
+#: config/aarch64/aarch64-builtins.c:1109 config/arm/arm-builtins.c:2272
 #, fuzzy, gcc-internal-format
 msgid "%Kargument %d must be a constant immediate"
 msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 
-#: config/aarch64/aarch64-builtins.c:1180 config/arm/arm-builtins.c:2492
+#: config/aarch64/aarch64-builtins.c:1180 config/arm/arm-builtins.c:2502
 #, fuzzy, gcc-internal-format
 msgid "%Klane index must be a constant immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
@@ -29435,27 +29478,27 @@
 msgid "%Ktotal size and element size must be a non-zero constant immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/aarch64/aarch64.c:1053
+#: config/aarch64/aarch64.c:1069
 #, fuzzy, gcc-internal-format
 msgid "%qs is incompatible with %s %s"
 msgstr "%s %qs"
 
-#: config/aarch64/aarch64.c:1055
+#: config/aarch64/aarch64.c:1071
 #, fuzzy, gcc-internal-format
 msgid "%qs feature modifier is incompatible with %s %s"
 msgstr "%s ei tue pituusmäärettä %qs %s"
 
-#: config/aarch64/aarch64.c:3772
+#: config/aarch64/aarch64.c:3788
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10287
+#: config/aarch64/aarch64.c:10303
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown flag passed in -moverride=%s (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10331
+#: config/aarch64/aarch64.c:10347
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s string ill-formed\n"
 msgstr ""
@@ -29462,7 +29505,7 @@
 "Käyttö: %s [MERKKIJONO]...\n"
 "  tai:  %s VALITSIN\n"
 
-#: config/aarch64/aarch64.c:10388
+#: config/aarch64/aarch64.c:10404
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr ""
@@ -29469,149 +29512,149 @@
 "Käyttö: %s [MERKKIJONO]...\n"
 "  tai:  %s VALITSIN\n"
 
-#: config/aarch64/aarch64.c:10406
+#: config/aarch64/aarch64.c:10422
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown tuning option (%s)"
 msgstr "tuntematon valitsin -%s"
 
-#: config/aarch64/aarch64.c:10683
+#: config/aarch64/aarch64.c:10699
 #, fuzzy, gcc-internal-format
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr "makron nimi puuttuu %qs:n jälkeen"
 
-#: config/aarch64/aarch64.c:10690
+#: config/aarch64/aarch64.c:10706
 #, fuzzy, gcc-internal-format
 msgid "invalid feature modifier in %<-mcpu=%s%>"
 msgstr "tuntematon konetila %qs"
 
-#: config/aarch64/aarch64.c:10717
+#: config/aarch64/aarch64.c:10733
 #, fuzzy, gcc-internal-format
 msgid "missing arch name in %<-march=%s%>"
 msgstr "makron nimi puuttuu %qs:n jälkeen"
 
-#: config/aarch64/aarch64.c:10720
+#: config/aarch64/aarch64.c:10736
 #, fuzzy, gcc-internal-format
 msgid "unknown value %qs for -march"
 msgstr "tuntematon cc_attr-arvo"
 
-#: config/aarch64/aarch64.c:10724
+#: config/aarch64/aarch64.c:10740
 #, fuzzy, gcc-internal-format
 msgid "invalid feature modifier in %<-march=%s%>"
 msgstr "tiedostonimi puuttuu %qs:n jälkeen"
 
-#: config/aarch64/aarch64.c:10750
+#: config/aarch64/aarch64.c:10766
 #, fuzzy, gcc-internal-format
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr "makron nimi puuttuu %qs:n jälkeen"
 
-#: config/aarch64/aarch64.c:10753
+#: config/aarch64/aarch64.c:10769
 #, fuzzy, gcc-internal-format
 msgid "unknown value %qs for -mtune"
 msgstr "tuntematon cc_attr-arvo"
 
-#: config/aarch64/aarch64.c:10871 config/arm/arm.c:3173
+#: config/aarch64/aarch64.c:10887 config/arm/arm.c:3173
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "switch -mcpu=%s conflicts with -march=%s switch"
 msgstr "valitsin -mcpu=%s on ristiriidassa valitsimen -march=%s kanssa"
 
-#: config/aarch64/aarch64.c:10906
+#: config/aarch64/aarch64.c:10922
 #, fuzzy, gcc-internal-format
 msgid "assembler does not support -mabi=ilp32"
 msgstr "%s ei tue %%n$-operandinumeromuotoilua"
 
-#: config/aarch64/aarch64.c:10913
+#: config/aarch64/aarch64.c:10929
 #, gcc-internal-format
 msgid "return address signing is only supported for -mabi=lp64"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10975
+#: config/aarch64/aarch64.c:10991
 #, fuzzy, gcc-internal-format
 msgid "code model %qs with -f%s"
 msgstr "koodimalli %s ei tue PIC-tilaa"
 
-#: config/aarch64/aarch64.c:11138
+#: config/aarch64/aarch64.c:11154
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11141
+#: config/aarch64/aarch64.c:11157
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11145 config/aarch64/aarch64.c:11184
-#: config/aarch64/aarch64.c:11257
+#: config/aarch64/aarch64.c:11161 config/aarch64/aarch64.c:11200
+#: config/aarch64/aarch64.c:11273
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "invalid value (\"%s\") in %<target()%> pragma or attribute"
 msgstr "%qs-attribuutin virheellinen argumentti"
 
-#: config/aarch64/aarch64.c:11177
+#: config/aarch64/aarch64.c:11193
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11180
+#: config/aarch64/aarch64.c:11196
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11213
+#: config/aarch64/aarch64.c:11229
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"tune=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11253
+#: config/aarch64/aarch64.c:11269
 #, fuzzy, gcc-internal-format
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr "%s:n perästä puuttuu operandi"
 
-#: config/aarch64/aarch64.c:11306 config/aarch64/aarch64.c:11483
+#: config/aarch64/aarch64.c:11322 config/aarch64/aarch64.c:11499
 #, fuzzy, gcc-internal-format
 #| msgid "malformed #pragma builtin"
 msgid "malformed %<target()%> pragma or attribute"
 msgstr "Väärin muotoiltu kohdekohtainen muuttujamäärittely"
 
-#: config/aarch64/aarch64.c:11354
+#: config/aarch64/aarch64.c:11370
 #, fuzzy, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr "%J%qD sallii vain nolla tai kaksi argumenttia"
 
-#: config/aarch64/aarch64.c:11362
+#: config/aarch64/aarch64.c:11378
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support the %<%%%s%c%> %s format"
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr "%s ei tue muotoilua %<%%%s%c%> %s"
 
-#: config/aarch64/aarch64.c:11416
+#: config/aarch64/aarch64.c:11432
 #, fuzzy, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr "kohde ”%s” ei täsmää kohdehahmon kanssa"
 
-#: config/aarch64/aarch64.c:11473 config/arm/arm.c:30742
-#: config/i386/i386.c:5440 config/powerpcspe/powerpcspe.c:39760
-#: config/rs6000/rs6000.c:36904 config/s390/s390.c:15746
+#: config/aarch64/aarch64.c:11489 config/arm/arm.c:30742
+#: config/i386/i386.c:5443 config/powerpcspe/powerpcspe.c:39760
+#: config/rs6000/rs6000.c:36960 config/s390/s390.c:15746
 #, fuzzy, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "%qE-attribuutti tarvitsee merkkijonovakioargumentin"
 
-#: config/aarch64/aarch64.c:11500
+#: config/aarch64/aarch64.c:11516
 #, fuzzy, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr "kohde ”%s” ei täsmää kohdehahmon kanssa"
 
-#: config/aarch64/aarch64.c:11509
+#: config/aarch64/aarch64.c:11525
 #, fuzzy, gcc-internal-format
 #| msgid "malformed #pragma builtin"
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr "Väärin muotoiltu kohdekohtainen muuttujamäärittely"
 
-#: config/aarch64/aarch64.c:13571
+#: config/aarch64/aarch64.c:13587
 #, gcc-internal-format
 msgid "%Klane %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13573
+#: config/aarch64/aarch64.c:13589
 #, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr ""
@@ -29671,8 +29714,8 @@
 msgid "bad value %qs for -mmemory-latency"
 msgstr ""
 
-#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6526
-#: config/arc/arc.c:6800 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
+#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6517
+#: config/arc/arc.c:6791 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
 #: config/tilepro/tilepro.c:3108
 #, fuzzy, gcc-internal-format
 msgid "bad builtin fcode"
@@ -29783,11 +29826,11 @@
 #: config/arm/arm.c:7029 config/avr/avr.c:9718 config/avr/avr.c:9734
 #: config/bfin/bfin.c:4705 config/bfin/bfin.c:4766 config/bfin/bfin.c:4795
 #: config/epiphany/epiphany.c:491 config/h8300/h8300.c:5459
-#: config/i386/i386.c:6452 config/i386/i386.c:12479 config/i386/i386.c:41424
-#: config/i386/i386.c:41474 config/i386/i386.c:41544 config/m68k/m68k.c:780
+#: config/i386/i386.c:6455 config/i386/i386.c:12482 config/i386/i386.c:41418
+#: config/i386/i386.c:41468 config/i386/i386.c:41538 config/m68k/m68k.c:780
 #: config/mcore/mcore.c:3070 config/nvptx/nvptx.c:4611
 #: config/powerpcspe/powerpcspe.c:35785 config/riscv/riscv.c:2698
-#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:32982
+#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:33038
 #: config/rx/rx.c:2719 config/rx/rx.c:2745 config/s390/s390.c:1056
 #: config/s390/s390.c:1143 config/sh/sh.c:8428 config/sh/sh.c:8446
 #: config/sh/sh.c:8470 config/sh/sh.c:8541 config/sh/sh.c:8564
@@ -29797,142 +29840,142 @@
 msgid "%qE attribute only applies to functions"
 msgstr "%qE-attribuutti pätee vain funktioihin, ei %s"
 
-#: config/arc/arc.c:6425
+#: config/arc/arc.c:6416
 #, fuzzy, gcc-internal-format
 #| msgid "%<__builtin_next_arg%> called without an argument"
 msgid "__builtin_arc_aligned with non-constant alignment"
 msgstr "funktiota %<__builtin_next_arg%> kutsuttu ilman argumenttia"
 
-#: config/arc/arc.c:6433
+#: config/arc/arc.c:6424
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to %<__builtin_frame_address%>"
 msgid "invalid alignment value for __builtin_arc_aligned"
 msgstr "epäkelpo argumentti funktiolle %<__builtin_frame_address%>"
 
-#: config/arc/arc.c:6596
+#: config/arc/arc.c:6587
 #, gcc-internal-format
 msgid "operand 1 should be an unsigned 3-bit immediate"
 msgstr ""
 
-#: config/arc/arc.c:6637 config/arc/arc.c:6734
+#: config/arc/arc.c:6628 config/arc/arc.c:6725
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6670 config/arc/arc.c:6702
+#: config/arc/arc.c:6661 config/arc/arc.c:6693
 #, gcc-internal-format
 msgid "operand 1 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6674 config/arc/arc.c:6706
+#: config/arc/arc.c:6665 config/arc/arc.c:6697
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "operand 2 should be an unsigned 8-bit value"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/arc/arc.c:6738
+#: config/arc/arc.c:6729
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "operand 3 should be an unsigned 8-bit value"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/arc/arc.c:6771
+#: config/arc/arc.c:6762
 #, gcc-internal-format
 msgid "operand 4 should be an unsigned 8-bit value (0-255)"
 msgstr ""
 
-#: config/arc/arc.c:6775
+#: config/arc/arc.c:6766
 #, gcc-internal-format
 msgid "operand 3 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6782
+#: config/arc/arc.c:6773
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (subreg 0-7)"
 msgstr ""
 
-#: config/arc/arc.c:6785
+#: config/arc/arc.c:6776
 #, gcc-internal-format
 msgid "operand 2 should be an even 3-bit value (subreg 0,2,4,6)"
 msgstr ""
 
-#: config/arc/arc.c:6832
+#: config/arc/arc.c:6823
 #, gcc-internal-format, gfc-internal-format
 msgid "builtin requires an immediate for operand %d"
 msgstr ""
 
-#: config/arc/arc.c:6837
+#: config/arc/arc.c:6828
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "operand %d should be a 6 bit unsigned immediate"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/arc/arc.c:6841
+#: config/arc/arc.c:6832
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "operand %d should be a 8 bit unsigned immediate"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/arc/arc.c:6845
+#: config/arc/arc.c:6836
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "operand %d should be a 3 bit unsigned immediate"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/arc/arc.c:6848
+#: config/arc/arc.c:6839
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown builtin immediate operand type for operand %d"
 msgstr ""
 
-#: config/arc/arc.c:6899
+#: config/arc/arc.c:6890
 #, gcc-internal-format
 msgid "register number must be a compile-time constant. Try giving higher optimization levels"
 msgstr ""
 
-#: config/arc/arc.c:7685
+#: config/arc/arc.c:7747
 #, gcc-internal-format
 msgid "Insn addresses not set after shorten_branches"
 msgstr ""
 
-#: config/arc/arc.c:7894
+#: config/arc/arc.c:7956
 #, fuzzy, gcc-internal-format
 msgid "insn addresses not freed"
 msgstr "tämä on käsky:"
 
-#: config/arc/arc.c:10682
+#: config/arc/arc.c:10670
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only valid for ARCv2 architecture"
 msgstr "%qE-attribuutti pätee vain funktioihin"
 
-#: config/arc/arc.c:10690 config/arc/arc.c:10729
+#: config/arc/arc.c:10678 config/arc/arc.c:10717
 #, fuzzy, gcc-internal-format
 msgid "argument of %qE attribute is missing"
 msgstr "%qE-attribuutti tarvitsee merkkijonovakioargumentin"
 
-#: config/arc/arc.c:10701 config/arc/arc.c:10740 config/arc/arc.c:10842
+#: config/arc/arc.c:10689 config/arc/arc.c:10728 config/arc/arc.c:10830
 #: config/avr/avr.c:9790
 #, gcc-internal-format
 msgid "%qE attribute allows only an integer constant argument"
 msgstr "%qE-attribuutti sallii vain kokonaislukuvakioargumentin"
 
-#: config/arc/arc.c:10721
+#: config/arc/arc.c:10709
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to function types"
 msgid "%qE attribute only valid for ARC EM architecture"
 msgstr "%qE-attribuutti pätee vain funktiotyyppeihin"
 
-#: config/arc/arc.c:10776
+#: config/arc/arc.c:10764
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to function types"
 msgid "%qE attribute only applies to types"
 msgstr "%qE-attribuutti pätee vain funktiotyyppeihin"
 
-#: config/arc/arc.c:10782
+#: config/arc/arc.c:10770
 #, fuzzy, gcc-internal-format
 msgid "argument of %qE attribute ignored"
 msgstr "%qE-attribuutti tarvitsee merkkijonovakioargumentin"
 
-#: config/arc/arc.c:10832 config/avr/avr.c:9777 config/bfin/bfin.c:4827
+#: config/arc/arc.c:10820 config/avr/avr.c:9777 config/bfin/bfin.c:4827
 #: config/i386/winnt.c:63 config/msp430/msp430.c:2018
 #: config/nvptx/nvptx.c:4634
 #, gcc-internal-format
@@ -29939,174 +29982,174 @@
 msgid "%qE attribute only applies to variables"
 msgstr "%qE-attribuutti pätee vain muuttujiin"
 
-#: config/arm/arm-builtins.c:2370
+#: config/arm/arm-builtins.c:2380
 #, fuzzy, gcc-internal-format
 msgid "this builtin is not supported for this target"
 msgstr "Ei ole tuettu"
 
-#: config/arm/arm-builtins.c:2475
+#: config/arm/arm-builtins.c:2485
 #, gcc-internal-format
 msgid "You must enable NEON instructions (e.g. -mfloat-abi=softfp -mfpu=neon) to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2513
+#: config/arm/arm-builtins.c:2523
 #, gcc-internal-format
 msgid "You must enable VFP instructions to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2573
+#: config/arm/arm-builtins.c:2583
 #, gcc-internal-format
 msgid "You must enable crypto instructions (e.g. include -mfloat-abi=softfp -mfpu=crypto-neon...) to use these intrinsics."
 msgstr ""
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:2633 config/arm/arm-builtins.c:2737
+#: config/arm/arm-builtins.c:2643 config/arm/arm-builtins.c:2747
 #, fuzzy, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr "mountin käyttöön vaaditaan pääkäyttäjän oikeudet"
 
-#: config/arm/arm-builtins.c:2641 config/arm/arm-builtins.c:2686
-#: config/arm/arm-builtins.c:2744 config/arm/arm-builtins.c:2753
+#: config/arm/arm-builtins.c:2651 config/arm/arm-builtins.c:2696
+#: config/arm/arm-builtins.c:2754 config/arm/arm-builtins.c:2763
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2646 config/arm/arm-builtins.c:2755
+#: config/arm/arm-builtins.c:2656 config/arm/arm-builtins.c:2765
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2651 config/arm/arm-builtins.c:2757
+#: config/arm/arm-builtins.c:2661 config/arm/arm-builtins.c:2767
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2823
+#: config/arm/arm-builtins.c:2833
 #, fuzzy, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr "PEITE"
 
-#: config/arm/arm-builtins.c:2828
+#: config/arm/arm-builtins.c:2838
 #, fuzzy, gcc-internal-format
 msgid "the range of mask should be in 0 to 255"
 msgstr "haluttu sijainti ei ole kokonaislukuvakio"
 
-#: config/arm/arm-builtins.c:3016
+#: config/arm/arm-builtins.c:3026
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3018
+#: config/arm/arm-builtins.c:3028
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3020
+#: config/arm/arm-builtins.c:3030
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3022
+#: config/arm/arm-builtins.c:3032
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3028
+#: config/arm/arm-builtins.c:3038
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3030
+#: config/arm/arm-builtins.c:3040
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3035
+#: config/arm/arm-builtins.c:3045
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3037
+#: config/arm/arm-builtins.c:3047
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3039
+#: config/arm/arm-builtins.c:3049
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3041
+#: config/arm/arm-builtins.c:3051
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3043
+#: config/arm/arm-builtins.c:3053
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3045
+#: config/arm/arm-builtins.c:3055
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3047
+#: config/arm/arm-builtins.c:3057
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3049
+#: config/arm/arm-builtins.c:3059
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3051
+#: config/arm/arm-builtins.c:3061
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3053
+#: config/arm/arm-builtins.c:3063
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3055
+#: config/arm/arm-builtins.c:3065
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3057
+#: config/arm/arm-builtins.c:3067
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3059
+#: config/arm/arm-builtins.c:3069
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3061
+#: config/arm/arm-builtins.c:3071
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3063
+#: config/arm/arm-builtins.c:3073
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3065
+#: config/arm/arm-builtins.c:3075
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3067
+#: config/arm/arm-builtins.c:3077
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3069
+#: config/arm/arm-builtins.c:3079
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr ""
@@ -31026,7 +31069,7 @@
 msgid "can%'t set position in PCH file: %m"
 msgstr "%s: ei voida avata PCH-tiedostoa: %m\n"
 
-#: config/i386/i386.c:3177
+#: config/i386/i386.c:3180
 #, fuzzy, gcc-internal-format
 msgid "wrong argument %qs to option %qs"
 msgstr ""
@@ -31033,551 +31076,551 @@
 "Käyttö: %s KOMENTO [ARGUMENTTI]...\n"
 "  tai:  %s VALITSIN\n"
 
-#: config/i386/i386.c:3183
+#: config/i386/i386.c:3186
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr ""
 
-#: config/i386/i386.c:3193
+#: config/i386/i386.c:3196
 #, fuzzy, gcc-internal-format
 msgid "wrong strategy name %qs specified for option %qs"
 msgstr "%Jkohdistusta ei voi määrittää %qD:lle"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3219
+#: config/i386/i386.c:3222
 #, fuzzy, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr "%Jkohdistusta ei voi määrittää %qD:lle"
 
-#: config/i386/i386.c:3232
+#: config/i386/i386.c:3235
 #, fuzzy, gcc-internal-format
 msgid "unknown alignment %qs specified for option %qs"
 msgstr "Tuntematon valitsin: %s %s %s"
 
-#: config/i386/i386.c:3242
+#: config/i386/i386.c:3245
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr ""
 
-#: config/i386/i386.c:3249
+#: config/i386/i386.c:3252
 #, fuzzy, gcc-internal-format
 msgid "too many size ranges specified in option %qs"
 msgstr "epäkelpo osoitintila %qs"
 
-#: config/i386/i386.c:3302
+#: config/i386/i386.c:3305
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unknown argument list function at %L"
 msgid "unknown parameter to option -mtune-ctrl: %s"
 msgstr "Tuntematon argumenttiluettelofunktio kohdassa %L"
 
-#: config/i386/i386.c:3726
+#: config/i386/i386.c:3729
 #, fuzzy, gcc-internal-format
 #| msgid "64-bit ABI not supported in ESA/390 mode"
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "64-bittinen ABI ei ole tuettu ESA/390-tilassa"
 
-#: config/i386/i386.c:3775
+#: config/i386/i386.c:3778
 #, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr ""
 
-#: config/i386/i386.c:3777
+#: config/i386/i386.c:3780
 #, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr ""
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3804
+#: config/i386/i386.c:3807
 #, gcc-internal-format
 msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386.c:3821
+#: config/i386/i386.c:3824
 #, fuzzy, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: config/i386/i386.c:3833
+#: config/i386/i386.c:3836
 #, fuzzy, gcc-internal-format
 msgid "-mabi=ms not supported with X32 ABI"
 msgstr "valitsin %qs ei ole enää tuettu"
 
-#: config/i386/i386.c:3851 config/i386/i386.c:3860 config/i386/i386.c:3872
-#: config/i386/i386.c:3883 config/i386/i386.c:3894
+#: config/i386/i386.c:3854 config/i386/i386.c:3863 config/i386/i386.c:3875
+#: config/i386/i386.c:3886 config/i386/i386.c:3897
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr ""
 
-#: config/i386/i386.c:3863 config/i386/i386.c:3875
+#: config/i386/i386.c:3866 config/i386/i386.c:3878
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "koodimalli %s ei tue PIC-tilaa"
 
-#: config/i386/i386.c:3881 config/i386/i386.c:3890 config/i386/i386.c:5213
+#: config/i386/i386.c:3884 config/i386/i386.c:3893 config/i386/i386.c:5216
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "koodimalli %s ei tue PIC-tilaa"
 
-#: config/i386/i386.c:3918
+#: config/i386/i386.c:3921
 #, fuzzy, gcc-internal-format
 msgid "-masm=intel not supported in this configuration"
 msgstr "weakref ei ole tuettu tässä konfiguraatiossa"
 
-#: config/i386/i386.c:3923
+#: config/i386/i386.c:3926
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr ""
 
-#: config/i386/i386.c:3932
+#: config/i386/i386.c:3935
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386.c:3934
+#: config/i386/i386.c:3937
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386.c:3941
+#: config/i386/i386.c:3944
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386.c:3943
+#: config/i386/i386.c:3946
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386.c:3951 config/i386/i386.c:4265
+#: config/i386/i386.c:3954 config/i386/i386.c:4268
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr ""
 
-#: config/i386/i386.c:4197 config/i386/i386.c:4200
+#: config/i386/i386.c:4200 config/i386/i386.c:4203
 #, fuzzy, gcc-internal-format
 msgid "Intel MPX does not support x32"
 msgstr "ISO C90 ei tue %<long long%> -tyyppiä"
 
-#: config/i386/i386.c:4205
+#: config/i386/i386.c:4208
 #, fuzzy, gcc-internal-format
 msgid "bad value (%qs) for %<-march=%> switch"
 msgstr "virheellinen aikakatkaisuarvo: %s"
 
-#: config/i386/i386.c:4206
+#: config/i386/i386.c:4209
 #, fuzzy, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"arch=\")%> attribute"
 msgstr "virheellinen aikakatkaisuarvo: %s"
 
-#: config/i386/i386.c:4228
+#: config/i386/i386.c:4231
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "Kelvolliset argumentit:"
 
-#: config/i386/i386.c:4230
+#: config/i386/i386.c:4233
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4235
+#: config/i386/i386.c:4238
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "Kelvolliset argumentit:"
 
-#: config/i386/i386.c:4236
+#: config/i386/i386.c:4239
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "Kelvolliset argumentit:"
 
-#: config/i386/i386.c:4284
+#: config/i386/i386.c:4287
 #, fuzzy, gcc-internal-format
 msgid "bad value (%qs) for %<-mtune=%> switch"
 msgstr "virheellinen aikakatkaisuarvo: %s"
 
-#: config/i386/i386.c:4285
+#: config/i386/i386.c:4288
 #, fuzzy, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"tune=\")%> attribute"
 msgstr "virheellinen aikakatkaisuarvo: %s"
 
-#: config/i386/i386.c:4305
+#: config/i386/i386.c:4308
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "Kelvolliset argumentit:"
 
-#: config/i386/i386.c:4307
+#: config/i386/i386.c:4310
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4312
+#: config/i386/i386.c:4315
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "Kelvolliset argumentit:"
 
-#: config/i386/i386.c:4313
+#: config/i386/i386.c:4316
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "Kelvolliset argumentit:"
 
-#: config/i386/i386.c:4379
+#: config/i386/i386.c:4382
 #, fuzzy, gcc-internal-format
 msgid "-mregparm is ignored in 64-bit mode"
 msgstr "64-bittinen ABI ei ole tuettu ESA/390-tilassa"
 
-#: config/i386/i386.c:4381
+#: config/i386/i386.c:4384
 #, gcc-internal-format
 msgid "-mregparm is ignored for Intel MCU psABI"
 msgstr ""
 
-#: config/i386/i386.c:4384
+#: config/i386/i386.c:4387
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "-mregparm=%d is not between 0 and %d"
 msgstr "  uid = %d, gid = %d, oikeudet = 0%o.\n"
 
-#: config/i386/i386.c:4417
+#: config/i386/i386.c:4420
 #, fuzzy, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "64-bittinen ABI ei ole tuettu ESA/390-tilassa"
 
-#: config/i386/i386.c:4418
+#: config/i386/i386.c:4421
 #, fuzzy, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "64-bittinen ABI ei ole tuettu ESA/390-tilassa"
 
-#: config/i386/i386.c:4497
+#: config/i386/i386.c:4500
 #, fuzzy, gcc-internal-format
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: config/i386/i386.c:4500
+#: config/i386/i386.c:4503
 #, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr ""
 
-#: config/i386/i386.c:4523
+#: config/i386/i386.c:4526
 #, gcc-internal-format, gfc-internal-format
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr ""
 
-#: config/i386/i386.c:4536
+#: config/i386/i386.c:4539
 #, fuzzy, gcc-internal-format
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: config/i386/i386.c:4539
+#: config/i386/i386.c:4542
 #, fuzzy, gcc-internal-format
 #| msgid "inter-module optimizations not implemented for C++"
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr "moduulienvälisiä optimointeja ei ole toteutettu C++:lle"
 
-#: config/i386/i386.c:4545
+#: config/i386/i386.c:4548
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386.c:4546
+#: config/i386/i386.c:4549
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386.c:4556
+#: config/i386/i386.c:4559
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr ""
 
-#: config/i386/i386.c:4563
+#: config/i386/i386.c:4566
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr ""
 
-#: config/i386/i386.c:4613
+#: config/i386/i386.c:4616
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr ""
 
-#: config/i386/i386.c:4615
+#: config/i386/i386.c:4618
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr ""
 
-#: config/i386/i386.c:4629
+#: config/i386/i386.c:4632
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr ""
 
-#: config/i386/i386.c:4631
+#: config/i386/i386.c:4634
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr ""
 
-#: config/i386/i386.c:4741
+#: config/i386/i386.c:4744
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr ""
 
-#: config/i386/i386.c:4744
+#: config/i386/i386.c:4747
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr ""
 
-#: config/i386/i386.c:4748
+#: config/i386/i386.c:4751
 #, gcc-internal-format
 msgid "-mcall-ms2sysv-xlogues isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386.c:4813 config/powerpcspe/powerpcspe.c:5663
+#: config/i386/i386.c:4816 config/powerpcspe/powerpcspe.c:5663
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown option for -mrecip=%s"
 msgstr "tuntematon valitsin -%s"
 
-#: config/i386/i386.c:4870 config/powerpcspe/powerpcspe.c:5339
+#: config/i386/i386.c:4873 config/powerpcspe/powerpcspe.c:5339
 #, gcc-internal-format
 msgid "%qs is not a valid number in -mstack-protector-guard-offset="
 msgstr ""
 
-#: config/i386/i386.c:4875 config/powerpcspe/powerpcspe.c:5344
+#: config/i386/i386.c:4878 config/powerpcspe/powerpcspe.c:5344
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid offset in -mstack-protector-guard-offset="
 msgstr "”%s” ei ole kelvollinen esikääntäjän valitsin"
 
-#: config/i386/i386.c:4907 config/powerpcspe/powerpcspe.c:5356
+#: config/i386/i386.c:4910 config/powerpcspe/powerpcspe.c:5356
 #, gcc-internal-format
 msgid "%qs is not a valid base register in -mstack-protector-guard-reg="
 msgstr ""
 
-#: config/i386/i386.c:5506 config/i386/i386.c:5553 config/s390/s390.c:15812
+#: config/i386/i386.c:5509 config/i386/i386.c:5556 config/s390/s390.c:15812
 #: config/s390/s390.c:15862 config/s390/s390.c:15879
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr "kohde ”%s” ei täsmää kohdehahmon kanssa"
 
-#: config/i386/i386.c:5534
+#: config/i386/i386.c:5537
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr "Tämä pikanäppäin on jo käytössä toiminnolle %s"
 
-#: config/i386/i386.c:5837
+#: config/i386/i386.c:5840
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and cdecl attributes are not compatible"
 msgid "interrupt and naked attributes are not compatible"
 msgstr "attribuutit stdcall ja cdecl eivät ole yhteensopivia"
 
-#: config/i386/i386.c:5852
+#: config/i386/i386.c:5855
 #, gcc-internal-format
 msgid "Only DWARF debug format is supported for interrupt service routine."
 msgstr ""
 
-#: config/i386/i386.c:5901
+#: config/i386/i386.c:5904
 #, fuzzy, gcc-internal-format
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "valitsimet -l ja -s eivät ole yhteensopivia"
 
-#: config/i386/i386.c:5913
+#: config/i386/i386.c:5916
 #, gcc-internal-format
 msgid "%<-mindirect-branch=thunk-extern%>, %<-fcf-protection=branch%> and %<-fcheck-pointer-bounds%> are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5949
+#: config/i386/i386.c:5952
 #, fuzzy, gcc-internal-format
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "valitsimet -l ja -s eivät ole yhteensopivia"
 
-#: config/i386/i386.c:6047
+#: config/i386/i386.c:6050
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in %s service routine"
 msgstr ""
 
-#: config/i386/i386.c:6051
+#: config/i386/i386.c:6054
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in function with no_caller_saved_registers attribute"
 msgstr "epäkelpo osoitintila %qs"
 
-#: config/i386/i386.c:6465 config/i386/i386.c:6516
+#: config/i386/i386.c:6468 config/i386/i386.c:6519
 #, fuzzy, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "attribuutit fastcall ja cdecl eivät ole yhteensopivia"
 
-#: config/i386/i386.c:6470
+#: config/i386/i386.c:6473
 #, fuzzy, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "attribuutit fastcall ja stdcall eivät ole yhteensopivia"
 
-#: config/i386/i386.c:6477 config/i386/i386.c:41444
+#: config/i386/i386.c:6480 config/i386/i386.c:41438
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "%qE-attribuutti tarvitsee kokonaislukuvakioargumentin"
 
-#: config/i386/i386.c:6483
+#: config/i386/i386.c:6486
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "%Jei voi asettaa %qE-attribuuttia määrittelyn jälkeen"
 
-#: config/i386/i386.c:6508 config/i386/i386.c:6551
+#: config/i386/i386.c:6511 config/i386/i386.c:6554
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "attribuutit fastcall ja cdecl eivät ole yhteensopivia"
 
-#: config/i386/i386.c:6512
+#: config/i386/i386.c:6515
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "attribuutit fastcall ja stdcall eivät ole yhteensopivia"
 
-#: config/i386/i386.c:6520 config/i386/i386.c:6569
+#: config/i386/i386.c:6523 config/i386/i386.c:6572
 #, fuzzy, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "attribuutit fastcall ja cdecl eivät ole yhteensopivia"
 
-#: config/i386/i386.c:6530 config/i386/i386.c:6547
+#: config/i386/i386.c:6533 config/i386/i386.c:6550
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "attribuutit stdcall ja cdecl eivät ole yhteensopivia"
 
-#: config/i386/i386.c:6534
+#: config/i386/i386.c:6537
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "attribuutit stdcall ja fastcall eivät ole yhteensopivia"
 
-#: config/i386/i386.c:6538 config/i386/i386.c:6565
+#: config/i386/i386.c:6541 config/i386/i386.c:6568
 #, fuzzy, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "attribuutit fastcall ja stdcall eivät ole yhteensopivia"
 
-#: config/i386/i386.c:6555 config/i386/i386.c:6573
+#: config/i386/i386.c:6558 config/i386/i386.c:6576
 #, fuzzy, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "attribuutit fastcall ja cdecl eivät ole yhteensopivia"
 
-#: config/i386/i386.c:6561
+#: config/i386/i386.c:6564
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "%qE-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: config/i386/i386.c:6805
+#: config/i386/i386.c:6808
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:6808
+#: config/i386/i386.c:6811
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:7126
+#: config/i386/i386.c:7129
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support saturating types"
 msgid "X32 does not support ms_abi attribute"
 msgstr "ISO C ei tue saturoituvia tyyppejä"
 
-#: config/i386/i386.c:7160
+#: config/i386/i386.c:7163
 #, gcc-internal-format
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr ""
 
-#: config/i386/i386.c:7502
+#: config/i386/i386.c:7505
 #, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7508
+#: config/i386/i386.c:7511
 #, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7522
+#: config/i386/i386.c:7525
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7528
+#: config/i386/i386.c:7531
 #, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7544
+#: config/i386/i386.c:7547
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7550
+#: config/i386/i386.c:7553
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7566
+#: config/i386/i386.c:7569
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7572
+#: config/i386/i386.c:7575
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7754
+#: config/i386/i386.c:7757
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:7871
+#: config/i386/i386.c:7874
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:7989
+#: config/i386/i386.c:7992
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:8152
+#: config/i386/i386.c:8155
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.c:8158
+#: config/i386/i386.c:8161
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.c:8174
+#: config/i386/i386.c:8177
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr ""
 
-#: config/i386/i386.c:8471 config/i386/i386.c:8750 config/i386/i386.c:9276
+#: config/i386/i386.c:8474 config/i386/i386.c:8753 config/i386/i386.c:9279
 #, gcc-internal-format
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:8473 config/i386/i386.c:8752 config/i386/i386.c:9278
+#: config/i386/i386.c:8476 config/i386/i386.c:8755 config/i386/i386.c:9281
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr ""
 
-#: config/i386/i386.c:9178
+#: config/i386/i386.c:9181
 #, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr ""
 
-#: config/i386/i386.c:11601
+#: config/i386/i386.c:11604
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "-mcall-ms2sysv-xlogues is not compatible with %s"
 msgstr "”%s”-liitännäinen on yhteensopiva."
 
-#: config/i386/i386.c:13593
+#: config/i386/i386.c:13596
 #, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr ""
 
-#: config/i386/i386.c:13683
+#: config/i386/i386.c:13686
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr ""
 
-#: config/i386/i386.c:14970
+#: config/i386/i386.c:14973
 #, fuzzy, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr "ISO C kieltää sisäkkäiset funktiot"
 
-#: config/i386/i386.c:14990
+#: config/i386/i386.c:14993
 #, fuzzy, gcc-internal-format
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
 msgstr "ISO C kieltää sisäkkäiset funktiot"
@@ -31584,204 +31627,204 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:15001
+#: config/i386/i386.c:15004
 #, fuzzy, gcc-internal-format
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr "ISO C90 ei tue joustavia taulukon jäseniä"
 
-#: config/i386/i386.c:17939
+#: config/i386/i386.c:17942
 #, gcc-internal-format
 msgid "'V' modifier on non-integer register"
 msgstr ""
 
-#: config/i386/i386.c:17950 config/i386/i386.c:17964
+#: config/i386/i386.c:17953 config/i386/i386.c:17967
 #, gcc-internal-format
 msgid "unsupported size for integer register"
 msgstr ""
 
-#: config/i386/i386.c:17996
+#: config/i386/i386.c:17999
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr ""
 
-#: config/i386/i386.c:18011
+#: config/i386/i386.c:18014
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr ""
 
-#: config/i386/i386.c:18202
+#: config/i386/i386.c:18205
 #, fuzzy, gcc-internal-format
 msgid "non-integer operand used with operand code 'z'"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/i386/i386.c:28467
+#: config/i386/i386.c:28470
 #, gcc-internal-format
 msgid "interrupt service routine can't be called directly"
 msgstr ""
 
-#: config/i386/i386.c:29995
+#: config/i386/i386.c:29998
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in -fabi-version=12 (GCC 8)"
 msgstr ""
 
-#: config/i386/i386.c:32435
+#: config/i386/i386.c:32438
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr ""
 
-#: config/i386/i386.c:32485
+#: config/i386/i386.c:32488
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for %s"
 msgstr "%s: %s: täsmäävyyttä ei löydy"
 
-#: config/i386/i386.c:32495
+#: config/i386/i386.c:32498
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr ""
 
-#: config/i386/i386.c:32657
+#: config/i386/i386.c:32660
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386.c:32662 config/i386/i386.c:32938
-#: config/rs6000/rs6000.c:37850
+#: config/i386/i386.c:32665 config/i386/i386.c:32941
+#: config/rs6000/rs6000.c:37906
 #, fuzzy, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "Varoita ylikuormitetuista virtuaalifunktioiden nimistä"
 
-#: config/i386/i386.c:32795 config/rs6000/rs6000.c:37607
+#: config/i386/i386.c:32798 config/rs6000/rs6000.c:37663
 #, fuzzy, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "#pragma redefine_extname ei ole tuettu tällä kohteella"
 
-#: config/i386/i386.c:33207
+#: config/i386/i386.c:33210
 #, fuzzy, gcc-internal-format
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr "%<__builtin_prefetch%>-funktion kolmannen argumentin pitää olla vakio"
 
-#: config/i386/i386.c:33232 config/i386/i386.c:33282
+#: config/i386/i386.c:33235 config/i386/i386.c:33285
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Parameter to builtin not valid: %s"
 msgstr "SISÄÄNRAKENNETTU CD %s\n"
 
-#: config/i386/i386.c:33975 config/i386/i386.c:35415
+#: config/i386/i386.c:33978 config/i386/i386.c:35418
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386.c:34370
+#: config/i386/i386.c:34373
 #, fuzzy, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386.c:34465
+#: config/i386/i386.c:34468
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "%<__builtin_prefetch%>-funktion kolmannen argumentin pitää olla vakio"
 
-#: config/i386/i386.c:35346
+#: config/i386/i386.c:35349
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386.c:35361
+#: config/i386/i386.c:35364
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386.c:35394
+#: config/i386/i386.c:35397
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386.c:35434
+#: config/i386/i386.c:35437
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386.c:35447
+#: config/i386/i386.c:35450
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/i386/i386.c:35457
+#: config/i386/i386.c:35460
 #, fuzzy, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386.c:35462 config/i386/i386.c:36249
+#: config/i386/i386.c:35465 config/i386/i386.c:36252
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386.c:35596
+#: config/i386/i386.c:35599
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr "%<__builtin_prefetch%>-funktion kolmannen argumentin pitää olla vakio"
 
-#: config/i386/i386.c:35601
+#: config/i386/i386.c:35604
 #, fuzzy, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr "virheellinen salasana"
 
-#: config/i386/i386.c:35607 config/i386/i386.c:35814
+#: config/i386/i386.c:35610 config/i386/i386.c:35817
 #, fuzzy, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr "virheellinen salasana"
 
-#: config/i386/i386.c:35796
+#: config/i386/i386.c:35799
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386.c:35802
+#: config/i386/i386.c:35805
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/i386/i386.c:35805
+#: config/i386/i386.c:35808
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386.c:36247
+#: config/i386/i386.c:36250
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386.c:36329 config/powerpcspe/powerpcspe.c:16219
-#: config/rs6000/rs6000.c:15304
+#: config/i386/i386.c:36332 config/powerpcspe/powerpcspe.c:16219
+#: config/rs6000/rs6000.c:15348
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr ""
 
-#: config/i386/i386.c:36539
+#: config/i386/i386.c:36542
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr ""
 
-#: config/i386/i386.c:36543
+#: config/i386/i386.c:36546
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr ""
 
-#: config/i386/i386.c:37381
+#: config/i386/i386.c:37375
 #, fuzzy, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "argumentin <%s>:lle on oltava yksittäinen merkki"
 
-#: config/i386/i386.c:38108 config/i386/i386.c:38290
+#: config/i386/i386.c:38102 config/i386/i386.c:38284
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386.c:38343
+#: config/i386/i386.c:38337
 #, fuzzy, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386.c:38349
+#: config/i386/i386.c:38343
 #, fuzzy, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr ""
@@ -31788,109 +31831,109 @@
 "Vihje: %s\n"
 "\n"
 
-#: config/i386/i386.c:38368
+#: config/i386/i386.c:38362
 #, fuzzy, gcc-internal-format
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386.c:41431
+#: config/i386/i386.c:41425
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "%qE-attribuutti pätee vain funktioihin"
 
-#: config/i386/i386.c:41452
+#: config/i386/i386.c:41446
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "näkyvyysargumentti ei ole merkkijono"
 
-#: config/i386/i386.c:41485 config/i386/i386.c:41494
+#: config/i386/i386.c:41479 config/i386/i386.c:41488
 #, gcc-internal-format
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:41530 config/powerpcspe/powerpcspe.c:35868
-#: config/rs6000/rs6000.c:33065
+#: config/i386/i386.c:41524 config/powerpcspe/powerpcspe.c:35868
+#: config/rs6000/rs6000.c:33121
 #, fuzzy, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "%qE-attribuuttia ei huomioida"
 
-#: config/i386/i386.c:41555 config/i386/i386.c:41577 config/ia64/ia64.c:815
+#: config/i386/i386.c:41549 config/i386/i386.c:41571 config/ia64/ia64.c:815
 #: config/s390/s390.c:1153
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "%qE-attribuutti tarvitsee merkkijonovakioargumentin"
 
-#: config/i386/i386.c:41565 config/i386/i386.c:41587 config/s390/s390.c:1182
+#: config/i386/i386.c:41559 config/i386/i386.c:41581 config/s390/s390.c:1182
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "%qE-attribuutti tarvitsee merkkijonovakioargumentin"
 
-#: config/i386/i386.c:41619
+#: config/i386/i386.c:41613
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386.c:41626
+#: config/i386/i386.c:41620
 #, gcc-internal-format, gfc-internal-format
 msgid "interrupt service routine should have unsigned %sint as the second argument"
 msgstr ""
 
-#: config/i386/i386.c:41636
+#: config/i386/i386.c:41630
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386.c:41639
+#: config/i386/i386.c:41633
 #, gcc-internal-format
 msgid "interrupt service routine can't have non-void return value"
 msgstr ""
 
-#: config/i386/i386.c:44676
+#: config/i386/i386.c:44670
 #, fuzzy, gcc-internal-format
 msgid "alternatives not allowed in asm flag output"
 msgstr "taulukon indeksin tyyppi on %<char%>"
 
-#: config/i386/i386.c:44740
+#: config/i386/i386.c:44734
 #, fuzzy, gcc-internal-format
 msgid "unknown asm flag output %qs"
 msgstr "Funktio %qs"
 
-#: config/i386/i386.c:44769
+#: config/i386/i386.c:44763
 #, fuzzy, gcc-internal-format
 msgid "invalid type for asm flag output"
 msgstr "virheellinen lvalue asm-tulosteessa %d"
 
-#: config/i386/i386.c:50634
+#: config/i386/i386.c:50628
 #, fuzzy, gcc-internal-format
 msgid "unknown architecture specific memory model"
 msgstr "Tuntematon arkkitehtuuri ”%s”"
 
-#: config/i386/i386.c:50641
+#: config/i386/i386.c:50635
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50647
+#: config/i386/i386.c:50641
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50671 config/i386/i386.c:50787
+#: config/i386/i386.c:50665 config/i386/i386.c:50781
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unsupported simdlen %d"
 msgstr "tuntematon värimoodi"
 
-#: config/i386/i386.c:50690
+#: config/i386/i386.c:50684
 #, fuzzy, gcc-internal-format
 msgid "unsupported return type %qT for simd"
 msgstr "%<operator delete%>:n on palautettava tyyppi %qT"
 
-#: config/i386/i386.c:50712
+#: config/i386/i386.c:50706
 #, fuzzy, gcc-internal-format
 msgid "unsupported argument type %qT for simd"
 msgstr "odotettiin %qT, mutta argumentti on tyyppiä %qT"
 
-#: config/i386/i386.c:51033
+#: config/i386/i386.c:51027
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr ""
@@ -32113,7 +32156,7 @@
 msgstr ""
 
 #: config/m68k/m68k.c:1128 config/powerpcspe/powerpcspe.c:28512
-#: config/rs6000/rs6000.c:25791
+#: config/rs6000/rs6000.c:25868
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr ""
@@ -32695,62 +32738,62 @@
 
 #. Trampoline is not supported on reduced-set registers yet.
 #: config/nds32/nds32.c:2327 config/nds32/nds32.c:2381
-#: config/nds32/nds32.c:3127 config/nds32/nds32.c:3201
-#: config/nds32/nds32.c:3216 config/nds32/nds32.c:3222
-#: config/nds32/nds32.c:3284 config/nds32/nds32.c:3290
-#: config/nds32/nds32.c:3322
+#: config/nds32/nds32.c:3128 config/nds32/nds32.c:3202
+#: config/nds32/nds32.c:3217 config/nds32/nds32.c:3223
+#: config/nds32/nds32.c:3285 config/nds32/nds32.c:3291
+#: config/nds32/nds32.c:3323
 #, fuzzy, gcc-internal-format
 msgid "a nested function is not supported for reduced registers"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
 #. The enum index value for array size is out of range.
-#: config/nds32/nds32.c:3025
+#: config/nds32/nds32.c:3026
 #, gcc-internal-format
 msgid "intrinsic register index is out of range"
 msgstr ""
 
-#: config/nds32/nds32.c:3041 config/nds32/nds32.c:3048
-#: config/nds32/nds32.c:3055 config/nds32/nds32.c:3062
-#: config/nds32/nds32.c:3069
+#: config/nds32/nds32.c:3042 config/nds32/nds32.c:3049
+#: config/nds32/nds32.c:3056 config/nds32/nds32.c:3063
+#: config/nds32/nds32.c:3070
 #, gcc-internal-format
 msgid "CCTL intrinsic function subtype out of range!"
 msgstr ""
 
-#: config/nds32/nds32.c:3508
+#: config/nds32/nds32.c:3509
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type for iteration variable %qE"
 msgid "invalid id value for interrupt/exception attribute"
 msgstr "virheellinen tyyppi iterointimuuttujalle %qE"
 
-#: config/nds32/nds32.c:3536
+#: config/nds32/nds32.c:3537
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "invalid id value for reset attribute"
 msgstr "%qs-attribuutin virheellinen argumentti"
 
-#: config/nds32/nds32.c:3552
+#: config/nds32/nds32.c:3553
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "invalid nmi function for reset attribute"
 msgstr "%qs-attribuutin virheellinen argumentti"
 
-#: config/nds32/nds32.c:3565
+#: config/nds32/nds32.c:3566
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "invalid warm function for reset attribute"
 msgstr "%qs-attribuutin virheellinen argumentti"
 
-#: config/nds32/nds32.c:3638
+#: config/nds32/nds32.c:3639
 #, gcc-internal-format
 msgid "Disable FPU ISA, the ABI option must be enable '-mfloat-abi=soft'"
 msgstr ""
 
-#: config/nds32/nds32.c:3641
+#: config/nds32/nds32.c:3642
 #, gcc-internal-format
 msgid "'-mabi=2fp+' option only support when FPU available, must be enable '-mext-fpu-sp' or '-mext-fpu-dp'"
 msgstr ""
 
-#: config/nds32/nds32.c:3647
+#: config/nds32/nds32.c:3648
 #, fuzzy, gcc-internal-format
 msgid "position-independent code not supported"
 msgstr "parametrilla %P on vaillinainen tyyppi %qT"
@@ -33088,12 +33131,12 @@
 msgid "junk at end of #pragma longcall"
 msgstr "roskaa ilmaisun %<#pragma pack%> lopussa"
 
-#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6154
+#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6152
 #, gcc-internal-format
 msgid "vec_lvsl is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6158
+#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6156
 #, gcc-internal-format
 msgid "vec_lvsr is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
@@ -33143,7 +33186,7 @@
 msgid "vec_insert only accepts 3 arguments"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6868
+#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6866
 #, fuzzy, gcc-internal-format
 msgid "passing arg %d of %qE discards qualifiers from pointer target type"
 msgstr "sijoitus hylkää kohdeosoitintyypin määreitä"
@@ -33228,7 +33271,7 @@
 msgid "target attribute or pragma changes SPE ABI"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4351 config/rs6000/rs6000.c:4223
+#: config/powerpcspe/powerpcspe.c:4351 config/rs6000/rs6000.c:4243
 #, fuzzy, gcc-internal-format
 msgid "AltiVec not supported in this target"
 msgstr "-mvsx ja -mno-altivec ovat yhteensopimattomat"
@@ -33388,7 +33431,7 @@
 msgid "-mvsx-small-integer requires -mpower8-vector, -mupper-regs-di, and -mdirect-move"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4959 config/rs6000/rs6000.c:4601
+#: config/powerpcspe/powerpcspe.c:4959 config/rs6000/rs6000.c:4628
 #, gcc-internal-format
 msgid "target attribute or pragma changes long double size"
 msgstr ""
@@ -33429,22 +33472,22 @@
 msgstr ""
 
 #: config/powerpcspe/powerpcspe.c:5140 config/powerpcspe/powerpcspe.c:5155
-#: config/rs6000/rs6000.c:4766 config/rs6000/rs6000.c:4781
+#: config/rs6000/rs6000.c:4791 config/rs6000/rs6000.c:4806
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:5168 config/rs6000/rs6000.c:4794
+#: config/powerpcspe/powerpcspe.c:5168 config/rs6000/rs6000.c:4819
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:5234 config/rs6000/rs6000.c:4828
+#: config/powerpcspe/powerpcspe.c:5234 config/rs6000/rs6000.c:4853
 #, gcc-internal-format
 msgid "target attribute or pragma changes single precision floating point"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:5237 config/rs6000/rs6000.c:4831
+#: config/powerpcspe/powerpcspe.c:5237 config/rs6000/rs6000.c:4856
 #, gcc-internal-format
 msgid "target attribute or pragma changes double precision floating point"
 msgstr ""
@@ -33454,12 +33497,12 @@
 msgid "-mstack-protector-guard=tls needs a valid base register"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:8415 config/rs6000/rs6000.c:7925
+#: config/powerpcspe/powerpcspe.c:8415 config/rs6000/rs6000.c:7950
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11237
+#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11269
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
@@ -33469,7 +33512,7 @@
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11595
+#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11633
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr ""
@@ -33479,12 +33522,12 @@
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12604
+#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12648
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12779
+#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12823
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
@@ -33494,29 +33537,29 @@
 msgid "internal error: builtin function %s already processed"
 msgstr "sisäistä funktiota %qs ei voi ottaa pois käytöstä"
 
-#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:13971
+#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:14015
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "argument 1 must be an 8-bit field value"
 msgstr "argumentin 1 on oltava 5-bittinen etumerkillinen literaali"
 
-#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14015
+#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14059
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "argumentin 1 on oltava 5-bittinen etumerkillinen literaali"
 
 #: config/powerpcspe/powerpcspe.c:14934 config/powerpcspe/powerpcspe.c:16803
-#: config/rs6000/rs6000.c:14101
+#: config/rs6000/rs6000.c:14145
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14119
+#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14163
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14135
+#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14179
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 7-bit unsigned literal"
@@ -33537,13 +33580,13 @@
 msgid "builtin %s is only valid in 64-bit mode"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14791
+#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14835
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument %d must be an unsigned literal"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14793
+#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14837
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "%<__builtin_args_info%>-funktion argumentti on rajojen ulkopuolella"
@@ -33565,54 +33608,54 @@
 msgid "hwcap %s is an invalid argument to builtin %s"
 msgstr "kokonaislukuargumentti %s ei kelpaa"
 
-#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15065
+#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15109
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15090
+#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15134
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15110
+#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15154
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15122
+#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15166
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be 0 or 2"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15134
+#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15178
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15148
+#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15192
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15160
+#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15204
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be 0 or 1"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15168
+#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15212
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be in the range 0..15"
 msgstr "kohdistuksen pitää olla kahden potenssi, ei %d"
 
-#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15237
-#: config/rs6000/rs6000.c:15569
+#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15281
+#: config/rs6000/rs6000.c:15613
 #, fuzzy, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15394
+#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15438
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr ""
@@ -33738,7 +33781,7 @@
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25758
+#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25835
 #, fuzzy, gcc-internal-format
 msgid "stack frame too large"
 msgstr "pinokehys ei ole 8:n tavun monikerta: %wd"
@@ -33748,12 +33791,12 @@
 msgid "-fsplit-stack uses register r29"
 msgstr "ISO C90 ei tue joustavia taulukon jäseniä"
 
-#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29459
+#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29536
 #, fuzzy, gcc-internal-format
 msgid "Stack frame larger than 2G is not supported for -fsplit-stack"
 msgstr "#pragma extern_prefix ei ole tuettu tällä kohteella"
 
-#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30447
+#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30524
 #, fuzzy, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "64-bittinen ABI ei ole tuettu ESA/390-tilassa"
@@ -33763,22 +33806,22 @@
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32830
+#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32907
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32832
+#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32909
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32834
+#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32911
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32836
+#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32913
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr ""
@@ -33788,7 +33831,7 @@
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32845
+#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32922
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr ""
@@ -34332,73 +34375,73 @@
 "Please use an explicit cpu name.  Valid cpu names are: %s"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6168 config/rs6000/rs6000-c.c:6219
-#: config/rs6000/rs6000-c.c:6489 config/rs6000/rs6000-c.c:6555
-#: config/rs6000/rs6000-c.c:6916 config/rs6000/rs6000-c.c:6963
+#: config/rs6000/rs6000-c.c:6166 config/rs6000/rs6000-c.c:6217
+#: config/rs6000/rs6000-c.c:6487 config/rs6000/rs6000-c.c:6553
+#: config/rs6000/rs6000-c.c:6914 config/rs6000/rs6000-c.c:6961
 #, fuzzy, gcc-internal-format
 msgid "builtin %qs only accepts 2 arguments"
 msgstr "%J%qD sallii vain nolla tai kaksi argumenttia"
 
-#: config/rs6000/rs6000-c.c:6292 config/rs6000/rs6000-c.c:6375
-#: config/rs6000/rs6000-c.c:6736
+#: config/rs6000/rs6000-c.c:6290 config/rs6000/rs6000-c.c:6373
+#: config/rs6000/rs6000-c.c:6734
 #, fuzzy, gcc-internal-format
 msgid "builtin %qs only accepts 3 arguments"
 msgstr "%J%qD sallii vain nolla tai kaksi argumenttia"
 
-#: config/rs6000/rs6000-c.c:6484
+#: config/rs6000/rs6000-c.c:6482
 #, fuzzy, gcc-internal-format
 msgid "builtin %qs only accepts 1 argument"
 msgstr "%J%qD sallii vain nolla tai kaksi argumenttia"
 
-#: config/rs6000/rs6000-c.c:7054
+#: config/rs6000/rs6000-c.c:7052
 #, fuzzy, gcc-internal-format
 msgid "builtin %qs requires builtin %qs"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
 
-#: config/rs6000/rs6000-c.c:7058
+#: config/rs6000/rs6000-c.c:7056
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs not supported in this compiler configuration"
 msgstr "weakref ei ole tuettu tässä konfiguraatiossa"
 
-#: config/rs6000/rs6000-c.c:7068
+#: config/rs6000/rs6000-c.c:7066
 #, fuzzy, gcc-internal-format
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr "virheellinen parametri %qs"
 
-#: config/rs6000/rs6000.c:3754 config/rs6000/rs6000.c:3757
-#: config/rs6000/rs6000.c:3760
+#: config/rs6000/rs6000.c:3772 config/rs6000/rs6000.c:3775
+#: config/rs6000/rs6000.c:3778
 #, fuzzy, gcc-internal-format
 msgid "%qs requires %qs or %qs"
 msgstr "%qs määritelty parametrille %qE"
 
-#: config/rs6000/rs6000.c:3861
+#: config/rs6000/rs6000.c:3879
 #, fuzzy, gcc-internal-format
 #| msgid "-m64 requires PowerPC64 architecture, enabling"
 msgid "%qs requires PowerPC64 architecture, enabling"
 msgstr "-m64 vaatii PowerPC64-suorittimen, otetaan käyttöön"
 
-#: config/rs6000/rs6000.c:4037
+#: config/rs6000/rs6000.c:4057
 #, gcc-internal-format
 msgid "%qs command-line option is deprecated"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4048
+#: config/rs6000/rs6000.c:4068
 #, gcc-internal-format
 msgid "%qs is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4147
+#: config/rs6000/rs6000.c:4167
 #, gcc-internal-format
 msgid "will not generate %qs instructions because assembler lacks %qs support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4240
+#: config/rs6000/rs6000.c:4260
 #, fuzzy, gcc-internal-format
 #| msgid "-mstring is not supported on little endian systems"
 msgid "%qs is not supported on little endian systems"
 msgstr "valitsin -mstring ei ole tuettu little-endian-järjestelmissä"
 
-#: config/rs6000/rs6000.c:4333
+#: config/rs6000/rs6000.c:4353
 #, gcc-internal-format
 msgid "power9 target option is incompatible with %<%s=<xxx>%> for <xxx> less than power9"
 msgstr ""
@@ -34405,7 +34448,7 @@
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:4341
+#: config/rs6000/rs6000.c:4361
 #, fuzzy, gcc-internal-format
 msgid "%qs incompatible with explicitly disabled options"
 msgstr "%s %qs"
@@ -34414,244 +34457,245 @@
 #. error messages.  However, if users have managed to select
 #. power9-fusion without selecting power8-fusion, they
 #. already know about undocumented flags.
-#: config/rs6000/rs6000.c:4366 config/rs6000/rs6000.c:4373
-#: config/rs6000/rs6000.c:4380 config/rs6000/rs6000.c:4388
-#: config/rs6000/rs6000.c:4407 config/rs6000/rs6000.c:4464
-#: config/rs6000/rs6000.c:4468 config/rs6000/rs6000.c:4485
-#: config/rs6000/rs6000.c:4538 config/rs6000/rs6000.c:4565
-#: config/rs6000/rs6000.c:4580 config/rs6000/rs6000.c:4588
-#: config/rs6000/rs6000.c:4684
+#: config/rs6000/rs6000.c:4386 config/rs6000/rs6000.c:4393
+#: config/rs6000/rs6000.c:4400 config/rs6000/rs6000.c:4408
+#: config/rs6000/rs6000.c:4427 config/rs6000/rs6000.c:4484
+#: config/rs6000/rs6000.c:4488 config/rs6000/rs6000.c:4505
+#: config/rs6000/rs6000.c:4558 config/rs6000/rs6000.c:4585
+#: config/rs6000/rs6000.c:4600 config/rs6000/rs6000.c:4608
+#: config/rs6000/rs6000.c:4709
 #, gcc-internal-format
 msgid "%qs requires %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4625
+#: config/rs6000/rs6000.c:4650
 #, gcc-internal-format
 msgid "Using IEEE extended precision long double"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4627
+#: config/rs6000/rs6000.c:4652
 #, gcc-internal-format
 msgid "Using IBM extended precision long double"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4644
+#: config/rs6000/rs6000.c:4669
 #, fuzzy, gcc-internal-format
 msgid "%qs requires VSX support"
 msgstr "%s ei tue muotoilua %<%%%c%> %s"
 
-#: config/rs6000/rs6000.c:4653
+#: config/rs6000/rs6000.c:4678
 #, gcc-internal-format
 msgid "The -mfloat128 option may not be fully supported"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4676
+#: config/rs6000/rs6000.c:4701
 #, gcc-internal-format
 msgid "%qs requires full ISA 3.0 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4743
+#: config/rs6000/rs6000.c:4768
 #, gcc-internal-format
 msgid "unknown vectorization library ABI type (%qs) for %qs switch"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4930
+#: config/rs6000/rs6000.c:4955
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr "Funktio %qs"
 
-#: config/rs6000/rs6000.c:4935
+#: config/rs6000/rs6000.c:4960
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr "Funktio %qs"
 
-#: config/rs6000/rs6000.c:4947
+#: config/rs6000/rs6000.c:4972
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid base register in %qs"
 msgstr "luokkanimeä ei ole annettu %qs:n kanssa"
 
-#: config/rs6000/rs6000.c:4955
+#: config/rs6000/rs6000.c:4980
 #, fuzzy, gcc-internal-format
 msgid "%qs needs a valid base register"
 msgstr "luokkanimeä ei ole annettu %qs:n kanssa"
 
-#: config/rs6000/rs6000.c:5253
+#: config/rs6000/rs6000.c:5278
 #, fuzzy, gcc-internal-format
 msgid "unknown option for %<%s=%s%>"
 msgstr "tuntematon valitsin -%s"
 
-#: config/rs6000/rs6000.c:5290
+#: config/rs6000/rs6000.c:5315
 #, fuzzy, gcc-internal-format
 #| msgid "Deprecated.  This switch has no effect"
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr "Vanhentunut. Tämä valitsin ei vaikuta mihinkään"
 
-#: config/rs6000/rs6000.c:11401
+#: config/rs6000/rs6000.c:11439
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11862
+#: config/rs6000/rs6000.c:11906
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13572
+#: config/rs6000/rs6000.c:13616
 #, fuzzy, gcc-internal-format
 msgid "internal error: builtin function %qs already processed"
 msgstr "sisäistä funktiota %qs ei voi ottaa pois käytöstä"
 
-#: config/rs6000/rs6000.c:14150
+#: config/rs6000/rs6000.c:14194
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 1-bit unsigned literal"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/rs6000/rs6000.c:14189
+#: config/rs6000/rs6000.c:14233
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qs must be a constant"
 msgstr "annettu yhteensopimatonta osoitintyyppiä oleva %d. argumentti funktiolle %qE"
 
-#: config/rs6000/rs6000.c:14247 config/rs6000/rs6000.c:15898
+#: config/rs6000/rs6000.c:14291 config/rs6000/rs6000.c:15942
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %<__builtin_args_info%> out of range"
 msgid "argument 1 of %qs is out of range"
 msgstr "%<__builtin_args_info%>-funktion argumentti on rajojen ulkopuolella"
 
-#: config/rs6000/rs6000.c:14742
+#: config/rs6000/rs6000.c:14786
 #, gcc-internal-format
 msgid "builtin %qs is only valid in 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14939
+#: config/rs6000/rs6000.c:14983
 #, fuzzy, gcc-internal-format
 msgid "builtin %qs only accepts a string argument"
 msgstr "%J%qD sallii vain nolla tai kaksi argumenttia"
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000.c:14958
+#: config/rs6000/rs6000.c:15002
 #, fuzzy, gcc-internal-format
 msgid "cpu %qs is an invalid argument to builtin %qs"
 msgstr "kokonaislukuargumentti %s ei kelpaa"
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000.c:14986
+#: config/rs6000/rs6000.c:15030
 #, fuzzy, gcc-internal-format
 msgid "%s %qs is an invalid argument to builtin %qs"
 msgstr "kokonaislukuargumentti %s ei kelpaa"
 
-#: config/rs6000/rs6000.c:15012
+#: config/rs6000/rs6000.c:15056
 #, gcc-internal-format
 msgid "builtin %qs needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15616
+#: config/rs6000/rs6000.c:15660
 #, fuzzy, gcc-internal-format
 msgid "second argument to %qs must be 0..12"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/rs6000/rs6000.c:15631
+#: config/rs6000/rs6000.c:15675
 #, fuzzy, gcc-internal-format
 msgid "third argument to %qs must be 0..12"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/rs6000/rs6000.c:15850
+#: config/rs6000/rs6000.c:15894
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument 1 of %s must be a constant"
 msgstr "annettu yhteensopimatonta osoitintyyppiä oleva %d. argumentti funktiolle %qE"
 
-#: config/rs6000/rs6000.c:15932
+#: config/rs6000/rs6000.c:15976
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs is only valid for the cell processor"
 msgstr "#pragma redefine_extname ei ole tuettu tällä kohteella"
 
-#: config/rs6000/rs6000.c:15934 config/rs6000/rs6000.c:15936
-#: config/rs6000/rs6000.c:15938 config/rs6000/rs6000.c:15940
-#: config/rs6000/rs6000.c:15946 config/rs6000/rs6000.c:15948
-#: config/rs6000/rs6000.c:15955 config/rs6000/rs6000.c:15962
-#: config/rs6000/rs6000.c:15969 config/rs6000/rs6000.c:15975
+#: config/rs6000/rs6000.c:15978 config/rs6000/rs6000.c:15980
+#: config/rs6000/rs6000.c:15982 config/rs6000/rs6000.c:15984
+#: config/rs6000/rs6000.c:15990 config/rs6000/rs6000.c:15992
+#: config/rs6000/rs6000.c:15999 config/rs6000/rs6000.c:16006
+#: config/rs6000/rs6000.c:16011 config/rs6000/rs6000.c:16014
+#: config/rs6000/rs6000.c:16018 config/rs6000/rs6000.c:16024
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs requires the %qs option"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
 
-#: config/rs6000/rs6000.c:15943 config/rs6000/rs6000.c:15952
-#: config/rs6000/rs6000.c:15959 config/rs6000/rs6000.c:15966
+#: config/rs6000/rs6000.c:15987 config/rs6000/rs6000.c:15996
+#: config/rs6000/rs6000.c:16003
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs requires the %qs and %qs options"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
 
-#: config/rs6000/rs6000.c:15972
+#: config/rs6000/rs6000.c:16021
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs requires ISA 3.0 IEEE 128-bit floating point"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
 
-#: config/rs6000/rs6000.c:15978
+#: config/rs6000/rs6000.c:16027
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs requires the %qs (or newer), and %qs or %qs options"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
 
-#: config/rs6000/rs6000.c:15982
+#: config/rs6000/rs6000.c:16031
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs is not supported with the current options"
 msgstr "#pragma redefine_extname ei ole tuettu tällä kohteella"
 
-#: config/rs6000/rs6000.c:18218
+#: config/rs6000/rs6000.c:18290
 #, fuzzy, gcc-internal-format
 msgid "internal error: builtin function %qs had an unexpected return type %qs"
 msgstr "sisäistä funktiota %qs ei voi ottaa pois käytöstä"
 
-#: config/rs6000/rs6000.c:18235
+#: config/rs6000/rs6000.c:18307
 #, fuzzy, gcc-internal-format
 msgid "internal error: builtin function %qs, argument %d had unexpected argument type %qs"
 msgstr "sisäistä funktiota %qs ei voi ottaa pois käytöstä"
 
-#: config/rs6000/rs6000.c:29451
+#: config/rs6000/rs6000.c:29528
 #, fuzzy, gcc-internal-format
 msgid "%qs uses register r29"
 msgstr "ISO C90 ei tue joustavia taulukon jäseniä"
 
-#: config/rs6000/rs6000.c:32748
+#: config/rs6000/rs6000.c:32825
 #, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32842
+#: config/rs6000/rs6000.c:32919
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32850
+#: config/rs6000/rs6000.c:32927
 #, fuzzy, gcc-internal-format
 #| msgid "%<long long%> invalid for %qs"
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "%<long long%> virheellinen %qs:lle"
 
-#: config/rs6000/rs6000.c:32853
+#: config/rs6000/rs6000.c:32930
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:36876
+#: config/rs6000/rs6000.c:36932
 #, fuzzy, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "virheellinen argumentti %s %s:lle"
 
-#: config/rs6000/rs6000.c:36879
+#: config/rs6000/rs6000.c:36935
 #, fuzzy, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr "tyhjä %s ei ole sallittu"
 
-#: config/rs6000/rs6000.c:36881
+#: config/rs6000/rs6000.c:36937
 #, fuzzy, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr "virheellinen argumentti %s %s:lle"
 
-#: config/rs6000/rs6000.c:37416
+#: config/rs6000/rs6000.c:37472
 #, fuzzy, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr "valitsin -mcpu=%s on ristiriidassa valitsimen -march=%s kanssa"
 
-#: config/rs6000/rs6000.c:37575
+#: config/rs6000/rs6000.c:37631
 #, gcc-internal-format
 msgid "target_clones attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
@@ -35394,49 +35438,49 @@
 msgid "subprogram %q+F not marked Inline"
 msgstr ""
 
-#: ada/gcc-interface/trans.c:6404
+#: ada/gcc-interface/trans.c:6401
 #, gcc-internal-format
 msgid "out-of-bounds access may be optimized away"
 msgstr ""
 
-#: ada/gcc-interface/trans.c:6406
+#: ada/gcc-interface/trans.c:6403
 #, fuzzy, gcc-internal-format
 msgid "containing loop"
 msgstr "continue-lause silmukan ulkopuolella"
 
-#: ada/gcc-interface/utils.c:3887
+#: ada/gcc-interface/utils.c:3890
 #, gcc-internal-format
 msgid "invalid element type for attribute %qs"
 msgstr "epäkelpo alkiotyyppi attribuutille %qs"
 
-#: ada/gcc-interface/utils.c:3911
+#: ada/gcc-interface/utils.c:3914
 #, fuzzy, gcc-internal-format
 #| msgid "number of components of the vector not a power of two"
 msgid "number of components of vector not a power of two"
 msgstr "vektorin komponenttien määrä ei ole kahden potenssi"
 
-#: ada/gcc-interface/utils.c:6037 ada/gcc-interface/utils.c:6215
-#: ada/gcc-interface/utils.c:6322
+#: ada/gcc-interface/utils.c:6043 ada/gcc-interface/utils.c:6220
+#: ada/gcc-interface/utils.c:6327
 #, gcc-internal-format
 msgid "%qs attribute ignored"
 msgstr "%qs attribuuttia ei huomioida"
 
-#: ada/gcc-interface/utils.c:6158
+#: ada/gcc-interface/utils.c:6164
 #, fuzzy, gcc-internal-format
 msgid "%qs attribute requires prototypes with named arguments"
 msgstr "%qE-attribuutti tarvitsee prototyyppejä, joilla nimettyjä argumentteja"
 
-#: ada/gcc-interface/utils.c:6167
+#: ada/gcc-interface/utils.c:6173
 #, fuzzy, gcc-internal-format
 msgid "%qs attribute only applies to variadic functions"
 msgstr "%qE-attribuutti soveltuu vain variadisiin funktioihin"
 
-#: ada/gcc-interface/utils.c:6282
+#: ada/gcc-interface/utils.c:6287
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute has no effect"
 msgstr "%qE-attribuuttia ei huomioida %qE:lle"
 
-#: ada/gcc-interface/utils.c:6406
+#: ada/gcc-interface/utils.c:6411
 #, gcc-internal-format
 msgid "attribute %qs applies to array types only"
 msgstr "attribuutti %qs soveltuu vain taulukkotyyppeihin"
@@ -35451,7 +35495,7 @@
 #. an unprototyped function, it is compile-time undefined;
 #. making it a constraint in that case was rejected in
 #. DR#252.
-#: c/c-convert.c:101 c/c-typeck.c:2175 c/c-typeck.c:6507 c/c-typeck.c:12138
+#: c/c-convert.c:101 c/c-typeck.c:2175 c/c-typeck.c:6512 c/c-typeck.c:12143
 #: cp/typeck.c:2027 cp/typeck.c:7977 cp/typeck.c:8742
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
@@ -35512,7 +35556,7 @@
 msgid "type of array %q+D completed incompatibly with implicit initialization"
 msgstr "%Jtaulukon %qD tyyppi viimeistelty epäkelvosti implisiittisellä alustuksella"
 
-#: c/c-decl.c:1567 c/c-decl.c:6701 c/c-decl.c:7574 c/c-decl.c:8381
+#: c/c-decl.c:1567 c/c-decl.c:6721 c/c-decl.c:7594 c/c-decl.c:8401
 #, gcc-internal-format
 msgid "originally defined here"
 msgstr "alunperin määritelty täällä"
@@ -35923,16 +35967,11 @@
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.c:4548 c/c-decl.c:7147
+#: c/c-decl.c:4548 c/c-decl.c:7167
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr ""
 
-#: c/c-decl.c:4635 cp/decl2.c:1520
-#, gcc-internal-format
-msgid "%q+D in declare target directive does not have mappable type"
-msgstr ""
-
 #: c/c-decl.c:4693
 #, gcc-internal-format
 msgid "%q+D is usually a function"
@@ -35958,7 +35997,7 @@
 #. of VLAs themselves count as VLAs, it does not make
 #. sense to permit them to be initialized given that
 #. ordinary VLAs may not be initialized.
-#: c/c-decl.c:4732 c/c-decl.c:4747 c/c-typeck.c:7630
+#: c/c-decl.c:4732 c/c-decl.c:4747 c/c-typeck.c:7635
 #, gcc-internal-format
 msgid "variable-sized object may not be initialized"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
@@ -36018,205 +36057,210 @@
 msgid "uninitialized const %qD is invalid in C++"
 msgstr "alustamaton vakio %qD on virheellinen C++-kielessä"
 
-#: c/c-decl.c:5268
+#: c/c-decl.c:5224 cp/decl.c:7318
 #, gcc-internal-format
+msgid "%q+D in declare target directive does not have mappable type"
+msgstr ""
+
+#: c/c-decl.c:5288
+#, gcc-internal-format
 msgid "ISO C forbids forward parameter declarations"
 msgstr "ISO C kieltää parametrien ennakkoesittelyn"
 
-#: c/c-decl.c:5371
+#: c/c-decl.c:5391
 #, fuzzy, gcc-internal-format
 msgid "defining a type in a compound literal is invalid in C++"
 msgstr "tyypin määritteleminen tyyppimuunnoksessa on virheellistä C++-kielessä"
 
-#: c/c-decl.c:5425 c/c-decl.c:5440
+#: c/c-decl.c:5445 c/c-decl.c:5460
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant"
 msgstr "bittikentän %qs leveys ei ole kokonaislukuvakio"
 
-#: c/c-decl.c:5435
+#: c/c-decl.c:5455
 #, fuzzy, gcc-internal-format
 msgid "bit-field %qs width not an integer constant expression"
 msgstr "bittikentän %qs leveys ei ole kokonaislukuvakio"
 
-#: c/c-decl.c:5446
+#: c/c-decl.c:5466
 #, gcc-internal-format
 msgid "negative width in bit-field %qs"
 msgstr "bittikentän %qs leveys on negatiivinen"
 
-#: c/c-decl.c:5451
+#: c/c-decl.c:5471
 #, gcc-internal-format
 msgid "zero width for bit-field %qs"
 msgstr "bittikentän %qs leveys on nolla"
 
-#: c/c-decl.c:5461
+#: c/c-decl.c:5481
 #, gcc-internal-format
 msgid "bit-field %qs has invalid type"
 msgstr "bittikentällä %qs on epäkelpo tyyppi"
 
-#: c/c-decl.c:5467
+#: c/c-decl.c:5487
 #, fuzzy, gcc-internal-format
 msgid "cannot declare bit-field %qs with %<warn_if_not_aligned%> type"
 msgstr "bittikentän %qD osoitetta ei voi ottaa"
 
-#: c/c-decl.c:5478
+#: c/c-decl.c:5498
 #, gcc-internal-format
 msgid "type of bit-field %qs is a GCC extension"
 msgstr "bittikentän %qs tyyppi on GCC-laajennos"
 
-#: c/c-decl.c:5484
+#: c/c-decl.c:5504
 #, gcc-internal-format
 msgid "width of %qs exceeds its type"
 msgstr "bittikentän %qs leveys ylittää tyyppinsä"
 
-#: c/c-decl.c:5497
+#: c/c-decl.c:5517
 #, gcc-internal-format
 msgid "%qs is narrower than values of its type"
 msgstr "%qs on kapeampi kuin tyyppisensä arvot"
 
-#: c/c-decl.c:5512
+#: c/c-decl.c:5532
 #, gcc-internal-format
 msgid "ISO C90 forbids array %qE whose size can%'t be evaluated"
 msgstr "ISO C90 kieltää taulukon %qE, jonka kokoa ei voida määrittää"
 
-#: c/c-decl.c:5515
+#: c/c-decl.c:5535
 #, gcc-internal-format
 msgid "ISO C90 forbids array whose size can%'t be evaluated"
 msgstr "ISO C90 kieltää taulukot, joiden kokoa ei voida määrittää"
 
-#: c/c-decl.c:5522
+#: c/c-decl.c:5542
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array %qE"
 msgstr "ISO C90 kieltää muuttuvakokoisen taulukon %qE"
 
-#: c/c-decl.c:5524
+#: c/c-decl.c:5544
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array"
 msgstr "ISO C90 kieltää muuttuvakokoisen taulukon"
 
-#: c/c-decl.c:5733 c/c-decl.c:6107 c/c-decl.c:6117
+#: c/c-decl.c:5753 c/c-decl.c:6127 c/c-decl.c:6137
 #, fuzzy, gcc-internal-format
 msgid "variably modified %qE at file scope"
 msgstr "muuttuja tai kenttä %qs esitelty tyhjäksi"
 
-#: c/c-decl.c:5735
+#: c/c-decl.c:5755
 #, fuzzy, gcc-internal-format
 msgid "variably modified field at file scope"
 msgstr "muuttuja tai kenttä %qs esitelty tyhjäksi"
 
-#: c/c-decl.c:5755
+#: c/c-decl.c:5775
 #, gcc-internal-format
 msgid "type defaults to %<int%> in declaration of %qE"
 msgstr "%qE:n esittelyssä tyyppi on oletuksena %<int%>"
 
-#: c/c-decl.c:5759
+#: c/c-decl.c:5779
 #, gcc-internal-format
 msgid "type defaults to %<int%> in type name"
 msgstr "tyypin nimessä tyyppi on oletuksena %<int%>"
 
 # XXX
-#: c/c-decl.c:5791
+#: c/c-decl.c:5811
 #, gcc-internal-format
 msgid "duplicate %<const%>"
 msgstr "ylimääräinen %<const%>"
 
-#: c/c-decl.c:5793
+#: c/c-decl.c:5813
 #, gcc-internal-format
 msgid "duplicate %<restrict%>"
 msgstr "ylimääräinen %<restrict%>"
 
-#: c/c-decl.c:5795
+#: c/c-decl.c:5815
 #, gcc-internal-format
 msgid "duplicate %<volatile%>"
 msgstr "ylimääräinen %<volatile%>"
 
-#: c/c-decl.c:5797
+#: c/c-decl.c:5817
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<restrict%>"
 msgid "duplicate %<_Atomic%>"
 msgstr "ylimääräinen %<const%>"
 
-#: c/c-decl.c:5800
+#: c/c-decl.c:5820
 #, gcc-internal-format, gfc-internal-format
 msgid "conflicting named address spaces (%s vs %s)"
 msgstr ""
 
-#: c/c-decl.c:5823 c/c-parser.c:2821
+#: c/c-decl.c:5843 c/c-parser.c:2821
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%>-qualified array type"
 msgstr "tyyppitäsmäämättömyys taulukkoviitteessä"
 
-#: c/c-decl.c:5837
+#: c/c-decl.c:5857
 #, gcc-internal-format
 msgid "function definition declared %<auto%>"
 msgstr "funktion määrittely esitelty %<auto%>:ksi"
 
-#: c/c-decl.c:5839
+#: c/c-decl.c:5859
 #, gcc-internal-format
 msgid "function definition declared %<register%>"
 msgstr "funktion määrittely esitelty %<register%>:ksi"
 
-#: c/c-decl.c:5841
+#: c/c-decl.c:5861
 #, gcc-internal-format
 msgid "function definition declared %<typedef%>"
 msgstr "funktion määrittely esitelty %<typedef%>:ksi"
 
-#: c/c-decl.c:5843
+#: c/c-decl.c:5863
 #, fuzzy, gcc-internal-format
 #| msgid "function definition declared %<auto%>"
 msgid "function definition declared %qs"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: c/c-decl.c:5861
+#: c/c-decl.c:5881
 #, gcc-internal-format
 msgid "storage class specified for structure field %qE"
 msgstr "tallennusluokka annettu tietueen kentälle %qE"
 
-#: c/c-decl.c:5864
+#: c/c-decl.c:5884
 #, gcc-internal-format
 msgid "storage class specified for structure field"
 msgstr "tallennusluokka annettu tietueen kentälle"
 
-#: c/c-decl.c:5868
+#: c/c-decl.c:5888
 #, gcc-internal-format
 msgid "storage class specified for parameter %qE"
 msgstr "tallennusluokka annettu parametrille %qE"
 
-#: c/c-decl.c:5871
+#: c/c-decl.c:5891
 #, gcc-internal-format
 msgid "storage class specified for unnamed parameter"
 msgstr "tallennusluokka annettu nimettömälle parametrille"
 
-#: c/c-decl.c:5874 cp/decl.c:10935
+#: c/c-decl.c:5894 cp/decl.c:10959
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "tallennusluokka annettu typenamelle"
 
-#: c/c-decl.c:5891
+#: c/c-decl.c:5911
 #, fuzzy, gcc-internal-format
 msgid "%qE initialized and declared %<extern%>"
 msgstr "%qs alustettu ja esitelty %<extern%>-avainsanalla"
 
-#: c/c-decl.c:5895
+#: c/c-decl.c:5915
 #, fuzzy, gcc-internal-format
 msgid "%qE has both %<extern%> and initializer"
 msgstr "%qs on sekä %<extern%> että alustin"
 
-#: c/c-decl.c:5900
+#: c/c-decl.c:5920
 #, fuzzy, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<auto%>"
 msgstr "%<auto%> tiedostoalueen tyhjässä esittelyssä"
 
-#: c/c-decl.c:5904
+#: c/c-decl.c:5924
 #, fuzzy, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<register%>"
 msgstr "%<register%> tiedostoalueen tyhjässä esittelyssä"
 
-#: c/c-decl.c:5909
+#: c/c-decl.c:5929
 #, fuzzy, gcc-internal-format
 msgid "nested function %qE declared %<extern%>"
 msgstr "sisäkkäinen funktio %qs esitelty %<extern%>:ksi"
 
-#: c/c-decl.c:5912
+#: c/c-decl.c:5932
 #, fuzzy, gcc-internal-format
 msgid "function-scope %qE implicitly auto and declared %qs"
 msgstr "funktioalue %qs implisiittisesti auto ja esitelty %<__thread%>:ksi"
@@ -36224,711 +36268,711 @@
 #. Only the innermost declarator (making a parameter be of
 #. array type which is converted to pointer type)
 #. may have static or type qualifiers.
-#: c/c-decl.c:5959 c/c-decl.c:6328
+#: c/c-decl.c:5979 c/c-decl.c:6348
 #, gcc-internal-format
 msgid "static or type qualifiers in non-parameter array declarator"
 msgstr "staattinen tai tyyppimääreitä ei-parametrisessa taulukkoesittelijässä"
 
-#: c/c-decl.c:6007
+#: c/c-decl.c:6027
 #, gcc-internal-format
 msgid "declaration of %qE as array of voids"
 msgstr "%qE:n esittely taulukollisena void-alkioita"
 
-#: c/c-decl.c:6009
+#: c/c-decl.c:6029
 #, gcc-internal-format
 msgid "declaration of type name as array of voids"
 msgstr "tyyppinimen esittely taulukollisena void-alkioita"
 
-#: c/c-decl.c:6016
+#: c/c-decl.c:6036
 #, gcc-internal-format
 msgid "declaration of %qE as array of functions"
 msgstr "%qE:n esittely taulukollisena funktioita"
 
-#: c/c-decl.c:6019
+#: c/c-decl.c:6039
 #, gcc-internal-format
 msgid "declaration of type name as array of functions"
 msgstr "tyyppinimen esittely taulukollisena funktioita"
 
-#: c/c-decl.c:6027 c/c-decl.c:8085
+#: c/c-decl.c:6047 c/c-decl.c:8105
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr "joustavan taulukkojäsenen sisältävän tietueen epäkelpo käyttö"
 
-#: c/c-decl.c:6053
+#: c/c-decl.c:6073
 #, gcc-internal-format
 msgid "size of array %qE has non-integer type"
 msgstr "taulukon %qE koko ei ole kokonaislukutyyppiä"
 
-#: c/c-decl.c:6057
+#: c/c-decl.c:6077
 #, gcc-internal-format
 msgid "size of unnamed array has non-integer type"
 msgstr "nimettömän taulukon koko ei ole kokonaislukutyyppiä"
 
-#: c/c-decl.c:6064
+#: c/c-decl.c:6084
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qE has non-integer type"
 msgid "size of array %qE has incomplete type"
 msgstr "taulukon %qE koko ei ole kokonaislukutyyppiä"
 
-#: c/c-decl.c:6067
+#: c/c-decl.c:6087
 #, fuzzy, gcc-internal-format
 #| msgid "size of unnamed array has non-integer type"
 msgid "size of unnamed array has incomplete type"
 msgstr "nimettömän taulukon koko ei ole kokonaislukutyyppiä"
 
-#: c/c-decl.c:6078
+#: c/c-decl.c:6098
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array %qE"
 msgstr "ISO C kieltää nollan kokoisen taulukon %qE"
 
-#: c/c-decl.c:6081
+#: c/c-decl.c:6101
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array"
 msgstr "ISO C kieltää nollan kokoisen taulukon"
 
-#: c/c-decl.c:6090
+#: c/c-decl.c:6110
 #, gcc-internal-format
 msgid "size of array %qE is negative"
 msgstr "taulukon %qE koko on negatiivinen"
 
-#: c/c-decl.c:6092
+#: c/c-decl.c:6112
 #, gcc-internal-format
 msgid "size of unnamed array is negative"
 msgstr "nimettömän taulukon koko on negatiivinen"
 
-#: c/c-decl.c:6216 c/c-decl.c:6871
+#: c/c-decl.c:6236 c/c-decl.c:6891
 #, gcc-internal-format
 msgid "ISO C90 does not support flexible array members"
 msgstr "ISO C90 ei tue joustavia taulukon jäseniä"
 
 #. C99 6.7.5.2p4
-#: c/c-decl.c:6238
+#: c/c-decl.c:6258
 #, gcc-internal-format
 msgid "%<[*]%> not in a declaration"
 msgstr "%<[*]%> ei ole esittelyssä"
 
-#: c/c-decl.c:6251
+#: c/c-decl.c:6271
 #, fuzzy, gcc-internal-format
 #| msgid "array type has incomplete element type"
 msgid "array type has incomplete element type %qT"
 msgstr "taulukon tyypillä on vaillinainen alkiotyyppi"
 
-#: c/c-decl.c:6257
+#: c/c-decl.c:6277
 #, fuzzy, gcc-internal-format
 #| msgid "multidimensional array must have bounds for all dimensions except the first"
 msgid "declaration of %qE as multidimensional array must have bounds for all dimensions except the first"
 msgstr "moniulotteisell taulukolla on oltava rajat kaikkiin suuntiin paitsi ensimmäiseen"
 
-#: c/c-decl.c:6261
+#: c/c-decl.c:6281
 #, fuzzy, gcc-internal-format
 #| msgid "multidimensional array must have bounds for all dimensions except the first"
 msgid "declaration of multidimensional array must have bounds for all dimensions except the first"
 msgstr "moniulotteisell taulukolla on oltava rajat kaikkiin suuntiin paitsi ensimmäiseen"
 
-#: c/c-decl.c:6364
+#: c/c-decl.c:6384
 #, gcc-internal-format
 msgid "%qE declared as function returning a function"
 msgstr "%qE esitelty funktion palauttavana funktiona"
 
-#: c/c-decl.c:6367
+#: c/c-decl.c:6387
 #, gcc-internal-format
 msgid "type name declared as function returning a function"
 msgstr "tyyppinimi esitelty funktion palauttavana funktiona"
 
-#: c/c-decl.c:6374
+#: c/c-decl.c:6394
 #, gcc-internal-format
 msgid "%qE declared as function returning an array"
 msgstr "%qE esitelty taulukon palauttavan funktiona"
 
-#: c/c-decl.c:6377
+#: c/c-decl.c:6397
 #, gcc-internal-format
 msgid "type name declared as function returning an array"
 msgstr "tyyppinimi esitelty taulukon palauttavan funktiona"
 
-#: c/c-decl.c:6418
+#: c/c-decl.c:6438
 #, fuzzy, gcc-internal-format
 msgid "function definition has qualified void return type"
 msgstr "funktion määrittely oikeuttaa tyhjän paluutyypin"
 
-#: c/c-decl.c:6421 cp/decl.c:11201
+#: c/c-decl.c:6441 cp/decl.c:11225
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "tyyppimääreet jätetään huomiotta funktion paluutyypissä"
 
-#: c/c-decl.c:6459 c/c-decl.c:6668 c/c-decl.c:6721 c/c-decl.c:6805
-#: c/c-decl.c:6926 c/c-parser.c:2823
+#: c/c-decl.c:6479 c/c-decl.c:6688 c/c-decl.c:6741 c/c-decl.c:6825
+#: c/c-decl.c:6946 c/c-parser.c:2823
 #, fuzzy, gcc-internal-format
 #| msgid "cast specifies function type"
 msgid "%<_Atomic%>-qualified function type"
 msgstr "tyyppimuunnos määrittää funktiotyypin"
 
-#: c/c-decl.c:6465 c/c-decl.c:6674 c/c-decl.c:6810 c/c-decl.c:6931
+#: c/c-decl.c:6485 c/c-decl.c:6694 c/c-decl.c:6830 c/c-decl.c:6951
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids qualified function types"
 msgstr "ISO C kieltää const- ja volatile-funktiotyypit"
 
-#: c/c-decl.c:6559
+#: c/c-decl.c:6579
 #, fuzzy, gcc-internal-format
 msgid "%qs combined with %<auto%> qualifier for %qE"
 msgstr "ristiriitaiset tyyppimääreet %q+D:lle"
 
-#: c/c-decl.c:6563
+#: c/c-decl.c:6583
 #, gcc-internal-format
 msgid "%qs combined with %<register%> qualifier for %qE"
 msgstr ""
 
-#: c/c-decl.c:6569
+#: c/c-decl.c:6589
 #, fuzzy, gcc-internal-format
 msgid "%qs specified for auto variable %qE"
 msgstr "%qs määritelty parametrille %qE"
 
-#: c/c-decl.c:6585
+#: c/c-decl.c:6605
 #, gcc-internal-format
 msgid "%qs specified for parameter %qE"
 msgstr "%qs määritelty parametrille %qE"
 
-#: c/c-decl.c:6588
+#: c/c-decl.c:6608
 #, gcc-internal-format
 msgid "%qs specified for unnamed parameter"
 msgstr "%qs määritelty nimettömälle parametrille"
 
-#: c/c-decl.c:6594
+#: c/c-decl.c:6614
 #, gcc-internal-format
 msgid "%qs specified for structure field %qE"
 msgstr "%qs määritelty tietueen kentälle %qE"
 
-#: c/c-decl.c:6597
+#: c/c-decl.c:6617
 #, gcc-internal-format
 msgid "%qs specified for structure field"
 msgstr "%qs määritelty tietueen kentälle"
 
-#: c/c-decl.c:6612
+#: c/c-decl.c:6632
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qs has invalid type"
 msgid "bit-field %qE has atomic type"
 msgstr "bittikentällä %qs on epäkelpo tyyppi"
 
-#: c/c-decl.c:6614
+#: c/c-decl.c:6634
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qs has invalid type"
 msgid "bit-field has atomic type"
 msgstr "bittikentällä %qs on epäkelpo tyyppi"
 
-#: c/c-decl.c:6623
+#: c/c-decl.c:6643
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for typedef %qE"
 msgstr "kohdistusta ei voi määritellä %q+D:lle"
 
-#: c/c-decl.c:6625
+#: c/c-decl.c:6645
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for %<register%> object %qE"
 msgstr "tallennusluokka annettu parametrille %qs"
 
-#: c/c-decl.c:6630
+#: c/c-decl.c:6650
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for parameter %qE"
 msgstr "%qs määritelty parametrille %qE"
 
-#: c/c-decl.c:6632
+#: c/c-decl.c:6652
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for unnamed parameter"
 msgstr "%qs määritelty nimettömälle parametrille"
 
-#: c/c-decl.c:6637
+#: c/c-decl.c:6657
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for bit-field %qE"
 msgstr "%qs määritelty tietueen kentälle %qE"
 
-#: c/c-decl.c:6639
+#: c/c-decl.c:6659
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for unnamed bit-field"
 msgstr "tallennusluokka annettu parametrille %qs"
 
-#: c/c-decl.c:6642
+#: c/c-decl.c:6662
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for function %qE"
 msgstr "kohdistusta ei voi määritellä %q+D:lle"
 
-#: c/c-decl.c:6649
+#: c/c-decl.c:6669
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of %qE"
 msgstr ""
 
-#: c/c-decl.c:6652
+#: c/c-decl.c:6672
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of unnamed field"
 msgstr ""
 
-#: c/c-decl.c:6683
+#: c/c-decl.c:6703
 #, fuzzy, gcc-internal-format
 msgid "typedef %q+D declared %<inline%>"
 msgstr "muuttuja %qD esitelty %<inline%>:ksi"
 
-#: c/c-decl.c:6685
+#: c/c-decl.c:6705
 #, fuzzy, gcc-internal-format
 msgid "typedef %q+D declared %<_Noreturn%>"
 msgstr "typedef %q+D määritelty uudelleen"
 
-#: c/c-decl.c:6727
+#: c/c-decl.c:6747
 #, gcc-internal-format
 msgid "ISO C forbids const or volatile function types"
 msgstr "ISO C kieltää const- ja volatile-funktiotyypit"
 
 #. C99 6.7.2.1p8
-#: c/c-decl.c:6738
+#: c/c-decl.c:6758
 #, gcc-internal-format
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr ""
 
-#: c/c-decl.c:6755 cp/decl.c:9989
+#: c/c-decl.c:6775 cp/decl.c:10010
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "muuttuja tai kenttä %qE esitelty voidiksi"
 
-#: c/c-decl.c:6795
+#: c/c-decl.c:6815
 #, gcc-internal-format
 msgid "attributes in parameter array declarator ignored"
 msgstr "parametritaulukon esittelijän attribuutit jätetään huomiotta"
 
-#: c/c-decl.c:6837
+#: c/c-decl.c:6857
 #, gcc-internal-format
 msgid "parameter %q+D declared %<inline%>"
 msgstr "parametri %q+D esitelty %<inline%>:ksi"
 
-#: c/c-decl.c:6839
+#: c/c-decl.c:6859
 #, fuzzy, gcc-internal-format
 msgid "parameter %q+D declared %<_Noreturn%>"
 msgstr "parametri %q+D esitelty %<inline%>:ksi"
 
-#: c/c-decl.c:6852
+#: c/c-decl.c:6872
 #, gcc-internal-format
 msgid "field %qE declared as a function"
 msgstr "kenttä %qE esitelty funktiona"
 
-#: c/c-decl.c:6859
+#: c/c-decl.c:6879
 #, fuzzy, gcc-internal-format
 msgid "field %qE has incomplete type"
 msgstr "nimettömällä kentällä on vaillinainen tyyppi"
 
-#: c/c-decl.c:6861
+#: c/c-decl.c:6881
 #, gcc-internal-format
 msgid "unnamed field has incomplete type"
 msgstr "nimettömällä kentällä on vaillinainen tyyppi"
 
-#: c/c-decl.c:6897 c/c-decl.c:6908 c/c-decl.c:6911
+#: c/c-decl.c:6917 c/c-decl.c:6928 c/c-decl.c:6931
 #, gcc-internal-format
 msgid "invalid storage class for function %qE"
 msgstr "epäkelpo tallennusluokka funktiolle %qE"
 
-#: c/c-decl.c:6968
+#: c/c-decl.c:6988
 #, gcc-internal-format
 msgid "cannot inline function %<main%>"
 msgstr "funktiota %<main%> ei voi määrittää avoimeksi"
 
-#: c/c-decl.c:6970
+#: c/c-decl.c:6990
 #, fuzzy, gcc-internal-format
 msgid "%<main%> declared %<_Noreturn%>"
 msgstr "%qs alustettu ja esitelty %<extern%>-avainsanalla"
 
-#: c/c-decl.c:6981
+#: c/c-decl.c:7001
 #, fuzzy, gcc-internal-format
 msgid "ISO C99 does not support %<_Noreturn%>"
 msgstr "ISO C90 ei tue %<long long%> -tyyppiä"
 
-#: c/c-decl.c:6984
+#: c/c-decl.c:7004
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support %<_Noreturn%>"
 msgstr "ISO C90 ei tue joustavia taulukon jäseniä"
 
-#: c/c-decl.c:7013
+#: c/c-decl.c:7033
 #, gcc-internal-format
 msgid "variable previously declared %<static%> redeclared %<extern%>"
 msgstr "%<static%>-määreellä esitelty muuttuja esitelty uudelleen %<extern%>-tyyppiseksi"
 
-#: c/c-decl.c:7023
+#: c/c-decl.c:7043
 #, gcc-internal-format
 msgid "variable %q+D declared %<inline%>"
 msgstr "muuttuja %qD esitelty %<inline%>:ksi"
 
-#: c/c-decl.c:7025
+#: c/c-decl.c:7045
 #, fuzzy, gcc-internal-format
 msgid "variable %q+D declared %<_Noreturn%>"
 msgstr "muuttuja %qD esitelty %<inline%>:ksi"
 
-#: c/c-decl.c:7060
+#: c/c-decl.c:7080
 #, gcc-internal-format
 msgid "non-nested function with variably modified type"
 msgstr ""
 
-#: c/c-decl.c:7062
+#: c/c-decl.c:7082
 #, gcc-internal-format
 msgid "object with variably modified type must have no linkage"
 msgstr ""
 
-#: c/c-decl.c:7153 c/c-decl.c:8821
+#: c/c-decl.c:7173 c/c-decl.c:8841
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr "funktion esittely ei ole prototyyppi"
 
-#: c/c-decl.c:7163
+#: c/c-decl.c:7183
 #, gcc-internal-format
 msgid "parameter names (without types) in function declaration"
 msgstr "parametrien nimet (ilman tyyppejä) funktion esittelyssä"
 
-#: c/c-decl.c:7201
+#: c/c-decl.c:7221
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has incomplete type"
 msgstr "parametrilla %u (%q+D) on vaillinainen tyyppi"
 
-#: c/c-decl.c:7205
+#: c/c-decl.c:7225
 #, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has incomplete type"
 msgstr "parametrilla %u in vaillinainen tyyppi"
 
-#: c/c-decl.c:7216
+#: c/c-decl.c:7236
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has void type"
 msgstr "parametrin %u (%q+D) tyyppi on void"
 
-#: c/c-decl.c:7220
+#: c/c-decl.c:7240
 #, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has void type"
 msgstr "parametrin %u tyyppi on void"
 
-#: c/c-decl.c:7294
+#: c/c-decl.c:7314
 #, fuzzy, gcc-internal-format
 msgid "%<void%> as only parameter may not be qualified"
 msgstr "%<void%>:in on oltava ainoa parametri"
 
-#: c/c-decl.c:7298 c/c-decl.c:7334
+#: c/c-decl.c:7318 c/c-decl.c:7354
 #, gcc-internal-format
 msgid "%<void%> must be the only parameter"
 msgstr "%<void%>:in on oltava ainoa parametri"
 
-#: c/c-decl.c:7328
+#: c/c-decl.c:7348
 #, gcc-internal-format
 msgid "parameter %q+D has just a forward declaration"
 msgstr "parametrilla %q+D on vain etukäteisesittely"
 
-#: c/c-decl.c:7374
+#: c/c-decl.c:7394
 #, gcc-internal-format
 msgid "%<%s %E%> declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr ""
 
-#: c/c-decl.c:7380
+#: c/c-decl.c:7400
 #, gcc-internal-format, gfc-internal-format
 msgid "anonymous %s declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr ""
 
-#: c/c-decl.c:7482
+#: c/c-decl.c:7502
 #, gcc-internal-format
 msgid "enum type defined here"
 msgstr "lueteltu tyyppi määritelty täällä"
 
-#: c/c-decl.c:7488
+#: c/c-decl.c:7508
 #, gcc-internal-format
 msgid "struct defined here"
 msgstr "struct määritelty täällä"
 
-#: c/c-decl.c:7494
+#: c/c-decl.c:7514
 #, gcc-internal-format
 msgid "union defined here"
 msgstr "union määritelty täällä"
 
-#: c/c-decl.c:7570
+#: c/c-decl.c:7590
 #, gcc-internal-format
 msgid "redefinition of %<union %E%>"
 msgstr "%<union %E%> uudelleenmääritelty"
 
-#: c/c-decl.c:7572
+#: c/c-decl.c:7592
 #, gcc-internal-format
 msgid "redefinition of %<struct %E%>"
 msgstr "%<struct %E%> uudelleenmääritelty"
 
-#: c/c-decl.c:7581
+#: c/c-decl.c:7601
 #, gcc-internal-format
 msgid "nested redefinition of %<union %E%>"
 msgstr "sisäkkäinen %<union %E%>:n uudelleenmäärittely"
 
-#: c/c-decl.c:7583
+#: c/c-decl.c:7603
 #, gcc-internal-format
 msgid "nested redefinition of %<struct %E%>"
 msgstr "sisäkkäinen %<struct %E%>:n uudelleenmäärittely"
 
-#: c/c-decl.c:7613 c/c-decl.c:8400
+#: c/c-decl.c:7633 c/c-decl.c:8420
 #, fuzzy, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr "tyypin määritteleminen tyyppimuunnoksessa on virheellistä C++-kielessä"
 
-#: c/c-decl.c:7680 cp/decl.c:4802
+#: c/c-decl.c:7700 cp/decl.c:4802
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "esittely ei esittele mitään"
 
-#: c/c-decl.c:7685
+#: c/c-decl.c:7705
 #, fuzzy, gcc-internal-format
 msgid "ISO C99 doesn%'t support unnamed structs/unions"
 msgstr "ISO C ei tue nimettömiä structeja/unioneita"
 
-#: c/c-decl.c:7688
+#: c/c-decl.c:7708
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 doesn%'t support unnamed structs/unions"
 msgstr "ISO C ei tue nimettömiä structeja/unioneita"
 
-#: c/c-decl.c:7781 c/c-decl.c:7799 c/c-decl.c:7860
+#: c/c-decl.c:7801 c/c-decl.c:7819 c/c-decl.c:7880
 #, gcc-internal-format
 msgid "duplicate member %q+D"
 msgstr "jäsenen %q+D kaksoiskappale"
 
-#: c/c-decl.c:7886
+#: c/c-decl.c:7906
 #, gcc-internal-format
 msgid "empty struct has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.c:7889
+#: c/c-decl.c:7909
 #, gcc-internal-format
 msgid "empty union has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.c:7994
+#: c/c-decl.c:8014
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr "unionilla ei ole nimettyjä jäseniä"
 
-#: c/c-decl.c:7996
+#: c/c-decl.c:8016
 #, gcc-internal-format
 msgid "union has no members"
 msgstr "unionilla ei ole jäseniä"
 
-#: c/c-decl.c:8001
+#: c/c-decl.c:8021
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr "structilla ei ole nimettyjä jäseniä"
 
-#: c/c-decl.c:8003
+#: c/c-decl.c:8023
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr "structilla ei ole jäseniä"
 
-#: c/c-decl.c:8064 cp/decl.c:12069
+#: c/c-decl.c:8084 cp/decl.c:12093
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "joustava taulukkojäsen unionissa"
 
-#: c/c-decl.c:8070
+#: c/c-decl.c:8090
 #, gcc-internal-format
 msgid "flexible array member not at end of struct"
 msgstr "joustava taulukkojäsen ei ole structin lopussa"
 
-#: c/c-decl.c:8076
+#: c/c-decl.c:8096
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member in union"
 msgid "flexible array member in a struct with no named members"
 msgstr "joustava taulukkojäsen unionissa"
 
-#: c/c-decl.c:8107
+#: c/c-decl.c:8127
 #, fuzzy, gcc-internal-format
 msgid "type %qT is too large"
 msgstr "Arvo on liian suuri annetulle tietotyypille"
 
-#: c/c-decl.c:8230
+#: c/c-decl.c:8250
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr "unionista ei voi tehdä läpinäkyvää"
 
-#: c/c-decl.c:8372
+#: c/c-decl.c:8392
 #, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr "sisäkkäinen %<enum %E%>:n uudelleenmäärittely"
 
 #. This enum is a named one that has been declared already.
-#: c/c-decl.c:8379
+#: c/c-decl.c:8399
 #, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr "%<enum %E%>:n uudelleenmäärittely"
 
-#: c/c-decl.c:8458 cp/decl.c:14423
+#: c/c-decl.c:8478 cp/decl.c:14447
 #, gcc-internal-format
 msgid "specified mode too small for enumeral values"
 msgstr "annettu tila on liian pieni luetelluille arvoille"
 
-#: c/c-decl.c:8473
+#: c/c-decl.c:8493
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr "luetellun tyypin arvot ylittävät suurimman kokonaisluvun arvoalueen"
 
-#: c/c-decl.c:8587 c/c-decl.c:8603
+#: c/c-decl.c:8607 c/c-decl.c:8623
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: c/c-decl.c:8598
+#: c/c-decl.c:8618
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: c/c-decl.c:8622
+#: c/c-decl.c:8642
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr "ylivuoto luetellun tyypin arvoissa"
 
-#: c/c-decl.c:8630
+#: c/c-decl.c:8650
 #, gcc-internal-format
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "ISO C rajoittaa luetellun tyypin arvot %<int%>-tyypin arvoalueelle"
 
-#: c/c-decl.c:8715 cp/decl.c:5104 cp/decl.c:14955
+#: c/c-decl.c:8735 cp/decl.c:5104 cp/decl.c:14979
 #, fuzzy, gcc-internal-format
 msgid "inline function %qD given attribute noinline"
 msgstr "%Javoimelle funktiolle %qD annettu attribuutti noinline"
 
-#: c/c-decl.c:8733
+#: c/c-decl.c:8753
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr "paluutyyppi on vaillinainen tyyppi"
 
-#: c/c-decl.c:8744
+#: c/c-decl.c:8764
 #, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr "paluutyyppi on oletuksena %<int%>"
 
-#: c/c-decl.c:8771
+#: c/c-decl.c:8791
 #, fuzzy, gcc-internal-format
 #| msgid "field %qE declared as a function"
 msgid "%q+D defined as variadic function without prototype"
 msgstr "kenttä %qE esitelty funktiona"
 
-#: c/c-decl.c:8830
+#: c/c-decl.c:8850
 #, gcc-internal-format
 msgid "no previous prototype for %qD"
 msgstr "%qD:lle ei ole edellistä prototyyppiä"
 
-#: c/c-decl.c:8839
+#: c/c-decl.c:8859
 #, gcc-internal-format
 msgid "%qD was used with no prototype before its definition"
 msgstr "%qD käytössä ilman prototyyppiä ennen sen määrittelyä"
 
-#: c/c-decl.c:8847 cp/decl.c:15090
+#: c/c-decl.c:8867 cp/decl.c:15114
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "%qD:lle ei ole edellistä esittelyä"
 
-#: c/c-decl.c:8857
+#: c/c-decl.c:8877
 #, gcc-internal-format
 msgid "%qD was used with no declaration before its definition"
 msgstr "%qD käytössä ilman esittelyä ennen sen määrittelyä"
 
-#: c/c-decl.c:8876
+#: c/c-decl.c:8896
 #, gcc-internal-format
 msgid "return type of %qD is not %<int%>"
 msgstr "%qD:n paluuarvon tyyppi ei ole %<int%>"
 
-#: c/c-decl.c:8878
+#: c/c-decl.c:8898
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr "%qD:n paluuarvon tyyppi ei ole %<int%>"
 
-#: c/c-decl.c:8885
+#: c/c-decl.c:8905
 #, gcc-internal-format
 msgid "%qD is normally a non-static function"
 msgstr "%qD on tavallisesti ei-staattinen funktio"
 
-#: c/c-decl.c:8922
+#: c/c-decl.c:8942
 #, gcc-internal-format
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr "vanhanmallisia parametriesittelyitä prototyypitetyssä funktiomäärittelyssä"
 
-#: c/c-decl.c:8937
+#: c/c-decl.c:8957
 #, gcc-internal-format
 msgid "traditional C rejects ISO C style function definitions"
 msgstr "perinteinen C ei hyväksy ISO C -tyylisiä funktiomäärittelyitä"
 
-#: c/c-decl.c:8953
+#: c/c-decl.c:8973
 #, gcc-internal-format
 msgid "parameter name omitted"
 msgstr "parametrin nimi jätetty pois"
 
-#: c/c-decl.c:8990
+#: c/c-decl.c:9010
 #, gcc-internal-format
 msgid "old-style function definition"
 msgstr "vanhanmallinen funktiomäärittely"
 
-#: c/c-decl.c:8999
+#: c/c-decl.c:9019
 #, gcc-internal-format
 msgid "parameter name missing from parameter list"
 msgstr "parametrin nimi puuttuu parametriluettelosta"
 
-#: c/c-decl.c:9015
+#: c/c-decl.c:9035
 #, gcc-internal-format
 msgid "%qD declared as a non-parameter"
 msgstr "%qD esitelty ei-parametrina"
 
-#: c/c-decl.c:9023
+#: c/c-decl.c:9043
 #, gcc-internal-format
 msgid "multiple parameters named %qD"
 msgstr "useita parametreja nimellä %qD"
 
-#: c/c-decl.c:9032
+#: c/c-decl.c:9052
 #, gcc-internal-format
 msgid "parameter %qD declared with void type"
 msgstr "parametri %qD esitelty void-tyyppisenä"
 
-#: c/c-decl.c:9061 c/c-decl.c:9066
+#: c/c-decl.c:9081 c/c-decl.c:9086
 #, gcc-internal-format
 msgid "type of %qD defaults to %<int%>"
 msgstr "%qD:n oletustyyppi on %<int%>"
 
-#: c/c-decl.c:9086
+#: c/c-decl.c:9106
 #, gcc-internal-format
 msgid "parameter %qD has incomplete type"
 msgstr "parametrin %qD tyyppi on vaillinainen"
 
-#: c/c-decl.c:9093
+#: c/c-decl.c:9113
 #, gcc-internal-format
 msgid "declaration for parameter %qD but no such parameter"
 msgstr "parametrin %qD esittely, mutta parametria ei ole olemassa"
 
-#: c/c-decl.c:9146
+#: c/c-decl.c:9166
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr "argumenttien määrä ei vastaa sisäistä prototyyppiä"
 
-#: c/c-decl.c:9157
+#: c/c-decl.c:9177
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr "argumenttien määrä ei vastaa prototyyppiä"
 
-#: c/c-decl.c:9160 c/c-decl.c:9207 c/c-decl.c:9221
+#: c/c-decl.c:9180 c/c-decl.c:9227 c/c-decl.c:9241
 #, gcc-internal-format
 msgid "prototype declaration"
 msgstr "prototyypin esittely"
 
-#: c/c-decl.c:9199
+#: c/c-decl.c:9219
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr "ylennetty argumentti %qD ei vastaa sisäistä prototyyppiä"
 
-#: c/c-decl.c:9204
+#: c/c-decl.c:9224
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr "ylennetty argumentti %qD ei vastaa prototyyppiä"
 
-#: c/c-decl.c:9214
+#: c/c-decl.c:9234
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr "argumentti %qD ei vastaa sisäistä prototyyppiä"
 
-#: c/c-decl.c:9219
+#: c/c-decl.c:9239
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr "argumentti %qD ei sovi prototyyppiin"
 
-#: c/c-decl.c:9470 cp/decl.c:15873
+#: c/c-decl.c:9490 cp/decl.c:15897
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "ei palautuslausetta funktiossa, joka palauttaa ei-voidin"
 
-#: c/c-decl.c:9490 cp/decl.c:15905
+#: c/c-decl.c:9510 cp/decl.c:15929
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "parametri %qD on alustettu"
@@ -36936,256 +36980,256 @@
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:9586
+#: c/c-decl.c:9606
 #, fuzzy, gcc-internal-format
 #| msgid "%<for%> loop initial declarations are only allowed in C99 mode"
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "%<for%>-silmukan alkuesittelyt ovat sallittuja vain C99-tilassa"
 
-#: c/c-decl.c:9591
+#: c/c-decl.c:9611
 #, fuzzy, gcc-internal-format
 #| msgid "use option -std=c99 or -std=gnu99 to compile your code"
 msgid "use option -std=c99, -std=gnu99, -std=c11 or -std=gnu11 to compile your code"
 msgstr "käytä valitsinta -std=c99 tai -std=gnu99 koodisi kääntämiseen"
 
-#: c/c-decl.c:9626
+#: c/c-decl.c:9646
 #, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "staattisen muuttujan %qD esittely %<for%>-silmukan alkuesittelyssä"
 
-#: c/c-decl.c:9630
+#: c/c-decl.c:9650
 #, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "%<extern%>-muuttujan %qD esittely %<for%>-silmukan alkuesittelyssä"
 
 # XXX: alkuesittely
-#: c/c-decl.c:9637
+#: c/c-decl.c:9657
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "%<struct %E%> esitelty %<for%>-silmukan alkuesittelyssä"
 
-#: c/c-decl.c:9642
+#: c/c-decl.c:9662
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "%<union %E%> esitelty %<for%>-silmukan alkuesittelyssä"
 
-#: c/c-decl.c:9646
+#: c/c-decl.c:9666
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "%<enum %E%> esitelty %<for%>-silmukan alkuesittelyssä"
 
-#: c/c-decl.c:9650
+#: c/c-decl.c:9670
 #, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "ei-muuttujan %qD esittely %<for%>-silmukan alkuesittelyssä"
 
-#: c/c-decl.c:9900
+#: c/c-decl.c:9920
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr ""
 
-#: c/c-decl.c:9958 c/c-decl.c:9965
+#: c/c-decl.c:9978 c/c-decl.c:9985
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qE declaration specifier"
 msgstr "useita tallennusluokkia esittelymääritteissä"
 
-#: c/c-decl.c:9992 c/c-decl.c:10376 c/c-decl.c:10766
+#: c/c-decl.c:10012 c/c-decl.c:10396 c/c-decl.c:10786
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr "yli yksi tietotyyppi esittelymääritteissä"
 
-#: c/c-decl.c:10004 cp/parser.c:28261
+#: c/c-decl.c:10024 cp/parser.c:28258
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> on liian pitkä GCC:lle"
 
-#: c/c-decl.c:10017
+#: c/c-decl.c:10037
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C90 ei tue %<long long%> -tyyppiä"
 
-#: c/c-decl.c:10246 c/c-parser.c:8848
+#: c/c-decl.c:10266 c/c-parser.c:8848
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C90 ei tue kompleksityyppejä"
 
-#: c/c-decl.c:10292
+#: c/c-decl.c:10312
 #, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr "ISO C ei tue saturoituvia tyyppejä"
 
-#: c/c-decl.c:10363 c/c-decl.c:10923
+#: c/c-decl.c:10383 c/c-decl.c:10943
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "%qE:n kaksoiskappale"
 
-#: c/c-decl.c:10419
+#: c/c-decl.c:10439
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C ei tue saturoituvia tyyppejä"
 
-#: c/c-decl.c:10441
+#: c/c-decl.c:10461
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr "kohteen int-tyyppi on kapeampi kuin kohteen char-tyyppi"
 
-#: c/c-decl.c:10484
+#: c/c-decl.c:10504
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support complex types"
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C90 ei tue kompleksityyppejä"
 
-#: c/c-decl.c:10603
+#: c/c-decl.c:10623
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support the %<_Float%d%s%> type"
 msgstr "ISO C ei tue saturoituvia tyyppejä"
 
-#: c/c-decl.c:10653
+#: c/c-decl.c:10673
 #, fuzzy, gcc-internal-format
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "kohteen int-tyyppi on kapeampi kuin kohteen char-tyyppi"
 
-#: c/c-decl.c:10724
+#: c/c-decl.c:10744
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support decimal floating point"
 msgstr "ISO C90 ei tue tyyppiä %<long long%>"
 
-#: c/c-decl.c:10747 c/c-decl.c:11013 c/c-parser.c:7842
+#: c/c-decl.c:10767 c/c-decl.c:11033 c/c-parser.c:7842
 #, fuzzy, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: c/c-decl.c:10749
+#: c/c-decl.c:10769
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C ei tue saturoituvia tyyppejä"
 
-#: c/c-decl.c:10784
+#: c/c-decl.c:10804
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr ""
 
-#: c/c-decl.c:10797
+#: c/c-decl.c:10817
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr "%qE ei ole typedef eikä sisäinen tyyppi"
 
-#: c/c-decl.c:10845
+#: c/c-decl.c:10865
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qE ei ole esittelyn alussa"
 
-#: c/c-decl.c:10866
+#: c/c-decl.c:10886
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<auto%>"
 msgid "%qE used with %<auto%>"
 msgstr "%qE:a saatetaan käyttää alustamattomana tässä funktiossa"
 
-#: c/c-decl.c:10868
+#: c/c-decl.c:10888
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<register%>"
 msgid "%qE used with %<register%>"
 msgstr "%qE:a käytetään alustamattomana tässä funktiossa"
 
-#: c/c-decl.c:10870
+#: c/c-decl.c:10890
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> used with %<typedef%>"
 msgid "%qE used with %<typedef%>"
 msgstr "%qE ei ole typedef eikä sisäinen tyyppi"
 
-#: c/c-decl.c:10884 c/c-parser.c:7360
+#: c/c-decl.c:10904 c/c-parser.c:7360
 #, fuzzy, gcc-internal-format
 msgid "ISO C99 does not support %qE"
 msgstr "ISO C90 ei tue %<long long%> -tyyppiä"
 
-#: c/c-decl.c:10887 c/c-parser.c:7363
+#: c/c-decl.c:10907 c/c-parser.c:7363
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support %qE"
 msgstr "ISO C90 ei tue %<long long%> -tyyppiä"
 
-#: c/c-decl.c:10899
+#: c/c-decl.c:10919
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "käytetty %<__thread%> ennen %<extern%>:a"
 
-#: c/c-decl.c:10908
+#: c/c-decl.c:10928
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "käytetty %<__thread%> ennen %<static%>:a"
 
-#: c/c-decl.c:10921
+#: c/c-decl.c:10941
 #, fuzzy, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr "fetchmail: säie nukkuu %d sekuntia.\n"
 
-#: c/c-decl.c:10929
+#: c/c-decl.c:10949
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr "useita tallennusluokkia esittelymääritteissä"
 
-#: c/c-decl.c:10937
+#: c/c-decl.c:10957
 #, fuzzy, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr "%qE:a käytetään alustamattomana tässä funktiossa"
 
-#: c/c-decl.c:11010
+#: c/c-decl.c:11030
 #, fuzzy, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "käytetty sekä %<__thread%> että %<auto&>"
 
-#: c/c-decl.c:11025
+#: c/c-decl.c:11045
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C ei tue pelkkää %<complex%>-tyyppiä merkityksellä %<double complex%>"
 
-#: c/c-decl.c:11076 c/c-decl.c:11092 c/c-decl.c:11118
+#: c/c-decl.c:11096 c/c-decl.c:11112 c/c-decl.c:11138
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C ei tue kompleksikokonaislukutyyppejä"
 
-#: c/c-decl.c:11514 cp/semantics.c:5348
+#: c/c-decl.c:11534 cp/semantics.c:5351
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:11518 cp/semantics.c:5352
+#: c/c-decl.c:11538 cp/semantics.c:5355
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.c:385 c/c-typeck.c:11426 cp/typeck.c:4680
+#: c/c-fold.c:385 c/c-typeck.c:11431 cp/typeck.c:4680
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count is negative"
 msgid "left shift of negative value"
 msgstr "vasemmalle siirron lukumäärä on negatiivinen"
 
-#: c/c-fold.c:395 c/c-typeck.c:11435 cp/typeck.c:4688
+#: c/c-fold.c:395 c/c-typeck.c:11440 cp/typeck.c:4688
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "vasemmalle siirron lukumäärä on negatiivinen"
 
-#: c/c-fold.c:396 c/c-typeck.c:11365 cp/typeck.c:4633
+#: c/c-fold.c:396 c/c-typeck.c:11370 cp/typeck.c:4633
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "oikealle siirron lukumäärä on negatiivinen"
 
-#: c/c-fold.c:404 c/c-typeck.c:11454 cp/typeck.c:4696
+#: c/c-fold.c:404 c/c-typeck.c:11459 cp/typeck.c:4696
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "vasemmalle siirron lukumäärä >= tyypin leveys"
 
-#: c/c-fold.c:405 c/c-typeck.c:11389 cp/typeck.c:4641
+#: c/c-fold.c:405 c/c-typeck.c:11394 cp/typeck.c:4641
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "oikealle siirron lukumäärä >= tyypin leveys"
 
-#: c/c-fold.c:412 c/c-typeck.c:11446
+#: c/c-fold.c:412 c/c-typeck.c:11451
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count >= width of type"
 msgid "left shift count >= width of vector element"
 msgstr "vasemmalle siirron lukumäärä >= tyypin leveys"
 
-#: c/c-fold.c:413 c/c-typeck.c:11376
+#: c/c-fold.c:413 c/c-typeck.c:11381
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count >= width of type"
 msgid "right shift count >= width of vector element"
@@ -37207,7 +37251,7 @@
 msgid "to match this %qs"
 msgstr "toinen täsmäävyys on täällä"
 
-#: c/c-parser.c:1216 cp/parser.c:28484
+#: c/c-parser.c:1216 cp/parser.c:28481
 #, fuzzy, gcc-internal-format
 msgid "expected end of line"
 msgstr "odotettiin %<(%> tai rivin loppu"
@@ -37249,7 +37293,7 @@
 msgstr "%qE ei nimeä tyyppiä"
 
 #: c/c-parser.c:1848 c/c-parser.c:11129 c/c-parser.c:16147 c/c-parser.c:16585
-#: c/c-parser.c:17061 cp/parser.c:36007 cp/parser.c:38993
+#: c/c-parser.c:17061 cp/parser.c:36004 cp/parser.c:38990
 #, fuzzy, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "useita tallennusluokkia esittelymääritteissä"
@@ -37264,7 +37308,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "odotettiin tunnistetta tai %<(%>"
 
-#: c/c-parser.c:1906 cp/parser.c:30161 cp/parser.c:30235
+#: c/c-parser.c:1906 cp/parser.c:30158 cp/parser.c:30232
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "parametritaulukon esittelijän attribuutit jätetään huomiotta"
@@ -37320,7 +37364,7 @@
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr "tallennusluokan voi antaa vain objekteille ja funktioille"
 
-#: c/c-parser.c:2220 cp/parser.c:13002 cp/parser.c:13159
+#: c/c-parser.c:2220 cp/parser.c:12999 cp/parser.c:13156
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "odotettiin %<,%> tai %<;%>"
@@ -37348,7 +37392,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C90 ei tue syntaksia %<[*]%> taulukkoesittelijöissä"
 
-#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38634
+#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38631
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr "odotettiin merkkijonoliteraalia"
@@ -37413,13 +37457,13 @@
 #: c/c-parser.c:10745 c/c-parser.c:10798 c/c-parser.c:10814 c/c-parser.c:10860
 #: c/c-parser.c:11496 c/c-parser.c:11537 c/c-parser.c:13445 c/c-parser.c:13681
 #: c/c-parser.c:15544 c/c-parser.c:18218 c/gimple-parser.c:1058
-#: c/gimple-parser.c:1096 cp/parser.c:28487 cp/parser.c:31013
-#: cp/parser.c:31043 cp/parser.c:31113 cp/parser.c:33230 cp/parser.c:38350
+#: c/gimple-parser.c:1096 cp/parser.c:28484 cp/parser.c:31010
+#: cp/parser.c:31040 cp/parser.c:31110 cp/parser.c:33227 cp/parser.c:38347
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "odotettu tunniste"
 
-#: c/c-parser.c:2995 cp/parser.c:18384
+#: c/c-parser.c:2995 cp/parser.c:18381
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "luetellun tyypin luettelon lopussa on pilkku"
@@ -37588,12 +37632,12 @@
 msgid "expected statement"
 msgstr "%s-lausetta odotettiin kohdassa %L"
 
-#: c/c-parser.c:5639 cp/parser.c:12516
+#: c/c-parser.c:5639 cp/parser.c:12513
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "ehdotetaan aaltosulkeita tyhjän lohkon ympärille %<if%>-lauseessa"
 
-#: c/c-parser.c:5681 cp/parser.c:12519
+#: c/c-parser.c:5681 cp/parser.c:12516
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "ehdotetaan aaltosulkeita tyhjän lohkon ympärille %<else%>-lauseessa"
@@ -37949,7 +37993,7 @@
 msgid "%<__builtin_complex%> operands of different types"
 msgstr "?:-lausekkeen operandeilla on eri tyypit, %qT ja %qT"
 
-#: c/c-parser.c:8891 cp/parser.c:6918
+#: c/c-parser.c:8891 cp/parser.c:6921
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_shuffle%>"
 msgstr "väärä määrä argumentteja funktiolle %<__builtin_next_arg%>"
@@ -38009,77 +38053,77 @@
 msgid "no type or storage class may be specified here,"
 msgstr "tallennusluokka annettu %qs:lle"
 
-#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31073
+#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31070
 #, fuzzy, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "<tuntematon>"
 
-#: c/c-parser.c:10682 cp/parser.c:31033
+#: c/c-parser.c:10682 cp/parser.c:31030
 #, fuzzy, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "%s:n perästä puuttuu operandi"
 
-#: c/c-parser.c:10685 cp/parser.c:31036
+#: c/c-parser.c:10685 cp/parser.c:31033
 #, fuzzy, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "%s:n perästä puuttuu operandi"
 
-#: c/c-parser.c:10699 cp/parser.c:31051
+#: c/c-parser.c:10699 cp/parser.c:31048
 #, fuzzy, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "%Jlohkoattribuuttia ei voi määrittää paikalliselle muuttujalle"
 
-#: c/c-parser.c:10704 cp/parser.c:31057
+#: c/c-parser.c:10704 cp/parser.c:31054
 #, fuzzy, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr "kuori on annettava polkuineen"
 
-#: c/c-parser.c:10711 cp/parser.c:31065
+#: c/c-parser.c:10711 cp/parser.c:31062
 #, fuzzy, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "%Jlohkoattribuuttia ei voi määrittää paikalliselle muuttujalle"
 
-#: c/c-parser.c:10905 cp/parser.c:38674
+#: c/c-parser.c:10905 cp/parser.c:38671
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
 #: c/c-parser.c:10949 c/c-parser.c:16582 c/c-parser.c:16840 c/c-parser.c:16899
-#: c/c-parser.c:16983 cp/parser.c:36004 cp/parser.c:36298 cp/parser.c:36386
-#: cp/parser.c:36457 cp/parser.c:38721 cp/parser.c:38736 cp/parser.c:38752
-#: cp/parser.c:38768 cp/parser.c:38784 cp/parser.c:38811 cp/parser.c:38824
-#: cp/parser.c:38847 cp/parser.c:38860
+#: c/c-parser.c:16983 cp/parser.c:36001 cp/parser.c:36295 cp/parser.c:36383
+#: cp/parser.c:36454 cp/parser.c:38718 cp/parser.c:38733 cp/parser.c:38749
+#: cp/parser.c:38765 cp/parser.c:38781 cp/parser.c:38808 cp/parser.c:38821
+#: cp/parser.c:38844 cp/parser.c:38857
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "<this%>-sanaa ei voi käyttää tässä yhteydessä"
 
-#: c/c-parser.c:10972 cp/parser.c:38837
+#: c/c-parser.c:10972 cp/parser.c:38834
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: c/c-parser.c:11050 cp/parser.c:38918
+#: c/c-parser.c:11050 cp/parser.c:38915
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr ""
 
-#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38947 cp/parser.c:38980
+#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38944 cp/parser.c:38977
 #, fuzzy, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "Odotettiin =-merkkiä PARAMETER-lauseessa kohdassa %C"
 
-#: c/c-parser.c:11111 cp/parser.c:38711
+#: c/c-parser.c:11111 cp/parser.c:38708
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "roskaa ilmaisun %<#pragma GCC pch_preprocess%> lopussa"
 
-#: c/c-parser.c:11421 cp/parser.c:31457
+#: c/c-parser.c:11421 cp/parser.c:31454
 #, fuzzy, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "%s: liian monta arvoa"
 
-#: c/c-parser.c:11443 cp/parser.c:31994
+#: c/c-parser.c:11443 cp/parser.c:31991
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "expected integer expression before ')'"
@@ -38095,55 +38139,55 @@
 msgid "%qD is not a variable"
 msgstr "%qD ei ole muuttuja"
 
-#: c/c-parser.c:11746 cp/semantics.c:6808
+#: c/c-parser.c:11746 cp/semantics.c:6811
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qD is not a pointer variable"
 msgstr "%qD ei ole muuttuja"
 
-#: c/c-parser.c:11788 cp/parser.c:32073
+#: c/c-parser.c:11788 cp/parser.c:32070
 #, fuzzy, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr "etumerkillisen ja etumerkittömän kokonaislukulausekkeen vertailu"
 
-#: c/c-parser.c:11865 cp/parser.c:32137
+#: c/c-parser.c:11865 cp/parser.c:32134
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<none%> or %<present%>"
 msgstr "odotettiin %<none%> tai %<shared%>"
 
-#: c/c-parser.c:11867 cp/parser.c:32139
+#: c/c-parser.c:11867 cp/parser.c:32136
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "odotettiin %<none%> tai %<shared%>"
 
-#: c/c-parser.c:11968 cp/parser.c:32242
+#: c/c-parser.c:11968 cp/parser.c:32239
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "käytetty %<__thread%> ennen %<extern%>:a"
 
-#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32260
-#: cp/parser.c:36290 cp/parser.c:36378
+#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32257
+#: cp/parser.c:36287 cp/parser.c:36375
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%>"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: c/c-parser.c:12035 cp/parser.c:32313
+#: c/c-parser.c:12035 cp/parser.c:32310
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:12042 cp/parser.c:32320
+#: c/c-parser.c:12042 cp/parser.c:32317
 #, fuzzy, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr "%s: Liian monta argumenttia\n"
 
-#: c/c-parser.c:12044 cp/parser.c:32322
+#: c/c-parser.c:12044 cp/parser.c:32319
 #, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr ""
 
-#: c/c-parser.c:12050 cp/parser.c:32328
+#: c/c-parser.c:12050 cp/parser.c:32325
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -38166,90 +38210,90 @@
 msgid "%<num_tasks%> value must be positive"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: c/c-parser.c:12229 cp/semantics.c:6992
+#: c/c-parser.c:12229 cp/semantics.c:6995
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<grainsize%> value must be positive"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: c/c-parser.c:12276 cp/semantics.c:7021
+#: c/c-parser.c:12276 cp/semantics.c:7024
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<priority%> value must be non-negative"
 msgstr "UNIT-numeron lauseessa kohdassa %L täytyy olla epänegatiivinen"
 
-#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32545 cp/parser.c:32552
+#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32542 cp/parser.c:32549
 #, fuzzy, gcc-internal-format
 msgid "expected %<tofrom%>"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32561 cp/parser.c:32568
+#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32558 cp/parser.c:32565
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<decltype%>"
 msgid "expected %<scalar%>"
 msgstr "Odotettiin skalaarialustuslauseketta kohdassa %C"
 
-#: c/c-parser.c:12425 cp/semantics.c:6299
+#: c/c-parser.c:12425 cp/semantics.c:6302
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%qs expression must be integral"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6331
+#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6334
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%qs value must be positive"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: c/c-parser.c:12499 cp/parser.c:31853
+#: c/c-parser.c:12499 cp/parser.c:31850
 #, fuzzy, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "%s: liian monta argumenttia\n"
 
-#: c/c-parser.c:12533 cp/parser.c:31886
+#: c/c-parser.c:12533 cp/parser.c:31883
 #, fuzzy, gcc-internal-format
 msgid "unexpected argument"
 msgstr "%qs attribuuttia ei huomioida"
 
-#: c/c-parser.c:12699 cp/semantics.c:7120
+#: c/c-parser.c:12699 cp/semantics.c:7123
 #, fuzzy, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "%qE-attribuutti sallii vain kokonaislukuvakioargumentin"
 
-#: c/c-parser.c:12765 cp/parser.c:32626
+#: c/c-parser.c:12765 cp/parser.c:32623
 #, fuzzy, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr "etumerkillisen ja etumerkittömän kokonaislukulausekkeen vertailu"
 
-#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37643
+#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37640
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or %<max%>"
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "odotettiin tunnistetta tai %<(%>"
 
-#: c/c-parser.c:12967 cp/parser.c:32840
+#: c/c-parser.c:12967 cp/parser.c:32837
 #, fuzzy, gcc-internal-format
 #| msgid "both %<long%> and %<void%> in declaration specifiers"
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "sekä %<long%> että %<void%> esittelymääritteissä"
 
-#: c/c-parser.c:13021 cp/parser.c:32856
+#: c/c-parser.c:13021 cp/parser.c:32853
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:13025 cp/parser.c:32859
+#: c/c-parser.c:13025 cp/parser.c:32856
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:13037 cp/semantics.c:6389
+#: c/c-parser.c:13037 cp/semantics.c:6392
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "chunk size value must be positive"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: c/c-parser.c:13060 cp/parser.c:32879
+#: c/c-parser.c:13060 cp/parser.c:32876
 #, fuzzy, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "%qE määritelty vääränlaisena tunnisteena"
@@ -38260,13 +38304,13 @@
 msgid "%<num_teams%> value must be positive"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: c/c-parser.c:13226 cp/semantics.c:6479
+#: c/c-parser.c:13226 cp/semantics.c:6482
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<thread_limit%> value must be positive"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: c/c-parser.c:13271 cp/semantics.c:6589
+#: c/c-parser.c:13271 cp/semantics.c:6592
 #, fuzzy, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr "etumerkillisen ja etumerkittömän kokonaislukulausekkeen vertailu"
@@ -38286,17 +38330,17 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr "etumerkillisen ja etumerkittömän kokonaislukulausekkeen vertailu"
 
-#: c/c-parser.c:13584 cp/parser.c:33374 cp/parser.c:33599
+#: c/c-parser.c:13584 cp/parser.c:33371 cp/parser.c:33596
 #, fuzzy, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "%qE määritelty vääränlaisena tunnisteena"
 
-#: c/c-parser.c:13669 cp/parser.c:33447
+#: c/c-parser.c:13669 cp/parser.c:33444
 #, fuzzy, gcc-internal-format
 msgid "invalid map kind"
 msgstr "%qE määritelty vääränlaisena tunnisteena"
 
-#: c/c-parser.c:13767 cp/parser.c:33546
+#: c/c-parser.c:13767 cp/parser.c:33543
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_double operand"
 msgid "invalid dist_schedule kind"
@@ -38307,70 +38351,70 @@
 msgid "invalid proc_bind kind"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: c/c-parser.c:14059 cp/parser.c:33825
+#: c/c-parser.c:14059 cp/parser.c:33822
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<namespace%>"
 msgid "expected %<#pragma acc%> clause"
 msgstr "odotettiin merkkijonoa ilmaisun %<#pragma message%> jälkeen"
 
-#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33836 cp/parser.c:34143
+#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33833 cp/parser.c:34140
 #, fuzzy, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "Funktio %qs"
 
-#: c/c-parser.c:14214 cp/parser.c:34010
+#: c/c-parser.c:14214 cp/parser.c:34007
 #, fuzzy, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "käytetty sekä %<__thread%> että %qs"
 
-#: c/c-parser.c:14334 cp/parser.c:34132
+#: c/c-parser.c:14334 cp/parser.c:34129
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "odotettiin merkkijonoa ilmaisun %<#pragma message%> jälkeen"
 
-#: c/c-parser.c:14472 cp/parser.c:36803
+#: c/c-parser.c:14472 cp/parser.c:36800
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14482 cp/parser.c:36813
+#: c/c-parser.c:14482 cp/parser.c:36810
 #, fuzzy, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr "%Jluetellun tyypin jäsenen %qd uudelleenesittely"
 
-#: c/c-parser.c:14502 cp/parser.c:36833
+#: c/c-parser.c:14502 cp/parser.c:36830
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr "rajat määrittelemättömän taulukon epäkelpo käyttö"
 
-#: c/c-parser.c:14513 cp/parser.c:36844
+#: c/c-parser.c:14513 cp/parser.c:36841
 #, fuzzy, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr "muuttuja tai kenttä %qs esitelty tyhjäksi"
 
-#: c/c-parser.c:14520 cp/parser.c:36851
+#: c/c-parser.c:14520 cp/parser.c:36848
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "%<extern%>-muuttujan %qD esittely %<for%>-silmukan alkuesittelyssä"
 
-#: c/c-parser.c:14528 cp/parser.c:36859
+#: c/c-parser.c:14528 cp/parser.c:36856
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "rajat määrittelemättömän taulukon epäkelpo käyttö"
 
-#: c/c-parser.c:14540 cp/parser.c:36871
+#: c/c-parser.c:14540 cp/parser.c:36868
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14632 cp/parser.c:36957
+#: c/c-parser.c:14632 cp/parser.c:36954
 #, fuzzy, gcc-internal-format
 #| msgid "expected a string after %<#pragma message%>"
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "odotettiin merkkijonoa ilmaisun %<#pragma message%> jälkeen"
 
-#: c/c-parser.c:14648 cp/parser.c:36974
+#: c/c-parser.c:14648 cp/parser.c:36971
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
@@ -38385,7 +38429,7 @@
 msgid "expected function name"
 msgstr "odotettiin luokan nimeä"
 
-#: c/c-parser.c:14893 cp/parser.c:38064
+#: c/c-parser.c:14893 cp/parser.c:38061
 #, fuzzy, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr "funktiomalli %qD esitelty uudelleen luokkamallina"
@@ -38395,45 +38439,45 @@
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr "%Jvanhanmallinen funktiomäärittely"
 
-#: c/c-parser.c:14953 cp/parser.c:38118 cp/parser.c:38160
+#: c/c-parser.c:14953 cp/parser.c:38115 cp/parser.c:38157
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr "%Jvanhanmallinen funktiomäärittely"
 
-#: c/c-parser.c:14970 cp/parser.c:38174
+#: c/c-parser.c:14970 cp/parser.c:38171
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%<#pragma acc routine%> already applied to %qD"
 msgstr "#pragma GCC optimize ei ole sallittu funktioiden sisällä"
 
-#: c/c-parser.c:14979 cp/parser.c:38183
+#: c/c-parser.c:14979 cp/parser.c:38180
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr "#pragma GCC optimize ei ole sallittu funktioiden sisällä"
 
-#: c/c-parser.c:14980 cp/parser.c:38184
+#: c/c-parser.c:14980 cp/parser.c:38181
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "#pragma GCC optimize ei ole sallittu funktioiden sisällä"
 
-#: c/c-parser.c:15023 cp/parser.c:37152
+#: c/c-parser.c:15023 cp/parser.c:37149
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
 
-#: c/c-parser.c:15435 cp/parser.c:34511 cp/parser.c:34537
+#: c/c-parser.c:15435 cp/parser.c:34508 cp/parser.c:34534
 #, fuzzy, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "roskaa ilmaisun %<#pragma pack%> lopussa"
 
-#: c/c-parser.c:15439 cp/parser.c:34568 cp/parser.c:34584
+#: c/c-parser.c:15439 cp/parser.c:34565 cp/parser.c:34581
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr ""
 
-#: c/c-parser.c:15488 cp/semantics.c:8401 cp/semantics.c:8411
+#: c/c-parser.c:15488 cp/semantics.c:8404 cp/semantics.c:8414
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
@@ -38443,22 +38487,22 @@
 msgid "expected %<(%> or end of line"
 msgstr "odotettiin %<(%> tai rivin loppu"
 
-#: c/c-parser.c:15619 cp/parser.c:35103
+#: c/c-parser.c:15619 cp/parser.c:35100
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:15630 cp/parser.c:35114
+#: c/c-parser.c:15630 cp/parser.c:35111
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:15648 cp/parser.c:35141
+#: c/c-parser.c:15648 cp/parser.c:35138
 #, fuzzy, gcc-internal-format
 msgid "for statement expected"
 msgstr "%s-lausetta odotettiin kohdassa %L"
 
-#: c/c-parser.c:15718 cp/semantics.c:8066 cp/semantics.c:8153
+#: c/c-parser.c:15718 cp/semantics.c:8069 cp/semantics.c:8156
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "odotettiin iteraatioesittelyä tai -alustusta"
@@ -38468,27 +38512,27 @@
 msgid "not enough perfectly nested loops"
 msgstr ""
 
-#: c/c-parser.c:15862 cp/parser.c:35364
+#: c/c-parser.c:15862 cp/parser.c:35361
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.c:15909 cp/parser.c:35184 cp/parser.c:35226 cp/pt.c:16385
+#: c/c-parser.c:15909 cp/parser.c:35181 cp/parser.c:35223 cp/pt.c:16407
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "sisäkkäisessä funktiossa käytetty rekisterimuuttujaa %qD"
 
-#: c/c-parser.c:16000 cp/parser.c:35437
+#: c/c-parser.c:16000 cp/parser.c:35434
 #, fuzzy, gcc-internal-format
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "%<void%> vain parametrina ei ole oikeutettu"
 
-#: c/c-parser.c:16166 cp/parser.c:35600
+#: c/c-parser.c:16166 cp/parser.c:35597
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:16374 cp/parser.c:35799
+#: c/c-parser.c:16374 cp/parser.c:35796
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<operator%>"
 msgid "expected %<for%> after %qs"
@@ -38495,47 +38539,47 @@
 msgstr "tiedostonimi puuttuu %qs:n jälkeen"
 
 # XXXXXXX
-#: c/c-parser.c:16573 cp/parser.c:35995
+#: c/c-parser.c:16573 cp/parser.c:35992
 #, fuzzy, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: c/c-parser.c:16793 cp/parser.c:36232
+#: c/c-parser.c:16793 cp/parser.c:36229
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16806 cp/parser.c:36245
+#: c/c-parser.c:16806 cp/parser.c:36242
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16853 cp/parser.c:36470
+#: c/c-parser.c:16853 cp/parser.c:36467
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:16925 cp/parser.c:36325
+#: c/c-parser.c:16925 cp/parser.c:36322
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16937 cp/parser.c:36337
+#: c/c-parser.c:16937 cp/parser.c:36334
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17011 cp/parser.c:36414
+#: c/c-parser.c:17011 cp/parser.c:36411
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17024 cp/parser.c:36427
+#: c/c-parser.c:17024 cp/parser.c:36424
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17238 cp/parser.c:36680
+#: c/c-parser.c:17238 cp/parser.c:36677
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -38555,33 +38599,33 @@
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17395 cp/parser.c:37273
+#: c/c-parser.c:17395 cp/parser.c:37270
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17474 cp/parser.c:37343
+#: c/c-parser.c:17474 cp/parser.c:37340
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> with clauses in between %<#pragma omp declare target%> without clauses and %<#pragma omp end declare target%>"
 msgstr ""
 
-#: c/c-parser.c:17493 cp/parser.c:37362
+#: c/c-parser.c:17493 cp/parser.c:37359
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17534 cp/parser.c:37409
+#: c/c-parser.c:17534 cp/parser.c:37406
 #, fuzzy, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "# Ei kohde:"
 
-#: c/c-parser.c:17541 cp/parser.c:37416
+#: c/c-parser.c:17541 cp/parser.c:37413
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<decltype%>"
 msgid "expected %<declare%>"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: c/c-parser.c:17547 cp/parser.c:37423
+#: c/c-parser.c:17547 cp/parser.c:37420
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr ""
@@ -38639,47 +38683,47 @@
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:17947 cp/parser.c:37868
+#: c/c-parser.c:17947 cp/parser.c:37865
 #, fuzzy, gcc-internal-format
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr "%qs määrittää %<auto%>:n tiedostoalue-esittelyssä"
 
-#: c/c-parser.c:18162 cp/semantics.c:7531
+#: c/c-parser.c:18162 cp/semantics.c:7534
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr ""
 
-#: c/c-parser.c:18164 cp/semantics.c:7533
+#: c/c-parser.c:18164 cp/semantics.c:7536
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "automaattimuuttuja %qE ei voi olla %<threadprivate%>"
 
-#: c/c-parser.c:18168 cp/semantics.c:7535
+#: c/c-parser.c:18168 cp/semantics.c:7538
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "parametrilla %u in vaillinainen tyyppi"
 
-#: c/c-parser.c:18368 cp/parser.c:38565
+#: c/c-parser.c:18368 cp/parser.c:38562
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:18374 cp/parser.c:38571
+#: c/c-parser.c:18374 cp/parser.c:38568
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
 
-#: c/c-parser.c:18383 cp/parser.c:38580
+#: c/c-parser.c:18383 cp/parser.c:38577
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.c:18385 cp/parser.c:38583
+#: c/c-parser.c:18385 cp/parser.c:38580
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.c:18391 cp/parser.c:38589
+#: c/c-parser.c:18391 cp/parser.c:38586
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
@@ -38696,7 +38740,7 @@
 msgid "%qD has an incomplete type %qT"
 msgstr "%2$qD:n parametrilla %1$P on vaillinainen tyyppi %3$qT"
 
-#: c/c-typeck.c:237 c/c-typeck.c:9994 c/c-typeck.c:10036 cp/call.c:4147
+#: c/c-typeck.c:237 c/c-typeck.c:9999 c/c-typeck.c:10041 cp/call.c:4147
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "void-lausekkeen epäkelpo käyttö"
@@ -38774,13 +38818,13 @@
 msgid "converting an array compound literal to a pointer is ill-formed in C++"
 msgstr ""
 
-#: c/c-typeck.c:2417 c/c-typeck.c:8641
+#: c/c-typeck.c:2417 c/c-typeck.c:8646
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%qT has no member named %qE; did you mean %qE?"
 msgstr "tyypillä %qT ei ole %qE-nimistä jäsentä"
 
-#: c/c-typeck.c:2421 c/c-typeck.c:8645
+#: c/c-typeck.c:2421 c/c-typeck.c:8650
 #, gcc-internal-format
 msgid "%qT has no member named %qE"
 msgstr "tyypillä %qT ei ole %qE-nimistä jäsentä"
@@ -38981,477 +39025,477 @@
 msgstr "vähennyslaskussa käytetty osoitinta funktioon"
 
 # XXX
-#: c/c-typeck.c:3847
+#: c/c-typeck.c:3852
 #, fuzzy, gcc-internal-format
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "%<void *%>-tyyppistä osoitinta käytetty laskutoimituksessa"
 
-#: c/c-typeck.c:3852 cp/typeck.c:5562
+#: c/c-typeck.c:3857 cp/typeck.c:5562
 #, fuzzy, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr "funktio-osoitinta käytetty laskutoimituksessa"
 
-#: c/c-typeck.c:4283
+#: c/c-typeck.c:4288
 #, fuzzy, gcc-internal-format
 msgid "%<~%> on a boolean expression"
 msgstr "odotettiin lauseketta"
 
-#: c/c-typeck.c:4287
+#: c/c-typeck.c:4292
 #, gcc-internal-format
 msgid "did you mean to use logical not?"
 msgstr ""
 
-#: c/c-typeck.c:4296
+#: c/c-typeck.c:4301
 #, gcc-internal-format
 msgid "ISO C does not support %<~%> for complex conjugation"
 msgstr "ISO C ei tue %<~%>-merkkiä kompleksikonjugaateissa"
 
-#: c/c-typeck.c:4335
+#: c/c-typeck.c:4340
 #, gcc-internal-format
 msgid "wrong type argument to unary exclamation mark"
 msgstr "unaariselle huutomerkille annettu väärä tyyppiargumentti"
 
-#: c/c-typeck.c:4393
+#: c/c-typeck.c:4398
 #, gcc-internal-format
 msgid "increment of enumeration value is invalid in C++"
 msgstr "luetellun arvon kasvattaminen on virhe C++:ssa"
 
-#: c/c-typeck.c:4396
+#: c/c-typeck.c:4401
 #, gcc-internal-format
 msgid "decrement of enumeration value is invalid in C++"
 msgstr "luetellun arvon vähentäminen on virhe C++:ssa"
 
-#: c/c-typeck.c:4403
+#: c/c-typeck.c:4408
 #, fuzzy, gcc-internal-format
 msgid "increment of a boolean expression"
 msgstr "odotettiin lauseketta"
 
-#: c/c-typeck.c:4406
+#: c/c-typeck.c:4411
 #, fuzzy, gcc-internal-format
 msgid "decrement of a boolean expression"
 msgstr "odotettiin lauseketta"
 
-#: c/c-typeck.c:4422
+#: c/c-typeck.c:4427
 #, gcc-internal-format
 msgid "ISO C does not support %<++%> and %<--%> on complex types"
 msgstr "ISO C ei tue kompleksityyppien %<++%>- ja %<--%>-operaatioita"
 
-#: c/c-typeck.c:4447 c/c-typeck.c:4481
+#: c/c-typeck.c:4452 c/c-typeck.c:4486
 #, gcc-internal-format
 msgid "wrong type argument to increment"
 msgstr "lisäykselle annettu väärä tyyppiargumentti"
 
-#: c/c-typeck.c:4449 c/c-typeck.c:4484
+#: c/c-typeck.c:4454 c/c-typeck.c:4489
 #, gcc-internal-format
 msgid "wrong type argument to decrement"
 msgstr "vähennykselle annettu väärä tyyppiargumentti"
 
-#: c/c-typeck.c:4469
+#: c/c-typeck.c:4474
 #, fuzzy, gcc-internal-format
 #| msgid "cannot increment a pointer to incomplete type %qT"
 msgid "increment of pointer to an incomplete type %qT"
 msgstr "ei voida kasvattaa osoitinta vaillinaiseen tyyppiin %qT"
 
-#: c/c-typeck.c:4473
+#: c/c-typeck.c:4478
 #, fuzzy, gcc-internal-format
 #| msgid "cannot decrement a pointer to incomplete type %qT"
 msgid "decrement of pointer to an incomplete type %qT"
 msgstr "ei voida vähentää osoitinta vaillinaiseen tyyppiin %qT"
 
-#: c/c-typeck.c:4577
+#: c/c-typeck.c:4582
 #, gcc-internal-format
 msgid "taking address of expression of type %<void%>"
 msgstr ""
 
-#: c/c-typeck.c:4636
+#: c/c-typeck.c:4641
 #, gcc-internal-format
 msgid "cannot take address of bit-field %qD"
 msgstr "bittikentän %qD osoitetta ei voi ottaa"
 
-#: c/c-typeck.c:4649
+#: c/c-typeck.c:4654
 #, gcc-internal-format
 msgid "cannot take address of scalar with reverse storage order"
 msgstr ""
 
-#: c/c-typeck.c:4657
+#: c/c-typeck.c:4662
 #, fuzzy, gcc-internal-format
 #| msgid "address of register variable %qD requested"
 msgid "address of array with reverse scalar storage order requested"
 msgstr "halutaan rekisterimuuttujan %qD osoite"
 
-#: c/c-typeck.c:4838
+#: c/c-typeck.c:4843
 #, gcc-internal-format
 msgid "global register variable %qD used in nested function"
 msgstr "sisäkkäisessä funktiossa käytetty globaalia rekisterimuuttujaa %qD"
 
-#: c/c-typeck.c:4841
+#: c/c-typeck.c:4846
 #, gcc-internal-format
 msgid "register variable %qD used in nested function"
 msgstr "sisäkkäisessä funktiossa käytetty rekisterimuuttujaa %qD"
 
-#: c/c-typeck.c:4846
+#: c/c-typeck.c:4851
 #, gcc-internal-format
 msgid "address of global register variable %qD requested"
 msgstr "halutaan globaalin rekisterimuuttujan %qD osoite"
 
-#: c/c-typeck.c:4848
+#: c/c-typeck.c:4853
 #, gcc-internal-format
 msgid "address of register variable %qD requested"
 msgstr "halutaan rekisterimuuttujan %qD osoite"
 
-#: c/c-typeck.c:4951
+#: c/c-typeck.c:4956
 #, gcc-internal-format
 msgid "non-lvalue array in conditional expression"
 msgstr "ehtolausekkeessa ei-lvalue-taulukko"
 
-#: c/c-typeck.c:5033
+#: c/c-typeck.c:5038
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other result of conditional"
 msgstr ""
 
-#: c/c-typeck.c:5092 c/c-typeck.c:5098
+#: c/c-typeck.c:5097 c/c-typeck.c:5103
 #, gcc-internal-format
 msgid "operand of ?: changes signedness from %qT to %qT due to unsignedness of other operand"
 msgstr ""
 
-#: c/c-typeck.c:5115
+#: c/c-typeck.c:5120
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr with only one void side"
 msgstr "ISO C kieltää ehtolausekkeet, joissa on vain yksi tyhjä puoli"
 
-#: c/c-typeck.c:5132
+#: c/c-typeck.c:5137
 #, fuzzy, gcc-internal-format
 msgid "pointers to disjoint address spaces used in conditional expression"
 msgstr "ehtolausekkeessa on osoitintyyppiristiriita"
 
-#: c/c-typeck.c:5143 c/c-typeck.c:5160
+#: c/c-typeck.c:5148 c/c-typeck.c:5165
 #, fuzzy, gcc-internal-format
 #| msgid "pointer type mismatch in conditional expression"
 msgid "pointer to array loses qualifier in conditional expression"
 msgstr "ehtolausekkeessa on osoitintyyppiristiriita"
 
-#: c/c-typeck.c:5148 c/c-typeck.c:5165
+#: c/c-typeck.c:5153 c/c-typeck.c:5170
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr between %<void *%> and function pointer"
 msgstr "ISO C kieltää ehtolausekkeet %<void *%>-tyypin ja funktio-osoittimen välillä"
 
-#: c/c-typeck.c:5178
+#: c/c-typeck.c:5183
 #, gcc-internal-format
 msgid "pointer type mismatch in conditional expression"
 msgstr "ehtolausekkeessa on osoitintyyppiristiriita"
 
-#: c/c-typeck.c:5187 c/c-typeck.c:5198
+#: c/c-typeck.c:5192 c/c-typeck.c:5203
 #, gcc-internal-format
 msgid "pointer/integer type mismatch in conditional expression"
 msgstr "ehtolausekkeessa on osoitin/kokonaislukutyyppiristiriita"
 
-#: c/c-typeck.c:5336
+#: c/c-typeck.c:5341
 #, gcc-internal-format
 msgid "left-hand operand of comma expression has no effect"
 msgstr "pilkkulausekkeen vasemmalla operandilla ei ole vaikutusta"
 
-#: c/c-typeck.c:5354 c/c-typeck.c:10636
+#: c/c-typeck.c:5359 c/c-typeck.c:10641
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "right-hand operand of comma expression has no effect"
 msgstr "pilkkulausekkeen vasemmalla operandilla ei ole vaikutusta"
 
-#: c/c-typeck.c:5423
+#: c/c-typeck.c:5428
 #, fuzzy
 msgid "cast adds %q#v qualifier to function type"
 msgstr "tyyppimuunnos lisää funktiotyyppiin uusia määreitä"
 
-#: c/c-typeck.c:5429
+#: c/c-typeck.c:5434
 #, fuzzy
 msgid "cast discards %qv qualifier from pointer target type"
 msgstr "osoitinkohdetyypin määreitä häviää tyyppimuunnoksessa"
 
-#: c/c-typeck.c:5464
+#: c/c-typeck.c:5469
 #, gcc-internal-format
 msgid "to be safe all intermediate pointers in cast from %qT to %qT must be %<const%> qualified"
 msgstr ""
 
-#: c/c-typeck.c:5554
+#: c/c-typeck.c:5559
 #, gcc-internal-format
 msgid "cast specifies array type"
 msgstr "tyyppimuunnos määrittää taulukkotyypin"
 
-#: c/c-typeck.c:5560
+#: c/c-typeck.c:5565
 #, gcc-internal-format
 msgid "cast specifies function type"
 msgstr "tyyppimuunnos määrittää funktiotyypin"
 
-#: c/c-typeck.c:5575
+#: c/c-typeck.c:5580
 #, gcc-internal-format
 msgid "ISO C forbids casting nonscalar to the same type"
 msgstr "ISO C kieltää tyyppimuuntamasta ei-skalaaria samaksi tyypiksi"
 
-#: c/c-typeck.c:5595
+#: c/c-typeck.c:5600
 #, gcc-internal-format
 msgid "ISO C forbids casts to union type"
 msgstr "ISO C kieltää tyyppimuunnokset unionityyppeihin"
 
-#: c/c-typeck.c:5605
+#: c/c-typeck.c:5610
 #, gcc-internal-format
 msgid "cast to union type from type not present in union"
 msgstr "unioniin kuulumattoman tyypin muunnos unionityypiksi"
 
-#: c/c-typeck.c:5640
+#: c/c-typeck.c:5645
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint generic address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5645
+#: c/c-typeck.c:5650
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to generic address space pointer from disjoint %s address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5650
+#: c/c-typeck.c:5655
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint %s address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5670
+#: c/c-typeck.c:5675
 #, gcc-internal-format
 msgid "cast increases required alignment of target type"
 msgstr "kohdetyypin vaatima kohdistus kasvaa tyyppimuunnoksessa"
 
-#: c/c-typeck.c:5681
+#: c/c-typeck.c:5686
 #, gcc-internal-format
 msgid "cast from pointer to integer of different size"
 msgstr "tyyppimuunnos osoittimesta erikokoiseen kokonaislukuun"
 
-#: c/c-typeck.c:5686
+#: c/c-typeck.c:5691
 #, gcc-internal-format
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "tyyppimuunnos %qT-tyyppisestä funktiokutsusta yhteensopimattomaan tyyppiin %qT"
 
-#: c/c-typeck.c:5695 cp/typeck.c:7811
+#: c/c-typeck.c:5700 cp/typeck.c:7811
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "tyyppimuunnos erikokoisesta kokonaisluvusta osoittimeksi"
 
-#: c/c-typeck.c:5709
+#: c/c-typeck.c:5714
 #, gcc-internal-format
 msgid "ISO C forbids conversion of function pointer to object pointer type"
 msgstr "ISO C kieltää funktio-osoittimen muuntamisen objektiosoitintyypiksi"
 
-#: c/c-typeck.c:5718
+#: c/c-typeck.c:5723
 #, gcc-internal-format
 msgid "ISO C forbids conversion of object pointer to function pointer type"
 msgstr "ISO C kieltää objektiosoittimen muuntamisen funktio-osoitintyypiksi"
 
-#: c/c-typeck.c:5728
+#: c/c-typeck.c:5733
 #, fuzzy, gcc-internal-format
 msgid "cast between incompatible function types from %qT to %qT"
 msgstr "ei voi muuntaa tyyppiä %qT tyypiksi %qT"
 
-#: c/c-typeck.c:5815
+#: c/c-typeck.c:5820
 #, gcc-internal-format
 msgid "defining a type in a cast is invalid in C++"
 msgstr "tyypin määritteleminen tyyppimuunnoksessa on virheellistä C++-kielessä"
 
-#: c/c-typeck.c:5856
+#: c/c-typeck.c:5861
 #, fuzzy, gcc-internal-format
 msgid "assignment to expression with array type"
 msgstr "virheellinen taulukkosijoitus"
 
-#: c/c-typeck.c:5982
+#: c/c-typeck.c:5987
 #, gcc-internal-format
 msgid "enum conversion in assignment is invalid in C++"
 msgstr "enum-muunnos sijoituksessa on virheellistä C++-kielessä"
 
-#: c/c-typeck.c:6180 c/c-typeck.c:6202 c/c-typeck.c:6226
+#: c/c-typeck.c:6185 c/c-typeck.c:6207 c/c-typeck.c:6231
 #, gcc-internal-format
 msgid "(near initialization for %qs)"
 msgstr "(%qs:n alustuksen lähistöllä)"
 
-#: c/c-typeck.c:6241
+#: c/c-typeck.c:6246
 #, gcc-internal-format
 msgid "array initialized from parenthesized string constant"
 msgstr "taulukko alustetaan suluilla ympäröidystä merkkijonovakiosta"
 
-#: c/c-typeck.c:6284 c/c-typeck.c:6476 c/c-typeck.c:6908
+#: c/c-typeck.c:6289 c/c-typeck.c:6481 c/c-typeck.c:6913
 #, gcc-internal-format
 msgid "expected %qT but argument is of type %qT"
 msgstr "odotettiin %qT, mutta argumentti on tyyppiä %qT"
 
-#: c/c-typeck.c:6471
+#: c/c-typeck.c:6476
 #, gcc-internal-format
 msgid "enum conversion when passing argument %d of %qE is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:6480
+#: c/c-typeck.c:6485
 #, fuzzy, gcc-internal-format
 #| msgid "enum conversion in assignment is invalid in C++"
 msgid "enum conversion from %qT to %qT in assignment is invalid in C++"
 msgstr "enum-muunnos sijoituksessa on virheellistä C++-kielessä"
 
-#: c/c-typeck.c:6484
+#: c/c-typeck.c:6489
 #, fuzzy, gcc-internal-format
 #| msgid "enum conversion in initialization is invalid in C++"
 msgid "enum conversion from %qT to %qT in initialization is invalid in C++"
 msgstr "enum-muunnos alustuksessa on virheellistä C++-kielessä"
 
-#: c/c-typeck.c:6489
+#: c/c-typeck.c:6494
 #, fuzzy, gcc-internal-format
 #| msgid "enum conversion in return is invalid in C++"
 msgid "enum conversion from %qT to %qT in return is invalid in C++"
 msgstr "enum-muunnos palautuksessa on virheellistä C++-kielessä"
 
-#: c/c-typeck.c:6523
+#: c/c-typeck.c:6528
 #, gcc-internal-format
 msgid "cannot pass rvalue to reference parameter"
 msgstr ""
 
-#: c/c-typeck.c:6656 c/c-typeck.c:6942
+#: c/c-typeck.c:6661 c/c-typeck.c:6947
 #, fuzzy
 msgid "passing argument %d of %qE makes %q#v qualified function pointer from unqualified"
 msgstr "argumentin %d antaminen funktiolle %qE tekee kokonaisluvusta osoittimen ilman tyyppimuunnosta"
 
-#: c/c-typeck.c:6659 c/c-typeck.c:6945
+#: c/c-typeck.c:6664 c/c-typeck.c:6950
 #, fuzzy
 msgid "assignment makes %q#v qualified function pointer from unqualified"
 msgstr "sijoitus hylkää kohdeosoitintyypin määreitä"
 
-#: c/c-typeck.c:6662 c/c-typeck.c:6947
+#: c/c-typeck.c:6667 c/c-typeck.c:6952
 #, fuzzy
 msgid "initialization makes %q#v qualified function pointer from unqualified"
 msgstr "alustus hylkää kohdeosoitintyypin määreitä"
 
-#: c/c-typeck.c:6665 c/c-typeck.c:6949
+#: c/c-typeck.c:6670 c/c-typeck.c:6954
 msgid "return makes %q#v qualified function pointer from unqualified"
 msgstr ""
 
-#: c/c-typeck.c:6673 c/c-typeck.c:6840 c/c-typeck.c:6883
+#: c/c-typeck.c:6678 c/c-typeck.c:6845 c/c-typeck.c:6888
 #, fuzzy
 msgid "passing argument %d of %qE discards %qv qualifier from pointer target type"
 msgstr "sijoitus hylkää kohdeosoitintyypin määreitä"
 
-#: c/c-typeck.c:6675 c/c-typeck.c:6842 c/c-typeck.c:6885
+#: c/c-typeck.c:6680 c/c-typeck.c:6847 c/c-typeck.c:6890
 #, fuzzy
 msgid "assignment discards %qv qualifier from pointer target type"
 msgstr "sijoitus hylkää kohdeosoitintyypin määreitä"
 
-#: c/c-typeck.c:6677 c/c-typeck.c:6844 c/c-typeck.c:6887
+#: c/c-typeck.c:6682 c/c-typeck.c:6849 c/c-typeck.c:6892
 #, fuzzy
 msgid "initialization discards %qv qualifier from pointer target type"
 msgstr "alustus hylkää kohdeosoitintyypin määreitä"
 
-#: c/c-typeck.c:6679 c/c-typeck.c:6846 c/c-typeck.c:6889
+#: c/c-typeck.c:6684 c/c-typeck.c:6851 c/c-typeck.c:6894
 #, fuzzy
 msgid "return discards %qv qualifier from pointer target type"
 msgstr "palautus hylkää kohdeosoitintyypin määreitä"
 
-#: c/c-typeck.c:6688
+#: c/c-typeck.c:6693
 #, gcc-internal-format
 msgid "ISO C prohibits argument conversion to union type"
 msgstr "ISO C kieltää argumenttien muuntamisen unionityypiksi"
 
-#: c/c-typeck.c:6750
+#: c/c-typeck.c:6755
 #, gcc-internal-format
 msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgstr ""
 
-#: c/c-typeck.c:6762
+#: c/c-typeck.c:6767
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE from pointer to non-enclosed address space"
 msgstr "annettu yhteensopimatonta osoitintyyppiä oleva %d. argumentti funktiolle %qE"
 
-#: c/c-typeck.c:6766
+#: c/c-typeck.c:6771
 #, fuzzy, gcc-internal-format
 msgid "assignment from pointer to non-enclosed address space"
 msgstr "tyyppimuunnos osoittimesta erikokoiseen kokonaislukuun"
 
-#: c/c-typeck.c:6770
+#: c/c-typeck.c:6775
 #, fuzzy, gcc-internal-format
 msgid "initialization from pointer to non-enclosed address space"
 msgstr "alustus yhteensopimattomasta osoitintyypistä"
 
-#: c/c-typeck.c:6774
+#: c/c-typeck.c:6779
 #, gcc-internal-format
 msgid "return from pointer to non-enclosed address space"
 msgstr ""
 
-#: c/c-typeck.c:6792
+#: c/c-typeck.c:6797
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE might be a candidate for a format attribute"
 msgstr "funktiokutsun argumentti voi olla ehdokas muotoiluattribuutille"
 
-#: c/c-typeck.c:6798
+#: c/c-typeck.c:6803
 #, fuzzy, gcc-internal-format
 msgid "assignment left-hand side might be a candidate for a format attribute"
 msgstr "funktio on ehkä mahdollinen ehdokas %qs-muotoiluattribuutille"
 
-#: c/c-typeck.c:6803
+#: c/c-typeck.c:6808
 #, fuzzy, gcc-internal-format
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "funktio on ehkä mahdollinen ehdokas %qs-muotoiluattribuutille"
 
-#: c/c-typeck.c:6808 cp/typeck.c:8891
+#: c/c-typeck.c:6813 cp/typeck.c:8891
 #, fuzzy, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "funktio on ehkä mahdollinen ehdokas %qs-muotoiluattribuutille"
 
-#: c/c-typeck.c:6857
+#: c/c-typeck.c:6862
 #, gcc-internal-format
 msgid "ISO C forbids passing argument %d of %qE between function pointer and %<void *%>"
 msgstr ""
 
-#: c/c-typeck.c:6860
+#: c/c-typeck.c:6865
 #, gcc-internal-format
 msgid "ISO C forbids assignment between function pointer and %<void *%>"
 msgstr "ISO C kieltää funktio-osoittimen ja %<void *%>-tyypin väliset sijoitukset"
 
-#: c/c-typeck.c:6862
+#: c/c-typeck.c:6867
 #, gcc-internal-format
 msgid "ISO C forbids initialization between function pointer and %<void *%>"
 msgstr "ISO C kieltää funktio-osoittimen ja %<void *%>-tyypin väliset alustukset"
 
-#: c/c-typeck.c:6864
+#: c/c-typeck.c:6869
 #, gcc-internal-format
 msgid "ISO C forbids return between function pointer and %<void *%>"
 msgstr "ISO C kieltää funktio-osoittimen ja %<void *%>-tyypin väliset palautukset"
 
-#: c/c-typeck.c:6904
+#: c/c-typeck.c:6909
 #, gcc-internal-format
 msgid "pointer targets in passing argument %d of %qE differ in signedness"
 msgstr ""
 
-#: c/c-typeck.c:6913
+#: c/c-typeck.c:6918
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible types in assignment of %qT to %qT"
 msgid "pointer targets in assignment from %qT to %qT differ in signedness"
 msgstr "vaillinaiset tyypit %qT:n sijoituksessa tyyppiin %qT"
 
-#: c/c-typeck.c:6918
+#: c/c-typeck.c:6923
 #, gcc-internal-format
 msgid "pointer targets in initialization of %qT from %qT differ in signedness"
 msgstr ""
 
-#: c/c-typeck.c:6923
+#: c/c-typeck.c:6928
 #, gcc-internal-format
 msgid "pointer targets in returning %qT from a function with return type %qT differ in signedness"
 msgstr ""
 
-#: c/c-typeck.c:6961
+#: c/c-typeck.c:6966
 #, gcc-internal-format
 msgid "passing argument %d of %qE from incompatible pointer type"
 msgstr "annettu yhteensopimatonta osoitintyyppiä oleva %d. argumentti funktiolle %qE"
 
-#: c/c-typeck.c:6967
+#: c/c-typeck.c:6972
 #, fuzzy, gcc-internal-format
 #| msgid "assignment from incompatible pointer type"
 msgid "assignment to %qT from incompatible pointer type %qT"
 msgstr "sijoitus yhteensopimattomasta osoitintyypistä"
 
-#: c/c-typeck.c:6972
+#: c/c-typeck.c:6977
 #, fuzzy, gcc-internal-format
 #| msgid "initialization from incompatible pointer type"
 msgid "initialization of %qT from incompatible pointer type %qT"
 msgstr "alustus yhteensopimattomasta osoitintyypistä"
 
-#: c/c-typeck.c:6977
+#: c/c-typeck.c:6982
 #, fuzzy, gcc-internal-format
 msgid "returning %qT from a function with incompatible return type %qT"
 msgstr "funktion paluuarvon tyyppi ei voi olla funktio"
@@ -39458,802 +39502,802 @@
 
 #. ??? This should not be an error when inlining calls to
 #. unprototyped functions.
-#: c/c-typeck.c:6991 c/c-typeck.c:7514 cp/typeck.c:2063
+#: c/c-typeck.c:6996 c/c-typeck.c:7519 cp/typeck.c:2063
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "ehtolausekkeessa ei-lvalue-taulukko"
 
-#: c/c-typeck.c:7004
+#: c/c-typeck.c:7009
 #, gcc-internal-format
 msgid "passing argument %d of %qE makes pointer from integer without a cast"
 msgstr "argumentin %d antaminen funktiolle %qE tekee kokonaisluvusta osoittimen ilman tyyppimuunnosta"
 
-#: c/c-typeck.c:7010
+#: c/c-typeck.c:7015
 #, fuzzy, gcc-internal-format
 #| msgid "assignment makes pointer from integer without a cast"
 msgid "assignment to %qT from %qT makes pointer from integer without a cast"
 msgstr "sijoituksessa tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: c/c-typeck.c:7015
+#: c/c-typeck.c:7020
 #, fuzzy, gcc-internal-format
 #| msgid "initialization makes pointer from integer without a cast"
 msgid "initialization of %qT from %qT makes pointer from integer without a cast"
 msgstr "alustuksessa tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: c/c-typeck.c:7019
+#: c/c-typeck.c:7024
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE makes pointer from integer without a cast"
 msgid "returning %qT from a function with return type %qT makes pointer from integer without a cast"
 msgstr "argumentin %d antaminen funktiolle %qE tekee kokonaisluvusta osoittimen ilman tyyppimuunnosta"
 
-#: c/c-typeck.c:7035
+#: c/c-typeck.c:7040
 #, gcc-internal-format
 msgid "passing argument %d of %qE makes integer from pointer without a cast"
 msgstr "argumentin %d antaminen funktiolle %qE tekee kokonaisluvusta osoittimen ilman tyyppimuunnosta"
 
-#: c/c-typeck.c:7041
+#: c/c-typeck.c:7046
 #, fuzzy, gcc-internal-format
 #| msgid "assignment makes integer from pointer without a cast"
 msgid "assignment to %qT from %qT makes integer from pointer without a cast"
 msgstr "sijoitus tekee osoittimesta kokonaisluvun ilman tyyppimuunnosta"
 
-#: c/c-typeck.c:7046
+#: c/c-typeck.c:7051
 #, fuzzy, gcc-internal-format
 #| msgid "initialization makes integer from pointer without a cast"
 msgid "initialization of %qT from %qT makes integer from pointer without a cast"
 msgstr "alustus tekee osoittimesta kokonaisluvun ilman tyyppimuunnosta"
 
-#: c/c-typeck.c:7050
+#: c/c-typeck.c:7055
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE makes integer from pointer without a cast"
 msgid "returning %qT from a function with return type %qT makes integer from pointer without a cast"
 msgstr "argumentin %d antaminen funktiolle %qE tekee kokonaisluvusta osoittimen ilman tyyppimuunnosta"
 
-#: c/c-typeck.c:7073
+#: c/c-typeck.c:7078
 #, gcc-internal-format
 msgid "incompatible type for argument %d of %qE"
 msgstr "funktiolle %2$qE annettu argumentin %1$d tyyppi on yhteensopimaton"
 
-#: c/c-typeck.c:7078
+#: c/c-typeck.c:7083
 #, gcc-internal-format
 msgid "incompatible types when assigning to type %qT from type %qT"
 msgstr "yhteensopimattomat tyypit sijoituksessa tyyppiin %qT tyypistä %qT"
 
-#: c/c-typeck.c:7083
+#: c/c-typeck.c:7088
 #, gcc-internal-format
 msgid "incompatible types when initializing type %qT using type %qT"
 msgstr "yhteensopimattomat tyypit alustettaessa tyyppiä %qT käyttäen tyyppiä %qT"
 
-#: c/c-typeck.c:7088
+#: c/c-typeck.c:7093
 #, fuzzy, gcc-internal-format
 msgid "incompatible types when returning type %qT but %qT was expected"
 msgstr "yhteensopimattomat tyypit alustettaessa tyyppiä %qT käyttäen tyyppiä %qT"
 
-#: c/c-typeck.c:7152
+#: c/c-typeck.c:7157
 #, gcc-internal-format
 msgid "traditional C rejects automatic aggregate initialization"
 msgstr "perinteinen C ei hyväksy automaattista koostealustusta"
 
-#: c/c-typeck.c:7388 c/c-typeck.c:8284 cp/typeck2.c:1045
+#: c/c-typeck.c:7393 c/c-typeck.c:8289 cp/typeck2.c:1045
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "joustavan taulukkojäsenen alustus"
 
-#: c/c-typeck.c:7398 cp/typeck2.c:1059
+#: c/c-typeck.c:7403 cp/typeck2.c:1059
 #, gcc-internal-format
 msgid "char-array initialized from wide string"
 msgstr "merkkitaulukon alustus leveästä merkkijonosta"
 
-#: c/c-typeck.c:7407
+#: c/c-typeck.c:7412
 #, gcc-internal-format
 msgid "wide character array initialized from non-wide string"
 msgstr "leveän merkkitaulukon alustus epäleveästä merkkijonosta"
 
-#: c/c-typeck.c:7413
+#: c/c-typeck.c:7418
 #, gcc-internal-format
 msgid "wide character array initialized from incompatible wide string"
 msgstr "leveän merkkitaulukon alustus epäyhteensopivasta leveästä merkkijonosta"
 
-#: c/c-typeck.c:7446
+#: c/c-typeck.c:7451
 #, gcc-internal-format
 msgid "array of inappropriate type initialized from string constant"
 msgstr "sopimattomasta tyypistä koostuva taulukko alustetaan merkkijonovakiosta"
 
-#: c/c-typeck.c:7533 c/c-typeck.c:7557 c/c-typeck.c:7560 c/c-typeck.c:7568
-#: c/c-typeck.c:7608 c/c-typeck.c:9131 c/c-typeck.c:9181
+#: c/c-typeck.c:7538 c/c-typeck.c:7562 c/c-typeck.c:7565 c/c-typeck.c:7573
+#: c/c-typeck.c:7613 c/c-typeck.c:9136 c/c-typeck.c:9186
 #, gcc-internal-format
 msgid "initializer element is not constant"
 msgstr "alustusalkio ei ole vakio"
 
-#: c/c-typeck.c:7542
+#: c/c-typeck.c:7547
 #, gcc-internal-format
 msgid "array initialized from non-constant array expression"
 msgstr "taulukko alustetaan muuttuvasta taulukkolausekkeesta"
 
-#: c/c-typeck.c:7573 c/c-typeck.c:7621 c/c-typeck.c:9191
+#: c/c-typeck.c:7578 c/c-typeck.c:7626 c/c-typeck.c:9196
 #, gcc-internal-format
 msgid "initializer element is not a constant expression"
 msgstr "alustinalkio ei ole vakiolauseke"
 
-#: c/c-typeck.c:7615 c/c-typeck.c:9186
+#: c/c-typeck.c:7620 c/c-typeck.c:9191
 #, gcc-internal-format
 msgid "initializer element is not computable at load time"
 msgstr "alustusalkiota ei pystytä laskemaan latausajankohtana"
 
-#: c/c-typeck.c:7634
+#: c/c-typeck.c:7639
 #, gcc-internal-format
 msgid "invalid initializer"
 msgstr "epäkelpo alustin"
 
-#: c/c-typeck.c:7912 cp/decl.c:6396
+#: c/c-typeck.c:7917 cp/decl.c:6396
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "läpinäkymättömiä vektorityyppejä ei voida alustaa"
 
-#: c/c-typeck.c:8132
+#: c/c-typeck.c:8137
 #, gcc-internal-format
 msgid "extra brace group at end of initializer"
 msgstr "alustimen lopussa on ylimääräinen lohko"
 
-#: c/c-typeck.c:8215
+#: c/c-typeck.c:8220
 #, gcc-internal-format
 msgid "braces around scalar initializer"
 msgstr "skalaarialustimen ympärillä on aaltosulkeet"
 
-#: c/c-typeck.c:8281 c/c-typeck.c:9615 cp/typeck2.c:1084 cp/typeck2.c:1297
+#: c/c-typeck.c:8286 c/c-typeck.c:9620 cp/typeck2.c:1084 cp/typeck2.c:1297
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "joustavan taulukkojäsenen alustaminen sisäkkäisessä asiayhteydessä"
 
-#: c/c-typeck.c:8318
+#: c/c-typeck.c:8323
 #, gcc-internal-format
 msgid "missing braces around initializer"
 msgstr "alustimen ympäriltä puuttuu aaltosulkeet"
 
-#: c/c-typeck.c:8341
+#: c/c-typeck.c:8346
 #, fuzzy, gcc-internal-format
 msgid "missing initializer for field %qD of %qT"
 msgstr "puuttuva alustin jäsenelle %qD"
 
-#: c/c-typeck.c:8365
+#: c/c-typeck.c:8370
 #, gcc-internal-format
 msgid "empty scalar initializer"
 msgstr "tyhjä skalaarialustin"
 
-#: c/c-typeck.c:8370
+#: c/c-typeck.c:8375
 #, gcc-internal-format
 msgid "extra elements in scalar initializer"
 msgstr "skalaarialustimessa ylimääräisiä alkioita"
 
-#: c/c-typeck.c:8483 c/c-typeck.c:8565
+#: c/c-typeck.c:8488 c/c-typeck.c:8570
 #, gcc-internal-format
 msgid "array index in non-array initializer"
 msgstr "taulukkoindeksi ei-taulukkoalustimessa"
 
-#: c/c-typeck.c:8488 c/c-typeck.c:8627
+#: c/c-typeck.c:8493 c/c-typeck.c:8632
 #, gcc-internal-format
 msgid "field name not in record or union initializer"
 msgstr ""
 
-#: c/c-typeck.c:8538
+#: c/c-typeck.c:8543
 #, gcc-internal-format
 msgid "array index in initializer not of integer type"
 msgstr "taulukkoindeksi alustimessa ei ole kokonaislukutyyppinen"
 
-#: c/c-typeck.c:8547 c/c-typeck.c:8556
+#: c/c-typeck.c:8552 c/c-typeck.c:8561
 #, gcc-internal-format
 msgid "array index in initializer is not an integer constant expression"
 msgstr "taulukkoindeksi alustimessa ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: c/c-typeck.c:8561 c/c-typeck.c:8563
+#: c/c-typeck.c:8566 c/c-typeck.c:8568
 #, gcc-internal-format
 msgid "nonconstant array index in initializer"
 msgstr "ei-vakio taulukkoindeksi alustimessa"
 
-#: c/c-typeck.c:8567 c/c-typeck.c:8570
+#: c/c-typeck.c:8572 c/c-typeck.c:8575
 #, gcc-internal-format
 msgid "array index in initializer exceeds array bounds"
 msgstr "taulukkoindeksi alustimessa ylittää taulukon rajat"
 
-#: c/c-typeck.c:8589
+#: c/c-typeck.c:8594
 #, gcc-internal-format
 msgid "empty index range in initializer"
 msgstr "tyhjä indeksiväli alustimessa"
 
-#: c/c-typeck.c:8598
+#: c/c-typeck.c:8603
 #, gcc-internal-format
 msgid "array index range in initializer exceeds array bounds"
 msgstr "taulukkoindeksiväli alustimessa ylittää taulukon rajat"
 
-#: c/c-typeck.c:8700 c/c-typeck.c:8730 c/c-typeck.c:9274
+#: c/c-typeck.c:8705 c/c-typeck.c:8735 c/c-typeck.c:9279
 #, fuzzy, gcc-internal-format
 msgid "initialized field with side-effects overwritten"
 msgstr "alustettu kenttä ylikirjoitettu"
 
-#: c/c-typeck.c:8704 c/c-typeck.c:8734 c/c-typeck.c:9277
+#: c/c-typeck.c:8709 c/c-typeck.c:8739 c/c-typeck.c:9282
 #, gcc-internal-format
 msgid "initialized field overwritten"
 msgstr "alustettu kenttä ylikirjoitettu"
 
-#: c/c-typeck.c:9208
+#: c/c-typeck.c:9213
 #, gcc-internal-format
 msgid "enum conversion in initialization is invalid in C++"
 msgstr "enum-muunnos alustuksessa on virheellistä C++-kielessä"
 
-#: c/c-typeck.c:9496
+#: c/c-typeck.c:9501
 #, gcc-internal-format
 msgid "excess elements in char array initializer"
 msgstr "ylimääräisiä alkioita merkkitaulukkoalustimessa"
 
-#: c/c-typeck.c:9503 c/c-typeck.c:9574
+#: c/c-typeck.c:9508 c/c-typeck.c:9579
 #, gcc-internal-format
 msgid "excess elements in struct initializer"
 msgstr "ylimääräisiä alkioita struct-alustimessa"
 
-#: c/c-typeck.c:9518
+#: c/c-typeck.c:9523
 #, gcc-internal-format
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr ""
 
-#: c/c-typeck.c:9589
+#: c/c-typeck.c:9594
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr "joustavan taulukkojäsenen ei-staattinen alustus"
 
-#: c/c-typeck.c:9687
+#: c/c-typeck.c:9692
 #, gcc-internal-format
 msgid "excess elements in union initializer"
 msgstr "ylimääräisiä alkioita union-alustimessa"
 
-#: c/c-typeck.c:9709
+#: c/c-typeck.c:9714
 #, fuzzy, gcc-internal-format
 msgid "traditional C rejects initialization of unions"
 msgstr "perinteinen C ei hyväksy automaattista koostealustusta"
 
-#: c/c-typeck.c:9777
+#: c/c-typeck.c:9782
 #, gcc-internal-format
 msgid "excess elements in array initializer"
 msgstr "ylimääräisiä alkioita taulukkoalustimessa"
 
-#: c/c-typeck.c:9811
+#: c/c-typeck.c:9816
 #, gcc-internal-format
 msgid "excess elements in vector initializer"
 msgstr "ylimääräisiä alkioita vektorialustimessa"
 
-#: c/c-typeck.c:9843
+#: c/c-typeck.c:9848
 #, gcc-internal-format
 msgid "excess elements in scalar initializer"
 msgstr "ylimääräisiä alkioita skalaarialustimessa"
 
-#: c/c-typeck.c:10086
+#: c/c-typeck.c:10091
 #, gcc-internal-format
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr ""
 
-#: c/c-typeck.c:10113 c/gimple-parser.c:1604 cp/typeck.c:9113
+#: c/c-typeck.c:10118 c/gimple-parser.c:1604 cp/typeck.c:9113
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "%<noreturn%>-esitellyllä funktiolla on %<return%>-lause"
 
-#: c/c-typeck.c:10139 c/c-typeck.c:10143
+#: c/c-typeck.c:10144 c/c-typeck.c:10148
 #, gcc-internal-format
 msgid "%<return%> with no value, in function returning non-void"
 msgstr "%<return%> ilman arvoa ei-voidin palauttavassa funktiossa"
 
-#: c/c-typeck.c:10157 c/gimple-parser.c:1614
+#: c/c-typeck.c:10162 c/gimple-parser.c:1614
 #, gcc-internal-format
 msgid "%<return%> with a value, in function returning void"
 msgstr "%<return%> arvon kanssa voidin palauttavassa funktiossa"
 
-#: c/c-typeck.c:10160
+#: c/c-typeck.c:10165
 #, gcc-internal-format
 msgid "ISO C forbids %<return%> with expression, in function returning void"
 msgstr "ISO C kieltää %<return%>:in lausekkeen kanssa voidin palauttavassa funktiossa"
 
-#: c/c-typeck.c:10236
+#: c/c-typeck.c:10241
 #, fuzzy, gcc-internal-format
 #| msgid "function returns address of local variable"
 msgid "function returns address of label"
 msgstr "funktio palauttaa osoitteen paikalliseen muuttujaan"
 
-#: c/c-typeck.c:10327 cp/semantics.c:1171
+#: c/c-typeck.c:10332 cp/semantics.c:1171
 #, fuzzy, gcc-internal-format
 msgid "switch quantity not an integer"
 msgstr "yhteensopivuusvalitsin (jätetään huomiotta)"
 
-#: c/c-typeck.c:10352
+#: c/c-typeck.c:10357
 #, gcc-internal-format
 msgid "%<long%> switch expression not converted to %<int%> in ISO C"
 msgstr ""
 
-#: c/c-typeck.c:10390 c/c-typeck.c:10398
+#: c/c-typeck.c:10395 c/c-typeck.c:10403
 #, gcc-internal-format
 msgid "case label is not an integer constant expression"
 msgstr "case-nimiö ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: c/c-typeck.c:10404 cp/parser.c:11067
+#: c/c-typeck.c:10409 cp/parser.c:11067
 #, fuzzy, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "break-lause silmukan tai switch-rakenteen ulkopuolella"
 
-#: c/c-typeck.c:10406
+#: c/c-typeck.c:10411
 #, fuzzy, gcc-internal-format
 msgid "%<default%> label not within a switch statement"
 msgstr "break-lause silmukan tai switch-rakenteen ulkopuolella"
 
-#: c/c-typeck.c:10578 cp/parser.c:12356
+#: c/c-typeck.c:10583 cp/parser.c:12353
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "break-lause silmukan tai switch-rakenteen ulkopuolella"
 
-#: c/c-typeck.c:10580 cp/parser.c:12379
+#: c/c-typeck.c:10585 cp/parser.c:12376
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "continue-lause silmukan ulkopuolella"
 
-#: c/c-typeck.c:10585 cp/parser.c:12369
+#: c/c-typeck.c:10590 cp/parser.c:12366
 #, fuzzy, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr "break-lause silmukan tai switch-rakenteen ulkopuolella"
 
-#: c/c-typeck.c:10590
+#: c/c-typeck.c:10595
 #, fuzzy, gcc-internal-format
 #| msgid "break statement not within loop or switch"
 msgid "break statement within %<#pragma simd%> loop body"
 msgstr "break-lause silmukan tai switch-rakenteen ulkopuolella"
 
-#: c/c-typeck.c:10592
+#: c/c-typeck.c:10597
 #, fuzzy, gcc-internal-format
 #| msgid "continue statement not within a loop"
 msgid "continue statement within %<#pragma simd%> loop body"
 msgstr "continue-lause silmukan ulkopuolella"
 
-#: c/c-typeck.c:10618 cp/cp-gimplify.c:432
+#: c/c-typeck.c:10623 cp/cp-gimplify.c:432
 #, gcc-internal-format
 msgid "statement with no effect"
 msgstr "lauseella ei ole vaikutusta"
 
-#: c/c-typeck.c:10662
+#: c/c-typeck.c:10667
 #, fuzzy, gcc-internal-format
 msgid "expression statement has incomplete type"
 msgstr "nimettömällä kentällä on vaillinainen tyyppi"
 
-#: c/c-typeck.c:11476 c/c-typeck.c:11644 cp/typeck.c:5017
+#: c/c-typeck.c:11481 c/c-typeck.c:11649 cp/typeck.c:5017
 #, fuzzy, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr "Varoita eri enum-tyyppien vertailusta"
 
-#: c/c-typeck.c:11484 c/c-typeck.c:11652 cp/typeck.c:5030
+#: c/c-typeck.c:11489 c/c-typeck.c:11657 cp/typeck.c:5030
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr ""
 
-#: c/c-typeck.c:11509 c/c-typeck.c:11677 cp/typeck.c:5058
+#: c/c-typeck.c:11514 c/c-typeck.c:11682 cp/typeck.c:5058
 #, fuzzy, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr "%qD esitelty extern-avainsanalla sisäkkäin"
 
-#: c/c-typeck.c:11523 cp/typeck.c:4743
+#: c/c-typeck.c:11528 cp/typeck.c:4743
 #, gcc-internal-format
 msgid "comparing floating point with == or != is unsafe"
 msgstr "liukulukujen vertailu operaattoreilla == ja != on epävarmaa"
 
-#: c/c-typeck.c:11541 c/c-typeck.c:11562
+#: c/c-typeck.c:11546 c/c-typeck.c:11567
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<false%> for the address of %qD will never be NULL"
 msgstr ""
 
-#: c/c-typeck.c:11547 c/c-typeck.c:11568
+#: c/c-typeck.c:11552 c/c-typeck.c:11573
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<true%> for the address of %qD will never be NULL"
 msgstr ""
 
-#: c/c-typeck.c:11589 c/c-typeck.c:11718
+#: c/c-typeck.c:11594 c/c-typeck.c:11723
 #, fuzzy, gcc-internal-format
 msgid "comparison of pointers to disjoint address spaces"
 msgstr "osoittimen ja kokonaisluku nollan suuruusvertailu"
 
-#: c/c-typeck.c:11596 c/c-typeck.c:11602
+#: c/c-typeck.c:11601 c/c-typeck.c:11607
 #, gcc-internal-format
 msgid "ISO C forbids comparison of %<void *%> with function pointer"
 msgstr "ISO C kieltää %<void *%>:n ja funktio-osoittimen vertailun"
 
-#: c/c-typeck.c:11609 c/c-typeck.c:11728
+#: c/c-typeck.c:11614 c/c-typeck.c:11733
 #, fuzzy, gcc-internal-format
 msgid "comparison of distinct pointer types lacks a cast"
 msgstr "erilaisten Objective-C-tyyppien vertailusta puuttuu tyyppimuunnos"
 
-#: c/c-typeck.c:11621 c/c-typeck.c:11626 c/c-typeck.c:11754 c/c-typeck.c:11759
+#: c/c-typeck.c:11626 c/c-typeck.c:11631 c/c-typeck.c:11759 c/c-typeck.c:11764
 #, gcc-internal-format
 msgid "comparison between pointer and integer"
 msgstr "osoittimen ja kokonaisluvun välinen vertailu"
 
-#: c/c-typeck.c:11706
+#: c/c-typeck.c:11711
 #, gcc-internal-format
 msgid "comparison of complete and incomplete pointers"
 msgstr "täydellisen ja vaillinaisen osoittimen vertailu"
 
-#: c/c-typeck.c:11708
+#: c/c-typeck.c:11713
 #, gcc-internal-format
 msgid "ISO C forbids ordered comparisons of pointers to functions"
 msgstr "ISO C kieltää funktio-osoittimien suuruusvertailun"
 
-#: c/c-typeck.c:11713
+#: c/c-typeck.c:11718
 #, fuzzy, gcc-internal-format
 msgid "ordered comparison of pointer with null pointer"
 msgstr "osoittimen ja kokonaisluku nollan suuruusvertailu"
 
-#: c/c-typeck.c:11736 c/c-typeck.c:11739 c/c-typeck.c:11746 c/c-typeck.c:11749
+#: c/c-typeck.c:11741 c/c-typeck.c:11744 c/c-typeck.c:11751 c/c-typeck.c:11754
 #: cp/typeck.c:5081 cp/typeck.c:5088
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "osoittimen ja kokonaisluku nollan suuruusvertailu"
 
-#: c/c-typeck.c:11811
+#: c/c-typeck.c:11816
 #, fuzzy, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
 msgstr "muunnos tyypistä %2$qT tyypiksi %1$qT"
 
-#: c/c-typeck.c:12126
+#: c/c-typeck.c:12131
 #, gcc-internal-format
 msgid "used array that cannot be converted to pointer where scalar is required"
 msgstr "käytetty osoittimeksi muuntumatonta taulukkoa paikassa, jossa vaaditaan skalaari"
 
-#: c/c-typeck.c:12130
+#: c/c-typeck.c:12135
 #, gcc-internal-format
 msgid "used struct type value where scalar is required"
 msgstr "käytetty tietuetyypin arvoa, vaikka vaaditaan skalaari"
 
-#: c/c-typeck.c:12134
+#: c/c-typeck.c:12139
 #, gcc-internal-format
 msgid "used union type value where scalar is required"
 msgstr "käytetty unionityypin arvoa, vaikka vaaditaan skalaari"
 
-#: c/c-typeck.c:12150
+#: c/c-typeck.c:12155
 #, fuzzy, gcc-internal-format
 msgid "used vector type where scalar is required"
 msgstr "käytetty unionityypin arvoa, vaikka vaaditaan skalaari"
 
-#: c/c-typeck.c:12340 cp/semantics.c:8508
+#: c/c-typeck.c:12345 cp/semantics.c:8511
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12379 cp/semantics.c:8545
+#: c/c-typeck.c:12384 cp/semantics.c:8548
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12423 c/c-typeck.c:13581 c/c-typeck.c:13642 c/c-typeck.c:13704
+#: c/c-typeck.c:12428 c/c-typeck.c:13586 c/c-typeck.c:13647 c/c-typeck.c:13709
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qs has invalid type"
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "bittikentän %qs leveys on nolla"
 
-#: c/c-typeck.c:12436 c/c-typeck.c:13628 cp/semantics.c:4546
-#: cp/semantics.c:6717
+#: c/c-typeck.c:12441 c/c-typeck.c:13633 cp/semantics.c:4549
+#: cp/semantics.c:6720
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qs has invalid type"
 msgid "bit-field %qE in %qs clause"
 msgstr "bittikentän %qs leveys on nolla"
 
-#: c/c-typeck.c:12445 c/c-typeck.c:13652 cp/semantics.c:4556
-#: cp/semantics.c:6735
+#: c/c-typeck.c:12450 c/c-typeck.c:13657 cp/semantics.c:4559
+#: cp/semantics.c:6738
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qD"
 msgid "%qE is a member of a union"
 msgstr "joustava taulukkojäsen unionissa"
 
-#: c/c-typeck.c:12455 cp/semantics.c:4570 cp/semantics.c:6760
+#: c/c-typeck.c:12460 cp/semantics.c:4573 cp/semantics.c:6763
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "muuttuja %qD esitelty uudelleen funktiona"
 
-#: c/c-typeck.c:12459 c/c-typeck.c:13669 cp/semantics.c:4574
-#: cp/semantics.c:6763
+#: c/c-typeck.c:12464 c/c-typeck.c:13674 cp/semantics.c:4577
+#: cp/semantics.c:6766
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qs määritelty parametrille %qE"
 
-#: c/c-typeck.c:12466
+#: c/c-typeck.c:12471
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qs has invalid type"
 msgid "%<_Atomic%> %qD in %qs clause"
 msgstr "bittikentän %qs leveys on nolla"
 
-#: c/c-typeck.c:12475 c/c-typeck.c:13676 c/c-typeck.c:13778
-#: cp/semantics.c:4591 cp/semantics.c:6769 cp/semantics.c:6931
+#: c/c-typeck.c:12480 c/c-typeck.c:13681 c/c-typeck.c:13783
+#: cp/semantics.c:4594 cp/semantics.c:6772 cp/semantics.c:6934
 #, fuzzy, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "sisäkkäisessä funktiossa käytetty rekisterimuuttujaa %qD"
 
-#: c/c-typeck.c:12511 cp/semantics.c:4623
+#: c/c-typeck.c:12516 cp/semantics.c:4626
 #, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr ""
 
-#: c/c-typeck.c:12518 cp/semantics.c:4630
+#: c/c-typeck.c:12523 cp/semantics.c:4633
 #, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr ""
 
-#: c/c-typeck.c:12545 c/c-typeck.c:12609 c/c-typeck.c:12867
-#: cp/semantics.c:4666 cp/semantics.c:4730
+#: c/c-typeck.c:12550 c/c-typeck.c:12614 c/c-typeck.c:12872
+#: cp/semantics.c:4669 cp/semantics.c:4733
 #, fuzzy, gcc-internal-format
 #| msgid "variable length array is used"
 msgid "zero length array section in %qs clause"
 msgstr "käytetään muuttuvapituista taulukkoa"
 
-#: c/c-typeck.c:12564 cp/semantics.c:4685
+#: c/c-typeck.c:12569 cp/semantics.c:4688
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12572 cp/semantics.c:4693
+#: c/c-typeck.c:12577 cp/semantics.c:4696
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12581 c/c-typeck.c:12691 cp/semantics.c:4702
-#: cp/semantics.c:4812
+#: c/c-typeck.c:12586 c/c-typeck.c:12696 cp/semantics.c:4705
+#: cp/semantics.c:4815
 #, fuzzy, gcc-internal-format
 #| msgid "variable length array is used"
 msgid "negative length in array section in %qs clause"
 msgstr "käytetään muuttuvapituista taulukkoa"
 
-#: c/c-typeck.c:12598 cp/semantics.c:4719
+#: c/c-typeck.c:12603 cp/semantics.c:4722
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12635 cp/semantics.c:4756
+#: c/c-typeck.c:12640 cp/semantics.c:4759
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12650 cp/semantics.c:4771
+#: c/c-typeck.c:12655 cp/semantics.c:4774
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12683 cp/semantics.c:4804
+#: c/c-typeck.c:12688 cp/semantics.c:4807
 #, fuzzy, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr "pilkkulausekkeen vasemmalla operandilla ei ole vaikutusta"
 
-#: c/c-typeck.c:12701 c/c-typeck.c:12810 cp/semantics.c:4822
-#: cp/semantics.c:4934
+#: c/c-typeck.c:12706 c/c-typeck.c:12815 cp/semantics.c:4825
+#: cp/semantics.c:4937
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12709 cp/semantics.c:4830
+#: c/c-typeck.c:12714 cp/semantics.c:4833
 #, fuzzy, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr "%qE:lla ei ole luokkatyyppiä"
 
-#: c/c-typeck.c:13103 c/c-typeck.c:13113
+#: c/c-typeck.c:13108 c/c-typeck.c:13118
 #, fuzzy, gcc-internal-format
 msgid "%qD in %<reduction%> clause is a zero size array"
 msgstr "ISO C++ kieltää nollan kokoisen taulukon %qD"
 
-#: c/c-typeck.c:13130
+#: c/c-typeck.c:13135
 #, fuzzy, gcc-internal-format
 #| msgid "cast specifies function type"
 msgid "%<_Atomic%> %qE in %<reduction%> clause"
 msgstr "tyyppimuunnos määrittää funktiotyypin"
 
-#: c/c-typeck.c:13178
+#: c/c-typeck.c:13183
 #, gcc-internal-format
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr ""
 
-#: c/c-typeck.c:13187 cp/semantics.c:5755
+#: c/c-typeck.c:13192 cp/semantics.c:5758
 #, fuzzy, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr "tyypillä %qE on käyttäjän määrittelemä muodostin"
 
-#: c/c-typeck.c:13275
+#: c/c-typeck.c:13280
 #, fuzzy, gcc-internal-format
 #| msgid "variable length array is used"
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "käytetään muuttuvapituista taulukkoa"
 
-#: c/c-typeck.c:13293 c/c-typeck.c:13836 cp/semantics.c:7249
+#: c/c-typeck.c:13298 c/c-typeck.c:13841 cp/semantics.c:7252
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13305 cp/semantics.c:7289
+#: c/c-typeck.c:13310 cp/semantics.c:7292
 #, fuzzy, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "automaattimuuttuja %qE ei voi olla %<threadprivate%>"
 
-#: c/c-typeck.c:13319 cp/semantics.c:5929
+#: c/c-typeck.c:13324 cp/semantics.c:5932
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr ""
 
-#: c/c-typeck.c:13327
+#: c/c-typeck.c:13332
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with type %qT"
 msgstr ""
 
-#: c/c-typeck.c:13335
+#: c/c-typeck.c:13340
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13354 cp/semantics.c:5999
+#: c/c-typeck.c:13359 cp/semantics.c:6002
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
-#: c/c-typeck.c:13384 c/c-typeck.c:13771 cp/semantics.c:6083
-#: cp/semantics.c:6924
+#: c/c-typeck.c:13389 c/c-typeck.c:13776 cp/semantics.c:6086
+#: cp/semantics.c:6927
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qs määritelty parametrille %qE"
 
-#: c/c-typeck.c:13393 cp/semantics.c:6092
+#: c/c-typeck.c:13398 cp/semantics.c:6095
 #, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr ""
 
-#: c/c-typeck.c:13404 c/c-typeck.c:13434 c/c-typeck.c:13463
+#: c/c-typeck.c:13409 c/c-typeck.c:13439 c/c-typeck.c:13468
 #, gcc-internal-format
 msgid "%qE appears more than once in data clauses"
 msgstr ""
 
-#: c/c-typeck.c:13411 c/c-typeck.c:13440 c/c-typeck.c:13600 c/c-typeck.c:13714
-#: c/c-typeck.c:13720 c/c-typeck.c:13733 c/c-typeck.c:13742
-#: cp/semantics.c:6102 cp/semantics.c:6109 cp/semantics.c:6160
-#: cp/semantics.c:6166 cp/semantics.c:6203 cp/semantics.c:6680
-#: cp/semantics.c:6817 cp/semantics.c:6823 cp/semantics.c:6836
-#: cp/semantics.c:6845
+#: c/c-typeck.c:13416 c/c-typeck.c:13445 c/c-typeck.c:13605 c/c-typeck.c:13719
+#: c/c-typeck.c:13725 c/c-typeck.c:13738 c/c-typeck.c:13747
+#: cp/semantics.c:6105 cp/semantics.c:6112 cp/semantics.c:6163
+#: cp/semantics.c:6169 cp/semantics.c:6206 cp/semantics.c:6683
+#: cp/semantics.c:6820 cp/semantics.c:6826 cp/semantics.c:6839
+#: cp/semantics.c:6848
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
-#: c/c-typeck.c:13413 c/c-typeck.c:13442 c/c-typeck.c:13722 c/c-typeck.c:13744
-#: cp/semantics.c:6111 cp/semantics.c:6168 cp/semantics.c:6825
-#: cp/semantics.c:6847
+#: c/c-typeck.c:13418 c/c-typeck.c:13447 c/c-typeck.c:13727 c/c-typeck.c:13749
+#: cp/semantics.c:6114 cp/semantics.c:6171 cp/semantics.c:6828
+#: cp/semantics.c:6850
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr ""
 
-#: c/c-typeck.c:13427 cp/semantics.c:6154
+#: c/c-typeck.c:13432 cp/semantics.c:6157
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "automaattimuuttuja %qE ei voi olla %<threadprivate%>"
 
-#: c/c-typeck.c:13456 cp/semantics.c:6197
+#: c/c-typeck.c:13461 cp/semantics.c:6200
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "automaattimuuttuja %qE ei voi olla %<threadprivate%>"
 
-#: c/c-typeck.c:13475 cp/semantics.c:6545
+#: c/c-typeck.c:13480 cp/semantics.c:6548
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "instanssimuuttuja %qE on esitelty yksityisenä"
 
-#: c/c-typeck.c:13482
+#: c/c-typeck.c:13487
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array"
 msgstr ""
 
-#: c/c-typeck.c:13489
+#: c/c-typeck.c:13494
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<aligned%> clause"
 msgstr "muuttuja %qD esitelty uudelleen funktiona"
 
-#: c/c-typeck.c:13496
+#: c/c-typeck.c:13501
 #, gcc-internal-format
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:13551 cp/semantics.c:6627
+#: c/c-typeck.c:13556 cp/semantics.c:6630
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr "instanssimuuttuja %qE on esitelty yksityisenä"
 
-#: c/c-typeck.c:13573 cp/semantics.c:6658
+#: c/c-typeck.c:13578 cp/semantics.c:6661
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13597 c/c-typeck.c:13731 cp/semantics.c:6677
-#: cp/semantics.c:6834
+#: c/c-typeck.c:13602 c/c-typeck.c:13736 cp/semantics.c:6680
+#: cp/semantics.c:6837
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr ""
 
-#: c/c-typeck.c:13603 c/c-typeck.c:13735 cp/semantics.c:6683
-#: cp/semantics.c:6838
+#: c/c-typeck.c:13608 c/c-typeck.c:13740 cp/semantics.c:6686
+#: cp/semantics.c:6841
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr ""
 
-#: c/c-typeck.c:13635 cp/semantics.c:6724
+#: c/c-typeck.c:13640 cp/semantics.c:6727
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not have class type"
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qE:lla ei ole luokkatyyppiä"
 
-#: c/c-typeck.c:13695 c/c-typeck.c:13785 cp/semantics.c:6799
-#: cp/semantics.c:6938
+#: c/c-typeck.c:13700 c/c-typeck.c:13790 cp/semantics.c:6802
+#: cp/semantics.c:6941
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not have class type"
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qE:lla ei ole luokkatyyppiä"
 
-#: c/c-typeck.c:13766 cp/semantics.c:6918
+#: c/c-typeck.c:13771 cp/semantics.c:6921
 #, fuzzy, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "halutaan rekisterimuuttujan %qD osoite"
 
-#: c/c-typeck.c:13794 cp/semantics.c:6947
+#: c/c-typeck.c:13799 cp/semantics.c:6950
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr ""
 
-#: c/c-typeck.c:13808 cp/semantics.c:6962
+#: c/c-typeck.c:13813 cp/semantics.c:6965
 #, fuzzy, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "  alustettaessa funktion %2$qD argumenttia %1$P"
 
-#: c/c-typeck.c:13811 cp/semantics.c:6964
+#: c/c-typeck.c:13816 cp/semantics.c:6967
 #, fuzzy, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "funktiolle %2$qE annettu argumentin %1$d tyyppi on yhteensopimaton"
 
-#: c/c-typeck.c:13826
+#: c/c-typeck.c:13831
 #, fuzzy, gcc-internal-format
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "indeksoitu arvo ei ole taulukko eikä osoitin"
 
-#: c/c-typeck.c:13900 cp/semantics.c:6359
+#: c/c-typeck.c:13905 cp/semantics.c:6362
 #, gcc-internal-format
 msgid "%<nonmonotonic%> modifier specified for %qs schedule kind"
 msgstr ""
 
-#: c/c-typeck.c:13931 cp/semantics.c:7141
+#: c/c-typeck.c:13936 cp/semantics.c:7144
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:13981 cp/semantics.c:7332
+#: c/c-typeck.c:13986 cp/semantics.c:7335
 #, fuzzy, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qs määritelty parametrille %qE"
 
-#: c/c-typeck.c:14001 cp/semantics.c:7223
+#: c/c-typeck.c:14006 cp/semantics.c:7226
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:14013 cp/semantics.c:7236
+#: c/c-typeck.c:14018 cp/semantics.c:7239
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14031 cp/semantics.c:7203
+#: c/c-typeck.c:14036 cp/semantics.c:7206
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14204
+#: c/c-typeck.c:14209
 #, gcc-internal-format
 msgid "cannot use %<va_arg%> with reverse storage order"
 msgstr ""
 
-#: c/c-typeck.c:14209
+#: c/c-typeck.c:14214
 #, fuzzy, gcc-internal-format
 #| msgid "first argument to %<va_arg%> not of type %<va_list%>"
 msgid "second argument to %<va_arg%> is of incomplete type %qT"
 msgstr "%<va_arg%>-funktion ensimmäinen argumentti ei ole tyyppiä %<va_list%>"
 
-#: c/c-typeck.c:14215
+#: c/c-typeck.c:14220
 #, gcc-internal-format
 msgid "C++ requires promoted type, not enum type, in %<va_arg%>"
 msgstr ""
@@ -40379,7 +40423,7 @@
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "virheellinen muunnos tyypistä %qT tyypiksi %qT"
 
-#: cp/call.c:3441 cp/pt.c:6495
+#: cp/call.c:3441 cp/pt.c:6509
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -40676,7 +40720,7 @@
 msgid "%q#D is private within this context"
 msgstr "tässä yhteydessä"
 
-#: cp/call.c:6478 cp/decl.c:7343
+#: cp/call.c:6478 cp/decl.c:7364
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "declared private here"
@@ -40688,7 +40732,7 @@
 msgid "%q#D is protected within this context"
 msgstr "tässä yhteydessä"
 
-#: cp/call.c:6486 cp/decl.c:7344
+#: cp/call.c:6486 cp/decl.c:7365
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "declared protected here"
@@ -41014,7 +41058,7 @@
 msgid "call to non-function %qD"
 msgstr "%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/call.c:9119 cp/pt.c:15053 cp/typeck.c:2901
+#: cp/call.c:9119 cp/pt.c:15075 cp/typeck.c:2901
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
@@ -41232,54 +41276,54 @@
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr ""
 
-#: cp/class.c:2098
+#: cp/class.c:2103
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr ""
 
-#: cp/class.c:2110
+#: cp/class.c:2115
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr ""
 
-#: cp/class.c:2152
+#: cp/class.c:2156
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr ""
 
-#: cp/class.c:2156
+#: cp/class.c:2160
 #, gcc-internal-format
 msgid "%q#D is public, but requires an existing %q#T object"
 msgstr ""
 
-#: cp/class.c:2430
+#: cp/class.c:2434
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr ""
 
-#: cp/class.c:2785
+#: cp/class.c:2789
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%qD can be marked override"
 msgstr "%q+D esitelty täällä"
 
-#: cp/class.c:2797
+#: cp/class.c:2801
 #, fuzzy, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr "funktion %q+D määrittely on merkitty dllimport-tyyppiseksi"
 
-#: cp/class.c:2799
+#: cp/class.c:2803
 #, fuzzy, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr "%Jnimike %qD määritelty, mutta ei käytetty"
 
-#: cp/class.c:2861
+#: cp/class.c:2865
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was hidden"
 msgid "%qD was hidden"
 msgstr "Näytä _piilotetut"
 
-#: cp/class.c:2863
+#: cp/class.c:2867
 #, fuzzy, gcc-internal-format
 #| msgid "        %qD"
 msgid "  by %qD"
@@ -41286,219 +41330,219 @@
 msgstr "nimellä %qD"
 
 # semi-fuzzy
-#: cp/class.c:2896
+#: cp/class.c:2900
 #, fuzzy, gcc-internal-format
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "ei-staattista datajäsentä %q+D käytetty virheellisesti"
 
-#: cp/class.c:2906 cp/name-lookup.c:3293 cp/parser.c:19720
+#: cp/class.c:2910 cp/name-lookup.c:3293 cp/parser.c:19717
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
 
-#: cp/class.c:3097
+#: cp/class.c:3101
 #, fuzzy, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr "Varoita perittyjen metodien puuttuvista toteutuksista"
 
-#: cp/class.c:3213
+#: cp/class.c:3217
 #, gcc-internal-format
 msgid "bit-field %q+#D with non-integral type"
 msgstr "bittikenttä %+q#D ei ole kokonaislukutyyppinen"
 
-#: cp/class.c:3229
+#: cp/class.c:3233
 #, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr "bittikentän %q+D leveys ei ole kokonaislukuvakio"
 
-#: cp/class.c:3234
+#: cp/class.c:3238
 #, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr "bittikentän %q+D leveys negatiivinen"
 
-#: cp/class.c:3239
+#: cp/class.c:3243
 #, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr "bittikentän %q+D leveys nolla"
 
-#: cp/class.c:3249
+#: cp/class.c:3253
 #, fuzzy, gcc-internal-format
 #| msgid "width of %q+D exceeds its type"
 msgid "width of %qD exceeds its type"
 msgstr "bittikentän %qs leveys ylittää tyyppinsä"
 
-#: cp/class.c:3255
+#: cp/class.c:3259
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is too small to hold all values of %q#T"
 msgid "%qD is too small to hold all values of %q#T"
 msgstr "%q+D on liian pieni sisältämään %q#T:n kaikkia arvoja"
 
-#: cp/class.c:3316
+#: cp/class.c:3320
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr ""
 
-#: cp/class.c:3319
+#: cp/class.c:3323
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr ""
 
-#: cp/class.c:3321
+#: cp/class.c:3325
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr ""
 
-#: cp/class.c:3325
+#: cp/class.c:3329
 #, gcc-internal-format
 msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/class.c:3453
+#: cp/class.c:3457
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D may not be static because it is a member of a union"
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr "%q+D ei voi olla staattinen koska se on unionin jäsen"
 
-#: cp/class.c:3460
+#: cp/class.c:3464
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qD has Java class type"
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr "ei-staattisella datajäsenellä %qD on Java-luokkatyyppi"
 
-#: cp/class.c:3470
+#: cp/class.c:3474
 #, fuzzy, gcc-internal-format
 msgid "field %q+D invalidly declared function type"
 msgstr "staattinen jäsenfunktio %q#D esitelty tyyppimääreillä"
 
-#: cp/class.c:3476
+#: cp/class.c:3480
 #, fuzzy, gcc-internal-format
 msgid "field %q+D invalidly declared method type"
 msgstr "%Jparametri %qD esitelty tyhjällä tyypillä"
 
-#: cp/class.c:3536
+#: cp/class.c:3540
 #, gcc-internal-format
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr ""
 
-#: cp/class.c:3585
+#: cp/class.c:3589
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr "jäsentä %qD ei voida esitellä sekä virtuaaliseksi että staattiseksi"
 
-#: cp/class.c:3591
+#: cp/class.c:3595
 #, fuzzy, gcc-internal-format
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr "%Jparametri %qD esitelty %<inline%>:ksi"
 
-#: cp/class.c:3617
+#: cp/class.c:3621
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr "useita kenttiä unionissa %qT alustettu"
 
-#: cp/class.c:3658
+#: cp/class.c:3662
 #, fuzzy, gcc-internal-format
 #| msgid "field %q+#D with same name as class"
 msgid "field %q#D with same name as class"
 msgstr "kentällä %q+#D on sama nimi kuin luokalla"
 
-#: cp/class.c:3681
+#: cp/class.c:3685
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr "luokalla %q#T on datajäseninä osoittimia"
 
-#: cp/class.c:3686
+#: cp/class.c:3690
 #, gcc-internal-format
 msgid "  but does not override %<%T(const %T&)%>"
 msgstr "  mutta ei ylikuormitusta %<%T(const %T&)%>"
 
-#: cp/class.c:3688
+#: cp/class.c:3692
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr "  eikä %<operator=(const %T&)%>"
 
-#: cp/class.c:3692
+#: cp/class.c:3696
 #, gcc-internal-format
 msgid "  but does not override %<operator=(const %T&)%>"
 msgstr "  mutta ei ylikuormitusta %<operator=(const %T&)%>"
 
-#: cp/class.c:4097
+#: cp/class.c:4101
 #, gcc-internal-format
 msgid "alignment of %qD increased in -fabi-version=9 (GCC 5.2)"
 msgstr ""
 
-#: cp/class.c:4100
+#: cp/class.c:4104
 #, fuzzy, gcc-internal-format
 msgid "alignment of %qD will increase in -fabi-version=9"
 msgstr "%J%qD:n lohko on ristiriidassa edellisen esittelyn kanssa"
 
-#: cp/class.c:4378
+#: cp/class.c:4382
 #, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr ""
 
-#: cp/class.c:4813
+#: cp/class.c:4817
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr ""
 
-#: cp/class.c:4834
+#: cp/class.c:4838
 #, fuzzy, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr "liikaa argumentteja metodille %qE"
 
-#: cp/class.c:5350 cp/constexpr.c:237
+#: cp/class.c:5367 cp/constexpr.c:237
 #, fuzzy, gcc-internal-format
 msgid "enclosing class of %<constexpr%> non-static member function %q+#D is not a literal type"
 msgstr "%q+D-funktion paluuarvon tyyppi ei ole %<int%>"
 
-#: cp/class.c:5374
+#: cp/class.c:5391
 #, fuzzy, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr "edellinen %q+#T:n määrittely"
 
-#: cp/class.c:5377
+#: cp/class.c:5394
 #, gcc-internal-format
 msgid "  %qT is a closure type, which is only literal in C++17 and later"
 msgstr ""
 
-#: cp/class.c:5380
+#: cp/class.c:5397
 #, fuzzy, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr "Java-luokalla %qT ei voi olla implisiittistä epätriviaalia hajotinta"
 
-#: cp/class.c:5387
+#: cp/class.c:5404
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no %<constexpr%> constructor that is not a copy or move constructor"
 msgstr ""
 
-#: cp/class.c:5420
+#: cp/class.c:5437
 #, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr ""
 
-#: cp/class.c:5435
+#: cp/class.c:5452
 #, fuzzy, gcc-internal-format
 msgid "  non-static data member %qD has non-literal type"
 msgstr "ei-staattisella datajäsenellä %qD on Java-luokkatyyppi"
 
-#: cp/class.c:5442
+#: cp/class.c:5459
 #, fuzzy, gcc-internal-format
 msgid "  non-static data member %qD has volatile type"
 msgstr "ei-staattisella datajäsenellä %qD on Java-luokkatyyppi"
 
-#: cp/class.c:5561
+#: cp/class.c:5578
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "luokalla %q#T on virtuaalifunktioita ja käytettävissä oleva epävirtuaalinen hajotin"
 
-#: cp/class.c:5590
+#: cp/class.c:5607
 #, gcc-internal-format
 msgid "non-static reference %q#D in class without a constructor"
 msgstr ""
 
-#: cp/class.c:5596
+#: cp/class.c:5613
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qE declared %<constexpr%>"
 msgid "non-static const member %q#D in class without a constructor"
@@ -41506,160 +41550,160 @@
 
 #. If the function is defaulted outside the class, we just
 #. give the synthesis error.
-#: cp/class.c:5624
+#: cp/class.c:5641
 #, gcc-internal-format
 msgid "%q+D declared to take const reference, but implicit declaration would take non-const"
 msgstr ""
 
-#: cp/class.c:5898
+#: cp/class.c:5915
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:5910
+#: cp/class.c:5927
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:6133
+#: cp/class.c:6150
 #, fuzzy, gcc-internal-format
 #| msgid "layout of classes derived from empty class %qT may change in a future version of GCC"
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr "tyhjästä luokasta %qT perittyjen luokkien rakenne saattaa muuttua GCC:n tulevissa versioissa"
 
-#: cp/class.c:6291
+#: cp/class.c:6308
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qE is too large"
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr "taulukon %qE koko on liian suuri"
 
-#: cp/class.c:6576
+#: cp/class.c:6593
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr "virheellinen ei-staattisen jäsenfunktion käyttö"
 
-#: cp/class.c:6578
+#: cp/class.c:6595
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of structure with flexible array member"
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr "joustavan taulukkojäsenen sisältävän tietueen epäkelpo käyttö"
 
-#: cp/class.c:6583
+#: cp/class.c:6600
 #, fuzzy, gcc-internal-format
 msgid "array member %q#D declared here"
 msgstr "%q+#D aiemmin esitelty täällä"
 
-#: cp/class.c:6610
+#: cp/class.c:6627
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member not at end of struct"
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr "joustava taulukkojäsen ei ole structin lopussa"
 
-#: cp/class.c:6612
+#: cp/class.c:6629
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member in otherwise empty struct"
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr "joustava taulukkojäsen muuten tyhjässä structissa"
 
-#: cp/class.c:6620 cp/class.c:6650
+#: cp/class.c:6637 cp/class.c:6667
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %q#T"
 msgid "in the definition of %q#T"
 msgstr "edellinen %q+#T:n määrittely"
 
-#: cp/class.c:6628
+#: cp/class.c:6645
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member not at end of struct"
 msgid "flexible array member %qD not at end of %q#T"
 msgstr "joustava taulukkojäsen ei ole structin lopussa"
 
-#: cp/class.c:6630
+#: cp/class.c:6647
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member in otherwise empty struct"
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr "joustava taulukkojäsen muuten tyhjässä structissa"
 
-#: cp/class.c:6648
+#: cp/class.c:6665
 #, fuzzy, gcc-internal-format
 msgid "next member %q#D declared here"
 msgstr "%q+#D aiemmin esitelty täällä"
 
-#: cp/class.c:6760 cp/parser.c:23239
+#: cp/class.c:6777 cp/parser.c:23236
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "%q#T uudelleenmääritelty"
 
-#: cp/class.c:6897
+#: cp/class.c:6914
 #, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "luokalla %q#T on virtuaalifunktioita ja käytettävissä oleva epävirtuaalinen hajotin"
 
-#: cp/class.c:6925
+#: cp/class.c:6942
 #, fuzzy, gcc-internal-format
 msgid "type transparent %q#T does not have any fields"
 msgstr "luokalla %qT ei ole %qD-nimistä kenttää"
 
-#: cp/class.c:6931
+#: cp/class.c:6948
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr ""
 
-#: cp/class.c:6935
+#: cp/class.c:6952
 #, fuzzy, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr "%<this%> ei ole käytettävissä staattisissa jäsenfunktioissa"
 
-#: cp/class.c:6941
+#: cp/class.c:6958
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:7071
+#: cp/class.c:7088
 #, fuzzy, gcc-internal-format
 msgid "definition of %qD does not match %<#include <initializer_list>%>"
 msgstr "funktion %q+D määrittely on merkitty dllimport-tyyppiseksi"
 
-#: cp/class.c:7082
+#: cp/class.c:7099
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr ""
 
-#: cp/class.c:7582
+#: cp/class.c:7599
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr ""
 
-#: cp/class.c:7672
+#: cp/class.c:7689
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr ""
 
-#: cp/class.c:7817
+#: cp/class.c:7834
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr ""
 
-#: cp/class.c:7844
+#: cp/class.c:7861
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr ""
 
-#: cp/class.c:7870
+#: cp/class.c:7887
 #, fuzzy, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "%qD ei ole %qD:n jäsen"
 
-#: cp/class.c:7873
+#: cp/class.c:7890
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr ""
 
-#: cp/class.c:7948 cp/class.c:7990
+#: cp/class.c:7965 cp/class.c:8007
 #, fuzzy, gcc-internal-format
 msgid "not enough type information"
 msgstr "liian vähän argumentteja"
 
-#: cp/class.c:7968
+#: cp/class.c:7985
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "%qE:ta ei voi muuntaa tyypistä %qT tyyppiin %qT"
@@ -41669,12 +41713,12 @@
 #. A name N used in a class S shall refer to the same declaration
 #. in its context and when re-evaluated in the completed scope of
 #. S.
-#: cp/class.c:8235
+#: cp/class.c:8252
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D"
 msgstr "esittelyssä %q+D"
 
-#: cp/class.c:8237
+#: cp/class.c:8254
 #, gcc-internal-format
 msgid "changes meaning of %qD from %q#D"
 msgstr ""
@@ -42074,17 +42118,17 @@
 msgid "unexpected AST of kind %s"
 msgstr "Odottamaton %s-lause kohdassa %C"
 
-#: cp/cp-gimplify.c:1415
+#: cp/cp-gimplify.c:1416
 #, gcc-internal-format
 msgid "throw will always call terminate()"
 msgstr ""
 
-#: cp/cp-gimplify.c:1418
+#: cp/cp-gimplify.c:1419
 #, gcc-internal-format
 msgid "in C++11 destructors default to noexcept"
 msgstr ""
 
-#: cp/cp-gimplify.c:1429
+#: cp/cp-gimplify.c:1430
 #, gcc-internal-format
 msgid "in C++11 this throw will terminate because destructors default to noexcept"
 msgstr ""
@@ -42506,7 +42550,7 @@
 msgid "redeclaration %qD differs in %<constexpr%> from previous declaration"
 msgstr "luetellun tyypin jäsenen %q+D uudelleenesittely"
 
-#: cp/decl.c:1304 cp/decl.c:13843
+#: cp/decl.c:1304 cp/decl.c:13867
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr "edellinen esittely %q+D"
@@ -42848,7 +42892,7 @@
 msgid "  enters OpenMP structured block"
 msgstr "  siirtyy catch-lohkoon"
 
-#: cp/decl.c:3434 cp/parser.c:12366 cp/parser.c:12387
+#: cp/decl.c:3434 cp/parser.c:12363 cp/parser.c:12384
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr ""
@@ -42858,7 +42902,7 @@
 msgid "%qD is not a type"
 msgstr "%qD ei ole tyyppi"
 
-#: cp/decl.c:3838 cp/parser.c:6366
+#: cp/decl.c:3838 cp/parser.c:6369
 #, gcc-internal-format
 msgid "%qD used without template parameters"
 msgstr ""
@@ -43244,8 +43288,8 @@
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.c:6011 cp/decl.c:6234 cp/typeck2.c:1310 cp/typeck2.c:1590
-#: cp/typeck2.c:1638 cp/typeck2.c:1685
+#: cp/decl.c:6011 cp/decl.c:6234 cp/typeck2.c:1310 cp/typeck2.c:1593
+#: cp/typeck2.c:1641 cp/typeck2.c:1688
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "liikaa alustimia %qT:lle"
@@ -43320,12 +43364,12 @@
 msgid "assignment (not initialization) in declaration"
 msgstr "sijoitus (ei alustus) esittelyssä"
 
-#: cp/decl.c:6873 cp/decl.c:12605
+#: cp/decl.c:6873 cp/decl.c:12629
 #, fuzzy, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C ei salli ylimääräisiä %<;%>-merkkejä funktion ulkopuolella"
 
-#: cp/decl.c:6877 cp/decl.c:12609
+#: cp/decl.c:6877 cp/decl.c:12633
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for %qs"
 msgid "%<register%> storage class specifier used"
@@ -43353,44 +43397,44 @@
 msgid "function %q#D is initialized like a variable"
 msgstr "funktio %q#D alustetaan kuin muuttuja"
 
-#: cp/decl.c:7329
+#: cp/decl.c:7350
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr ""
 
-#: cp/decl.c:7332
+#: cp/decl.c:7353
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.c:7339
+#: cp/decl.c:7360
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "perustyypin %qT kaksoiskappale virheellinen"
 
-#: cp/decl.c:7365
+#: cp/decl.c:7386
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:7374
+#: cp/decl.c:7395
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:7592
+#: cp/decl.c:7613
 #, fuzzy, gcc-internal-format
 #| msgid "cannot decrement a pointer to incomplete type %qT"
 msgid "structured binding refers to incomplete type %qT"
 msgstr "ei voida vähentää osoitinta vaillinaiseen tyyppiin %qT"
 
-#: cp/decl.c:7608
+#: cp/decl.c:7629
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable length array %qE"
 msgid "cannot decompose variable length array %qT"
 msgstr "ISO C90 kieltää muuttuvakokoisen taulukon %qE"
 
-#: cp/decl.c:7617 cp/decl.c:7702
+#: cp/decl.c:7638 cp/decl.c:7723
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qs specified for structure field"
 msgid "%u name provided for structured binding"
@@ -43398,7 +43442,7 @@
 msgstr[0] "%qs määritelty tietueen kentälle"
 msgstr[1] "%qs määritelty tietueen kentälle"
 
-#: cp/decl.c:7621
+#: cp/decl.c:7642
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
@@ -43405,7 +43449,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:7624
+#: cp/decl.c:7645
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
@@ -43412,899 +43456,899 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:7669
+#: cp/decl.c:7690
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr "luokalla %q#T on datajäseninä osoittimia"
 
-#: cp/decl.c:7695
+#: cp/decl.c:7716
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "taulukon koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/decl.c:7704
+#: cp/decl.c:7725
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.c:7725
+#: cp/decl.c:7746
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type for iteration variable %qE"
 msgid "in initialization of structured binding variable %qD"
 msgstr "virheellinen tyyppi iterointimuuttujalle %qE"
 
-#: cp/decl.c:7751
+#: cp/decl.c:7772
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr "tyyppimuunnos lisää funktiotyyppiin uusia määreitä"
 
-#: cp/decl.c:7756
+#: cp/decl.c:7777
 #, fuzzy, gcc-internal-format
 #| msgid "cannot decrement a pointer to incomplete type %qT"
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "ei voida vähentää osoitinta vaillinaiseen tyyppiin %qT"
 
-#: cp/decl.c:7761
+#: cp/decl.c:7782
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose lambda closure type %qT"
 msgstr "Pyydettyä osoitetta ei voi asettaa"
 
-#: cp/decl.c:7765
+#: cp/decl.c:7786
 #, fuzzy, gcc-internal-format
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "paluutyyppi on vaillinainen tyyppi"
 
-#: cp/decl.c:7774
+#: cp/decl.c:7795
 #, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr ""
 
-#: cp/decl.c:8213
+#: cp/decl.c:8234
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:8216
+#: cp/decl.c:8237
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:8222
+#: cp/decl.c:8243
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:8450
+#: cp/decl.c:8471
 #, fuzzy, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "alustin ei pysty päättelemään taulukon %q+D kokoa"
 
-#: cp/decl.c:8454
+#: cp/decl.c:8475
 #, fuzzy, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "%qD-taulukon koko puuttuu"
 
-#: cp/decl.c:8457
+#: cp/decl.c:8478
 #, fuzzy, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "nollan kokoinen taulukko %qD"
 
-#: cp/decl.c:8473
+#: cp/decl.c:8494
 #, fuzzy, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "Java-luokalla %qT ei voi olla hajotinta"
 
-#: cp/decl.c:8475
+#: cp/decl.c:8496
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.c:8499
+#: cp/decl.c:8520
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "funktio %qD esitelty virtuaaliseksi unionissa"
 
-#: cp/decl.c:8501
+#: cp/decl.c:8522
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr ""
 
-#: cp/decl.c:8506
+#: cp/decl.c:8527
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "parametri %qD esitelty void-tyyppisenä"
 
-#: cp/decl.c:8508
+#: cp/decl.c:8529
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "parametri %q+D esitelty %<inline%>:ksi"
 
-#: cp/decl.c:8510
+#: cp/decl.c:8531
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:8515
+#: cp/decl.c:8536
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "parametri %qD esitelty void-tyyppisenä"
 
-#: cp/decl.c:8517
+#: cp/decl.c:8538
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "parametri %qD esitelty void-tyyppisenä"
 
-#: cp/decl.c:8519
+#: cp/decl.c:8540
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr ""
 
-#: cp/decl.c:8524
+#: cp/decl.c:8545
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "funktio %qD esitelty virtuaaliseksi unionissa"
 
-#: cp/decl.c:8526
+#: cp/decl.c:8547
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "parametri %q+D esitelty %<inline%>:ksi"
 
-#: cp/decl.c:8528
+#: cp/decl.c:8549
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr ""
 
-#: cp/decl.c:8535
+#: cp/decl.c:8556
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D esitelty ystävänä"
 
-#: cp/decl.c:8542
+#: cp/decl.c:8563
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "nimike %qD esitelty muttei määritelty"
 
-#: cp/decl.c:8574
+#: cp/decl.c:8595
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr ""
 
-#: cp/decl.c:8614
+#: cp/decl.c:8635
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "staattinen jäsenfunktio %q#D esitelty tyyppimääreillä"
 
-#: cp/decl.c:8624
+#: cp/decl.c:8645
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a non-parameter"
 msgid "concept %q#D declared with function parameters"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
 
-#: cp/decl.c:8630
+#: cp/decl.c:8651
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD declared with void type"
 msgid "concept %q#D declared with a deduced return type"
 msgstr "parametri %qD esitelty void-tyyppisenä"
 
-#: cp/decl.c:8632
+#: cp/decl.c:8653
 #, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr ""
 
-#: cp/decl.c:8703
+#: cp/decl.c:8724
 #, fuzzy, gcc-internal-format
 #| msgid "old-style function definition"
 msgid "concept %qD has no definition"
 msgstr "%qD:n poistettu määrittely"
 
-#: cp/decl.c:8772
+#: cp/decl.c:8793
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr ""
 
 #. Something like `template <class T> friend void f<T>()'.
-#: cp/decl.c:8782
+#: cp/decl.c:8803
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr ""
 
-#: cp/decl.c:8800
+#: cp/decl.c:8821
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:8808
+#: cp/decl.c:8829
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:8857
+#: cp/decl.c:8878
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "funktiota %<main%> ei voi määrittää avoimeksi"
 
-#: cp/decl.c:8859
+#: cp/decl.c:8880
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "funktiota %<main%> ei voi määrittää avoimeksi"
 
-#: cp/decl.c:8861
+#: cp/decl.c:8882
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be %<constexpr%>"
 msgstr "parametriksi ei voida esitellä %<constexpr%>:ksi"
 
-#: cp/decl.c:8863
+#: cp/decl.c:8884
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "funktiota %<main%> ei voi määrittää avoimeksi"
 
-#: cp/decl.c:8920
+#: cp/decl.c:8941
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.c:8921
+#: cp/decl.c:8942
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr ""
 
-#: cp/decl.c:8929
+#: cp/decl.c:8950
 #, fuzzy, gcc-internal-format
 #| msgid "static member function %q#D declared with type qualifiers"
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "staattinen jäsenfunktio %q#D esitelty tyyppimääreillä"
 
-#: cp/decl.c:8930
+#: cp/decl.c:8951
 #, fuzzy, gcc-internal-format
 #| msgid "static member function %q#D declared with type qualifiers"
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "staattinen jäsenfunktio %q#D esitelty tyyppimääreillä"
 
-#: cp/decl.c:8940
+#: cp/decl.c:8961
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared at namespace scope"
 msgstr ""
 
-#: cp/decl.c:8946
+#: cp/decl.c:8967
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "deduction guide %qD must not have a function body"
 msgstr "%qD:n esittely ei-funktiona"
 
-#: cp/decl.c:8959
+#: cp/decl.c:8980
 #, fuzzy, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr "malli C-linkityksellä"
 
-#: cp/decl.c:8969
+#: cp/decl.c:8990
 #, fuzzy, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "virheellinen IACC-argumentti"
 
-#: cp/decl.c:8977
+#: cp/decl.c:8998
 #, fuzzy, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr "virheellinen loppuliite ”%.*s” kokonaislukuvakiolla"
 
-#: cp/decl.c:8983
+#: cp/decl.c:9004
 #, fuzzy, gcc-internal-format
 msgid "floating point suffix %qs shadowed by implementation"
 msgstr "virheellinen loppuliite ”%.*s” kokonaislukuvakiolla"
 
-#: cp/decl.c:8991
+#: cp/decl.c:9012
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/decl.c:8996
+#: cp/decl.c:9017
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "%qD:n esittely ei-jäsenenä"
 
-#: cp/decl.c:9076
+#: cp/decl.c:9097
 #, fuzzy, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "paluutyyppi on oletuksena %<int%>"
 
-#: cp/decl.c:9116
+#: cp/decl.c:9137
 #, fuzzy, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "funktion määrittely esitelty %<auto%>:ksi"
 
-#: cp/decl.c:9121
+#: cp/decl.c:9142
 #, fuzzy, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "%q+D:n edellinen määrittely oli täällä"
 
-#: cp/decl.c:9123
+#: cp/decl.c:9144
 #, fuzzy, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr "%q+D:n edellinen määrittely oli täällä"
 
-#: cp/decl.c:9140
+#: cp/decl.c:9161
 #, fuzzy, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "staattinen jäsenfunktio %q#D esitelty tyyppimääreillä"
 
-#: cp/decl.c:9329
+#: cp/decl.c:9350
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "%Jparametri %qD esitelty %<inline%>:ksi"
 
-#: cp/decl.c:9337
+#: cp/decl.c:9358
 #, fuzzy, gcc-internal-format
 #| msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "automaattimuuttuja %qE ei voi olla %<threadprivate%>"
 
-#: cp/decl.c:9344
+#: cp/decl.c:9365
 #, fuzzy, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr "keskeytysfunktiolla on oltava void-paluutyyppi"
 
 # semi-fuzzy
-#: cp/decl.c:9464
+#: cp/decl.c:9485
 #, fuzzy, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "ei-staattista datajäsentä %q+D käytetty virheellisesti"
 
-#: cp/decl.c:9468
+#: cp/decl.c:9489
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "ISO C++ kieltää epäkokonaislukutyyppiä %2$qT olevan vakiojäsenen %1$qD alustamisen"
 
-#: cp/decl.c:9472
+#: cp/decl.c:9493
 #, fuzzy, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "ISO C++ kieltää epäkokonaislukutyyppiä %2$qT olevan vakiojäsenen %1$qD alustamisen"
 
-#: cp/decl.c:9486
+#: cp/decl.c:9507
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:9493
+#: cp/decl.c:9514
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr ""
 
-#: cp/decl.c:9498
+#: cp/decl.c:9519
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO C++ kieltää epäkokonaislukutyyppiä %2$qT olevan vakiojäsenen %1$qD alustamisen"
 
-#: cp/decl.c:9598
+#: cp/decl.c:9619
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "taulukon %qD koolla on epäkokonaislukutyyppi %qT"
 
-#: cp/decl.c:9600
+#: cp/decl.c:9621
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "taulukon koolla on epäkokonaislukutyyppi %qT"
 
-#: cp/decl.c:9630 cp/decl.c:9680
+#: cp/decl.c:9651 cp/decl.c:9701
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "taulukon koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/decl.c:9646
+#: cp/decl.c:9667
 #, gcc-internal-format
 msgid "size of array %qD is negative"
 msgstr "taulukon %qD koko on negatiivinen"
 
-#: cp/decl.c:9648 cp/init.c:3651
+#: cp/decl.c:9669 cp/init.c:3667
 #, gcc-internal-format
 msgid "size of array is negative"
 msgstr "taulukon koko on negatiivinen"
 
-#: cp/decl.c:9662
+#: cp/decl.c:9683
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C++ kieltää nollan kokoisen taulukon %qD"
 
-#: cp/decl.c:9664
+#: cp/decl.c:9685
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++ kieltää nollan kokoisen taulukon"
 
-#: cp/decl.c:9677
+#: cp/decl.c:9698
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/decl.c:9686
+#: cp/decl.c:9707
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++ kieltää muuttuvakokoisen taulukon %qD"
 
-#: cp/decl.c:9688
+#: cp/decl.c:9709
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++ kieltää muuttuvakokoisen taulukon"
 
-#: cp/decl.c:9694
+#: cp/decl.c:9715
 #, fuzzy, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr "käytetään muuttuvapituista taulukkoa"
 
-#: cp/decl.c:9697
+#: cp/decl.c:9718
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr "käytetään muuttuvapituista taulukkoa"
 
-#: cp/decl.c:9746
+#: cp/decl.c:9767
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "taulukon koon ylivuoto"
 
-#: cp/decl.c:9799
+#: cp/decl.c:9820
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "%qD declared as array of %qT"
 msgstr "%qD esiteltiin täällä"
 
-#: cp/decl.c:9809
+#: cp/decl.c:9830
 #, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "%qD:n esittely void-taulukkona"
 
-#: cp/decl.c:9811
+#: cp/decl.c:9832
 #, gcc-internal-format
 msgid "creating array of void"
 msgstr "luodaan void-taulukko"
 
-#: cp/decl.c:9816
+#: cp/decl.c:9837
 #, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "%qD:n esittely funktioiden taulukkona"
 
-#: cp/decl.c:9818
+#: cp/decl.c:9839
 #, gcc-internal-format
 msgid "creating array of functions"
 msgstr "luodaan funktioiden taulukko"
 
-#: cp/decl.c:9823
+#: cp/decl.c:9844
 #, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "%qD:n esittely viitteiden taulukkona"
 
-#: cp/decl.c:9825
+#: cp/decl.c:9846
 #, gcc-internal-format
 msgid "creating array of references"
 msgstr "luodaan viitteiden taulukko"
 
-#: cp/decl.c:9830
+#: cp/decl.c:9851
 #, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "%qD:n esittely funktiojäsenten taulukkona"
 
-#: cp/decl.c:9832
+#: cp/decl.c:9853
 #, gcc-internal-format
 msgid "creating array of function members"
 msgstr "luodaan funktiojäsenten taulukkoa"
 
-#: cp/decl.c:9846
+#: cp/decl.c:9867
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "moniulotteisell taulukolla on oltava rajat kaikkiin suuntiin paitsi ensimmäiseen"
 
-#: cp/decl.c:9850
+#: cp/decl.c:9871
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "moniulotteisell taulukolla on oltava rajat kaikkiin suuntiin paitsi ensimmäiseen"
 
-#: cp/decl.c:9909
+#: cp/decl.c:9930
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr ""
 
-#: cp/decl.c:9912
+#: cp/decl.c:9933
 #, fuzzy, gcc-internal-format
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "Tyhjä taulukkomuodostin kohdassa %C ei ole sallittu"
 
-#: cp/decl.c:9922
+#: cp/decl.c:9943
 #, fuzzy, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "virheellinen hajottimen %qD käyttö tyyppinä"
 
-#: cp/decl.c:9925
+#: cp/decl.c:9946
 #, fuzzy, gcc-internal-format
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "%Jvanhanmallinen funktiomäärittely"
 
-#: cp/decl.c:9937
+#: cp/decl.c:9958
 #, fuzzy, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "paluutyyppi %q#T on vaillinainen"
 
-#: cp/decl.c:9940
+#: cp/decl.c:9961
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr ""
 
-#: cp/decl.c:9948
+#: cp/decl.c:9969
 #, fuzzy, gcc-internal-format
 msgid "return type specified for deduction guide"
 msgstr "virheellinen hajottimen %qD käyttö tyyppinä"
 
-#: cp/decl.c:9951
+#: cp/decl.c:9972
 #, fuzzy, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "%Jvanhanmallinen funktiomäärittely"
 
-#: cp/decl.c:9955
+#: cp/decl.c:9976
 #, fuzzy, gcc-internal-format
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "%qD esitelty ei-parametrina"
 
-#: cp/decl.c:9964
+#: cp/decl.c:9985
 #, fuzzy, gcc-internal-format
 msgid "decl-specifier in declaration of deduction guide"
 msgstr "useita tallennusluokkia esittelymääritteissä"
 
-#: cp/decl.c:9985
+#: cp/decl.c:10006
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "nimetön muuttuja tai kenttä esitelty voidiksi"
 
-#: cp/decl.c:9992
+#: cp/decl.c:10013
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "muuttuja tai kenttä esitelty voidiksi"
 
-#: cp/decl.c:10007
+#: cp/decl.c:10028
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "ystäväesittely ei nimeä luokkaa tai funktiota"
 
-#: cp/decl.c:10013
+#: cp/decl.c:10034
 #, fuzzy, gcc-internal-format
 msgid "inline variables are only available with -std=c++17 or -std=gnu++17"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/decl.c:10268
+#: cp/decl.c:10292
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "Virheellinen käyttäjänimi ”%s” funktiossa %s, rivillä %d. Keskeytys."
 
-#: cp/decl.c:10271 cp/decl.c:10291
+#: cp/decl.c:10295 cp/decl.c:10315
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "määrittelemättömän tyypin %<%s %s%> epäkelpo käyttö"
 
-#: cp/decl.c:10274
+#: cp/decl.c:10298
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "Virheellinen käyttäjänimi ”%s” funktiossa %s, rivillä %d. Keskeytys."
 
-#: cp/decl.c:10283
+#: cp/decl.c:10307
 #, gcc-internal-format
 msgid "%q#T is not a class or a namespace"
 msgstr "%q#T ei ole luokka eikä nimiavaruus"
 
-#: cp/decl.c:10305 cp/decl.c:10398 cp/decl.c:10407 cp/decl.c:11970
+#: cp/decl.c:10329 cp/decl.c:10422 cp/decl.c:10431 cp/decl.c:11994
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "%qD:n esittely ei-funktiona"
 
-#: cp/decl.c:10311
+#: cp/decl.c:10335
 #, gcc-internal-format
 msgid "declaration of %qD as non-member"
 msgstr "%qD:n esittely ei-jäsenenä"
 
-#: cp/decl.c:10339
+#: cp/decl.c:10363
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr ""
 
-#: cp/decl.c:10390
+#: cp/decl.c:10414
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "funktion määrittely ei esittele parametrejä"
 
-#: cp/decl.c:10415
+#: cp/decl.c:10439
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "vaillinaisen tyypin typedef %qD epäkelpo käyttö"
 
-#: cp/decl.c:10420
+#: cp/decl.c:10444
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "parametrin %qD esittely, mutta parametria ei ole olemassa"
 
-#: cp/decl.c:10454
+#: cp/decl.c:10478
 #, fuzzy, gcc-internal-format
 msgid "%<concept%> cannot appear in a typedef declaration"
 msgstr "%Hprototyypin esittely"
 
-#: cp/decl.c:10460
+#: cp/decl.c:10484
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgstr "%Hprototyypin esittely"
 
-#: cp/decl.c:10468
+#: cp/decl.c:10492
 #, fuzzy, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "yli yksi tietotyyppi esittelymääritteissä"
 
-#: cp/decl.c:10474
+#: cp/decl.c:10498
 #, fuzzy, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr "useita tallennusluokkia esittelymääritteissä"
 
-#: cp/decl.c:10515
+#: cp/decl.c:10539
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C ei tue pelkkää %<complex%>-tyyppiä merkityksellä %<double complex%>"
 
-#: cp/decl.c:10564 cp/decl.c:10567 cp/decl.c:10570
+#: cp/decl.c:10588 cp/decl.c:10591 cp/decl.c:10594
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ kieltää muuttujan %qs esittelyn ilman tyyppiä"
 
-#: cp/decl.c:10586
+#: cp/decl.c:10610
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr "kohteen int-tyyppi on kapeampi kuin kohteen char-tyyppi"
 
-#: cp/decl.c:10592
+#: cp/decl.c:10616
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ 1998 ei tue %<long long%> -tyyppiä"
 
-#: cp/decl.c:10614 cp/decl.c:10634
+#: cp/decl.c:10638 cp/decl.c:10658
 #, gcc-internal-format
 msgid "%<signed%> or %<unsigned%> invalid for %qs"
 msgstr "%<signed%> tai %<unsigned%> virheellinen %qs:lle"
 
-#: cp/decl.c:10616
+#: cp/decl.c:10640
 #, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgstr "sekä %<signed%> että %<unsigned%> määritelty %qs:lle"
 
-#: cp/decl.c:10618
+#: cp/decl.c:10642
 #, gcc-internal-format
 msgid "%<long long%> invalid for %qs"
 msgstr "%<long long%> virheellinen %qs:lle"
 
-#: cp/decl.c:10620
+#: cp/decl.c:10644
 #, gcc-internal-format
 msgid "%<long%> invalid for %qs"
 msgstr "%<long%> virheellinen %qs:lle"
 
-#: cp/decl.c:10622
+#: cp/decl.c:10646
 #, gcc-internal-format
 msgid "%<short%> invalid for %qs"
 msgstr "%<short%> virheellinen %qs:lle"
 
-#: cp/decl.c:10624
+#: cp/decl.c:10648
 #, gcc-internal-format
 msgid "%<long%> or %<short%> invalid for %qs"
 msgstr "%<long%> tai %<short%> virheellinen %qs:lle"
 
-#: cp/decl.c:10626
+#: cp/decl.c:10650
 #, fuzzy, gcc-internal-format
 msgid "%<long%>, %<int%>, %<short%>, or %<char%> invalid for %qs"
 msgstr "%<long%> tai %<short%> virheellinen %qs:lle"
 
-#: cp/decl.c:10628
+#: cp/decl.c:10652
 #, fuzzy, gcc-internal-format
 msgid "%<long%> or %<short%> specified with char for %qs"
 msgstr "sekä %<long%> että %<short%> määritelty %qs:lle"
 
-#: cp/decl.c:10630
+#: cp/decl.c:10654
 #, gcc-internal-format
 msgid "%<long%> and %<short%> specified together for %qs"
 msgstr "sekä %<long%> että %<short%> määritelty %qs:lle"
 
-#: cp/decl.c:10636
+#: cp/decl.c:10660
 #, gcc-internal-format
 msgid "%<short%> or %<long%> invalid for %qs"
 msgstr "%<short%> tai %<long%> virheellinen %qs:lle"
 
-#: cp/decl.c:10644
+#: cp/decl.c:10668
 #, gcc-internal-format
 msgid "long, short, signed or unsigned used invalidly for %qs"
 msgstr ""
 
-#: cp/decl.c:10712
+#: cp/decl.c:10736
 #, fuzzy, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "epäkelpo osoitintila %qs"
 
-#: cp/decl.c:10751
+#: cp/decl.c:10775
 #, gcc-internal-format
 msgid "template placeholder type %qT must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.c:10769
+#: cp/decl.c:10793
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "jäsentä %qD ei voida esitellä sekä virtuaaliseksi että staattiseksi"
 
-#: cp/decl.c:10775
+#: cp/decl.c:10799
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD cannot be declared both %<virtual%> and %<constexpr%>"
 msgstr "jäsentä %qD ei voida esitellä sekä virtuaaliseksi että staattiseksi"
 
-#: cp/decl.c:10785
+#: cp/decl.c:10809
 #, fuzzy, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "parametrin %qD esittely, mutta parametria ei ole olemassa"
 
-#: cp/decl.c:10790
+#: cp/decl.c:10814
 #, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "tallennusluokka annettu malliparametrille %qs"
 
-#: cp/decl.c:10796
+#: cp/decl.c:10820
 #, gcc-internal-format
 msgid "storage class specifiers invalid in parameter declarations"
 msgstr "tallennusluokkatarkentimet virheellisiä parameteresittelyissä"
 
-#: cp/decl.c:10800
+#: cp/decl.c:10824
 #, fuzzy, gcc-internal-format
 #| msgid "a parameter cannot be declared %<constexpr%>"
 msgid "a parameter cannot be declared %<concept%>"
 msgstr "parametriksi ei voida esitellä %<constexpr%>:ksi"
 
-#: cp/decl.c:10805
+#: cp/decl.c:10829
 #, gcc-internal-format
 msgid "a parameter cannot be declared %<constexpr%>"
 msgstr "parametriksi ei voida esitellä %<constexpr%>:ksi"
 
-#: cp/decl.c:10815
+#: cp/decl.c:10839
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "%<virtual%> luokan esittelyn ulkopuolella"
 
-#: cp/decl.c:10825
+#: cp/decl.c:10849
 #, fuzzy, gcc-internal-format
 #| msgid "%<namespace%> definition is not allowed here"
 msgid "structured binding declaration cannot be %<inline%>"
 msgstr "%<namespace%>-määrittely ei ole sallittu täällä"
 
-#: cp/decl.c:10828
+#: cp/decl.c:10852
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %<typedef%>"
 msgstr "malliesittelylle %q+D"
 
-#: cp/decl.c:10830
+#: cp/decl.c:10854
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "structured binding declaration cannot be %<constexpr%>"
 msgstr "hajotin ei voi olla %<constexpr%>"
 
-#: cp/decl.c:10834
+#: cp/decl.c:10858
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr "attribuutti jätetty huomioimatta %q+#T:n esittelyssä"
 
-#: cp/decl.c:10839
+#: cp/decl.c:10863
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "structured binding declaration cannot be %<concept%>"
 msgstr "hajotin ei voi olla %<constexpr%>"
 
-#: cp/decl.c:10845
+#: cp/decl.c:10869
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %<register%>"
 msgstr "ISO C kieltää %<register%>-taulukon indeksoinnin"
 
-#: cp/decl.c:10849
+#: cp/decl.c:10873
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<static%>"
 msgstr ""
 
-#: cp/decl.c:10853
+#: cp/decl.c:10877
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %<extern%>"
 msgstr "sisäkkäinen funktio %qs esitelty %<extern%>:ksi"
 
-#: cp/decl.c:10857
+#: cp/decl.c:10881
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %<mutable%>"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: cp/decl.c:10861
+#: cp/decl.c:10885
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10872
+#: cp/decl.c:10896
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr "attribuutti jätetty huomioimatta %q+#T:n esittelyssä"
 
-#: cp/decl.c:10875
+#: cp/decl.c:10899
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10906
+#: cp/decl.c:10930
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "useita tallennusluokkia %qs:n esittelyssä"
 
-#: cp/decl.c:10929
+#: cp/decl.c:10953
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "tallennusluokka annettu %qs:lle"
 
-#: cp/decl.c:10933
+#: cp/decl.c:10957
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "tallennusluokka annettu parametrille %qs"
 
-#: cp/decl.c:10946
+#: cp/decl.c:10970
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "sisäkkäinen funktio %qs esitelty %<extern%>:ksi"
 
-#: cp/decl.c:10950
+#: cp/decl.c:10974
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10957
+#: cp/decl.c:10981
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "funktioalue %qs implisiittisesti auto ja esitelty %<__thread%>:ksi"
 
-#: cp/decl.c:10969
+#: cp/decl.c:10993
 #, fuzzy, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "tallennusluokkatarkentimet virheellisiä parameteresittelyissä"
 
-#: cp/decl.c:11050
+#: cp/decl.c:11074
 #, fuzzy, gcc-internal-format
 #| msgid "multiple storage classes in declaration of %qs"
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "useita tallennusluokkia %qs:n esittelyssä"
 
-#: cp/decl.c:11098
+#: cp/decl.c:11122
 #, fuzzy, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr "paluutyyppi on vaillinainen tyyppi"
 
-#: cp/decl.c:11118
+#: cp/decl.c:11142
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.c:11121
+#: cp/decl.c:11145
 #, fuzzy, gcc-internal-format
 msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/decl.c:11127
+#: cp/decl.c:11151
 #, fuzzy, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr "%qs-nimikkeen kaksoisesittely"
 
-#: cp/decl.c:11134
+#: cp/decl.c:11158
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:11147
+#: cp/decl.c:11171
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "deduced class type %qD in function return type"
 msgstr "tyyppimääreet jätetään huomiotta funktion paluutyypissä"
 
-#: cp/decl.c:11156
+#: cp/decl.c:11180
 #, fuzzy, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr "%qs-nimikkeen kaksoisesittely"
 
-#: cp/decl.c:11169
+#: cp/decl.c:11193
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
@@ -44311,59 +44355,59 @@
 
 #. Not using maybe_warn_cpp0x because this should
 #. always be an error.
-#: cp/decl.c:11180
+#: cp/decl.c:11204
 #, gcc-internal-format
 msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/decl.c:11183
+#: cp/decl.c:11207
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.c:11212
+#: cp/decl.c:11236
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: cp/decl.c:11218
+#: cp/decl.c:11242
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs esitelty taulukon palauttavan funktiona"
 
-#: cp/decl.c:11247
+#: cp/decl.c:11271
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "hajotin ei voi olla staattinen jäsenfunktio"
 
-#: cp/decl.c:11248
+#: cp/decl.c:11272
 #, fuzzy, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "hajotin ei voi olla staattinen jäsenfunktio"
 
-#: cp/decl.c:11252
+#: cp/decl.c:11276
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "hajottimet eivät voi olla cv-määriteltyjä"
 
-#: cp/decl.c:11253
+#: cp/decl.c:11277
 #, fuzzy, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "hajottimet eivät voi olla cv-määriteltyjä"
 
-#: cp/decl.c:11261
+#: cp/decl.c:11285
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "destructors may not be ref-qualified"
 msgstr "hajottimet eivät voi olla cv-määriteltyjä"
 
-#: cp/decl.c:11262
+#: cp/decl.c:11286
 #, fuzzy, gcc-internal-format
 #| msgid "destructors may not be cv-qualified"
 msgid "constructors may not be ref-qualified"
 msgstr "hajottimet eivät voi olla cv-määriteltyjä"
 
-#: cp/decl.c:11280
+#: cp/decl.c:11304
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructors cannot be declared %<virtual%>"
@@ -44370,252 +44414,252 @@
 msgstr "muodostimia ei voi esitellä virtuaalisiksi"
 
 #. Cannot be both friend and virtual.
-#: cp/decl.c:11295
+#: cp/decl.c:11319
 #, fuzzy, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "tyypillä %qE on virtuaalisia jäsenfunktioita"
 
-#: cp/decl.c:11299
+#: cp/decl.c:11323
 #, fuzzy, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "luokkamäärittelyä ei voi esitellä ystäväksi"
 
-#: cp/decl.c:11301
+#: cp/decl.c:11325
 #, gcc-internal-format
 msgid "can%'t define friend function %qs in a local class definition"
 msgstr ""
 
-#: cp/decl.c:11313
+#: cp/decl.c:11337
 #, fuzzy, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr "%qs-nimikkeen kaksoisesittely"
 
-#: cp/decl.c:11339
+#: cp/decl.c:11363
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "hajottimilla ei voi olla parametreja"
 
-#: cp/decl.c:11379
+#: cp/decl.c:11403
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "luokalla %q#T on datajäseninä osoittimia"
 
-#: cp/decl.c:11392 cp/decl.c:11399
+#: cp/decl.c:11416 cp/decl.c:11423
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr ""
 
-#: cp/decl.c:11401
+#: cp/decl.c:11425
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr ""
 
-#: cp/decl.c:11430
+#: cp/decl.c:11454
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "tyyppimuunnos lisää funktiotyyppiin uusia määreitä"
 
-#: cp/decl.c:11431
+#: cp/decl.c:11455
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "tyyppimuunnos lisää funktiotyyppiin uusia määreitä"
 
-#: cp/decl.c:11504
+#: cp/decl.c:11528
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.c:11574
+#: cp/decl.c:11598
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr ""
 
-#: cp/decl.c:11599
+#: cp/decl.c:11623
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr ""
 
-#: cp/decl.c:11605
+#: cp/decl.c:11629
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr ""
 
-#: cp/decl.c:11635
+#: cp/decl.c:11659
 #, fuzzy, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "funktiota %<main%> ei voi määrittää avoimeksi"
 
-#: cp/decl.c:11637
+#: cp/decl.c:11661
 #, fuzzy, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "funktiota %<main%> ei voi määrittää avoimeksi"
 
-#: cp/decl.c:11645
+#: cp/decl.c:11669
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr ""
 
-#: cp/decl.c:11685
+#: cp/decl.c:11709
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr ""
 
-#: cp/decl.c:11693
+#: cp/decl.c:11717
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.c:11695
+#: cp/decl.c:11719
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.c:11706
+#: cp/decl.c:11730
 #, fuzzy, gcc-internal-format
 #| msgid "%<virtual%> outside class declaration"
 msgid "%<explicit%> outside class declaration"
 msgstr "%<virtual%> luokan esittelyn ulkopuolella"
 
-#: cp/decl.c:11709
+#: cp/decl.c:11733
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> in empty declaration"
 msgid "%<explicit%> in friend declaration"
 msgstr "%<inline%> tyhjässä esittelyssä"
 
-#: cp/decl.c:11712
+#: cp/decl.c:11736
 #, fuzzy, gcc-internal-format
 #| msgid "only declarations of constructors can be %<explicit%>"
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "vain muodostimen esittely voi olla %<explicit%>"
 
-#: cp/decl.c:11721
+#: cp/decl.c:11745
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:11726
+#: cp/decl.c:11750
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:11732
+#: cp/decl.c:11756
 #, fuzzy, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: cp/decl.c:11737
+#: cp/decl.c:11761
 #, fuzzy, gcc-internal-format
 msgid "static %qs cannot be declared %<mutable%>"
 msgstr "jäsentä %qD ei voida esitellä sekä virtuaaliseksi että staattiseksi"
 
-#: cp/decl.c:11742
+#: cp/decl.c:11766
 #, gcc-internal-format
 msgid "const %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:11747
+#: cp/decl.c:11771
 #, fuzzy, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "%Jparametri %qD esitelty %<inline%>:ksi"
 
-#: cp/decl.c:11778
+#: cp/decl.c:11802
 #, fuzzy, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "funktion määrittely esitelty %<auto%>:ksi"
 
-#: cp/decl.c:11783
+#: cp/decl.c:11807
 #, fuzzy, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr "<typedef-virhe>"
 
-#: cp/decl.c:11787
+#: cp/decl.c:11811
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr ""
 
-#: cp/decl.c:11813
+#: cp/decl.c:11837
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr ""
 
-#: cp/decl.c:11900
+#: cp/decl.c:11924
 #, fuzzy, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "ystäväesittely ei nimeä luokkaa tai funktiota"
 
-#: cp/decl.c:11908
+#: cp/decl.c:11932
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr ""
 
-#: cp/decl.c:11910
+#: cp/decl.c:11934
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr ""
 
-#: cp/decl.c:11914
+#: cp/decl.c:11938
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr ""
 
-#: cp/decl.c:11927
+#: cp/decl.c:11951
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr ""
 
-#: cp/decl.c:11947
+#: cp/decl.c:11971
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "virheelliset määreet ei-jäsenfunktion tyypissä"
 
-#: cp/decl.c:11951
+#: cp/decl.c:11975
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.c:11961
+#: cp/decl.c:11985
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr ""
 
-#: cp/decl.c:11976
+#: cp/decl.c:12000
 #, fuzzy, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "virheellinen %qT-tyyppisen viittauksen alustus %qT-tyyppisestä lausekkeesta"
 
-#: cp/decl.c:11995
+#: cp/decl.c:12019
 #, fuzzy, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "parametrin %qD esittely, mutta parametria ei ole olemassa"
 
-#: cp/decl.c:12001
+#: cp/decl.c:12025
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "parametri esitelty %<auto%>:ksi"
 
-#: cp/decl.c:12003
+#: cp/decl.c:12027
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "parametri esitelty %<auto%>:ksi"
 
-#: cp/decl.c:12052 cp/parser.c:3270
+#: cp/decl.c:12076 cp/parser.c:3270
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "mallinimen %qE virheellinen käyttö ilman argumenttiluetteloa"
 
-#: cp/decl.c:12056
+#: cp/decl.c:12080
 #, fuzzy, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr "ei-staattinen datajäsen %qE esitelty %<constexpr%>:ksi"
 
-#: cp/decl.c:12080
+#: cp/decl.c:12104
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids zero-size array %qD"
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C++ kieltää nollan kokoisen taulukon %qD"
 
-#: cp/decl.c:12083
+#: cp/decl.c:12107
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array members"
@@ -44622,164 +44666,164 @@
 msgstr "ISO C90 ei tue joustavia taulukon jäseniä"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:12099
+#: cp/decl.c:12123
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "%qD:n virheellinen käyttö"
 
-#: cp/decl.c:12121
+#: cp/decl.c:12145
 #, fuzzy, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "virheellinen funktioesittely"
 
-#: cp/decl.c:12130
+#: cp/decl.c:12154
 #, fuzzy, gcc-internal-format
 #| msgid "function %qD declared virtual inside a union"
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "funktio %qD esitelty virtuaaliseksi unionissa"
 
-#: cp/decl.c:12139
+#: cp/decl.c:12163
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "jäsentä %qD ei voida esitellä sekä virtuaaliseksi että staattiseksi"
 
-#: cp/decl.c:12153
+#: cp/decl.c:12177
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr ""
 
-#: cp/decl.c:12160
+#: cp/decl.c:12184
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "%qD:n esittely %qT:n jäsenenä"
 
-#: cp/decl.c:12166
+#: cp/decl.c:12190
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "a destructor cannot be %<concept%>"
 msgstr "hajotin ei voi olla %<constexpr%>"
 
-#: cp/decl.c:12171
+#: cp/decl.c:12195
 #, gcc-internal-format
 msgid "a destructor cannot be %<constexpr%>"
 msgstr "hajotin ei voi olla %<constexpr%>"
 
-#: cp/decl.c:12177
+#: cp/decl.c:12201
 #, fuzzy, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "%qD esitelty staattisesti sisäkkäin"
 
-#: cp/decl.c:12185
+#: cp/decl.c:12209
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "a constructor cannot be %<concept%>"
 msgstr "Kopiomuodostin %qs"
 
-#: cp/decl.c:12190
+#: cp/decl.c:12214
 #, fuzzy, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr "hajotin ei voi olla staattinen jäsenfunktio"
 
-#: cp/decl.c:12199
+#: cp/decl.c:12223
 #, fuzzy, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr "%qs:n esittely taulukollisena tyhjiä alkioita"
 
-#: cp/decl.c:12202
+#: cp/decl.c:12226
 #, fuzzy, gcc-internal-format
 msgid "variable template declared here"
 msgstr "%qD esiteltiin täällä"
 
-#: cp/decl.c:12257
+#: cp/decl.c:12281
 #, fuzzy, gcc-internal-format
 #| msgid "field %qD has incomplete type"
 msgid "field %qD has incomplete type %qT"
 msgstr "%2$qD:n parametrilla %1$P on vaillinainen tyyppi %3$qT"
 
-#: cp/decl.c:12262
+#: cp/decl.c:12286
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "nimellä %qT on vaillinainen tyyppi"
 
-#: cp/decl.c:12272
+#: cp/decl.c:12296
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr ""
 
-#: cp/decl.c:12318
+#: cp/decl.c:12342
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qE declared %<constexpr%>"
 msgid "static data member %qE declared %<concept%>"
 msgstr "ei-staattinen datajäsen %qE esitelty %<constexpr%>:ksi"
 
-#: cp/decl.c:12322
+#: cp/decl.c:12346
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: cp/decl.c:12350
+#: cp/decl.c:12374
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qE declared %<constexpr%>"
 msgid "non-static data member %qE declared %<concept%>"
 msgstr "ei-staattinen datajäsen %qE esitelty %<constexpr%>:ksi"
 
-#: cp/decl.c:12354
+#: cp/decl.c:12378
 #, gcc-internal-format
 msgid "non-static data member %qE declared %<constexpr%>"
 msgstr "ei-staattinen datajäsen %qE esitelty %<constexpr%>:ksi"
 
-#: cp/decl.c:12409
+#: cp/decl.c:12433
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "tallennusluokka %<auto%> virheellinen funktiolle %qs"
 
-#: cp/decl.c:12411
+#: cp/decl.c:12435
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "tallennusluokka %<register%> virheellinen funktiolle %qs"
 
-#: cp/decl.c:12415
+#: cp/decl.c:12439
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "tallennusluokka %<__thread%> virheellinen funktiolle %qs"
 
-#: cp/decl.c:12418
+#: cp/decl.c:12442
 #, fuzzy, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "tallennusluokka %<__thread%> virheellinen funktiolle %qs"
 
-#: cp/decl.c:12423
+#: cp/decl.c:12447
 #, fuzzy, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "%Jvanhanmallinen funktiomäärittely"
 
-#: cp/decl.c:12434
+#: cp/decl.c:12458
 #, fuzzy, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "tallennusluokkatarkentimet virheellisiä parameteresittelyissä"
 
-#: cp/decl.c:12438
+#: cp/decl.c:12462
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.c:12446
+#: cp/decl.c:12470
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "virtuaalinen ei-luokkafunktio %qs"
 
-#: cp/decl.c:12453
+#: cp/decl.c:12477
 #, fuzzy, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "virtuaalinen ei-luokkafunktio %qs"
 
-#: cp/decl.c:12454
+#: cp/decl.c:12478
 #, fuzzy, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "virtuaalinen ei-luokkafunktio %qs"
 
-#: cp/decl.c:12489
+#: cp/decl.c:12513
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr ""
@@ -44786,77 +44830,77 @@
 
 #. 7.1.1: There can be no static function declarations within a
 #. block.
-#: cp/decl.c:12497
+#: cp/decl.c:12521
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr ""
 
-#: cp/decl.c:12533
+#: cp/decl.c:12557
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr ""
 
-#: cp/decl.c:12540
+#: cp/decl.c:12564
 #, fuzzy, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "jäsentä %qD ei voida esitellä sekä virtuaaliseksi että staattiseksi"
 
-#: cp/decl.c:12546
+#: cp/decl.c:12570
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr ""
 
-#: cp/decl.c:12553
+#: cp/decl.c:12577
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "%qD käytössä ilman esittelyä ennen sen määrittelyä"
 
-#: cp/decl.c:12574
+#: cp/decl.c:12598
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "%q#D:n esittelyllä ei ole alustimia"
 
-#: cp/decl.c:12585
+#: cp/decl.c:12609
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs alustettu ja esitelty %<extern%>-avainsanalla"
 
-#: cp/decl.c:12589
+#: cp/decl.c:12613
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs on sekä %<extern%> että alustin"
 
-#: cp/decl.c:12754
+#: cp/decl.c:12778
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "%qD:n malliargumentti käyttää paikallista tyyppiä %qT"
 
-#: cp/decl.c:12757
+#: cp/decl.c:12781
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr ""
 
-#: cp/decl.c:12841
+#: cp/decl.c:12865
 #, fuzzy, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "vaillinaisen tyypin typedef %qD epäkelpo käyttö"
 
-#: cp/decl.c:12845
+#: cp/decl.c:12869
 #, fuzzy, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "Varoita implisiittisistä funktioesittelyistä"
 
-#: cp/decl.c:12868
+#: cp/decl.c:12892
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "parametri %qD virheellisesti esitelty metodityyppi"
 
-#: cp/decl.c:12895
+#: cp/decl.c:12919
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.c:12897
+#: cp/decl.c:12921
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr ""
@@ -44876,176 +44920,176 @@
 #. or implicitly defined), there's no need to worry about their
 #. existence.  Theoretically, they should never even be
 #. instantiated, but that's hard to forestall.
-#: cp/decl.c:13150
+#: cp/decl.c:13174
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "virheellinen muodostin; tarkoitit todennäköisesti %<%T (const %T&)%>"
 
-#: cp/decl.c:13228
+#: cp/decl.c:13252
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr ""
 
-#: cp/decl.c:13234
+#: cp/decl.c:13258
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr ""
 
-#: cp/decl.c:13261
+#: cp/decl.c:13285
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr "jäsenfunktiota %qD ei voi kutsua ilman oliota"
 
-#: cp/decl.c:13267
+#: cp/decl.c:13291
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr ""
 
-#: cp/decl.c:13277
+#: cp/decl.c:13301
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr ""
 
 #. 13.4.0.3
-#: cp/decl.c:13303
+#: cp/decl.c:13327
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading operator ?:"
 msgstr "ISO C++ kieltää ?:-operaattorin ylikuormituksen"
 
 #. Variadic.
-#: cp/decl.c:13314
+#: cp/decl.c:13338
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD:lla ei saa olla vaihtuvaa määrää argumentteja"
 
-#: cp/decl.c:13338
+#: cp/decl.c:13362
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either zero or one argument"
 msgid "%qD must have either zero or one argument"
 msgstr "%qD:n on otettava joko nolla tai yksi argumenttia"
 
-#: cp/decl.c:13339
+#: cp/decl.c:13363
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either one or two arguments"
 msgid "%qD must have either one or two arguments"
 msgstr "%qD:n on otettava joko yksi tai kaksi argumenttia"
 
-#: cp/decl.c:13350
+#: cp/decl.c:13374
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L must have at least two arguments"
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "Kääntäjänsisäisellä ”%s”-funktiolla kohdassa %L on oltava vähintään kaksi argumenttia"
 
-#: cp/decl.c:13351
+#: cp/decl.c:13375
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L must have at least two arguments"
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "Kääntäjänsisäisellä ”%s”-funktiolla kohdassa %L on oltava vähintään kaksi argumenttia"
 
-#: cp/decl.c:13361
+#: cp/decl.c:13385
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have no arguments"
 msgstr "%qD:n on otettava tasan kaksi argumenttia"
 
-#: cp/decl.c:13362 cp/decl.c:13371
+#: cp/decl.c:13386 cp/decl.c:13395
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly one argument"
 msgid "%qD must have exactly one argument"
 msgstr "%qD:n on otettava tasan yksi argumentti"
 
-#: cp/decl.c:13372
+#: cp/decl.c:13396
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have exactly two arguments"
 msgstr "%qD:n on otettava tasan kaksi argumenttia"
 
-#: cp/decl.c:13389 cp/decl.c:13392
+#: cp/decl.c:13413 cp/decl.c:13416
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD:lla ei voi olla oletusargumentteja"
 
-#: cp/decl.c:13419
+#: cp/decl.c:13443
 #, fuzzy, gcc-internal-format
 msgid "conversion to a reference to void will never use a type conversion operator"
 msgstr "muunnnos void-tyypiksi ei koskaan käytä tyyppimuunnosoperaattoria"
 
-#: cp/decl.c:13421
+#: cp/decl.c:13445
 #, gcc-internal-format
 msgid "conversion to void will never use a type conversion operator"
 msgstr "muunnnos void-tyypiksi ei koskaan käytä tyyppimuunnosoperaattoria"
 
-#: cp/decl.c:13428
+#: cp/decl.c:13452
 #, fuzzy, gcc-internal-format
 msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgstr "muunnnos void-tyypiksi ei koskaan käytä tyyppimuunnosoperaattoria"
 
-#: cp/decl.c:13430
+#: cp/decl.c:13454
 #, fuzzy, gcc-internal-format
 msgid "conversion to the same type will never use a type conversion operator"
 msgstr "muunnnos void-tyypiksi ei koskaan käytä tyyppimuunnosoperaattoria"
 
-#: cp/decl.c:13438
+#: cp/decl.c:13462
 #, gcc-internal-format
 msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13440
+#: cp/decl.c:13464
 #, fuzzy, gcc-internal-format
 msgid "conversion to a base class will never use a type conversion operator"
 msgstr "muunnnos void-tyypiksi ei koskaan käytä tyyppimuunnosoperaattoria"
 
-#: cp/decl.c:13455
+#: cp/decl.c:13479
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr ""
 
-#: cp/decl.c:13474
+#: cp/decl.c:13498
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.c:13480
+#: cp/decl.c:13504
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.c:13492
+#: cp/decl.c:13516
 #, fuzzy, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "<paluuarvo> "
 
-#: cp/decl.c:13547
+#: cp/decl.c:13571
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr ""
 
-#: cp/decl.c:13570
+#: cp/decl.c:13594
 #, fuzzy, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: cp/decl.c:13573
+#: cp/decl.c:13597
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr ""
 
-#: cp/decl.c:13575
+#: cp/decl.c:13599
 #, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "%q+D:lla on edellinen esittely täällä"
 
-#: cp/decl.c:13583
+#: cp/decl.c:13607
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr ""
 
-#: cp/decl.c:13584 cp/decl.c:13591
+#: cp/decl.c:13608 cp/decl.c:13615
 #, fuzzy, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr "%q+D:lla on edellinen esittely täällä"
 
-#: cp/decl.c:13590
+#: cp/decl.c:13614
 #, fuzzy, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "lueteltu tyyppi määritelty täällä"
@@ -45057,94 +45101,94 @@
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:13605
+#: cp/decl.c:13629
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr ""
 
-#: cp/decl.c:13659 cp/name-lookup.c:4652
+#: cp/decl.c:13683 cp/name-lookup.c:4652
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD:llä on sama nimi kuin luokalla, jossa se on esitelty"
 
-#: cp/decl.c:13689 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6425
-#: cp/pt.c:9209
+#: cp/decl.c:13713 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6428
+#: cp/pt.c:9223
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT ei ole malli"
 
-#: cp/decl.c:13694
+#: cp/decl.c:13718
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:13703 cp/name-lookup.c:4079 cp/name-lookup.c:4086
-#: cp/name-lookup.c:4939 cp/parser.c:6376 cp/parser.c:26300
+#: cp/decl.c:13727 cp/name-lookup.c:4079 cp/name-lookup.c:4086
+#: cp/name-lookup.c:4939 cp/parser.c:6379 cp/parser.c:26297
 #, fuzzy, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "sijoitus kirjoitussuojattuun viitteeseen %qD"
 
-#: cp/decl.c:13806
+#: cp/decl.c:13830
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr ""
 
-#: cp/decl.c:13842
+#: cp/decl.c:13866
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "C++:n sisäinen tietotyyppi %qT määritelty uudelleen"
 
-#: cp/decl.c:13982
+#: cp/decl.c:14006
 #, fuzzy, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "useita kenttiä unionissa %qT alustettu"
 
-#: cp/decl.c:13989
+#: cp/decl.c:14013
 #, fuzzy, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr "%q+D on yleensä funktio"
 
-#: cp/decl.c:14000
+#: cp/decl.c:14024
 #, fuzzy, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr "%q+D on yleensä funktio"
 
-#: cp/decl.c:14025
+#: cp/decl.c:14049
 #, fuzzy, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "%qT ei ole luokka-, struct- eikä unionityyppi"
 
-#: cp/decl.c:14055
+#: cp/decl.c:14079
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "rekursiivinen tyyppi %qT määrittelemätön"
 
-#: cp/decl.c:14057
+#: cp/decl.c:14081
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "perustyypin %qT kaksoiskappale virheellinen"
 
-#: cp/decl.c:14202
+#: cp/decl.c:14226
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14205 cp/decl.c:14213 cp/decl.c:14225 cp/parser.c:18284
+#: cp/decl.c:14229 cp/decl.c:14237 cp/decl.c:14249 cp/parser.c:18281
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "edellinen määrittely täällä"
 
-#: cp/decl.c:14210
+#: cp/decl.c:14234
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14222
+#: cp/decl.c:14246
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14300
+#: cp/decl.c:14324
 #, fuzzy, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr "cppchar_t:n on oltava etumerkitön tyyppi"
@@ -45153,77 +45197,77 @@
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:14447
+#: cp/decl.c:14471
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr ""
 
-#: cp/decl.c:14619
+#: cp/decl.c:14643
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/decl.c:14629
+#: cp/decl.c:14653
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/decl.c:14678
+#: cp/decl.c:14702
 #, fuzzy, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/decl.c:14679
+#: cp/decl.c:14703
 #, fuzzy, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/decl.c:14690
+#: cp/decl.c:14714
 #, fuzzy, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "ylivuoto luetellun tyypin arvoissa"
 
-#: cp/decl.c:14710
+#: cp/decl.c:14734
 #, fuzzy, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/decl.c:14821
+#: cp/decl.c:14845
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "paluutyyppi %q#T on vaillinainen"
 
-#: cp/decl.c:14999 cp/typeck.c:9286
+#: cp/decl.c:15023 cp/typeck.c:9286
 #, fuzzy, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator delete%>:n on palautettava tyyppi %qT"
 
-#: cp/decl.c:15344
+#: cp/decl.c:15368
 #, gcc-internal-format
 msgid "invalid function declaration"
 msgstr "virheellinen funktioesittely"
 
-#: cp/decl.c:15786
+#: cp/decl.c:15810
 #, fuzzy, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr "return-lause ilman arvoa funktiossa, jonka paluutyyppi on %qT"
 
-#: cp/decl.c:15788 cp/typeck.c:9166
+#: cp/decl.c:15812 cp/typeck.c:9166
 #, fuzzy, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "funktion paluuarvojen tyypit eivät ole yhteensopivia %<volatile%>:n takia"
 
-#: cp/decl.c:15996
+#: cp/decl.c:16020
 #, gcc-internal-format
 msgid "invalid member function declaration"
 msgstr "virheellinen jäsenfunktioesittely"
 
-#: cp/decl.c:16010
+#: cp/decl.c:16034
 #, fuzzy, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD on jo määritelty"
 
-#: cp/decl.c:16386
+#: cp/decl.c:16410
 #, fuzzy, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr "%q+D:n oletustyyppi on %<int%>"
@@ -45263,7 +45307,7 @@
 msgid "deleting %qT is undefined"
 msgstr "rekursiivinen tyyppi %qT määrittelemätön"
 
-#: cp/decl2.c:585 cp/pt.c:5552
+#: cp/decl2.c:585 cp/pt.c:5566
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "malliesittelylle %q+D"
@@ -45276,7 +45320,7 @@
 #. [temp.mem]
 #.
 #. A destructor shall not be a member template.
-#: cp/decl2.c:640 cp/pt.c:5511
+#: cp/decl2.c:640 cp/pt.c:5525
 #, fuzzy, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "jäsentä %qD ei voida esitellä sekä virtuaaliseksi että staattiseksi"
@@ -45456,47 +45500,47 @@
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "%<operator delete%>:n ensimmäisen parametrin tyypin on oltava %qT"
 
-#: cp/decl2.c:2660
+#: cp/decl2.c:2650
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2664
+#: cp/decl2.c:2654
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2669
+#: cp/decl2.c:2659
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2677
+#: cp/decl2.c:2667
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr ""
 
-#: cp/decl2.c:2695
+#: cp/decl2.c:2685
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2699
+#: cp/decl2.c:2689
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2704
+#: cp/decl2.c:2694
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2711
+#: cp/decl2.c:2701
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr ""
 
-#: cp/decl2.c:4309
+#: cp/decl2.c:4299
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using unnamed type, is used but never defined"
 msgstr "%J%qF käytetty, mutta ei määritelty"
@@ -45505,62 +45549,62 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4318
+#: cp/decl2.c:4308
 #, fuzzy, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr "%J%qD esitelty uudelleen ilman linkitystä"
 
-#: cp/decl2.c:4322
+#: cp/decl2.c:4312
 #, fuzzy, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr "%J%qD esitelty uudelleen ilman linkitystä"
 
-#: cp/decl2.c:4326
+#: cp/decl2.c:4316
 #, gcc-internal-format
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr ""
 
-#: cp/decl2.c:4334
+#: cp/decl2.c:4324
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "%J%qF käytetty, mutta ei määritelty"
 
-#: cp/decl2.c:4338
+#: cp/decl2.c:4328
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4341
+#: cp/decl2.c:4331
 #, fuzzy, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "%J%qD esitelty uudelleen ilman linkitystä"
 
-#: cp/decl2.c:4529
+#: cp/decl2.c:4519
 #, fuzzy, gcc-internal-format
 msgid "mangling of %q#D as %qE conflicts with a previous mangle"
 msgstr "%q+D:n data-alue on ristiriidassa edellisen esittelyn kanssa"
 
-#: cp/decl2.c:4532
+#: cp/decl2.c:4522
 #, fuzzy, gcc-internal-format
 msgid "previous mangling %q#D"
 msgstr "edellinen esittely %q+D"
 
-#: cp/decl2.c:4534
+#: cp/decl2.c:4524
 #, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr ""
 
-#: cp/decl2.c:4606 cp/decl2.c:4609
+#: cp/decl2.c:4596 cp/decl2.c:4599
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.c:4956
+#: cp/decl2.c:4946
 #, fuzzy, gcc-internal-format
 msgid "inline function %qD used but never defined"
 msgstr "sisäkkäinen funktio %qs esitelty %<extern%>:ksi"
 
-#: cp/decl2.c:5143
+#: cp/decl2.c:5133
 #, fuzzy, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr "oletusargumentti annettu %2$q#D:n parametrille %1$d"
@@ -45567,17 +45611,17 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5251
+#: cp/decl2.c:5241
 #, fuzzy, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr "NULLin muunnos epäosoitintyypiksi"
 
-#: cp/decl2.c:5254
+#: cp/decl2.c:5244
 #, fuzzy, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "poistettu funktio %q+D"
 
-#: cp/decl2.c:5307
+#: cp/decl2.c:5297
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr ""
@@ -45864,338 +45908,338 @@
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr "%qs:n esittely taulukollisena tyhjiä alkioita"
 
-#: cp/init.c:613
+#: cp/init.c:629
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr ""
 
-#: cp/init.c:615
+#: cp/init.c:631
 #, fuzzy, gcc-internal-format
 #| msgid "union defined here"
 msgid "defined here"
 msgstr "union määritelty täällä"
 
-#: cp/init.c:673
+#: cp/init.c:689
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer for array member %q#D"
 msgid "initializer for flexible array member %q#D"
 msgstr "virheellinen alustin taulukon jäsenelle %q#D"
 
-#: cp/init.c:699
+#: cp/init.c:715
 #, gcc-internal-format
 msgid "%qD should be initialized in the member initialization list"
 msgstr "%qD tulee alustaa jäsenten alustuslistassa"
 
-#: cp/init.c:720
+#: cp/init.c:736
 #, fuzzy, gcc-internal-format
 msgid "%qD is initialized with itself"
 msgstr "parametri %qD on alustettu"
 
-#: cp/init.c:831
+#: cp/init.c:847
 #, gcc-internal-format
 msgid "invalid initializer for array member %q#D"
 msgstr "virheellinen alustin taulukon jäsenelle %q#D"
 
-#: cp/init.c:845 cp/init.c:869 cp/init.c:2410 cp/method.c:1368
+#: cp/init.c:861 cp/init.c:885 cp/init.c:2427 cp/method.c:1368
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr "alustamaton const-jäsen %qD"
 
-#: cp/init.c:847 cp/init.c:864 cp/init.c:871 cp/init.c:2395 cp/init.c:2423
+#: cp/init.c:863 cp/init.c:880 cp/init.c:887 cp/init.c:2412 cp/init.c:2440
 #: cp/method.c:1371 cp/method.c:1382
 #, fuzzy, gcc-internal-format
 msgid "%q#D should be initialized"
 msgstr "%q+D alustetaan jäljempänä kuin"
 
-#: cp/init.c:862 cp/init.c:2382 cp/method.c:1379
+#: cp/init.c:878 cp/init.c:2399 cp/method.c:1379
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr "jäsen %qD on alustamaton viittaus"
 
-#: cp/init.c:1041
+#: cp/init.c:1057
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D will be initialized after"
 msgid "%qD will be initialized after"
 msgstr "%q+D alustetaan jäljempänä kuin"
 
-#: cp/init.c:1044
+#: cp/init.c:1060
 #, fuzzy, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr "perustyypin %qT kaksoiskappale virheellinen"
 
-#: cp/init.c:1048
+#: cp/init.c:1064
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D"
 msgid "  %q#D"
 msgstr "  %q+#D"
 
-#: cp/init.c:1050
+#: cp/init.c:1066
 #, fuzzy, gcc-internal-format
 msgid "  base %qT"
 msgstr "perustyypin %qT kaksoiskappale virheellinen"
 
-#: cp/init.c:1052
+#: cp/init.c:1068
 #, gcc-internal-format
 msgid "  when initialized here"
 msgstr "  tässä alustuksessa"
 
-#: cp/init.c:1069
+#: cp/init.c:1085
 #, fuzzy, gcc-internal-format
 msgid "multiple initializations given for %qD"
 msgstr "useita parametreja nimellä %qD"
 
-#: cp/init.c:1073
+#: cp/init.c:1089
 #, fuzzy, gcc-internal-format
 msgid "multiple initializations given for base %qT"
 msgstr "(%qs:n alustuksen lähistöllä)"
 
-#: cp/init.c:1158
+#: cp/init.c:1174
 #, fuzzy, gcc-internal-format
 msgid "initializations for multiple members of %qT"
 msgstr "useita kenttiä unionissa %qT alustettu"
 
-#: cp/init.c:1255
+#: cp/init.c:1271
 #, gcc-internal-format
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr ""
 
-#: cp/init.c:1482 cp/init.c:1501
+#: cp/init.c:1498 cp/init.c:1517
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr "luokalla %qT ei ole %qD-nimistä kenttää"
 
-#: cp/init.c:1488
+#: cp/init.c:1504
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr ""
 
-#: cp/init.c:1495
+#: cp/init.c:1511
 #, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr ""
 
-#: cp/init.c:1534
+#: cp/init.c:1550
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr ""
 
-#: cp/init.c:1542
+#: cp/init.c:1558
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr ""
 
-#: cp/init.c:1589
+#: cp/init.c:1605
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr ""
 
-#: cp/init.c:1597
+#: cp/init.c:1613
 #, fuzzy, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr "perustyypin %qT kaksoiskappale virheellinen"
 
-#: cp/init.c:1600
+#: cp/init.c:1616
 #, fuzzy, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/init.c:1710 cp/init.c:4386 cp/typeck2.c:1175
+#: cp/init.c:1727 cp/init.c:4402 cp/typeck2.c:1175
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
 
-#: cp/init.c:2019 cp/semantics.c:3268
+#: cp/init.c:2036 cp/semantics.c:3271
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qT ei ole luokkatyyppi"
 
-#: cp/init.c:2075
+#: cp/init.c:2092
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr ""
 
-#: cp/init.c:2089
+#: cp/init.c:2106
 #, fuzzy, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr "bittikentän %qD osoitetta ei voi ottaa"
 
-#: cp/init.c:2175 cp/typeck.c:1893
+#: cp/init.c:2192 cp/typeck.c:1893
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "virheellinen ei-staattisen jäsenfunktion käyttö"
 
-#: cp/init.c:2182 cp/semantics.c:1835
+#: cp/init.c:2199 cp/semantics.c:1835
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "virheellinen ei-staattisen jäsenfunktion käyttö"
 
-#: cp/init.c:2379
+#: cp/init.c:2396
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr "alustamaton const-jäsen %qD"
 
-#: cp/init.c:2387
+#: cp/init.c:2404
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "alustamaton const-jäsen %qD"
 
-#: cp/init.c:2391
+#: cp/init.c:2408
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr "alustamaton const-jäsen %qD"
 
-#: cp/init.c:2407
+#: cp/init.c:2424
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2415
+#: cp/init.c:2432
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "alustamaton const-jäsen %qD"
 
-#: cp/init.c:2419
+#: cp/init.c:2436
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr "alustamaton const-jäsen %qD"
 
-#: cp/init.c:2710
+#: cp/init.c:2727
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2721
+#: cp/init.c:2738
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2732
+#: cp/init.c:2749
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2880
+#: cp/init.c:2896
 #, fuzzy, gcc-internal-format
 msgid "integer overflow in array size"
 msgstr "kokonaislukuylivuoto lausekkeessa"
 
-#: cp/init.c:2890
+#: cp/init.c:2906
 #, fuzzy, gcc-internal-format
 msgid "array size in new-expression must be constant"
 msgstr "taulukon koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/init.c:2904
+#: cp/init.c:2920
 #, fuzzy, gcc-internal-format
 msgid "variably modified type not allowed in new-expression"
 msgstr "muuttuja tai kenttä %qs esitelty tyhjäksi"
 
-#: cp/init.c:2920
+#: cp/init.c:2936
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by typedef"
 msgstr ""
 
-#: cp/init.c:2922
+#: cp/init.c:2938
 #, gcc-internal-format
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr ""
 
-#: cp/init.c:2932
+#: cp/init.c:2948
 #, fuzzy, gcc-internal-format
 msgid "invalid type %<void%> for new"
 msgstr "epäkelpo %qs:n soveltaminen tyhjään tyyppiin"
 
-#: cp/init.c:2975
+#: cp/init.c:2991
 #, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr ""
 
-#: cp/init.c:3101
+#: cp/init.c:3117
 #, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr ""
 
-#: cp/init.c:3108 cp/search.c:1023
+#: cp/init.c:3124 cp/search.c:1026
 #, fuzzy, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "%qD:n esittely ei-jäsenenä"
 
-#: cp/init.c:3181
+#: cp/init.c:3197
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr ""
 
-#: cp/init.c:3184
+#: cp/init.c:3200
 #, fuzzy, gcc-internal-format
 #| msgid "class %qT does not have any field named %qD"
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr "luokalla %qT ei ole %qD-nimistä kenttää"
 
-#: cp/init.c:3187
+#: cp/init.c:3203
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr ""
 
-#: cp/init.c:3370
+#: cp/init.c:3386
 #, fuzzy, gcc-internal-format
 msgid "parenthesized initializer in array new"
 msgstr "taulukkoindeksi ei-taulukkoalustimessa"
 
-#: cp/init.c:3633
+#: cp/init.c:3649
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr ""
 
-#: cp/init.c:3665
+#: cp/init.c:3681
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr ""
 
-#: cp/init.c:3674
+#: cp/init.c:3690
 #, fuzzy, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr "funktion paluuarvon tyyppi ei voi olla funktio"
 
-#: cp/init.c:3743
+#: cp/init.c:3759
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete [] operator:"
 msgstr ""
 
-#: cp/init.c:3747
+#: cp/init.c:3763
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete [] will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4295
+#: cp/init.c:4311
 #, fuzzy, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "muotoilu %s päättyy %%:iin"
 
-#: cp/init.c:4599
+#: cp/init.c:4615
 #, fuzzy, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr "taulukon %qE koko on negatiivinen"
 
-#: cp/init.c:4623
+#: cp/init.c:4639
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete operator:"
 msgstr ""
 
-#: cp/init.c:4628
+#: cp/init.c:4644
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4642
+#: cp/init.c:4658
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4647
+#: cp/init.c:4663
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4954
+#: cp/init.c:4970
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr ""
@@ -46678,7 +46722,7 @@
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "%qE-attribuutti pätee vain muuttujiin"
 
-#: cp/name-lookup.c:5111 cp/name-lookup.c:7065
+#: cp/name-lookup.c:5111 cp/name-lookup.c:7073
 #, fuzzy, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "%<fast_interrupt%>-attribuuttidirektiivi jätetty huomiotta"
@@ -46729,55 +46773,55 @@
 msgid "it was later defined here"
 msgstr "struct määritelty täällä"
 
-#: cp/name-lookup.c:6687
+#: cp/name-lookup.c:6695
 #, gcc-internal-format
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn't a template"
 msgstr ""
 
-#: cp/name-lookup.c:7059
+#: cp/name-lookup.c:7067
 #, fuzzy, gcc-internal-format
 #| msgid "switch %qs is no longer supported"
 msgid "strong using directive no longer supported"
 msgstr "valitsin %qs ei ole enää tuettu"
 
-#: cp/name-lookup.c:7062
+#: cp/name-lookup.c:7070
 #, gcc-internal-format
 msgid "you may use an inline namespace instead"
 msgstr ""
 
-#: cp/name-lookup.c:7079
+#: cp/name-lookup.c:7087
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on local using directive"
 msgstr "parametritaulukon esittelijän attribuutit jätetään huomiotta"
 
-#: cp/name-lookup.c:7163
+#: cp/name-lookup.c:7171
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr ""
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:7183
+#: cp/name-lookup.c:7191
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot nest more than %d namespaces"
 msgstr ""
 
-#: cp/name-lookup.c:7218
+#: cp/name-lookup.c:7226
 #, fuzzy, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr "%Jlohkoattribuuttia ei voi määrittää paikalliselle muuttujalle"
 
-#: cp/name-lookup.c:7219
+#: cp/name-lookup.c:7227
 #, fuzzy, gcc-internal-format
 #| msgid "label %qD defined here"
 msgid "%qD defined here"
 msgstr "nimiö %qD määritelty täällä"
 
-#: cp/name-lookup.c:7292
+#: cp/name-lookup.c:7300
 #, gcc-internal-format
 msgid "XXX entering pop_everything ()\n"
 msgstr ""
 
-#: cp/name-lookup.c:7301
+#: cp/name-lookup.c:7309
 #, gcc-internal-format
 msgid "XXX leaving pop_everything ()\n"
 msgstr ""
@@ -46797,7 +46841,7 @@
 msgid "LEXER_DEBUGGING_ENABLED_P is not set to true"
 msgstr ""
 
-#: cp/parser.c:1352 cp/parser.c:37254
+#: cp/parser.c:1352 cp/parser.c:37251
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -46822,7 +46866,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr "pyyntö jäsenen %qs käsittelyyn jossain, joka ei ole tietue tai unioni"
 
-#: cp/parser.c:2949 cp/parser.c:18221
+#: cp/parser.c:2949 cp/parser.c:18218
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "%<%T::%E%> on esittelemättä"
@@ -46902,7 +46946,7 @@
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "liukulukuylivuoto lausekkeessa"
 
-#: cp/parser.c:3143 cp/pt.c:17853
+#: cp/parser.c:3143 cp/pt.c:17890
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr ""
@@ -47126,7 +47170,7 @@
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr ""
 
-#: cp/parser.c:4587 cp/parser.c:12940
+#: cp/parser.c:4587 cp/parser.c:12937
 #, fuzzy, gcc-internal-format
 msgid "expected declaration"
 msgstr "odotettiin iteraatioesittelyä tai -alustusta"
@@ -47176,7 +47220,7 @@
 msgid "fold-expressions only available with -std=c++17 or -std=gnu++17"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:5275 cp/parser.c:5452 cp/parser.c:5630 cp/semantics.c:3612
+#: cp/parser.c:5275 cp/parser.c:5452 cp/parser.c:5633 cp/semantics.c:3615
 #, fuzzy, gcc-internal-format
 msgid "expected primary-expression"
 msgstr "odotettiin lauseketta"
@@ -47196,92 +47240,92 @@
 msgid "local variable %qD may not appear in this context"
 msgstr "paikallinen muuttuja %qD ei voi esiintyä tässä yhteydessä"
 
-#: cp/parser.c:5787
+#: cp/parser.c:5790
 #, fuzzy, gcc-internal-format
 msgid "expected id-expression"
 msgstr "odotettiin lauseketta"
 
-#: cp/parser.c:5919
+#: cp/parser.c:5922
 #, fuzzy, gcc-internal-format
 msgid "scope %qT before %<~%> is not a class-name"
 msgstr "%qT ei ole luokka tai nimiavaruus"
 
-#: cp/parser.c:5948 cp/parser.c:7860
+#: cp/parser.c:5951 cp/parser.c:7860
 #, fuzzy, gcc-internal-format
 msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:6059
+#: cp/parser.c:6062
 #, gcc-internal-format
 msgid "declaration of %<~%T%> as member of %qT"
 msgstr "%<~%T%>:n esittely %qT:n jäsenenä"
 
-#: cp/parser.c:6074
+#: cp/parser.c:6077
 #, gcc-internal-format
 msgid "typedef-name %qD used as destructor declarator"
 msgstr ""
 
-#: cp/parser.c:6111 cp/parser.c:20249
+#: cp/parser.c:6114 cp/parser.c:20246
 #, fuzzy, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr "ID"
 
-#: cp/parser.c:6220
+#: cp/parser.c:6223
 #, gcc-internal-format
 msgid "found %<:%> in nested-name-specifier, expected %<::%>"
 msgstr ""
 
-#: cp/parser.c:6288
+#: cp/parser.c:6291
 #, fuzzy, gcc-internal-format
 msgid "decltype evaluates to %qT, which is not a class or enumeration type"
 msgstr "%Jcase-arvo %qs ei ole luetellussa tyypissä"
 
-#: cp/parser.c:6314
+#: cp/parser.c:6317
 #, fuzzy, gcc-internal-format
 msgid "function template-id %qD in nested-name-specifier"
 msgstr "useita tallennuspaikkoja esittelymääritteissä"
 
-#: cp/parser.c:6322
+#: cp/parser.c:6325
 #, fuzzy, gcc-internal-format
 msgid "variable template-id %qD in nested-name-specifier"
 msgstr "useita tallennuspaikkoja esittelymääritteissä"
 
-#: cp/parser.c:6426 cp/typeck.c:2684 cp/typeck.c:2687 cp/typeck.c:2704
+#: cp/parser.c:6429 cp/typeck.c:2684 cp/typeck.c:2687 cp/typeck.c:2704
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD ei ole malli"
 
-#: cp/parser.c:6504
+#: cp/parser.c:6507
 #, fuzzy, gcc-internal-format
 msgid "expected nested-name-specifier"
 msgstr "Odotettiin käyttöoikeustarkennetta kohdassa %C"
 
-#: cp/parser.c:6711 cp/parser.c:8950
+#: cp/parser.c:6714 cp/parser.c:8950
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:6797
+#: cp/parser.c:6800
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a %<typeid%> expression"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:6889
+#: cp/parser.c:6892
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "väärä määrä argumentteja funktiolle %<__builtin_next_arg%>"
 
-#: cp/parser.c:6901 cp/pt.c:18416
+#: cp/parser.c:6904 cp/pt.c:18453
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "väärä määrä argumentteja funktiolle %<__builtin_next_arg%>"
 
-#: cp/parser.c:6995
+#: cp/parser.c:6998
 #, gcc-internal-format
 msgid "ISO C++ forbids compound-literals"
 msgstr "ISO C++ kieltää yhdysliteraalit"
 
-#: cp/parser.c:7054
+#: cp/parser.c:7057
 #, gcc-internal-format
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
@@ -47412,7 +47456,7 @@
 msgid "capture of non-variable %qE"
 msgstr "%qD ei ole muuttuja"
 
-#: cp/parser.c:10391 cp/parser.c:10401 cp/semantics.c:3453 cp/semantics.c:3465
+#: cp/parser.c:10391 cp/parser.c:10401 cp/semantics.c:3456 cp/semantics.c:3468
 #, fuzzy, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "%q+D esitelty täällä"
@@ -47498,7 +47542,7 @@
 msgid "init-statement in selection statements only available with -std=c++17 or -std=gnu++17"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:11546 cp/parser.c:28490
+#: cp/parser.c:11546 cp/parser.c:28487
 #, fuzzy, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "%s-lausetta odotettiin kohdassa %L"
@@ -47518,563 +47562,563 @@
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:12250 cp/parser.c:28493
+#: cp/parser.c:12250 cp/parser.c:28490
 #, fuzzy, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "odotettiin iteraatioesittelyä tai -alustusta"
 
-#: cp/parser.c:12298
+#: cp/parser.c:12297
 #, fuzzy, gcc-internal-format
 msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:12426
+#: cp/parser.c:12423
 #, fuzzy, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr "parametriksi ei voida esitellä %<constexpr%>:ksi"
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:12434
+#: cp/parser.c:12431
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ kieltää lasketut goto-käskyt"
 
-#: cp/parser.c:12447 cp/parser.c:28496
+#: cp/parser.c:12444 cp/parser.c:28493
 #, fuzzy, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "%s-lausetta odotettiin kohdassa %L"
 
-#: cp/parser.c:12620 cp/parser.c:23584
+#: cp/parser.c:12617 cp/parser.c:23581
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "ylimääräinen %<;%>"
 
-#: cp/parser.c:12863
+#: cp/parser.c:12860
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr "%<__label__%> ei ole lohkon alussa"
 
-#: cp/parser.c:13083
+#: cp/parser.c:13080
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:13103
+#: cp/parser.c:13100
 #, fuzzy, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr "odotettiin %qT, mutta argumentti on tyyppiä %qT"
 
-#: cp/parser.c:13124
+#: cp/parser.c:13121
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr ""
 
-#: cp/parser.c:13148
+#: cp/parser.c:13145
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:13203
+#: cp/parser.c:13200
 #, fuzzy, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr "tyhjä indeksiväli alustimessa"
 
-#: cp/parser.c:13206
+#: cp/parser.c:13203
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13257
+#: cp/parser.c:13254
 #, fuzzy, gcc-internal-format
 msgid "structured bindings only available with -std=c++17 or -std=gnu++17"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:13306
+#: cp/parser.c:13303
 #, fuzzy, gcc-internal-format
 msgid "empty structured binding declaration"
 msgstr "odotettiin iteraatioesittelyä tai -alustusta"
 
-#: cp/parser.c:13324
+#: cp/parser.c:13321
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for structured binding declaration"
 msgstr "puuttuva alustin jäsenelle %qD"
 
-#: cp/parser.c:13491
+#: cp/parser.c:13488
 #, fuzzy, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr "luokkamäärittelyä ei voi esitellä ystäväksi"
 
-#: cp/parser.c:13558
+#: cp/parser.c:13555
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr ""
 
-#: cp/parser.c:13594
+#: cp/parser.c:13591
 #, fuzzy, gcc-internal-format
 msgid "decl-specifier invalid in condition"
 msgstr "virheellinen muunnostarkennin jälkiliitteessä: %c"
 
-#: cp/parser.c:13600
+#: cp/parser.c:13597
 #, fuzzy, gcc-internal-format
 msgid "%qD invalid in lambda"
 msgstr "muuttujan %q+D koko muistissa ei ole tunnettu"
 
-#: cp/parser.c:13693
+#: cp/parser.c:13690
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "luokkamäärittelyä ei voi esitellä ystäväksi"
 
-#: cp/parser.c:13763 cp/parser.c:24064
+#: cp/parser.c:13760 cp/parser.c:24061
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr "mallit eivät voi olla virtuaalisia"
 
-#: cp/parser.c:13805
+#: cp/parser.c:13802
 #, fuzzy, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr "%s: virheellinen kenttämääritys %s"
 
-#: cp/parser.c:13909
+#: cp/parser.c:13906
 #, fuzzy, gcc-internal-format
 msgid "static_assert without a message only available with -std=c++17 or -std=gnu++17"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:14111
+#: cp/parser.c:14108
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:14264
+#: cp/parser.c:14261
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:14291
+#: cp/parser.c:14288
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "virheellinen %<auto%>:n käyttö muunnosoperaattorissa"
 
-#: cp/parser.c:14295
+#: cp/parser.c:14292
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr "epäkelpo %<restrict%>-avainsanan käyttö"
 
-#: cp/parser.c:14379
+#: cp/parser.c:14376
 #, fuzzy, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr "skalaarialustimen ympärillä on aaltosulkeet"
 
-#: cp/parser.c:14406
+#: cp/parser.c:14403
 #, fuzzy, gcc-internal-format
 #| msgid "cannot expand initializer for member %<%D%>"
 msgid "cannot expand initializer for member %qD"
 msgstr "ei voi laajentaa alustinta jäsenelle %<%D%>"
 
-#: cp/parser.c:14418 cp/pt.c:24255
+#: cp/parser.c:14415 cp/pt.c:24333
 #, fuzzy, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "%q+D esitelty staattisena, edellinen esittely ei-staattinen"
 
-#: cp/parser.c:14430 cp/pt.c:24267
+#: cp/parser.c:14427 cp/pt.c:24345
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
 
-#: cp/parser.c:14482
+#: cp/parser.c:14479
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr ""
 
-#: cp/parser.c:14552
+#: cp/parser.c:14549
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:14927
+#: cp/parser.c:14924
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr ""
 
-#: cp/parser.c:14933
+#: cp/parser.c:14930
 #, fuzzy, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr "odotettiin tunnistetta tai %<(%>"
 
-#: cp/parser.c:14942
+#: cp/parser.c:14939
 #, fuzzy, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr "leveä merkkijonovakio %<asm%>-lauseessa"
 
-#: cp/parser.c:14948
+#: cp/parser.c:14945
 #, fuzzy, gcc-internal-format
 msgid "invalid encoding prefix in literal operator"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: cp/parser.c:14975
+#: cp/parser.c:14972
 #, fuzzy, gcc-internal-format
 msgid "expected operator"
 msgstr "odotettiin %<operator%>"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:15020
+#: cp/parser.c:15017
 #, fuzzy, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "Avainsana %s on tuntematon tai sillä ei vielä ole toteutusta"
 
-#: cp/parser.c:15190
+#: cp/parser.c:15187
 #, fuzzy, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr "virheellinen parametrityyppi %qT"
 
-#: cp/parser.c:15198
+#: cp/parser.c:15195
 #, fuzzy, gcc-internal-format
 msgid "cv-qualified type parameter"
 msgstr "hajottimet eivät voi olla cv-määriteltyjä"
 
-#: cp/parser.c:15283
+#: cp/parser.c:15280
 #, fuzzy, gcc-internal-format
 msgid "variadic constraint introduced without %<...%>"
 msgstr "anonyymit variadiset makrot esiteltiin C99:ssä"
 
-#: cp/parser.c:15347
+#: cp/parser.c:15344
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "mallinimen %qE virheellinen käyttö ilman argumenttiluetteloa"
 
-#: cp/parser.c:15582 cp/parser.c:15668 cp/parser.c:21694
+#: cp/parser.c:15579 cp/parser.c:15665 cp/parser.c:21691
 #, fuzzy, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "strftime-muotoilut eivät voi muotoilla argumentteja"
 
-#: cp/parser.c:15586 cp/parser.c:15672
+#: cp/parser.c:15583 cp/parser.c:15669
 #, fuzzy, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr "strftime-muotoilut eivät voi muotoilla argumentteja"
 
-#: cp/parser.c:15738
+#: cp/parser.c:15735
 #, fuzzy, gcc-internal-format
 msgid "expected template-id"
 msgstr "odotettiin %<template%>"
 
-#: cp/parser.c:15798
+#: cp/parser.c:15795
 #, fuzzy, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "jäsennysvirhe malliargumenttien luettelossa"
 
-#: cp/parser.c:15802
+#: cp/parser.c:15799
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr ""
 
-#: cp/parser.c:15806
+#: cp/parser.c:15803
 #, fuzzy, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr "(G++ hyväksyy koodin -fpermissive-valitsimella)"
 
-#: cp/parser.c:15924
+#: cp/parser.c:15921
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "jäsennysvirhe malliargumenttien luettelossa"
 
 #. The name does not name a template.
-#: cp/parser.c:15992 cp/parser.c:16122 cp/parser.c:16337
+#: cp/parser.c:15989 cp/parser.c:16119 cp/parser.c:16334
 #, fuzzy, gcc-internal-format
 msgid "expected template-name"
 msgstr "odotettiin %<template%>"
 
 #. Explain what went wrong.
-#: cp/parser.c:16038
+#: cp/parser.c:16035
 #, fuzzy, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr "%qD ei ole mallifunktio"
 
-#: cp/parser.c:16040
+#: cp/parser.c:16037
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr ""
 
-#: cp/parser.c:16189
+#: cp/parser.c:16186
 #, fuzzy, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr "ENUM-määrittelylause odotettiin ennen kohdetta %C"
 
-#: cp/parser.c:16298 cp/parser.c:16316 cp/parser.c:16483
+#: cp/parser.c:16295 cp/parser.c:16313 cp/parser.c:16480
 #, fuzzy, gcc-internal-format
 msgid "expected template-argument"
 msgstr "odotettiin %<template%>"
 
-#: cp/parser.c:16458
+#: cp/parser.c:16455
 #, fuzzy, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr "%qD:n malliargumentti käyttää paikallista tyyppiä %qT"
 
-#: cp/parser.c:16585
+#: cp/parser.c:16582
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr ""
 
-#: cp/parser.c:16589
+#: cp/parser.c:16586
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr ""
 
-#: cp/parser.c:16648
+#: cp/parser.c:16645
 #, fuzzy, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr "malli C-linkityksellä"
 
-#: cp/parser.c:16869
+#: cp/parser.c:16866
 #, fuzzy, gcc-internal-format
 msgid "expected type specifier"
 msgstr "Odotettiin käyttöoikeustarkennetta kohdassa %C"
 
-#: cp/parser.c:17053
+#: cp/parser.c:17050
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:17059
+#: cp/parser.c:17056
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:17064
+#: cp/parser.c:17061
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -fconcepts"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:17209
+#: cp/parser.c:17206
 #, fuzzy, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "odotettiin %<template%>"
 
-#: cp/parser.c:17278
+#: cp/parser.c:17275
 #, fuzzy, gcc-internal-format
 msgid "expected type-name"
 msgstr "Odotettu nimi"
 
-#: cp/parser.c:17631
+#: cp/parser.c:17628
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr ""
 
-#: cp/parser.c:17854
+#: cp/parser.c:17851
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "esittely %qD ei esittele mitään"
 
-#: cp/parser.c:17942
+#: cp/parser.c:17939
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "parametritaulukon esittelijän attribuutit jätetään huomiotta"
 
-#: cp/parser.c:17946
+#: cp/parser.c:17943
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "parametritaulukon esittelijän attribuutit jätetään huomiotta"
 
-#: cp/parser.c:17951
+#: cp/parser.c:17948
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr ""
 
-#: cp/parser.c:18085
+#: cp/parser.c:18082
 #, fuzzy, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "%qD ei ole malli"
 
-#: cp/parser.c:18096
+#: cp/parser.c:18093
 #, fuzzy, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/parser.c:18111
+#: cp/parser.c:18108
 #, fuzzy, gcc-internal-format
 #| msgid "%<namespace%> definition is not allowed here"
 msgid "unnamed scoped enum is not allowed"
 msgstr "%<namespace%>-määrittely ei ole sallittu täällä"
 
-#: cp/parser.c:18166
+#: cp/parser.c:18163
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: cp/parser.c:18215
+#: cp/parser.c:18212
 #, fuzzy, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "%qs-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: cp/parser.c:18229
+#: cp/parser.c:18226
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration does not name a class or function"
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "ystäväesittely ei nimeä luokkaa tai funktiota"
 
-#: cp/parser.c:18241 cp/parser.c:23070
+#: cp/parser.c:18238 cp/parser.c:23067
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "%J%qD:n edellinen esittely oli täällä"
 
-#: cp/parser.c:18246 cp/parser.c:23075
+#: cp/parser.c:18243 cp/parser.c:23072
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "esittely %qD ei esittele mitään"
 
-#: cp/parser.c:18258 cp/parser.c:23089
+#: cp/parser.c:18255 cp/parser.c:23086
 #, fuzzy, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr "ylimääräinen %<;%>"
 
-#: cp/parser.c:18282
+#: cp/parser.c:18279
 #, fuzzy, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "edellinen %q+#T:n määrittely"
 
-#: cp/parser.c:18295
+#: cp/parser.c:18292
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids incrementing an enum"
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO C++ kieltää enumin lisäyksen"
 
-#: cp/parser.c:18315
+#: cp/parser.c:18312
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:18318
+#: cp/parser.c:18315
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:18497
+#: cp/parser.c:18494
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD ei ole nimiavaruuden nimi"
 
-#: cp/parser.c:18503
+#: cp/parser.c:18500
 #, fuzzy, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "odotettiin %<namespace%>"
 
-#: cp/parser.c:18570
+#: cp/parser.c:18567
 #, fuzzy, gcc-internal-format
 msgid "nested namespace definitions only available with -std=c++17 or -std=gnu++17"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:18578
+#: cp/parser.c:18575
 #, fuzzy, gcc-internal-format
 msgid "nested namespace name required"
 msgstr "odotettiin %<namespace%>"
 
-#: cp/parser.c:18583
+#: cp/parser.c:18580
 #, fuzzy, gcc-internal-format
 msgid "namespace name required"
 msgstr "%qD on nimiavaruus"
 
-#: cp/parser.c:18587
+#: cp/parser.c:18584
 #, fuzzy, gcc-internal-format
 #| msgid "%<namespace%> definition is not allowed here"
 msgid "a nested namespace definition cannot have attributes"
 msgstr "%<namespace%>-määrittely ei ole sallittu täällä"
 
-#: cp/parser.c:18590
+#: cp/parser.c:18587
 #, fuzzy, gcc-internal-format
 #| msgid "%<namespace%> definition is not allowed here"
 msgid "a nested namespace definition cannot be inline"
 msgstr "%<namespace%>-määrittely ei ole sallittu täällä"
 
-#: cp/parser.c:18597
+#: cp/parser.c:18594
 #, fuzzy, gcc-internal-format
 msgid "namespace %qD entered"
 msgstr "%qD on nimiavaruus"
 
-#: cp/parser.c:18652
+#: cp/parser.c:18649
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "%<namespace%>-määrittely ei ole sallittu täällä"
 
-#: cp/parser.c:18803
+#: cp/parser.c:18800
 #, fuzzy, gcc-internal-format
 msgid "pack expansion in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:18818
+#: cp/parser.c:18815
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr ""
 
-#: cp/parser.c:18865
+#: cp/parser.c:18862
 #, fuzzy, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:18875
+#: cp/parser.c:18872
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:18940
+#: cp/parser.c:18937
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:19106
+#: cp/parser.c:19103
 #, fuzzy, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr "parametriksi ei voida esitellä %<constexpr%>:ksi"
 
-#: cp/parser.c:19493
+#: cp/parser.c:19490
 #, fuzzy, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "%<namespace%>-määrittely ei ole sallittu täällä"
 
-#: cp/parser.c:19504
+#: cp/parser.c:19501
 #, fuzzy, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr "%Jvanhanmallinen funktiomäärittely"
 
-#: cp/parser.c:19508
+#: cp/parser.c:19505
 #, fuzzy, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "Ristiriita funktioargumentin attribuuteissa kohdassa %C"
 
-#: cp/parser.c:19559
+#: cp/parser.c:19556
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
 #. Anything else is an error.
-#: cp/parser.c:19598 cp/parser.c:21906
+#: cp/parser.c:19595 cp/parser.c:21903
 #, fuzzy, gcc-internal-format
 msgid "expected initializer"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: cp/parser.c:19679
+#: cp/parser.c:19676
 #, fuzzy, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "epäkelpo alustin"
 
-#: cp/parser.c:19713
+#: cp/parser.c:19710
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr ""
 
-#: cp/parser.c:19727
+#: cp/parser.c:19724
 #, fuzzy, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr "%Jsisäänrakennettu funktio %qD esitelty ei-funktiona"
 
-#: cp/parser.c:20169
+#: cp/parser.c:20166
 #, fuzzy, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "taulukkoindeksi alustimessa ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/parser.c:20295
+#: cp/parser.c:20292
 #, fuzzy, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr "parametrilla %P on vaillinainen tyyppi %qT"
 
-#: cp/parser.c:20299
+#: cp/parser.c:20296
 #, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "%<%T::%E%> ei ole tyyppi"
@@ -48083,17 +48127,17 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:20328
+#: cp/parser.c:20325
 #, fuzzy, gcc-internal-format
 msgid "invalid declarator"
 msgstr "Varoita implisiittisistä funktioesittelyistä"
 
-#: cp/parser.c:20336
+#: cp/parser.c:20333
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "muodostimen virheellinen käyttö mallina"
 
-#: cp/parser.c:20338
+#: cp/parser.c:20335
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr ""
@@ -48100,388 +48144,388 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:20410
+#: cp/parser.c:20407
 #, fuzzy, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr "id="
 
-#: cp/parser.c:20435
+#: cp/parser.c:20432
 #, fuzzy, gcc-internal-format
 msgid "expected declarator"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: cp/parser.c:20554
+#: cp/parser.c:20551
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD on nimiavaruus"
 
-#: cp/parser.c:20556
+#: cp/parser.c:20553
 #, fuzzy, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "parametrilla %P on vaillinainen tyyppi %qT"
 
-#: cp/parser.c:20577
+#: cp/parser.c:20574
 #, fuzzy, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "odotettiin %<operator%>"
 
-#: cp/parser.c:20638
+#: cp/parser.c:20635
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "cv-määreen kaksoiskappale"
 
-#: cp/parser.c:20692
+#: cp/parser.c:20689
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate cv-qualifier"
 msgid "multiple ref-qualifiers"
 msgstr "ristiriitaiset tyyppimääreet %q+D:lle"
 
-#: cp/parser.c:20729
+#: cp/parser.c:20726
 #, fuzzy, gcc-internal-format
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr "-m64 vaatii PowerPC64-suorittimen"
 
-#: cp/parser.c:20787
+#: cp/parser.c:20784
 #, fuzzy, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "Kaksoiskappale pääsy-tarkenne kohdassa %C"
 
-#: cp/parser.c:21025
+#: cp/parser.c:21022
 #, fuzzy, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/parser.c:21031 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2090
+#: cp/parser.c:21028 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2093
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr "virheellinen parametrityyppi %qT"
 
-#: cp/parser.c:21052
+#: cp/parser.c:21049
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:21057
+#: cp/parser.c:21054
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "virheellinen %<auto%>:n käyttö muunnosoperaattorissa"
 
-#: cp/parser.c:21145
+#: cp/parser.c:21142
 #, fuzzy, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "Odotettiin käyttöoikeustarkennetta kohdassa %C"
 
-#: cp/parser.c:21429
+#: cp/parser.c:21426
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "odotettiin %<,%> tai %<...%>"
 
-#: cp/parser.c:21504
+#: cp/parser.c:21501
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:21678
+#: cp/parser.c:21675
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr ""
 
-#: cp/parser.c:21696
+#: cp/parser.c:21693
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "%<operator new%>:n ensimmäisellä parametrilla ei voi olla oletusargumenttia"
 
-#: cp/parser.c:21702
+#: cp/parser.c:21699
 #, fuzzy, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr "%<operator new%>:n ensimmäisellä parametrilla ei voi olla oletusargumenttia"
 
-#: cp/parser.c:21704
+#: cp/parser.c:21701
 #, fuzzy, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr "%<operator new%>:n ensimmäisellä parametrilla ei voi olla oletusargumenttia"
 
-#: cp/parser.c:22131
+#: cp/parser.c:22128
 #, fuzzy, gcc-internal-format
 msgid "C++ designated initializers only available with -std=c++2a or -std=gnu++2a"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:22151
+#: cp/parser.c:22148
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr "ISO C ei salli ylimääräisiä %<;%>-merkkejä funktion ulkopuolella"
 
-#: cp/parser.c:22189
+#: cp/parser.c:22186
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C90 ei tue joustavia taulukkojäseniä"
 
-#: cp/parser.c:22203
+#: cp/parser.c:22200
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr ""
 
-#: cp/parser.c:22228
+#: cp/parser.c:22225
 #, fuzzy, gcc-internal-format
 msgid "%<...%> not allowed in designated initializer list"
 msgstr "ISO C ei salli ylimääräisiä %<;%>-merkkejä funktion ulkopuolella"
 
-#: cp/parser.c:22266
+#: cp/parser.c:22263
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr ""
 
-#: cp/parser.c:22322 cp/parser.c:22448
+#: cp/parser.c:22319 cp/parser.c:22445
 #, fuzzy, gcc-internal-format
 msgid "expected class-name"
 msgstr "odotettiin luokan nimeä"
 
-#: cp/parser.c:22650
+#: cp/parser.c:22647
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "Odotettiin :: TYPE-määrittelyssä kohdassa %C"
 
-#: cp/parser.c:22653
+#: cp/parser.c:22650
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "Odotettiin :: TYPE-määrittelyssä kohdassa %C"
 
-#: cp/parser.c:22656
+#: cp/parser.c:22653
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "Odotettiin :: TYPE-määrittelyssä kohdassa %C"
 
-#: cp/parser.c:23012
+#: cp/parser.c:23009
 #, fuzzy, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: cp/parser.c:23023
+#: cp/parser.c:23020
 #, fuzzy, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "ei löydetä luokkaa %qE"
 
-#: cp/parser.c:23031
+#: cp/parser.c:23028
 #, fuzzy, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr "virheellinen luokan nimi %qD:n esittelyssä"
 
-#: cp/parser.c:23038
+#: cp/parser.c:23035
 #, fuzzy, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "ystäväesittely ei nimeä luokkaa tai funktiota"
 
-#: cp/parser.c:23050
+#: cp/parser.c:23047
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr ""
 
-#: cp/parser.c:23056
+#: cp/parser.c:23053
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "virheellinen luokan nimi %qD:n esittelyssä"
 
-#: cp/parser.c:23114
+#: cp/parser.c:23111
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr ""
 
-#: cp/parser.c:23146
+#: cp/parser.c:23143
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "funktiomalli %qD esitelty uudelleen luokkamallina"
 
-#: cp/parser.c:23182
+#: cp/parser.c:23179
 #, fuzzy, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr "%s: ei voida avata PCH-tiedostoa: %m\n"
 
-#: cp/parser.c:23241
+#: cp/parser.c:23238
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+#T"
 msgid "previous definition of %q#T"
 msgstr "edellinen %q+#T:n määrittely"
 
-#: cp/parser.c:23331 cp/parser.c:28499
+#: cp/parser.c:23328 cp/parser.c:28496
 #, fuzzy, gcc-internal-format
 msgid "expected class-key"
 msgstr "odotettiin %<class%>"
 
-#: cp/parser.c:23355
+#: cp/parser.c:23352
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:23359
+#: cp/parser.c:23356
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "tallennusluokka annettu typenamelle"
 
-#: cp/parser.c:23605
+#: cp/parser.c:23602
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr ""
 
-#: cp/parser.c:23623
+#: cp/parser.c:23620
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "ystäväesittely ei nimeä luokkaa tai funktiota"
 
-#: cp/parser.c:23641
+#: cp/parser.c:23638
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:23738
+#: cp/parser.c:23735
 #, fuzzy, gcc-internal-format
 msgid "default member initializers for bit-fields only available with -std=c++2a or -std=gnu++2a"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:23745
+#: cp/parser.c:23742
 #, fuzzy, gcc-internal-format
 msgid "default member initializer for unnamed bit-field"
 msgstr "tallennusluokka annettu parametrille %qs"
 
-#: cp/parser.c:23758
+#: cp/parser.c:23755
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr ""
 
-#: cp/parser.c:23903
+#: cp/parser.c:23900
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr "pure-tarkenne funktiomäärittelyssä"
 
-#: cp/parser.c:23923
+#: cp/parser.c:23920
 #, fuzzy, gcc-internal-format
 msgid "extra %<;%> after in-class function definition"
 msgstr "Odotettiin :: TYPE-määrittelyssä kohdassa %C"
 
-#: cp/parser.c:23970
+#: cp/parser.c:23967
 #, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr "ylimääräinen %<,%> jäsenesittelyn lopussa"
 
-#: cp/parser.c:23984
+#: cp/parser.c:23981
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "ylimääräinen %<,%> jäsenesittelyn lopussa"
 
-#: cp/parser.c:24058
+#: cp/parser.c:24055
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr ""
 
-#: cp/parser.c:24093
+#: cp/parser.c:24090
 #, fuzzy, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "skalaarialustimen ympärillä on aaltosulkeet"
 
-#: cp/parser.c:24223
+#: cp/parser.c:24220
 #, fuzzy, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr "varoitus: lähdetiedosto %s annettu useammin kuin kerran"
 
-#: cp/parser.c:24243
+#: cp/parser.c:24240
 #, fuzzy, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr "varoitus: lähdetiedosto %s annettu useammin kuin kerran"
 
-#: cp/parser.c:24267
+#: cp/parser.c:24264
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr ""
 
-#: cp/parser.c:24270
+#: cp/parser.c:24267
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:24364 cp/parser.c:24442
+#: cp/parser.c:24361 cp/parser.c:24439
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:24450
+#: cp/parser.c:24447
 #, fuzzy, gcc-internal-format
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: cp/parser.c:24456
+#: cp/parser.c:24453
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr ""
 
-#: cp/parser.c:24500
+#: cp/parser.c:24497
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%> in conversion operator"
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "virheellinen %<auto%>:n käyttö muunnosoperaattorissa"
 
-#: cp/parser.c:24539
+#: cp/parser.c:24536
 #, fuzzy, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr "hajotin ei voi olla %<constexpr%>"
 
-#: cp/parser.c:24650
+#: cp/parser.c:24647
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:25203
+#: cp/parser.c:25200
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr "%qE-attribuutti on ristiriidassa attribuutin %s kanssa"
 
-#: cp/parser.c:25217
+#: cp/parser.c:25214
 #, fuzzy, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr "vakio tai tunniste odotettu"
 
-#: cp/parser.c:25301
+#: cp/parser.c:25298
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr "%qE-attribuutti on ristiriidassa attribuutin %s kanssa"
 
-#: cp/parser.c:25305
+#: cp/parser.c:25302
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr "%qE-attribuutti on ristiriidassa attribuutin %s kanssa"
 
-#: cp/parser.c:25342
+#: cp/parser.c:25339
 #, fuzzy, gcc-internal-format
 msgid "expected attribute before %<...%>"
 msgstr "ENUM-määrittelylause odotettiin ennen kohdetta %C"
 
-#: cp/parser.c:25403
+#: cp/parser.c:25400
 #, fuzzy, gcc-internal-format
 msgid "attribute using prefix only available with -std=c++17 or -std=gnu++17"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:25721
+#: cp/parser.c:25718
 #, fuzzy, gcc-internal-format
 msgid "%<requires%> only available with -fconcepts"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:25753
+#: cp/parser.c:25750
 #, fuzzy, gcc-internal-format
 msgid "a requires expression cannot appear outside a template"
 msgstr "taulukon koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/parser.c:26467
+#: cp/parser.c:26464
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:26472
+#: cp/parser.c:26469
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "virheellinen %<%T::%E%>:n esittely"
 
-#: cp/parser.c:26476
+#: cp/parser.c:26473
 #, fuzzy, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "%J%qD:n edellinen esittely oli täällä"
@@ -48490,414 +48534,414 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:26483
+#: cp/parser.c:26480
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr ""
 
-#: cp/parser.c:26832
+#: cp/parser.c:26829
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "nimetyt paluuarvot eivät ole enää tuettuja"
 
-#: cp/parser.c:26991
+#: cp/parser.c:26988
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr ""
 
-#: cp/parser.c:26996
+#: cp/parser.c:26993
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr ""
 
-#: cp/parser.c:27066
+#: cp/parser.c:27063
 #, fuzzy, gcc-internal-format
 #| msgid "Enable multiply instructions"
 msgid "empty introduction-list"
 msgstr "[Tyhjä]"
 
-#: cp/parser.c:27090
+#: cp/parser.c:27087
 #, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr ""
 
-#: cp/parser.c:27112
+#: cp/parser.c:27109
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr ""
 
-#: cp/parser.c:27121
+#: cp/parser.c:27118
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "malli C-linkityksellä"
 
-#: cp/parser.c:27141
+#: cp/parser.c:27138
 #, fuzzy, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "    Ei ilmaistuja epäjäseniä\n"
 
-#: cp/parser.c:27245
+#: cp/parser.c:27242
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "malliesittelylle %q+D"
 
-#: cp/parser.c:27296
+#: cp/parser.c:27293
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "a class template declaration must not declare anything else"
 msgstr "esittely ei esittele mitään"
 
-#: cp/parser.c:27342
+#: cp/parser.c:27339
 #, fuzzy, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: cp/parser.c:27650
+#: cp/parser.c:27647
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr ""
 
-#: cp/parser.c:27663
+#: cp/parser.c:27660
 #, fuzzy, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "mallinimen %qE virheellinen käyttö ilman argumenttiluetteloa"
 
-#: cp/parser.c:27958
+#: cp/parser.c:27955
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:28118
+#: cp/parser.c:28115
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "virheellinen hajottimen %qD käyttö tyyppinä"
 
-#: cp/parser.c:28133
+#: cp/parser.c:28130
 #, fuzzy, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "käytetty %<__thread%> ennen %<extern%>:a"
 
-#: cp/parser.c:28267
+#: cp/parser.c:28264
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ 1998 ei tue %<long long%> -tyyppiä"
 
-#: cp/parser.c:28275
+#: cp/parser.c:28272
 #, fuzzy, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "sekä %<_Sat%> että %<char%> esittelymääritteissä"
 
-#: cp/parser.c:28280
+#: cp/parser.c:28277
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "ylimääräinen %<const%>"
 
-#: cp/parser.c:28304
+#: cp/parser.c:28301
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "kaksois-%qs"
 
-#: cp/parser.c:28356
+#: cp/parser.c:28353
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "odotettiin %<new%>"
 
-#: cp/parser.c:28359
+#: cp/parser.c:28356
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "odotettiin %<delete%>"
 
-#: cp/parser.c:28362
+#: cp/parser.c:28359
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "odotettiin %<return%>"
 
-#: cp/parser.c:28368
+#: cp/parser.c:28365
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "odotettiin %<extern%>"
 
-#: cp/parser.c:28371
+#: cp/parser.c:28368
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "odotettiin %<static_assert%>"
 
-#: cp/parser.c:28374
+#: cp/parser.c:28371
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "odotettiin %<decltype%>"
 
-#: cp/parser.c:28377
+#: cp/parser.c:28374
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "odotettiin %<operator%>"
 
-#: cp/parser.c:28380
+#: cp/parser.c:28377
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "odotettiin %<class%>"
 
-#: cp/parser.c:28383
+#: cp/parser.c:28380
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "odotettiin %<template%>"
 
-#: cp/parser.c:28386
+#: cp/parser.c:28383
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "odotettiin %<namespace%>"
 
 # XXXXXXX
-#: cp/parser.c:28389
+#: cp/parser.c:28386
 #, fuzzy, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: cp/parser.c:28392
+#: cp/parser.c:28389
 #, fuzzy, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "odotettiin %<=%>, %<,%>, %<;%>, %<asm%> tai %<__attribute__%>"
 
-#: cp/parser.c:28395
+#: cp/parser.c:28392
 #, fuzzy, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "”)” oli odotus"
 
-#: cp/parser.c:28398
+#: cp/parser.c:28395
 #, fuzzy, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "  siirtyy catch-lohkoon"
 
-#: cp/parser.c:28401
+#: cp/parser.c:28398
 #, fuzzy, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "<throw-lauseke>"
 
-#: cp/parser.c:28404
+#: cp/parser.c:28401
 #, fuzzy, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "nimiö "
 
-#: cp/parser.c:28407
+#: cp/parser.c:28404
 #, fuzzy, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: cp/parser.c:28410
+#: cp/parser.c:28407
 #, fuzzy, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "Taso 2 ei ole synkronoitu"
 
-#: cp/parser.c:28413
+#: cp/parser.c:28410
 #, fuzzy, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "<throw-lauseke>"
 
-#: cp/parser.c:28416
+#: cp/parser.c:28413
 #, fuzzy, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: cp/parser.c:28419
+#: cp/parser.c:28416
 #, fuzzy, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: cp/parser.c:28451
+#: cp/parser.c:28448
 #, fuzzy, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "”)” oli odotus"
 
-#: cp/parser.c:28463
+#: cp/parser.c:28460
 #, fuzzy, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "”)” oli odotus"
 
-#: cp/parser.c:28466
+#: cp/parser.c:28463
 #, fuzzy, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "”)” oli odotus"
 
-#: cp/parser.c:28469
+#: cp/parser.c:28466
 #, fuzzy, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "”)” oli odotus"
 
-#: cp/parser.c:28475
+#: cp/parser.c:28472
 #, fuzzy, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "odotettiin %<:%> tai %<...%>"
 
-#: cp/parser.c:28502
+#: cp/parser.c:28499
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "  odotettiin luokkamallia, saatiin %qT"
 
-#: cp/parser.c:28772
+#: cp/parser.c:28769
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr ""
 
-#: cp/parser.c:28777
+#: cp/parser.c:28774
 #, fuzzy, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "%q+#D aiemmin esitelty täällä"
 
-#: cp/parser.c:28798
+#: cp/parser.c:28795
 #, fuzzy, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD esitelty uudelleen eri näkyvyydellä"
 
-#: cp/parser.c:28819
+#: cp/parser.c:28816
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr ""
 
 # XXX
-#: cp/parser.c:29062
+#: cp/parser.c:29059
 #, fuzzy, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "oletusargumentti määritelty lambda-parametrille"
 
-#: cp/parser.c:29303 cp/parser.c:30620 cp/parser.c:30808
+#: cp/parser.c:29300 cp/parser.c:30617 cp/parser.c:30805
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr ""
 
-#: cp/parser.c:29372
+#: cp/parser.c:29369
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr "useita tallennuspaikkoja esittelymääritteissä"
 
-#: cp/parser.c:29442
+#: cp/parser.c:29439
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:29473
+#: cp/parser.c:29470
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr ""
 
-#: cp/parser.c:29883
+#: cp/parser.c:29880
 #, fuzzy, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "%qE ei ole Objective-C-luokkanimi eikä -alias"
 
-#: cp/parser.c:29958 cp/parser.c:29976
+#: cp/parser.c:29955 cp/parser.c:29973
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr "Odotettiin toista ulottuvuutta taulukkoesittelyssä kohdassa %C"
 
-#: cp/parser.c:29970 cp/parser.c:30035
+#: cp/parser.c:29967 cp/parser.c:30032
 #, fuzzy, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "%Jlohkoattribuuttia ei voi määrittää paikalliselle muuttujalle"
 
-#: cp/parser.c:30078
+#: cp/parser.c:30075
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:30284 cp/parser.c:30291 cp/parser.c:30298
+#: cp/parser.c:30281 cp/parser.c:30288 cp/parser.c:30295
 #, fuzzy, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "virheellinen tyyppi iterointimuuttujalle %qE"
 
-#: cp/parser.c:30413
+#: cp/parser.c:30410
 #, fuzzy, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "odotettiin tunnistetta tai %<(%>"
 
-#: cp/parser.c:30585
+#: cp/parser.c:30582
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:30592
+#: cp/parser.c:30589
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "%qs-attribuuttia ei huomioida %qs:lle"
 
-#: cp/parser.c:30867 cp/parser.c:30874 cp/parser.c:30881
+#: cp/parser.c:30864 cp/parser.c:30871 cp/parser.c:30878
 #, fuzzy, gcc-internal-format
 msgid "invalid type for property"
 msgstr "virheellinen vastaanottajatyyppi %qs"
 
-#: cp/parser.c:32011
+#: cp/parser.c:32008
 #, fuzzy, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/parser.c:32724
+#: cp/parser.c:32721
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid reduction-identifier"
 msgstr "odotettiin tunnistetta tai %<(%>"
 
-#: cp/parser.c:34911
+#: cp/parser.c:34908
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:35231 cp/pt.c:16392
+#: cp/parser.c:35228 cp/pt.c:16414
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "sisäkkäisessä funktiossa käytetty rekisterimuuttujaa %qD"
 
-#: cp/parser.c:35316
+#: cp/parser.c:35313
 #, fuzzy, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr "mahdollisia ikisilmukoita ei voi optimoida"
 
-#: cp/parser.c:37521
+#: cp/parser.c:37518
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer clause"
 msgstr "epäkelpo alustin"
 
-#: cp/parser.c:37549
+#: cp/parser.c:37546
 #, fuzzy, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "odotettiin kokonaislukulauseketta"
 
-#: cp/parser.c:37561
+#: cp/parser.c:37558
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:37662
+#: cp/parser.c:37659
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in declare reduction type list"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:37682 cp/semantics.c:5405
+#: cp/parser.c:37679 cp/semantics.c:5408
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37687 cp/semantics.c:5414
+#: cp/parser.c:37684 cp/semantics.c:5417
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37690 cp/pt.c:12944 cp/semantics.c:5420
+#: cp/parser.c:37687 cp/pt.c:12966 cp/semantics.c:5423
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37693 cp/semantics.c:5426
+#: cp/parser.c:37690 cp/semantics.c:5429
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:38047
+#: cp/parser.c:38044
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:38057
+#: cp/parser.c:38054
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%qD does not refer to a namespace scope function"
@@ -48904,50 +48948,50 @@
 msgstr "#pragma GCC optimize ei ole sallittu funktioiden sisällä"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:38392
+#: cp/parser.c:38389
 #, fuzzy, gcc-internal-format
 msgid "atomic_cancel"
 msgstr "_Peru"
 
-#: cp/parser.c:38435 cp/semantics.c:8575
+#: cp/parser.c:38432 cp/semantics.c:8578
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:38437 cp/semantics.c:8577
+#: cp/parser.c:38434 cp/semantics.c:8580
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:38631
+#: cp/parser.c:38628
 #, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "roskaa ilmaisun %<#pragma GCC pch_preprocess%> lopussa"
 
-#: cp/parser.c:38927
+#: cp/parser.c:38924
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "#pragma GCC optimize ei ole sallittu funktioiden sisällä"
 
-#: cp/parser.c:38959
+#: cp/parser.c:38956
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr "#pragma GCC optimize ei ole sallittu funktioiden sisällä"
 
-#: cp/parser.c:39039
+#: cp/parser.c:39036
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "moduulienvälisiä optimointeja ei ole toteutettu C++:lle"
 
-#: cp/parser.c:39295
+#: cp/parser.c:39292
 #, fuzzy, gcc-internal-format
 #| msgid "templates may not be %<virtual%>"
 msgid "implicit templates may not be %<virtual%>"
 msgstr "mallit eivät voi olla virtuaalisia"
 
-#: cp/parser.c:39351
+#: cp/parser.c:39348
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
@@ -49034,7 +49078,7 @@
 msgid "specialization of %qD after instantiation"
 msgstr ""
 
-#: cp/pt.c:1954 cp/semantics.c:5274
+#: cp/pt.c:1954 cp/semantics.c:5277
 #, fuzzy, gcc-internal-format
 msgid "%s %#qD"
 msgstr "%s %d"
@@ -49202,107 +49246,107 @@
 msgid "argument to __integer_pack must be between 0 and %d"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/pt.c:3942
+#: cp/pt.c:3955
 #, gcc-internal-format
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr ""
 
-#: cp/pt.c:4010
+#: cp/pt.c:4023
 #, gcc-internal-format
 msgid "expansion pattern %qT contains no argument packs"
 msgstr ""
 
-#: cp/pt.c:4012
+#: cp/pt.c:4025
 #, gcc-internal-format
 msgid "expansion pattern %qE contains no argument packs"
 msgstr ""
 
-#: cp/pt.c:4063
+#: cp/pt.c:4077
 #, fuzzy, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr "parametrin %qD esittely, mutta parametria ei ole olemassa"
 
-#: cp/pt.c:4080 cp/pt.c:4835
+#: cp/pt.c:4094 cp/pt.c:4849
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "        %qD"
 
-#: cp/pt.c:4082
+#: cp/pt.c:4096
 #, gcc-internal-format
 msgid "        <anonymous>"
 msgstr "        <nimetön>"
 
-#: cp/pt.c:4208
+#: cp/pt.c:4222
 #, fuzzy, gcc-internal-format
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr "%J%qD:n esittely varjostaa parametria"
 
-#: cp/pt.c:4211
+#: cp/pt.c:4225
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q+#D shadows template parameter"
 msgstr "malliesittelylle %q+D"
 
-#: cp/pt.c:4213
+#: cp/pt.c:4227
 #, fuzzy, gcc-internal-format
 msgid "template parameter %qD declared here"
 msgstr "%qD esitelty ei-parametrina"
 
-#: cp/pt.c:4771
+#: cp/pt.c:4785
 #, fuzzy, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr "muuttuja %qD esitelty %<inline%>:ksi"
 
-#: cp/pt.c:4830
+#: cp/pt.c:4844
 #, fuzzy, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr "%qs:n esittelyssä tyyppi on oletuksena %<int%>"
 
-#: cp/pt.c:4854
+#: cp/pt.c:4868
 #, fuzzy, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.c:4858
+#: cp/pt.c:4872
 #, fuzzy, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.c:4862 cp/pt.c:4873
+#: cp/pt.c:4876 cp/pt.c:4887
 #, fuzzy, gcc-internal-format
 msgid "primary template here"
 msgstr "ensiö"
 
-#: cp/pt.c:4870
+#: cp/pt.c:4884
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:4885
+#: cp/pt.c:4899
 #, fuzzy, gcc-internal-format
 msgid "partial specialization %qD is not more specialized than"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.c:4887
+#: cp/pt.c:4901
 #, fuzzy, gcc-internal-format
 msgid "primary template %qD"
 msgstr "ensiö"
 
-#: cp/pt.c:4934
+#: cp/pt.c:4948
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:4937
+#: cp/pt.c:4951
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:4958
+#: cp/pt.c:4972
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr ""
 
-#: cp/pt.c:5004
+#: cp/pt.c:5018
 #, fuzzy, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
@@ -49309,17 +49353,17 @@
 msgstr[0] "tyyppimuunnettu argumentti %qD ei sovi prototyyppiin"
 msgstr[1] "tyyppimuunnettu argumentti %qD ei sovi prototyyppiin"
 
-#: cp/pt.c:5066
+#: cp/pt.c:5080
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "%qs-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: cp/pt.c:5070
+#: cp/pt.c:5084
 #, fuzzy, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "%qs:n esittely taulukollisena tyhjiä alkioita"
 
-#: cp/pt.c:5247
+#: cp/pt.c:5261
 #, fuzzy, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "%qD:lla ei voi olla oletusargumentteja"
@@ -49327,47 +49371,47 @@
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5269
+#: cp/pt.c:5283
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "%Jparametrin nimi puuttuu parametrilistasta"
 
-#: cp/pt.c:5305
+#: cp/pt.c:5319
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr ""
 
-#: cp/pt.c:5308
+#: cp/pt.c:5322
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/pt.c:5311
+#: cp/pt.c:5325
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/pt.c:5314
+#: cp/pt.c:5328
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr ""
 
-#: cp/pt.c:5317 cp/pt.c:5375
+#: cp/pt.c:5331 cp/pt.c:5389
 #, fuzzy, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "tallennusluokka annettu parametrille %qs"
 
-#: cp/pt.c:5489
+#: cp/pt.c:5503
 #, fuzzy, gcc-internal-format
 msgid "template %qD declared"
 msgstr "%qD ei ole malli"
 
-#: cp/pt.c:5496
+#: cp/pt.c:5510
 #, fuzzy, gcc-internal-format
 msgid "template class without a name"
 msgstr "funktiomalli %qD esitelty uudelleen luokkamallina"
 
-#: cp/pt.c:5504
+#: cp/pt.c:5518
 #, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr ""
@@ -49377,57 +49421,57 @@
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5526
+#: cp/pt.c:5540
 #, fuzzy, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "%qD ei ole malli"
 
-#: cp/pt.c:5669
+#: cp/pt.c:5683
 #, fuzzy, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "malliesittelylle %q+D"
 
-#: cp/pt.c:5712
+#: cp/pt.c:5726
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr ""
 
-#: cp/pt.c:5726
+#: cp/pt.c:5740
 #, fuzzy, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "malliesittelylle %q+D"
 
-#: cp/pt.c:5729
+#: cp/pt.c:5743
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr ""
 
-#: cp/pt.c:5731
+#: cp/pt.c:5745
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "Vaaditaan todennus.\n"
 
-#: cp/pt.c:5752
+#: cp/pt.c:5766
 #, fuzzy, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "tyyppimuunnettu argumentti %qD ei sovi prototyyppiin"
 
-#: cp/pt.c:5755
+#: cp/pt.c:5769
 #, fuzzy, gcc-internal-format
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "muodostimen virheellinen käyttö mallina"
 
-#: cp/pt.c:5882
+#: cp/pt.c:5896
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT ei ole malli"
 
-#: cp/pt.c:5895
+#: cp/pt.c:5909
 #, fuzzy, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "%qs:n esittelyssä tyyppi on oletuksena %<int%>"
 
-#: cp/pt.c:5906
+#: cp/pt.c:5920
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
@@ -49434,7 +49478,7 @@
 msgstr[0] "%J%qD:n edellinen esittely oli täällä"
 msgstr[1] "%J%qD:n edellinen esittely oli täällä"
 
-#: cp/pt.c:5910
+#: cp/pt.c:5924
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
@@ -49441,12 +49485,12 @@
 msgstr[0] "%J%qD:n edellinen esittely oli täällä"
 msgstr[1] "%J%qD:n edellinen esittely oli täällä"
 
-#: cp/pt.c:5947
+#: cp/pt.c:5961
 #, fuzzy, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "malliesittelylle %q+D"
 
-#: cp/pt.c:5948
+#: cp/pt.c:5962
 #, fuzzy, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "%q+D esitelty uudelleen erityyppisenä symbolina"
@@ -49455,117 +49499,117 @@
 #.
 #. A template-parameter may not be given default arguments
 #. by two different declarations in the same scope.
-#: cp/pt.c:5958
+#: cp/pt.c:5972
 #, fuzzy, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "%q+D määritelty uudelleen"
 
-#: cp/pt.c:5960
+#: cp/pt.c:5974
 #, fuzzy, gcc-internal-format
 msgid "original definition appeared here"
 msgstr "edellinen määrittely oli täällä"
 
-#: cp/pt.c:5988
+#: cp/pt.c:6002
 #, fuzzy, gcc-internal-format
 msgid "redeclaration %q#D with different constraints"
 msgstr "%q+D:n virheellinen uudelleenesittely"
 
-#: cp/pt.c:5991
+#: cp/pt.c:6005
 #, fuzzy, gcc-internal-format
 msgid "original declaration appeared here"
 msgstr "varjostunut esittely on täällä"
 
-#: cp/pt.c:6250 cp/pt.c:6318
+#: cp/pt.c:6264 cp/pt.c:6332
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.c:6253
+#: cp/pt.c:6267
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6256
+#: cp/pt.c:6270
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6268
+#: cp/pt.c:6282
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.c:6272
+#: cp/pt.c:6286
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.c:6321
+#: cp/pt.c:6335
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr ""
 
-#: cp/pt.c:6323
+#: cp/pt.c:6337
 #, fuzzy, gcc-internal-format
 msgid "because it is a member of %qT"
 msgstr "%qD:n esittely %qT:n jäsenenä"
 
-#: cp/pt.c:6383
+#: cp/pt.c:6397
 #, fuzzy, gcc-internal-format
 msgid "  couldn't deduce template parameter %qD"
 msgstr "%Juseita parametreja nimellä %qD"
 
-#: cp/pt.c:6392
+#: cp/pt.c:6406
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.c:6401
+#: cp/pt.c:6415
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr "  täsmäämättömät tyypit %qT ja %qT"
 
-#: cp/pt.c:6410
+#: cp/pt.c:6424
 #, fuzzy, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr "strftime-muotoilut eivät voi muotoilla argumentteja"
 
-#: cp/pt.c:6421
+#: cp/pt.c:6435
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "tyyppimuunnettu argumentti %qD ei sovi prototyyppiin"
 
-#: cp/pt.c:6431
+#: cp/pt.c:6445
 #, fuzzy, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr "%qE-attribuuttia ei huomioida %qE:lle"
 
-#: cp/pt.c:6440
+#: cp/pt.c:6454
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:6452
+#: cp/pt.c:6466
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.c:6456
+#: cp/pt.c:6470
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.c:6467
+#: cp/pt.c:6481
 #, fuzzy, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.c:6478
+#: cp/pt.c:6492
 #, fuzzy, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.c:6490
+#: cp/pt.c:6504
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "  candidate expects %d argument, %d provided"
 #| msgid_plural "  candidate expects %d arguments, %d provided"
@@ -49574,298 +49618,298 @@
 msgstr[0] "  ehdokas odottaa %d argumenttia, %d annettu"
 msgstr[1] "  ehdokas odottaa %d argumenttia, %d annettu"
 
-#: cp/pt.c:6521
+#: cp/pt.c:6535
 #, fuzzy, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "%qE:ta ei voi muuntaa tyypistä %qT tyyppiin %qT"
 
-#: cp/pt.c:6534
+#: cp/pt.c:6548
 #, fuzzy, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "muunnos tyypistä %qT tyyppiin %qT on moniselitteinen"
 
-#: cp/pt.c:6538
+#: cp/pt.c:6552
 #, fuzzy, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "muunnos tyypistä %qT tyyppiin %qT"
 
-#: cp/pt.c:6549
+#: cp/pt.c:6563
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.c:6559
+#: cp/pt.c:6573
 #, fuzzy, gcc-internal-format
 msgid "  can't deduce a template for %qT from non-template type %qT"
 msgstr "parametrilla %P on vaillinainen tyyppi %qT"
 
-#: cp/pt.c:6569
+#: cp/pt.c:6583
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
 msgstr "tyyppimuunnettu argumentti %qD ei sovi prototyyppiin"
 
-#: cp/pt.c:6609
+#: cp/pt.c:6623
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr ""
 
-#: cp/pt.c:6758
+#: cp/pt.c:6772
 #, fuzzy, gcc-internal-format
 msgid "in template argument for type %qT"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.c:6772
+#: cp/pt.c:6786
 #, fuzzy, gcc-internal-format
 msgid "template argument %qE for type %qT not a constant integer"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.c:6833
+#: cp/pt.c:6847
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr ""
 
-#: cp/pt.c:6841
+#: cp/pt.c:6855
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is not an object with external linkage"
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.c:6857
+#: cp/pt.c:6871
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.c:6864
+#: cp/pt.c:6878
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr ""
 
-#: cp/pt.c:6873
+#: cp/pt.c:6887
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.c:6888
+#: cp/pt.c:6902
 #, fuzzy, gcc-internal-format
 msgid "the address of %qD is not a valid template argument"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.c:6897
+#: cp/pt.c:6911
 #, fuzzy, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.c:6904
+#: cp/pt.c:6918
 #, fuzzy, gcc-internal-format
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.c:6933
+#: cp/pt.c:6947
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr ""
 
-#: cp/pt.c:6941
+#: cp/pt.c:6955
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.c:6959
+#: cp/pt.c:6973
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr ""
 
-#: cp/pt.c:6975
+#: cp/pt.c:6989
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is not an object with external linkage"
 msgid "%qE is not a valid template argument for type %qT because it is not an object with linkage"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.c:6986
+#: cp/pt.c:7000
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because object %qD does not have linkage"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.c:7036
+#: cp/pt.c:7050
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.c:7038
+#: cp/pt.c:7052
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr ""
 
-#: cp/pt.c:7092
+#: cp/pt.c:7106
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.c:7654
+#: cp/pt.c:7668
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "%qD:n malliargumentti käyttää paikallista tyyppiä %qT"
 
-#: cp/pt.c:7670
+#: cp/pt.c:7684
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr "%qD:n malliargumentti käyttää paikallista tyyppiä %qT"
 
-#: cp/pt.c:7805
+#: cp/pt.c:7819
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr ""
 
-#: cp/pt.c:7834
+#: cp/pt.c:7848
 #, fuzzy, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "virheellinen hajottimen %qD käyttö tyyppinä"
 
-#: cp/pt.c:7839
+#: cp/pt.c:7853
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr ""
 
-#: cp/pt.c:7855 cp/pt.c:7877 cp/pt.c:7931
+#: cp/pt.c:7869 cp/pt.c:7891 cp/pt.c:7945
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.c:7860
+#: cp/pt.c:7874
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  odotettiin %qT-tyyppistä vakiota, saatiin %qT"
 
-#: cp/pt.c:7865
+#: cp/pt.c:7879
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  odotettiin luokkamallia, saatiin %qE"
 
-#: cp/pt.c:7868
+#: cp/pt.c:7882
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  odotettiin tyyppiä, saatiin %qE"
 
-#: cp/pt.c:7882
+#: cp/pt.c:7896
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  odotettiin tyyppiä, saatiin %qT"
 
-#: cp/pt.c:7885
+#: cp/pt.c:7899
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  odotettiin luokkamallia, saatiin %qT"
 
-#: cp/pt.c:7935
+#: cp/pt.c:7949
 #, fuzzy, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  odotettiin tyyppiä, saatiin %qT"
 
-#: cp/pt.c:7949
+#: cp/pt.c:7963
 #, fuzzy, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "tallennusluokka annettu parametrille %qs"
 
-#: cp/pt.c:7952
+#: cp/pt.c:7966
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a type, got %qE"
 msgid "  expected %qD but got %qD"
 msgstr "  odotettiin tyyppiä, saatiin %qE"
 
-#: cp/pt.c:8012
+#: cp/pt.c:8026
 #, fuzzy, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "%qE:ta ei voi muuntaa tyypistä %qT tyyppiin %qT"
 
-#: cp/pt.c:8149 cp/pt.c:8465
+#: cp/pt.c:8163 cp/pt.c:8479
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "muodostimen virheellinen käyttö mallina"
 
-#: cp/pt.c:8164 cp/pt.c:8298
+#: cp/pt.c:8178 cp/pt.c:8312
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr ""
 
-#: cp/pt.c:8294
+#: cp/pt.c:8308
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "attribuutille %qs annettu väärä määrä argumentteja"
 
-#: cp/pt.c:8303
+#: cp/pt.c:8317
 #, fuzzy, gcc-internal-format
 #| msgid "prototype for %q+#D"
 msgid "provided for %qD"
 msgstr "nimellä %qD"
 
-#: cp/pt.c:8328
+#: cp/pt.c:8342
 #, fuzzy, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr "tallennusluokka annettu parametrille %qs"
 
-#: cp/pt.c:8332
+#: cp/pt.c:8346
 #, fuzzy, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "tallennusluokka annettu parametrille %qs"
 
-#: cp/pt.c:8431
+#: cp/pt.c:8445
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:9054
+#: cp/pt.c:9068
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "malliesittelylle %q+D"
 
-#: cp/pt.c:9221
+#: cp/pt.c:9235
 #, fuzzy, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "%qD:n malliargumentti käyttää paikallista tyyppiä %qT"
 
-#: cp/pt.c:9223
+#: cp/pt.c:9237
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "malliesittelylle %q+D"
 
-#: cp/pt.c:9346
+#: cp/pt.c:9360
 #, fuzzy, gcc-internal-format
 msgid "template constraint failure"
 msgstr "%qT ei ole malli"
 
-#: cp/pt.c:9697
+#: cp/pt.c:9718
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "use of invalid variable template %qE"
 msgstr "%qD ei ole muuttuja"
 
-#: cp/pt.c:10125
+#: cp/pt.c:10148
 #, gcc-internal-format, gfc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:11202
+#: cp/pt.c:11225
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member in union"
 msgid "flexible array member %qD in union"
 msgstr "joustava taulukkojäsen unionissa"
 
-#: cp/pt.c:11691
+#: cp/pt.c:11713
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:12160
+#: cp/pt.c:12182
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr ""
 
-#: cp/pt.c:12163
+#: cp/pt.c:12185
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr ""
 
-#: cp/pt.c:12747
+#: cp/pt.c:12769
 #, fuzzy, gcc-internal-format
 msgid "  when instantiating default argument for call to %qD"
 msgstr "%q+D määritelty uudelleen"
@@ -49883,208 +49927,208 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:13708
+#: cp/pt.c:13730
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "muuttujalla %qD on funktiotyyppi"
 
-#: cp/pt.c:13881
+#: cp/pt.c:13903
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "virheellinen parametrityyppi %qT"
 
-#: cp/pt.c:13883
+#: cp/pt.c:13905
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "esittelyssä %q+D"
 
-#: cp/pt.c:14001
+#: cp/pt.c:14023
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "taulukon palauttava funktio"
 
-#: cp/pt.c:14003
+#: cp/pt.c:14025
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "funktion palauttava funktio"
 
-#: cp/pt.c:14043
+#: cp/pt.c:14065
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr ""
 
-#: cp/pt.c:14637
+#: cp/pt.c:14659
 #, fuzzy, gcc-internal-format
 msgid "forming reference to void"
 msgstr "tyhjää arvoa ei jätetä huomioimatta, vaikka kuuluisi"
 
-#: cp/pt.c:14639
+#: cp/pt.c:14661
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "NULLin muunnos epäosoitintyypiksi %qT"
 
-#: cp/pt.c:14641
+#: cp/pt.c:14663
 #, fuzzy, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "tyyppitäsmäämättömyys taulukkoviitteessä"
 
-#: cp/pt.c:14654
+#: cp/pt.c:14676
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "tyyppimuunnos lisää funktiotyyppiin uusia määreitä"
 
-#: cp/pt.c:14657
+#: cp/pt.c:14679
 #, fuzzy, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "tyyppimuunnos lisää funktiotyyppiin uusia määreitä"
 
-#: cp/pt.c:14705
+#: cp/pt.c:14727
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr ""
 
-#: cp/pt.c:14711
+#: cp/pt.c:14733
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr ""
 
-#: cp/pt.c:14717
+#: cp/pt.c:14739
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "%<void *%>-tyyppistä osoitinta käytetty laskutoimituksessa"
 
-#: cp/pt.c:14783
+#: cp/pt.c:14805
 #, fuzzy, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "luodaan void-taulukko"
 
-#: cp/pt.c:14816
+#: cp/pt.c:14838
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT ei ole luokka-, struct- eikä unionityyppi"
 
-#: cp/pt.c:14853
+#: cp/pt.c:14875
 #, fuzzy, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%Jcase-arvo %qs ei ole luetellussa tyypissä"
 
-#: cp/pt.c:14861
+#: cp/pt.c:14883
 #, fuzzy, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr "%qT ei ole luokka-, struct- eikä unionityyppi"
 
-#: cp/pt.c:14925
+#: cp/pt.c:14947
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.c:15000
+#: cp/pt.c:15022
 #, fuzzy, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "muodostimen virheellinen käyttö mallina"
 
-#: cp/pt.c:15178
+#: cp/pt.c:15200
 #, fuzzy, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "objektityyppi %qT ei täsmää hajottimen nimen ~%qT kanssa"
 
-#: cp/pt.c:15193
+#: cp/pt.c:15215
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr ""
 
-#: cp/pt.c:15195
+#: cp/pt.c:15217
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr ""
 
-#: cp/pt.c:15394
+#: cp/pt.c:15416
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "käytetään virheellistä kenttää %qD"
 
-#: cp/pt.c:15883 cp/pt.c:17386
+#: cp/pt.c:15905 cp/pt.c:17408
 #, fuzzy, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "void-lausekkeen epäkelpo käyttö"
 
-#: cp/pt.c:15887 cp/pt.c:17390
+#: cp/pt.c:15909 cp/pt.c:17412
 #, fuzzy, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "Käytä rekistereitä argumenttien välittämiseen"
 
-#: cp/pt.c:18334
+#: cp/pt.c:18371
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:18362
+#: cp/pt.c:18399
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:18367
+#: cp/pt.c:18404
 #, fuzzy, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "käytä #includea sen sijaan"
 
-#: cp/pt.c:18370
+#: cp/pt.c:18407
 #, fuzzy, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "käytä #includea sen sijaan"
 
-#: cp/pt.c:18375
+#: cp/pt.c:18412
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "%J%qD esitelty avoimeksi määrittelyn jälkeen"
 
-#: cp/pt.c:18712
+#: cp/pt.c:18752
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT ei ole luokka eikä nimiavaruus"
 
-#: cp/pt.c:18715
+#: cp/pt.c:18755
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD ei ole luokka eikä nimiavaruus"
 
-#: cp/pt.c:19026
+#: cp/pt.c:19066
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is/uses anonymous type"
 msgid "%qT is/uses unnamed type"
 msgstr "%qT on/käyttää anonyymiä tyyppiä"
 
-#: cp/pt.c:19028
+#: cp/pt.c:19068
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "%qD:n malliargumentti käyttää paikallista tyyppiä %qT"
 
-#: cp/pt.c:19038
+#: cp/pt.c:19078
 #, fuzzy, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "odotettiin %qT, mutta argumentti on tyyppiä %qT"
 
-#: cp/pt.c:19053
+#: cp/pt.c:19093
 #, fuzzy, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/pt.c:19071
+#: cp/pt.c:19111
 #, fuzzy, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "ohjelman alustusta yritettäessä"
 
-#: cp/pt.c:22972
+#: cp/pt.c:23050
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "%qs-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: cp/pt.c:22974
+#: cp/pt.c:23052
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "malliesittelylle %q+D"
 
-#: cp/pt.c:22980
+#: cp/pt.c:23058
 #, fuzzy
 msgid "%s %#qS"
 msgstr ""
@@ -50092,72 +50136,72 @@
 "%s, %s, %s, %s,\n"
 "%s, %s ja %s.\n"
 
-#: cp/pt.c:23004 cp/pt.c:23091
+#: cp/pt.c:23082 cp/pt.c:23169
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr ""
 
-#: cp/pt.c:23023
+#: cp/pt.c:23101
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr ""
 
-#: cp/pt.c:23029 cp/pt.c:23086
+#: cp/pt.c:23107 cp/pt.c:23164
 #, fuzzy, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "%qD ei ole mallifunktio"
 
-#: cp/pt.c:23034
+#: cp/pt.c:23112
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr ""
 
-#: cp/pt.c:23042
+#: cp/pt.c:23120
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "käyttämätön muuttuja %q+D"
 
-#: cp/pt.c:23078
+#: cp/pt.c:23156
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "jäsenen %q+D kaksoiskappale"
 
-#: cp/pt.c:23101 cp/pt.c:23187
+#: cp/pt.c:23179 cp/pt.c:23265
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ kieltää metodiosoittimen käytön vähennyslaskussa"
 
-#: cp/pt.c:23106 cp/pt.c:23204
+#: cp/pt.c:23184 cp/pt.c:23282
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr ""
 
-#: cp/pt.c:23163
+#: cp/pt.c:23241
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "%qs:n esittely taulukollisena tyhjiä alkioita"
 
-#: cp/pt.c:23165
+#: cp/pt.c:23243
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr ""
 
-#: cp/pt.c:23174
+#: cp/pt.c:23252
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr ""
 
-#: cp/pt.c:23192
+#: cp/pt.c:23270
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr ""
 
-#: cp/pt.c:23238
+#: cp/pt.c:23316
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr ""
 
-#: cp/pt.c:23536
+#: cp/pt.c:23614
 #, fuzzy, gcc-internal-format
 msgid "exception specification of %qD depends on itself"
 msgstr "%q+D:n edellinen esittely oli täällä"
@@ -50169,109 +50213,109 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:23842
+#: cp/pt.c:23920
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr ""
 
-#: cp/pt.c:24043
+#: cp/pt.c:24121
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:24418
+#: cp/pt.c:24496
 #, fuzzy, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "staattinen tai tyyppimääreitä ei-parametrisessa taulukkoesittelijässä"
 
-#: cp/pt.c:24420
+#: cp/pt.c:24498
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.c:25723
+#: cp/pt.c:25802
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr ""
 
-#: cp/pt.c:25961
+#: cp/pt.c:26040
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/pt.c:26440
+#: cp/pt.c:26519
 #, fuzzy, gcc-internal-format
 msgid "non-class template %qT used without template arguments"
 msgstr "%qD ei ole mallifunktio"
 
-#: cp/pt.c:26586
+#: cp/pt.c:26665
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:26593
+#: cp/pt.c:26672
 #, fuzzy, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.c:26607
+#: cp/pt.c:26686
 #, fuzzy, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "liian paljon argumentteja funktiolle %qs"
 
-#: cp/pt.c:26614
+#: cp/pt.c:26693
 #, fuzzy, gcc-internal-format
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "Tiedostoa ”%s” on jo tarkasteltu.\n"
 
-#: cp/pt.c:26676
+#: cp/pt.c:26755
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:26679
+#: cp/pt.c:26758
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:26711
+#: cp/pt.c:26790
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/pt.c:26746
+#: cp/pt.c:26825
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "ei voi emuloida %qs"
 
-#: cp/pt.c:26748
+#: cp/pt.c:26827
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "%qE:n muunnos tyypistä %qT tyyppiin %qT ei ole yksiselitteinen"
 
-#: cp/pt.c:26781
+#: cp/pt.c:26860
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:26785
+#: cp/pt.c:26864
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not constant"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "alustusalkio ei ole vakio"
 
-#: cp/pt.c:26789
+#: cp/pt.c:26868
 #, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.c:26793
+#: cp/pt.c:26872
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not constant"
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "alustusalkio ei ole vakio"
 
-#: cp/pt.c:26912
+#: cp/pt.c:26991
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr "virheellinen %<auto%>:n käyttö muunnosoperaattorissa"
@@ -50328,79 +50372,79 @@
 msgid "cannot dynamic_cast %qE (of type %q#T) to type %q#T (%s)"
 msgstr ""
 
-#: cp/search.c:240
+#: cp/search.c:243
 #, fuzzy, gcc-internal-format
 msgid "%qT is an ambiguous base of %qT"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/search.c:256
+#: cp/search.c:259
 #, fuzzy, gcc-internal-format
 msgid "%qT is an inaccessible base of %qT"
 msgstr "perustyypin %qT kaksoiskappale virheellinen"
 
-#: cp/search.c:1905
+#: cp/search.c:1908
 #, fuzzy, gcc-internal-format
 msgid "invalid covariant return type for %q#D"
 msgstr "epäkelpo vektorityyppi attribuutille %qs"
 
-#: cp/search.c:1907 cp/search.c:1922 cp/search.c:1928 cp/search.c:1957
+#: cp/search.c:1910 cp/search.c:1925 cp/search.c:1931 cp/search.c:1960
 #, fuzzy, gcc-internal-format
 msgid "overridden function is %q#D"
 msgstr "poistamaton funktio %q+D"
 
-#: cp/search.c:1920
+#: cp/search.c:1923
 #, fuzzy, gcc-internal-format
 msgid "invalid covariant return type for %q+#D"
 msgstr "epäkelpo vektorityyppi attribuutille %qs"
 
-#: cp/search.c:1926
+#: cp/search.c:1929
 #, fuzzy, gcc-internal-format
 msgid "conflicting return type specified for %q+#D"
 msgstr "ristiriitaiset tyyppimääreet %q+D:lle"
 
-#: cp/search.c:1942
+#: cp/search.c:1945
 #, gcc-internal-format
 msgid "looser throw specifier for %q+#F"
 msgstr ""
 
-#: cp/search.c:1944
+#: cp/search.c:1947
 #, fuzzy, gcc-internal-format
 msgid "overridden function is %q#F"
 msgstr "poistamaton funktio %q+D"
 
-#: cp/search.c:1955
+#: cp/search.c:1958
 #, fuzzy, gcc-internal-format
 msgid "conflicting type attributes specified for %q+#D"
 msgstr "ristiriitaiset tyyppimääreet %q+D:lle"
 
-#: cp/search.c:1972
+#: cp/search.c:1975
 #, gcc-internal-format
 msgid "%qD declared %<transaction_safe_dynamic%>"
 msgstr ""
 
-#: cp/search.c:1974
+#: cp/search.c:1977
 #, fuzzy, gcc-internal-format
 #| msgid "variable %q+D declared %<inline%>"
 msgid "overriding %qD declared %<transaction_safe%>"
 msgstr "muuttuja %qD esitelty %<inline%>:ksi"
 
-#: cp/search.c:1981
+#: cp/search.c:1984
 #, fuzzy, gcc-internal-format
 msgid "deleted function %q+D overriding non-deleted function"
 msgstr "poistamaton funktio %q+D"
 
-#: cp/search.c:1984 cp/search.c:1992 cp/search.c:2000
+#: cp/search.c:1987 cp/search.c:1995 cp/search.c:2003
 #, fuzzy, gcc-internal-format
 msgid "overridden function is %qD"
 msgstr "poistamaton funktio %q+D"
 
-#: cp/search.c:1989
+#: cp/search.c:1992
 #, fuzzy, gcc-internal-format
 #| msgid "non-deleted function %q+D"
 msgid "non-deleted function %q+D overriding deleted function"
 msgstr "poistamaton funktio %q+D"
 
-#: cp/search.c:1998
+#: cp/search.c:2001
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "virtual function %q+D overriding final function"
@@ -50408,12 +50452,12 @@
 
 #. A static member function cannot match an inherited
 #. virtual member function.
-#: cp/search.c:2082
+#: cp/search.c:2085
 #, fuzzy, gcc-internal-format
 msgid "%q+#D cannot be declared"
 msgstr "%q+D esitelty ystävänä"
 
-#: cp/search.c:2083
+#: cp/search.c:2086
 #, gcc-internal-format
 msgid "  since %q+#D declared in base class"
 msgstr ""
@@ -50454,593 +50498,609 @@
 msgid "invalid use of member %qD in static member function"
 msgstr "virheellinen ei-staattisen jäsenfunktion käyttö"
 
-#: cp/semantics.c:2153
+#: cp/semantics.c:2156
 #, gcc-internal-format
 msgid "a statement expression is an insufficient context for overload resolution"
 msgstr ""
 
-#: cp/semantics.c:2540
+#: cp/semantics.c:2543
 #, fuzzy, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr "ei argumentteja"
 
-#: cp/semantics.c:2622
+#: cp/semantics.c:2625
 #, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr "%<this%> ei ole käytettävissä staattisissa jäsenfunktioissa"
 
-#: cp/semantics.c:2624
+#: cp/semantics.c:2627
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr "virheellinen ei-staattisen jäsenfunktion käyttö"
 
-#: cp/semantics.c:2626
+#: cp/semantics.c:2629
 #, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr ""
 
-#: cp/semantics.c:2648
+#: cp/semantics.c:2651
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr ""
 
-#: cp/semantics.c:2656 cp/typeck.c:2604
+#: cp/semantics.c:2659 cp/typeck.c:2604
 #, fuzzy, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "objektityyppi %qT ei täsmää hajottimen nimen ~%qT kanssa"
 
-#: cp/semantics.c:2678
+#: cp/semantics.c:2681
 #, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr "%qE ei ole tyyppiä %qT"
 
-#: cp/semantics.c:2751
+#: cp/semantics.c:2754
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr "ei-objektityyppinen yhdysliteraali %qT"
 
-#: cp/semantics.c:2892
+#: cp/semantics.c:2895
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr ""
 
-#: cp/semantics.c:2942
+#: cp/semantics.c:2945
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr ""
 
-#: cp/semantics.c:2945
+#: cp/semantics.c:2948
 #, fuzzy, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr "mallinimen %qE virheellinen käyttö ilman argumenttiluetteloa"
 
-#: cp/semantics.c:2962
+#: cp/semantics.c:2965
 #, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr ""
 
-#: cp/semantics.c:2993
+#: cp/semantics.c:2996
 #, fuzzy, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr "virheellinen muunnos tyypistä %qT tyyppiin %qT"
 
-#: cp/semantics.c:3263
+#: cp/semantics.c:3266
 #, fuzzy, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "perustyypin %qT kaksoiskappale virheellinen"
 
-#: cp/semantics.c:3423
+#: cp/semantics.c:3426
 #, gcc-internal-format
 msgid "cannot capture member %qD of anonymous union"
 msgstr ""
 
-#: cp/semantics.c:3443 cp/semantics.c:9269
+#: cp/semantics.c:3446 cp/semantics.c:9272
 #, fuzzy, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "        %qD"
 
-#: cp/semantics.c:3448
+#: cp/semantics.c:3451
 #, fuzzy, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr "oletusargumentti määritelty lambda-parametrille"
 
-#: cp/semantics.c:3450
+#: cp/semantics.c:3453
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.c:3462
+#: cp/semantics.c:3465
 #, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr ""
 
-#: cp/semantics.c:3464
+#: cp/semantics.c:3467
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr ""
 
-#: cp/semantics.c:3596
+#: cp/semantics.c:3599
 #, fuzzy, gcc-internal-format
 msgid "use of parameter outside function body"
 msgstr "poistettu funktio %q+D"
 
-#: cp/semantics.c:3606
+#: cp/semantics.c:3609
 #, fuzzy, gcc-internal-format
 #| msgid "mismatched arguments"
 msgid "missing template arguments"
 msgstr "täsmäämättömät argumentit"
 
-#: cp/semantics.c:3633
+#: cp/semantics.c:3636
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr ""
 
-#: cp/semantics.c:3664
+#: cp/semantics.c:3667
 #, fuzzy, gcc-internal-format
 msgid "use of namespace %qD as expression"
 msgstr "%qD ei ole nimiavaruuden nimi"
 
-#: cp/semantics.c:3669
+#: cp/semantics.c:3672
 #, fuzzy, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr "  odotettiin luokkamallia, saatiin %qT"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:3675
+#: cp/semantics.c:3678
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr ""
 
-#: cp/semantics.c:3702
+#: cp/semantics.c:3705
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/semantics.c:3841
+#: cp/semantics.c:3844
 #, fuzzy, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "%qE ei ole tyyppi"
 
-#: cp/semantics.c:3870
+#: cp/semantics.c:3873
 #, fuzzy, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr "odotettiin %qT, mutta argumentti on tyyppiä %qT"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4009
+#: cp/semantics.c:4012
 #, fuzzy, gcc-internal-format
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr "tarpeeton tyyppimääre tyhjässä esittelyssä"
 
-#: cp/semantics.c:4038
+#: cp/semantics.c:4041
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr ""
 
-#: cp/semantics.c:4052
+#: cp/semantics.c:4055
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "jäsenfunktiota %qD ei voi kutsua ilman oliota"
 
-#: cp/semantics.c:4056
+#: cp/semantics.c:4059
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function"
 msgstr "jäsenfunktiota %qD ei voi kutsua ilman oliota"
 
-#: cp/semantics.c:4061
+#: cp/semantics.c:4064
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr "jäsenfunktiota %qD ei voi kutsua ilman oliota"
 
-#: cp/semantics.c:4072
+#: cp/semantics.c:4075
 #, fuzzy, gcc-internal-format
 #| msgid "cannot receive objects of non-trivially-copyable type %q#T through %<...%>; "
 msgid "offsetof within non-standard-layout type %qT is conditionally-supported"
 msgstr "ei-triviaalisti-kopioitavan tyyppisiä %q#T-olioita ei voi vastaanottaa %<...%>:n kautta"
 
-#: cp/semantics.c:4583 cp/semantics.c:6069 cp/semantics.c:6140
-#: cp/semantics.c:6183 cp/semantics.c:6533 cp/semantics.c:6632
-#: cp/semantics.c:6775
+#: cp/semantics.c:4586 cp/semantics.c:6072 cp/semantics.c:6143
+#: cp/semantics.c:6186 cp/semantics.c:6536 cp/semantics.c:6635
+#: cp/semantics.c:6778
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5271
+#: cp/semantics.c:5274
 #, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr ""
 
-#: cp/semantics.c:5544
+#: cp/semantics.c:5547
 #, fuzzy, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr "ISO C kieltää nollan kokoisen taulukon %qE"
 
-#: cp/semantics.c:5592
+#: cp/semantics.c:5595
 #, fuzzy, gcc-internal-format
 msgid "%qE has const type for %<reduction%>"
 msgstr "tyypillä %qE on virtuaalisia jäsenfunktioita"
 
-#: cp/semantics.c:5707
+#: cp/semantics.c:5710
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:5941
+#: cp/semantics.c:5944
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5955
+#: cp/semantics.c:5958
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5977
+#: cp/semantics.c:5980
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6080
+#: cp/semantics.c:6083
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "muuttuja %qD esitelty uudelleen funktiona"
 
-#: cp/semantics.c:6152
+#: cp/semantics.c:6155
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "muuttuja %qD esitelty uudelleen funktiona"
 
-#: cp/semantics.c:6195
+#: cp/semantics.c:6198
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "muuttuja %qD esitelty uudelleen funktiona"
 
-#: cp/semantics.c:6240
+#: cp/semantics.c:6243
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<gang%> static expression must be integral"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: cp/semantics.c:6254
+#: cp/semantics.c:6257
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<gang%> static value must be positive"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: cp/semantics.c:6288
+#: cp/semantics.c:6291
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<gang%> num expression must be integral"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: cp/semantics.c:6291
+#: cp/semantics.c:6294
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<vector%> length expression must be integral"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: cp/semantics.c:6295
+#: cp/semantics.c:6298
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<worker%> num expression must be integral"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: cp/semantics.c:6317
+#: cp/semantics.c:6320
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<gang%> num value must be positive"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: cp/semantics.c:6321
+#: cp/semantics.c:6324
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<vector%> length value must be positive"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: cp/semantics.c:6326
+#: cp/semantics.c:6329
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<worker%> num value must be positive"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: cp/semantics.c:6376
+#: cp/semantics.c:6379
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6406
+#: cp/semantics.c:6409
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6419
+#: cp/semantics.c:6422
 #, fuzzy, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "etumerkillisen ja etumerkittömän kokonaislukulausekkeen vertailu"
 
-#: cp/semantics.c:6438
+#: cp/semantics.c:6441
 #, fuzzy, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/semantics.c:6466
+#: cp/semantics.c:6469
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6495
+#: cp/semantics.c:6498
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr ""
 
-#: cp/semantics.c:6516
+#: cp/semantics.c:6519
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6543
+#: cp/semantics.c:6546
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "muuttuja %qD esitelty uudelleen funktiona"
 
-#: cp/semantics.c:6557
+#: cp/semantics.c:6560
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:6563
+#: cp/semantics.c:6566
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: cp/semantics.c:6576
+#: cp/semantics.c:6579
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6625
+#: cp/semantics.c:6628
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr "muuttuja %qD esitelty uudelleen funktiona"
 
-#: cp/semantics.c:6910
+#: cp/semantics.c:6913
 #, fuzzy, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr "%qE ei ole malli"
 
-#: cp/semantics.c:6914
+#: cp/semantics.c:6917
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6979
+#: cp/semantics.c:6982
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<grainsize%> expression must be integral"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/semantics.c:7008
+#: cp/semantics.c:7011
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<priority%> expression must be integral"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/semantics.c:7037
+#: cp/semantics.c:7040
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<num_tasks%> expression must be integral"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: cp/semantics.c:7066
+#: cp/semantics.c:7069
 #, fuzzy, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr "indeksoitu arvo ei ole taulukko eikä osoitin"
 
-#: cp/semantics.c:7105
+#: cp/semantics.c:7108
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<tile%> argument needs integral type"
 msgstr "%s:n arvon on oltava kokonaisluku"
 
-#: cp/semantics.c:7524
+#: cp/semantics.c:7527
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.c:7538
+#: cp/semantics.c:7541
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "%Jparametrin %qD tyyppi on vaillinainen"
 
-#: cp/semantics.c:7743
+#: cp/semantics.c:7746
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.c:8171
+#: cp/semantics.c:8174
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.c:8398 cp/semantics.c:8408
+#: cp/semantics.c:8401 cp/semantics.c:8411
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.c:8702
+#: cp/semantics.c:8705
 #, fuzzy, gcc-internal-format
 #| msgid "static assertion failed: %s"
 msgid "static assertion failed"
 msgstr "staattinen väite epäonnistui: %s"
 
-#: cp/semantics.c:8704
+#: cp/semantics.c:8707
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr "staattinen väite epäonnistui: %s"
 
-#: cp/semantics.c:8709
+#: cp/semantics.c:8712
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "ei-vakio ehto staattiselle väitteelle"
 
-#: cp/semantics.c:8739
+#: cp/semantics.c:8742
 #, gcc-internal-format
 msgid "argument to decltype must be an expression"
 msgstr "decltypen argumentin on oltava lauseke"
 
-#: cp/semantics.c:8767
+#: cp/semantics.c:8770
 #, fuzzy, gcc-internal-format
 msgid "decltype cannot resolve address of overloaded function"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/semantics.c:9308
+#: cp/semantics.c:9311
 #, fuzzy, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "pilkkulausekkeen vasemmalla operandilla ei ole vaikutusta"
 
-#: cp/semantics.c:9361
+#: cp/semantics.c:9364
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.c:9363
+#: cp/semantics.c:9366
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:9381
+#: cp/semantics.c:9384
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %<__builtin_return_address%>"
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "ei-tuettu argumentti funktiolle %<__builtin_return_address%>"
 
-#: cp/tree.c:1276
+#: cp/tree.c:1295
 #, gcc-internal-format
 msgid "%qV qualifiers cannot be applied to %qT"
 msgstr ""
 
-#: cp/tree.c:1788
+#: cp/tree.c:1807
 #, fuzzy, gcc-internal-format
 msgid "lambda-expression in a constant expression"
 msgstr "liukulukuvakio esikääntäjän lausekkeessa"
 
-#: cp/tree.c:1792
+#: cp/tree.c:1811
 #, fuzzy, gcc-internal-format
 msgid "statement-expression in a constant expression"
 msgstr "liukulukuvakio esikääntäjän lausekkeessa"
 
-#: cp/tree.c:4050
+#: cp/tree.c:4083
+#, gcc-internal-format
+msgid "-fabi-version=13 (GCC 8.2) fixes the calling convention for %qT, which was accidentally changed in 8.1"
+msgstr ""
+
+#: cp/tree.c:4087
+#, gcc-internal-format
+msgid "-fabi-version=12 (GCC 8.1) accidentally changes the calling convention for %qT"
+msgstr ""
+
+#: cp/tree.c:4090
 #, fuzzy, gcc-internal-format
-msgid "the calling convention for %qT changes in -fabi-version=12 (GCC 8)"
-msgstr "%J%qD:n lohko on ristiriidassa edellisen esittelyn kanssa"
+#| msgid "declared here"
+msgid " declared here"
+msgstr "esitelty täällä"
 
-#: cp/tree.c:4055
+#: cp/tree.c:4094
 #, gcc-internal-format
+msgid "the calling convention for %qT changes in -fabi-version=13 (GCC 8.2)"
+msgstr ""
+
+#: cp/tree.c:4096
+#, gcc-internal-format
 msgid " because all of its copy and move constructors are deleted"
 msgstr ""
 
-#: cp/tree.c:4416
+#: cp/tree.c:4464
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to %qD with void return type"
 msgstr "%qs-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: cp/tree.c:4423
+#: cp/tree.c:4471
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to function types"
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr "%qE-attribuutti pätee vain funktiotyyppeihin"
 
-#: cp/tree.c:4475
+#: cp/tree.c:4523
 #, fuzzy, gcc-internal-format
 msgid "requested init_priority is not an integer constant"
 msgstr "haluttu sijainti ei ole kokonaislukuvakio"
 
-#: cp/tree.c:4497
+#: cp/tree.c:4545
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr ""
 
-#: cp/tree.c:4505
+#: cp/tree.c:4553
 #, gcc-internal-format
 msgid "requested init_priority is out of range"
 msgstr ""
 
-#: cp/tree.c:4515
+#: cp/tree.c:4563
 #, gcc-internal-format
 msgid "requested init_priority is reserved for internal use"
 msgstr ""
 
-#: cp/tree.c:4526
+#: cp/tree.c:4574
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr "Rinnakkaiset työt (-j) eivät ole tuettuja tällä alustalla."
 
-#: cp/tree.c:4553
+#: cp/tree.c:4601
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %qE"
 msgstr "%qs:n esittely taulukollisena tyhjiä alkioita"
 
-#: cp/tree.c:4573
+#: cp/tree.c:4621
 #, fuzzy, gcc-internal-format
 msgid "the %qE attribute requires arguments"
 msgstr "%qE-attribuutti tarvitsee prototyyppejä, joilla nimettyjä argumentteja"
 
-#: cp/tree.c:4584
+#: cp/tree.c:4632
 #, fuzzy, gcc-internal-format
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "näkyvyysargumentti ei ole merkkijono"
 
-#: cp/tree.c:4597 cp/tree.c:4610
+#: cp/tree.c:4645 cp/tree.c:4658
 #, fuzzy, gcc-internal-format
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "näkyvyysargumentti ei ole merkkijono"
 
-#: cp/tree.c:4599
+#: cp/tree.c:4647
 #, fuzzy, gcc-internal-format
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "universaali merkki %.*s ei ole kelvollinen tunniste"
 
-#: cp/tree.c:4612
+#: cp/tree.c:4660
 #, fuzzy, gcc-internal-format
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "universaali merkki %.*s ei ole kelvollinen tunniste"
 
-#: cp/tree.c:4636
+#: cp/tree.c:4684
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "%qs-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: cp/tree.c:4642
+#: cp/tree.c:4690
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "%J%qE-attribuutti soveltuu vain funktioihin"
 
-#: cp/tree.c:4649
+#: cp/tree.c:4697
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "%J%qE-attribuutti soveltuu vain funktioihin"
 
-#: cp/tree.c:4656
+#: cp/tree.c:4704
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "%J%qE-attribuutti soveltuu vain funktioihin"
 
-#: cp/tree.c:4678
+#: cp/tree.c:4726
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "%J%qE-attribuutti soveltuu vain funktioihin"
 
-#: cp/tree.c:4684
+#: cp/tree.c:4732
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "%J%qE-attribuutti soveltuu vain funktioihin"
 
-#: cp/tree.c:5440
+#: cp/tree.c:5488
 #, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "nolla nollaosoitinvakiona"
 
-#: cp/tree.c:5453
+#: cp/tree.c:5501
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr "verifiointi epäonnistui kohdassa PC=%d: %s"
@@ -52179,112 +52239,112 @@
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr ""
 
-#: cp/typeck2.c:1496 cp/typeck2.c:1523
+#: cp/typeck2.c:1499 cp/typeck2.c:1526
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "puuttuva alustin jäsenelle %qD"
 
-#: cp/typeck2.c:1504
+#: cp/typeck2.c:1507
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "jäsen %qD on alustamaton viittaus"
 
-#: cp/typeck2.c:1511
+#: cp/typeck2.c:1514
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized reference member %qD"
 msgid "member %qD with uninitialized reference fields"
 msgstr "jäsen %qD on alustamaton viittaus"
 
-#: cp/typeck2.c:1587
+#: cp/typeck2.c:1590
 #, fuzzy, gcc-internal-format
 #| msgid "type of %qD does not match original declaration"
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "%qD:n tyyppi ei täsmää aiemman esittelyn kanssa"
 
-#: cp/typeck2.c:1660
+#: cp/typeck2.c:1663
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "alustettavassa unionissa ei ole kenttää %qD"
 
-#: cp/typeck2.c:1671
+#: cp/typeck2.c:1674
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr ""
 
-#: cp/typeck2.c:1858
+#: cp/typeck2.c:1861
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr ""
 
-#: cp/typeck2.c:1872
+#: cp/typeck2.c:1875
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr ""
 
-#: cp/typeck2.c:1898
+#: cp/typeck2.c:1901
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr ""
 
-#: cp/typeck2.c:1900
+#: cp/typeck2.c:1903
 #, fuzzy, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "PRINT_OPERAND_ADDRESS, null-osoitin"
 
-#: cp/typeck2.c:1927
+#: cp/typeck2.c:1930
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr ""
 
-#: cp/typeck2.c:1936
+#: cp/typeck2.c:1939
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr ""
 
-#: cp/typeck2.c:1958
+#: cp/typeck2.c:1961
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2018
+#: cp/typeck2.c:2021
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "jäsenfunktio-osoitinta käytetty laskutoimituksessa"
 
-#: cp/typeck2.c:2029
+#: cp/typeck2.c:2032
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "jäsenfunktio-osoitinta käytetty laskutoimituksessa"
 
-#: cp/typeck2.c:2037
+#: cp/typeck2.c:2040
 #, fuzzy, gcc-internal-format
 #| msgid "pointer to member function used in arithmetic"
 msgid "pointer-to-member-function type %qT requires an lvalue before C++2a"
 msgstr "jäsenfunktio-osoitinta käytetty laskutoimituksessa"
 
-#: cp/typeck2.c:2080
+#: cp/typeck2.c:2083
 #, fuzzy, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "tyyppimuunnos määrittää taulukkotyypin"
 
-#: cp/typeck2.c:2096
+#: cp/typeck2.c:2099
 #, fuzzy, gcc-internal-format
 msgid "cannot deduce template arguments for %qT from ()"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/typeck2.c:2114
+#: cp/typeck2.c:2117
 #, fuzzy, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "virheellinen %qT-tyyppisen viittauksen alustus %qT-tyyppisestä lausekkeesta"
 
-#: cp/typeck2.c:2341
+#: cp/typeck2.c:2344
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr ""
 
-#: cp/typeck2.c:2344
+#: cp/typeck2.c:2347
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr ""
@@ -52505,11 +52565,11 @@
 msgstr "Taulukkoviitteellä kohdassa %C ei voi olla yli %d ulottuvuutta"
 
 #: fortran/array.c:221 fortran/array.c:661 fortran/check.c:2849
-#: fortran/check.c:5222 fortran/check.c:5260 fortran/check.c:5302
-#: fortran/check.c:5329 fortran/check.c:5529 fortran/match.c:1821
+#: fortran/check.c:5225 fortran/check.c:5263 fortran/check.c:5305
+#: fortran/check.c:5332 fortran/check.c:5532 fortran/match.c:1821
 #: fortran/match.c:3174 fortran/match.c:3516 fortran/match.c:3712
-#: fortran/simplify.c:2909 fortran/simplify.c:2939 fortran/simplify.c:5764
-#: fortran/simplify.c:7658
+#: fortran/simplify.c:2909 fortran/simplify.c:2939 fortran/simplify.c:5769
+#: fortran/simplify.c:7663
 #, gcc-internal-format
 msgid "Coarrays disabled at %C, use %<-fcoarray=%> to enable"
 msgstr ""
@@ -52645,99 +52705,104 @@
 msgid "DO-iterator %qs at %L is inside iterator of the same name"
 msgstr ""
 
-#: fortran/array.c:1073 fortran/array.c:1255
+#: fortran/array.c:1073 fortran/array.c:1264
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in array constructor at %C"
 msgstr "Syntaksivirhe taulukkomuodostimessa kohdassa %C"
 
-#: fortran/array.c:1129
+#: fortran/array.c:1105
 #, fuzzy, gcc-internal-format, gfc-internal-format
+msgid "NULL() at %C cannot appear in an array constructor"
+msgstr "ylivuoto vakiolausekkeessa"
+
+#: fortran/array.c:1138
+#, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "[...] style array constructors at %C"
 msgstr "Odotettiin taulukkoindeksiä kohdassa %C"
 
-#: fortran/array.c:1149
+#: fortran/array.c:1158
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array constructor including type specification at %C"
 msgstr "%qD esitelty extern-avainsanalla sisäkkäin"
 
-#: fortran/array.c:1155 fortran/match.c:4148
+#: fortran/array.c:1164 fortran/match.c:4148
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-spec at %L cannot contain a deferred type parameter"
 msgstr ""
 
-#: fortran/array.c:1163
+#: fortran/array.c:1172
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-spec at %L cannot contain an asterisk for a type parameter"
 msgstr ""
 
-#: fortran/array.c:1181
+#: fortran/array.c:1190
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty array constructor at %C is not allowed"
 msgstr "Tyhjä taulukkomuodostin kohdassa %C ei ole sallittu"
 
-#: fortran/array.c:1218 fortran/array.c:1228
+#: fortran/array.c:1227 fortran/array.c:1237
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "incompatible type for argument %d of %qE"
 msgid "Incompatible typespec for array element at %L"
 msgstr "Alkio %s-taulukkomuodostimessa kohdassa %L on %s"
 
-#: fortran/array.c:1302
+#: fortran/array.c:1311
 #, gcc-internal-format, gfc-internal-format
 msgid "Element in %s array constructor at %L is %s"
 msgstr "Alkio %s-taulukkomuodostimessa kohdassa %L on %s"
 
-#: fortran/array.c:1633
+#: fortran/array.c:1642
 #, gcc-internal-format, gfc-internal-format
 msgid "Iterator step at %L cannot be zero"
 msgstr "Iteraattoriaskel kohdassa %L ei voi olla nolla"
 
-#: fortran/array.c:1770
+#: fortran/array.c:1779
 #, gcc-internal-format
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit.   See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/array.c:1940
+#: fortran/array.c:1949
 #, gcc-internal-format, gfc-internal-format
 msgid "AC-IMPLIED-DO initial expression references control variable at %L"
 msgstr ""
 
-#: fortran/array.c:1947
+#: fortran/array.c:1956
 #, gcc-internal-format, gfc-internal-format
 msgid "AC-IMPLIED-DO final expression references control variable at %L"
 msgstr ""
 
-#: fortran/array.c:1954
+#: fortran/array.c:1963
 #, gcc-internal-format, gfc-internal-format
 msgid "AC-IMPLIED-DO step expression references control variable at %L"
 msgstr ""
 
-#: fortran/array.c:1966
+#: fortran/array.c:1975
 #, gcc-internal-format, gfc-internal-format
 msgid "Array constructor value at %L shall not be unlimited polymorphic [F2008: C4106]"
 msgstr ""
 
-#: fortran/array.c:2055
+#: fortran/array.c:2067
 #, gcc-internal-format, gfc-internal-format
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor at %L"
 msgstr ""
 
-#: fortran/array.c:2174
+#: fortran/array.c:2186
 #, gcc-internal-format
 msgid "spec_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2233
+#: fortran/array.c:2245
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2237
+#: fortran/array.c:2249
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad array dimension at %L"
 msgstr "Taulukkoviite rajojen ulkopuolella"
 
-#: fortran/array.c:2264 fortran/data.c:552 fortran/data.c:571
-#: fortran/data.c:585 fortran/data.c:714
+#: fortran/array.c:2276 fortran/data.c:563 fortran/data.c:582
+#: fortran/data.c:596 fortran/data.c:725
 #, fuzzy, gcc-internal-format
 msgid "Simplification error"
 msgstr ""
@@ -52744,22 +52809,22 @@
 " EPÄONNISTUI\n"
 "\n"
 
-#: fortran/array.c:2376
+#: fortran/array.c:2388
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimen_type"
 msgstr ""
 
-#: fortran/array.c:2427
+#: fortran/array.c:2439
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2472
+#: fortran/array.c:2484
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad EXPR_ARRAY expr"
 msgstr ""
 
-#: fortran/array.c:2620
+#: fortran/array.c:2632
 #, gcc-internal-format
 msgid "gfc_find_array_ref(): No ref found"
 msgstr ""
@@ -52818,7 +52883,7 @@
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or PROCEDURE"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on oltava INTEGER tai PROCEDURE"
 
-#: fortran/check.c:205 fortran/check.c:6658
+#: fortran/check.c:205 fortran/check.c:6661
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be a constant"
 msgid "%qs argument of %qs intrinsic at %L must be a constant"
@@ -52946,7 +53011,7 @@
 msgid "Unequal character lengths (%ld/%ld) in %s at %L"
 msgstr "Erisuuret merkkipituudet (%ld/%ld) merkkijonossa %s kohdassa %L"
 
-#: fortran/check.c:946 fortran/check.c:6602
+#: fortran/check.c:946 fortran/check.c:6605
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' and '%s' arguments of '%s' intrinsic at %L must have the same type"
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have the same type"
@@ -53191,9 +53256,9 @@
 msgstr "%<__builtin_args_info%>-funktion argumentin pitää olla vakio"
 
 #: fortran/check.c:1939 fortran/check.c:2525 fortran/check.c:2628
-#: fortran/check.c:2835 fortran/check.c:2880 fortran/check.c:4256
-#: fortran/check.c:4390 fortran/check.c:4445 fortran/check.c:5515
-#: fortran/check.c:5644
+#: fortran/check.c:2835 fortran/check.c:2880 fortran/check.c:4259
+#: fortran/check.c:4393 fortran/check.c:4448 fortran/check.c:5518
+#: fortran/check.c:5647
 #, fuzzy, gcc-internal-format
 msgid "%qs intrinsic with KIND argument at %L"
 msgstr "%qE-attribuutti soveltuu vain variadisiin funktioihin"
@@ -53402,7 +53467,7 @@
 msgid "NULL intrinsic with allocatable MOLD at %L"
 msgstr ""
 
-#: fortran/check.c:3768 fortran/check.c:5591
+#: fortran/check.c:3768 fortran/check.c:5594
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be the same type and kind as '%s'"
 msgid "%qs argument of %qs intrinsic at %L must provide at least as many elements as there are .TRUE. values in %qs (%ld/%d)"
@@ -53426,391 +53491,391 @@
 msgid "%qs argument of %qs intrinsic at %L must not be a subobject of %qs"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentti ”%1$s” kohdassa %3$L ”ei saa olla ”%4$s”:n aliobjekti"
 
-#: fortran/check.c:3901
+#: fortran/check.c:3904
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The argument of the RANK intrinsic at %L must be a data object"
 msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 
-#: fortran/check.c:4005
+#: fortran/check.c:4008
 #, fuzzy, gcc-internal-format
 #| msgid "'shape' argument of 'reshape' intrinsic at %L must be an array of constant size"
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L must be an array of constant size"
 msgstr "kääntäjänsisäisen ”reshape”-funktion argumentti ”shape” kohdassa %L ei saa olla vakiokokoinen taulukko"
 
-#: fortran/check.c:4015
+#: fortran/check.c:4018
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L is empty"
 msgid "%qs argument of %qs intrinsic at %L is empty"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on tyhjä"
 
-#: fortran/check.c:4022
+#: fortran/check.c:4025
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L has negative element (%d)"
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L has more than %d elements"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentilla ”%1$s” kohdassa %3$L on negatiivinen alkio (%4$d)"
 
-#: fortran/check.c:4039
+#: fortran/check.c:4042
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L has negative element (%d)"
 msgid "%qs argument of %qs intrinsic at %L has negative element (%d)"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentilla ”%1$s” kohdassa %3$L on negatiivinen alkio (%4$d)"
 
-#: fortran/check.c:4071
+#: fortran/check.c:4074
 #, gcc-internal-format, gfc-internal-format
 msgid "Element %d of actual argument of RESHAPE at %L cannot be negative"
 msgstr ""
 
-#: fortran/check.c:4109
+#: fortran/check.c:4112
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L has wrong number of elements (%d/%d)"
 msgid "%qs argument of %qs intrinsic at %L has wrong number of elements (%d/%d)"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on väärä määrä alkioita (%4$d/%5$d)"
 
-#: fortran/check.c:4127
+#: fortran/check.c:4130
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L has out-of-range dimension (%d)"
 msgid "%qs argument of %qs intrinsic at %L has out-of-range dimension (%d)"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on lukualueen ulkopuolinen ulottuvuus (%4$d)"
 
-#: fortran/check.c:4136
+#: fortran/check.c:4139
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L has invalid permutation of dimensions (dimension '%d' duplicated)"
 msgid "%qs argument of %qs intrinsic at %L has invalid permutation of dimensions (dimension %qd duplicated)"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on virheellinen ulottuvuuksia permutaatio (ulottuvuus ”%4$d” kahteen kertaan)"
 
-#: fortran/check.c:4172
+#: fortran/check.c:4175
 #, gcc-internal-format, gfc-internal-format
 msgid "Without padding, there are not enough elements in the intrinsic RESHAPE source at %L to match the shape"
 msgstr ""
 
-#: fortran/check.c:4189 fortran/check.c:4208
+#: fortran/check.c:4192 fortran/check.c:4211
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L cannot be of type %s"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on oltava %4$s"
 
-#: fortran/check.c:4199 fortran/check.c:4218
+#: fortran/check.c:4202 fortran/check.c:4221
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be of an extensible type"
 msgid "%qs argument of %qs intrinsic at %L must be of an extensible type"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on oltava laajennettavaa tyyppiä"
 
-#: fortran/check.c:4317
+#: fortran/check.c:4320
 #, gcc-internal-format
 msgid "SELECTED_REAL_KIND with neither %<P%> nor %<R%> argument at %L"
 msgstr ""
 
-#: fortran/check.c:4348
+#: fortran/check.c:4351
 #, fuzzy, gcc-internal-format
 msgid "%qs intrinsic with RADIX argument at %L"
 msgstr "%qE-attribuutti soveltuu vain variadisiin funktioihin"
 
-#: fortran/check.c:4383
+#: fortran/check.c:4386
 #, fuzzy, gcc-internal-format
 #| msgid "'source' argument of 'shape' intrinsic at %L must not be an assumed size array"
 msgid "%<source%> argument of %<shape%> intrinsic at %L must not be an assumed size array"
 msgstr "kääntäjänsisäisen ”shape”-funktion argumentti ”source” kohdassa %L ei saa olla oletetun kokoinen taulukko"
 
-#: fortran/check.c:4460 fortran/check.c:6641
+#: fortran/check.c:4463 fortran/check.c:6644
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be a procedure"
 msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 
-#: fortran/check.c:4473 fortran/check.c:4612 fortran/check.c:6633
+#: fortran/check.c:4476 fortran/check.c:4615 fortran/check.c:6636
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be TYPE(*)"
 msgstr "%<__builtin_args_info%>-funktion argumentin pitää olla vakio"
 
-#: fortran/check.c:4484 fortran/check.c:4624
+#: fortran/check.c:4487 fortran/check.c:4627
 #, fuzzy, gcc-internal-format
 #| msgid "'source' argument of 'shape' intrinsic at %L must not be an assumed size array"
 msgid "%qs argument of %qs intrinsic at %L shall not be an assumed-size array"
 msgstr "kääntäjänsisäisen ”shape”-funktion argumentti ”source” kohdassa %L ei saa olla oletetun kokoinen taulukko"
 
-#: fortran/check.c:4554
+#: fortran/check.c:4557
 #, gcc-internal-format
 msgid "is_c_interoperable(): gfc_simplify_expr failed"
 msgstr ""
 
-#: fortran/check.c:4603
+#: fortran/check.c:4606
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be an interoperable data entity: %s"
 msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 
-#: fortran/check.c:4642
+#: fortran/check.c:4645
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_1 at %L to C_ASSOCIATED shall have the type TYPE(C_PTR) or TYPE(C_FUNPTR)"
 msgstr ""
 
-#: fortran/check.c:4656
+#: fortran/check.c:4659
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_2 at %L to C_ASSOCIATED shall have the same type as C_PTR_1: %s instead of %s"
 msgstr ""
 
-#: fortran/check.c:4680
+#: fortran/check.c:4683
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_POINTER shall have the type TYPE(C_PTR)"
 msgstr ""
 
-#: fortran/check.c:4692
+#: fortran/check.c:4695
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER must be a pointer"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: fortran/check.c:4699
+#: fortran/check.c:4702
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FPTR argument at %L to C_F_POINTER shall not be polymorphic"
 msgstr "Tämänhetkisen argumentin kohteelle ”%s” on oltava osoitin kohdassa %L"
 
-#: fortran/check.c:4706
+#: fortran/check.c:4709
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER shall not be coindexed"
 msgstr "%<__builtin_args_info%>-funktion argumentin pitää olla vakio"
 
-#: fortran/check.c:4713
+#: fortran/check.c:4716
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected SHAPE argument at %L to C_F_POINTER with scalar FPTR"
 msgstr ""
 
-#: fortran/check.c:4719
+#: fortran/check.c:4722
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected SHAPE argument to C_F_POINTER with array FPTR at %L"
 msgstr ""
 
-#: fortran/check.c:4738
+#: fortran/check.c:4741
 #, gcc-internal-format, gfc-internal-format
 msgid "SHAPE argument at %L to C_F_POINTER must have the same size as the RANK of FPTR"
 msgstr ""
 
-#: fortran/check.c:4748
+#: fortran/check.c:4751
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic FPTR at %L to C_F_POINTER"
 msgstr ""
 
-#: fortran/check.c:4753
+#: fortran/check.c:4756
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array FPTR at %L to C_F_POINTER: %s"
 msgstr ""
 
-#: fortran/check.c:4769
+#: fortran/check.c:4772
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_PROCPOINTER shall have the type TYPE(C_FUNPTR)"
 msgstr ""
 
-#: fortran/check.c:4781
+#: fortran/check.c:4784
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall be a procedure pointer"
 msgstr ""
 
-#: fortran/check.c:4788
+#: fortran/check.c:4791
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall not be coindexed"
 msgstr "%<__builtin_args_info%>-funktion argumentin pitää olla vakio"
 
-#: fortran/check.c:4794
+#: fortran/check.c:4797
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure pointer at %L to C_F_PROCPOINTER"
 msgstr ""
 
-#: fortran/check.c:4808
+#: fortran/check.c:4811
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall not be coindexed"
 msgstr "%<__builtin_args_info%>-funktion argumentin pitää olla vakio"
 
-#: fortran/check.c:4823
+#: fortran/check.c:4826
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L is invalid as X argument to C_FUNLOC"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/check.c:4831
+#: fortran/check.c:4834
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall be a procedure or a procedure pointer"
 msgstr ""
 
-#: fortran/check.c:4837
+#: fortran/check.c:4840
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure at %L to C_FUNLOC"
 msgstr "Proseduuri ”%s” kohdassa %C on jo määritelty kohdassa %L"
 
-#: fortran/check.c:4851
+#: fortran/check.c:4854
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall not be coindexed"
 msgstr "%<__builtin_args_info%>-funktion argumentin pitää olla vakio"
 
-#: fortran/check.c:4857
+#: fortran/check.c:4860
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "X argument at %L to C_LOC shall not be polymorphic"
 msgstr "Tämänhetkisen argumentin kohteelle ”%s” on oltava osoitin kohdassa %L"
 
-#: fortran/check.c:4868
+#: fortran/check.c:4871
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall have either the POINTER or the TARGET attribute"
 msgstr ""
 
-#: fortran/check.c:4876
+#: fortran/check.c:4879
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall be not be a zero-sized string"
 msgstr "%qs ei ole kelpo tulostetiedosto"
 
-#: fortran/check.c:4885
+#: fortran/check.c:4888
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument at %L to C_LOC shall not be polymorphic"
 msgstr "Tämänhetkisen argumentin kohteelle ”%s” on oltava osoitin kohdassa %L"
 
-#: fortran/check.c:4892
+#: fortran/check.c:4895
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array at %L as argument to C_LOC: %s"
 msgstr "liikaa argumentteja funktiolle %s %q+#D"
 
-#: fortran/check.c:4903
+#: fortran/check.c:4906
 #, gcc-internal-format, gfc-internal-format
 msgid "Array of interoperable type at %L to C_LOC which is nonallocatable and neither assumed size nor explicit size"
 msgstr ""
 
-#: fortran/check.c:4908
+#: fortran/check.c:4911
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array section at %L to C_LOC"
 msgstr "%Jlohkoattribuutti ei ole sallittu %qD:lle"
 
-#: fortran/check.c:4936
+#: fortran/check.c:4939
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "non double precision REAL argument to %s intrinsic at %L"
 msgstr "%<__builtin_args_info%>-funktion argumentti puuttuu"
 
-#: fortran/check.c:4949
+#: fortran/check.c:4952
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be of rank %d"
 msgid "%qs argument of %qs intrinsic at %L must be less than rank %d"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on oltava %4$d tasoa"
 
-#: fortran/check.c:4968
+#: fortran/check.c:4971
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L is not a valid dimension index"
 msgid "%qs argument of %qs intrinsic at %L is not a valid dimension index"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentti ”%1$s” kohdassa %3$L ei ole kelvollinen ulottuvuusindeksi"
 
-#: fortran/check.c:5231
+#: fortran/check.c:5234
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s argument to IMAGE_INDEX must be a rank one array at %L"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: fortran/check.c:5242
+#: fortran/check.c:5245
 #, gcc-internal-format, gfc-internal-format
 msgid "The number of array elements of the SUB argument to IMAGE_INDEX at %L shall be %d (corank) not %d"
 msgstr ""
 
-#: fortran/check.c:5275
+#: fortran/check.c:5278
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to NUM_IMAGES at %L"
 msgstr ""
 
-#: fortran/check.c:5288
+#: fortran/check.c:5291
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FAILED= argument to NUM_IMAGES at %L"
 msgstr "%<__builtin_args_info%>-funktion argumentti puuttuu"
 
-#: fortran/check.c:5312
+#: fortran/check.c:5315
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "TEAM argument at %L to the intrinsic TEAM_NUMBER shall be of type TEAM_TYPE"
 msgstr "%<__builtin_args_info%>-funktion argumentin pitää olla vakio"
 
-#: fortran/check.c:5338
+#: fortran/check.c:5341
 #, gcc-internal-format, gfc-internal-format
 msgid "DIM argument without COARRAY argument not allowed for THIS_IMAGE intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:5345
+#: fortran/check.c:5348
 #, gcc-internal-format, gfc-internal-format
 msgid "The DISTANCE argument may not be specified together with the COARRAY or DIM argument in intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:5356
+#: fortran/check.c:5359
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk in formal argument list at %C"
 msgid "Unexpected DIM argument with noncoarray argument at %L"
 msgstr "Odottamatonta roskaa muodollisessa argumenttiluettelossa kohdassa %C"
 
-#: fortran/check.c:5374
+#: fortran/check.c:5377
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to THIS_IMAGE at %L"
 msgstr "Funktion %s argumentti kohdassa %L on negatiivinen"
 
-#: fortran/check.c:5454
+#: fortran/check.c:5457
 #, fuzzy, gcc-internal-format
 #| msgid "'MOLD' argument of 'TRANSFER' intrinsic at %L must not be %s"
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L must not be %s"
 msgstr "kääntäjänsisäisen ”TRANSFER”-funktion argumentti ”MOLD” kohdassa %L ei saa olla %s"
 
-#: fortran/check.c:5483
+#: fortran/check.c:5486
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic TRANSFER at %L has partly undefined result: source size %ld < result size %ld"
 msgstr ""
 
-#: fortran/check.c:5605
+#: fortran/check.c:5608
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must have the same rank as '%s' or be a scalar"
 msgid "%qs argument of %qs intrinsic at %L must have the same rank as %qs or be a scalar"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on oltava samaa tasoa kuin ”%4$s” tai sen on oltava skalaari"
 
-#: fortran/check.c:5618
+#: fortran/check.c:5621
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' and '%s' arguments of '%s' intrinsic at %L must have identical shape."
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have identical shape."
 msgstr "kääntäjänsisäisen ”%3$s”-funktion argumenttien ”%1$s” ja ”%2$s” kohdassa %4$L on oltava muodoltaan identtisiä."
 
-#: fortran/check.c:5861 fortran/check.c:5893
+#: fortran/check.c:5864 fortran/check.c:5896
 #, fuzzy, gcc-internal-format
 #| msgid "Size of '%s' argument of '%s' intrinsic at %L too small (%i/%i)"
 msgid "Size of %qs argument of %qs intrinsic at %L too small (%i/%i)"
 msgstr "Kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” koko kohdassa %3$L on liian pieni (%4$i/%5$i)"
 
-#: fortran/check.c:5901
+#: fortran/check.c:5904
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many arguments to %s at %L"
 msgstr "Liikaa argumentteja funktiolle %s kohdassa %L"
 
-#: fortran/check.c:5919
+#: fortran/check.c:5922
 #, gcc-internal-format
 msgid "fe_runtime_error string must be null terminated"
 msgstr ""
 
-#: fortran/check.c:5931
+#: fortran/check.c:5934
 #, gcc-internal-format, gfc-internal-format
 msgid "fe_runtime_error: Wrong number of arguments (%d instead of %d)"
 msgstr ""
 
-#: fortran/check.c:5971
+#: fortran/check.c:5974
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:5990
+#: fortran/check.c:5993
 #, gcc-internal-format, gfc-internal-format
 msgid "Real COUNT_RATE argument to SYSTEM_CLOCK at %L"
 msgstr ""
 
-#: fortran/check.c:6000
+#: fortran/check.c:6003
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT_RATE argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:6017
+#: fortran/check.c:6020
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT_MAX argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:6234
+#: fortran/check.c:6237
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be of kind %d"
 msgid "%qs argument of %qs intrinsic at %L must be of a kind not wider than the default kind (%d)"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on oltava %4$d:n kaltainen"
 
-#: fortran/check.c:6586 fortran/check.c:6594
+#: fortran/check.c:6589 fortran/check.c:6597
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L must be INTEGER or LOGICAL"
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or LOGICAL"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on oltava INTEGER tai LOGICAL"
 
-#: fortran/check.c:6625
+#: fortran/check.c:6628
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic function NULL at %L cannot be an actual argument to STORAGE_SIZE, because it returns a disassociated pointer"
 msgstr ""
@@ -53822,7 +53887,7 @@
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:727 fortran/decl.c:3636 fortran/decl.c:10066
+#: fortran/class.c:727 fortran/decl.c:3655 fortran/decl.c:10091
 #, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr ""
@@ -53849,44 +53914,49 @@
 msgid "non-constant array in DATA statement %L"
 msgstr ""
 
-#: fortran/data.c:137
+#: fortran/data.c:140
 #, gcc-internal-format, gfc-internal-format
 msgid "failure to simplify substring reference in DATA statement at %L"
 msgstr ""
 
-#: fortran/data.c:170
+#: fortran/data.c:173
 #, gcc-internal-format, gfc-internal-format
 msgid "Unused initialization string at %L because variable has zero length"
 msgstr ""
 
-#: fortran/data.c:176
+#: fortran/data.c:179
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Initialization string at %L was truncated to fit the variable (%ld/%ld)"
 msgstr "alustusmerkkijono typistetty, jotta se täsmäisi muuttujaan kohdassa %L"
 
-#: fortran/data.c:265
+#: fortran/data.c:268
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L already is initialized at %L"
 msgid "%qs at %L already is initialized at %L"
 msgstr "”%s” kohdassa %L on jo alustettu kohdassa %L"
 
-#: fortran/data.c:289
+#: fortran/data.c:292
 #, gcc-internal-format, gfc-internal-format
 msgid "Data element below array lower bound at %L"
 msgstr "Data-alkio taulukon alarajan alapuolella kohdassa %L"
 
-#: fortran/data.c:306 fortran/data.c:395
+#: fortran/data.c:309 fortran/data.c:398
 #, gcc-internal-format, gfc-internal-format
 msgid "Data element above array upper bound at %L"
 msgstr "Data-alkio taulukon ylärajan yläpuolella kohdassa %L"
 
-#: fortran/data.c:336 fortran/data.c:505
+#: fortran/data.c:339 fortran/data.c:496
 #, fuzzy, gcc-internal-format
 msgid "re-initialization of %qs at %L"
 msgstr "(%qs:n alustuksen lähistöllä)"
 
-#: fortran/data.c:727
+#: fortran/data.c:515
 #, gcc-internal-format
+msgid "Nonpointer object %qs with default initialization shall not appear in a DATA statement at %L"
+msgstr ""
+
+#: fortran/data.c:738
+#, gcc-internal-format
 msgid "TODO: Vector sections in data statements"
 msgstr ""
 
@@ -53913,813 +53983,812 @@
 msgid "Invalid initializer %s in Data statement at %C"
 msgstr "Virheellinen alustin %s Data-lauseessa kohdassa %C"
 
-#: fortran/decl.c:536
+#: fortran/decl.c:537
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C is not allowed in a PURE procedure"
 msgstr "Alustus kohdassa %C ei ole sallittu PURE-proseduurissa"
 
-#: fortran/decl.c:573
+#: fortran/decl.c:574
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "DATA statement at %C is not allowed in a PURE procedure"
 msgid "DATA statement at %C cannot appear within an INTERFACE"
 msgstr "DATA-lause kohdassa %C ei ole sallittu PURE-proseduurissa"
 
-#: fortran/decl.c:597
+#: fortran/decl.c:598
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid initializer %s in Data statement at %C"
 msgid "Invalid substring in data-implied-do at %L in DATA statement"
 msgstr "Virheellinen alustin %s Data-lauseessa kohdassa %C"
 
-#: fortran/decl.c:619
+#: fortran/decl.c:620
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %C is not allowed in a PURE procedure"
 msgstr "DATA-lause kohdassa %C ei ole sallittu PURE-proseduurissa"
 
-#: fortran/decl.c:664
+#: fortran/decl.c:662
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Empty old style initializer list at %C"
 msgstr "vanhanmallinen funktiomäärittely"
 
-#: fortran/decl.c:684
+#: fortran/decl.c:671
 #, fuzzy, gcc-internal-format, gfc-internal-format
+msgid "Array in initializer list at %L must have an explicit shape"
+msgstr "muuttuvakokoista objektia ei voi alustaa"
+
+#: fortran/decl.c:694
+#, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "extra elements in scalar initializer"
 msgid "Repeat spec invalid in scalar initializer at %C"
 msgstr "skalaarialustimessa ylimääräisiä alkioita"
 
-#: fortran/decl.c:689
+#: fortran/decl.c:699
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Repeat spec must be an integer at %C"
 msgstr "haluttu sijainti ei ole kokonaislukuvakio"
 
-#: fortran/decl.c:698
+#: fortran/decl.c:710
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected alternate return label at %C"
 msgid "Expected data constant after repeat spec at %C"
 msgstr "Odotettiin vaihtoehtoista paluunimiötä kohdassa %C"
 
-#: fortran/decl.c:729
+#: fortran/decl.c:742
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected scalar initialization expression at %C"
 msgid "End of scalar initializer expected at %C"
 msgstr "Odotettiin skalaarialustuslauseketta kohdassa %C"
 
-#: fortran/decl.c:758
+#: fortran/decl.c:773
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "nonconstant array index in initializer"
-msgid "Expected constant array-spec in initializer list at %L"
-msgstr "ei-vakio taulukkoindeksi alustimessa"
-
-#: fortran/decl.c:767
-#, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "excess elements in array initializer"
 msgid "Not enough elements in array initializer at %C"
 msgstr "ylimääräisiä alkioita taulukkoalustimessa"
 
-#: fortran/decl.c:769
+#: fortran/decl.c:775
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "excess elements in array initializer"
 msgid "Too many elements in array initializer at %C"
 msgstr "ylimääräisiä alkioita taulukkoalustimessa"
 
-#: fortran/decl.c:790
+#: fortran/decl.c:795
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in old style initializer list at %C"
 msgstr "Syntaksivirhe argumenttiluettelossa kohdassa %C"
 
-#: fortran/decl.c:812
+#: fortran/decl.c:821
 #, gcc-internal-format, gfc-internal-format
 msgid "The assumed-rank array at %C shall not have a codimension"
 msgstr ""
 
-#: fortran/decl.c:876
+#: fortran/decl.c:885
 #, gcc-internal-format, gfc-internal-format
 msgid "Sum of array rank %d and corank %d at %C exceeds maximum allowed dimensions of %d"
 msgstr ""
 
-#: fortran/decl.c:900
+#: fortran/decl.c:909
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad INTENT specification at %C"
 msgstr "Kaksoiskappale %s-spesifikaatio kohdassa %C"
 
-#: fortran/decl.c:921
+#: fortran/decl.c:930
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "deferred type parameter at %C"
 msgstr "virheellinen parametrityyppi %qT"
 
-#: fortran/decl.c:1004 fortran/resolve.c:11705
+#: fortran/decl.c:1013 fortran/resolve.c:11725
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr "odotettiin kokonaislukulauseketta"
 
-#: fortran/decl.c:1030
+#: fortran/decl.c:1039
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Old-style character length at %C"
 msgstr "Syntaksivirhe merkkipituusspesifikaatiossa kohdassa %C"
 
-#: fortran/decl.c:1061
+#: fortran/decl.c:1070
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in character length specification at %C"
 msgstr "Syntaksivirhe merkkipituusspesifikaatiossa kohdassa %C"
 
-#: fortran/decl.c:1212 fortran/decl.c:1217 fortran/decl.c:1266
+#: fortran/decl.c:1221 fortran/decl.c:1226 fortran/decl.c:1275
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %C is already defined at %L"
 msgid "Procedure %qs at %C is already defined at %L"
 msgstr "Proseduuri ”%s” kohdassa %C on jo määritelty kohdassa %L"
 
-#: fortran/decl.c:1222
+#: fortran/decl.c:1231
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %C is already defined at %L"
 msgid "Contained procedure %qs at %C clashes with procedure defined at %L"
 msgstr "Proseduuri ”%s” kohdassa %C on jo määritelty kohdassa %L"
 
-#: fortran/decl.c:1231
+#: fortran/decl.c:1240
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is already defined as a generic interface at %L"
 msgid "Name %qs at %C is already defined as a generic interface at %L"
 msgstr "Nimi ”%s” kohdassa %C on jo määritelty geneerisenä rajapintana kohdassa %L"
 
-#: fortran/decl.c:1244
+#: fortran/decl.c:1253
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %C has an explicit interface and must not have attributes declared at %L"
 msgid "Procedure %qs at %C has an explicit interface from a previous declaration"
 msgstr "Proseduurilla ”%s” kohdassa %C on eksplisiittinen rajapinta ja sillä ei saa olla attribuutteja, jotka on esitelty kohdassa %L"
 
-#: fortran/decl.c:1257
+#: fortran/decl.c:1266
 #, gcc-internal-format
 msgid "Procedure %qs defined in interface body at %L clashes with internal procedure defined at %C"
 msgstr ""
 
-#: fortran/decl.c:1335
+#: fortran/decl.c:1344
 #, gcc-internal-format
 msgid "Procedure %qs at %L must have the BIND(C) attribute to be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:1362
+#: fortran/decl.c:1371
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because derived type %qs is not C interoperable"
 msgstr ""
 
-#: fortran/decl.c:1369
+#: fortran/decl.c:1378
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because it is polymorphic"
 msgstr ""
 
-#: fortran/decl.c:1376
+#: fortran/decl.c:1385
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument of the BIND(C) procedure %qs but may not be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:1391
+#: fortran/decl.c:1400
 #, gcc-internal-format
 msgid "Character argument %qs at %L must be length 1 because procedure %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1404
+#: fortran/decl.c:1413
 #, gcc-internal-format
 msgid "Variable %qs at %L with ALLOCATABLE attribute in procedure %qs with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1412
+#: fortran/decl.c:1421
 #, gcc-internal-format
 msgid "Variable %qs at %L with POINTER attribute in procedure %qs with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1421
+#: fortran/decl.c:1430
 #, gcc-internal-format
 msgid "Scalar variable %qs at %L with POINTER or ALLOCATABLE in procedure %qs with BIND(C) is not yet supported"
 msgstr ""
 
-#: fortran/decl.c:1430
+#: fortran/decl.c:1439
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
 msgid "Variable %qs at %L cannot have both the OPTIONAL and the VALUE attribute because procedure %qs is BIND(C)"
 msgstr "Muuttujalla ”%s” kohdassa %L ei voi olla sekä POINTER- että BIND(C)-attribuutit"
 
-#: fortran/decl.c:1437
+#: fortran/decl.c:1446
 #, gcc-internal-format
 msgid "Variable %qs at %L with OPTIONAL attribute in procedure %qs which is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1448
+#: fortran/decl.c:1457
 #, gcc-internal-format
 msgid "Assumed-shape array %qs at %L as dummy argument to the BIND(C) procedure %qs at %L"
 msgstr ""
 
-#: fortran/decl.c:1516
+#: fortran/decl.c:1525
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L may not have basic type of %s"
 msgid "Symbol %qs at %C also declared as a type at %L"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/decl.c:1575
+#: fortran/decl.c:1584
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %C must be declared with a C interoperable kind since common block %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1615
+#: fortran/decl.c:1624
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER length must be a constant at %L"
 msgstr "Odotettiin PARAMETER-symbolia kompleksivakiossa kohdassa %C"
 
-#: fortran/decl.c:1630
+#: fortran/decl.c:1639
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CHARACTER expression at %L is being truncated (%d/%d)"
 msgid "CHARACTER expression at %L is being truncated (%ld/%ld)"
 msgstr "CHARACTER-lauseke kohdassa %L on typistetty (%d/%d)"
 
-#: fortran/decl.c:1638
+#: fortran/decl.c:1647
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The CHARACTER elements of the array constructor at %L must have the same length (%d/%d)"
 msgid "The CHARACTER elements of the array constructor at %L must have the same length (%ld/%ld)"
 msgstr "Taulukkomuodostimen CHARACTER-alkioiden kohdassa %L on oltava saman pituisia (%d/%d)"
 
-#: fortran/decl.c:1729
+#: fortran/decl.c:1738
 #, gcc-internal-format
 msgid "Initializer not allowed for PARAMETER %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:1739
+#: fortran/decl.c:1748
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER at %L is missing an initializer"
 msgstr "PARAMETER kohdassa %L on ilman alustinta"
 
-#: fortran/decl.c:1749
+#: fortran/decl.c:1758
 #, gcc-internal-format
 msgid "Variable %qs at %C with an initializer already appears in a DATA statement"
 msgstr ""
 
-#: fortran/decl.c:1792
+#: fortran/decl.c:1801
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot initialize parameter array at %L with variable length elements"
 msgstr ""
 
-#: fortran/decl.c:1861
+#: fortran/decl.c:1870
 #, gcc-internal-format, gfc-internal-format
 msgid "Can't initialize implied-shape array at %L with scalar"
 msgstr ""
 
-#: fortran/decl.c:1896
+#: fortran/decl.c:1905
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-constant lower bound in implied-shape declaration at %L"
 msgstr "%qD esitelty extern-avainsanalla sisäkkäin"
 
-#: fortran/decl.c:1982 fortran/decl.c:1989
+#: fortran/decl.c:1991 fortran/decl.c:1998
 #, gcc-internal-format, gfc-internal-format
 msgid "Component at %C must have the POINTER attribute"
 msgstr ""
 
-#: fortran/decl.c:1998
+#: fortran/decl.c:2007
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L must have at least two arguments"
 msgid "Component %qs with CLASS at %C must be allocatable or pointer"
 msgstr "Kääntäjänsisäisellä ”%s”-funktiolla kohdassa %L on oltava vähintään kaksi argumenttia"
 
-#: fortran/decl.c:2007
+#: fortran/decl.c:2016
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr ""
 
-#: fortran/decl.c:2031 fortran/symbol.c:2230
+#: fortran/decl.c:2040 fortran/symbol.c:2244
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %C is already defined at %L"
 msgid "Component %qs at %C already declared at %L"
 msgstr "Proseduuri ”%s” kohdassa %C on jo määritelty kohdassa %L"
 
-#: fortran/decl.c:2079
+#: fortran/decl.c:2088
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer array component of structure at %C must have a deferred shape"
 msgstr ""
 
-#: fortran/decl.c:2088
+#: fortran/decl.c:2097
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component of structure at %C must have a deferred shape"
 msgstr ""
 
-#: fortran/decl.c:2097
+#: fortran/decl.c:2106
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have an explicit shape"
 msgstr ""
 
-#: fortran/decl.c:2114
+#: fortran/decl.c:2123
 #, fuzzy, gcc-internal-format
 #| msgid "a parameter list with an ellipsis can%'t match an empty parameter name list declaration"
 msgid "Type parameter %qs at %C has no corresponding entry in the type parameter name list at %L"
 msgstr "kolme pistettä sisältävä parametriluettelo ei sovellu tyhjään parametrinimiluettelon esittelyyn"
 
-#: fortran/decl.c:2171
+#: fortran/decl.c:2180
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C is ambiguous"
 msgstr "NULL()-alustus kohdassa %C on moniselitteinen"
 
-#: fortran/decl.c:2188
+#: fortran/decl.c:2197
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C may not have MOLD"
 msgstr ""
 
-#: fortran/decl.c:2205
+#: fortran/decl.c:2214
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Initialization of pointer at %C is not allowed in a PURE procedure"
 msgstr "Alustus kohdassa %C ei ole sallittu PURE-proseduurissa"
 
-#: fortran/decl.c:2226
+#: fortran/decl.c:2235
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Error in pointer initialization at %C"
 msgstr "Alustus kohdassa %C ei ole osoitinmuuttuja"
 
-#: fortran/decl.c:2233
+#: fortran/decl.c:2242
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "non-NULL pointer initialization at %C"
 msgstr "NULL()-alustus kohdassa %C on moniselitteinen"
 
-#: fortran/decl.c:2256
+#: fortran/decl.c:2265
 #, gcc-internal-format
 msgid "RESULT variable %qs at %L prohibits FUNCTION name %qs at %C from appearing in a specification statement"
 msgstr ""
 
-#: fortran/decl.c:2318
+#: fortran/decl.c:2327
 #, fuzzy, gcc-internal-format
 msgid "%qs not allowed outside STRUCTURE at %C"
 msgstr "Odottamaton %s-lause INTERFACE-lohkossa kohdassa %C"
 
-#: fortran/decl.c:2320
+#: fortran/decl.c:2329
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qD"
 msgid "%qs at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr "Jäsenfunktio %qs"
 
-#: fortran/decl.c:2327
+#: fortran/decl.c:2336
 #, fuzzy, gcc-internal-format
 msgid "%qs entity cannot have attributes at %C"
 msgstr "%qD:lla ei voi olla oletusargumentteja"
 
-#: fortran/decl.c:2367
+#: fortran/decl.c:2376
 #, gcc-internal-format
 msgid "Non-PARAMETER symbol %qs at %L can't be implied-shape"
 msgstr ""
 
-#: fortran/decl.c:2377
+#: fortran/decl.c:2386
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Implied-shape array at %L"
 msgstr "Alkio %s-taulukkomuodostimessa kohdassa %L on %s"
 
-#: fortran/decl.c:2422
+#: fortran/decl.c:2431
 #, gcc-internal-format, gfc-internal-format
 msgid "Explicit shaped array with nonconstant bounds at %C"
 msgstr ""
 
-#: fortran/decl.c:2501
+#: fortran/decl.c:2510
 #, gcc-internal-format
 msgid "%qs at %C is a redefinition of the declaration in the corresponding interface for MODULE PROCEDURE %qs"
 msgstr ""
 
-#: fortran/decl.c:2512
+#: fortran/decl.c:2521
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "%qs entity cannot have an initializer at %C"
 msgstr "Tyhjällä ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/decl.c:2538 fortran/decl.c:8369
+#: fortran/decl.c:2547 fortran/decl.c:8388
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr ""
 
-#: fortran/decl.c:2546
+#: fortran/decl.c:2555
 #, gcc-internal-format
 msgid "Couldn't set pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:2609
+#: fortran/decl.c:2618
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Old-style initialization at %C"
 msgstr "vanhanmallinen funktiomäärittely"
 
-#: fortran/decl.c:2617
+#: fortran/decl.c:2626
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr "virheellinen %qT-tyyppisen viittauksen alustus %qT-tyyppisestä lausekkeesta"
 
-#: fortran/decl.c:2630
+#: fortran/decl.c:2639
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in old style initialization of %s at %C"
 msgstr "Alustus kohdassa %C ei ole osoitinmuuttuja"
 
-#: fortran/decl.c:2650 fortran/decl.c:6661
+#: fortran/decl.c:2659 fortran/decl.c:6680
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr "Alustus kohdassa %C ei ole osoitinmuuttuja"
 
-#: fortran/decl.c:2663
+#: fortran/decl.c:2672
 #, fuzzy, gcc-internal-format
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr "Alustus kohdassa %C ei ole osoitinmuuttuja"
 
-#: fortran/decl.c:2672 fortran/decl.c:10240
+#: fortran/decl.c:2681 fortran/decl.c:10265
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr "Odotettiin alustuslauseketta kohdassa %C"
 
-#: fortran/decl.c:2679
+#: fortran/decl.c:2688
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr "Muuttujan alustus kohdassa %C ei ole sallittu PURE-proseduurissa"
 
-#: fortran/decl.c:2696
+#: fortran/decl.c:2705
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr "Alustus kohdassa %C ei ole sallittu PURE-proseduurissa"
 
-#: fortran/decl.c:2710
+#: fortran/decl.c:2719
 #, gcc-internal-format, gfc-internal-format
 msgid "The component with KIND or LEN attribute at %C does not not appear in the type parameter list at %L"
 msgstr ""
 
-#: fortran/decl.c:2718
+#: fortran/decl.c:2727
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C that appears in the type parameter list at %L has neither the KIND nor LEN attribute"
 msgstr ""
 
-#: fortran/decl.c:2726
+#: fortran/decl.c:2735
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C which is a type parameter must be a scalar"
 msgstr ""
 
-#: fortran/decl.c:2789 fortran/decl.c:2825
+#: fortran/decl.c:2798 fortran/decl.c:2834
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr "Vanhantyylinen esittely %s*%d ei ole tuettu kohdassa %C"
 
-#: fortran/decl.c:2831
+#: fortran/decl.c:2840
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr "Ei-vakio tyyppiesittely %s*%d kohdassa %C"
 
-#: fortran/decl.c:2890 fortran/decl.c:2967
+#: fortran/decl.c:2899 fortran/decl.c:2976
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis at %C"
 msgstr "Puuttuva oikea sulje kohdassa %C"
 
-#: fortran/decl.c:2903 fortran/decl.c:3038
+#: fortran/decl.c:2912 fortran/decl.c:3047
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr "Odotettiin alustuslauseketta kohdassa %C"
 
-#: fortran/decl.c:2911 fortran/decl.c:3044
+#: fortran/decl.c:2920 fortran/decl.c:3053
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr "Odotettiin skalaarialustuslauseketta kohdassa %C"
 
-#: fortran/decl.c:2941 fortran/decl.c:3657
+#: fortran/decl.c:2950 fortran/decl.c:3676
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr "Vanhantyylinen esittely %s*%d ei ole tuettu kohdassa %C"
 
-#: fortran/decl.c:2954
+#: fortran/decl.c:2963
 #, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr ""
 
-#: fortran/decl.c:2965
+#: fortran/decl.c:2974
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr "Puuttuva oikea sulje kohdassa %C"
 
-#: fortran/decl.c:3070
+#: fortran/decl.c:3079
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr ""
 
-#: fortran/decl.c:3202
+#: fortran/decl.c:3211
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr "Syntaksivirhe CHARACTER-esittelyssä kohdassa %C"
 
-#: fortran/decl.c:3291
+#: fortran/decl.c:3310
 #, gcc-internal-format, gfc-internal-format
 msgid "RECORD at %C is an extension, enable it with -fdec-structure"
 msgstr ""
 
-#: fortran/decl.c:3304
+#: fortran/decl.c:3323
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Interface-name expected after '(' at %C"
 msgid "Structure name expected after RECORD at %C"
 msgstr "Odotettiin nimetöntä rajapintaa kohdassa %C"
 
-#: fortran/decl.c:3417
+#: fortran/decl.c:3436
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C cannot contain both ASSUMED and DEFERRED parameters"
 msgstr ""
 
-#: fortran/decl.c:3441
+#: fortran/decl.c:3460
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C does not contain enough parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3465
+#: fortran/decl.c:3484
 #, fuzzy, gcc-internal-format
 #| msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgid "The derived parameter %qs at %C does not have a default value"
 msgstr "%<operator new%>:n ensimmäisellä parametrilla ei voi olla oletusargumenttia"
 
-#: fortran/decl.c:3497
+#: fortran/decl.c:3516
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The parameter expression at %C must be of INTEGER type and not %s type"
 msgstr "Lauseke CASE-lauseessa kohdassa %L on oltava %s-tyyppinen"
 
-#: fortran/decl.c:3525
+#: fortran/decl.c:3544
 #, gcc-internal-format
 msgid "The KIND parameter %qs at %C cannot either be ASSUMED or DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:3532
+#: fortran/decl.c:3551
 #, fuzzy, gcc-internal-format
 msgid "The value for the KIND parameter %qs at %C does not reduce to a constant expression"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: fortran/decl.c:3547
+#: fortran/decl.c:3566
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C contains too many parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3556
+#: fortran/decl.c:3575
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Parameterized derived type at %C is ambiguous"
 msgstr "sijoitus kirjoitussuojattuun viitteeseen %qD"
 
-#: fortran/decl.c:3819
+#: fortran/decl.c:3838
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BYTE type at %C"
 msgstr "Odotettiin :: TYPE-määrittelyssä kohdassa %C"
 
-#: fortran/decl.c:3824
+#: fortran/decl.c:3843
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr ""
 
-#: fortran/decl.c:3846
+#: fortran/decl.c:3865
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C is not allowed for components"
 msgstr ""
 
-#: fortran/decl.c:3849
+#: fortran/decl.c:3868
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr "oletetaan palauttavan %<id%> ja hyväksyvän"
 
-#: fortran/decl.c:3872 fortran/decl.c:3903 fortran/decl.c:3932
-#: fortran/decl.c:4216
+#: fortran/decl.c:3891 fortran/decl.c:3922 fortran/decl.c:3951
+#: fortran/decl.c:4235
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr "Odotettiin :: TYPE-määrittelyssä kohdassa %C"
 
-#: fortran/decl.c:3928
+#: fortran/decl.c:3947
 #, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr ""
 
-#: fortran/decl.c:3971 fortran/decl.c:4107 fortran/decl.c:4119
-#: fortran/decl.c:4133 fortran/decl.c:4611 fortran/decl.c:4619
+#: fortran/decl.c:3990 fortran/decl.c:4126 fortran/decl.c:4138
+#: fortran/decl.c:4152 fortran/decl.c:4630 fortran/decl.c:4638
 #, fuzzy, gcc-internal-format
 #| msgid "Type name '%s' at %C is ambiguous"
 msgid "Type name %qs at %C is ambiguous"
 msgstr "Monimerkityksellinen symboli TYPE-määrittelyssä kohdassa %C"
 
-#: fortran/decl.c:4066
+#: fortran/decl.c:4085
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CLASS statement at %C"
 msgstr "Syntaksivirhe IMPORT-lauseessa kohdassa %C"
 
-#: fortran/decl.c:4148
+#: fortran/decl.c:4167
 #, gcc-internal-format
 msgid "Type name %qs at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr ""
 
-#: fortran/decl.c:4287
+#: fortran/decl.c:4306
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr "Tyhjä IMPLICIT-lause kohdassa %C"
 
-#: fortran/decl.c:4296
+#: fortran/decl.c:4315
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr ""
 
-#: fortran/decl.c:4355
+#: fortran/decl.c:4374
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr "loppumerkki %c puuttuu"
 
-#: fortran/decl.c:4401
+#: fortran/decl.c:4420
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4454
+#: fortran/decl.c:4473
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr ""
 
-#: fortran/decl.c:4464
+#: fortran/decl.c:4483
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr "Tyhjä IMPLICIT-lause kohdassa %C"
 
-#: fortran/decl.c:4570
+#: fortran/decl.c:4589
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr ""
 
-#: fortran/decl.c:4577
+#: fortran/decl.c:4596
 #, gcc-internal-format, gfc-internal-format
 msgid "F2008: C1210 IMPORT statement at %C is not permitted in a module procedure interface body"
 msgstr ""
 
-#: fortran/decl.c:4582
+#: fortran/decl.c:4601
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C"
 msgstr "Syntaksivirhe IMPORT-lauseessa kohdassa %C"
 
-#: fortran/decl.c:4596
+#: fortran/decl.c:4615
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr ""
 
-#: fortran/decl.c:4625
+#: fortran/decl.c:4644
 #, gcc-internal-format
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr ""
 
-#: fortran/decl.c:4632
+#: fortran/decl.c:4651
 #, gcc-internal-format
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr ""
 
-#: fortran/decl.c:4673
+#: fortran/decl.c:4692
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IMPORT statement at %C"
 msgstr "Syntaksivirhe IMPORT-lauseessa kohdassa %C"
 
-#: fortran/decl.c:5010
+#: fortran/decl.c:5029
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing codimension specification at %C"
 msgstr "Puuttuva ulottuvuusspesifikaatio kohdassa %C"
 
-#: fortran/decl.c:5012
+#: fortran/decl.c:5031
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr "Puuttuva ulottuvuusspesifikaatio kohdassa %C"
 
-#: fortran/decl.c:5107
+#: fortran/decl.c:5126
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr "Kaksoiskappele %s attribuutti kohdassa %L"
 
-#: fortran/decl.c:5124
+#: fortran/decl.c:5143
 #, gcc-internal-format
 msgid "%s at %L is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:5141
+#: fortran/decl.c:5160
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr "Odotettiin :: TYPE-määrittelyssä kohdassa %C"
 
-#: fortran/decl.c:5150
+#: fortran/decl.c:5169
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "KIND attribute at %C in a TYPE definition"
 msgstr "Attribuutti kohdassa %L ei ole sallittu TYPE-määrittelyssä"
 
-#: fortran/decl.c:5158
+#: fortran/decl.c:5177
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be INTEGER"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on oltava POINTER"
 
-#: fortran/decl.c:5165
+#: fortran/decl.c:5184
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5174
+#: fortran/decl.c:5193
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LEN attribute at %C in a TYPE definition"
 msgstr "Odotettiin :: TYPE-määrittelyssä kohdassa %C"
 
-#: fortran/decl.c:5182
+#: fortran/decl.c:5201
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be INTEGER"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L on oltava POINTER"
 
-#: fortran/decl.c:5189
+#: fortran/decl.c:5208
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5198
+#: fortran/decl.c:5217
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr "Attribuutti kohdassa %L ei ole sallittu TYPE-määrittelyssä"
 
-#: fortran/decl.c:5216
+#: fortran/decl.c:5235
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr "Attribuutti kohdassa %L ei ole sallittu TYPE-määrittelyssä"
 
-#: fortran/decl.c:5226
+#: fortran/decl.c:5245
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr "%s-attribuutti kohdassa %L ei ole sallittu moduulin spesifikaatio-osan ulkopuolella"
 
-#: fortran/decl.c:5236
+#: fortran/decl.c:5255
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "Attribute at %L is not allowed outside a TYPE definition"
 msgstr "Attribuutti kohdassa %L ei ole sallittu TYPE-määrittelyssä"
 
-#: fortran/decl.c:5249
+#: fortran/decl.c:5268
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr "Odotettiin sitomisattribuuttia kohdassa %C"
 
-#: fortran/decl.c:5260
+#: fortran/decl.c:5279
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr "yhtenäistä dataa"
 
-#: fortran/decl.c:5315 fortran/decl.c:8673
+#: fortran/decl.c:5334 fortran/decl.c:8692
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr "PROTECTED kohdassa %C on sallittu vain moduulin spesifikaatio-osassa"
 
-#: fortran/decl.c:5321
+#: fortran/decl.c:5340
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute at %C"
 msgstr "Kaksoiskappale POINTER-attribuutti kohdassa %C"
 
-#: fortran/decl.c:5355
+#: fortran/decl.c:5374
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VALUE attribute at %C"
 msgstr "Kaksoiskappale VALUE-attribuutti määritelty kohdassa %L"
 
-#: fortran/decl.c:5362
+#: fortran/decl.c:5381
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
 msgstr "Syntaksivirhe VOLATILE-lauseessa kohdassa %C"
 
-#: fortran/decl.c:5369
+#: fortran/decl.c:5388
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr ""
 
-#: fortran/decl.c:5410
+#: fortran/decl.c:5429
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr "Useita tunnisteita tarjottu yhdellä NAME= tarkenteella kohdassa %C"
 
-#: fortran/decl.c:5508
+#: fortran/decl.c:5527
 #, fuzzy, gcc-internal-format
 #| msgid "Return type of BIND(C) function '%s' at %L cannot be an array"
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr "BIND(C)-funktion ”%s” paluutyyppi kohdassa %L ei voi olla taulukko"
 
-#: fortran/decl.c:5530
+#: fortran/decl.c:5549
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5539
+#: fortran/decl.c:5558
 #, gcc-internal-format
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5543
+#: fortran/decl.c:5562
 #, gcc-internal-format
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5555
+#: fortran/decl.c:5574
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr ""
 
-#: fortran/decl.c:5569
+#: fortran/decl.c:5588
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr "Muuttujalla ”%s” kohdassa %L ei voi olla sekä POINTER- että BIND(C)-attribuutit"
 
-#: fortran/decl.c:5577
+#: fortran/decl.c:5596
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr "Muuttujalla ”%s” kohdassa %L ei voi olla sekä ALLOCATABLE- että BIND(C)-attribuutit"
 
-#: fortran/decl.c:5589
+#: fortran/decl.c:5608
 #, fuzzy, gcc-internal-format
 #| msgid "Return type of BIND(C) function '%s' at %L cannot be an array"
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr "BIND(C)-funktion ”%s” paluutyyppi kohdassa %L ei voi olla taulukko"
 
-#: fortran/decl.c:5597
+#: fortran/decl.c:5616
 #, fuzzy, gcc-internal-format
 #| msgid "Return type of BIND(C) function '%s' at %L cannot be a character string"
 msgid "Return type of BIND(C) function %qs at %L cannot be a character string"
@@ -54727,988 +54796,994 @@
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:5608
+#: fortran/decl.c:5627
 #, gcc-internal-format
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr ""
 
-#: fortran/decl.c:5682
+#: fortran/decl.c:5701
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5727
+#: fortran/decl.c:5746
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5734
+#: fortran/decl.c:5753
 #, fuzzy, gcc-internal-format
 msgid "Missing symbol"
 msgstr "symboli ”%s”"
 
-#: fortran/decl.c:5763
+#: fortran/decl.c:5782
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) statement at %C"
 msgstr "Tyhjä IMPLICIT-lause kohdassa %C"
 
-#: fortran/decl.c:5850
+#: fortran/decl.c:5869
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr ""
 
-#: fortran/decl.c:5892
+#: fortran/decl.c:5911
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in data declaration at %C"
 msgid "Syntax error in anonymous structure declaration at %C"
 msgstr "Syntaksivirhe data-esittelyssä kohdassa %C"
 
-#: fortran/decl.c:5901
+#: fortran/decl.c:5920
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr "Syntaksivirhe data-esittelyssä kohdassa %C"
 
-#: fortran/decl.c:5951
+#: fortran/decl.c:5970
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C"
 msgstr "Odotettiin moduuliproseduurinimeä kohdassa %C"
 
-#: fortran/decl.c:5996
+#: fortran/decl.c:6015
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IMPURE procedure at %C"
 msgstr "Odotettiin moduuliproseduurinimeä kohdassa %C"
 
-#: fortran/decl.c:6008
+#: fortran/decl.c:6027
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr ""
 
-#: fortran/decl.c:6054
+#: fortran/decl.c:6073
 #, gcc-internal-format, gfc-internal-format
 msgid "ELEMENTAL prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6061
+#: fortran/decl.c:6080
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6068
+#: fortran/decl.c:6087
 #, gcc-internal-format, gfc-internal-format
 msgid "RECURSIVE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6134 fortran/primary.c:1820
+#: fortran/decl.c:6153 fortran/primary.c:1820
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected alternate return label at %C"
 msgid "Alternate-return argument at %C"
 msgstr "Odotettiin vaihtoehtoista paluunimiötä kohdassa %C"
 
-#: fortran/decl.c:6140 fortran/decl.c:6148
+#: fortran/decl.c:6159 fortran/decl.c:6167
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "A parameter name is required at %C"
 msgstr "sijoituksen vasemman operandin on oltava lvalue"
 
-#: fortran/decl.c:6188
+#: fortran/decl.c:6207
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is the name of the procedure"
 msgid "Name %qs at %C is the name of the procedure"
 msgstr "Odotettiin moduuliproseduurinimeä kohdassa %C"
 
-#: fortran/decl.c:6201
+#: fortran/decl.c:6220
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected another dimension in array declaration at %C"
 msgid "Expected parameter list in type declaration at %C"
 msgstr "Odotettiin toista ulottuvuutta taulukkoesittelyssä kohdassa %C"
 
-#: fortran/decl.c:6204
+#: fortran/decl.c:6223
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr "Odottamatonta roskaa muodollisessa argumenttiluettelossa kohdassa %C"
 
-#: fortran/decl.c:6222
+#: fortran/decl.c:6241
 #, fuzzy, gcc-internal-format
 msgid "Duplicate name %qs in parameter list at %C"
 msgstr "%J%qD:lle ei ole aiempaa esittelyä"
 
-#: fortran/decl.c:6225
+#: fortran/decl.c:6244
 #, fuzzy, gcc-internal-format
 #| msgid "Duplicate symbol '%s' in formal argument list at %C"
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr "Kaksoiskappalesymboli ”%s” muodollisessa argumenttiluettelossa paikassa %C"
 
-#: fortran/decl.c:6264
+#: fortran/decl.c:6283
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in MODULE PROCEDURE formal argument names (%s/%s) at %C"
 msgstr ""
 
-#: fortran/decl.c:6270
+#: fortran/decl.c:6289
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in number of MODULE PROCEDURE formal arguments at %C"
 msgstr ""
 
-#: fortran/decl.c:6309
+#: fortran/decl.c:6328
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr "RESULT-muuttujan paikassa %C on oltava erilainen kuin funktionimen"
 
-#: fortran/decl.c:6386
+#: fortran/decl.c:6405
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr "Odottamatonta roskaa funktioesittelyn jälkeen kohdassa %C"
 
-#: fortran/decl.c:6396 fortran/decl.c:7494
+#: fortran/decl.c:6415 fortran/decl.c:7513
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr "%Jlohkoattribuuttia ei voi määrittää paikalliselle muuttujalle"
 
-#: fortran/decl.c:6600
+#: fortran/decl.c:6619
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:6607
+#: fortran/decl.c:6626
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:6613
+#: fortran/decl.c:6632
 #, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr ""
 
-#: fortran/decl.c:6636
+#: fortran/decl.c:6655
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L may not have basic type of %s"
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/decl.c:6682 fortran/decl.c:6870 fortran/decl.c:10723
+#: fortran/decl.c:6701 fortran/decl.c:6889 fortran/decl.c:10748
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr "Syntaksivirhe PROCEDURE-lauseessa kohdassa %C"
 
-#: fortran/decl.c:6731 fortran/decl.c:10623
+#: fortran/decl.c:6750 fortran/decl.c:10648
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '::' after binding-attributes at %C"
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr "Odotettiin erityistä sitomisnimeä kohdassa %C"
 
-#: fortran/decl.c:6738
+#: fortran/decl.c:6757
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr ""
 
-#: fortran/decl.c:6742
+#: fortran/decl.c:6761
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component at %C"
 msgstr "Odotettiin tyyppiriippuvaista proseduuria tai proseduurin osoitinkomponenttia kohdassa %C"
 
-#: fortran/decl.c:6814
+#: fortran/decl.c:6833
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in procedure pointer component at %C"
 msgstr "Syntaksivirhe proseduuriosoitinkomponentissa kohdassa %C"
 
-#: fortran/decl.c:6832
+#: fortran/decl.c:6851
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr "PROCEDURE-lauseen kohdassa %C on oltava geneerisessä rajapinnassa"
 
-#: fortran/decl.c:6841 fortran/decl.c:9392
+#: fortran/decl.c:6860 fortran/decl.c:9411
 #, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr ""
 
-#: fortran/decl.c:6911
+#: fortran/decl.c:6930
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE statement at %C"
 msgstr "Syntaksivirhe PROCEDURE-lauseessa kohdassa %C"
 
-#: fortran/decl.c:6983
+#: fortran/decl.c:7002
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr "Odotetiin muodollista argumenttiluetteloa funktiomäärittelyssä kohdassa %C"
 
-#: fortran/decl.c:7007 fortran/decl.c:7011 fortran/decl.c:7266
-#: fortran/decl.c:7270 fortran/decl.c:7462 fortran/decl.c:7466
-#: fortran/symbol.c:1875
+#: fortran/decl.c:7026 fortran/decl.c:7030 fortran/decl.c:7285
+#: fortran/decl.c:7289 fortran/decl.c:7481 fortran/decl.c:7485
+#: fortran/symbol.c:1889
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr ""
 
-#: fortran/decl.c:7164
+#: fortran/decl.c:7183
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C"
 msgstr "Syntaksivirhe IMPORT-lauseessa kohdassa %C"
 
-#: fortran/decl.c:7173
+#: fortran/decl.c:7192
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr ""
 
-#: fortran/decl.c:7176
+#: fortran/decl.c:7195
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr ""
 
-#: fortran/decl.c:7179
+#: fortran/decl.c:7198
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PRINT statement at %C not allowed within PURE procedure"
 msgid "ENTRY statement at %C cannot appear within a SUBMODULE"
 msgstr "PRINT-lause kohdassa %C ei ole sallittu PURE-proseduurin sisällä"
 
-#: fortran/decl.c:7182
+#: fortran/decl.c:7201
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr ""
 
-#: fortran/decl.c:7186 fortran/decl.c:7231
+#: fortran/decl.c:7205 fortran/decl.c:7250
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr ""
 
-#: fortran/decl.c:7190
+#: fortran/decl.c:7209
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PRINT statement at %C not allowed within PURE procedure"
 msgid "ENTRY statement at %C cannot appear within a STRUCTURE block"
 msgstr "PRINT-lause kohdassa %C ei ole sallittu PURE-proseduurin sisällä"
 
-#: fortran/decl.c:7194
+#: fortran/decl.c:7213
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr ""
 
-#: fortran/decl.c:7198
+#: fortran/decl.c:7217
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr ""
 
-#: fortran/decl.c:7203
+#: fortran/decl.c:7222
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr ""
 
-#: fortran/decl.c:7207
+#: fortran/decl.c:7226
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr ""
 
-#: fortran/decl.c:7211
+#: fortran/decl.c:7230
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr ""
 
-#: fortran/decl.c:7215
+#: fortran/decl.c:7234
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr ""
 
-#: fortran/decl.c:7219
+#: fortran/decl.c:7238
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr ""
 
-#: fortran/decl.c:7223
+#: fortran/decl.c:7242
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected END statement at %C"
 msgid "Unexpected ENTRY statement at %C"
 msgstr "Odottamaton CASE-lause kohdassa %C"
 
-#: fortran/decl.c:7244
+#: fortran/decl.c:7263
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr ""
 
-#: fortran/decl.c:7295 fortran/decl.c:7501
+#: fortran/decl.c:7314 fortran/decl.c:7520
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7563 fortran/decl.c:7570
+#: fortran/decl.c:7582 fortran/decl.c:7589
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr "virheellinen muunnostarkennin jälkiliitteessä: %c"
 
-#: fortran/decl.c:7610
+#: fortran/decl.c:7629
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr ""
 
-#: fortran/decl.c:7626
+#: fortran/decl.c:7645
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASYNCHRONOUS= specifier at %L must be an initialization expression"
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr "ASYNCHRONOUS= määrite kohdassa %L täytyy olla alustuslauseke"
 
-#: fortran/decl.c:7634
+#: fortran/decl.c:7653
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr ""
 
-#: fortran/decl.c:7653
+#: fortran/decl.c:7672
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing closing paren for binding label at %C"
 msgstr ""
 
-#: fortran/decl.c:7659
+#: fortran/decl.c:7678
 #, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr "Sitomisnimeä ei ole sallittu BIND(C):ssä kohdassa %C"
 
-#: fortran/decl.c:7665
+#: fortran/decl.c:7684
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7694
+#: fortran/decl.c:7713
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr "Sitomisnimeä ei ole sallittu BIND(C):ssä kohdassa %C"
 
-#: fortran/decl.c:7939
+#: fortran/decl.c:7958
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr "Odottamaton END-lause kohdassa %C"
 
-#: fortran/decl.c:7948
+#: fortran/decl.c:7967
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "END statement instead of %s statement at %L"
 msgstr "%s-lausetta odotettiin kohdassa %L"
 
 #. We would have required END [something].
-#: fortran/decl.c:7957
+#: fortran/decl.c:7976
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr "%s-lausetta odotettiin kohdassa %L"
 
-#: fortran/decl.c:7968
+#: fortran/decl.c:7987
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting %s statement at %C"
 msgid "Expecting %s statement at %L"
 msgstr "%s-lausetta odotettiin kohdassa %L"
 
-#: fortran/decl.c:7988
+#: fortran/decl.c:8007
 #, fuzzy, gcc-internal-format
 #| msgid "Expected block name of '%s' in %s statement at %C"
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr "Odotettiin ”%s”-lohkonimeä %s-lauseessa kohdassa %C"
 
-#: fortran/decl.c:8005
+#: fortran/decl.c:8024
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr "Odotettiin päättävää nimeä kohdassa %C"
 
-#: fortran/decl.c:8019 fortran/decl.c:8027
+#: fortran/decl.c:8038 fortran/decl.c:8046
 #, fuzzy, gcc-internal-format
 #| msgid "Expected label '%s' for %s statement at %C"
 msgid "Expected label %qs for %s statement at %C"
 msgstr "Odotettiin lauseketta %s-lauseessa kohdassa %C"
 
-#: fortran/decl.c:8126
+#: fortran/decl.c:8145
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr ""
 
-#: fortran/decl.c:8134
+#: fortran/decl.c:8153
 #, gcc-internal-format, gfc-internal-format
 msgid "Dimensions specified for %s at %L after its initialization"
 msgstr ""
 
-#: fortran/decl.c:8142
+#: fortran/decl.c:8161
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr ""
 
-#: fortran/decl.c:8151
+#: fortran/decl.c:8170
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr ""
 
-#: fortran/decl.c:8249
+#: fortran/decl.c:8268
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr "Odottamaton merkki muuttujaluettelossa kohdassa %C"
 
-#: fortran/decl.c:8286
+#: fortran/decl.c:8305
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "Expected %<(%> at %C"
 msgstr "Odotettiin merkkiä ”,” kohdassa %C"
 
-#: fortran/decl.c:8300 fortran/decl.c:8340
+#: fortran/decl.c:8319 fortran/decl.c:8359
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr "Odotettiin muuttujanimeä kohdassa %C"
 
-#: fortran/decl.c:8316
+#: fortran/decl.c:8335
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C must be an integer"
 msgstr "Cray-osoittimen kohdassa %C on oltava kokonaisluku"
 
-#: fortran/decl.c:8320
+#: fortran/decl.c:8339
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr "Cray-osoittimella kohdassa %C on %d-tavun tarkkuus; muistiosoitteet vaativat %d tavua"
 
-#: fortran/decl.c:8326
+#: fortran/decl.c:8345
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr "Odotettiin merkkiä ”,” kohdassa %C"
 
-#: fortran/decl.c:8365
+#: fortran/decl.c:8384
 #, gcc-internal-format
 msgid "Couldn't set Cray pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:8389
+#: fortran/decl.c:8408
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr "Odotettiin ”)” kohdassa %C"
 
-#: fortran/decl.c:8401
+#: fortran/decl.c:8420
 #, fuzzy, gcc-internal-format
 #| msgid "Expected \",\" or end of statement at %C"
 msgid "Expected %<,%> or end of statement at %C"
 msgstr "Odottamaton END-lause kohdassa %C"
 
-#: fortran/decl.c:8427
+#: fortran/decl.c:8446
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:8459
+#: fortran/decl.c:8478
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:8478
+#: fortran/decl.c:8497
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer declaration at %C requires -fcray-pointer flag"
 msgstr ""
 
-#: fortran/decl.c:8517
+#: fortran/decl.c:8536
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS statement at %C"
 msgstr "Odottamaton %s-lause kohdassa %C"
 
-#: fortran/decl.c:8623
+#: fortran/decl.c:8642
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:8640
+#: fortran/decl.c:8659
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:8679
+#: fortran/decl.c:8698
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED statement at %C"
 msgstr "Syntaksivirhe PROTECTED-lauseessa kohdassa %C"
 
-#: fortran/decl.c:8717
+#: fortran/decl.c:8736
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr "Syntaksivirhe PROTECTED-lauseessa kohdassa %C"
 
-#: fortran/decl.c:8741
+#: fortran/decl.c:8760
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr "PROTECTED kohdassa %C on sallittu vain moduulin spesifikaatio-osassa"
 
-#: fortran/decl.c:8778
+#: fortran/decl.c:8797
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr "PROTECTED kohdassa %C on sallittu vain moduulin spesifikaatio-osassa"
 
-#: fortran/decl.c:8806
+#: fortran/decl.c:8825
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr "Odotettiin muuttujanimeä kohdassa %C PARAMETER-lauseessa"
 
-#: fortran/decl.c:8813
+#: fortran/decl.c:8832
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr "Odotettiin =-merkkiä PARAMETER-lauseessa kohdassa %C"
 
-#: fortran/decl.c:8819
+#: fortran/decl.c:8838
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr "Odotettiin lauseketta kohdassa %C PARAMETER-lauseessa"
 
-#: fortran/decl.c:8839
+#: fortran/decl.c:8858
 #, gcc-internal-format, gfc-internal-format
 msgid "Initializing already initialized variable at %C"
 msgstr "Alustetaan jo alustettu muuttuja kohdassa %C"
 
 #. With legacy PARAMETER statements, don't expect a terminating ')'.
-#: fortran/decl.c:8864
+#: fortran/decl.c:8883
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER without '()' at %C"
 msgstr ""
 
-#: fortran/decl.c:8880
+#: fortran/decl.c:8899
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr "Odottamattomia merkkejä PARAMETER-lauseessa kohdassa %C"
 
-#: fortran/decl.c:8899 fortran/decl.c:8955
+#: fortran/decl.c:8918 fortran/decl.c:8974
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:8934
+#: fortran/decl.c:8953
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected variable in READ statement at %C"
 msgid "Expected entity-list in AUTOMATIC statement at %C"
 msgstr "Odotettiin muuttujaa READ-lauseessa kohdassa %C"
 
-#: fortran/decl.c:8941
+#: fortran/decl.c:8960
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in VOLATILE statement at %C"
 msgid "Syntax error in AUTOMATIC statement at %C"
 msgstr "Syntaksivirhe VOLATILE-lauseessa kohdassa %C"
 
-#: fortran/decl.c:8990
+#: fortran/decl.c:9009
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected variable in READ statement at %C"
 msgid "Expected entity-list in STATIC statement at %C"
 msgstr "Odotettiin muuttujaa READ-lauseessa kohdassa %C"
 
-#: fortran/decl.c:8997
+#: fortran/decl.c:9016
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in STATIC statement at %C"
 msgstr "Syntaksivirhe SAVE-lauseessa kohdassa %C"
 
-#: fortran/decl.c:9016
+#: fortran/decl.c:9035
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:9027
+#: fortran/decl.c:9046
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr "Syntaksivirhe SAVE-lauseessa kohdassa %C"
 
-#: fortran/decl.c:9073
+#: fortran/decl.c:9092
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr "Syntaksivirhe SAVE-lauseessa kohdassa %C"
 
-#: fortran/decl.c:9087
+#: fortran/decl.c:9106
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:9091
+#: fortran/decl.c:9110
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VALUE statement at %C"
 msgstr "Syntaksivirhe VALUE-lauseessa kohdassa %C"
 
-#: fortran/decl.c:9129
+#: fortran/decl.c:9148
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VALUE statement at %C"
 msgstr "Syntaksivirhe VALUE-lauseessa kohdassa %C"
 
-#: fortran/decl.c:9141
+#: fortran/decl.c:9160
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE statement at %C"
 msgstr "Syntaksivirhe VOLATILE-lauseessa kohdassa %C"
 
-#: fortran/decl.c:9168
+#: fortran/decl.c:9187
 #, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr ""
 
-#: fortran/decl.c:9193
+#: fortran/decl.c:9212
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr "Syntaksivirhe VOLATILE-lauseessa kohdassa %C"
 
-#: fortran/decl.c:9205
+#: fortran/decl.c:9224
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS statement at %C"
 msgstr "Odottamaton %s-lause kohdassa %C"
 
-#: fortran/decl.c:9249
+#: fortran/decl.c:9268
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr "Syntaksivirhe VALUE-lauseessa kohdassa %C"
 
-#: fortran/decl.c:9274
+#: fortran/decl.c:9293
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE declaration at %C"
 msgstr "Odotettiin moduuliproseduurinimeä kohdassa %C"
 
-#: fortran/decl.c:9367
+#: fortran/decl.c:9386
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr "PROCEDURE-lauseen kohdassa %C on oltava geneerisessä rajapinnassa"
 
-#: fortran/decl.c:9425
+#: fortran/decl.c:9444
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr "SAVE-attribuuttia kohdassa %L ei voida määritellä PURE-proseduurissa"
 
-#: fortran/decl.c:9474
+#: fortran/decl.c:9493
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr "Monimerkityksellinen symboli TYPE-määrittelyssä kohdassa %C"
 
-#: fortran/decl.c:9483
+#: fortran/decl.c:9502
 #, gcc-internal-format
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr ""
 
-#: fortran/decl.c:9489
+#: fortran/decl.c:9508
 #, gcc-internal-format
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr ""
 
-#: fortran/decl.c:9496
+#: fortran/decl.c:9515
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:9503
+#: fortran/decl.c:9522
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr ""
 
-#: fortran/decl.c:9526
+#: fortran/decl.c:9545
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:9538
+#: fortran/decl.c:9557
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:9559
+#: fortran/decl.c:9578
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
 msgstr "abstrakti metodi ei-abstraktissa luokassa"
 
-#: fortran/decl.c:9605
+#: fortran/decl.c:9624
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Failed to create structure type '%s' at %C"
 msgstr "%s: Tulostetiedoston %s sulkeminen epäonnistui\n"
 
-#: fortran/decl.c:9611
+#: fortran/decl.c:9630
 #, fuzzy, gcc-internal-format
 #| msgid "%qD has already been defined"
 msgid "Type definition of %qs at %C was already defined at %L"
 msgstr "%qD on jo määritelty"
 
-#: fortran/decl.c:9658
+#: fortran/decl.c:9677
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Junk after MAP statement at %C"
 msgstr "Odottamatonta roskaa ELSE-lauseen jälkeen kohdassa %C"
 
-#: fortran/decl.c:9691
+#: fortran/decl.c:9710
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Junk after UNION statement at %C"
 msgstr "Odottamatonta roskaa ELSE-lauseen jälkeen kohdassa %C"
 
-#: fortran/decl.c:9726
+#: fortran/decl.c:9745
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qD"
 msgid "%s at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr "Jäsenfunktio %qs"
 
-#: fortran/decl.c:9740
+#: fortran/decl.c:9759
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after function declaration at %C"
 msgid "Structure name expected in non-nested structure declaration at %C"
 msgstr "Odottamatonta roskaa funktioesittelyn jälkeen kohdassa %C"
 
-#: fortran/decl.c:9758
+#: fortran/decl.c:9777
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Junk after non-nested STRUCTURE statement at %C"
 msgstr "Odottamatonta roskaa ELSE-lauseen jälkeen kohdassa %C"
 
-#: fortran/decl.c:9765
+#: fortran/decl.c:9784
 #, fuzzy, gcc-internal-format
 #| msgid "External '%s' at %L cannot have an initializer"
 msgid "Structure name %qs at %C cannot be the same as an intrinsic type"
 msgstr "Ulkoisella ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/decl.c:9926
+#: fortran/decl.c:9947
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr "Odotettiin :: TYPE-määrittelyssä kohdassa %C"
 
-#: fortran/decl.c:9954
+#: fortran/decl.c:9975
 #, fuzzy, gcc-internal-format
 #| msgid "External '%s' at %L cannot have an initializer"
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr "Ulkoisella ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/decl.c:9964
+#: fortran/decl.c:9986
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L may not have basic type of %s"
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/decl.c:9981
+#: fortran/decl.c:9989
 #, fuzzy, gcc-internal-format
+#| msgid "Procedure '%s' at %L may not have basic type of %s"
+msgid "Derived type name %qs at %C already has a basic type"
+msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
+
+#: fortran/decl.c:10006
+#, fuzzy, gcc-internal-format
 #| msgid "%qD has already been defined"
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr "%qD on jo määritelty"
 
-#: fortran/decl.c:10042
+#: fortran/decl.c:10067
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CHARACTER declaration at %C"
 msgid "Garbage after PARAMETERIZED TYPE declaration at %C"
 msgstr "Syntaksivirhe CHARACTER-esittelyssä kohdassa %C"
 
-#: fortran/decl.c:10126
+#: fortran/decl.c:10151
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr ""
 
-#: fortran/decl.c:10146
+#: fortran/decl.c:10171
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENUM and ENUMERATOR at %C"
 msgstr "enum-muunnos sijoituksessa on virheellistä C++-kielessä"
 
-#: fortran/decl.c:10178
+#: fortran/decl.c:10203
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr "Enumeraattori ylittää C-kokonaislukutyypin kohdassa %C"
 
-#: fortran/decl.c:10257
+#: fortran/decl.c:10282
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: fortran/decl.c:10305
+#: fortran/decl.c:10330
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr "ENUM-määrittelylause odotettiin ennen kohdetta %C"
 
-#: fortran/decl.c:10341
+#: fortran/decl.c:10366
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr "Syntaksivirhe ENUMERATOR-määrittelyssä kohdassa %C"
 
-#: fortran/decl.c:10388 fortran/decl.c:10403
+#: fortran/decl.c:10413 fortran/decl.c:10428
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate access-specifier at %C"
 msgstr "Kaksoiskappale pääsy-tarkenne kohdassa %C"
 
-#: fortran/decl.c:10423
+#: fortran/decl.c:10448
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10443
+#: fortran/decl.c:10468
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10470
+#: fortran/decl.c:10495
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate POINTER attribute at %C"
 msgstr "Kaksoiskappale POINTER-attribuutti kohdassa %C"
 
-#: fortran/decl.c:10488
+#: fortran/decl.c:10513
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr "Kaksoiskappale pääsy-tarkenne kohdassa %C"
 
-#: fortran/decl.c:10504
+#: fortran/decl.c:10529
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DEFERRED at %C"
 msgstr "Kaksoiskappale %s-nimiöspesifikaatio kohdassa %C"
 
-#: fortran/decl.c:10517
+#: fortran/decl.c:10542
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected access-specifier at %C"
 msgstr "Odotettiin käyttöoikeustarkennetta kohdassa %C"
 
-#: fortran/decl.c:10519
+#: fortran/decl.c:10544
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr "Odotettiin sitomisattribuuttia kohdassa %C"
 
-#: fortran/decl.c:10527
+#: fortran/decl.c:10552
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED can't both appear at %C"
 msgstr ""
 
-#: fortran/decl.c:10539
+#: fortran/decl.c:10564
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr "Odotettiin tyyppiriippuvaista proseduuria tai proseduurin osoitinkomponenttia kohdassa %C"
 
-#: fortran/decl.c:10581
+#: fortran/decl.c:10606
 #, fuzzy, gcc-internal-format
 #| msgid "Interface-name expected after '(' at %C"
 msgid "Interface-name expected after %<(%> at %C"
 msgstr "Odotettiin nimetöntä rajapintaa kohdassa %C"
 
-#: fortran/decl.c:10587
+#: fortran/decl.c:10612
 #, fuzzy, gcc-internal-format
 #| msgid "')' expected at %C"
 msgid "%<)%> expected at %C"
 msgstr "Odotettiin merkkiä ”,” kohdassa %C"
 
-#: fortran/decl.c:10607
+#: fortran/decl.c:10632
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:10612
+#: fortran/decl.c:10637
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:10635
+#: fortran/decl.c:10660
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr "Odotettiin sitomisnimeä kohteessa %C"
 
-#: fortran/decl.c:10639
+#: fortran/decl.c:10664
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
 msgstr "Odotettiin moduuliproseduurinimeä kohdassa %C"
 
-#: fortran/decl.c:10651
+#: fortran/decl.c:10676
 #, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:10657
+#: fortran/decl.c:10682
 #, gcc-internal-format
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr ""
 
-#: fortran/decl.c:10667
+#: fortran/decl.c:10692
 #, fuzzy, gcc-internal-format
 #| msgid "Expected binding target after '=>' at %C"
 msgid "Expected binding target after %<=>%> at %C"
 msgstr "Odotettiin sitomisnimeä kohteessa %C"
 
-#: fortran/decl.c:10684
+#: fortran/decl.c:10709
 #, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr ""
 
-#: fortran/decl.c:10695
+#: fortran/decl.c:10720
 #, gcc-internal-format
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:10746
+#: fortran/decl.c:10771
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr ""
 
-#: fortran/decl.c:10766
+#: fortran/decl.c:10791
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '::' at %C"
 msgid "Expected %<::%> at %C"
 msgstr "Odotettiin merkkiä ”,” kohdassa %C"
 
-#: fortran/decl.c:10778
+#: fortran/decl.c:10803
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected generic name or operator descriptor at %C"
 msgstr "Odotettiin geneeristä nimeä tai operaattorimäärittelijää kohdassa %C"
 
-#: fortran/decl.c:10799
+#: fortran/decl.c:10824
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Malformed GENERIC statement at %C"
 msgstr "Odotettiin geneeristä nimeä tai operaattorimäärittelijää kohdassa %C"
 
-#: fortran/decl.c:10810
+#: fortran/decl.c:10835
 #, fuzzy, gcc-internal-format
 #| msgid "Expected '=>' at %C"
 msgid "Expected %<=>%> at %C"
 msgstr "Odotettiin merkkiä ”,” kohdassa %C"
 
-#: fortran/decl.c:10846
+#: fortran/decl.c:10871
 #, gcc-internal-format
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:10854
+#: fortran/decl.c:10879
 #, gcc-internal-format
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr ""
 
-#: fortran/decl.c:10902
+#: fortran/decl.c:10927
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr "Odotettiin erityistä sitomisnimeä kohdassa %C"
 
-#: fortran/decl.c:10912
+#: fortran/decl.c:10937
 #, gcc-internal-format
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:10930
+#: fortran/decl.c:10955
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr "Roskaa CALL-lauseen jälkeen kohdassa %C"
 
-#: fortran/decl.c:10965
+#: fortran/decl.c:10990
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr ""
 
-#: fortran/decl.c:10976
+#: fortran/decl.c:11001
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr ""
 
-#: fortran/decl.c:10998
+#: fortran/decl.c:11023
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr "Tyhjä taulukkomuodostin kohdassa %C ei ole sallittu"
 
-#: fortran/decl.c:11005
+#: fortran/decl.c:11030
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr "Odotettiin moduuliproseduurinimeä kohdassa %C"
 
-#: fortran/decl.c:11015
+#: fortran/decl.c:11040
 #, fuzzy, gcc-internal-format
 #| msgid "Expected \",\" at %C"
 msgid "Expected %<,%> at %C"
 msgstr "Odotettiin merkkiä ”,” kohdassa %C"
 
-#: fortran/decl.c:11021
+#: fortran/decl.c:11046
 #, fuzzy, gcc-internal-format
 #| msgid "Unknown procedure name \"%s\" at %C"
 msgid "Unknown procedure name %qs at %C"
 msgstr "Odotettiin moduuliproseduurinimeä kohdassa %C"
 
-#: fortran/decl.c:11034
+#: fortran/decl.c:11059
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %C is already defined at %L"
 msgid "%qs at %C is already defined as FINAL procedure"
 msgstr "Proseduuri ”%s” kohdassa %C on jo määritelty kohdassa %L"
 
-#: fortran/decl.c:11104
+#: fortran/decl.c:11129
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr "Tuntematon attribuutti !GCC$ ATTRIBUTES-lauseessa kohdassa %C"
 
-#: fortran/decl.c:11150
+#: fortran/decl.c:11175
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr "Syntaksivirhe !GCC$ ATTRIBUTES-lauseessa kohdassa %C"
 
-#: fortran/decl.c:11170
+#: fortran/decl.c:11195
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive requires a non-negative integral constant less than or equal to %u at %C"
 msgstr ""
 
-#: fortran/decl.c:11184
+#: fortran/decl.c:11209
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ UNROLL directive at %C"
 msgstr "Syntaksivirhe iteraattorissa kohdassa %C"
@@ -56054,29 +56129,29 @@
 msgid "BOZ literal at %L used to initialize non-integer variable %qs"
 msgstr ""
 
-#: fortran/expr.c:3369 fortran/resolve.c:10197
+#: fortran/expr.c:3369 fortran/resolve.c:10210
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal at %L outside a DATA statement and outside INT/REAL/DBLE/CMPLX"
 msgstr ""
 
-#: fortran/expr.c:3380 fortran/resolve.c:10208
+#: fortran/expr.c:3380 fortran/resolve.c:10221
 #, gcc-internal-format
 msgid "BOZ literal at %L is bitwise transferred non-integer symbol %qs"
 msgstr ""
 
-#: fortran/expr.c:3388 fortran/resolve.c:10217
+#: fortran/expr.c:3388 fortran/resolve.c:10230
 #, fuzzy, gcc-internal-format
 #| msgid "Arithmetic underflow converting %s to %s at %L. This check can be disabled with the option -fno-range-check"
 msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "Aritmeettien alivuoto muunnettaessa %s arvoksi %s kohdassa %L. Tämä tarkistus voidaan ottaa pois käytöstä valitsimella -fno-range-check"
 
-#: fortran/expr.c:3392 fortran/resolve.c:10221
+#: fortran/expr.c:3392 fortran/resolve.c:10234
 #, fuzzy, gcc-internal-format
 #| msgid "Arithmetic overflow converting %s to %s at %L. This check can be disabled with the option -fno-range-check"
 msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "Aritmeettinen ylivuoto muunnettaessa %s arvoksi %s kohdassa %L. Tämä tarkistus voidaan ottaa pois käytöstä valitsimella -fno-range-check"
 
-#: fortran/expr.c:3396 fortran/resolve.c:10225
+#: fortran/expr.c:3396 fortran/resolve.c:10238
 #, fuzzy, gcc-internal-format
 #| msgid "Arithmetic NaN converting %s to %s at %L. This check can be disabled with the option -fno-range-check"
 msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
@@ -56087,152 +56162,152 @@
 msgid "The assignment to a KIND or LEN component of a parameterized type at %L is not allowed"
 msgstr ""
 
-#: fortran/expr.c:3426
+#: fortran/expr.c:3429
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible types in DATA statement at %L; attempted conversion of %s to %s"
 msgstr "Yhteensopimattomat tyypit DATA-lauseessa kohdassa %L; yritettiin muuntaa tyyppi %s tyypiksi %s"
 
-#: fortran/expr.c:3465
+#: fortran/expr.c:3468
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is not a POINTER at %L"
 msgstr "Virheellinen proseduuriosoitinsijoitus kohdassa %L"
 
-#: fortran/expr.c:3473
+#: fortran/expr.c:3476
 #, gcc-internal-format
 msgid "%qs in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgstr ""
 
-#: fortran/expr.c:3496
+#: fortran/expr.c:3499
 #, fuzzy, gcc-internal-format
 msgid "Expected bounds specification for %qs at %L"
 msgstr "%J%qD:lle ei ole aiempaa esittelyä"
 
-#: fortran/expr.c:3501
+#: fortran/expr.c:3504
 #, fuzzy, gcc-internal-format
 msgid "Bounds specification for %qs in pointer assignment at %L"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.c:3514
+#: fortran/expr.c:3517
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Lower bound has to be present at %L"
 msgstr "Data-alkio taulukon alarajan alapuolella kohdassa %L"
 
-#: fortran/expr.c:3520
+#: fortran/expr.c:3523
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Stride must not be present at %L"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/expr.c:3532
+#: fortran/expr.c:3535
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the upper bounds must be specified at %L"
 msgstr ""
 
-#: fortran/expr.c:3558
+#: fortran/expr.c:3561
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %L shall not have a coindex"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/expr.c:3579
+#: fortran/expr.c:3582
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure pointer assignment at %L"
 msgstr "Virheellinen proseduuriosoitinsijoitus kohdassa %L"
 
-#: fortran/expr.c:3603
+#: fortran/expr.c:3606
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs is invalid as proc-target in procedure pointer assignment at %L"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.c:3612
+#: fortran/expr.c:3615
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' is invalid in procedure pointer assignment at %L"
 msgid "Abstract interface %qs is invalid in procedure pointer assignment at %L"
 msgstr "Käskyfunktio ”%s” on virheellinen proseduuriosoitinsijoituksessa kohdassa %L"
 
-#: fortran/expr.c:3622
+#: fortran/expr.c:3625
 #, fuzzy, gcc-internal-format
 #| msgid "Statement function '%s' is invalid in procedure pointer assignment at %L"
 msgid "Statement function %qs is invalid in procedure pointer assignment at %L"
 msgstr "Käskyfunktio ”%s” on virheellinen proseduuriosoitinsijoituksessa kohdassa %L"
 
-#: fortran/expr.c:3628
+#: fortran/expr.c:3631
 #, fuzzy, gcc-internal-format
 #| msgid "Internal procedure '%s' is invalid in procedure pointer assignment at %L"
 msgid "Internal procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "Sisäinen proseduuri ”%s” on virheellinen proseduuriosoittimessa kohdassa %L"
 
-#: fortran/expr.c:3635
+#: fortran/expr.c:3638
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic %qs at %L is invalid in procedure pointer assignment"
 msgstr "Virheellinen proseduuriosoitinsijoitus kohdassa %L"
 
-#: fortran/expr.c:3643
+#: fortran/expr.c:3646
 #, fuzzy, gcc-internal-format
 msgid "Nonintrinsic elemental procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.c:3666
+#: fortran/expr.c:3669
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in the procedure pointer assignment at %L: mismatch in the calling convention"
 msgstr "Rajapintatäsmäämättömyys proseduuriosoitinsijoituksessa kohdassa %L: %s"
 
-#: fortran/expr.c:3719
+#: fortran/expr.c:3722
 #, fuzzy, gcc-internal-format
 #| msgid "Interface mismatch in procedure pointer assignment at %L: %s"
 msgid "Interface mismatch in procedure pointer assignment at %L: %qs is not a subroutine"
 msgstr "Rajapintatäsmäämättömyys proseduuriosoitinsijoituksessa kohdassa %L: %s"
 
-#: fortran/expr.c:3729 fortran/expr.c:3744
+#: fortran/expr.c:3732 fortran/expr.c:3747
 #, fuzzy, gcc-internal-format
 #| msgid "Expected a procedure for argument '%s' at %L"
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr "Virheellinen proseduuriargumentti kohdassa %L"
 
-#: fortran/expr.c:3735 fortran/expr.c:3750 fortran/resolve.c:2566
+#: fortran/expr.c:3738 fortran/expr.c:3753 fortran/resolve.c:2566
 #, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr ""
 
-#: fortran/expr.c:3762
+#: fortran/expr.c:3765
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %s"
 msgstr "Rajapintatäsmäämättömyys proseduuriosoitinsijoituksessa kohdassa %L: %s"
 
-#: fortran/expr.c:3771
+#: fortran/expr.c:3774
 #, gcc-internal-format
 msgid "Procedure pointer target %qs at %L must be either an intrinsic, host or use associated, referenced or have the EXTERNAL attribute"
 msgstr ""
 
-#: fortran/expr.c:3788
+#: fortran/expr.c:3791
 #, gcc-internal-format, gfc-internal-format
 msgid "Data-pointer-object at %L must be unlimited polymorphic, or of a type with the BIND or SEQUENCE attribute, to be compatible with an unlimited polymorphic target"
 msgstr ""
 
-#: fortran/expr.c:3793
+#: fortran/expr.c:3796
 #, gcc-internal-format, gfc-internal-format
 msgid "Different types in pointer assignment at %L; attempted assignment of %s to %s"
 msgstr "Eri tyypit osoitinsijoituksessa kohdassa %L; yritettiin tyypin %s sijoitusta tyyppiin %s"
 
-#: fortran/expr.c:3802
+#: fortran/expr.c:3805
 #, gcc-internal-format, gfc-internal-format
 msgid "Different kind type parameters in pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3809
+#: fortran/expr.c:3812
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Different ranks in pointer assignment at %L"
 msgstr "Yhteensopimattomat tasot %d ja %d sijoituksessa kohdassa %L"
 
-#: fortran/expr.c:3828
+#: fortran/expr.c:3831
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is smaller than size of the pointer (%ld < %ld) at %L"
 msgstr ""
 
-#: fortran/expr.c:3841
+#: fortran/expr.c:3844
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target must be rank 1 or simply contiguous at %L"
 msgstr ""
 
-#: fortran/expr.c:3845
+#: fortran/expr.c:3848
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is not rank 1 at %L"
 msgstr ""
@@ -56240,147 +56315,152 @@
 #. The test above might need to be extend when F08, Note 5.4 has to be
 #. interpreted in the way that target and pointer with the same coindex
 #. are allowed.
-#: fortran/expr.c:3877 fortran/expr.c:3925
+#: fortran/expr.c:3880 fortran/expr.c:3928
 #, gcc-internal-format, gfc-internal-format
 msgid "Data target at %L shall not have a coindex"
 msgstr ""
 
-#: fortran/expr.c:3880
+#: fortran/expr.c:3883
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr "yhteensopimattomat tyypit sijoituksessa"
 
-#: fortran/expr.c:3888
+#: fortran/expr.c:3891
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr ""
 
-#: fortran/expr.c:3895
+#: fortran/expr.c:3898
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr ""
 
-#: fortran/expr.c:3904
+#: fortran/expr.c:3907
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr ""
 
-#: fortran/expr.c:3912
+#: fortran/expr.c:3915
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/expr.c:3936
+#: fortran/expr.c:3939
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to contiguous pointer from non-contiguous target at %L"
 msgstr ""
 
-#: fortran/expr.c:3975
+#: fortran/expr.c:3978
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr ""
 
-#: fortran/expr.c:4051 fortran/resolve.c:1452
+#: fortran/expr.c:4054 fortran/resolve.c:1452
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr "(%qs:n alustuksen lähistöllä)"
 
-#: fortran/expr.c:4057
+#: fortran/expr.c:4060
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr ""
 
-#: fortran/expr.c:4072 fortran/resolve.c:1458
+#: fortran/expr.c:4075 fortran/resolve.c:1458
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr "(%qs:n alustuksen lähistöllä)"
 
-#: fortran/expr.c:4084
+#: fortran/expr.c:4087
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr ""
 
-#: fortran/expr.c:5512
+#: fortran/expr.c:4557
+#, gcc-internal-format
+msgid "generate_isocbinding_initializer(): bad iso_c_binding type, expected %<c_ptr%> or %<c_funptr%>"
+msgstr ""
+
+#: fortran/expr.c:5568
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.c:5520
+#: fortran/expr.c:5576
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5528
+#: fortran/expr.c:5584
 #, fuzzy, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.c:5537
+#: fortran/expr.c:5593
 #, fuzzy, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.c:5548
+#: fortran/expr.c:5604
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5557
+#: fortran/expr.c:5613
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.c:5570
+#: fortran/expr.c:5626
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5583
+#: fortran/expr.c:5639
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.c:5613
+#: fortran/expr.c:5669
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5621
+#: fortran/expr.c:5677
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.c:5634
+#: fortran/expr.c:5690
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5642
+#: fortran/expr.c:5698
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a variable definition context (%s) at %L"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.c:5654
+#: fortran/expr.c:5710
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs can not appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.c:5713
+#: fortran/expr.c:5769
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:5717
+#: fortran/expr.c:5773
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L associated to expression can not be used in a variable definition context (%s)"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.c:5728
+#: fortran/expr.c:5784
 #, fuzzy, gcc-internal-format
 msgid "Associate-name %qs can not appear in a variable definition context (%s) at %L because its target at %L can not, either"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.c:5770
+#: fortran/expr.c:5826
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr ""
@@ -56390,23 +56470,23 @@
 msgid "can't open input file: %s"
 msgstr "ei voi avata syötetiedostoa: %s"
 
-#: fortran/frontend-passes.c:190
+#: fortran/frontend-passes.c:192
 #, fuzzy, gcc-internal-format
 msgid "No location in statement"
 msgstr "Ei välitetä lausenimiöstä tyhjässä lauseessa kohdassa %L"
 
-#: fortran/frontend-passes.c:205
+#: fortran/frontend-passes.c:207
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected exponent in expression at %C"
 msgid "No location in expression near %L"
 msgstr "Odotettiin eksponenttia lausekkeessa kohdassa %C"
 
-#: fortran/frontend-passes.c:409
+#: fortran/frontend-passes.c:414
 #, gcc-internal-format
 msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
-#: fortran/frontend-passes.c:817 fortran/trans-array.c:1182
+#: fortran/frontend-passes.c:822 fortran/trans-array.c:1182
 #: fortran/trans-array.c:6440 fortran/trans-array.c:7864
 #: fortran/trans-intrinsic.c:7307
 #, fuzzy, gcc-internal-format, gfc-internal-format
@@ -56413,68 +56493,68 @@
 msgid "Creating array temporary at %L"
 msgstr "Luodaan väliaikainen komentotiedosto %s\n"
 
-#: fortran/frontend-passes.c:842 fortran/frontend-passes.c:846
+#: fortran/frontend-passes.c:847 fortran/frontend-passes.c:851
 #, fuzzy, gcc-internal-format
 msgid "Removing call to function %qs at %L"
 msgstr "lopetusalkio puuttuu funktiokutsusta"
 
-#: fortran/frontend-passes.c:1273 fortran/frontend-passes.c:1312
+#: fortran/frontend-passes.c:1278 fortran/frontend-passes.c:1317
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "bad expression"
 msgstr "odotettiin lauseketta"
 
-#: fortran/frontend-passes.c:1308
+#: fortran/frontend-passes.c:1313
 #, fuzzy, gcc-internal-format
 msgid "bad op"
 msgstr "Siirrä alas"
 
-#: fortran/frontend-passes.c:2161
+#: fortran/frontend-passes.c:2166
 #, fuzzy, gcc-internal-format
 msgid "illegal OP in optimize_comparison"
 msgstr "epäkelpo totuusarvolauseke"
 
-#: fortran/frontend-passes.c:2407
+#: fortran/frontend-passes.c:2412
 #, gcc-internal-format
 msgid "Variable %qs at %L set to undefined value inside loop  beginning at %L as INTENT(OUT) argument to subroutine %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:2414
+#: fortran/frontend-passes.c:2419
 #, gcc-internal-format
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to subroutine %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:2637 fortran/frontend-passes.c:2661
+#: fortran/frontend-passes.c:2642 fortran/frontend-passes.c:2666
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L out of bounds (%ld < %ld) in loop beginning at %L"
 msgstr "Taulukkoviite kohdassa %L on rajojen ulkopuolella (%ld < %ld) ulottuvuudessa %d"
 
-#: fortran/frontend-passes.c:2646 fortran/frontend-passes.c:2670
+#: fortran/frontend-passes.c:2651 fortran/frontend-passes.c:2675
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L out of bounds (%ld > %ld) in loop beginning at %L"
 msgstr "Taulukkoviite kohdassa %L on rajojen ulkopuolella (%ld < %ld) ulottuvuudessa %d"
 
-#: fortran/frontend-passes.c:2730
+#: fortran/frontend-passes.c:2735
 #, gcc-internal-format
 msgid "Variable %qs at %L set to undefined value inside loop beginning at %L as INTENT(OUT) argument to function %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:2736
+#: fortran/frontend-passes.c:2741
 #, gcc-internal-format
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:3128 fortran/trans-expr.c:1581
+#: fortran/frontend-passes.c:3133 fortran/trans-expr.c:1581
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr ""
 
-#: fortran/frontend-passes.c:3637
+#: fortran/frontend-passes.c:3642
 #, gcc-internal-format
 msgid "Scalarization using DIMEN_RANGE unimplemented"
 msgstr ""
 
-#: fortran/frontend-passes.c:4429
+#: fortran/frontend-passes.c:4434
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Interchanging loops at %L"
 msgstr "continue-lause silmukan ulkopuolella"
@@ -56600,12 +56680,12 @@
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:970 fortran/resolve.c:16351
+#: fortran/interface.c:970 fortran/resolve.c:16378
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:977 fortran/resolve.c:16369
+#: fortran/interface.c:977 fortran/resolve.c:16396
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
@@ -57829,7 +57909,7 @@
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.c:3369 fortran/resolve.c:14263
+#: fortran/io.c:3369 fortran/resolve.c:14283
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -57998,7 +58078,7 @@
 msgid "Integer too large at %C"
 msgstr "Kokonaisluku liian suuri kohdassa %C"
 
-#: fortran/match.c:580 fortran/parse.c:1132
+#: fortran/match.c:580 fortran/parse.c:1136
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many digits in statement label at %C"
 msgstr ""
@@ -58768,58 +58848,58 @@
 msgid "Expected block name %qs of SELECT construct at %C"
 msgstr "tyhjä esittely"
 
-#: fortran/match.c:6186
+#: fortran/match.c:6201
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in PROTECTED statement at %C"
 msgid "parse error in SELECT TYPE statement at %C"
 msgstr "Syntaksivirhe PROTECTED-lauseessa kohdassa %C"
 
-#: fortran/match.c:6211
+#: fortran/match.c:6226
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr ""
 
-#: fortran/match.c:6249
+#: fortran/match.c:6264
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr "Odottamaton CASE-lause kohdassa %C"
 
-#: fortran/match.c:6301
+#: fortran/match.c:6316
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CASE specification at %C"
 msgstr "Syntaksivirhe CASE-spesifikaatiossa kohdassa %C"
 
-#: fortran/match.c:6319
+#: fortran/match.c:6334
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected TYPE IS statement at %C"
 msgstr "Odottamaton TYPE IS -lause kohdassa %C"
 
-#: fortran/match.c:6351
+#: fortran/match.c:6366
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr ""
 
-#: fortran/match.c:6362
+#: fortran/match.c:6377
 #, gcc-internal-format, gfc-internal-format
 msgid "All the LEN type parameters in the TYPE IS statement at %C must be ASSUMED"
 msgstr ""
 
-#: fortran/match.c:6373
+#: fortran/match.c:6388
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr "Syntaksivirhe TYPE IS -spesifikaatiossa kohdassa %C"
 
-#: fortran/match.c:6449
+#: fortran/match.c:6464
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr "Syntaksvirhe CLASS IS -spesifikaatiossa kohdassa %C"
 
-#: fortran/match.c:6572
+#: fortran/match.c:6587
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr "Odottamaton %s-lause WHERE-lohkossa kohdassa %C"
 
-#: fortran/match.c:6610
+#: fortran/match.c:6625
 #, fuzzy, gcc-internal-format
 #| msgid "Label '%s' at %C doesn't match IF label '%s'"
 msgid "Label %qs at %C doesn't match WHERE label %qs"
@@ -58977,195 +59057,195 @@
 msgid "mio_array_ref(): Unknown array ref"
 msgstr ""
 
-#: fortran/module.c:3716
+#: fortran/module.c:3718
 #, gcc-internal-format, gfc-internal-format
 msgid "Namelist %s cannot be renamed by USE association to %s"
 msgstr ""
 
-#: fortran/module.c:4832
+#: fortran/module.c:4834
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4835
+#: fortran/module.c:4837
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:5029
+#: fortran/module.c:5031
 #, gcc-internal-format
 msgid "%qs of module %qs, imported at %C, is also the name of the current program unit"
 msgstr ""
 
-#: fortran/module.c:5381
+#: fortran/module.c:5383
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5388
+#: fortran/module.c:5390
 #, gcc-internal-format
 msgid "User operator %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5393
+#: fortran/module.c:5395
 #, gcc-internal-format
 msgid "Intrinsic operator %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5628
+#: fortran/module.c:5630
 #, gcc-internal-format
 msgid "write_symbol(): bad module symbol %qs"
 msgstr ""
 
-#: fortran/module.c:5961
+#: fortran/module.c:5963
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr ""
 
-#: fortran/module.c:6148
+#: fortran/module.c:6150
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open module file '%s' for writing at %C: %s"
 msgid "Can't open module file %qs for writing at %C: %s"
 msgstr "Ei voi avata moduulitiedostoa ”%s” kirjoittamista varten kohdassa %C: %s"
 
-#: fortran/module.c:6169
+#: fortran/module.c:6171
 #, fuzzy, gcc-internal-format
 msgid "Error writing module file %qs for writing: %s"
 msgstr "Virhe kirjoitettaessa moduulitiedostoa %s"
 
-#: fortran/module.c:6180
+#: fortran/module.c:6182
 #, fuzzy, gcc-internal-format
 #| msgid "Can't delete module file '%s': %s"
 msgid "Can't delete module file %qs: %s"
 msgstr "Ei voida poistaa moduulitiedostoa ”%s”: %s"
 
-#: fortran/module.c:6183
+#: fortran/module.c:6185
 #, fuzzy, gcc-internal-format
 #| msgid "Can't rename module file '%s' to '%s': %s"
 msgid "Can't rename module file %qs to %qs: %s"
 msgstr "Ei voida nimetä uudelleen moduulitiedostoa ”%s” nimellä ”%s”: %s"
 
-#: fortran/module.c:6189
+#: fortran/module.c:6191
 #, fuzzy, gcc-internal-format
 #| msgid "Can't delete temporary module file '%s': %s"
 msgid "Can't delete temporary module file %qs: %s"
 msgstr "Ei voida poistaa tilapäistä moduulitiedostoa ”%s”: %s"
 
-#: fortran/module.c:6246
+#: fortran/module.c:6248
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' already declared"
 msgid "Symbol %qs at %C already declared"
 msgstr "%qs alustettu ja esitelty %<extern%>-avainsanalla"
 
-#: fortran/module.c:6317
+#: fortran/module.c:6319
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr ""
 
-#: fortran/module.c:6425 fortran/module.c:6769
+#: fortran/module.c:6427 fortran/module.c:6771
 #, gcc-internal-format
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr ""
 
-#: fortran/module.c:6553
+#: fortran/module.c:6555
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr ""
 
-#: fortran/module.c:6574 fortran/module.c:6607 fortran/module.c:6649
+#: fortran/module.c:6576 fortran/module.c:6609 fortran/module.c:6651
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' already declared"
 msgid "Symbol %qs already declared"
 msgstr "%qs alustettu ja esitelty %<extern%>-avainsanalla"
 
-#: fortran/module.c:6754
+#: fortran/module.c:6756
 #, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:6776
+#: fortran/module.c:6778
 #, gcc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr ""
 
-#: fortran/module.c:6844
+#: fortran/module.c:6846
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr ""
 
-#: fortran/module.c:6898
+#: fortran/module.c:6900
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr ""
 
-#: fortran/module.c:6924
+#: fortran/module.c:6926
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr "tyhjä esittely"
 
-#: fortran/module.c:6953
+#: fortran/module.c:6955
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr ""
 
-#: fortran/module.c:6965
+#: fortran/module.c:6967
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
 msgstr "Odotettiin sitomisattribuuttia kohdassa %C"
 
-#: fortran/module.c:6978
+#: fortran/module.c:6980
 #, gcc-internal-format
 msgid "Can't find an intrinsic module named %qs at %C"
 msgstr ""
 
-#: fortran/module.c:6984
+#: fortran/module.c:6986
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr "odotettiin ”::” moduuliluonteen jälkeen paikassa %C, mutta ei löytynyt"
 
-#: fortran/module.c:6990
+#: fortran/module.c:6992
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr "odotettiin ”::” moduuliluonteen jälkeen paikassa %C, mutta ei löytynyt"
 
-#: fortran/module.c:6996
+#: fortran/module.c:6998
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr "odotettiin ”::” moduuliluonteen jälkeen paikassa %C, mutta ei löytynyt"
 
-#: fortran/module.c:7006
+#: fortran/module.c:7008
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open module file '%s' for reading at %C: %s"
 msgid "Can't open module file %qs for reading at %C: %s"
 msgstr "Ei voi avata moduulitiedostoa ”%s” lukemista varten kohdassa %C: %s"
 
-#: fortran/module.c:7009
+#: fortran/module.c:7011
 #, gcc-internal-format
 msgid "Module file %qs has not been generated, either because the module does not contain a MODULE PROCEDURE or there is an error in the module."
 msgstr ""
 
-#: fortran/module.c:7020
+#: fortran/module.c:7022
 #, gcc-internal-format
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:7043
+#: fortran/module.c:7045
 #, gcc-internal-format
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr ""
 
-#: fortran/module.c:7051
+#: fortran/module.c:7053
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr ""
 
-#: fortran/module.c:7066
+#: fortran/module.c:7068
 #, gcc-internal-format, gfc-internal-format
 msgid "Can't USE the same %smodule we're building"
 msgstr ""
 
 #: fortran/openmp.c:296 fortran/openmp.c:397 fortran/openmp.c:692
-#: fortran/openmp.c:3167
+#: fortran/openmp.c:3166
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "COMMON block /%s/ not found at %C"
 msgstr "Odottamaton %s-lause INTERFACE-lohkossa kohdassa %C"
@@ -59244,890 +59324,890 @@
 
 #: fortran/openmp.c:2180
 #, fuzzy, gcc-internal-format, gfc-internal-format
-msgid "Invalid argument to !$ACC WAIT at %L"
+msgid "Invalid argument to !$ACC WAIT at %C"
 msgstr "Virheellinen proseduuriargumentti kohdassa %L"
 
-#: fortran/openmp.c:2188
+#: fortran/openmp.c:2187
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT clause at %L requires a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/openmp.c:2221
+#: fortran/openmp.c:2220
 #, gcc-internal-format, gfc-internal-format
 msgid "ACC CACHE directive must be inside of loop %C"
 msgstr ""
 
-#: fortran/openmp.c:2252
+#: fortran/openmp.c:2251
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for typename"
 msgid "Multiple loop axes specified for routine"
 msgstr "tallennusluokka annettu typenamelle"
 
-#: fortran/openmp.c:2278
+#: fortran/openmp.c:2277
 #, gcc-internal-format, gfc-internal-format
 msgid "Only the !$ACC ROUTINE form without list is allowed in interface block at %C"
 msgstr ""
 
-#: fortran/openmp.c:2306
+#: fortran/openmp.c:2305
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgid "Syntax error in !$ACC ROUTINE ( NAME ) at %C, invalid function name %s"
 msgstr "Syntaksivirhe !GCC$ ATTRIBUTES-lauseessa kohdassa %C"
 
-#: fortran/openmp.c:2315
+#: fortran/openmp.c:2314
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgid "Syntax error in !$ACC ROUTINE ( NAME ) at %C"
 msgstr "Syntaksivirhe !GCC$ ATTRIBUTES-lauseessa kohdassa %C"
 
-#: fortran/openmp.c:2322
+#: fortran/openmp.c:2321
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$ACC ROUTINE ( NAME ) at %C, expecting ')' after NAME"
 msgstr ""
 
-#: fortran/openmp.c:2457 fortran/openmp.c:2481
+#: fortran/openmp.c:2456 fortran/openmp.c:2480
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP CRITICAL statement at %C"
 msgstr "Odottamatonta roskaa ELSE IF -lauseen jälkeen kohdassa %C"
 
-#: fortran/openmp.c:2548
+#: fortran/openmp.c:2547
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP FLUSH statement at %C"
 msgstr "Odottamatonta roskaa ELSE IF -lauseen jälkeen kohdassa %C"
 
-#: fortran/openmp.c:2942 fortran/openmp.c:6225
+#: fortran/openmp.c:2941 fortran/openmp.c:6230
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined %s !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2946 fortran/openmp.c:6229
+#: fortran/openmp.c:2945 fortran/openmp.c:6234
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2951
+#: fortran/openmp.c:2950
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2953
+#: fortran/openmp.c:2952
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2973
+#: fortran/openmp.c:2972
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after !$OMP DECLARE REDUCTION at %C"
 msgstr "tyhjä esittely"
 
-#: fortran/openmp.c:3010
+#: fortran/openmp.c:3009
 #, gcc-internal-format, gfc-internal-format
 msgid "Only the !$OMP DECLARE TARGET form without clauses is allowed in interface block at %C"
 msgstr ""
 
-#: fortran/openmp.c:3025
+#: fortran/openmp.c:3024
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after !$OMP DECLARE TARGET at %C"
 msgstr "tyhjä esittely"
 
-#: fortran/openmp.c:3048
+#: fortran/openmp.c:3047
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Symbol '%s' at %C is already in a COMMON block"
 msgid "OMP DECLARE TARGET variable at %L is an element of a COMMON block"
 msgstr "Symboli ”%s” kohdassa %C on jo COMMON-lohkossa"
 
-#: fortran/openmp.c:3053
+#: fortran/openmp.c:3052
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET variable at %L previously mentioned in LINK clause and later in TO clause"
 msgstr ""
 
-#: fortran/openmp.c:3059
+#: fortran/openmp.c:3058
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET variable at %L previously mentioned in TO clause and later in LINK clause"
 msgstr ""
 
-#: fortran/openmp.c:3063
+#: fortran/openmp.c:3062
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable at %L mentioned multiple times in clauses of the same OMP DECLARE TARGET directive"
 msgstr ""
 
-#: fortran/openmp.c:3078
+#: fortran/openmp.c:3077
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET COMMON at %L previously mentioned in LINK clause and later in TO clause"
 msgstr ""
 
-#: fortran/openmp.c:3084
+#: fortran/openmp.c:3083
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET COMMON at %L previously mentioned in TO clause and later in LINK clause"
 msgstr ""
 
-#: fortran/openmp.c:3088
+#: fortran/openmp.c:3087
 #, gcc-internal-format, gfc-internal-format
 msgid "COMMON at %L mentioned multiple times in clauses of the same OMP DECLARE TARGET directive"
 msgstr ""
 
-#: fortran/openmp.c:3115
+#: fortran/openmp.c:3114
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in VOLATILE statement at %C"
 msgid "Syntax error in !$OMP DECLARE TARGET list at %C"
 msgstr "Syntaksivirhe VOLATILE-lauseessa kohdassa %C"
 
-#: fortran/openmp.c:3147
+#: fortran/openmp.c:3146
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate variable at %C is an element of a COMMON block"
 msgstr ""
 
-#: fortran/openmp.c:3184
+#: fortran/openmp.c:3183
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after OMP THREADPRIVATE at %C"
 msgstr "Odottamatonta roskaa ELSE IF -lauseen jälkeen kohdassa %C"
 
-#: fortran/openmp.c:3191
+#: fortran/openmp.c:3190
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$OMP THREADPRIVATE list at %C"
 msgstr "Syntaksivirhe argumenttiluettelossa kohdassa %C"
 
-#: fortran/openmp.c:3405
+#: fortran/openmp.c:3404
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after TASKWAIT clause at %C"
 msgstr "Odottamatonta roskaa ELSE-lauseen jälkeen kohdassa %C"
 
-#: fortran/openmp.c:3419
+#: fortran/openmp.c:3418
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after TASKYIELD clause at %C"
 msgstr "Odottamatonta roskaa ELSE IF -lauseen jälkeen kohdassa %C"
 
-#: fortran/openmp.c:3478
+#: fortran/openmp.c:3477
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP WORKSHARE statement at %C"
 msgstr "Odottamatonta roskaa ELSE IF -lauseen jälkeen kohdassa %C"
 
-#: fortran/openmp.c:3492
+#: fortran/openmp.c:3491
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP MASTER statement at %C"
 msgstr "Odottamatonta roskaa ELSE IF -lauseen jälkeen kohdassa %C"
 
-#: fortran/openmp.c:3551
+#: fortran/openmp.c:3550
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP ATOMIC statement at %C"
 msgstr "Odottamatonta roskaa ELSE IF -lauseen jälkeen kohdassa %C"
 
-#: fortran/openmp.c:3578
+#: fortran/openmp.c:3577
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP BARRIER statement at %C"
 msgstr "Odottamatonta roskaa ELSE IF -lauseen jälkeen kohdassa %C"
 
-#: fortran/openmp.c:3592
+#: fortran/openmp.c:3591
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP TASKGROUP statement at %C"
 msgstr "Odottamatonta roskaa ELSE IF -lauseen jälkeen kohdassa %C"
 
-#: fortran/openmp.c:3642
+#: fortran/openmp.c:3641
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP CANCELLATION POINT statement at %C"
 msgstr "tyhjä esittely"
 
-#: fortran/openmp.c:3662
+#: fortran/openmp.c:3661
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after NOWAIT clause at %C"
 msgstr "Odottamatonta roskaa ELSE-lauseen jälkeen kohdassa %C"
 
-#: fortran/openmp.c:3704
+#: fortran/openmp.c:3703
 #, gcc-internal-format, gfc-internal-format
 msgid "%s clause at %L requires a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/openmp.c:3715
+#: fortran/openmp.c:3714
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in CASE statement at %L must be of type %s"
 msgid "INTEGER expression of %s clause at %L must be positive"
 msgstr "Lauseke CASE-lauseessa kohdassa %L on oltava %s-tyyppinen"
 
-#: fortran/openmp.c:3726
+#: fortran/openmp.c:3725
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in CASE statement at %L must be of type %s"
 msgid "INTEGER expression of %s clause at %L must be non-negative"
 msgstr "Lauseke CASE-lauseessa kohdassa %L on oltava %s-tyyppinen"
 
-#: fortran/openmp.c:3737
+#: fortran/openmp.c:3736
 #, gcc-internal-format
 msgid "POINTER object %qs of derived type in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3740
+#: fortran/openmp.c:3739
 #, fuzzy, gcc-internal-format
 #| msgid "Can't convert %s to %s at %L"
 msgid "Cray pointer object %qs of derived type in %s clause at %L"
 msgstr "Ei voi muuntaa tyyppiä %s tyyppiin %s kohdassa %L"
 
-#: fortran/openmp.c:3743
+#: fortran/openmp.c:3742
 #, fuzzy, gcc-internal-format
 #| msgid "Can't convert %s to %s at %L"
 msgid "Cray pointee object %qs of derived type in %s clause at %L"
 msgstr "Ei voi muuntaa tyyppiä %s tyyppiin %s kohdassa %L"
 
-#: fortran/openmp.c:3749 fortran/openmp.c:4687
+#: fortran/openmp.c:3748 fortran/openmp.c:4686
 #, gcc-internal-format
 msgid "POINTER object %qs of polymorphic type in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3754
+#: fortran/openmp.c:3753
 #, fuzzy, gcc-internal-format
 #| msgid "Can't convert %s to %s at %L"
 msgid "Cray pointer object %qs of polymorphic type in %s clause at %L"
 msgstr "Ei voi muuntaa tyyppiä %s tyyppiin %s kohdassa %L"
 
-#: fortran/openmp.c:3759
+#: fortran/openmp.c:3758
 #, fuzzy, gcc-internal-format
 #| msgid "Can't convert %s to %s at %L"
 msgid "Cray pointee object %qs of polymorphic type in %s clause at %L"
 msgstr "Ei voi muuntaa tyyppiä %s tyyppiin %s kohdassa %L"
 
-#: fortran/openmp.c:3769 fortran/openmp.c:4385 fortran/openmp.c:4490
+#: fortran/openmp.c:3768 fortran/openmp.c:4384 fortran/openmp.c:4489
 #, fuzzy, gcc-internal-format
 msgid "Assumed size array %qs in %s clause at %L"
 msgstr "%Jlohkoattribuutti ei ole sallittu %qD:lle"
 
-#: fortran/openmp.c:3772
+#: fortran/openmp.c:3771
 #, fuzzy, gcc-internal-format
 msgid "Assumed rank array %qs in %s clause at %L"
 msgstr "%Jlohkoattribuutti ei ole sallittu %qD:lle"
 
-#: fortran/openmp.c:3776
+#: fortran/openmp.c:3775
 #, gcc-internal-format
 msgid "Noncontiguous deferred shape array %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3784
+#: fortran/openmp.c:3783
 #, gcc-internal-format
 msgid "ALLOCATABLE object %qs of derived type in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3789
+#: fortran/openmp.c:3788
 #, gcc-internal-format
 msgid "ALLOCATABLE object %qs of polymorphic type in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3801 fortran/openmp.c:4480
+#: fortran/openmp.c:3800 fortran/openmp.c:4479
 #, fuzzy, gcc-internal-format
 #| msgid "Object '%s' is not a variable at %L"
 msgid "POINTER object %qs in %s clause at %L"
 msgstr "Objekti ”%s” ei ole muuttuja kohdassa %L"
 
-#: fortran/openmp.c:3806 fortran/openmp.c:4691
+#: fortran/openmp.c:3805 fortran/openmp.c:4690
 #, fuzzy, gcc-internal-format
 #| msgid "Can't convert %s to %s at %L"
 msgid "Cray pointer object %qs in %s clause at %L"
 msgstr "Ei voi muuntaa tyyppiä %s tyyppiin %s kohdassa %L"
 
-#: fortran/openmp.c:3811 fortran/openmp.c:4694
+#: fortran/openmp.c:3810 fortran/openmp.c:4693
 #, fuzzy, gcc-internal-format
 #| msgid "Can't convert %s to %s at %L"
 msgid "Cray pointee object %qs in %s clause at %L"
 msgstr "Ei voi muuntaa tyyppiä %s tyyppiin %s kohdassa %L"
 
-#: fortran/openmp.c:3816 fortran/openmp.c:4682
+#: fortran/openmp.c:3815 fortran/openmp.c:4681
 #, gcc-internal-format
 msgid "ALLOCATABLE object %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3819
+#: fortran/openmp.c:3818
 #, fuzzy, gcc-internal-format
 #| msgid "Object '%s' is not a variable at %L"
 msgid "VALUE object %qs in %s clause at %L"
 msgstr "Objekti ”%s” ei ole muuttuja kohdassa %L"
 
-#: fortran/openmp.c:3862
+#: fortran/openmp.c:3861
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Implicitly declared function %s used in !$OMP DECLARE REDUCTION at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/openmp.c:3911
+#: fortran/openmp.c:3910
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Implicitly declared subroutine %s used in !$OMP DECLARE REDUCTION at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/openmp.c:3944
+#: fortran/openmp.c:3943
 #, gcc-internal-format, gfc-internal-format
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:3952 fortran/openmp.c:3963 fortran/resolve.c:10028
-#: fortran/resolve.c:11295
+#: fortran/openmp.c:3951 fortran/openmp.c:3962 fortran/resolve.c:10041
+#: fortran/resolve.c:11315
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/openmp.c:3967
+#: fortran/openmp.c:3966
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause without modifier at %L used together with IF clauses with modifiers"
 msgstr ""
 
-#: fortran/openmp.c:4044
+#: fortran/openmp.c:4043
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause modifier %s at %L not appropriate for the current OpenMP construct"
 msgstr ""
 
-#: fortran/openmp.c:4054
+#: fortran/openmp.c:4053
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/openmp.c:4064
+#: fortran/openmp.c:4063
 #, gcc-internal-format, gfc-internal-format
 msgid "SCHEDULE clause's chunk_size at %L requires a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/openmp.c:4069
+#: fortran/openmp.c:4068
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in CASE statement at %L must be of type %s"
 msgid "INTEGER expression of SCHEDULE clause's chunk_size at %L must be positive"
 msgstr "Lauseke CASE-lauseessa kohdassa %L on oltava %s-tyyppinen"
 
-#: fortran/openmp.c:4084
+#: fortran/openmp.c:4083
 #, fuzzy, gcc-internal-format
 #| msgid "Variable type is UNKNOWN in assignment at %L"
 msgid "Variable %qs is not a dummy argument at %L"
 msgstr "Muuttujatyyppi on UNKNOWN sijoituksessa kohdassa %L"
 
-#: fortran/openmp.c:4116
+#: fortran/openmp.c:4115 fortran/openmp.c:5998
 #, fuzzy, gcc-internal-format
 #| msgid "Object '%s' is not a variable at %L"
 msgid "Object %qs is not a variable at %L"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/openmp.c:4132 fortran/openmp.c:4143 fortran/openmp.c:4151
-#: fortran/openmp.c:4162 fortran/openmp.c:4174 fortran/openmp.c:4189
-#: fortran/openmp.c:6023
+#: fortran/openmp.c:4131 fortran/openmp.c:4142 fortran/openmp.c:4150
+#: fortran/openmp.c:4161 fortran/openmp.c:4173 fortran/openmp.c:4188
+#: fortran/openmp.c:6028
 #, gcc-internal-format
 msgid "Symbol %qs present on multiple clauses at %L"
 msgstr ""
 
-#: fortran/openmp.c:4196
+#: fortran/openmp.c:4195
 #, fuzzy, gcc-internal-format
 msgid "Array %qs is not permitted in reduction at %L"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: fortran/openmp.c:4209
+#: fortran/openmp.c:4208
 #, gcc-internal-format
 msgid "Symbol %qs present on both FROM and TO clauses at %L"
 msgstr ""
 
-#: fortran/openmp.c:4231
+#: fortran/openmp.c:4230
 #, gcc-internal-format
 msgid "Non-THREADPRIVATE object %qs in COPYIN clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4239
+#: fortran/openmp.c:4238
 #, gcc-internal-format
 msgid "Assumed size array %qs in COPYPRIVATE clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4242
+#: fortran/openmp.c:4241
 #, gcc-internal-format
 msgid "INTENT(IN) POINTER %qs in COPYPRIVATE clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4250
+#: fortran/openmp.c:4249
 #, gcc-internal-format
 msgid "THREADPRIVATE object %qs in SHARED clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4253
+#: fortran/openmp.c:4252
 #, gcc-internal-format
 msgid "Cray pointee %qs in SHARED clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4256
+#: fortran/openmp.c:4255
 #, gcc-internal-format
 msgid "ASSOCIATE name %qs in SHARED clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4271
+#: fortran/openmp.c:4270
 #, gcc-internal-format
 msgid "%qs in ALIGNED clause must be POINTER, ALLOCATABLE, Cray pointer or C_PTR at %L"
 msgstr ""
 
-#: fortran/openmp.c:4283
+#: fortran/openmp.c:4282
 #, fuzzy, gcc-internal-format
 msgid "%qs in ALIGNED clause at %L requires a scalar positive constant integer alignment expression"
 msgstr "etumerkillisen ja etumerkittömän kokonaislukulausekkeen vertailu"
 
-#: fortran/openmp.c:4302
+#: fortran/openmp.c:4301
 #, gcc-internal-format, gfc-internal-format
 msgid "SINK dependence type only allowed on ORDERED directive at %L"
 msgstr ""
 
-#: fortran/openmp.c:4306
+#: fortran/openmp.c:4305
 #, gcc-internal-format, gfc-internal-format
 msgid "DEPEND SINK used together with DEPEND SOURCE on the same construct at %L"
 msgstr ""
 
-#: fortran/openmp.c:4316
+#: fortran/openmp.c:4315
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SINK addend not a constant integer at %L"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: fortran/openmp.c:4322
+#: fortran/openmp.c:4321
 #, gcc-internal-format, gfc-internal-format
 msgid "Only SOURCE or SINK dependence types are allowed on ORDERED directive at %L"
 msgstr ""
 
-#: fortran/openmp.c:4333 fortran/openmp.c:4354
+#: fortran/openmp.c:4332 fortran/openmp.c:4353
 #, gcc-internal-format
 msgid "%qs in %s clause at %L is not a proper array section"
 msgstr ""
 
-#: fortran/openmp.c:4337
+#: fortran/openmp.c:4336
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coarrays not supported in %s clause at %L"
 msgstr "osoittimet eivät ole sallittuja case-arvoja"
 
-#: fortran/openmp.c:4346
+#: fortran/openmp.c:4345
 #, gcc-internal-format, gfc-internal-format
 msgid "Stride should not be specified for array section in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4367
+#: fortran/openmp.c:4366
 #, gcc-internal-format
 msgid "%qs in DEPEND clause at %L is a zero size array section"
 msgstr ""
 
-#: fortran/openmp.c:4403
+#: fortran/openmp.c:4402
 #, gcc-internal-format, gfc-internal-format
 msgid "TARGET%s with map-type other than TO, FROM, TOFROM, or ALLOC on MAP clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4419
+#: fortran/openmp.c:4418
 #, gcc-internal-format, gfc-internal-format
 msgid "TARGET ENTER DATA with map-type other than TO, or ALLOC on MAP clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4434
+#: fortran/openmp.c:4433
 #, gcc-internal-format, gfc-internal-format
 msgid "TARGET EXIT DATA with map-type other than FROM, RELEASE, or DELETE on MAP clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4450 fortran/openmp.c:4466
+#: fortran/openmp.c:4449 fortran/openmp.c:4465
 #, gcc-internal-format
 msgid "THREADPRIVATE object %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4453 fortran/openmp.c:4469
+#: fortran/openmp.c:4452 fortran/openmp.c:4468
 #, fuzzy, gcc-internal-format
 msgid "Cray pointee %qs in %s clause at %L"
 msgstr "Virheellinen proseduuriargumentti kohdassa %L"
 
-#: fortran/openmp.c:4472
+#: fortran/openmp.c:4471
 #, gcc-internal-format
 msgid "ASSOCIATE name %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4477
+#: fortran/openmp.c:4476
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer %qs in %s clause at %L"
 msgstr "Rajapintatäsmäämättömyys proseduuriosoitinsijoituksessa kohdassa %L: %s"
 
-#: fortran/openmp.c:4483
+#: fortran/openmp.c:4482
 #, fuzzy, gcc-internal-format
 #| msgid "Can't convert %s to %s at %L"
 msgid "Cray pointer %qs in %s clause at %L"
 msgstr "Ei voi muuntaa tyyppiä %s tyyppiin %s kohdassa %L"
 
-#: fortran/openmp.c:4493
+#: fortran/openmp.c:4492
 #, gcc-internal-format
 msgid "Variable %qs in %s clause is used in NAMELIST statement at %L"
 msgstr ""
 
 #. case OMP_LIST_REDUCTION:
-#: fortran/openmp.c:4503
+#: fortran/openmp.c:4502
 #, gcc-internal-format
 msgid "INTENT(IN) POINTER %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4596
+#: fortran/openmp.c:4595
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP DECLARE REDUCTION %s not found for type %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:4622
+#: fortran/openmp.c:4621
 #, gcc-internal-format, gfc-internal-format
 msgid "LINEAR clause modifier used on DO or SIMD construct at %L"
 msgstr ""
 
-#: fortran/openmp.c:4627
+#: fortran/openmp.c:4626
 #, gcc-internal-format, gfc-internal-format
 msgid "LINEAR clause specified together with ORDERED clause with argument at %L"
 msgstr ""
 
-#: fortran/openmp.c:4632
+#: fortran/openmp.c:4631
 #, fuzzy, gcc-internal-format
 #| msgid "%s at %L must be INTEGER"
 msgid "LINEAR variable %qs must be INTEGER at %L"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/openmp.c:4637
+#: fortran/openmp.c:4636
 #, fuzzy, gcc-internal-format
 #| msgid "Actual argument for '%s' must be a pointer at %L"
 msgid "LINEAR dummy argument %qs with VALUE attribute with %s modifier at %L"
 msgstr "Varsinaisen argumentin kohteelle ”%s” on oltava osoitin kohdassa %L"
 
-#: fortran/openmp.c:4648
+#: fortran/openmp.c:4647
 #, gcc-internal-format
 msgid "%qs in LINEAR clause at %L requires a scalar integer linear-step expression"
 msgstr ""
 
-#: fortran/openmp.c:4665
+#: fortran/openmp.c:4664
 #, fuzzy, gcc-internal-format
 msgid "%qs in LINEAR clause at %L requires a constant integer linear-step expression or dummy argument specified in UNIFORM clause"
 msgstr "etumerkillisen ja etumerkittömän kokonaislukulausekkeen vertailu"
 
-#: fortran/openmp.c:4699
+#: fortran/openmp.c:4698
 #, fuzzy, gcc-internal-format
 msgid "%s clause variable %qs at %L is neither a POINTER nor an array"
 msgstr "indeksoitu arvo ei ole taulukko eikä osoitin"
 
-#: fortran/openmp.c:4731
+#: fortran/openmp.c:4730
 #, gcc-internal-format, gfc-internal-format
 msgid "DIST_SCHEDULE clause's chunk_size at %L requires a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/openmp.c:4763
+#: fortran/openmp.c:4762
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Incompatible use of TILE and COLLAPSE at %L"
 msgstr "Yhteensopimattomat tasot %d ja %d sijoituksessa kohdassa %L"
 
-#: fortran/openmp.c:4765
+#: fortran/openmp.c:4764
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE dependence type only allowed on ORDERED directive at %L"
 msgstr ""
 
-#: fortran/openmp.c:4778
+#: fortran/openmp.c:4777
 #, gcc-internal-format, gfc-internal-format
 msgid "%s must contain at least one MAP clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4875
+#: fortran/openmp.c:4874
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unexpected !$OMP ATOMIC expression at %L"
 msgstr "Odottamatonta roskaa ELSE IF -lauseen jälkeen kohdassa %C"
 
-#: fortran/openmp.c:4904
+#: fortran/openmp.c:4903
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC statement must set a scalar variable of intrinsic type at %L"
 msgstr ""
 
-#: fortran/openmp.c:4929
+#: fortran/openmp.c:4928
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC READ statement must read from a scalar variable of intrinsic type at %L"
 msgstr ""
 
-#: fortran/openmp.c:4934
+#: fortran/openmp.c:4933
 #, gcc-internal-format, gfc-internal-format
 msgid "expr in !$OMP ATOMIC WRITE assignment var = expr must be scalar and cannot reference var at %L"
 msgstr ""
 
-#: fortran/openmp.c:4956 fortran/openmp.c:5247
+#: fortran/openmp.c:4955 fortran/openmp.c:5246
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE capture statement must read from a scalar variable of intrinsic type at %L"
 msgstr ""
 
-#: fortran/openmp.c:4971
+#: fortran/openmp.c:4970
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE update statement must set a scalar variable of intrinsic type at %L"
 msgstr ""
 
-#: fortran/openmp.c:4978 fortran/openmp.c:5254
+#: fortran/openmp.c:4977 fortran/openmp.c:5253
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE capture statement reads from different variable than update statement writes into at %L"
 msgstr ""
 
-#: fortran/openmp.c:4994
+#: fortran/openmp.c:4993
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC with ALLOCATABLE variable at %L"
 msgstr "kääntäjänsisäisten ”!$OMP ATOMIC”-argumenttien on oltava skaalaareja kohdassa %L"
 
-#: fortran/openmp.c:5036
+#: fortran/openmp.c:5035
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "!$OMP ATOMIC assignment intrinsic must be MIN, MAX, IAND, IOR or IEOR at %L"
 msgid "!$OMP ATOMIC assignment operator must be binary +, *, -, /, .AND., .OR., .EQV. or .NEQV. at %L"
 msgstr "kääntäjänsisäisen ”!$OMP ATOMIC”-sijoituksen on oltava MIN, MAX, IAND, IOR tai IEOR kohdassa %L"
 
-#: fortran/openmp.c:5084
+#: fortran/openmp.c:5083
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment must be var = var op expr or var = expr op var at %L"
 msgstr ""
 
-#: fortran/openmp.c:5098
+#: fortran/openmp.c:5097
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC var = var op expr not mathematically equivalent to var = var op (expr) at %L"
 msgstr ""
 
-#: fortran/openmp.c:5130
+#: fortran/openmp.c:5129
 #, gcc-internal-format, gfc-internal-format
 msgid "expr in !$OMP ATOMIC assignment var = var op expr must be scalar and cannot reference var at %L"
 msgstr ""
 
-#: fortran/openmp.c:5154
+#: fortran/openmp.c:5153
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment intrinsic IAND, IOR or IEOR must have two arguments at %L"
 msgstr "kääntäjänsisäisellä ”!$OMP ATOMIC”-sijoituksella IAND, IOR tai IEOR täytyy olla kaksi argumenttia kohdassa %L"
 
-#: fortran/openmp.c:5161
+#: fortran/openmp.c:5160
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment intrinsic must be MIN, MAX, IAND, IOR or IEOR at %L"
 msgstr "kääntäjänsisäisen ”!$OMP ATOMIC”-sijoituksen on oltava MIN, MAX, IAND, IOR tai IEOR kohdassa %L"
 
-#: fortran/openmp.c:5178
+#: fortran/openmp.c:5177
 #, fuzzy, gcc-internal-format
 #| msgid "!$OMP ATOMIC intrinsic arguments except one must not reference '%s' at %L"
 msgid "!$OMP ATOMIC intrinsic arguments except one must not reference %qs at %L"
 msgstr "kääntäjänsisäiset ”!$OMP ATOMIC”-argumentit paitsi yksi eivät saa viitata kohteeseen ”%s” kohdassa %L"
 
-#: fortran/openmp.c:5185
+#: fortran/openmp.c:5184
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC intrinsic arguments must be scalar at %L"
 msgstr "kääntäjänsisäisten ”!$OMP ATOMIC”-argumenttien on oltava skaalaareja kohdassa %L"
 
-#: fortran/openmp.c:5193
+#: fortran/openmp.c:5192
 #, fuzzy, gcc-internal-format
 #| msgid "First or last !$OMP ATOMIC intrinsic argument must be '%s' at %L"
 msgid "First or last !$OMP ATOMIC intrinsic argument must be %qs at %L"
 msgstr "Ensimmäisen tai viimeisen kääntäjänsisäisen ”!$OMP ATOMIC”-argumentin on oltava ”%s” kohdassa %L"
 
-#: fortran/openmp.c:5211
+#: fortran/openmp.c:5210
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment must have an operator or intrinsic on right hand side at %L"
 msgstr "”!$OMP ATOMIC”-sijoituksen on oltava operaattori tai kääntäjänsisäinen oikealla puolella kohdassa %L"
 
-#: fortran/openmp.c:5225
+#: fortran/openmp.c:5224
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE capture statement must set a scalar variable of intrinsic type at %L"
 msgstr ""
 
-#: fortran/openmp.c:5544
+#: fortran/openmp.c:5543
 #, gcc-internal-format, gfc-internal-format
 msgid "%s cannot be a DO WHILE or DO without loop control at %L"
 msgstr ""
 
-#: fortran/openmp.c:5550
+#: fortran/openmp.c:5549
 #, gcc-internal-format, gfc-internal-format
 msgid "%s cannot be a DO CONCURRENT loop at %L"
 msgstr ""
 
-#: fortran/openmp.c:5556
+#: fortran/openmp.c:5555
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "!$OMP DO iteration variable must not be THREADPRIVATE at %L"
 msgid "%s iteration variable must be of type integer at %L"
 msgstr "”!$OMP DO”-iteraatiomuuttuja ei saa olla THREADPRIVATE kohdassa %L"
 
-#: fortran/openmp.c:5560
+#: fortran/openmp.c:5559
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "!$OMP DO iteration variable must not be THREADPRIVATE at %L"
 msgid "%s iteration variable must not be THREADPRIVATE at %L"
 msgstr "”!$OMP DO”-iteraatiomuuttuja ei saa olla THREADPRIVATE kohdassa %L"
 
-#: fortran/openmp.c:5573
+#: fortran/openmp.c:5572
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "!$OMP DO iteration variable present on clause other than PRIVATE or LASTPRIVATE at %L"
 msgid "%s iteration variable present on clause other than PRIVATE or LASTPRIVATE at %L"
 msgstr "”!$OMP DO”-iteraatiomuuttuja on läsnä muussa lauseessa kuin PRIVATE tai LASTPRIVATE kohdassa %L"
 
-#: fortran/openmp.c:5577
+#: fortran/openmp.c:5576
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "!$OMP DO iteration variable present on clause other than PRIVATE or LASTPRIVATE at %L"
 msgid "%s iteration variable present on clause other than LASTPRIVATE at %L"
 msgstr "”!$OMP DO”-iteraatiomuuttuja on läsnä muussa lauseessa kuin PRIVATE tai LASTPRIVATE kohdassa %L"
 
-#: fortran/openmp.c:5581
+#: fortran/openmp.c:5580
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "!$OMP DO iteration variable present on clause other than PRIVATE or LASTPRIVATE at %L"
 msgid "%s iteration variable present on clause other than LINEAR at %L"
 msgstr "”!$OMP DO”-iteraatiomuuttuja on läsnä muussa lauseessa kuin PRIVATE tai LASTPRIVATE kohdassa %L"
 
-#: fortran/openmp.c:5599
+#: fortran/openmp.c:5598
 #, gcc-internal-format, gfc-internal-format
 msgid "%s collapsed loops don't form rectangular iteration space at %L"
 msgstr ""
 
-#: fortran/openmp.c:5611
+#: fortran/openmp.c:5610
 #, gcc-internal-format, gfc-internal-format
 msgid "collapsed %s loops not perfectly nested at %L"
 msgstr ""
 
-#: fortran/openmp.c:5620 fortran/openmp.c:5628
+#: fortran/openmp.c:5619 fortran/openmp.c:5627
 #, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for collapsed %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:5712 fortran/openmp.c:5725
+#: fortran/openmp.c:5711 fortran/openmp.c:5724
 #, gcc-internal-format, gfc-internal-format
 msgid "The %s directive cannot be specified within a %s region at %L"
 msgstr ""
 
-#: fortran/openmp.c:5744
+#: fortran/openmp.c:5743
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP cannot be a DO WHILE or DO without loop control at %L"
 msgstr ""
 
-#: fortran/openmp.c:5750
+#: fortran/openmp.c:5749
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "!$OMP DO iteration variable must not be THREADPRIVATE at %L"
 msgid "!$ACC LOOP iteration variable must be of type integer at %L"
 msgstr "”!$OMP DO”-iteraatiomuuttuja ei saa olla THREADPRIVATE kohdassa %L"
 
-#: fortran/openmp.c:5766
+#: fortran/openmp.c:5765
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s loops don't form rectangular iteration space at %L"
 msgstr ""
 
-#: fortran/openmp.c:5778
+#: fortran/openmp.c:5777
 #, gcc-internal-format, gfc-internal-format
 msgid "%s !$ACC LOOP loops not perfectly nested at %L"
 msgstr ""
 
-#: fortran/openmp.c:5788 fortran/openmp.c:5797
+#: fortran/openmp.c:5787 fortran/openmp.c:5796
 #, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for %s !$ACC LOOP at %L"
 msgstr ""
 
-#: fortran/openmp.c:5812 fortran/openmp.c:5819
+#: fortran/openmp.c:5811 fortran/openmp.c:5818
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s in PARALLEL region doesn't allow %s arguments at %L"
 msgstr ""
 
-#: fortran/openmp.c:5841
+#: fortran/openmp.c:5840
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside another loop parallelized across gangs at %L"
 msgstr ""
 
-#: fortran/openmp.c:5845 fortran/openmp.c:5849
+#: fortran/openmp.c:5844 fortran/openmp.c:5848
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside loop parallelized across workers at %L"
 msgstr ""
 
-#: fortran/openmp.c:5856
+#: fortran/openmp.c:5855
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across workers at %L"
 msgstr ""
 
-#: fortran/openmp.c:5860
+#: fortran/openmp.c:5859
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across vectors at %L"
 msgstr ""
 
-#: fortran/openmp.c:5866
+#: fortran/openmp.c:5865
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across vectors is not allowed inside another loop parallelized across vectors at %L"
 msgstr ""
 
-#: fortran/openmp.c:5878
+#: fortran/openmp.c:5877
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with INDEPENDENT at %L"
 msgstr ""
 
-#: fortran/openmp.c:5880
+#: fortran/openmp.c:5879
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with GANG at %L"
 msgstr ""
 
-#: fortran/openmp.c:5882
+#: fortran/openmp.c:5881
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with WORKER at %L"
 msgstr ""
 
-#: fortran/openmp.c:5884
+#: fortran/openmp.c:5883
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with VECTOR at %L"
 msgstr ""
 
-#: fortran/openmp.c:5886
+#: fortran/openmp.c:5885
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with AUTO at %L"
 msgstr ""
 
-#: fortran/openmp.c:5891
+#: fortran/openmp.c:5890
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with GANG at %L"
 msgstr ""
 
-#: fortran/openmp.c:5893
+#: fortran/openmp.c:5892
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with WORKER at %L"
 msgstr ""
 
-#: fortran/openmp.c:5895
+#: fortran/openmp.c:5894
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with VECTOR at %L"
 msgstr ""
 
-#: fortran/openmp.c:5899
+#: fortran/openmp.c:5898
 #, gcc-internal-format, gfc-internal-format
 msgid "Tiled loop cannot be parallelized across gangs, workers and vectors at the same time at %L"
 msgstr ""
 
-#: fortran/openmp.c:5934
+#: fortran/openmp.c:5933
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "TILE requires constant expression at %L"
 msgstr "ei-vakio alustuslauseke kohdassa %L"
 
-#: fortran/openmp.c:5999
+#: fortran/openmp.c:6004
 #, fuzzy, gcc-internal-format
 #| msgid "Object '%s' is not a variable at %L"
 msgid "PARAMETER object %qs is not allowed at %L"
 msgstr "Objekti ”%s” ei ole muuttuja kohdassa %L"
 
-#: fortran/openmp.c:6006
+#: fortran/openmp.c:6011
 #, fuzzy, gcc-internal-format
 msgid "Array sections: %qs not allowed in !$ACC DECLARE at %L"
 msgstr "funktiolle %2$qE annettu argumentin %1$d tyyppi on yhteensopimaton"
 
-#: fortran/openmp.c:6133
+#: fortran/openmp.c:6138
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP TARGET UPDATE at %L requires at least one TO or FROM clause"
 msgstr ""
 
-#: fortran/openmp.c:6155
+#: fortran/openmp.c:6160
 #, gcc-internal-format
 msgid "!$OMP DECLARE SIMD should refer to containing procedure %qs at %L"
 msgstr ""
 
-#: fortran/openmp.c:6179
+#: fortran/openmp.c:6184
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_PRIV or OMP_ORIG used in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6187
+#: fortran/openmp.c:6192
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_OUT or OMP_IN used in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6216
+#: fortran/openmp.c:6221
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid operator for !$OMP DECLARE REDUCTION %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:6238
+#: fortran/openmp.c:6243
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER length in !$OMP DECLARE REDUCTION %s not constant at %L"
 msgstr ""
 
-#: fortran/openmp.c:6254
+#: fortran/openmp.c:6259
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6269
+#: fortran/openmp.c:6274
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6279
+#: fortran/openmp.c:6284
 #, gcc-internal-format, gfc-internal-format
 msgid "One of actual subroutine arguments in INITIALIZER clause of !$OMP DECLARE REDUCTION must be OMP_PRIV at %L"
 msgstr ""
 
-#: fortran/openmp.c:6287
+#: fortran/openmp.c:6292
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing INITIALIZER clause for !$OMP DECLARE REDUCTION of derived type without default initializer at %L"
 msgstr ""
@@ -60239,510 +60319,510 @@
 msgid "Unclassifiable statement at %C"
 msgstr "Luokittelemiskelvoton lause kohdassa %C"
 
-#: fortran/parse.c:629
+#: fortran/parse.c:631
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Initialization at %C is not allowed in a PURE procedure"
 msgid "OpenACC directives at %C may not appear in PURE procedures"
 msgstr "Alustus kohdassa %C ei ole sallittu PURE-proseduurissa"
 
-#: fortran/parse.c:705
+#: fortran/parse.c:707
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unclassifiable statement at %C"
 msgid "Unclassifiable OpenACC directive at %C"
 msgstr "Luokittelematon lause IF-lauseessa kohdassa %C"
 
-#: fortran/parse.c:831 fortran/parse.c:1040
+#: fortran/parse.c:835 fortran/parse.c:1044
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Initialization at %C is not allowed in a PURE procedure"
 msgid "OpenMP directives other than SIMD or DECLARE TARGET at %C may not appear in PURE or ELEMENTAL procedures"
 msgstr "Alustus kohdassa %C ei ole sallittu PURE-proseduurissa"
 
-#: fortran/parse.c:1024
+#: fortran/parse.c:1028
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable OpenMP directive at %C"
 msgstr "Luokittelematon lause IF-lauseessa kohdassa %C"
 
-#: fortran/parse.c:1076
+#: fortran/parse.c:1080
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable GCC directive at %C"
 msgstr "Luokittelemiskelvoton lause kohdassa %C"
 
-#: fortran/parse.c:1135 fortran/parse.c:1362
+#: fortran/parse.c:1139 fortran/parse.c:1366
 #, gcc-internal-format, gfc-internal-format
 msgid "Zero is not a valid statement label at %C"
 msgstr "Nolla ei ole kelvollinen lausekenimiö kohdassa %C"
 
-#: fortran/parse.c:1142 fortran/parse.c:1354
+#: fortran/parse.c:1146 fortran/parse.c:1358
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-numeric character in statement label at %C"
 msgstr "Ei-numeerinen merkki lausenimiössä kohdassa %C"
 
-#: fortran/parse.c:1154 fortran/parse.c:1403
+#: fortran/parse.c:1158 fortran/parse.c:1407
 #, gcc-internal-format, gfc-internal-format
 msgid "Semicolon at %C needs to be preceded by statement"
 msgstr "Lauseen on edellettävä puolipistettä kohdassa %C"
 
-#: fortran/parse.c:1161 fortran/parse.c:1418
+#: fortran/parse.c:1165 fortran/parse.c:1422
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Ignoring statement label in empty statement at %L"
 msgid "Statement label without statement at %L"
 msgstr "Ei välitetä lausenimiöstä tyhjässä lauseessa kohdassa %L"
 
-#: fortran/parse.c:1224 fortran/parse.c:1405
+#: fortran/parse.c:1228 fortran/parse.c:1409
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Semicolon at %C without preceding statement"
 msgstr ""
 
-#: fortran/parse.c:1247 fortran/parse.c:1381
+#: fortran/parse.c:1251 fortran/parse.c:1385
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad continuation line at %C"
 msgstr "odotettua jatkoriviä ei löytynyt"
 
-#: fortran/parse.c:1679
+#: fortran/parse.c:1683
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT statement at %L does not have a statement label"
 msgstr ""
 
-#: fortran/parse.c:2435
+#: fortran/parse.c:2439
 #, gcc-internal-format
 msgid "gfc_ascii_statement(): Bad statement code"
 msgstr ""
 
-#: fortran/parse.c:2577
+#: fortran/parse.c:2581
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement at %C"
 msgstr "Odottamaton %s-lause kohdassa %C"
 
-#: fortran/parse.c:2732
+#: fortran/parse.c:2736
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot follow %s statement at %L"
 msgstr ""
 
-#: fortran/parse.c:2749
+#: fortran/parse.c:2753
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of file in '%s'"
 msgid "Unexpected end of file in %qs"
 msgstr "odottamaton tiedoston loppu #line-direktiivin jälkeen"
 
-#: fortran/parse.c:2784
+#: fortran/parse.c:2788
 #, fuzzy, gcc-internal-format
 #| msgid "Derived-type '%s' with SEQUENCE must not have a CONTAINS section at %C"
 msgid "Derived-type %qs with SEQUENCE must not have a CONTAINS section at %C"
 msgstr "Perityllä tyypillä ”%s” SEQUENCE:lla ei saa olla CONTAINS-lohkoa kohdassa %C"
 
-#: fortran/parse.c:2787
+#: fortran/parse.c:2791
 #, fuzzy, gcc-internal-format
 #| msgid "Derived-type '%s' with BIND(C) must not have a CONTAINS section at %C"
 msgid "Derived-type %qs with BIND(C) must not have a CONTAINS section at %C"
 msgstr "Perityllä tyypillä ”%s” BIND(C):llä ei saa olla CONTAINS-lohkoa kohdassa %C"
 
-#: fortran/parse.c:2807
+#: fortran/parse.c:2811
 #, gcc-internal-format, gfc-internal-format
 msgid "Components in TYPE at %C must precede CONTAINS"
 msgstr ""
 
-#: fortran/parse.c:2811
+#: fortran/parse.c:2815
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type-bound procedure at %C"
 msgstr "tyhjä esittely"
 
-#: fortran/parse.c:2819
+#: fortran/parse.c:2823
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "GENERIC binding at %C"
 msgstr "Odotettiin erityistä sitomisnimeä kohdassa %C"
 
-#: fortran/parse.c:2827
+#: fortran/parse.c:2831
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure declaration at %C"
 msgstr "Odotettiin moduuliproseduurinimeä kohdassa %C"
 
-#: fortran/parse.c:2839
+#: fortran/parse.c:2843
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type definition at %C with empty CONTAINS section"
 msgstr ""
 
-#: fortran/parse.c:2849 fortran/parse.c:3304
+#: fortran/parse.c:2853 fortran/parse.c:3308
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement in TYPE at %C must be inside a MODULE"
 msgstr ""
 
-#: fortran/parse.c:2856
+#: fortran/parse.c:2860
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede procedure bindings"
 msgstr ""
 
-#: fortran/parse.c:2863 fortran/parse.c:3317
+#: fortran/parse.c:2867 fortran/parse.c:3321
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PRIVATE statement at %C"
 msgstr "Kaksoiskappale POINTER-attribuutti kohdassa %C"
 
-#: fortran/parse.c:2873
+#: fortran/parse.c:2877
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede CONTAINS"
 msgstr ""
 
-#: fortran/parse.c:2877
+#: fortran/parse.c:2881
 #, gcc-internal-format, gfc-internal-format
 msgid "Already inside a CONTAINS block at %C"
 msgstr ""
 
-#: fortran/parse.c:2996
+#: fortran/parse.c:3000
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s at %L of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray, which is not possible as the component has the pointer attribute"
 msgstr ""
 
-#: fortran/parse.c:3002
+#: fortran/parse.c:3006
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer component %s at %L has a noncoarray subcomponent of type LOCK_TYPE, which must have a codimension or be a subcomponent of a coarray"
 msgstr ""
 
-#: fortran/parse.c:3007
+#: fortran/parse.c:3011
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L of type LOCK_TYPE must have a codimension"
 msgstr ""
 
-#: fortran/parse.c:3011
+#: fortran/parse.c:3015
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L must have a codimension as it has a noncoarray subcomponent of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/parse.c:3016
+#: fortran/parse.c:3020
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as already a coarray subcomponent exists)"
 msgstr ""
 
-#: fortran/parse.c:3023
+#: fortran/parse.c:3027
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as %s at %L has a codimension or a coarray subcomponent)"
 msgstr ""
 
-#: fortran/parse.c:3033
+#: fortran/parse.c:3037
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s at %L of type EVENT_TYPE must have a codimension or be a subcomponent of a coarray, which is not possible as the component has the pointer attribute"
 msgstr ""
 
-#: fortran/parse.c:3039
+#: fortran/parse.c:3043
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer component %s at %L has a noncoarray subcomponent of type EVENT_TYPE, which must have a codimension or be a subcomponent of a coarray"
 msgstr ""
 
-#: fortran/parse.c:3044
+#: fortran/parse.c:3048
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L of type EVENT_TYPE must have a codimension"
 msgstr ""
 
-#: fortran/parse.c:3048
+#: fortran/parse.c:3052
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L must have a codimension as it has a noncoarray subcomponent of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/parse.c:3053
+#: fortran/parse.c:3057
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as already a coarray subcomponent exists)"
 msgstr ""
 
-#: fortran/parse.c:3060
+#: fortran/parse.c:3064
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as %s at %L has a codimension or a coarray subcomponent)"
 msgstr ""
 
-#: fortran/parse.c:3112
+#: fortran/parse.c:3116
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "failed to create map component '%s'"
 msgstr "%s: ei voida avata PCH-tiedostoa: %m\n"
 
-#: fortran/parse.c:3145
+#: fortran/parse.c:3149
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "failed to create union component '%s'"
 msgstr "ei löydetä luokkaa %qE"
 
-#: fortran/parse.c:3200
+#: fortran/parse.c:3204
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in data declaration at %C"
 msgid "Syntax error in nested structure declaration at %C"
 msgstr "Syntaksivirhe data-esittelyssä kohdassa %C"
 
-#: fortran/parse.c:3287
+#: fortran/parse.c:3291
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside CONTAINS"
 msgstr ""
 
-#: fortran/parse.c:3295
+#: fortran/parse.c:3299
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type definition at %C without components"
 msgstr ""
 
-#: fortran/parse.c:3311
+#: fortran/parse.c:3315
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede structure components"
 msgstr ""
 
-#: fortran/parse.c:3328
+#: fortran/parse.c:3332
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede structure components"
 msgstr ""
 
-#: fortran/parse.c:3334
+#: fortran/parse.c:3338
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE attribute at %C already specified in TYPE statement"
 msgstr ""
 
-#: fortran/parse.c:3339
+#: fortran/parse.c:3343
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SEQUENCE statement at %C"
 msgstr "tuntematon ohjaussarja ’\\%c’"
 
-#: fortran/parse.c:3349
+#: fortran/parse.c:3353
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS block in derived type definition at %C"
 msgstr ""
 
-#: fortran/parse.c:3407
+#: fortran/parse.c:3411
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM declaration at %C has no ENUMERATORS"
 msgstr ""
 
-#: fortran/parse.c:3494
+#: fortran/parse.c:3498
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in INTERFACE block at %C"
 msgstr "Odottamaton %s-lause INTERFACE-lohkossa kohdassa %C"
 
-#: fortran/parse.c:3518
+#: fortran/parse.c:3522
 #, gcc-internal-format
 msgid "Name %qs of ABSTRACT INTERFACE at %C cannot be the same as an intrinsic type"
 msgstr ""
 
-#: fortran/parse.c:3552
+#: fortran/parse.c:3556
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement at %C in INTERFACE body"
 msgstr "Odottamaton %s-lause kohdassa %C INTERFACE-rungossa"
 
-#: fortran/parse.c:3570
+#: fortran/parse.c:3574
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is the name of the procedure"
 msgid "INTERFACE procedure %qs at %L has the same name as the enclosing procedure"
 msgstr "Nimi ”%s” kohdassa %C on proseduurin nimi"
 
-#: fortran/parse.c:3700
+#: fortran/parse.c:3704
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement is not allowed inside of BLOCK at %C"
 msgstr "Odottamaton %s-lause INTERFACE-lohkossa kohdassa %C"
 
-#: fortran/parse.c:3732
+#: fortran/parse.c:3736
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement not allowed in PURE procedure at %C"
 msgid "%s statement is not allowed inside of BLOCK DATA at %C"
 msgstr "Odottamaton %s-lause BLOCK DATA -lohkossa kohdassa %C"
 
-#: fortran/parse.c:3822
+#: fortran/parse.c:3826
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement must appear in a MODULE"
 msgstr "Odottamaton %s-lause MODULE-lohkossa kohdassa %C"
 
-#: fortran/parse.c:3830
+#: fortran/parse.c:3834
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C follows another accessibility specification"
 msgstr ""
 
-#: fortran/parse.c:3882
+#: fortran/parse.c:3886
 #, fuzzy, gcc-internal-format
 msgid "Bad kind expression for function %qs at %L"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: fortran/parse.c:3886
+#: fortran/parse.c:3890
 #, fuzzy, gcc-internal-format
 #| msgid "Return value of function '%s' at %L not set"
 msgid "The type for function %qs at %L is not accessible"
 msgstr "Funktion ”%s” paluuarvoa kohdassa %L ei ole asetettu"
 
-#: fortran/parse.c:3946
+#: fortran/parse.c:3950
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C follows previous unmasked ELSEWHERE"
 msgstr ""
 
-#: fortran/parse.c:3968
+#: fortran/parse.c:3972
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in WHERE block at %C"
 msgstr "Odottamaton %s-lause WHERE-lohkossa kohdassa %C"
 
-#: fortran/parse.c:4027
+#: fortran/parse.c:4031
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in FORALL block at %C"
 msgstr "Odottamaton %s-lause FORALL-lohkossa kohdassa %C"
 
-#: fortran/parse.c:4078
+#: fortran/parse.c:4082
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSE IF statement at %C cannot follow ELSE statement at %L"
 msgstr ""
 
-#: fortran/parse.c:4096
+#: fortran/parse.c:4100
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ELSE statements at %L and %C"
 msgstr "Kaksoiskappale-ELSE-lauseet kohdissa %L ja %C"
 
-#: fortran/parse.c:4157
+#: fortran/parse.c:4161
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected a CASE or END SELECT statement following SELECT CASE at %C"
 msgstr "Odotettiin CASE- tai END SELECT-lausetta seuraavaa SELECT CASE-lausetta kohdassa %C"
 
-#: fortran/parse.c:4241
+#: fortran/parse.c:4245
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected TYPE IS, CLASS IS or END SELECT statement following SELECT TYPE at %C"
 msgstr ""
 
-#: fortran/parse.c:4303
+#: fortran/parse.c:4307
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %C cannot be redefined inside loop beginning at %L"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: fortran/parse.c:4336
+#: fortran/parse.c:4340
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is within another block"
 msgstr ""
 
-#: fortran/parse.c:4346
+#: fortran/parse.c:4350
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is interwoven with another DO loop"
 msgstr ""
 
-#: fortran/parse.c:4372
+#: fortran/parse.c:4376
 #, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL block inside of OpenACC region at %C"
 msgstr ""
 
-#: fortran/parse.c:4373
+#: fortran/parse.c:4377
 #, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL block inside of OpenMP region at %C"
 msgstr ""
 
-#: fortran/parse.c:4399
+#: fortran/parse.c:4403
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label in END CRITICAL at %C does not match CRITICAL label"
 msgstr ""
 
-#: fortran/parse.c:4468
+#: fortran/parse.c:4472
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BLOCK construct at %C"
 msgstr "Lohkonimiö ei ole sopiva IF-lauseelle kohdassa %C"
 
-#: fortran/parse.c:4502
+#: fortran/parse.c:4506
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASSOCIATE construct at %C"
 msgstr "Muodostin %qs"
 
-#: fortran/parse.c:4690
+#: fortran/parse.c:4694
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label in ENDDO at %C doesn't match DO label"
 msgstr ""
 
-#: fortran/parse.c:4706
+#: fortran/parse.c:4710
 #, gcc-internal-format, gfc-internal-format
 msgid "Named block DO at %L requires matching ENDDO name"
 msgstr ""
 
-#: fortran/parse.c:4897
+#: fortran/parse.c:4901
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing !$OMP END ATOMIC after !$OMP ATOMIC CAPTURE at %C"
 msgstr ""
 
-#: fortran/parse.c:4913 fortran/parse.c:4972
+#: fortran/parse.c:4917 fortran/parse.c:4976
 #, gcc-internal-format, gfc-internal-format
 msgid "OpenACC directive inside of CRITICAL block at %C"
 msgstr ""
 
-#: fortran/parse.c:4947
+#: fortran/parse.c:4951
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expecting %s statement at %C"
 msgid "Expecting %s at %C"
 msgstr "%s (%s, oletus %c): "
 
-#: fortran/parse.c:4991
+#: fortran/parse.c:4995
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected '(' at %C"
 msgid "Expected DO loop at %C"
 msgstr "Odotettiin merkkiä ”,” kohdassa %C"
 
-#: fortran/parse.c:5011
+#: fortran/parse.c:5015
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant !$ACC END LOOP at %C"
 msgstr ""
 
-#: fortran/parse.c:5225
+#: fortran/parse.c:5229
 #, gcc-internal-format, gfc-internal-format
 msgid "Name after !$omp critical and !$omp end critical does not match at %C"
 msgstr ""
 
-#: fortran/parse.c:5283
+#: fortran/parse.c:5287
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot terminate a non-block DO loop"
 msgstr ""
 
-#: fortran/parse.c:5297
+#: fortran/parse.c:5301
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %C after the first executable statement"
 msgstr ""
 
-#: fortran/parse.c:5423
+#: fortran/parse.c:5427
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive does not commence a loop at %C"
 msgstr ""
 
-#: fortran/parse.c:5538
+#: fortran/parse.c:5542
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %C is already defined at %L"
 msgid "Contained procedure %qs at %C is already ambiguous"
 msgstr "Proseduuri ”%s” kohdassa %C on jo määritelty kohdassa %L"
 
-#: fortran/parse.c:5595
+#: fortran/parse.c:5599
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in CONTAINS section at %C"
 msgstr "Odottamaton %s-lause CONTAINS-lohkossa kohdassa %C"
 
-#: fortran/parse.c:5620
+#: fortran/parse.c:5624
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS statement without FUNCTION or SUBROUTINE statement at %L"
 msgstr "%s-lausetta odotettiin kohdassa %L"
 
-#: fortran/parse.c:5732
+#: fortran/parse.c:5736
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS statement at %C is already in a contained program unit"
 msgstr ""
 
-#: fortran/parse.c:5784
+#: fortran/parse.c:5788
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is already defined as a generic interface at %L"
 msgid "Global binding name %qs at %L is already being used as a %s at %L"
 msgstr "Nimi ”%s” kohdassa %C on jo määritelty geneerisenä rajapintana kohdassa %L"
 
-#: fortran/parse.c:5788
+#: fortran/parse.c:5792
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is already defined as a generic interface at %L"
 msgid "Global name %qs at %L is already being used as a %s at %L"
 msgstr "Nimi ”%s” kohdassa %C on jo määritelty geneerisenä rajapintana kohdassa %L"
 
-#: fortran/parse.c:5794
+#: fortran/parse.c:5798
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is already defined as a generic interface at %L"
 msgid "Global binding name %qs at %L is already being used at %L"
 msgstr "Nimi ”%s” kohdassa %C on jo määritelty geneerisenä rajapintana kohdassa %L"
 
-#: fortran/parse.c:5797
+#: fortran/parse.c:5801
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is already defined as a generic interface at %L"
 msgid "Global name %qs at %L is already being used at %L"
 msgstr "Nimi ”%s” kohdassa %C on jo määritelty geneerisenä rajapintana kohdassa %L"
 
-#: fortran/parse.c:5819
+#: fortran/parse.c:5823
 #, gcc-internal-format, gfc-internal-format
 msgid "Blank BLOCK DATA at %C conflicts with prior BLOCK DATA at %L"
 msgstr ""
 
-#: fortran/parse.c:5845
+#: fortran/parse.c:5849
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in BLOCK DATA at %C"
 msgstr "Odottamaton %s-lause BLOCK DATA -lohkossa kohdassa %C"
 
-#: fortran/parse.c:5949
+#: fortran/parse.c:5953
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in MODULE at %C"
 msgstr "Odottamaton %s-lause MODULE-lohkossa kohdassa %C"
@@ -60750,7 +60830,7 @@
 #. If we see a duplicate main program, shut down.  If the second
 #. instance is an implied main program, i.e. data decls or executable
 #. statements, we're in for lots of errors.
-#: fortran/parse.c:6333
+#: fortran/parse.c:6337
 #, gcc-internal-format, gfc-internal-format
 msgid "Two main PROGRAMs at %L and %C"
 msgstr ""
@@ -61525,7 +61605,7 @@
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.c:1893 fortran/resolve.c:9560 fortran/resolve.c:11225
+#: fortran/resolve.c:1893 fortran/resolve.c:9573 fortran/resolve.c:11245
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "Nimiö %d kohdassa %L on määritelty, mutta ei käytetty"
@@ -61639,7 +61719,7 @@
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr ""
 
-#: fortran/resolve.c:2905 fortran/resolve.c:16283
+#: fortran/resolve.c:2905 fortran/resolve.c:16310
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr ""
@@ -61765,199 +61845,199 @@
 msgid "logical_to_bitwise(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:4059
+#: fortran/resolve.c:4065
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:4229 fortran/resolve.c:4252
+#: fortran/resolve.c:4235 fortran/resolve.c:4258
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:4347
+#: fortran/resolve.c:4353
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Taulukkoviite kohdassa %L on rajojen ulkopuolella (%ld < %ld) ulottuvuudessa %d"
 
-#: fortran/resolve.c:4352
+#: fortran/resolve.c:4358
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr "Taulukkoviite kohdassa %L on rajojen ulkopuolella (%ld < %ld) ulottuvuudessa %d"
 
-#: fortran/resolve.c:4362
+#: fortran/resolve.c:4368
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Taulukkoviite kohdassa %L on rajojen ulkopuolella (%ld < %ld) ulottuvuudessa %d"
 
-#: fortran/resolve.c:4367
+#: fortran/resolve.c:4373
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr "Taulukkoviite kohdassa %L on rajojen ulkopuolella (%ld < %ld) ulottuvuudessa %d"
 
-#: fortran/resolve.c:4387
+#: fortran/resolve.c:4393
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr "Iteraattoriaskel kohdassa %L ei voi olla nolla"
 
-#: fortran/resolve.c:4404
+#: fortran/resolve.c:4410
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Taulukkoviite kohdassa %L on rajojen ulkopuolella (%ld < %ld) ulottuvuudessa %d"
 
-#: fortran/resolve.c:4412
+#: fortran/resolve.c:4418
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Taulukkoviite kohdassa %L on rajojen ulkopuolella (%ld < %ld) ulottuvuudessa %d"
 
-#: fortran/resolve.c:4428
+#: fortran/resolve.c:4434
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "Taulukkoviite kohdassa %L on rajojen ulkopuolella (%ld < %ld) ulottuvuudessa %d"
 
-#: fortran/resolve.c:4437
+#: fortran/resolve.c:4443
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "Taulukkoviite kohdassa %L on rajojen ulkopuolella (%ld < %ld) ulottuvuudessa %d"
 
-#: fortran/resolve.c:4453
+#: fortran/resolve.c:4459
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of references"
 msgid "check_dimension(): Bad array reference"
 msgstr "luodaan viitteiden taulukko"
 
-#: fortran/resolve.c:4476
+#: fortran/resolve.c:4482
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:4486
+#: fortran/resolve.c:4492
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr "Taulukkoviite kohdassa %L on rajojen ulkopuolella (%ld < %ld) ulottuvuudessa %d"
 
-#: fortran/resolve.c:4494
+#: fortran/resolve.c:4500
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr "ehtolausekkeessa on tyyppiristiriita"
 
-#: fortran/resolve.c:4510
+#: fortran/resolve.c:4516
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr ""
 
-#: fortran/resolve.c:4538
+#: fortran/resolve.c:4544
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.c:4544
+#: fortran/resolve.c:4550
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr ""
 
-#: fortran/resolve.c:4550
+#: fortran/resolve.c:4556
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr "taulukkoindeksi ei-taulukkoalustimessa"
 
-#: fortran/resolve.c:4589
+#: fortran/resolve.c:4595
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.c:4596
+#: fortran/resolve.c:4602
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr ""
 
-#: fortran/resolve.c:4641
+#: fortran/resolve.c:4647
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr ""
 
-#: fortran/resolve.c:4652
+#: fortran/resolve.c:4658
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.c:4663
+#: fortran/resolve.c:4669
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.c:4706
+#: fortran/resolve.c:4712
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr ""
 
-#: fortran/resolve.c:4804
+#: fortran/resolve.c:4810
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:4811
+#: fortran/resolve.c:4817
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4820
+#: fortran/resolve.c:4826
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr ""
 
-#: fortran/resolve.c:4833
+#: fortran/resolve.c:4839
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:4840
+#: fortran/resolve.c:4846
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr "Alimerkkijonon loppuindeksi kohdassa %L on liian suuri"
 
-#: fortran/resolve.c:4850
+#: fortran/resolve.c:4856
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr ""
 
-#: fortran/resolve.c:4860
+#: fortran/resolve.c:4866
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr "Alimerkkijonon loppuindeksi kohdassa %L on liian suuri"
 
-#: fortran/resolve.c:5013
+#: fortran/resolve.c:5019
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of references"
 msgid "resolve_ref(): Bad array reference"
 msgstr "luodaan viitteiden taulukko"
 
-#: fortran/resolve.c:5027
+#: fortran/resolve.c:5033
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:5037
+#: fortran/resolve.c:5043
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:5056
+#: fortran/resolve.c:5062
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:5154
+#: fortran/resolve.c:5160
 #, gcc-internal-format
 msgid "expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.c:5236
+#: fortran/resolve.c:5242
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr ""
 
-#: fortran/resolve.c:5246
+#: fortran/resolve.c:5252
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -61966,12 +62046,12 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5256
+#: fortran/resolve.c:5262
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5271
+#: fortran/resolve.c:5277
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -61980,269 +62060,269 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5281
+#: fortran/resolve.c:5287
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5292
+#: fortran/resolve.c:5298
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5301
+#: fortran/resolve.c:5307
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5316
+#: fortran/resolve.c:5322
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5478
+#: fortran/resolve.c:5484
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5483
+#: fortran/resolve.c:5489
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5553
+#: fortran/resolve.c:5559
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.c:5566
+#: fortran/resolve.c:5572
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.c:5919
+#: fortran/resolve.c:5925
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.c:5926
+#: fortran/resolve.c:5932
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5961
+#: fortran/resolve.c:5967
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5970
+#: fortran/resolve.c:5976
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr ""
 
 #. Nothing matching found!
-#: fortran/resolve.c:6158
+#: fortran/resolve.c:6164
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:6185
+#: fortran/resolve.c:6191
 #, fuzzy, gcc-internal-format
 #| msgid "%s at %L must be INTEGER"
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/resolve.c:6236
+#: fortran/resolve.c:6242
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: fortran/resolve.c:6786
+#: fortran/resolve.c:6792
 #, fuzzy, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/resolve.c:6812
+#: fortran/resolve.c:6818
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.c:6822
+#: fortran/resolve.c:6828
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/resolve.c:6826 fortran/resolve.c:6833
+#: fortran/resolve.c:6832 fortran/resolve.c:6839
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/resolve.c:6875
+#: fortran/resolve.c:6881
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:6911
+#: fortran/resolve.c:6917
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.c:6928
+#: fortran/resolve.c:6934
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.c:6934
+#: fortran/resolve.c:6940
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.c:6995
+#: fortran/resolve.c:7001
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7000
+#: fortran/resolve.c:7006
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7007
+#: fortran/resolve.c:7013
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7015
+#: fortran/resolve.c:7021
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr ""
 
-#: fortran/resolve.c:7020
+#: fortran/resolve.c:7026
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:7033
+#: fortran/resolve.c:7039
 #, fuzzy, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "%J%qD:lle ei ole aiempaa esittelyä"
 
-#: fortran/resolve.c:7136 fortran/resolve.c:7428
+#: fortran/resolve.c:7142 fortran/resolve.c:7434
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:7144 fortran/resolve.c:7393
+#: fortran/resolve.c:7150 fortran/resolve.c:7399
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7250
+#: fortran/resolve.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7281
+#: fortran/resolve.c:7287
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.c:7439
+#: fortran/resolve.c:7445
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.c:7451
+#: fortran/resolve.c:7457
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.c:7465
+#: fortran/resolve.c:7471
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7480
+#: fortran/resolve.c:7486
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7493
+#: fortran/resolve.c:7499
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.c:7511
+#: fortran/resolve.c:7517
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.c:7592 fortran/resolve.c:7607
+#: fortran/resolve.c:7598 fortran/resolve.c:7613
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7599
+#: fortran/resolve.c:7605
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.c:7622
+#: fortran/resolve.c:7628
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7649
+#: fortran/resolve.c:7655
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7668
+#: fortran/resolve.c:7674
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.c:7683
+#: fortran/resolve.c:7689
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.c:7694
+#: fortran/resolve.c:7700
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.c:7726
+#: fortran/resolve.c:7732
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:7749
+#: fortran/resolve.c:7755
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:7760
+#: fortran/resolve.c:7766
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.c:7771
+#: fortran/resolve.c:7782
 #, gcc-internal-format, gfc-internal-format
-msgid "Errmsg-variable at %L must be a scalar CHARACTER variable"
+msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:7794
+#: fortran/resolve.c:7805
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:7824
+#: fortran/resolve.c:7835
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.c:7830 fortran/resolve.c:7836
+#: fortran/resolve.c:7841 fortran/resolve.c:7847
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -62251,234 +62331,234 @@
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8064
+#: fortran/resolve.c:8075
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "CASE-nimiö kohdassa %L menee CASE-nimiön päälle kohdassa %L"
 
-#: fortran/resolve.c:8115
+#: fortran/resolve.c:8126
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "Lauseke CASE-lauseessa kohdassa %L on oltava %s-tyyppinen"
 
-#: fortran/resolve.c:8126
+#: fortran/resolve.c:8137
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "Lauseke CASE-lauseessa kohdassa %L on oltava %d-kaltainen"
 
-#: fortran/resolve.c:8139
+#: fortran/resolve.c:8150
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.c:8185
+#: fortran/resolve.c:8196
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr ""
 
-#: fortran/resolve.c:8204
+#: fortran/resolve.c:8215
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr ""
 
-#: fortran/resolve.c:8214
+#: fortran/resolve.c:8225
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.c:8232 fortran/resolve.c:8240
+#: fortran/resolve.c:8243 fortran/resolve.c:8251
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "Lauseke CASE-lauseessa kohdassa %L on oltava %s-tyyppinen"
 
-#: fortran/resolve.c:8302 fortran/resolve.c:8873
+#: fortran/resolve.c:8313 fortran/resolve.c:8884
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr ""
 
-#: fortran/resolve.c:8328
+#: fortran/resolve.c:8339
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:8340
+#: fortran/resolve.c:8351
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:8355
+#: fortran/resolve.c:8366
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr ""
 
-#: fortran/resolve.c:8458
+#: fortran/resolve.c:8469
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr ""
 
-#: fortran/resolve.c:8518
+#: fortran/resolve.c:8529
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/resolve.c:8523
+#: fortran/resolve.c:8534
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/resolve.c:8545
+#: fortran/resolve.c:8556
 #, fuzzy, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: fortran/resolve.c:8556
+#: fortran/resolve.c:8567
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:8763
+#: fortran/resolve.c:8774
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "yhteensopimattomat tyypit sijoituksessa"
 
-#: fortran/resolve.c:8783 fortran/resolve.c:8795
+#: fortran/resolve.c:8794 fortran/resolve.c:8806
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/resolve.c:8824
+#: fortran/resolve.c:8835
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CASE label at %L overlaps with CASE label at %L"
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "CASE-nimiö kohdassa %L menee CASE-nimiön päälle kohdassa %L"
 
-#: fortran/resolve.c:8836
+#: fortran/resolve.c:8847
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.c:8848
+#: fortran/resolve.c:8859
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr ""
 
-#: fortran/resolve.c:8851
+#: fortran/resolve.c:8862
 #, fuzzy, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.c:8861
+#: fortran/resolve.c:8872
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.c:9108
+#: fortran/resolve.c:9119
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9204
+#: fortran/resolve.c:9215
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr ""
 
-#: fortran/resolve.c:9257
+#: fortran/resolve.c:9268
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/resolve.c:9267
+#: fortran/resolve.c:9278
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9280
+#: fortran/resolve.c:9291
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9289
+#: fortran/resolve.c:9300
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr ""
 
-#: fortran/resolve.c:9296
+#: fortran/resolve.c:9307
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9307
+#: fortran/resolve.c:9318
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr ""
 
-#: fortran/resolve.c:9313
+#: fortran/resolve.c:9324
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9328
+#: fortran/resolve.c:9339
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:9388
+#: fortran/resolve.c:9399
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:9398
+#: fortran/resolve.c:9409
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:9402
+#: fortran/resolve.c:9413
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: fortran/resolve.c:9405
+#: fortran/resolve.c:9416
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: fortran/resolve.c:9412 fortran/resolve.c:9533
+#: fortran/resolve.c:9423 fortran/resolve.c:9545
 #, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:9424 fortran/resolve.c:9540
+#: fortran/resolve.c:9435 fortran/resolve.c:9553
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:9436
+#: fortran/resolve.c:9447
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr ""
 
-#: fortran/resolve.c:9449
+#: fortran/resolve.c:9460
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument to decltype must be an expression"
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "decltypen argumentin on oltava lauseke"
 
-#: fortran/resolve.c:9510
+#: fortran/resolve.c:9521
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:9514 fortran/resolve.c:9524
+#: fortran/resolve.c:9525 fortran/resolve.c:9535
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: fortran/resolve.c:9567
+#: fortran/resolve.c:9580
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9577
+#: fortran/resolve.c:9590
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr "Haarautuminen kohdassa %L voi aiheuttaa ikisilmukan"
@@ -62485,12 +62565,12 @@
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:9594 fortran/resolve.c:9617
+#: fortran/resolve.c:9607 fortran/resolve.c:9630
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.c:9598 fortran/resolve.c:9623
+#: fortran/resolve.c:9611 fortran/resolve.c:9636
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -62498,108 +62578,108 @@
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:9638
+#: fortran/resolve.c:9651
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9710
+#: fortran/resolve.c:9723
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:9726
+#: fortran/resolve.c:9739
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:9734 fortran/resolve.c:9821
+#: fortran/resolve.c:9747 fortran/resolve.c:9834
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:9744 fortran/resolve.c:9831
+#: fortran/resolve.c:9757 fortran/resolve.c:9844
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:9775
+#: fortran/resolve.c:9788
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "Sijoitus FORALL-indeksimuuttujaan kohdassa %L"
 
-#: fortran/resolve.c:9784
+#: fortran/resolve.c:9797
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr ""
 
-#: fortran/resolve.c:9949
+#: fortran/resolve.c:9962
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr ""
 
-#: fortran/resolve.c:9959
+#: fortran/resolve.c:9972
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr ""
 
-#: fortran/resolve.c:10036
+#: fortran/resolve.c:10049
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr ""
 
-#: fortran/resolve.c:10138
+#: fortran/resolve.c:10151
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:10251
+#: fortran/resolve.c:10264
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr "CHARACTER-lauseke kohdassa %L on typistetty (%d/%d)"
 
-#: fortran/resolve.c:10283
+#: fortran/resolve.c:10296
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:10288
+#: fortran/resolve.c:10301
 #, gcc-internal-format, gfc-internal-format
 msgid "The impure variable at %L is assigned to a derived type variable with a POINTER component in a PURE procedure (12.6)"
 msgstr ""
 
-#: fortran/resolve.c:10298
+#: fortran/resolve.c:10311
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "kirjoitussuojatun muuttujan %qs sijoitus"
 
-#: fortran/resolve.c:10330
+#: fortran/resolve.c:10343
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:10334
+#: fortran/resolve.c:10347
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assignment to a FORALL index variable at %L"
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "Muuttujatyyppi on UNKNOWN sijoituksessa kohdassa %L"
 
-#: fortran/resolve.c:10339
+#: fortran/resolve.c:10352
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.c:10346
+#: fortran/resolve.c:10359
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr ""
 
-#: fortran/resolve.c:10357
+#: fortran/resolve.c:10370
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr "yhteensopimattomat tyypit sijoituksessa"
 
-#: fortran/resolve.c:10663
+#: fortran/resolve.c:10683
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
@@ -62606,69 +62686,69 @@
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:10905
+#: fortran/resolve.c:10925
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid procedure pointer assignment at %L"
 msgid "Pointer procedure assignment at %L"
 msgstr "Virheellinen proseduuriosoitinsijoitus kohdassa %L"
 
-#: fortran/resolve.c:10917
+#: fortran/resolve.c:10937
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr "yhteensopimattomat tyypit sijoituksessa"
 
-#: fortran/resolve.c:11157
+#: fortran/resolve.c:11177
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:11160
+#: fortran/resolve.c:11180
 #, fuzzy, gcc-internal-format
 #| msgid "Variable %s cannot be assigned in PURE procedure at %C"
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "Muuttuja %s ei voida liittää PURE-proseduuriin kohdassa %C"
 
-#: fortran/resolve.c:11171
+#: fortran/resolve.c:11191
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr ""
 
-#: fortran/resolve.c:11233
+#: fortran/resolve.c:11253
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:11278
+#: fortran/resolve.c:11298
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid NULL at %L"
 msgstr "virheellinen %%L-arvo"
 
-#: fortran/resolve.c:11282
+#: fortran/resolve.c:11302
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:11339
+#: fortran/resolve.c:11359
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:11344
+#: fortran/resolve.c:11364
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:11428
+#: fortran/resolve.c:11448
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:11507
+#: fortran/resolve.c:11527
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr ""
 
-#: fortran/resolve.c:11617
+#: fortran/resolve.c:11637
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
@@ -62675,7 +62755,7 @@
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:11630
+#: fortran/resolve.c:11650
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
@@ -62683,59 +62763,59 @@
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:11647
+#: fortran/resolve.c:11667
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: fortran/resolve.c:11732
+#: fortran/resolve.c:11752
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "Merkkijonon pituus kohdassa %L on liian suuri"
 
-#: fortran/resolve.c:11961
+#: fortran/resolve.c:11981
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:11965
+#: fortran/resolve.c:11985
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L may not be ALLOCATABLE"
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "Argumentti ”%s”/”%s” PASS(%s) kohdassa %L ei voi olla ALLOCATABLE"
 
-#: fortran/resolve.c:11973
+#: fortran/resolve.c:11993
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:11983
+#: fortran/resolve.c:12003
 #, fuzzy, gcc-internal-format
 #| msgid "Automatic array '%s' at %L cannot have an initializer"
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "Automaattitaulukolla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.c:11998
+#: fortran/resolve.c:12018
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.c:12010
+#: fortran/resolve.c:12030
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.c:12041
+#: fortran/resolve.c:12061
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.c:12063
+#: fortran/resolve.c:12083
 #, fuzzy, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:12090
+#: fortran/resolve.c:12110
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
@@ -62742,63 +62822,63 @@
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12131
+#: fortran/resolve.c:12151
 #, fuzzy, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:12150
+#: fortran/resolve.c:12170
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr ""
 
-#: fortran/resolve.c:12171
+#: fortran/resolve.c:12191
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr ""
 
-#: fortran/resolve.c:12178
+#: fortran/resolve.c:12198
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr ""
 
-#: fortran/resolve.c:12225
+#: fortran/resolve.c:12245
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable '%s' at %L cannot have an initializer"
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "Varattavalla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.c:12228
+#: fortran/resolve.c:12248
 #, fuzzy, gcc-internal-format
 #| msgid "External '%s' at %L cannot have an initializer"
 msgid "External %qs at %L cannot have an initializer"
 msgstr "Ulkoisella ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.c:12232
+#: fortran/resolve.c:12252
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "Tyhjällä ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.c:12235
+#: fortran/resolve.c:12255
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L cannot have an initializer"
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "Luontaisella ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.c:12238
+#: fortran/resolve.c:12258
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L cannot have an initializer"
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "Funktiolla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.c:12241
+#: fortran/resolve.c:12261
 #, fuzzy, gcc-internal-format
 #| msgid "Automatic array '%s' at %L cannot have an initializer"
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "Automaattitaulukolla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.c:12283
+#: fortran/resolve.c:12303
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s at %L"
 msgstr ""
@@ -62806,868 +62886,874 @@
 "  tai:  %s -l [SIGNAALI]...\n"
 "  tai:  %s -t [SIGNAALI]...\n"
 
-#: fortran/resolve.c:12310
+#: fortran/resolve.c:12330
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:12332
+#: fortran/resolve.c:12352
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:12354
+#: fortran/resolve.c:12374
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.c:12372
+#: fortran/resolve.c:12392
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L cannot have an initializer"
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "Funktiolla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.c:12381
+#: fortran/resolve.c:12401
 #, fuzzy, gcc-internal-format
 #| msgid "External object '%s' at %L may not have an initializer"
 msgid "External object %qs at %L may not have an initializer"
 msgstr "Ulkoisella objektilla ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/resolve.c:12389
+#: fortran/resolve.c:12409
 #, fuzzy, gcc-internal-format
 #| msgid "ELEMENTAL function '%s' at %L must have a scalar result"
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "ELEMENTAL-funktiolla ”%s” kohdassa %L täytyy olla skalaaritulos"
 
-#: fortran/resolve.c:12399
+#: fortran/resolve.c:12419
 #, fuzzy, gcc-internal-format
 #| msgid "argument of function call might be a candidate for a format attribute"
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "funktiokutsun argumentti voi olla ehdokas muotoiluattribuutille"
 
-#: fortran/resolve.c:12418
+#: fortran/resolve.c:12438
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be array-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "CHARACTER(*)-funktio ”%s” kohdassa %L ei voi olla taulukkoarvoinen"
 
-#: fortran/resolve.c:12422
+#: fortran/resolve.c:12442
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pointer-valued"
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "CHARACTER(*)-funktio ”%s” kohdassa %L ei voi olla osoitinarvoinen"
 
-#: fortran/resolve.c:12426
+#: fortran/resolve.c:12446
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "CHARACTER(*)-funktio ”%s” kohdassa %L ei voi olla puhdas"
 
-#: fortran/resolve.c:12430
+#: fortran/resolve.c:12450
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be recursive"
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "CHARACTER(*)-funktio ”%s” kohdassa %L ei voi olla rekursiivinen"
 
-#: fortran/resolve.c:12443
+#: fortran/resolve.c:12463
 #, fuzzy, gcc-internal-format
 #| msgid "CHARACTER(*) function '%s' at %L cannot be pure"
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: fortran/resolve.c:12452
+#: fortran/resolve.c:12472
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.c:12458
+#: fortran/resolve.c:12478
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy procedure '%s' at %C cannot have a generic interface"
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "Valeproseduurilla ”%s” kohdassa %C ei voi olla geneeristä rajapintaa"
 
-#: fortran/resolve.c:12470
+#: fortran/resolve.c:12490
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L may not have the POINTER attribute"
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr "Argumentilla ”%s”/”%s” PASS(%s) kohdassa %L ei voi olla POINTER-attribuuttia"
 
-#: fortran/resolve.c:12527
+#: fortran/resolve.c:12547
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with SAVE attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "SAVE-attribuuttia kohdassa %L ei voida määritellä PURE-proseduurissa"
 
-#: fortran/resolve.c:12533
+#: fortran/resolve.c:12553
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with INTENT attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "PROCEDURE-attribuutti on ristiriidassa INTENT-attribuutin kanssa kohteessa ”%s” kohdassa %L"
 
-#: fortran/resolve.c:12539
+#: fortran/resolve.c:12559
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with RESULT attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "PROCEDURE-attribuutti on ristiriidassa RESULT-attribuutin kanssa kohteessa ”%s” kohdassa %L"
 
-#: fortran/resolve.c:12547
+#: fortran/resolve.c:12567
 #, fuzzy, gcc-internal-format
 #| msgid "EXTERNAL attribute conflicts with FUNCTION attribute in '%s' at %L"
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "EXTERNAL-attribuutti on ristiriidassa FUNCTION-attribuutin kanssa kohteessa ”%s” kohdassa %L"
 
-#: fortran/resolve.c:12553
+#: fortran/resolve.c:12573
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.c:12596
+#: fortran/resolve.c:12616
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12604
+#: fortran/resolve.c:12624
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12612
+#: fortran/resolve.c:12632
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12621
+#: fortran/resolve.c:12641
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.c:12705
+#: fortran/resolve.c:12725
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:12714
+#: fortran/resolve.c:12734
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr ""
 
-#: fortran/resolve.c:12723
+#: fortran/resolve.c:12743
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of FINAL procedure at %L must be of type '%s'"
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "FINAL-proseduurin argumentin kohdassa %L täytyy olla tyyppiä ”%s”"
 
-#: fortran/resolve.c:12731
+#: fortran/resolve.c:12751
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:12737
+#: fortran/resolve.c:12757
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:12743
+#: fortran/resolve.c:12763
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr ""
 
-#: fortran/resolve.c:12751
+#: fortran/resolve.c:12771
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:12760
+#: fortran/resolve.c:12780
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr ""
 
-#: fortran/resolve.c:12782
+#: fortran/resolve.c:12802
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr ""
 
-#: fortran/resolve.c:12819
+#: fortran/resolve.c:12839
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr ""
 
-#: fortran/resolve.c:12859
+#: fortran/resolve.c:12879
 #, gcc-internal-format
 msgid "%qs and %qs can't be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12895
+#: fortran/resolve.c:12915
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.c:12954
+#: fortran/resolve.c:12974
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12966
+#: fortran/resolve.c:12986
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.c:12994
+#: fortran/resolve.c:13014
 #, gcc-internal-format
 msgid "GENERIC %qs at %L can't overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.c:13050
+#: fortran/resolve.c:13070
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L can't be NOPASS"
 msgstr ""
 
-#: fortran/resolve.c:13242
+#: fortran/resolve.c:13262
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr ""
 
-#: fortran/resolve.c:13284
+#: fortran/resolve.c:13304
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:13298
+#: fortran/resolve.c:13318
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L must have at least two arguments"
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "Kääntäjänsisäisellä ”%s”-funktiolla kohdassa %L on oltava vähintään kaksi argumenttia"
 
-#: fortran/resolve.c:13312 fortran/resolve.c:13778
+#: fortran/resolve.c:13332 fortran/resolve.c:13798
 #, fuzzy, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 
-#: fortran/resolve.c:13320
+#: fortran/resolve.c:13340
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L must be of the derived type '%s'"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr "Argumentin ”%s”/”%s” PASS(%s) kohdassa %L täytyy olla perittyä tyyppiä ”%s”"
 
-#: fortran/resolve.c:13329
+#: fortran/resolve.c:13349
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 
-#: fortran/resolve.c:13335
+#: fortran/resolve.c:13355
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "%<__builtin_args_info%>-funktion argumentin pitää olla vakio"
 
-#: fortran/resolve.c:13341
+#: fortran/resolve.c:13361
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "%<__builtin_args_info%>-funktion argumentin pitää olla vakio"
 
-#: fortran/resolve.c:13370
+#: fortran/resolve.c:13390
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L may not have basic type of %s"
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/resolve.c:13380
+#: fortran/resolve.c:13400
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L may not have basic type of %s"
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/resolve.c:13472
+#: fortran/resolve.c:13492
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.c:13574
+#: fortran/resolve.c:13594
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:13583
+#: fortran/resolve.c:13603
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13593
+#: fortran/resolve.c:13613
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.c:13602
+#: fortran/resolve.c:13622
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.c:13613
+#: fortran/resolve.c:13633
 #, fuzzy, gcc-internal-format
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "Argumentin %s kohdassa %L on oltava pituudeltaan yksi"
 
-#: fortran/resolve.c:13711
+#: fortran/resolve.c:13731
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "tyhjä esittely"
 
-#: fortran/resolve.c:13725
+#: fortran/resolve.c:13745
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L must have at least two arguments"
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "Kääntäjänsisäisellä ”%s”-funktiolla kohdassa %L on oltava vähintään kaksi argumenttia"
 
-#: fortran/resolve.c:13741
+#: fortran/resolve.c:13761
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L must be of the derived type '%s'"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "Argumentin ”%s”/”%s” PASS(%s) kohdassa %L täytyy olla perittyä tyyppiä ”%s”"
 
-#: fortran/resolve.c:13751
+#: fortran/resolve.c:13771
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L must be scalar"
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "Argumentin ”%s”/”%s” PASS(%s) kohdassa %L täytyy olla skalaari"
 
-#: fortran/resolve.c:13760
+#: fortran/resolve.c:13780
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L may not have the POINTER attribute"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "Argumentilla ”%s”/”%s” PASS(%s) kohdassa %L ei voi olla POINTER-attribuuttia"
 
-#: fortran/resolve.c:13769
+#: fortran/resolve.c:13789
 #, fuzzy, gcc-internal-format
 #| msgid "Argument '%s' of '%s' with PASS(%s) at %L may not be ALLOCATABLE"
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "Argumentti ”%s”/”%s” PASS(%s) kohdassa %L ei voi olla ALLOCATABLE"
 
-#: fortran/resolve.c:13811
+#: fortran/resolve.c:13831
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr ""
 
-#: fortran/resolve.c:13824
+#: fortran/resolve.c:13844
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr ""
 
-#: fortran/resolve.c:13835
+#: fortran/resolve.c:13855
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13868
+#: fortran/resolve.c:13888
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:13876
+#: fortran/resolve.c:13896
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.c:13885
+#: fortran/resolve.c:13905
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr ""
 
-#: fortran/resolve.c:13903 fortran/resolve.c:13915
+#: fortran/resolve.c:13923 fortran/resolve.c:13935
 #, gcc-internal-format
 msgid "The pointer component %qs of %qs at %L is a type that has not been declared"
 msgstr ""
 
-#: fortran/resolve.c:13989
+#: fortran/resolve.c:14009
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Conflict in attributes of function argument at %C"
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "Ristiriita funktioargumentin attribuuteissa kohdassa %C"
 
-#: fortran/resolve.c:14034
+#: fortran/resolve.c:14054
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.c:14047
+#: fortran/resolve.c:14067
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr ""
 
-#: fortran/resolve.c:14111
+#: fortran/resolve.c:14131
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14144
+#: fortran/resolve.c:14164
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.c:14216
+#: fortran/resolve.c:14236
 #, fuzzy, gcc-internal-format
 #| msgid "Empty array constructor at %C is not allowed"
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "Tyhjä taulukkomuodostin kohdassa %C ei ole sallittu"
 
-#: fortran/resolve.c:14222
+#: fortran/resolve.c:14242
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14228
+#: fortran/resolve.c:14248
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14236
+#: fortran/resolve.c:14256
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14253
+#: fortran/resolve.c:14273
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14275
+#: fortran/resolve.c:14295
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14286
+#: fortran/resolve.c:14306
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14313
+#: fortran/resolve.c:14333
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with INTENT attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "PROCEDURE-attribuutti on ristiriidassa INTENT-attribuutin kanssa kohteessa ”%s” kohdassa %L"
 
-#: fortran/resolve.c:14337
+#: fortran/resolve.c:14357
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:14353
+#: fortran/resolve.c:14373
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:14364
+#: fortran/resolve.c:14384
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr ""
 
-#: fortran/resolve.c:14372
+#: fortran/resolve.c:14392
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "Muuttujalla ”%s” kohdassa %L ei voi olla sekä POINTER- että BIND(C)-attribuutit"
 
-#: fortran/resolve.c:14423
+#: fortran/resolve.c:14443
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr ""
 
-#: fortran/resolve.c:14434
+#: fortran/resolve.c:14454
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.c:14441
+#: fortran/resolve.c:14461
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.c:14480
+#: fortran/resolve.c:14500
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:14544
+#: fortran/resolve.c:14564
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "%qE-attribuutti soveltuu vain variadisiin funktioihin"
 
-#: fortran/resolve.c:14547
+#: fortran/resolve.c:14567
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "SAVE-attribuuttia kohdassa %L ei voida määritellä PURE-proseduurissa"
 
-#: fortran/resolve.c:14643
+#: fortran/resolve.c:14663
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:14664
+#: fortran/resolve.c:14684
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/resolve.c:14677
+#: fortran/resolve.c:14697
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14680
+#: fortran/resolve.c:14700
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14688
+#: fortran/resolve.c:14708
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14695
+#: fortran/resolve.c:14715
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:14708
+#: fortran/resolve.c:14728
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "Sijoitus FORALL-indeksimuuttujaan kohdassa %L"
 
-#: fortran/resolve.c:14714
+#: fortran/resolve.c:14734
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14724
+#: fortran/resolve.c:14744
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:14733
+#: fortran/resolve.c:14753
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.c:14746 fortran/resolve.c:14923
+#: fortran/resolve.c:14766 fortran/resolve.c:14943
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.c:14760
+#: fortran/resolve.c:14780
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14769
+#: fortran/resolve.c:14789
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:14778
+#: fortran/resolve.c:14798
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Muuttujalla ”%s” kohdassa %L ei voi olla sekä ALLOCATABLE- että BIND(C)-attribuutit"
 
-#: fortran/resolve.c:14786
+#: fortran/resolve.c:14806
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:14793
+#: fortran/resolve.c:14813
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:14813
+#: fortran/resolve.c:14833
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.c:14820
+#: fortran/resolve.c:14840
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14827
+#: fortran/resolve.c:14847
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:14834
+#: fortran/resolve.c:14854
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:14860
+#: fortran/resolve.c:14880
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:14870
+#: fortran/resolve.c:14890
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of %s at %L must be of length one"
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "Argumentin %s kohdassa %L on oltava pituudeltaan yksi"
 
-#: fortran/resolve.c:14949
+#: fortran/resolve.c:14969
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:14964
+#: fortran/resolve.c:14984
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14977
+#: fortran/resolve.c:14997
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14995
+#: fortran/resolve.c:15015
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.c:15007
+#: fortran/resolve.c:15027
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:15016
+#: fortran/resolve.c:15036
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L cannot be INTENT(IN)"
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L ei voi olla INTENT(IN)"
 
-#: fortran/resolve.c:15028
+#: fortran/resolve.c:15048
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr ""
 
-#: fortran/resolve.c:15037
+#: fortran/resolve.c:15057
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15049
+#: fortran/resolve.c:15069
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15065
+#: fortran/resolve.c:15085
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15073
+#: fortran/resolve.c:15093
 #, fuzzy, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:15080
+#: fortran/resolve.c:15100
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15092
+#: fortran/resolve.c:15112
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.c:15101
+#: fortran/resolve.c:15121
 #, fuzzy, gcc-internal-format
 #| msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "Muuttujan alustus kohdassa %C ei ole sallittu PURE-proseduurissa"
 
-#: fortran/resolve.c:15117
+#: fortran/resolve.c:15137
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15123
+#: fortran/resolve.c:15143
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15148
+#: fortran/resolve.c:15168
 #, fuzzy, gcc-internal-format
 #| msgid "Unknown argument list function at %L"
 msgid "Namelist %qs can not be an argument to subroutine or function at %L"
 msgstr "Tuntematon argumenttiluettelofunktio kohdassa %L"
 
-#: fortran/resolve.c:15218
+#: fortran/resolve.c:15238
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:15229
+#: fortran/resolve.c:15249
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:15333
+#: fortran/resolve.c:15353
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:15339
+#: fortran/resolve.c:15359
 #, fuzzy, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:15345
+#: fortran/resolve.c:15365
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.c:15354
+#: fortran/resolve.c:15374
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:15368
+#: fortran/resolve.c:15388
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:15414
+#: fortran/resolve.c:15434
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.c:15427
+#: fortran/resolve.c:15447
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.c:15526
+#: fortran/resolve.c:15546
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15534
+#: fortran/resolve.c:15554
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15542
+#: fortran/resolve.c:15562
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15667
+#: fortran/resolve.c:15687
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.c:15832
+#: fortran/resolve.c:15852
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "Nimiö %d kohdassa %L on määritelty, mutta ei käytetty"
 
-#: fortran/resolve.c:15838
+#: fortran/resolve.c:15858
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "Nimiö %d kohdassa %L on määritelty, mutta sitä ei voida käyttää"
 
-#: fortran/resolve.c:15922
+#: fortran/resolve.c:15942
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15931
+#: fortran/resolve.c:15951
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15939
+#: fortran/resolve.c:15959
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:15955
+#: fortran/resolve.c:15975
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16058
+#: fortran/resolve.c:16078
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "Syntaksivirhe IMPORT-lauseessa kohdassa %C"
 
-#: fortran/resolve.c:16073
+#: fortran/resolve.c:16093
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:16098
+#: fortran/resolve.c:16118
 #, fuzzy, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: fortran/resolve.c:16107
+#: fortran/resolve.c:16127
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16180
+#: fortran/resolve.c:16200
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16191
+#: fortran/resolve.c:16211
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16202
+#: fortran/resolve.c:16222
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr ""
 
-#: fortran/resolve.c:16293
+#: fortran/resolve.c:16253
+#, fuzzy, gcc-internal-format
+#| msgid "Syntax error in character length specification at %C"
+msgid "Self reference in character length expression for %qs at %L"
+msgstr "Syntaksivirhe merkkipituusspesifikaatiossa kohdassa %C"
+
+#: fortran/resolve.c:16320
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.c:16306
+#: fortran/resolve.c:16333
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:16326
+#: fortran/resolve.c:16353
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:16336
+#: fortran/resolve.c:16363
 #, fuzzy, gcc-internal-format
 #| msgid "Return type of BIND(C) function '%s' at %L cannot be a character string"
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "BIND(C)-funktion ”%s” paluutyyppi kohdassa %L ei voi olla merkkijono"
 
-#: fortran/resolve.c:16344
+#: fortran/resolve.c:16371
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L must have at least two arguments"
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "Kääntäjänsisäisellä ”%s”-funktiolla kohdassa %L on oltava vähintään kaksi argumenttia"
 
-#: fortran/resolve.c:16358
+#: fortran/resolve.c:16385
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:16376
+#: fortran/resolve.c:16403
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:16383
+#: fortran/resolve.c:16410
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr ""
 
-#: fortran/resolve.c:16461
+#: fortran/resolve.c:16488
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -63995,19 +64081,12 @@
 msgid "simplify_min_max(): Bad type in arglist"
 msgstr ""
 
-#. Result is processor-dependent.
-#: fortran/simplify.c:5472
-#, fuzzy, gcc-internal-format, gfc-internal-format
-msgid "Second argument MOD at %L is zero"
-msgstr "%<__builtin_prefetch%>-funktion toinen argumentti on epäkelpo; käytetään nollaa"
+#: fortran/simplify.c:5470 fortran/simplify.c:5478
+#, fuzzy, gcc-internal-format
+msgid "Argument %qs of MOD at %L shall not be zero"
+msgstr "%qs ei ole kelpo tulostetiedosto"
 
-#. Result is processor-dependent.
-#: fortran/simplify.c:5483
-#, fuzzy, gcc-internal-format, gfc-internal-format
-msgid "Second argument of MOD at %L is zero"
-msgstr "%<__builtin_prefetch%>-funktion toinen argumentti on epäkelpo; käytetään nollaa"
-
-#: fortran/simplify.c:5494
+#: fortran/simplify.c:5484
 #, gcc-internal-format
 msgid "gfc_simplify_mod(): Bad arguments"
 msgstr ""
@@ -64015,98 +64094,98 @@
 #. Result is processor-dependent. This processor just opts
 #. to not handle it at all.
 #. Result is processor-dependent.
-#: fortran/simplify.c:5520 fortran/simplify.c:5532
+#: fortran/simplify.c:5525 fortran/simplify.c:5537
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Second argument of MODULO at %L is zero"
 msgstr "%<__builtin_prefetch%>-funktion toinen argumentti on epäkelpo; käytetään nollaa"
 
-#: fortran/simplify.c:5552
+#: fortran/simplify.c:5557
 #, gcc-internal-format
 msgid "gfc_simplify_modulo(): Bad arguments"
 msgstr ""
 
-#: fortran/simplify.c:5600
+#: fortran/simplify.c:5605
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Result of NEAREST is NaN at %L"
 msgstr "Haarautuminen kohdassa %L voi aiheuttaa ikisilmukan"
 
-#: fortran/simplify.c:6081
+#: fortran/simplify.c:6086
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative at %L"
 msgstr ""
 
-#: fortran/simplify.c:6137
+#: fortran/simplify.c:6142
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument NCOPIES of REPEAT intrinsic is too large at %L"
 msgstr ""
 
-#: fortran/simplify.c:6174
+#: fortran/simplify.c:6179
 #, gcc-internal-format, gfc-internal-format
 msgid "Evaluation of string longer than 2**28 at %L deferred to runtime, expect bugs"
 msgstr ""
 
-#: fortran/simplify.c:6302
+#: fortran/simplify.c:6307
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Integer too large at %C"
 msgid "Reshaped array too large at %C"
 msgstr "Kokonaisluku liian suuri kohdassa %C"
 
-#: fortran/simplify.c:6416
+#: fortran/simplify.c:6421
 #, gcc-internal-format, gfc-internal-format
 msgid "Result of SCALE overflows its kind at %L"
 msgstr ""
 
-#: fortran/simplify.c:6995
+#: fortran/simplify.c:7000
 #, fuzzy, gcc-internal-format
 msgid "Bad type in gfc_simplify_sign"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: fortran/simplify.c:7024
+#: fortran/simplify.c:7029
 #, gcc-internal-format
 msgid "in gfc_simplify_sin(): Bad type"
 msgstr ""
 
-#: fortran/simplify.c:7151 fortran/simplify.c:7431
+#: fortran/simplify.c:7156 fortran/simplify.c:7436
 #, gcc-internal-format
 msgid "Failure getting length of a constant array."
 msgstr ""
 
-#: fortran/simplify.c:7161
+#: fortran/simplify.c:7166
 #, gcc-internal-format
 msgid "The number of elements (%d) in the array constructor at %L requires an increase of the allowed %d upper limit.  See %<-fmax-array-constructor%> option."
 msgstr ""
 
-#: fortran/simplify.c:7227
+#: fortran/simplify.c:7232
 #, gcc-internal-format, gfc-internal-format
 msgid "Simplification of SPREAD at %C not yet implemented"
 msgstr ""
 
-#: fortran/simplify.c:7251
+#: fortran/simplify.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SQRT at %L has a negative value"
 msgstr ""
 
-#: fortran/simplify.c:7267
+#: fortran/simplify.c:7272
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid argument of SQRT at %L"
 msgstr "Virheellinen proseduuriargumentti kohdassa %L"
 
-#: fortran/simplify.c:7598
+#: fortran/simplify.c:7603
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY lower bound is %ld)"
 msgstr ""
 
-#: fortran/simplify.c:7621
+#: fortran/simplify.c:7626
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY upper bound is %ld)"
 msgstr ""
 
-#: fortran/simplify.c:7993
+#: fortran/simplify.c:7998
 #, gcc-internal-format
 msgid "gfc_convert_constant(): Unexpected type"
 msgstr ""
 
-#: fortran/simplify.c:8078
+#: fortran/simplify.c:8083
 #, gcc-internal-format
 msgid "Character %qs in string at %L cannot be converted into character kind %d"
 msgstr ""
@@ -64212,7 +64291,7 @@
 msgid "BIND(C) applied to %s %s at %L"
 msgstr "Nimi ”%s” kohdassa %C on jo määritelty geneerisenä rajapintana kohdassa %L"
 
-#: fortran/symbol.c:901 fortran/symbol.c:912 fortran/symbol.c:1762
+#: fortran/symbol.c:901 fortran/symbol.c:912 fortran/symbol.c:1776
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s attribute conflicts with %s attribute at %L"
 msgstr "Kaksoiskappale-%s-attribuutti määritelty kohdassa %L"
@@ -64287,17 +64366,23 @@
 msgid "Duplicate VOLATILE attribute specified at %L"
 msgstr "Kaksoiskappale VALUE-attribuutti määritelty kohdassa %L"
 
-#: fortran/symbol.c:1367
+#: fortran/symbol.c:1360
 #, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "SAVE attribute at %L cannot be specified in a PURE procedure"
+msgid "VOLATILE attribute at %L cannot be specified in a PURE procedure"
+msgstr "SAVE-attribuuttia kohdassa %L ei voida määritellä PURE-proseduurissa"
+
+#: fortran/symbol.c:1381
+#, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ASYNCHRONOUS attribute specified at %L"
 msgstr "Kaksoiskappale-%s-attribuutti määritelty kohdassa %L"
 
-#: fortran/symbol.c:1758
+#: fortran/symbol.c:1772
 #, fuzzy, gcc-internal-format
 msgid "%s attribute of %qs conflicts with %s attribute at %L"
 msgstr "Kaksoiskappale-%s-attribuutti määritelty kohdassa %L"
 
-#: fortran/symbol.c:1794
+#: fortran/symbol.c:1808
 #, gcc-internal-format, gfc-internal-format
 msgid ""
 "%s procedure at %L is already declared as %s procedure. \n"
@@ -64304,217 +64389,217 @@
 "F2008: A pointer function assignment is ambiguous if it is the first executable statement after the specification block. Please add any other kind of executable statement before it. FIXME"
 msgstr ""
 
-#: fortran/symbol.c:1802
+#: fortran/symbol.c:1816
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s procedure at %L is already declared as %s procedure"
 msgstr "Proseduuri ”%s” kohdassa %C on jo määritelty kohdassa %L"
 
-#: fortran/symbol.c:1837
+#: fortran/symbol.c:1851
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgstr ""
 
-#: fortran/symbol.c:1861
+#: fortran/symbol.c:1875
 #, gcc-internal-format, gfc-internal-format
 msgid "ACCESS specification at %L was already specified"
 msgstr ""
 
-#: fortran/symbol.c:1878
+#: fortran/symbol.c:1892
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate BIND attribute specified at %L"
 msgstr "Kaksoiskappale-BIND-attribuutti määritelty kohdassa %L"
 
-#: fortran/symbol.c:1885
+#: fortran/symbol.c:1899
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) at %L"
 msgstr "Kaksoiskappale-BIND-attribuutti määritelty kohdassa %L"
 
-#: fortran/symbol.c:1901
+#: fortran/symbol.c:1915
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate EXTENDS attribute specified at %L"
 msgstr "Kaksoiskappale-EXTENDS-attribuutti määritelty kohdassa %L"
 
-#: fortran/symbol.c:1905
+#: fortran/symbol.c:1919
 #, gcc-internal-format, gfc-internal-format
 msgid "EXTENDS at %L"
 msgstr ""
 
-#: fortran/symbol.c:1931
+#: fortran/symbol.c:1945
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L already has an explicit interface"
 msgstr "Nimi ”%s” kohdassa %C on jo määritelty geneerisenä rajapintana kohdassa %L"
 
-#: fortran/symbol.c:1938
+#: fortran/symbol.c:1952
 #, gcc-internal-format
 msgid "%qs at %L has attributes specified outside its INTERFACE body"
 msgstr ""
 
-#: fortran/symbol.c:1976
+#: fortran/symbol.c:1990
 #, gcc-internal-format
 msgid "Symbol %qs at %L conflicts with symbol from module %qs, use-associated at %L"
 msgstr ""
 
-#: fortran/symbol.c:1980
+#: fortran/symbol.c:1994
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L may not have basic type of %s"
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/symbol.c:1987
+#: fortran/symbol.c:2001
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L may not have basic type of %s"
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/symbol.c:1999
+#: fortran/symbol.c:2013
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "Symbol %qs at %L cannot have a type"
 msgstr "Tyhjällä ”%s” kohdassa %L ei voi olla alustinta"
 
-#: fortran/symbol.c:2242
+#: fortran/symbol.c:2256
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %L may not have basic type of %s"
 msgid "Component %qs at %C already in the parent type at %L"
 msgstr "Proseduuri ”%s” kohdassa %L ei voi olla perustyyppiä %s"
 
-#: fortran/symbol.c:2327
+#: fortran/symbol.c:2341
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %L is ambiguous"
 msgid "Symbol %qs at %C is ambiguous"
 msgstr "Monimerkityksellinen symboli TYPE-määrittelyssä kohdassa %C"
 
-#: fortran/symbol.c:2359
+#: fortran/symbol.c:2373
 #, gcc-internal-format
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr ""
 
-#: fortran/symbol.c:2508
+#: fortran/symbol.c:2522
 #, gcc-internal-format
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr ""
 
-#: fortran/symbol.c:2529
+#: fortran/symbol.c:2543
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qD"
 msgid "%qs at %C is not a member of the %qs structure; did you mean %qs?"
 msgstr "Jäsenfunktio %qs"
 
-#: fortran/symbol.c:2533
+#: fortran/symbol.c:2547
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qD"
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr "Jäsenfunktio %qs"
 
-#: fortran/symbol.c:2697
+#: fortran/symbol.c:2711
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr "FORMAT-nimiö %d kohdassa %L ei ole määritelty"
 
-#: fortran/symbol.c:2708
+#: fortran/symbol.c:2722
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr ""
 
-#: fortran/symbol.c:2718
+#: fortran/symbol.c:2732
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr ""
 
-#: fortran/symbol.c:2724
+#: fortran/symbol.c:2738
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:2766
+#: fortran/symbol.c:2780
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr ""
 
-#: fortran/symbol.c:2775
+#: fortran/symbol.c:2789
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr ""
 
-#: fortran/symbol.c:2781
+#: fortran/symbol.c:2795
 #, gcc-internal-format, gfc-internal-format
 msgid "Shared DO termination label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:3110
+#: fortran/symbol.c:3124
 #, gcc-internal-format
 msgid "new_symbol(): Symbol name too long"
 msgstr ""
 
-#: fortran/symbol.c:3135
+#: fortran/symbol.c:3149
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr ""
 
-#: fortran/symbol.c:3138
+#: fortran/symbol.c:3152
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
 msgstr ""
 
 #. Symbol is from another namespace.
-#: fortran/symbol.c:3381
+#: fortran/symbol.c:3395
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C is already in a COMMON block"
 msgid "Symbol %qs at %C has already been host associated"
 msgstr "Symboli ”%s” kohdassa %C on jo COMMON-lohkossa"
 
-#: fortran/symbol.c:4397
+#: fortran/symbol.c:4411
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr ""
 
-#: fortran/symbol.c:4410
+#: fortran/symbol.c:4424
 #, gcc-internal-format
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr ""
 
-#: fortran/symbol.c:4428
+#: fortran/symbol.c:4442
 #, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr ""
 
-#: fortran/symbol.c:4449
+#: fortran/symbol.c:4463
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:4459
+#: fortran/symbol.c:4473
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs at %L cannot be a member of the BIND(C) derived type %qs at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/symbol.c:4470
+#: fortran/symbol.c:4484
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:4509
+#: fortran/symbol.c:4523
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.c:4519
+#: fortran/symbol.c:4533
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/symbol.c:4533
+#: fortran/symbol.c:4547
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
 msgid "Derived type %qs at %L cannot be declared with both PRIVATE and BIND(C) attributes"
 msgstr "Muuttujalla ”%s” kohdassa %L ei voi olla sekä POINTER- että BIND(C)-attribuutit"
 
-#: fortran/symbol.c:4541
+#: fortran/symbol.c:4555
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.c:5018 fortran/symbol.c:5023
+#: fortran/symbol.c:5032 fortran/symbol.c:5037
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' is used before it is typed at %L"
 msgid "Symbol %qs is used before it is typed at %L"
@@ -64562,7 +64647,7 @@
 msgid "Creating array temporary at %L for argument %qs"
 msgstr ""
 
-#: fortran/trans-array.c:10693
+#: fortran/trans-array.c:10724
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr ""
@@ -64771,12 +64856,12 @@
 msgid "%<dim%> argument of %s intrinsic at %L is not a valid dimension index"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentti ”%1$s” kohdassa %3$L ei ole kelvollinen ulottuvuusindeksi"
 
-#: fortran/trans-intrinsic.c:10572 fortran/trans-stmt.c:1050
+#: fortran/trans-intrinsic.c:10574 fortran/trans-stmt.c:1050
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, the event component of derived type at %L is not yet supported"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:10579
+#: fortran/trans-intrinsic.c:10581
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The event variable at %L shall not be coindexed"
 msgstr "%<__builtin_args_info%>-funktion argumentin pitää olla vakio"
@@ -64816,7 +64901,7 @@
 msgid "Sorry, only support for integer kind %d implemented for image-set at %L"
 msgstr ""
 
-#: fortran/trans-stmt.c:3346
+#: fortran/trans-stmt.c:3343
 #, gcc-internal-format
 msgid "gfc_trans_select(): Bad type for case expr."
 msgstr ""
@@ -64944,7 +65029,7 @@
 msgid "two or more sections for %s"
 msgstr "yli yksi tietotyyppi esittelymääritteissä"
 
-#: lto/lto-partition.c:516
+#: lto/lto-partition.c:570
 #, gcc-internal-format
 msgid "min partition size cannot be greater than max partition size"
 msgstr ""
@@ -65082,57 +65167,57 @@
 msgid "Cannot read %s"
 msgstr "tietokantaa %s ei voi lukea"
 
-#: lto/lto.c:2369
+#: lto/lto.c:2337
 #, gcc-internal-format
 msgid "lto_obj_file_open() failed"
 msgstr ""
 
-#: lto/lto.c:2394
+#: lto/lto.c:2362
 #, gcc-internal-format
 msgid "waitpid failed"
 msgstr "waitpid epäonnistui"
 
-#: lto/lto.c:2397
+#: lto/lto.c:2365
 #, fuzzy, gcc-internal-format
 msgid "streaming subprocess failed"
 msgstr "  -time                    Mittaa kunkin aliprosessin suoritusaika\n"
 
-#: lto/lto.c:2400
+#: lto/lto.c:2368
 #, gcc-internal-format
 msgid "streaming subprocess was killed by signal"
 msgstr ""
 
-#: lto/lto.c:2476
+#: lto/lto.c:2445
 #, fuzzy, gcc-internal-format
 msgid "no LTRANS output list filename provided"
 msgstr "kirjoitettaessa LTRANS-tulosteluetteloa %s: %m"
 
-#: lto/lto.c:2564
+#: lto/lto.c:2525
 #, gcc-internal-format
 msgid "opening LTRANS output list %s: %m"
 msgstr "avattaessa LTRANS-tulosteluetteloa %s: %m"
 
-#: lto/lto.c:2570
+#: lto/lto.c:2532
 #, gcc-internal-format
 msgid "writing to LTRANS output list %s: %m"
 msgstr "kirjoitettaessa LTRANS-tulosteluetteloa %s: %m"
 
-#: lto/lto.c:2581
+#: lto/lto.c:2542
 #, gcc-internal-format
 msgid "closing LTRANS output list %s: %m"
 msgstr "suljettaessa LTRANS-tulosteluetteloa %s: %m"
 
-#: lto/lto.c:2833
+#: lto/lto.c:2794
 #, gcc-internal-format
 msgid "could not open symbol resolution file: %m"
 msgstr "ei voitu avata symbolinselvitystiedostoa: %m"
 
-#: lto/lto.c:2954
+#: lto/lto.c:2915
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing resolution data for %s"
 msgstr "alustimen ympäriltä puuttuu aaltosulkeet"
 
-#: lto/lto.c:2986
+#: lto/lto.c:2947
 #, gcc-internal-format
 msgid "errors during merging of translation units"
 msgstr ""
Index: gcc/po/el.po
===================================================================
--- gcc/po/el.po	(.../tags/gcc_8_2_0_release)
+++ gcc/po/el.po	(.../branches/gcc-8-branch)
@@ -6,7 +6,7 @@
 msgstr ""
 "Project-Id-Version: gcc 4.0-b20041128\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2018-05-01 20:30+0000\n"
+"POT-Creation-Date: 2018-07-25 14:25+0000\n"
 "PO-Revision-Date: 2004-12-15 18:53+0000\n"
 "Last-Translator: Simos Xenitellis <simos74@gmx.net>\n"
 "Language-Team: Greek <nls@tux.hellug.gr>\n"
@@ -37,13 +37,13 @@
 msgid "[cannot find %s]"
 msgstr "Δεν είναι δυνατόν να εκτελεστεί το %s"
 
-#: collect2.c:1557
+#: collect2.c:1585
 #, fuzzy, c-format
 #| msgid "gcc version %s\n"
 msgid "collect2 version %s\n"
 msgstr "έκδοση gcc %s\n"
 
-#: collect2.c:1664
+#: collect2.c:1692
 #, fuzzy, c-format
 msgid "%d constructor found\n"
 msgid_plural "%d constructors found\n"
@@ -50,7 +50,7 @@
 msgstr[0] "το `%s' είναι πρόγονος του `%s'"
 msgstr[1] "το `%s' είναι πρόγονος του `%s'"
 
-#: collect2.c:1668
+#: collect2.c:1696
 #, fuzzy, c-format
 msgid "%d destructor found\n"
 msgid_plural "%d destructors found\n"
@@ -57,7 +57,7 @@
 msgstr[0] "Δεν βρέθηκε μέσο"
 msgstr[1] "Δεν βρέθηκε μέσο"
 
-#: collect2.c:1672
+#: collect2.c:1700
 #, fuzzy, c-format
 msgid "%d frame table found\n"
 msgid_plural "%d frame tables found\n"
@@ -64,12 +64,12 @@
 msgstr[0] "δεν δώθηκε συμβολικό όνομα"
 msgstr[1] "δεν δώθηκε συμβολικό όνομα"
 
-#: collect2.c:1836
+#: collect2.c:1864
 #, fuzzy, c-format
 msgid "[Leaving %s]\n"
 msgstr "διαγραφή καταλόγου %s\n"
 
-#: collect2.c:2068
+#: collect2.c:2094
 #, c-format
 msgid ""
 "\n"
@@ -76,7 +76,7 @@
 "write_c_file - output name is %s, prefix is %s\n"
 msgstr ""
 
-#: collect2.c:2584
+#: collect2.c:2610
 #, c-format
 msgid ""
 "\n"
@@ -98,7 +98,7 @@
 msgid "%s: some warnings being treated as errors"
 msgstr "%s: Προειδοποίηση: η uname απέτυχε: %s\n"
 
-#: diagnostic.c:324 input.c:222 input.c:1834 c-family/c-opts.c:1377
+#: diagnostic.c:324 input.c:222 input.c:1834 c-family/c-opts.c:1392
 #: fortran/cpp.c:576 fortran/error.c:1008 fortran/error.c:1028
 msgid "<built-in>"
 msgstr ""
@@ -190,13 +190,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:4164 config/arc/arc.c:5784 config/i386/i386.c:17302
+#: final.c:4164 config/arc/arc.c:5775 config/i386/i386.c:17305
 #: config/pdp11/pdp11.c:1715
 #, c-format
 msgid "floating constant misused"
 msgstr ""
 
-#: final.c:4222 config/arc/arc.c:5881 config/i386/i386.c:17393
+#: final.c:4222 config/arc/arc.c:5872 config/i386/i386.c:17396
 #: config/pdp11/pdp11.c:1756
 #, fuzzy, c-format
 msgid "invalid expression as operand"
@@ -1185,7 +1185,7 @@
 msgid "GCSE disabled"
 msgstr ""
 
-#: gimple-ssa-isolate-paths.c:542 c/c-typeck.c:10240
+#: gimple-ssa-isolate-paths.c:542 c/c-typeck.c:10245
 #, gcc-internal-format
 msgid "function returns address of local variable"
 msgstr ""
@@ -1496,7 +1496,7 @@
 msgid "options enabled: "
 msgstr "επιλογή α\n"
 
-#: tree-diagnostic.c:299 c/c-decl.c:5419 c/c-typeck.c:7259 cp/error.c:1042
+#: tree-diagnostic.c:299 c/c-decl.c:5439 c/c-typeck.c:7264 cp/error.c:1042
 #: c-family/c-pretty-print.c:413
 #, fuzzy, gcc-internal-format
 msgid "<anonymous>"
@@ -2970,64 +2970,64 @@
 msgstr ""
 
 #. Handle deferred options from command-line.
-#: c-family/c-opts.c:1402 fortran/cpp.c:590
+#: c-family/c-opts.c:1417 fortran/cpp.c:590
 msgid "<command-line>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6613
+#: config/aarch64/aarch64.c:6629
 #, fuzzy, c-format
 msgid "unsupported operand for code '%c'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/aarch64/aarch64.c:6624 config/aarch64/aarch64.c:6640
-#: config/aarch64/aarch64.c:6652 config/aarch64/aarch64.c:6663
-#: config/aarch64/aarch64.c:6673 config/aarch64/aarch64.c:6694
-#: config/aarch64/aarch64.c:6764 config/aarch64/aarch64.c:6775
-#: config/aarch64/aarch64.c:6789 config/aarch64/aarch64.c:7011
-#: config/aarch64/aarch64.c:7029
+#: config/aarch64/aarch64.c:6640 config/aarch64/aarch64.c:6656
+#: config/aarch64/aarch64.c:6668 config/aarch64/aarch64.c:6679
+#: config/aarch64/aarch64.c:6689 config/aarch64/aarch64.c:6710
+#: config/aarch64/aarch64.c:6780 config/aarch64/aarch64.c:6791
+#: config/aarch64/aarch64.c:6805 config/aarch64/aarch64.c:7027
+#: config/aarch64/aarch64.c:7045
 #, fuzzy, c-format
 msgid "invalid operand for '%%%c'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/aarch64/aarch64.c:6709 config/aarch64/aarch64.c:6720
-#: config/aarch64/aarch64.c:6871 config/aarch64/aarch64.c:6882
+#: config/aarch64/aarch64.c:6725 config/aarch64/aarch64.c:6736
+#: config/aarch64/aarch64.c:6887 config/aarch64/aarch64.c:6898
 #, fuzzy, c-format
 msgid "invalid vector constant"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: config/aarch64/aarch64.c:6732 config/aarch64/aarch64.c:6744
-#: config/aarch64/aarch64.c:6755
+#: config/aarch64/aarch64.c:6748 config/aarch64/aarch64.c:6760
+#: config/aarch64/aarch64.c:6771
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6823 config/arm/arm.c:22704
+#: config/aarch64/aarch64.c:6839 config/arm/arm.c:22704
 #, fuzzy, c-format
 msgid "missing operand"
 msgstr "έχει παραληφθεί η λίστα με τα πεδία"
 
-#: config/aarch64/aarch64.c:6908
+#: config/aarch64/aarch64.c:6924
 #, fuzzy, c-format
 msgid "invalid constant"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/aarch64/aarch64.c:6911
+#: config/aarch64/aarch64.c:6927
 #, fuzzy, c-format
 msgid "invalid operand"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/aarch64/aarch64.c:7040 config/aarch64/aarch64.c:7045
+#: config/aarch64/aarch64.c:7056 config/aarch64/aarch64.c:7061
 #, fuzzy, c-format
 msgid "invalid operand prefix '%%%c'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/aarch64/aarch64.c:7062
+#: config/aarch64/aarch64.c:7078
 #, fuzzy, c-format
 msgid "invalid address mode"
 msgstr "Ακατάλληλη χρήση του διαμορφωτή διεύθυνσης"
 
-#: config/alpha/alpha.c:5125 config/i386/i386.c:18558
-#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21798
+#: config/alpha/alpha.c:5125 config/i386/i386.c:18561
+#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21875
 #: config/sparc/sparc.c:9290
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
@@ -3044,7 +3044,7 @@
 msgstr "μη έγκυρος χρήστης"
 
 #: config/alpha/alpha.c:5223 config/ia64/ia64.c:5534
-#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21506
+#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21583
 #: config/xtensa/xtensa.c:2429
 #, fuzzy, c-format
 msgid "invalid %%R value"
@@ -3051,13 +3051,13 @@
 msgstr "μη έγκυρος χρήστης"
 
 #: config/alpha/alpha.c:5229 config/powerpcspe/powerpcspe.c:23933
-#: config/rs6000/rs6000.c:21426 config/xtensa/xtensa.c:2396
+#: config/rs6000/rs6000.c:21503 config/xtensa/xtensa.c:2396
 #, fuzzy, c-format
 msgid "invalid %%N value"
 msgstr "μη έγκυρος χρήστης"
 
 #: config/alpha/alpha.c:5237 config/powerpcspe/powerpcspe.c:23961
-#: config/rs6000/rs6000.c:21454
+#: config/rs6000/rs6000.c:21531
 #, fuzzy, c-format
 msgid "invalid %%P value"
 msgstr "μη έγκυρος χρήστης"
@@ -3088,7 +3088,7 @@
 msgstr "μη έγκυρος χρήστης"
 
 #: config/alpha/alpha.c:5323 config/powerpcspe/powerpcspe.c:24021
-#: config/rs6000/rs6000.c:21514
+#: config/rs6000/rs6000.c:21591
 #, fuzzy, c-format
 msgid "invalid %%s value"
 msgstr "μη έγκυρος χρήστης"
@@ -3099,7 +3099,7 @@
 msgstr "μη έγκυρος χρήστης"
 
 #: config/alpha/alpha.c:5371 config/powerpcspe/powerpcspe.c:23797
-#: config/rs6000/rs6000.c:21290
+#: config/rs6000/rs6000.c:21367
 #, fuzzy, c-format
 msgid "invalid %%E value"
 msgstr "μη έγκυρος χρήστης"
@@ -3110,7 +3110,7 @@
 msgstr "Δεν είναι δυνατόν να βρεθεί ο τύπος του επεξεργαστή."
 
 #: config/alpha/alpha.c:5405 config/cr16/cr16.c:1569
-#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21803
+#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21880
 #: config/spu/spu.c:1458
 #, fuzzy, c-format
 msgid "invalid %%xn code"
@@ -3121,57 +3121,57 @@
 msgid "invalid operand address"
 msgstr "Ακατάλληλη χρήση του διαμορφωτή διεύθυνσης"
 
-#: config/arc/arc.c:3810
+#: config/arc/arc.c:3808
 #, fuzzy, c-format
 msgid "invalid operand to %%Z code"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/arc/arc.c:3818
+#: config/arc/arc.c:3816
 #, fuzzy, c-format
 msgid "invalid operand to %%z code"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/arc/arc.c:3826
+#: config/arc/arc.c:3824
 #, fuzzy, c-format
 msgid "invalid operands to %%c code"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/arc/arc.c:3834
+#: config/arc/arc.c:3832
 #, fuzzy, c-format
 msgid "invalid operand to %%M code"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/arc/arc.c:3842 config/m32r/m32r.c:2100
+#: config/arc/arc.c:3840 config/m32r/m32r.c:2100
 #, fuzzy, c-format
 msgid "invalid operand to %%p code"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/arc/arc.c:3853 config/m32r/m32r.c:2093
+#: config/arc/arc.c:3851 config/m32r/m32r.c:2093
 #, fuzzy, c-format
 msgid "invalid operand to %%s code"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/arc/arc.c:4001 config/m32r/m32r.c:2126
+#: config/arc/arc.c:3999 config/m32r/m32r.c:2126
 #, fuzzy, c-format
 msgid "invalid operand to %%R code"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/arc/arc.c:4077 config/m32r/m32r.c:2149
+#: config/arc/arc.c:4075 config/m32r/m32r.c:2149
 #, fuzzy, c-format
 msgid "invalid operand to %%H/%%L code"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/arc/arc.c:4145 config/m32r/m32r.c:2220
+#: config/arc/arc.c:4143 config/m32r/m32r.c:2220
 #, fuzzy, c-format
 msgid "invalid operand to %%U code"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/arc/arc.c:4157
+#: config/arc/arc.c:4155
 #, fuzzy, c-format
 msgid "invalid operand to %%V code"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/arc/arc.c:4214
+#: config/arc/arc.c:4212
 #, fuzzy, c-format
 msgid "invalid operand to %%O code"
 msgstr "Μη έγκυρη επιλογή `%s'"
@@ -3178,18 +3178,18 @@
 
 #. Unknown flag.
 #. Undocumented flag.
-#: config/arc/arc.c:4240 config/epiphany/epiphany.c:1305
-#: config/m32r/m32r.c:2247 config/nds32/nds32.c:3079 config/sparc/sparc.c:9569
+#: config/arc/arc.c:4238 config/epiphany/epiphany.c:1305
+#: config/m32r/m32r.c:2247 config/nds32/nds32.c:3080 config/sparc/sparc.c:9569
 #, fuzzy, c-format
 msgid "invalid operand output code"
 msgstr "Μη έγκυρος κώδικας αίτησης"
 
-#: config/arc/arc.c:5869
+#: config/arc/arc.c:5860
 #, fuzzy, c-format
 msgid "invalid UNSPEC as operand: %d"
 msgstr "μη έγκυρη μετατόπιση UTC"
 
-#: config/arc/arc.c:6158 config/cris/cris.c:2568
+#: config/arc/arc.c:6149 config/cris/cris.c:2568
 #, fuzzy
 msgid "unrecognized supposed constant"
 msgstr "άγνωστο πρόθεμα: %s"
@@ -3225,7 +3225,7 @@
 #: config/arm/arm.c:22685 config/arm/arm.c:22692 config/bfin/bfin.c:1441
 #: config/bfin/bfin.c:1448 config/bfin/bfin.c:1455 config/bfin/bfin.c:1462
 #: config/bfin/bfin.c:1471 config/bfin/bfin.c:1478 config/bfin/bfin.c:1485
-#: config/bfin/bfin.c:1492 config/nds32/nds32.c:3098
+#: config/bfin/bfin.c:1492 config/nds32/nds32.c:3099
 #, fuzzy, c-format
 msgid "invalid operand for code '%c'"
 msgstr "Μη έγκυρη επιλογή `%s'"
@@ -3607,98 +3607,98 @@
 msgid "bad output_condmove_single operand"
 msgstr "αρχείο εξόδου"
 
-#: config/i386/i386.c:17387
+#: config/i386/i386.c:17390
 #, fuzzy, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "μη έγκυρη μετατόπιση UTC"
 
-#: config/i386/i386.c:17925
+#: config/i386/i386.c:17928
 #, fuzzy, c-format
 msgid "invalid use of register '%s'"
 msgstr "μη έγκυρος αριθμός από γραμμές"
 
-#: config/i386/i386.c:17930
+#: config/i386/i386.c:17933
 #, fuzzy, c-format
 msgid "invalid use of asm flag output"
 msgstr "Η παράμετρος κινητής υποδιαστολής δεν είναι έγκυρη: %s"
 
-#: config/i386/i386.c:18160
+#: config/i386/i386.c:18163
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/i386/i386.c:18195
+#: config/i386/i386.c:18198
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/i386/i386.c:18264
+#: config/i386/i386.c:18267
 #, fuzzy, c-format
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/i386/i386.c:18269
+#: config/i386/i386.c:18272
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'Z'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/i386/i386.c:18346
+#: config/i386/i386.c:18349
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr ""
 
-#: config/i386/i386.c:18425
+#: config/i386/i386.c:18428
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr ""
 
-#: config/i386/i386.c:18443
+#: config/i386/i386.c:18446
 #, fuzzy, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/i386/i386.c:18456
+#: config/i386/i386.c:18459
 #, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr ""
 
-#: config/i386/i386.c:18471
+#: config/i386/i386.c:18474
 #, fuzzy, c-format
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/i386/i386.c:18499
+#: config/i386/i386.c:18502
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr ""
 
-#: config/i386/i386.c:18517
+#: config/i386/i386.c:18520
 #, fuzzy, c-format
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/i386/i386.c:18540
+#: config/i386/i386.c:18543
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr ""
 
-#: config/i386/i386.c:18626
+#: config/i386/i386.c:18629
 #, fuzzy, c-format
 msgid "invalid operand code '%c'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/i386/i386.c:18688
+#: config/i386/i386.c:18691
 #, fuzzy, c-format
 msgid "invalid constraints for operand"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/i386/i386.c:18738
+#: config/i386/i386.c:18741
 #, fuzzy, c-format
 msgid "invalid vector immediate"
 msgstr "μη έγκυρο δικαίωμα"
 
 # src/grep.c:1133
-#: config/i386/i386.c:29572
+#: config/i386/i386.c:29575
 #, fuzzy
 msgid "unknown insn mode"
 msgstr "άγνωστη μέθοδος καταλόγων"
@@ -3740,7 +3740,7 @@
 msgstr "μη έγκυρος χρήστης"
 
 #: config/iq2000/iq2000.c:3185 config/powerpcspe/powerpcspe.c:23951
-#: config/rs6000/rs6000.c:21444
+#: config/rs6000/rs6000.c:21521
 #, fuzzy, c-format
 msgid "invalid %%p value"
 msgstr "μη έγκυρος χρήστης"
@@ -3796,7 +3796,7 @@
 msgstr ""
 
 #: config/m32r/m32r.c:2350 config/m32r/m32r.c:2365
-#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33292
+#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33348
 #, fuzzy
 msgid "bad address"
 msgstr "Εσφαλμένη διεύθυνση"
@@ -3919,192 +3919,192 @@
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4411 config/rs6000/rs6000.c:4258
+#: config/powerpcspe/powerpcspe.c:4411 config/rs6000/rs6000.c:4278
 msgid "-maltivec=le not allowed for big-endian targets"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4423 config/rs6000/rs6000.c:4273
+#: config/powerpcspe/powerpcspe.c:4423 config/rs6000/rs6000.c:4293
 msgid "-mvsx requires hardware floating point"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4431 config/rs6000/rs6000.c:4281
+#: config/powerpcspe/powerpcspe.c:4431 config/rs6000/rs6000.c:4301
 msgid "-mvsx and -mpaired are incompatible"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4433 config/rs6000/rs6000.c:4283
+#: config/powerpcspe/powerpcspe.c:4433 config/rs6000/rs6000.c:4303
 #, fuzzy
 msgid "-mvsx needs indexed addressing"
 msgstr "Ακατάλληλη χρήση του διαμορφωτή διεύθυνσης"
 
-#: config/powerpcspe/powerpcspe.c:4438 config/rs6000/rs6000.c:4288
+#: config/powerpcspe/powerpcspe.c:4438 config/rs6000/rs6000.c:4308
 msgid "-mvsx and -mno-altivec are incompatible"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4440 config/rs6000/rs6000.c:4290
+#: config/powerpcspe/powerpcspe.c:4440 config/rs6000/rs6000.c:4310
 msgid "-mno-altivec disables vsx"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4648 config/rs6000/rs6000.c:4416
+#: config/powerpcspe/powerpcspe.c:4648 config/rs6000/rs6000.c:4436
 #, fuzzy
 msgid "-mquad-memory requires 64-bit mode"
 msgstr "Εσφαλμένος κώδικας αίτησης"
 
-#: config/powerpcspe/powerpcspe.c:4651 config/rs6000/rs6000.c:4419
+#: config/powerpcspe/powerpcspe.c:4651 config/rs6000/rs6000.c:4439
 msgid "-mquad-memory-atomic requires 64-bit mode"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4663 config/rs6000/rs6000.c:4431
+#: config/powerpcspe/powerpcspe.c:4663 config/rs6000/rs6000.c:4451
 msgid "-mquad-memory is not available in little endian mode"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4735 config/rs6000/rs6000.c:4512
+#: config/powerpcspe/powerpcspe.c:4735 config/rs6000/rs6000.c:4532
 #, fuzzy
 msgid "-mtoc-fusion requires 64-bit"
 msgstr "Εσφαλμένος κώδικας αίτησης"
 
-#: config/powerpcspe/powerpcspe.c:4742 config/rs6000/rs6000.c:4519
+#: config/powerpcspe/powerpcspe.c:4742 config/rs6000/rs6000.c:4539
 msgid "-mtoc-fusion requires medium/large code model"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10915
+#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10947
 #, fuzzy
 msgid "bad move"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21087
+#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21164
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21278
+#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21355
 #, fuzzy, c-format
 msgid "invalid %%e value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21299
+#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21376
 #, fuzzy, c-format
 msgid "invalid %%f value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21308
+#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21385
 #, fuzzy, c-format
 msgid "invalid %%F value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21317
+#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21394
 #, fuzzy, c-format
 msgid "invalid %%G value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21352
+#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21429
 #, fuzzy, c-format
 msgid "invalid %%j code"
 msgstr "μη έγκυρο δικαίωμα"
 
-#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21362
+#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21439
 #, fuzzy, c-format
 msgid "invalid %%J code"
 msgstr "μη έγκυρο δικαίωμα"
 
-#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21372
+#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21449
 #, fuzzy, c-format
 msgid "invalid %%k value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21387
+#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21464
 #: config/xtensa/xtensa.c:2415
 #, fuzzy, c-format
 msgid "invalid %%K value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21434
+#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21511
 #, fuzzy, c-format
 msgid "invalid %%O value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21481
+#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21558
 #, fuzzy, c-format
 msgid "invalid %%q value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21534
+#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21611
 #, fuzzy, c-format
 msgid "invalid %%T value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21546
+#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21623
 #, fuzzy, c-format
 msgid "invalid %%u value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21560
+#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21637
 #: config/xtensa/xtensa.c:2384
 #, fuzzy, c-format
 msgid "invalid %%v value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21627
+#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21704
 #: config/xtensa/xtensa.c:2436
 #, fuzzy, c-format
 msgid "invalid %%x value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21747
+#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21824
 #, fuzzy, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "μη έγκυρη μέτρηση επανάληψης `%s' στη κατασκευή [c*n]"
 
-#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22282
+#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22359
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22288
+#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22365
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22294
+#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22371
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36572
+#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36628
 #, fuzzy
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "πολύ λίγα ορίσματα"
 
-#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38739
+#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38795
 #, fuzzy
 msgid "Could not generate addis value for fusion"
 msgstr "Ακατάλληλη εντολή"
 
-#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38809
+#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38865
 #, fuzzy
 msgid "Unable to generate load/store offset for fusion"
 msgstr "Αδύνατη η δημιουργία διεργασίας στον εξυπηρετητή"
 
-#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38908
+#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38964
 msgid "Bad GPR fusion"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39126
+#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39182
 msgid "emit_fusion_p9_load, bad reg #1"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39172
+#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39228
 msgid "emit_fusion_p9_load, bad reg #2"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39175
+#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39231
 msgid "emit_fusion_p9_load not MEM"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39213
+#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39269
 msgid "emit_fusion_p9_store, bad reg #1"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39259
+#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39315
 msgid "emit_fusion_p9_store, bad reg #2"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39262
+#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39318
 msgid "emit_fusion_p9_store not MEM"
 msgstr ""
 
@@ -4490,14 +4490,14 @@
 #: c/gimple-parser.c:188 c/gimple-parser.c:197 c/gimple-parser.c:226
 #: c/gimple-parser.c:1375 c/gimple-parser.c:1404 c/gimple-parser.c:1484
 #: c/gimple-parser.c:1511 c/c-parser.c:3204 c/c-parser.c:9967
-#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27841
-#: cp/parser.c:28430
+#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27838
+#: cp/parser.c:28427
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "Μη ορισμένο όνομα %s"
 
 #: c/c-parser.c:2431 c/c-parser.c:7573 c/c-parser.c:8015 c/c-parser.c:8058
-#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27839 cp/parser.c:28448
+#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27836 cp/parser.c:28445
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "Μη ορισμένο όνομα %s"
@@ -4512,7 +4512,7 @@
 #: c/gimple-parser.c:821 c/gimple-parser.c:837 c/gimple-parser.c:853
 #: c/gimple-parser.c:880 c/gimple-parser.c:915 c/gimple-parser.c:1038
 #: c/gimple-parser.c:1209 c/gimple-parser.c:1220 c/gimple-parser.c:1342
-#: c/gimple-parser.c:1441 cp/parser.c:28478
+#: c/gimple-parser.c:1441 cp/parser.c:28475
 #, fuzzy, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "Μη ορισμένο όνομα %s"
@@ -4520,7 +4520,7 @@
 #: c/c-parser.c:3824 c/c-parser.c:4733 c/c-parser.c:4769 c/c-parser.c:6441
 #: c/c-parser.c:8125 c/c-parser.c:8983 c/c-parser.c:9127 c/c-parser.c:11588
 #: c/c-parser.c:18220 c/c-parser.c:18222 c/gimple-parser.c:1015
-#: cp/parser.c:28442
+#: cp/parser.c:28439
 #, fuzzy, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "Μη ορισμένο όνομα %s"
@@ -4534,7 +4534,7 @@
 #: c/c-parser.c:17792 c/gimple-parser.c:363 c/gimple-parser.c:811
 #: c/gimple-parser.c:873 c/gimple-parser.c:911 c/gimple-parser.c:1198
 #: c/gimple-parser.c:1339 c/gimple-parser.c:1438 c/c-parser.c:11911
-#: cp/parser.c:28433
+#: cp/parser.c:28430
 #, fuzzy, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "Μη ορισμένο όνομα %s"
@@ -4541,7 +4541,7 @@
 
 #: c/c-parser.c:4903 c/c-parser.c:10310 c/c-parser.c:16212 c/c-parser.c:18449
 #: c/gimple-parser.c:141 c/gimple-parser.c:1444 c/c-parser.c:3018
-#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18155 cp/parser.c:28439
+#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18152 cp/parser.c:28436
 #, fuzzy, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "Μη ορισμένο όνομα %s"
@@ -4551,13 +4551,13 @@
 #: c/c-parser.c:12351 c/c-parser.c:12493 c/c-parser.c:12864 c/c-parser.c:12957
 #: c/c-parser.c:13566 c/c-parser.c:17636 c/c-parser.c:17695
 #: c/gimple-parser.c:431 c/gimple-parser.c:1492 c/gimple-parser.c:1519
-#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28472 cp/parser.c:29597
-#: cp/parser.c:32279
+#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28469 cp/parser.c:29594
+#: cp/parser.c:32276
 #, fuzzy, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: c/c-parser.c:5974 cp/parser.c:28365
+#: c/c-parser.c:5974 cp/parser.c:28362
 #, fuzzy, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "Μη ορισμένο όνομα %s"
@@ -4567,18 +4567,18 @@
 msgid "expected %<.%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30172
-#: cp/parser.c:30246
+#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30169
+#: cp/parser.c:30243
 #, fuzzy, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28457
+#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28454
 #, fuzzy, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28481
+#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28478
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr ""
@@ -4586,33 +4586,33 @@
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15190 c/c-parser.c:15234 c/c-parser.c:15466 c/c-parser.c:15701
 #: c/c-parser.c:17833 c/gimple-parser.c:286 c/c-parser.c:4792
-#: cp/parser.c:28460
+#: cp/parser.c:28457
 #, fuzzy, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28436
-#: cp/parser.c:30389
+#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28433
+#: cp/parser.c:30386
 #, fuzzy, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35674
+#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35671
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr ""
 
-#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28445 cp/parser.c:31535
+#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28442 cp/parser.c:31532
 #, fuzzy, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: c/c-typeck.c:7847
+#: c/c-typeck.c:7852
 #, fuzzy
 msgid "(anonymous)"
 msgstr "((ανώνυμο))"
 
-#: c/gimple-parser.c:795 cp/parser.c:15791 cp/parser.c:28454
+#: c/gimple-parser.c:795 cp/parser.c:15788 cp/parser.c:28451
 #, fuzzy, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "Μη ορισμένο όνομα %s"
@@ -4886,11 +4886,11 @@
 msgid "%r%s:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr ""
 
-#: cp/pt.c:1949 cp/semantics.c:5268
+#: cp/pt.c:1949 cp/semantics.c:5271
 msgid "candidates are:"
 msgstr ""
 
-#: cp/pt.c:1951 cp/pt.c:22975
+#: cp/pt.c:1951 cp/pt.c:23053
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] ""
@@ -4943,27 +4943,27 @@
 msgid "source type is not polymorphic"
 msgstr ""
 
-#: cp/typeck.c:6083 c/c-typeck.c:4261
+#: cp/typeck.c:6083 c/c-typeck.c:4266
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr ""
 
-#: cp/typeck.c:6084 c/c-typeck.c:4248
+#: cp/typeck.c:6084 c/c-typeck.c:4253
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr ""
 
-#: cp/typeck.c:6111 c/c-typeck.c:4302
+#: cp/typeck.c:6111 c/c-typeck.c:4307
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr ""
 
-#: cp/typeck.c:6128 c/c-typeck.c:4310
+#: cp/typeck.c:6128 c/c-typeck.c:4315
 #, fuzzy, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "λάθος αριθμός ορισμάτων"
 
-#: cp/typeck.c:6140 c/c-typeck.c:4322
+#: cp/typeck.c:6140 c/c-typeck.c:4327
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr ""
@@ -5224,78 +5224,78 @@
 msgid "Expected attribute bit name"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: fortran/module.c:3223
+#: fortran/module.c:3225
 #, fuzzy
 msgid "Expected integer string"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: fortran/module.c:3227
+#: fortran/module.c:3229
 msgid "Error converting integer"
 msgstr ""
 
-#: fortran/module.c:3249
+#: fortran/module.c:3251
 #, fuzzy
 msgid "Expected real string"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: fortran/module.c:3474
+#: fortran/module.c:3476
 #, fuzzy
 msgid "Expected expression type"
 msgstr "Μη έγκυρη προπορευόμενη κανονική έκφραση"
 
-#: fortran/module.c:3554
+#: fortran/module.c:3556
 #, fuzzy
 msgid "Bad operator"
 msgstr "μη έγκυρος χρήστης"
 
-#: fortran/module.c:3671
+#: fortran/module.c:3673
 #, fuzzy
 msgid "Bad type in constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: fortran/module.c:7038
+#: fortran/module.c:7040
 #, fuzzy
 msgid "Unexpected end of module"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: fortran/parse.c:1757
+#: fortran/parse.c:1761
 msgid "arithmetic IF"
 msgstr ""
 
-#: fortran/parse.c:1766
+#: fortran/parse.c:1770
 #, fuzzy
 msgid "attribute declaration"
 msgstr "Μη έγκυρη ανταλλαγή"
 
-#: fortran/parse.c:1802
+#: fortran/parse.c:1806
 #, fuzzy
 msgid "data declaration"
 msgstr "κενό αλφαριθμητικό"
 
-#: fortran/parse.c:1820
+#: fortran/parse.c:1824
 #, fuzzy
 msgid "derived type declaration"
 msgstr "κενό αλφαριθμητικό"
 
-#: fortran/parse.c:1947
+#: fortran/parse.c:1951
 msgid "block IF"
 msgstr ""
 
-#: fortran/parse.c:1956
+#: fortran/parse.c:1960
 msgid "implied END DO"
 msgstr ""
 
-#: fortran/parse.c:2050 fortran/resolve.c:11199
+#: fortran/parse.c:2054 fortran/resolve.c:11219
 #, fuzzy
 msgid "assignment"
 msgstr "προσπέρασμα ορίσματος"
 
-#: fortran/parse.c:2053 fortran/resolve.c:11250 fortran/resolve.c:11253
+#: fortran/parse.c:2057 fortran/resolve.c:11270 fortran/resolve.c:11273
 #, fuzzy
 msgid "pointer assignment"
 msgstr "προσπέρασμα ορίσματος"
 
-#: fortran/parse.c:2071
+#: fortran/parse.c:2075
 msgid "simple IF"
 msgstr ""
 
@@ -5410,108 +5410,113 @@
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:3878
+#: fortran/resolve.c:3879
 #, c-format
+msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
+msgstr ""
+
+#: fortran/resolve.c:3884
+#, c-format
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3893
+#: fortran/resolve.c:3899
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3926
+#: fortran/resolve.c:3932
 #, c-format
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:3949
+#: fortran/resolve.c:3955
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:3963
+#: fortran/resolve.c:3969
 #, fuzzy
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: fortran/resolve.c:4015
+#: fortran/resolve.c:4021
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr ""
 
-#: fortran/resolve.c:4021
+#: fortran/resolve.c:4027
 #, c-format
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4034
+#: fortran/resolve.c:4040
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L; did you mean '%s'?"
 msgstr ""
 
-#: fortran/resolve.c:4037
+#: fortran/resolve.c:4043
 #, c-format
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr ""
 
-#: fortran/resolve.c:4040
+#: fortran/resolve.c:4046
 #, c-format
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr ""
 
-#: fortran/resolve.c:4044
+#: fortran/resolve.c:4050
 #, c-format
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr ""
 
-#: fortran/resolve.c:4132
+#: fortran/resolve.c:4138
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr ""
 
-#: fortran/resolve.c:6849
+#: fortran/resolve.c:6855
 msgid "Loop variable"
 msgstr ""
 
-#: fortran/resolve.c:6853
+#: fortran/resolve.c:6859
 msgid "iterator variable"
 msgstr ""
 
-#: fortran/resolve.c:6857
+#: fortran/resolve.c:6863
 msgid "Start expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:6861
+#: fortran/resolve.c:6867
 #, fuzzy
 msgid "End expression in DO loop"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: fortran/resolve.c:6865
+#: fortran/resolve.c:6871
 msgid "Step expression in DO loop"
 msgstr ""
 
-#: fortran/resolve.c:7150 fortran/resolve.c:7153
+#: fortran/resolve.c:7156 fortran/resolve.c:7159
 msgid "DEALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.c:7525 fortran/resolve.c:7528
+#: fortran/resolve.c:7531 fortran/resolve.c:7534
 msgid "ALLOCATE object"
 msgstr ""
 
-#: fortran/resolve.c:7720 fortran/resolve.c:9417
+#: fortran/resolve.c:7726 fortran/resolve.c:9428
 msgid "STAT variable"
 msgstr ""
 
-#: fortran/resolve.c:7764 fortran/resolve.c:9429
+#: fortran/resolve.c:7770 fortran/resolve.c:9440
 msgid "ERRMSG variable"
 msgstr ""
 
-#: fortran/resolve.c:9219
+#: fortran/resolve.c:9230
 msgid "item in READ"
 msgstr ""
 
-#: fortran/resolve.c:9441
+#: fortran/resolve.c:9452
 msgid "ACQUIRED_LOCK variable"
 msgstr ""
 
@@ -5544,7 +5549,7 @@
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:10154
+#: fortran/trans-expr.c:10157
 #, fuzzy
 msgid "Assignment of scalar to unallocated array"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
@@ -5554,12 +5559,12 @@
 msgid "Unequal character lengths (%ld/%ld) in %s"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:8088
+#: fortran/trans-intrinsic.c:8090
 #, c-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative (its value is %ld)"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:8120
+#: fortran/trans-intrinsic.c:8122
 msgid "Argument NCOPIES of REPEAT intrinsic is too large"
 msgstr ""
 
@@ -5580,15 +5585,15 @@
 msgid "Invalid image number %d in SYNC IMAGES"
 msgstr ""
 
-#: fortran/trans-stmt.c:2180
+#: fortran/trans-stmt.c:2177
 msgid "Loop iterates infinitely"
 msgstr ""
 
-#: fortran/trans-stmt.c:2200 fortran/trans-stmt.c:2456
+#: fortran/trans-stmt.c:2197 fortran/trans-stmt.c:2453
 msgid "Loop variable has been modified"
 msgstr ""
 
-#: fortran/trans-stmt.c:2309
+#: fortran/trans-stmt.c:2306
 msgid "DO step value is zero"
 msgstr ""
 
@@ -6218,10 +6223,10 @@
 msgid "Allow dollar signs in entity names."
 msgstr ""
 
-#: fortran/lang.opt:485 config/alpha/alpha.opt:31 common.opt:783
-#: common.opt:985 common.opt:989 common.opt:993 common.opt:997 common.opt:1532
-#: common.opt:1588 common.opt:1712 common.opt:1716 common.opt:1946
-#: common.opt:2116 common.opt:2792
+#: fortran/lang.opt:485 config/alpha/alpha.opt:31 common.opt:649
+#: common.opt:783 common.opt:989 common.opt:993 common.opt:997 common.opt:1001
+#: common.opt:1536 common.opt:1592 common.opt:1716 common.opt:1720
+#: common.opt:1950 common.opt:2120 common.opt:2796
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr ""
 
@@ -6443,12 +6448,12 @@
 msgstr ""
 
 #: fortran/lang.opt:751 c-family/c.opt:1356 c-family/c.opt:1384
-#: c-family/c.opt:1634 config/pa/pa.opt:42 config/pa/pa.opt:70 common.opt:1154
-#: common.opt:1333 common.opt:1408 common.opt:1676 common.opt:1799
-#: common.opt:2169 common.opt:2205 common.opt:2298 common.opt:2302
-#: common.opt:2407 common.opt:2498 common.opt:2506 common.opt:2514
-#: common.opt:2522 common.opt:2623 common.opt:2675 common.opt:2755
-#: common.opt:2893 common.opt:2897 common.opt:2901 common.opt:2905
+#: c-family/c.opt:1634 config/pa/pa.opt:42 config/pa/pa.opt:70 common.opt:1158
+#: common.opt:1337 common.opt:1412 common.opt:1680 common.opt:1803
+#: common.opt:2173 common.opt:2209 common.opt:2302 common.opt:2306
+#: common.opt:2411 common.opt:2502 common.opt:2510 common.opt:2518
+#: common.opt:2526 common.opt:2627 common.opt:2679 common.opt:2759
+#: common.opt:2897 common.opt:2901 common.opt:2905 common.opt:2909
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr ""
 
@@ -6498,7 +6503,7 @@
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:220 c-family/c.opt:224
 #: c-family/c.opt:236 c-family/c.opt:1855 c-family/c.opt:1863 brig/lang.opt:39
-#: config/darwin.opt:56 common.opt:338 common.opt:341 common.opt:3046
+#: config/darwin.opt:56 common.opt:338 common.opt:341 common.opt:3050
 #, fuzzy, c-format
 msgid "missing filename after %qs"
 msgstr "παράληψη ορίσματος αρχείου"
@@ -7094,7 +7099,7 @@
 #: c-family/c.opt:1525 c-family/c.opt:1528 c-family/c.opt:1569
 #: c-family/c.opt:1704 c-family/c.opt:1731 c-family/c.opt:1771
 #: c-family/c.opt:1802 c-family/c.opt:1806 c-family/c.opt:1822
-#: config/ia64/ia64.opt:167 config/ia64/ia64.opt:170 c-family/c-opts.c:434
+#: config/ia64/ia64.opt:167 config/ia64/ia64.opt:170 c-family/c-opts.c:432
 #, fuzzy, gcc-internal-format
 msgid "switch %qs is no longer supported"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
@@ -14529,10 +14534,6 @@
 msgid "Warn if dereferencing a NULL pointer may lead to erroneous or undefined behavior."
 msgstr ""
 
-#: common.opt:649
-msgid "Warn if the loop cannot be optimized due to nontrivial assumptions."
-msgstr ""
-
 #: common.opt:656
 msgid "Warn about some C++ One Definition Rule violations during link time optimization."
 msgstr ""
@@ -14705,1703 +14706,1703 @@
 msgid "-dumpdir <dir>\tSet the directory name to be used for dumps."
 msgstr ""
 
-#: common.opt:946
+#: common.opt:950
 msgid "The version of the C++ ABI in use."
 msgstr ""
 
-#: common.opt:950
+#: common.opt:954
 msgid "Aggressively optimize loops using language constraints."
 msgstr ""
 
-#: common.opt:954
+#: common.opt:958
 #, fuzzy
 msgid "Align the start of functions."
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: common.opt:964
+#: common.opt:968
 msgid "Align labels which are only reached by jumping."
 msgstr ""
 
-#: common.opt:971
+#: common.opt:975
 msgid "Align all labels."
 msgstr ""
 
-#: common.opt:978
+#: common.opt:982
 msgid "Align the start of loops."
 msgstr ""
 
-#: common.opt:1001
+#: common.opt:1005
 msgid "Select what to sanitize."
 msgstr ""
 
-#: common.opt:1005
+#: common.opt:1009
 msgid "Select type of coverage sanitization."
 msgstr ""
 
-#: common.opt:1009
+#: common.opt:1013
 msgid "-fasan-shadow-offset=<number>\tUse custom shadow memory offset."
 msgstr ""
 
-#: common.opt:1013
+#: common.opt:1017
 msgid "-fsanitize-sections=<sec1,sec2,...>\tSanitize global variables in user-defined sections."
 msgstr ""
 
-#: common.opt:1018
+#: common.opt:1022
 msgid "After diagnosing undefined behavior attempt to continue execution."
 msgstr ""
 
-#: common.opt:1022
+#: common.opt:1026
 msgid "This switch is deprecated; use -fsanitize-recover= instead."
 msgstr ""
 
-#: common.opt:1029
+#: common.opt:1033
 msgid "Use trap instead of a library function for undefined behavior sanitization."
 msgstr ""
 
-#: common.opt:1033
+#: common.opt:1037
 msgid "Generate unwind tables that are exact at each instruction boundary."
 msgstr ""
 
-#: common.opt:1037
+#: common.opt:1041
 #, fuzzy
 msgid "Generate auto-inc/dec instructions."
 msgstr "Ακατάλληλη εντολή"
 
-#: common.opt:1041
+#: common.opt:1045
 msgid "Use sample profile information for call graph node weights. The default profile file is fbdata.afdo in 'pwd'."
 msgstr ""
 
-#: common.opt:1046
+#: common.opt:1050
 msgid "Use sample profile information for call graph node weights. The profile file is specified in the argument."
 msgstr ""
 
-#: common.opt:1055
+#: common.opt:1059
 #, fuzzy
 msgid "Generate code to check bounds before indexing arrays."
 msgstr "Χρήση ξεχωριστής λανθάνουσας μνήμης για κάθε χρήστη"
 
-#: common.opt:1059
+#: common.opt:1063
 msgid "Replace add, compare, branch with branch on count register."
 msgstr ""
 
-#: common.opt:1063
+#: common.opt:1067
 msgid "Use profiling information for branch probabilities."
 msgstr ""
 
-#: common.opt:1067
+#: common.opt:1071
 msgid "Perform branch target load optimization before prologue / epilogue threading."
 msgstr ""
 
-#: common.opt:1071
+#: common.opt:1075
 msgid "Perform branch target load optimization after prologue / epilogue threading."
 msgstr ""
 
-#: common.opt:1075
+#: common.opt:1079
 msgid "Restrict target load migration not to re-use registers in any basic block."
 msgstr ""
 
-#: common.opt:1079
+#: common.opt:1083
 msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions."
 msgstr ""
 
-#: common.opt:1083
+#: common.opt:1087
 msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls."
 msgstr ""
 
-#: common.opt:1090
+#: common.opt:1094
 msgid "Save registers around function calls."
 msgstr ""
 
-#: common.opt:1094
+#: common.opt:1098
 msgid "This switch is deprecated; do not use."
 msgstr ""
 
-#: common.opt:1098
+#: common.opt:1102
 msgid "Check the return value of new in C++."
 msgstr ""
 
-#: common.opt:1102 common.opt:1106
+#: common.opt:1106 common.opt:1110
 #, fuzzy
 msgid "Perform internal consistency checkings."
 msgstr "εσωτερικό σφάλμα gcc"
 
-#: common.opt:1110
+#: common.opt:1114
 #, fuzzy
 msgid "Enable code hoisting."
 msgstr "αδύνατη η φόρτωση δεδομένων προφίλ"
 
-#: common.opt:1114
+#: common.opt:1118
 msgid "Looks for opportunities to reduce stack adjustments and stack references."
 msgstr ""
 
-#: common.opt:1118
+#: common.opt:1122
 msgid "Do not put uninitialized globals in the common section."
 msgstr ""
 
-#: common.opt:1126
+#: common.opt:1130
 msgid "-fcompare-debug[=<opts>]\tCompile with and without e.g. -gtoggle, and compare the final-insns dump."
 msgstr ""
 
-#: common.opt:1130
+#: common.opt:1134
 msgid "Run only the second compilation of -fcompare-debug."
 msgstr ""
 
-#: common.opt:1134
+#: common.opt:1138
 msgid "Perform comparison elimination after register allocation has finished."
 msgstr ""
 
-#: common.opt:1138
+#: common.opt:1142
 msgid "Do not perform optimizations increasing noticeably stack usage."
 msgstr ""
 
-#: common.opt:1142
+#: common.opt:1146
 msgid "Perform a register copy-propagation optimization pass."
 msgstr ""
 
-#: common.opt:1146
+#: common.opt:1150
 msgid "Perform cross-jumping optimization."
 msgstr ""
 
-#: common.opt:1150
+#: common.opt:1154
 msgid "When running CSE, follow jumps to their targets."
 msgstr ""
 
-#: common.opt:1158
+#: common.opt:1162
 msgid "Omit range reduction step when performing complex division."
 msgstr ""
 
-#: common.opt:1162
+#: common.opt:1166
 msgid "Complex multiplication and division follow Fortran rules."
 msgstr ""
 
-#: common.opt:1166
+#: common.opt:1170
 msgid "Place data items into their own section."
 msgstr ""
 
-#: common.opt:1170
+#: common.opt:1174
 msgid "List all available debugging counters with their limits and counts."
 msgstr ""
 
-#: common.opt:1174
+#: common.opt:1178
 msgid "-fdbg-cnt=<counter>:<limit>[,<counter>:<limit>,...]\tSet the debug counter limit."
 msgstr ""
 
-#: common.opt:1178
+#: common.opt:1182
 msgid "-fdebug-prefix-map=<old>=<new> Map one directory name to another in debug information."
 msgstr ""
 
-#: common.opt:1182
+#: common.opt:1186
 msgid "-ffile-prefix-map=<old>=<new> Map one directory name to another in compilation result."
 msgstr ""
 
-#: common.opt:1186
+#: common.opt:1190
 msgid "Output .debug_types section when using DWARF v4 debuginfo."
 msgstr ""
 
-#: common.opt:1192
+#: common.opt:1196
 msgid "Defer popping functions args from stack until later."
 msgstr ""
 
-#: common.opt:1196
+#: common.opt:1200
 msgid "Attempt to fill delay slots of branch instructions."
 msgstr ""
 
-#: common.opt:1200
+#: common.opt:1204
 msgid "Delete dead instructions that may throw exceptions."
 msgstr ""
 
-#: common.opt:1204
+#: common.opt:1208
 msgid "Delete useless null pointer checks."
 msgstr ""
 
-#: common.opt:1208
+#: common.opt:1212
 msgid "Stream extra data to support more aggressive devirtualization in LTO local transformation mode."
 msgstr ""
 
-#: common.opt:1212
+#: common.opt:1216
 msgid "Perform speculative devirtualization."
 msgstr ""
 
-#: common.opt:1216
+#: common.opt:1220
 msgid "Try to convert virtual calls to direct ones."
 msgstr ""
 
-#: common.opt:1220
+#: common.opt:1224
 msgid "-fdiagnostics-show-location=[once|every-line]\tHow often to emit source location at the beginning of line-wrapped diagnostics."
 msgstr ""
 
-#: common.opt:1237
+#: common.opt:1241
 msgid "Show the source line with a caret indicating the column."
 msgstr ""
 
-#: common.opt:1245
+#: common.opt:1249
 msgid "-fdiagnostics-color=[never|always|auto]\tColorize diagnostics."
 msgstr ""
 
-#: common.opt:1265
+#: common.opt:1269
 msgid "Print fix-it hints in machine-readable form."
 msgstr ""
 
-#: common.opt:1269
+#: common.opt:1273
 msgid "Print fix-it hints to stderr in unified diff format."
 msgstr ""
 
-#: common.opt:1273
+#: common.opt:1277
 msgid "Amend appropriate diagnostic messages with the command line option that controls them."
 msgstr ""
 
-#: common.opt:1277
+#: common.opt:1281
 msgid "-fdisable-[tree|rtl|ipa]-<pass>=range1+range2 disables an optimization pass."
 msgstr ""
 
-#: common.opt:1281
+#: common.opt:1285
 msgid "-fenable-[tree|rtl|ipa]-<pass>=range1+range2 enables an optimization pass."
 msgstr ""
 
-#: common.opt:1285
+#: common.opt:1289
 msgid "-fdump-<type>\tDump various compiler internals to a file."
 msgstr ""
 
-#: common.opt:1292
+#: common.opt:1296
 msgid "-fdump-final-insns=filename\tDump to filename the insns at the end of translation."
 msgstr ""
 
-#: common.opt:1296
+#: common.opt:1300
 msgid "-fdump-go-spec=filename\tWrite all declarations to file as Go code."
 msgstr ""
 
-#: common.opt:1300
+#: common.opt:1304
 msgid "Suppress output of addresses in debugging dumps."
 msgstr ""
 
-#: common.opt:1304
+#: common.opt:1308
 msgid "Collect and dump debug information into temporary file if ICE in C/C++ compiler occurred."
 msgstr ""
 
-#: common.opt:1309
+#: common.opt:1313
 msgid "Dump detailed information on GCC's internal representation of source code locations."
 msgstr ""
 
-#: common.opt:1313
+#: common.opt:1317
 msgid "Dump optimization passes."
 msgstr ""
 
-#: common.opt:1317
+#: common.opt:1321
 msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps."
 msgstr ""
 
-#: common.opt:1321
+#: common.opt:1325
 msgid "Suppress output of previous and next insn numbers in debugging dumps."
 msgstr ""
 
-#: common.opt:1325
+#: common.opt:1329
 msgid "Enable CFI tables via GAS assembler directives."
 msgstr ""
 
-#: common.opt:1329
+#: common.opt:1333
 msgid "Perform early inlining."
 msgstr ""
 
-#: common.opt:1337
+#: common.opt:1341
 msgid "Perform interprocedural reduction of aggregates."
 msgstr ""
 
-#: common.opt:1341
+#: common.opt:1345
 msgid "Perform unused symbol elimination in debug info."
 msgstr ""
 
-#: common.opt:1345
+#: common.opt:1349
 msgid "Perform unused type elimination in debug info."
 msgstr ""
 
-#: common.opt:1349
+#: common.opt:1353
 msgid "Do not suppress C++ class debug information."
 msgstr ""
 
-#: common.opt:1353
+#: common.opt:1357
 #, fuzzy
 msgid "Enable exception handling."
 msgstr "αδύνατη η φόρτωση δεδομένων προφίλ"
 
-#: common.opt:1357
+#: common.opt:1361
 msgid "Perform a number of minor, expensive optimizations."
 msgstr ""
 
-#: common.opt:1361
+#: common.opt:1365
 msgid "-fexcess-precision=[fast|standard]\tSpecify handling of excess floating-point precision."
 msgstr ""
 
-#: common.opt:1364
+#: common.opt:1368
 #, fuzzy, c-format
 msgid "unknown excess precision style %qs"
 msgstr "άγνωστο σετ `%s'"
 
-#: common.opt:1376
+#: common.opt:1380
 msgid "-fpermitted-flt-eval-methods=[c11|ts-18661]\tSpecify which values of FLT_EVAL_METHOD are permitted."
 msgstr ""
 
-#: common.opt:1379
+#: common.opt:1383
 #, c-format
 msgid "unknown specification for the set of FLT_EVAL_METHOD values to permit %qs"
 msgstr ""
 
-#: common.opt:1392
+#: common.opt:1396
 msgid "Output lto objects containing both the intermediate language and binary output."
 msgstr ""
 
-#: common.opt:1396
+#: common.opt:1400
 msgid "Assume no NaNs or infinities are generated."
 msgstr ""
 
-#: common.opt:1400
+#: common.opt:1404
 msgid "-ffixed-<register>\tMark <register> as being unavailable to the compiler."
 msgstr ""
 
-#: common.opt:1404
+#: common.opt:1408
 msgid "Don't allocate floats and doubles in extended-precision registers."
 msgstr ""
 
-#: common.opt:1412
+#: common.opt:1416
 msgid "Perform a forward propagation pass on RTL."
 msgstr ""
 
-#: common.opt:1416
+#: common.opt:1420
 msgid "-ffp-contract=[off|on|fast]\tPerform floating-point expression contraction."
 msgstr ""
 
-#: common.opt:1419
+#: common.opt:1423
 #, fuzzy, c-format
 msgid "unknown floating point contraction style %qs"
 msgstr "πάρα πολλά ορίσματα"
 
-#: common.opt:1433
+#: common.opt:1437
 msgid "Allow built-in functions ceil, floor, round, trunc to raise \"inexact\" exceptions."
 msgstr ""
 
-#: common.opt:1440
+#: common.opt:1444
 #, fuzzy
 msgid "Allow function addresses to be held in registers."
 msgstr "Δεν είναι δυνατό να δεσμευτεί μνήμη"
 
-#: common.opt:1444
+#: common.opt:1448
 msgid "Place each function into its own section."
 msgstr ""
 
-#: common.opt:1448
+#: common.opt:1452
 msgid "Perform global common subexpression elimination."
 msgstr ""
 
-#: common.opt:1452
+#: common.opt:1456
 msgid "Perform enhanced load motion during global common subexpression elimination."
 msgstr ""
 
-#: common.opt:1456
+#: common.opt:1460
 msgid "Perform store motion after global common subexpression elimination."
 msgstr ""
 
-#: common.opt:1460
+#: common.opt:1464
 msgid "Perform redundant load after store elimination in global common subexpression elimination."
 msgstr ""
 
-#: common.opt:1465
+#: common.opt:1469
 msgid "Perform global common subexpression elimination after register allocation has finished."
 msgstr ""
 
-#: common.opt:1482
+#: common.opt:1486
 msgid "-fgnat-encodings=[all|gdb|minimal]\tSelect the balance between GNAT encodings and standard DWARF emitted in the debug information"
 msgstr ""
 
-#: common.opt:1487
+#: common.opt:1491
 msgid "Enable in and out of Graphite representation."
 msgstr ""
 
-#: common.opt:1491
+#: common.opt:1495
 msgid "Enable Graphite Identity transformation."
 msgstr ""
 
-#: common.opt:1495
+#: common.opt:1499
 msgid "Enable hoisting adjacent loads to encourage generating conditional move instructions."
 msgstr ""
 
-#: common.opt:1504
+#: common.opt:1508
 msgid "Mark all loops as parallel."
 msgstr ""
 
-#: common.opt:1508 common.opt:1516 common.opt:2587
+#: common.opt:1512 common.opt:1520 common.opt:2591
 msgid "Enable loop nest transforms.  Same as -floop-nest-optimize."
 msgstr ""
 
-#: common.opt:1512
+#: common.opt:1516
 msgid "Enable loop interchange on trees."
 msgstr ""
 
-#: common.opt:1520
+#: common.opt:1524
 msgid "Perform unroll-and-jam on loops."
 msgstr ""
 
-#: common.opt:1524
+#: common.opt:1528
 msgid "Enable support for GNU transactional memory."
 msgstr ""
 
-#: common.opt:1528
+#: common.opt:1532
 msgid "Use STB_GNU_UNIQUE if supported by the assembler."
 msgstr ""
 
-#: common.opt:1536
+#: common.opt:1540
 msgid "Enable the loop nest optimizer."
 msgstr ""
 
-#: common.opt:1540
+#: common.opt:1544
 msgid "Force bitfield accesses to match their type width."
 msgstr ""
 
-#: common.opt:1544
+#: common.opt:1548
 msgid "Merge adjacent stores."
 msgstr ""
 
-#: common.opt:1548
+#: common.opt:1552
 msgid "Enable guessing of branch probabilities."
 msgstr ""
 
-#: common.opt:1556
+#: common.opt:1560
 #, fuzzy
 msgid "Process #ident directives."
 msgstr "%%%c: κατευθυντήριος γραμμή μη έγκυρη."
 
-#: common.opt:1560
+#: common.opt:1564
 msgid "Perform conversion of conditional jumps to branchless equivalents."
 msgstr ""
 
-#: common.opt:1564
+#: common.opt:1568
 msgid "Perform conversion of conditional jumps to conditional execution."
 msgstr ""
 
-#: common.opt:1568
+#: common.opt:1572
 msgid "-fstack-reuse=[all|named_vars|none]\tSet stack reuse level for local variables."
 msgstr ""
 
-#: common.opt:1571
+#: common.opt:1575
 #, fuzzy, c-format
 msgid "unknown Stack Reuse Level %qs"
 msgstr "άγνωστο σετ `%s'"
 
-#: common.opt:1584
+#: common.opt:1588
 msgid "Convert conditional jumps in innermost loops to branchless equivalents."
 msgstr ""
 
-#: common.opt:1596
+#: common.opt:1600
 #, fuzzy
 msgid "Do not generate .size directives."
 msgstr "Ακατάλληλη εντολή"
 
-#: common.opt:1600
+#: common.opt:1604
 msgid "Perform indirect inlining."
 msgstr ""
 
-#: common.opt:1606
+#: common.opt:1610
 msgid "Enable inlining of function declared \"inline\", disabling disables all inlining."
 msgstr ""
 
-#: common.opt:1610
+#: common.opt:1614
 msgid "Integrate functions into their callers when code size is known not to grow."
 msgstr ""
 
-#: common.opt:1614
+#: common.opt:1618
 msgid "Integrate functions not declared \"inline\" into their callers when profitable."
 msgstr ""
 
-#: common.opt:1618
+#: common.opt:1622
 msgid "Integrate functions only required by their single caller."
 msgstr ""
 
-#: common.opt:1625
+#: common.opt:1629
 msgid "-finline-limit=<number>\tLimit the size of inlined functions to <number>."
 msgstr ""
 
-#: common.opt:1629
+#: common.opt:1633
 msgid "Inline __atomic operations when a lock free instruction sequence is available."
 msgstr ""
 
-#: common.opt:1636
+#: common.opt:1640
 msgid "-fcf-protection=[full|branch|return|none]\tInstrument functions with checks to verify jump/call/return control-flow transfer instructions have valid targets."
 msgstr ""
 
-#: common.opt:1640
+#: common.opt:1644
 #, c-format
 msgid "unknown Control-Flow Protection Level %qs"
 msgstr ""
 
-#: common.opt:1656
+#: common.opt:1660
 msgid "Instrument function entry and exit with profiling calls."
 msgstr ""
 
-#: common.opt:1660
+#: common.opt:1664
 msgid "-finstrument-functions-exclude-function-list=name,...  Do not instrument listed functions."
 msgstr ""
 
-#: common.opt:1664
+#: common.opt:1668
 msgid "-finstrument-functions-exclude-file-list=filename,...  Do not instrument functions listed in files."
 msgstr ""
 
-#: common.opt:1668
+#: common.opt:1672
 msgid "Perform interprocedural constant propagation."
 msgstr ""
 
-#: common.opt:1672
+#: common.opt:1676
 msgid "Perform cloning to make Interprocedural constant propagation stronger."
 msgstr ""
 
-#: common.opt:1680
+#: common.opt:1684
 msgid "Perform interprocedural bitwise constant propagation."
 msgstr ""
 
-#: common.opt:1684
+#: common.opt:1688
 msgid "Perform interprocedural profile propagation."
 msgstr ""
 
-#: common.opt:1688
+#: common.opt:1692
 msgid "Perform interprocedural points-to analysis."
 msgstr ""
 
-#: common.opt:1692
+#: common.opt:1696
 #, fuzzy
 msgid "Discover pure and const functions."
 msgstr "Ακατάλληλη εντολή"
 
-#: common.opt:1696
+#: common.opt:1700
 msgid "Perform Identical Code Folding for functions and read-only variables."
 msgstr ""
 
-#: common.opt:1700
+#: common.opt:1704
 msgid "Perform Identical Code Folding for functions."
 msgstr ""
 
-#: common.opt:1704
+#: common.opt:1708
 msgid "Perform Identical Code Folding for variables."
 msgstr ""
 
-#: common.opt:1708
+#: common.opt:1712
 msgid "Discover readonly and non addressable static variables."
 msgstr ""
 
-#: common.opt:1720
+#: common.opt:1724
 msgid "Perform IPA Value Range Propagation."
 msgstr ""
 
-#: common.opt:1724
+#: common.opt:1728
 msgid "-fira-algorithm=[CB|priority]\tSet the used IRA algorithm."
 msgstr ""
 
-#: common.opt:1727
+#: common.opt:1731
 #, fuzzy, c-format
 msgid "unknown IRA algorithm %qs"
 msgstr "άγνωστο σετ `%s'"
 
-#: common.opt:1737
+#: common.opt:1741
 msgid "-fira-region=[one|all|mixed]\tSet regions for IRA."
 msgstr ""
 
-#: common.opt:1740
+#: common.opt:1744
 #, fuzzy, c-format
 msgid "unknown IRA region %qs"
 msgstr "άγνωστος χαρακτήρας `%s'"
 
-#: common.opt:1753
+#: common.opt:1757
 msgid "Use IRA based register pressure calculation in RTL hoist optimizations."
 msgstr ""
 
-#: common.opt:1758
+#: common.opt:1762
 msgid "Use IRA based register pressure calculation in RTL loop optimizations."
 msgstr ""
 
-#: common.opt:1763
+#: common.opt:1767
 msgid "Share slots for saving different hard registers."
 msgstr ""
 
-#: common.opt:1767
+#: common.opt:1771
 msgid "Share stack slots for spilled pseudo-registers."
 msgstr ""
 
-#: common.opt:1771
+#: common.opt:1775
 msgid "-fira-verbose=<number>\tControl IRA's level of diagnostic messages."
 msgstr ""
 
-#: common.opt:1775
+#: common.opt:1779
 msgid "Optimize induction variables on trees."
 msgstr ""
 
-#: common.opt:1779
+#: common.opt:1783
 msgid "Use jump tables for sufficiently large switch statements."
 msgstr ""
 
-#: common.opt:1783
+#: common.opt:1787
 msgid "Generate code for functions even if they are fully inlined."
 msgstr ""
 
-#: common.opt:1787
+#: common.opt:1791
 msgid "Generate code for static functions even if they are never called."
 msgstr ""
 
-#: common.opt:1791
+#: common.opt:1795
 msgid "Emit static const variables even if they are not used."
 msgstr ""
 
-#: common.opt:1795
+#: common.opt:1799
 msgid "Give external symbols a leading underscore."
 msgstr ""
 
-#: common.opt:1803
+#: common.opt:1807
 msgid "Do CFG-sensitive rematerialization in LRA."
 msgstr ""
 
-#: common.opt:1807
+#: common.opt:1811
 msgid "Enable link-time optimization."
 msgstr ""
 
-#: common.opt:1811
+#: common.opt:1815
 msgid "Link-time optimization with number of parallel jobs or jobserver."
 msgstr ""
 
-#: common.opt:1814
+#: common.opt:1818
 #, fuzzy, c-format
 msgid "unknown LTO partitioning model %qs"
 msgstr "άγνωστο σετ `%s'"
 
-#: common.opt:1833
+#: common.opt:1837
 msgid "Specify the algorithm to partition symbols and vars at linktime."
 msgstr ""
 
-#: common.opt:1838
+#: common.opt:1842
 msgid "-flto-compression-level=<number>\tUse zlib compression level <number> for IL."
 msgstr ""
 
-#: common.opt:1842
+#: common.opt:1846
 msgid "Merge C++ types using One Definition Rule."
 msgstr ""
 
-#: common.opt:1846
+#: common.opt:1850
 msgid "Report various link-time optimization statistics."
 msgstr ""
 
-#: common.opt:1850
+#: common.opt:1854
 msgid "Report various link-time optimization statistics for WPA only."
 msgstr ""
 
-#: common.opt:1854
+#: common.opt:1858
 #, fuzzy
 msgid "Set errno after built-in math functions."
 msgstr "εσωτερικό σφάλμα στο %s, γραμμή %u"
 
-#: common.opt:1858
+#: common.opt:1862
 msgid "-fmax-errors=<number>\tMaximum number of errors to report."
 msgstr ""
 
-#: common.opt:1862
+#: common.opt:1866
 msgid "Report on permanent memory allocation."
 msgstr ""
 
-#: common.opt:1866
+#: common.opt:1870
 msgid "Report on permanent memory allocation in WPA only."
 msgstr ""
 
-#: common.opt:1873
+#: common.opt:1877
 msgid "Attempt to merge identical constants and constant variables."
 msgstr ""
 
-#: common.opt:1877
+#: common.opt:1881
 msgid "Attempt to merge identical constants across compilation units."
 msgstr ""
 
-#: common.opt:1881
+#: common.opt:1885
 msgid "Attempt to merge identical debug strings across compilation units."
 msgstr ""
 
-#: common.opt:1885
+#: common.opt:1889
 msgid "-fmessage-length=<number>\tLimit diagnostics to <number> characters per line.  0 suppresses line-wrapping."
 msgstr ""
 
-#: common.opt:1889
+#: common.opt:1893
 msgid "Perform SMS based modulo scheduling before the first scheduling pass."
 msgstr ""
 
-#: common.opt:1893
+#: common.opt:1897
 msgid "Perform SMS based modulo scheduling with register moves allowed."
 msgstr ""
 
-#: common.opt:1897
+#: common.opt:1901
 msgid "Move loop invariant computations out of loops."
 msgstr ""
 
-#: common.opt:1901
+#: common.opt:1905
 msgid "Use the RTL dead code elimination pass."
 msgstr ""
 
-#: common.opt:1905
+#: common.opt:1909
 msgid "Use the RTL dead store elimination pass."
 msgstr ""
 
-#: common.opt:1909
+#: common.opt:1913
 msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling."
 msgstr ""
 
-#: common.opt:1913
+#: common.opt:1917
 msgid "Support synchronous non-call exceptions."
 msgstr ""
 
-#: common.opt:1916
+#: common.opt:1920
 #, fuzzy, c-format
 msgid "options or targets missing after %qs"
 msgstr "Αρχή αρχείου %s\n"
 
-#: common.opt:1917
+#: common.opt:1921
 msgid "-foffload=<targets>=<options>  Specify offloading targets and options for them."
 msgstr ""
 
-#: common.opt:1921
+#: common.opt:1925
 msgid "-foffload-abi=[lp64|ilp32]     Set the ABI to use in an offload compiler."
 msgstr ""
 
 # src/grep.c:1133
-#: common.opt:1924
+#: common.opt:1928
 #, fuzzy, c-format
 msgid "unknown offload ABI %qs"
 msgstr "άγνωστη μέθοδος καταλόγων"
 
-#: common.opt:1934
+#: common.opt:1938
 msgid "When possible do not generate stack frames."
 msgstr ""
 
-#: common.opt:1938
+#: common.opt:1942
 msgid "Enable all optimization info dumps on stderr."
 msgstr ""
 
-#: common.opt:1942
+#: common.opt:1946
 msgid "-fopt-info[-<type>=filename]\tDump compiler optimization details."
 msgstr ""
 
-#: common.opt:1950
+#: common.opt:1954
 msgid "Optimize sibling and tail recursive calls."
 msgstr ""
 
-#: common.opt:1954
+#: common.opt:1958
 msgid "Perform partial inlining."
 msgstr ""
 
-#: common.opt:1958 common.opt:1962
+#: common.opt:1962 common.opt:1966
 msgid "Report on memory allocation before interprocedural optimization."
 msgstr ""
 
-#: common.opt:1966
+#: common.opt:1970
 msgid "Pack structure members together without holes."
 msgstr ""
 
-#: common.opt:1970
+#: common.opt:1974
 msgid "-fpack-struct=<number>\tSet initial maximum structure member alignment."
 msgstr ""
 
-#: common.opt:1974
+#: common.opt:1978
 msgid "Return small aggregates in memory, not registers."
 msgstr ""
 
-#: common.opt:1978
+#: common.opt:1982
 msgid "Perform loop peeling."
 msgstr ""
 
-#: common.opt:1982
+#: common.opt:1986
 msgid "Enable machine specific peephole optimizations."
 msgstr ""
 
-#: common.opt:1986
+#: common.opt:1990
 msgid "Enable an RTL peephole pass before sched2."
 msgstr ""
 
-#: common.opt:1990
+#: common.opt:1994
 msgid "Generate position-independent code if possible (large mode)."
 msgstr ""
 
-#: common.opt:1994
+#: common.opt:1998
 msgid "Generate position-independent code for executables if possible (large mode)."
 msgstr ""
 
-#: common.opt:1998
+#: common.opt:2002
 msgid "Generate position-independent code if possible (small mode)."
 msgstr ""
 
-#: common.opt:2002
+#: common.opt:2006
 msgid "Generate position-independent code for executables if possible (small mode)."
 msgstr ""
 
-#: common.opt:2006
+#: common.opt:2010
 msgid "Use PLT for PIC calls (-fno-plt: load the address from GOT at call site)."
 msgstr ""
 
-#: common.opt:2010
+#: common.opt:2014
 msgid "Specify a plugin to load."
 msgstr ""
 
-#: common.opt:2014
+#: common.opt:2018
 msgid "-fplugin-arg-<name>-<key>[=<value>]\tSpecify argument <key>=<value> for plugin <name>."
 msgstr ""
 
-#: common.opt:2018
+#: common.opt:2022
 msgid "Run predictive commoning optimization."
 msgstr ""
 
-#: common.opt:2022
+#: common.opt:2026
 msgid "Generate prefetch instructions, if available, for arrays in loops."
 msgstr ""
 
-#: common.opt:2026
+#: common.opt:2030
 #, fuzzy
 msgid "Enable basic program profiling code."
 msgstr "αδύνατη η φόρτωση δεδομένων προφίλ"
 
-#: common.opt:2030
+#: common.opt:2034
 msgid "Generate absolute source path names for gcov."
 msgstr ""
 
-#: common.opt:2034
+#: common.opt:2038
 msgid "Insert arc-based program profiling code."
 msgstr ""
 
-#: common.opt:2038
+#: common.opt:2042
 msgid "Set the top-level directory for storing the profile data. The default is 'pwd'."
 msgstr ""
 
-#: common.opt:2043
+#: common.opt:2047
 msgid "Enable correction of flow inconsistent profile data input."
 msgstr ""
 
-#: common.opt:2047
+#: common.opt:2051
 msgid "-fprofile-update=[single|atomic|prefer-atomic]\tSet the profile update method."
 msgstr ""
 
-#: common.opt:2050
+#: common.opt:2054
 #, fuzzy, c-format
 msgid "unknown profile update method %qs"
 msgstr "άγνωστο σετ `%s'"
 
-#: common.opt:2063
+#: common.opt:2067
 msgid "Enable common options for generating profile info for profile feedback directed optimizations."
 msgstr ""
 
-#: common.opt:2067
+#: common.opt:2071
 msgid "Enable common options for generating profile info for profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr ""
 
-#: common.opt:2071
+#: common.opt:2075
 msgid "Enable common options for performing profile feedback directed optimizations."
 msgstr ""
 
-#: common.opt:2075
+#: common.opt:2079
 msgid "Enable common options for performing profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr ""
 
-#: common.opt:2079
+#: common.opt:2083
 msgid "Insert code to profile values of expressions."
 msgstr ""
 
-#: common.opt:2083
+#: common.opt:2087
 #, fuzzy
 msgid "Report on consistency of profile."
 msgstr "εσωτερικό σφάλμα gcc"
 
-#: common.opt:2087
+#: common.opt:2091
 msgid "Enable function reordering that improves code placement."
 msgstr ""
 
-#: common.opt:2091
+#: common.opt:2095
 msgid "Insert NOP instructions at each function entry."
 msgstr ""
 
-#: common.opt:2098
+#: common.opt:2102
 msgid "-frandom-seed=<string>\tMake compile reproducible using <string>."
 msgstr ""
 
-#: common.opt:2108
+#: common.opt:2112
 msgid "Record gcc command line switches in the object file."
 msgstr ""
 
-#: common.opt:2112
+#: common.opt:2116
 msgid "Return small aggregates in registers."
 msgstr ""
 
-#: common.opt:2120
+#: common.opt:2124
 msgid "Tell DSE that the storage for a C++ object is dead when the constructor starts and when the destructor finishes."
 msgstr ""
 
-#: common.opt:2128
+#: common.opt:2132
 msgid "Relief of register pressure through live range shrinkage."
 msgstr ""
 
-#: common.opt:2132
+#: common.opt:2136
 msgid "Perform a register renaming optimization pass."
 msgstr ""
 
-#: common.opt:2136
+#: common.opt:2140
 msgid "Perform a target dependent instruction fusion optimization pass."
 msgstr ""
 
-#: common.opt:2140
+#: common.opt:2144
 msgid "Reorder basic blocks to improve code placement."
 msgstr ""
 
-#: common.opt:2144
+#: common.opt:2148
 msgid "-freorder-blocks-algorithm=[simple|stc]\tSet the used basic block reordering algorithm."
 msgstr ""
 
-#: common.opt:2147
+#: common.opt:2151
 #, c-format
 msgid "unknown basic block reordering algorithm %qs"
 msgstr ""
 
-#: common.opt:2157
+#: common.opt:2161
 msgid "Reorder basic blocks and partition into hot and cold sections."
 msgstr ""
 
-#: common.opt:2161
+#: common.opt:2165
 msgid "Reorder functions to improve code placement."
 msgstr ""
 
-#: common.opt:2165
+#: common.opt:2169
 msgid "Add a common subexpression elimination pass after loop optimizations."
 msgstr ""
 
-#: common.opt:2173
+#: common.opt:2177
 msgid "Disable optimizations that assume default FP rounding behavior."
 msgstr ""
 
-#: common.opt:2177
+#: common.opt:2181
 msgid "Enable scheduling across basic blocks."
 msgstr ""
 
-#: common.opt:2181
+#: common.opt:2185
 msgid "Enable register pressure sensitive insn scheduling."
 msgstr ""
 
-#: common.opt:2185
+#: common.opt:2189
 msgid "Allow speculative motion of non-loads."
 msgstr ""
 
-#: common.opt:2189
+#: common.opt:2193
 msgid "Allow speculative motion of some loads."
 msgstr ""
 
-#: common.opt:2193
+#: common.opt:2197
 msgid "Allow speculative motion of more loads."
 msgstr ""
 
-#: common.opt:2197
+#: common.opt:2201
 msgid "-fsched-verbose=<number>\tSet the verbosity level of the scheduler."
 msgstr ""
 
-#: common.opt:2201
+#: common.opt:2205
 msgid "If scheduling post reload, do superblock scheduling."
 msgstr ""
 
-#: common.opt:2209
+#: common.opt:2213
 #, fuzzy
 msgid "Reschedule instructions before register allocation."
 msgstr "Αποτυχία δέσμευσης πόρων συστήματος"
 
-#: common.opt:2213
+#: common.opt:2217
 #, fuzzy
 msgid "Reschedule instructions after register allocation."
 msgstr "Αποτυχία δέσμευσης πόρων συστήματος"
 
-#: common.opt:2220
+#: common.opt:2224
 msgid "Schedule instructions using selective scheduling algorithm."
 msgstr ""
 
-#: common.opt:2224
+#: common.opt:2228
 msgid "Run selective scheduling after reload."
 msgstr ""
 
-#: common.opt:2228
+#: common.opt:2232
 msgid "Run self-tests, using the given path to locate test files."
 msgstr ""
 
-#: common.opt:2232
+#: common.opt:2236
 msgid "Perform software pipelining of inner loops during selective scheduling."
 msgstr ""
 
-#: common.opt:2236
+#: common.opt:2240
 msgid "Perform software pipelining of outer loops during selective scheduling."
 msgstr ""
 
-#: common.opt:2240
+#: common.opt:2244
 msgid "Reschedule pipelined regions without pipelining."
 msgstr ""
 
-#: common.opt:2244
+#: common.opt:2248
 msgid "Allow interposing function (or variables) by ones with different semantics (or initializer) respectively by dynamic linker."
 msgstr ""
 
-#: common.opt:2250
+#: common.opt:2254
 msgid "Allow premature scheduling of queued insns."
 msgstr ""
 
-#: common.opt:2254
+#: common.opt:2258
 msgid "-fsched-stalled-insns=<number>\tSet number of queued insns that can be prematurely scheduled."
 msgstr ""
 
-#: common.opt:2262
+#: common.opt:2266
 msgid "Set dependence distance checking in premature scheduling of queued insns."
 msgstr ""
 
-#: common.opt:2266
+#: common.opt:2270
 msgid "-fsched-stalled-insns-dep=<number>\tSet dependence distance checking in premature scheduling of queued insns."
 msgstr ""
 
-#: common.opt:2270
+#: common.opt:2274
 msgid "Enable the group heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2274
+#: common.opt:2278
 msgid "Enable the critical path heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2278
+#: common.opt:2282
 msgid "Enable the speculative instruction heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2282
+#: common.opt:2286
 msgid "Enable the rank heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2286
+#: common.opt:2290
 msgid "Enable the last instruction heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2290
+#: common.opt:2294
 msgid "Enable the dependent count heuristic in the scheduler."
 msgstr ""
 
-#: common.opt:2294
+#: common.opt:2298
 msgid "Access data in the same section from shared anchor points."
 msgstr ""
 
-#: common.opt:2306
+#: common.opt:2310
 msgid "Turn on Redundant Extensions Elimination pass."
 msgstr ""
 
-#: common.opt:2310
+#: common.opt:2314
 msgid "Show column numbers in diagnostics, when available.  Default on."
 msgstr ""
 
-#: common.opt:2314
+#: common.opt:2318
 msgid "Emit function prologues only before parts of the function that need it, rather than at the top of the function."
 msgstr ""
 
-#: common.opt:2319
+#: common.opt:2323
 msgid "Shrink-wrap parts of the prologue and epilogue separately."
 msgstr ""
 
-#: common.opt:2323
+#: common.opt:2327
 msgid "Disable optimizations observable by IEEE signaling NaNs."
 msgstr ""
 
-#: common.opt:2327
+#: common.opt:2331
 msgid "Disable floating point optimizations that ignore the IEEE signedness of zero."
 msgstr ""
 
-#: common.opt:2331
+#: common.opt:2335
 msgid "Convert floating point constants to single precision constants."
 msgstr ""
 
-#: common.opt:2335
+#: common.opt:2339
 msgid "Split lifetimes of induction variables when loops are unrolled."
 msgstr ""
 
-#: common.opt:2339
+#: common.opt:2343
 msgid "Generate discontiguous stack frames."
 msgstr ""
 
-#: common.opt:2343
+#: common.opt:2347
 msgid "Split wide types into independent registers."
 msgstr ""
 
-#: common.opt:2347
+#: common.opt:2351
 msgid "Enable backward propagation of use properties at the SSA level."
 msgstr ""
 
-#: common.opt:2351
+#: common.opt:2355
 msgid "Optimize conditional patterns using SSA PHI nodes."
 msgstr ""
 
-#: common.opt:2355
+#: common.opt:2359
 msgid "Optimize amount of stdarg registers saved to stack at start of function."
 msgstr ""
 
-#: common.opt:2359
+#: common.opt:2363
 msgid "Apply variable expansion when loops are unrolled."
 msgstr ""
 
-#: common.opt:2363
+#: common.opt:2367
 msgid "-fstack-check=[no|generic|specific]\tInsert stack checking code into the program."
 msgstr ""
 
-#: common.opt:2367
+#: common.opt:2371
 msgid "Insert stack checking code into the program.  Same as -fstack-check=specific."
 msgstr ""
 
-#: common.opt:2371
+#: common.opt:2375
 msgid "Insert code to probe each page of stack space as it is allocated to protect from stack-clash style attacks."
 msgstr ""
 
-#: common.opt:2379
+#: common.opt:2383
 msgid "-fstack-limit-register=<register>\tTrap if the stack goes past <register>."
 msgstr ""
 
-#: common.opt:2383
+#: common.opt:2387
 msgid "-fstack-limit-symbol=<name>\tTrap if the stack goes past symbol <name>."
 msgstr ""
 
-#: common.opt:2387
+#: common.opt:2391
 msgid "Use propolice as a stack protection method."
 msgstr ""
 
-#: common.opt:2391
+#: common.opt:2395
 msgid "Use a stack protection method for every function."
 msgstr ""
 
-#: common.opt:2395
+#: common.opt:2399
 msgid "Use a smart stack protection method for certain functions."
 msgstr ""
 
-#: common.opt:2399
+#: common.opt:2403
 msgid "Use stack protection method only for functions with the stack_protect attribute."
 msgstr ""
 
-#: common.opt:2403
+#: common.opt:2407
 msgid "Output stack usage information on a per-function basis."
 msgstr ""
 
-#: common.opt:2415
+#: common.opt:2419
 msgid "Assume strict aliasing rules apply."
 msgstr ""
 
-#: common.opt:2419
+#: common.opt:2423
 msgid "Treat signed overflow as undefined.  Negated as -fwrapv -fwrapv-pointer."
 msgstr ""
 
-#: common.opt:2423
+#: common.opt:2427
 msgid "Implement __atomic operations via libcalls to legacy __sync functions."
 msgstr ""
 
-#: common.opt:2427
+#: common.opt:2431
 #, fuzzy
 #| msgid "syntax error at %qs token"
 msgid "Check for syntax errors, then stop."
 msgstr "συντακτικό σφάλμα στο σύμβολο %qs"
 
-#: common.opt:2431
+#: common.opt:2435
 msgid "Create data files needed by \"gcov\"."
 msgstr ""
 
-#: common.opt:2435
+#: common.opt:2439
 msgid "Perform jump threading optimizations."
 msgstr ""
 
-#: common.opt:2439
+#: common.opt:2443
 msgid "Report the time taken by each compiler pass."
 msgstr ""
 
-#: common.opt:2443
+#: common.opt:2447
 msgid "Record times taken by sub-phases separately."
 msgstr ""
 
-#: common.opt:2447
+#: common.opt:2451
 msgid "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tSet the default thread-local storage code generation model."
 msgstr ""
 
-#: common.opt:2450
+#: common.opt:2454
 #, fuzzy, c-format
 msgid "unknown TLS model %qs"
 msgstr "άγνωστο σετ `%s'"
 
-#: common.opt:2466
+#: common.opt:2470
 msgid "Reorder top level functions, variables, and asms."
 msgstr ""
 
-#: common.opt:2470
+#: common.opt:2474
 msgid "Perform superblock formation via tail duplication."
 msgstr ""
 
-#: common.opt:2474
+#: common.opt:2478
 msgid "For targets that normally need trampolines for nested functions, always generate them instead of using descriptors."
 msgstr ""
 
-#: common.opt:2482
+#: common.opt:2486
 #, fuzzy
 msgid "Assume floating-point operations can trap."
 msgstr "Εξαίρεση κινητής υποδιαστολής"
 
-#: common.opt:2486
+#: common.opt:2490
 msgid "Trap for signed overflow in addition, subtraction and multiplication."
 msgstr ""
 
-#: common.opt:2490
+#: common.opt:2494
 msgid "Enable SSA-CCP optimization on trees."
 msgstr ""
 
-#: common.opt:2494
+#: common.opt:2498
 msgid "Enable SSA-BIT-CCP optimization on trees."
 msgstr ""
 
-#: common.opt:2502
+#: common.opt:2506
 msgid "Enable loop header copying on trees."
 msgstr ""
 
-#: common.opt:2510
+#: common.opt:2514
 msgid "Enable SSA coalescing of user variables."
 msgstr ""
 
-#: common.opt:2518
+#: common.opt:2522
 msgid "Enable copy propagation on trees."
 msgstr ""
 
-#: common.opt:2526
+#: common.opt:2530
 msgid "Transform condition stores into unconditional ones."
 msgstr ""
 
-#: common.opt:2530
+#: common.opt:2534
 msgid "Perform conversions of switch initializations."
 msgstr ""
 
-#: common.opt:2534
+#: common.opt:2538
 msgid "Enable SSA dead code elimination optimization on trees."
 msgstr ""
 
-#: common.opt:2538
+#: common.opt:2542
 msgid "Enable dominator optimizations."
 msgstr ""
 
-#: common.opt:2542
+#: common.opt:2546
 msgid "Enable tail merging on trees."
 msgstr ""
 
-#: common.opt:2546
+#: common.opt:2550
 msgid "Enable dead store elimination."
 msgstr ""
 
-#: common.opt:2550
+#: common.opt:2554
 msgid "Enable forward propagation on trees."
 msgstr ""
 
-#: common.opt:2554
+#: common.opt:2558
 msgid "Enable Full Redundancy Elimination (FRE) on trees."
 msgstr ""
 
-#: common.opt:2558
+#: common.opt:2562
 msgid "Enable string length optimizations on trees."
 msgstr ""
 
-#: common.opt:2562
+#: common.opt:2566
 msgid "Detect paths that trigger erroneous or undefined behavior due to dereferencing a null pointer.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
-#: common.opt:2568
+#: common.opt:2572
 msgid "Detect paths that trigger erroneous or undefined behavior due to a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
-#: common.opt:2575
+#: common.opt:2579
 #, fuzzy
 msgid "Enable loop distribution on trees."
 msgstr "Ακατάλληλη εντολή"
 
-#: common.opt:2579
+#: common.opt:2583
 msgid "Enable loop distribution for patterns transformed into a library call."
 msgstr ""
 
-#: common.opt:2583
+#: common.opt:2587
 msgid "Enable loop invariant motion on trees."
 msgstr ""
 
-#: common.opt:2591
+#: common.opt:2595
 msgid "Create canonical induction variables in loops."
 msgstr ""
 
-#: common.opt:2595
+#: common.opt:2599
 msgid "Enable loop optimizations on tree level."
 msgstr ""
 
-#: common.opt:2599
+#: common.opt:2603
 msgid "-ftree-parallelize-loops=<number>\tEnable automatic parallelization of loops."
 msgstr ""
 
-#: common.opt:2603
+#: common.opt:2607
 msgid "Enable hoisting loads from conditional pointers."
 msgstr ""
 
-#: common.opt:2607
+#: common.opt:2611
 msgid "Enable SSA-PRE optimization on trees."
 msgstr ""
 
-#: common.opt:2611
+#: common.opt:2615
 msgid "In SSA-PRE optimization on trees, enable partial-partial redundancy elimination."
 msgstr ""
 
-#: common.opt:2615
+#: common.opt:2619
 msgid "Perform function-local points-to analysis on trees."
 msgstr ""
 
-#: common.opt:2619
+#: common.opt:2623
 msgid "Enable reassociation on tree level."
 msgstr ""
 
-#: common.opt:2627
+#: common.opt:2631
 msgid "Enable SSA code sinking on trees."
 msgstr ""
 
-#: common.opt:2631
+#: common.opt:2635
 msgid "Perform straight-line strength reduction."
 msgstr ""
 
-#: common.opt:2635
+#: common.opt:2639
 msgid "Perform scalar replacement of aggregates."
 msgstr ""
 
-#: common.opt:2639
+#: common.opt:2643
 msgid "Replace temporary expressions in the SSA->normal pass."
 msgstr ""
 
-#: common.opt:2643
+#: common.opt:2647
 msgid "Perform live range splitting during the SSA->normal pass."
 msgstr ""
 
-#: common.opt:2647
+#: common.opt:2651
 msgid "Perform Value Range Propagation on trees."
 msgstr ""
 
-#: common.opt:2651
+#: common.opt:2655
 msgid "Split paths leading to loop backedges."
 msgstr ""
 
-#: common.opt:2655
+#: common.opt:2659
 msgid "Assume common declarations may be overridden with ones with a larger trailing array."
 msgstr ""
 
-#: common.opt:2660
+#: common.opt:2664
 msgid "Compile whole compilation unit at a time."
 msgstr ""
 
-#: common.opt:2664
+#: common.opt:2668
 msgid "Perform loop unrolling when iteration count is known."
 msgstr ""
 
-#: common.opt:2668
+#: common.opt:2672
 msgid "Perform loop unrolling for all loops."
 msgstr ""
 
-#: common.opt:2679
+#: common.opt:2683
 msgid "Allow optimization for floating-point arithmetic which may change the result of the operation due to rounding."
 msgstr ""
 
-#: common.opt:2684
+#: common.opt:2688
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr ""
 
-#: common.opt:2692
+#: common.opt:2696
 msgid "Allow math optimizations that may violate IEEE or ISO standards."
 msgstr ""
 
-#: common.opt:2696
+#: common.opt:2700
 msgid "Perform loop unswitching."
 msgstr ""
 
-#: common.opt:2700
+#: common.opt:2704
 msgid "Perform loop splitting."
 msgstr ""
 
-#: common.opt:2704
+#: common.opt:2708
 msgid "Just generate unwind tables for exception handling."
 msgstr ""
 
-#: common.opt:2708
+#: common.opt:2712
 msgid "Use the bfd linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2712
+#: common.opt:2716
 msgid "Use the gold linker instead of the default linker."
 msgstr ""
 
-#: common.opt:2724
+#: common.opt:2728
 msgid "Perform variable tracking."
 msgstr ""
 
-#: common.opt:2732
+#: common.opt:2736
 msgid "Perform variable tracking by annotating assignments."
 msgstr ""
 
-#: common.opt:2738
+#: common.opt:2742
 msgid "Toggle -fvar-tracking-assignments."
 msgstr ""
 
-#: common.opt:2746
+#: common.opt:2750
 msgid "Perform variable tracking and also tag variables that are uninitialized."
 msgstr ""
 
-#: common.opt:2751
+#: common.opt:2755
 msgid "Enable vectorization on trees."
 msgstr ""
 
-#: common.opt:2759
+#: common.opt:2763
 msgid "Enable loop vectorization on trees."
 msgstr ""
 
-#: common.opt:2763
+#: common.opt:2767
 msgid "Enable basic block vectorization (SLP) on trees."
 msgstr ""
 
-#: common.opt:2767
+#: common.opt:2771
 msgid "Specifies the cost model for vectorization. -fvect-cost-model=[unlimited|dynamic|cheap]\tSpecifies the cost model for vectorization."
 msgstr ""
 
-#: common.opt:2772
+#: common.opt:2776
 msgid "-fsimd-cost-model=[unlimited|dynamic|cheap]\tSpecifies the vectorization cost model for code marked with a simd directive."
 msgstr ""
 
-#: common.opt:2775
+#: common.opt:2779
 #, fuzzy, c-format
 msgid "unknown vectorizer cost model %qs"
 msgstr "άγνωστο σετ `%s'"
 
-#: common.opt:2788
+#: common.opt:2792
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr ""
 
-#: common.opt:2796
+#: common.opt:2800
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr ""
 
-#: common.opt:2806
+#: common.opt:2810
 msgid "Add extra commentary to assembler output."
 msgstr ""
 
-#: common.opt:2810
+#: common.opt:2814
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility."
 msgstr ""
 
 # src/request.c:806 src/request.c:912
-#: common.opt:2813
+#: common.opt:2817
 #, fuzzy, c-format
 msgid "unrecognized visibility value %qs"
 msgstr "Μη αναγνωρίσημο όνομα επιφάνειας `%s'"
 
-#: common.opt:2829
+#: common.opt:2833
 msgid "Validate vtable pointers before using them."
 msgstr ""
 
 # src/request.c:263
-#: common.opt:2832
+#: common.opt:2836
 #, fuzzy, c-format
 msgid "unknown vtable verify initialization priority %qs"
 msgstr "Το βήμα αρχικοποίησης απέτυχε"
 
-#: common.opt:2845
+#: common.opt:2849
 msgid "Output vtable verification counters."
 msgstr ""
 
-#: common.opt:2849
+#: common.opt:2853
 msgid "Output vtable verification pointer sets information."
 msgstr ""
 
-#: common.opt:2853
+#: common.opt:2857
 #, fuzzy
 msgid "Use expression value profiles in optimizations."
 msgstr "Λάθος έκφραση στην αποτίμηση: %s"
 
-#: common.opt:2857
+#: common.opt:2861
 msgid "Construct webs and split unrelated uses of single variable."
 msgstr ""
 
-#: common.opt:2861
+#: common.opt:2865
 msgid "Enable conditional dead code elimination for builtin calls."
 msgstr ""
 
-#: common.opt:2865
+#: common.opt:2869
 msgid "Perform whole program optimizations."
 msgstr ""
 
-#: common.opt:2869
+#: common.opt:2873
 msgid "Assume pointer overflow wraps around."
 msgstr ""
 
-#: common.opt:2873
+#: common.opt:2877
 msgid "Assume signed arithmetic overflow wraps around."
 msgstr ""
 
-#: common.opt:2877
+#: common.opt:2881
 msgid "Put zero initialized data in the bss section."
 msgstr ""
 
-#: common.opt:2881
+#: common.opt:2885
 msgid "Generate debug information in default format."
 msgstr ""
 
-#: common.opt:2885
+#: common.opt:2889
 msgid "Assume assembler support for (DWARF2+) .loc directives"
 msgstr ""
 
-#: common.opt:2889
+#: common.opt:2893
 msgid "Assume assembler support for view in (DWARF2+) .loc directives"
 msgstr ""
 
-#: common.opt:2892 common.opt:2896 common.opt:2900 common.opt:2904
+#: common.opt:2896 common.opt:2900 common.opt:2904 common.opt:2908
 #, fuzzy, c-format
 msgid "switch %qs no longer supported"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: common.opt:2909
+#: common.opt:2913
 msgid "Record DW_AT_decl_column and DW_AT_call_column in DWARF."
 msgstr ""
 
-#: common.opt:2913
+#: common.opt:2917
 msgid "Generate debug information in default version of DWARF format."
 msgstr ""
 
-#: common.opt:2917
+#: common.opt:2921
 msgid "Generate debug information in DWARF v2 (or later) format."
 msgstr ""
 
-#: common.opt:2921
+#: common.opt:2925
 msgid "Generate debug information in default extended format."
 msgstr ""
 
-#: common.opt:2925
+#: common.opt:2929
 msgid "Generate extended entry point information for inlined functions"
 msgstr ""
 
-#: common.opt:2929
+#: common.opt:2933
 msgid "Compute locview reset points based on insn length estimates"
 msgstr ""
 
-#: common.opt:2937
+#: common.opt:2941
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:2941
+#: common.opt:2945
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:2945
+#: common.opt:2949
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr ""
 
-#: common.opt:2949
+#: common.opt:2953
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr ""
 
-#: common.opt:2953
+#: common.opt:2957
 msgid "Generate debug information in separate .dwo files."
 msgstr ""
 
-#: common.opt:2957
+#: common.opt:2961
 msgid "Generate debug information in STABS format."
 msgstr ""
 
-#: common.opt:2961
+#: common.opt:2965
 msgid "Generate debug information in extended STABS format."
 msgstr ""
 
-#: common.opt:2965
+#: common.opt:2969
 msgid "Emit progressive recommended breakpoint locations."
 msgstr ""
 
-#: common.opt:2969
+#: common.opt:2973
 msgid "Don't emit DWARF additions beyond selected version."
 msgstr ""
 
-#: common.opt:2973
+#: common.opt:2977
 msgid "Toggle debug information generation."
 msgstr ""
 
-#: common.opt:2977
+#: common.opt:2981
 msgid "Augment variable location lists with progressive views."
 msgstr ""
 
-#: common.opt:2984
+#: common.opt:2988
 msgid "Generate debug information in VMS format."
 msgstr ""
 
-#: common.opt:2988
+#: common.opt:2992
 msgid "Generate debug information in XCOFF format."
 msgstr ""
 
-#: common.opt:2992
+#: common.opt:2996
 msgid "Generate debug information in extended XCOFF format."
 msgstr ""
 
-#: common.opt:3010
+#: common.opt:3014
 msgid "Generate compressed debug sections."
 msgstr ""
 
-#: common.opt:3014
+#: common.opt:3018
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>."
 msgstr ""
 
-#: common.opt:3021
+#: common.opt:3025
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory."
 msgstr ""
 
-#: common.opt:3025
+#: common.opt:3029
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory."
 msgstr ""
 
-#: common.opt:3047
+#: common.opt:3051
 #, fuzzy
 msgid "-o <file>\tPlace output into <file>."
 msgstr "  -o <αρχείο>              Τοποθέτηση της εξόδου στο <αρχείο>\n"
 
-#: common.opt:3051
+#: common.opt:3055
 #, fuzzy
 msgid "Enable function profiling."
 msgstr "αδύνατη η φόρτωση δεδομένων προφίλ"
 
-#: common.opt:3061
+#: common.opt:3065
 msgid "Like -pedantic but issue them as errors."
 msgstr ""
 
-#: common.opt:3101
+#: common.opt:3105
 msgid "Do not display functions compiled or elapsed time."
 msgstr ""
 
-#: common.opt:3133
+#: common.opt:3137
 msgid "Enable verbose output."
 msgstr ""
 
-#: common.opt:3137
+#: common.opt:3141
 #, fuzzy
 msgid "Display the compiler's version."
 msgstr "  --help                   Εμφάνιση αυτών των πληροφοριών\n"
 
-#: common.opt:3141
+#: common.opt:3145
 #, fuzzy
 msgid "Suppress warnings."
 msgstr "%s: προειδοποίηση: "
 
-#: common.opt:3151
+#: common.opt:3155
 msgid "Create a shared library."
 msgstr ""
 
-#: common.opt:3196
+#: common.opt:3200
 msgid "Don't create a dynamically linked position independent executable."
 msgstr ""
 
-#: common.opt:3200
+#: common.opt:3204
 msgid "Create a dynamically linked position independent executable."
 msgstr ""
 
-#: common.opt:3204
+#: common.opt:3208
 msgid "Create a static position independent executable."
 msgstr ""
 
-#: common.opt:3211
+#: common.opt:3215
 msgid "Use caller save register across calls if possible."
 msgstr ""
 
-#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:598 cp/cvt.c:1308
+#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:599 cp/cvt.c:1308
 #: cp/cvt.c:1561
 #, gcc-internal-format
 msgid "value computed is not used"
@@ -16432,7 +16433,7 @@
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
 #: go/gofrontend/expressions.cc:4331 c/c-parser.c:13477 c/c-parser.c:13484
-#: cp/parser.c:33264 cp/parser.c:33271
+#: cp/parser.c:33261 cp/parser.c:33268
 #, fuzzy, gcc-internal-format
 msgid "expected integer"
 msgstr "Μη ορισμένο όνομα %s"
@@ -16907,14 +16908,14 @@
 msgid "ignoring attribute %qE because it conflicts with attribute %qs"
 msgstr ""
 
-#: attribs.c:449 c-family/c-attribs.c:1894 cp/decl.c:13690 cp/friend.c:302
-#: cp/tree.c:4559
+#: attribs.c:449 c-family/c-attribs.c:1905 cp/decl.c:13714 cp/friend.c:302
+#: cp/tree.c:4607
 #, fuzzy, gcc-internal-format
 msgid "previous declaration here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
 #. Warn about and ignore all others for now, but store them.
-#: attribs.c:564 c-family/c-attribs.c:2717 objc/objc-act.c:4963
+#: attribs.c:564 c-family/c-attribs.c:2728 objc/objc-act.c:4963
 #: objc/objc-act.c:6932 objc/objc-act.c:8119 objc/objc-act.c:8170
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute directive ignored"
@@ -16933,17 +16934,17 @@
 #. This is a c++11 attribute that appertains to a
 #. type-specifier, outside of the definition of, a class
 #. type.  Ignore it.
-#: attribs.c:590 cp/decl.c:10999
+#: attribs.c:590 cp/decl.c:11023
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: attribs.c:592 cp/decl.c:11000
+#: attribs.c:592 cp/decl.c:11024
 #, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr ""
 
-#: attribs.c:610 c-family/c-attribs.c:3219
+#: attribs.c:610 c-family/c-attribs.c:3230
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute does not apply to types"
 msgstr "προειδοποίηση: το --pid=PID δεν υποστηρίζεται σε αυτό το σύστημα"
@@ -16959,40 +16960,40 @@
 msgstr ""
 
 #: attribs.c:691 attribs.c:1622 attribs.c:1632 attribs.c:1642
-#: c-family/c-attribs.c:540 c-family/c-attribs.c:559 c-family/c-attribs.c:577
-#: c-family/c-attribs.c:607 c-family/c-attribs.c:628 c-family/c-attribs.c:649
-#: c-family/c-attribs.c:690 c-family/c-attribs.c:717 c-family/c-attribs.c:733
-#: c-family/c-attribs.c:750 c-family/c-attribs.c:766 c-family/c-attribs.c:792
-#: c-family/c-attribs.c:807 c-family/c-attribs.c:835 c-family/c-attribs.c:852
-#: c-family/c-attribs.c:870 c-family/c-attribs.c:893 c-family/c-attribs.c:931
-#: c-family/c-attribs.c:954 c-family/c-attribs.c:971 c-family/c-attribs.c:1000
-#: c-family/c-attribs.c:1021 c-family/c-attribs.c:1042
-#: c-family/c-attribs.c:1069 c-family/c-attribs.c:1099
-#: c-family/c-attribs.c:1136 c-family/c-attribs.c:1189
-#: c-family/c-attribs.c:1255 c-family/c-attribs.c:1313
-#: c-family/c-attribs.c:1402 c-family/c-attribs.c:1432
-#: c-family/c-attribs.c:1483 c-family/c-attribs.c:1998
-#: c-family/c-attribs.c:2035 c-family/c-attribs.c:2096
-#: c-family/c-attribs.c:2152 c-family/c-attribs.c:2230
-#: c-family/c-attribs.c:2312 c-family/c-attribs.c:2371
-#: c-family/c-attribs.c:2390 c-family/c-attribs.c:2498
-#: c-family/c-attribs.c:2514 c-family/c-attribs.c:2530
-#: c-family/c-attribs.c:2551 c-family/c-attribs.c:2608
-#: c-family/c-attribs.c:2635 c-family/c-attribs.c:2690
-#: c-family/c-attribs.c:2870 c-family/c-attribs.c:2891
-#: c-family/c-attribs.c:3004 c-family/c-attribs.c:3031
-#: c-family/c-attribs.c:3221 c-family/c-attribs.c:3239
-#: c-family/c-attribs.c:3262 c-family/c-attribs.c:3301
-#: c-family/c-attribs.c:3383 c-family/c-attribs.c:3439
-#: c-family/c-attribs.c:3455 c-family/c-attribs.c:3549
-#: c-family/c-common.c:5600 config/darwin.c:2072 config/arm/arm.c:6868
+#: c-family/c-attribs.c:547 c-family/c-attribs.c:566 c-family/c-attribs.c:584
+#: c-family/c-attribs.c:614 c-family/c-attribs.c:635 c-family/c-attribs.c:656
+#: c-family/c-attribs.c:697 c-family/c-attribs.c:728 c-family/c-attribs.c:744
+#: c-family/c-attribs.c:761 c-family/c-attribs.c:777 c-family/c-attribs.c:803
+#: c-family/c-attribs.c:818 c-family/c-attribs.c:846 c-family/c-attribs.c:863
+#: c-family/c-attribs.c:881 c-family/c-attribs.c:904 c-family/c-attribs.c:942
+#: c-family/c-attribs.c:965 c-family/c-attribs.c:982 c-family/c-attribs.c:1011
+#: c-family/c-attribs.c:1032 c-family/c-attribs.c:1053
+#: c-family/c-attribs.c:1080 c-family/c-attribs.c:1110
+#: c-family/c-attribs.c:1147 c-family/c-attribs.c:1200
+#: c-family/c-attribs.c:1266 c-family/c-attribs.c:1324
+#: c-family/c-attribs.c:1413 c-family/c-attribs.c:1443
+#: c-family/c-attribs.c:1494 c-family/c-attribs.c:2009
+#: c-family/c-attribs.c:2046 c-family/c-attribs.c:2107
+#: c-family/c-attribs.c:2163 c-family/c-attribs.c:2241
+#: c-family/c-attribs.c:2323 c-family/c-attribs.c:2382
+#: c-family/c-attribs.c:2401 c-family/c-attribs.c:2509
+#: c-family/c-attribs.c:2525 c-family/c-attribs.c:2541
+#: c-family/c-attribs.c:2562 c-family/c-attribs.c:2619
+#: c-family/c-attribs.c:2646 c-family/c-attribs.c:2701
+#: c-family/c-attribs.c:2881 c-family/c-attribs.c:2902
+#: c-family/c-attribs.c:3015 c-family/c-attribs.c:3042
+#: c-family/c-attribs.c:3232 c-family/c-attribs.c:3250
+#: c-family/c-attribs.c:3273 c-family/c-attribs.c:3312
+#: c-family/c-attribs.c:3394 c-family/c-attribs.c:3450
+#: c-family/c-attribs.c:3466 c-family/c-attribs.c:3560
+#: c-family/c-common.c:5598 config/darwin.c:2072 config/arm/arm.c:6868
 #: config/arm/arm.c:6896 config/arm/arm.c:6913 config/avr/avr.c:9698
-#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6497
-#: config/i386/i386.c:41520 config/ia64/ia64.c:788
-#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33056
-#: config/spu/spu.c:3743 ada/gcc-interface/utils.c:6244
-#: ada/gcc-interface/utils.c:6261 ada/gcc-interface/utils.c:6277
-#: ada/gcc-interface/utils.c:6303 brig/brig-lang.c:476 lto/lto-lang.c:283
+#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6500
+#: config/i386/i386.c:41514 config/ia64/ia64.c:788
+#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33112
+#: config/spu/spu.c:3743 ada/gcc-interface/utils.c:6249
+#: ada/gcc-interface/utils.c:6266 ada/gcc-interface/utils.c:6282
+#: ada/gcc-interface/utils.c:6308 brig/brig-lang.c:476 lto/lto-lang.c:283
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute ignored"
 msgstr "το `%s' είναι πρόγονος του `%s'"
@@ -17361,89 +17362,104 @@
 msgid "%Kattempt to free a non-heap object"
 msgstr ""
 
-#: calls.c:1434
+#: calls.c:1291 file-prefix-map.c:50
+#, fuzzy, gcc-internal-format
+msgid "invalid argument %qs to %qs"
+msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
+
+#: calls.c:1452
 #, gcc-internal-format
 msgid "%Kargument %i value %qE is negative"
 msgstr ""
 
-#: calls.c:1452
+#: calls.c:1470
 #, fuzzy, gcc-internal-format
 msgid "%Kargument %i value is zero"
 msgstr "%s: σφάλμα ανάγνωσης"
 
-#: calls.c:1469
+#: calls.c:1487
 #, gcc-internal-format
 msgid "%Kargument %i value %qE exceeds maximum object size %E"
 msgstr ""
 
-#: calls.c:1483
+#: calls.c:1501
 #, gcc-internal-format
 msgid "%Kargument %i range [%E, %E] is negative"
 msgstr ""
 
-#: calls.c:1490
+#: calls.c:1508
 #, gcc-internal-format
 msgid "%Kargument %i range [%E, %E] exceeds maximum object size %E"
 msgstr ""
 
-#: calls.c:1520
+#: calls.c:1538
 #, gcc-internal-format
 msgid "%Kproduct %<%E * %E%> of arguments %i and %i exceeds %<SIZE_MAX%>"
 msgstr ""
 
-#: calls.c:1526
+#: calls.c:1544
 #, gcc-internal-format
 msgid "%Kproduct %<%E * %E%> of arguments %i and %i exceeds maximum object size %E"
 msgstr ""
 
-#: calls.c:1537 calls.c:1540
+#: calls.c:1555 calls.c:1558
 #, gcc-internal-format
 msgid "argument %i in the range [%E, %E]"
 msgstr ""
 
-#: calls.c:1551
+#: calls.c:1569
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "in a call to built-in allocation function %qD"
 msgstr "κλήση σε μη-συνάρτηση %qD"
 
-#: calls.c:1554
+#: calls.c:1572
 #, gcc-internal-format
 msgid "in a call to allocation function %qD declared here"
 msgstr ""
 
-#: calls.c:1711
+#: calls.c:1835
 #, gcc-internal-format
-msgid "%qD argument %i declared attribute %<nonstring%> is smaller than the specified bound %E"
+msgid "%qD argument %i declared attribute %<nonstring%> is smaller than the specified bound %wu"
 msgstr ""
 
-#: calls.c:1716
+#: calls.c:1841
+#, gcc-internal-format
+msgid "%qD argument %i declared attribute %<nonstring%> is smaller than the specified bound [%E, %E]"
+msgstr ""
+
+#: calls.c:1847
+#, gcc-internal-format
+msgid "%qD argument %i declared attribute %<nonstring%> may be smaller than the specified bound [%E, %E]"
+msgstr ""
+
+#: calls.c:1857
 #, fuzzy, gcc-internal-format
 msgid "%qD argument %i declared attribute %<nonstring%>"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: calls.c:1721
+#: calls.c:1862
 #, fuzzy, gcc-internal-format
 msgid "argument %qD declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: calls.c:1735
+#: calls.c:1876
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot tail-call: %s"
 msgstr "αδυναμία εκτέλεσης ioctl στο `%s'"
 
-#: calls.c:3365
+#: calls.c:3506
 #, gcc-internal-format
 msgid "function call has aggregate value"
 msgstr ""
 
-#: calls.c:4059
+#: calls.c:4200
 #, fuzzy, gcc-internal-format
 msgid "passing too large argument on stack"
 msgstr "Λείπει παράμετρος για `%s'"
 
 # src/shred.c:1134
-#: cfgexpand.c:1665 function.c:1002 varasm.c:2231
+#: cfgexpand.c:1665 function.c:1002 varasm.c:2242
 #, fuzzy, gcc-internal-format
 msgid "size of variable %q+D is too large"
 msgstr "%s: το αρχείο είναι πολύ μεγάλο"
@@ -18015,212 +18031,212 @@
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr ""
 
-#: cgraph.c:3051
+#: cgraph.c:3056
 #, gcc-internal-format
 msgid "caller edge count invalid"
 msgstr ""
 
-#: cgraph.c:3135
+#: cgraph.c:3140
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr ""
 
-#: cgraph.c:3142
+#: cgraph.c:3147
 #, gcc-internal-format
 msgid "cgraph count invalid"
 msgstr ""
 
-#: cgraph.c:3147
+#: cgraph.c:3152
 #, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr ""
 
-#: cgraph.c:3152
+#: cgraph.c:3157
 #, fuzzy, gcc-internal-format
 msgid "local symbols must be defined"
 msgstr "δεν δώθηκε συμβολικό όνομα"
 
-#: cgraph.c:3157
+#: cgraph.c:3162
 #, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr ""
 
-#: cgraph.c:3162
+#: cgraph.c:3167
 #, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr ""
 
-#: cgraph.c:3167
+#: cgraph.c:3172
 #, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr ""
 
-#: cgraph.c:3174
+#: cgraph.c:3179
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for indirect edge from %s"
 msgstr ""
 
-#: cgraph.c:3181
+#: cgraph.c:3186
 #, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr ""
 
-#: cgraph.c:3196
+#: cgraph.c:3201
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr ""
 
-#: cgraph.c:3206
+#: cgraph.c:3211
 #, fuzzy, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr "ορισμός δικαιωμάτων στο %s"
 
-#: cgraph.c:3211
+#: cgraph.c:3216
 #, gcc-internal-format
 msgid "multiple inline callers"
 msgstr ""
 
-#: cgraph.c:3218
+#: cgraph.c:3223
 #, fuzzy, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr "ορισμός δικαιωμάτων στο %s"
 
-#: cgraph.c:3239
+#: cgraph.c:3244
 #, gcc-internal-format
 msgid "caller edge count does not match BB count"
 msgstr ""
 
-#: cgraph.c:3261
+#: cgraph.c:3266
 #, gcc-internal-format
 msgid "indirect call count does not match BB count"
 msgstr ""
 
-#: cgraph.c:3272
+#: cgraph.c:3277
 #, fuzzy, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr "ορισμός δικαιωμάτων στο %s"
 
-#: cgraph.c:3277
+#: cgraph.c:3282
 #, fuzzy, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr "ορισμός δικαιωμάτων στο %s"
 
-#: cgraph.c:3289
+#: cgraph.c:3294
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr ""
 
-#: cgraph.c:3301
+#: cgraph.c:3306
 #, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr ""
 
-#: cgraph.c:3307
+#: cgraph.c:3312
 #, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr ""
 
-#: cgraph.c:3312
+#: cgraph.c:3317
 #, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr ""
 
-#: cgraph.c:3317
+#: cgraph.c:3322
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr ""
 
-#: cgraph.c:3329
+#: cgraph.c:3334
 #, gcc-internal-format
 msgid "Alias has call edges"
 msgstr ""
 
-#: cgraph.c:3337
+#: cgraph.c:3342
 #, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr ""
 
-#: cgraph.c:3342
+#: cgraph.c:3347
 #, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr ""
 
-#: cgraph.c:3349
+#: cgraph.c:3354
 #, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr ""
 
-#: cgraph.c:3358
+#: cgraph.c:3363
 #, gcc-internal-format
 msgid "Instrumentation clone does not reference original node"
 msgstr ""
 
-#: cgraph.c:3365
+#: cgraph.c:3370
 #, gcc-internal-format
 msgid "Not instrumented node has non-NULL original declaration"
 msgstr ""
 
-#: cgraph.c:3375
+#: cgraph.c:3380
 #, gcc-internal-format
 msgid "Instrumented node has wrong original declaration"
 msgstr ""
 
-#: cgraph.c:3393
+#: cgraph.c:3398
 #, gcc-internal-format
 msgid "Node has more than one chkp reference"
 msgstr ""
 
-#: cgraph.c:3398
+#: cgraph.c:3403
 #, gcc-internal-format
 msgid "Wrong node is referenced with chkp reference"
 msgstr ""
 
-#: cgraph.c:3406
+#: cgraph.c:3411
 #, gcc-internal-format
 msgid "Analyzed node has no reference to instrumented version"
 msgstr ""
 
-#: cgraph.c:3420
+#: cgraph.c:3425
 #, gcc-internal-format
 msgid "Alias chain for instrumented node is broken"
 msgstr ""
 
-#: cgraph.c:3429
+#: cgraph.c:3434
 #, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3434
+#: cgraph.c:3439
 #, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr ""
 
-#: cgraph.c:3439
+#: cgraph.c:3444
 #, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr ""
 
-#: cgraph.c:3445
+#: cgraph.c:3450
 #, gcc-internal-format
 msgid "Instrumentation thunk has wrong edge callee"
 msgstr ""
 
-#: cgraph.c:3481
+#: cgraph.c:3486
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr ""
 
-#: cgraph.c:3489
+#: cgraph.c:3494
 #, fuzzy, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: cgraph.c:3498
+#: cgraph.c:3503
 #, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr ""
 
-#: cgraph.c:3508
+#: cgraph.c:3513
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr ""
@@ -18227,27 +18243,27 @@
 
 # src/getopt.c:628
 # src/getopt.c:628
-#: cgraph.c:3518
+#: cgraph.c:3523
 #, fuzzy, gcc-internal-format
 msgid "reference to dead statement"
 msgstr "%s: η επιλογή `%s' είναι ασαφής\n"
 
-#: cgraph.c:3531
+#: cgraph.c:3536
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3543
+#: cgraph.c:3548
 #, gcc-internal-format, gfc-internal-format
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr ""
 
-#: cgraph.c:3554
+#: cgraph.c:3559
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr ""
 
-#: cgraph.c:3661 varpool.c:306
+#: cgraph.c:3666 varpool.c:306
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s: section %s is missing"
 msgstr "έχουν παραληφθεί ορίσματα"
@@ -18278,12 +18294,12 @@
 msgstr ""
 
 #. include_self=
-#: cgraphunit.c:981 c/c-decl.c:11282
+#: cgraphunit.c:981 c/c-decl.c:11302
 #, fuzzy, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cgraphunit.c:983 c/c-decl.c:11291
+#: cgraphunit.c:983 c/c-decl.c:11311
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr ""
@@ -18398,13 +18414,13 @@
 msgid "cannot find '%s'"
 msgstr "αδυναμία ανοίγματος του `%s'"
 
-#: collect-utils.c:183 collect2.c:2361 collect2.c:2560 gcc.c:3080 gcc.c:6856
+#: collect-utils.c:183 collect2.c:2387 collect2.c:2586 gcc.c:3080 gcc.c:6856
 #, fuzzy, gcc-internal-format
 msgid "pex_init failed: %m"
 msgstr "αδυναμία ανοίγματος αρχείου εξόδου `%s'"
 
 # src/request.c:37
-#: collect-utils.c:192 collect2.c:2370 collect2.c:2568 gcc.c:8498
+#: collect-utils.c:192 collect2.c:2396 collect2.c:2594 gcc.c:8498
 #, fuzzy, gcc-internal-format
 #| msgid "%s: %s"
 msgid "%s: %m"
@@ -18415,28 +18431,28 @@
 msgid "COLLECT_LTO_WRAPPER must be set"
 msgstr ""
 
-#: collect2.c:966 gcc.c:7382 lto-wrapper.c:1666
+#: collect2.c:969 gcc.c:7382 lto-wrapper.c:1692
 #: config/i386/intelmic-mkoffload.c:556 config/nvptx/mkoffload.c:405
 #, gcc-internal-format
 msgid "atexit failed"
 msgstr ""
 
-#: collect2.c:1064
+#: collect2.c:1067
 #, gcc-internal-format
 msgid "no arguments"
 msgstr "χωρίς ορίσματα"
 
-#: collect2.c:1303 opts.c:904
+#: collect2.c:1311 opts.c:904
 #, fuzzy, gcc-internal-format
 msgid "LTO support has not been enabled in this configuration"
 msgstr "Η οικογένεια διευθύνσεων δεν υποστηρίζεται από την οικογένεια πρωτοκόλλου"
 
-#: collect2.c:1344
+#: collect2.c:1352
 #, fuzzy, gcc-internal-format
 msgid "can't open %s: %m"
 msgstr "αδυναμία ανοίγματος του `%s'"
 
-#: collect2.c:1450
+#: collect2.c:1472
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown demangling style '%s'"
 msgstr "άγνωστο σετ `%s'"
@@ -18443,69 +18459,69 @@
 
 # src/getopt1.c:132
 # src/getopt1.c:132
-#: collect2.c:1546 collect2.c:1729 collect2.c:1769
+#: collect2.c:1574 collect2.c:1757 collect2.c:1797
 #, fuzzy, gcc-internal-format
 #| msgid "fopen %s"
 msgid "fopen %s: %m"
 msgstr "fopen %s"
 
-#: collect2.c:1549 collect2.c:1734 collect2.c:1772
+#: collect2.c:1577 collect2.c:1762 collect2.c:1800
 #, fuzzy, gcc-internal-format
 #| msgid "fclose %s"
 msgid "fclose %s: %m"
 msgstr "fclose %s"
 
-#: collect2.c:2335
+#: collect2.c:2361
 #, fuzzy, gcc-internal-format
 msgid "cannot find 'nm'"
 msgstr "αδυναμία ανοίγματος του `%s'"
 
-#: collect2.c:2383
+#: collect2.c:2409
 #, fuzzy, gcc-internal-format
 msgid "can't open nm output: %m"
 msgstr "αδυναμία ανοίγματος αρχείου εξόδου `%s'"
 
-#: collect2.c:2467
+#: collect2.c:2493
 #, gcc-internal-format, gfc-internal-format
 msgid "init function found in object %s"
 msgstr ""
 
-#: collect2.c:2478
+#: collect2.c:2504
 #, gcc-internal-format, gfc-internal-format
 msgid "fini function found in object %s"
 msgstr ""
 
-#: collect2.c:2535
+#: collect2.c:2561
 #, fuzzy, gcc-internal-format
 msgid "cannot find 'ldd'"
 msgstr "αδυναμία ανοίγματος του `%s'"
 
-#: collect2.c:2581
+#: collect2.c:2607
 #, fuzzy, gcc-internal-format
 msgid "can't open ldd output: %m"
 msgstr "αδυναμία ανοίγματος αρχείου εξόδου `%s'"
 
-#: collect2.c:2599
+#: collect2.c:2625
 #, gcc-internal-format, gfc-internal-format
 msgid "dynamic dependency %s not found"
 msgstr ""
 
-#: collect2.c:2611
+#: collect2.c:2637
 #, gcc-internal-format, gfc-internal-format
 msgid "unable to open dynamic dependency '%s'"
 msgstr ""
 
-#: collect2.c:2765
+#: collect2.c:2791
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s: not a COFF file"
 msgstr "%s: Δεν είναι κανονικό αρχείο"
 
-#: collect2.c:2930
+#: collect2.c:2961
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s: cannot open as COFF file"
 msgstr "αδυναμία ανοίγματος αρχείου εξόδου"
 
-#: collect2.c:2989
+#: collect2.c:3020
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "library lib%s not found"
 msgstr "Πιθανόν δε βρέθηκε"
@@ -18715,12 +18731,12 @@
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr ""
 
-#: dwarf2out.c:10901
+#: dwarf2out.c:10909
 #, gcc-internal-format
 msgid "-gdwarf-6 is output as version 5 with incompatibilities"
 msgstr ""
 
-#: dwarf2out.c:14415
+#: dwarf2out.c:14423
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
@@ -18840,11 +18856,6 @@
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr ""
 
-#: file-prefix-map.c:50
-#, fuzzy, gcc-internal-format
-msgid "invalid argument %qs to %qs"
-msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
-
 #: final.c:1868
 #, fuzzy, gcc-internal-format
 msgid "the frame size of %wd bytes is larger than %wd bytes"
@@ -18865,42 +18876,42 @@
 msgid "large fixed-point constant implicitly truncated to fixed-point type"
 msgstr ""
 
-#: fold-const.c:4151 fold-const.c:4161
+#: fold-const.c:4157 fold-const.c:4167
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d due to width of bit-field"
 msgstr ""
 
-#: fold-const.c:5478 tree-ssa-reassoc.c:2374 tree-ssa-reassoc.c:3214
+#: fold-const.c:5484 tree-ssa-reassoc.c:2379 tree-ssa-reassoc.c:3219
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
 
-#: fold-const.c:5928 fold-const.c:5942
+#: fold-const.c:5934 fold-const.c:5948
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr ""
 
-#: fold-const.c:6085
+#: fold-const.c:6091
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr ""
 
-#: fold-const.c:6090
+#: fold-const.c:6096
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr ""
 
-#: fold-const.c:8310
+#: fold-const.c:8316
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr ""
 
-#: fold-const.c:8710
+#: fold-const.c:8716
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr ""
 
-#: fold-const.c:12063
+#: fold-const.c:12069
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr ""
@@ -18910,7 +18921,7 @@
 msgid "total size of local objects too large"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: function.c:1776 gimplify.c:6270
+#: function.c:1776 gimplify.c:6273
 #, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr ""
@@ -19216,7 +19227,7 @@
 msgid "%s: linker input file unused because linking not done"
 msgstr ""
 
-#: gcc.c:8420 c-family/c-opts.c:770
+#: gcc.c:8420 c-family/c-opts.c:768
 #, gcc-internal-format
 msgid "cannot use %<-%> as input filename for a precompiled header"
 msgstr ""
@@ -19456,7 +19467,7 @@
 msgid "%G%qD destination unchanged after copying no bytes"
 msgstr ""
 
-#: gimple-fold.c:2052 tree-ssa-strlen.c:2050
+#: gimple-fold.c:2052 tree-ssa-strlen.c:2074
 msgid "%G%qD specified bound %E equals destination size"
 msgstr ""
 
@@ -19478,12 +19489,12 @@
 msgid "null pointer dereference"
 msgstr "Μη έγκυρη πισω-παραπομπή"
 
-#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12451
-#: tree.c:12488 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10147
-#: c/c-typeck.c:10164 c/gimple-parser.c:1616 c/gimple-parser.c:1624
+#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12455
+#: tree.c:12492 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10152
+#: c/c-typeck.c:10169 c/gimple-parser.c:1616 c/gimple-parser.c:1624
 #: cp/call.c:6493 cp/call.c:8098 cp/constexpr.c:820 cp/constexpr.c:2309
-#: cp/cvt.c:1015 cp/cvt.c:1042 cp/decl.c:7334 cp/decl2.c:5256 cp/pt.c:8334
-#: cp/semantics.c:1836 cp/semantics.c:4053 cp/typeck.c:1700 cp/typeck.c:1895
+#: cp/cvt.c:1015 cp/cvt.c:1042 cp/decl.c:7355 cp/decl2.c:5246 cp/pt.c:8348
+#: cp/semantics.c:1836 cp/semantics.c:4056 cp/typeck.c:1700 cp/typeck.c:1895
 #: cp/typeck.c:3837
 #, fuzzy, gcc-internal-format
 msgid "declared here"
@@ -19494,27 +19505,27 @@
 msgid "nonnull argument %qD compared to NULL"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2517 gimple-ssa-sprintf.c:2637
+#: gimple-ssa-sprintf.c:2555 gimple-ssa-sprintf.c:2675
 #, gcc-internal-format
 msgid "%qE output may be truncated before the last format character"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2519 gimple-ssa-sprintf.c:2639
+#: gimple-ssa-sprintf.c:2557 gimple-ssa-sprintf.c:2677
 #, gcc-internal-format
 msgid "%qE output truncated before the last format character"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2522 gimple-ssa-sprintf.c:2642
+#: gimple-ssa-sprintf.c:2560 gimple-ssa-sprintf.c:2680
 #, gcc-internal-format
 msgid "%qE may write a terminating nul past the end of the destination"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2524 gimple-ssa-sprintf.c:2644
+#: gimple-ssa-sprintf.c:2562 gimple-ssa-sprintf.c:2682
 #, gcc-internal-format
 msgid "%qE writing a terminating nul past the end of the destination"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2534
+#: gimple-ssa-sprintf.c:2572
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size %wu"
@@ -19521,7 +19532,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.c:2541
+#: gimple-ssa-sprintf.c:2579
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size %wu"
@@ -19528,7 +19539,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.c:2548
+#: gimple-ssa-sprintf.c:2586
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size %wu"
@@ -19535,67 +19546,67 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.c:2559
+#: gimple-ssa-sprintf.c:2597
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2562
+#: gimple-ssa-sprintf.c:2600
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2564
+#: gimple-ssa-sprintf.c:2602
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2576
+#: gimple-ssa-sprintf.c:2614
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2579
+#: gimple-ssa-sprintf.c:2617
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2582
+#: gimple-ssa-sprintf.c:2620
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2591
+#: gimple-ssa-sprintf.c:2629
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2594
+#: gimple-ssa-sprintf.c:2632
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2597
+#: gimple-ssa-sprintf.c:2635
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2606
+#: gimple-ssa-sprintf.c:2644
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2609
+#: gimple-ssa-sprintf.c:2647
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2611
+#: gimple-ssa-sprintf.c:2649
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2653
+#: gimple-ssa-sprintf.c:2691
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size between %wu and %wu"
@@ -19602,7 +19613,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.c:2660
+#: gimple-ssa-sprintf.c:2698
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size between %wu and %wu"
@@ -19609,7 +19620,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.c:2668
+#: gimple-ssa-sprintf.c:2706
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size between %wu and %wu"
@@ -19616,102 +19627,102 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.c:2680
+#: gimple-ssa-sprintf.c:2718
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2683
+#: gimple-ssa-sprintf.c:2721
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2686
+#: gimple-ssa-sprintf.c:2724
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2699
+#: gimple-ssa-sprintf.c:2737
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2702
+#: gimple-ssa-sprintf.c:2740
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2705
+#: gimple-ssa-sprintf.c:2743
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2715
+#: gimple-ssa-sprintf.c:2753
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2718
+#: gimple-ssa-sprintf.c:2756
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2721
+#: gimple-ssa-sprintf.c:2759
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2730
+#: gimple-ssa-sprintf.c:2768
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2733
+#: gimple-ssa-sprintf.c:2771
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2736
+#: gimple-ssa-sprintf.c:2774
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2825
+#: gimple-ssa-sprintf.c:2863
 #, gcc-internal-format
 msgid "%<%.*s%> directive argument is null"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2890
+#: gimple-ssa-sprintf.c:2928
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes exceeds minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2897
+#: gimple-ssa-sprintf.c:2935
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may exceed minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2900
+#: gimple-ssa-sprintf.c:2938
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes exceeds minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2929
+#: gimple-ssa-sprintf.c:2967
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2936
+#: gimple-ssa-sprintf.c:2974
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2939
+#: gimple-ssa-sprintf.c:2977
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may cause result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2949
+#: gimple-ssa-sprintf.c:2987
 #, gcc-internal-format
 msgid "assuming directive output of %wu byte"
 msgid_plural "assuming directive output of %wu bytes"
@@ -19718,77 +19729,77 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: gimple-ssa-sprintf.c:2956
+#: gimple-ssa-sprintf.c:2994
 #, fuzzy, gcc-internal-format
 msgid "directive argument %qE"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: gimple-ssa-sprintf.c:2958
+#: gimple-ssa-sprintf.c:2996
 #, gcc-internal-format
 msgid "directive argument in the range [%E, %E]"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2962
+#: gimple-ssa-sprintf.c:3000
 #, gcc-internal-format
 msgid "using the range [%E, %E] for directive argument"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2982
+#: gimple-ssa-sprintf.c:3020
 #, gcc-internal-format
 msgid "%qE output %wu byte into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2983
+#: gimple-ssa-sprintf.c:3021
 #, gcc-internal-format
 msgid "%qE output %wu bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2987
+#: gimple-ssa-sprintf.c:3025
 #, gcc-internal-format
 msgid "%qE output between %wu and %wu bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2992
+#: gimple-ssa-sprintf.c:3030
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes (assuming %wu) into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2997
+#: gimple-ssa-sprintf.c:3035
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3368
+#: gimple-ssa-sprintf.c:3406
 #, gcc-internal-format
 msgid "%<%.*s%> directive width out of range"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3402
+#: gimple-ssa-sprintf.c:3440
 #, gcc-internal-format
 msgid "%<%.*s%> directive precision out of range"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3893
+#: gimple-ssa-sprintf.c:3931
 #, gcc-internal-format
 msgid "specified bound %wu exceeds maximum object size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3899
+#: gimple-ssa-sprintf.c:3937
 #, gcc-internal-format
 msgid "specified bound %wu exceeds %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3949
+#: gimple-ssa-sprintf.c:3987
 #, gcc-internal-format
 msgid "null destination pointer"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3966
+#: gimple-ssa-sprintf.c:4004
 #, gcc-internal-format
 msgid "specified bound %wu exceeds the size %wu of the destination object"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3978
+#: gimple-ssa-sprintf.c:4016
 #, fuzzy, gcc-internal-format
 msgid "null format string"
 msgstr "Η αλυσίδα μορφής δεν είναι έγκυρη: `%s'"
@@ -20002,10 +20013,10 @@
 msgstr ""
 
 #: gimple-ssa-warn-restrict.c:1678 c/c-decl.c:3603 c/c-decl.c:3874
-#: c/c-typeck.c:8345 cp/class.c:1346 cp/class.c:3098 cp/decl.c:3979
-#: cp/decl.c:10753 cp/decl.c:11151 cp/decl.c:11160 cp/friend.c:384
+#: c/c-typeck.c:8350 cp/class.c:1346 cp/class.c:3102 cp/decl.c:3979
+#: cp/decl.c:10777 cp/decl.c:11175 cp/decl.c:11184 cp/friend.c:384
 #: cp/friend.c:393 cp/parser.c:3275 cp/parser.c:3372 cp/parser.c:3422
-#: cp/parser.c:6327 cp/parser.c:21027
+#: cp/parser.c:6330 cp/parser.c:21024
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
@@ -20073,219 +20084,219 @@
 msgid "using result of function returning %<void%>"
 msgstr "`return' χωρίς τιμή, σε συνάρτηση που επιστρέφει μη-κενό"
 
-#: gimplify.c:6128
+#: gimplify.c:6131
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid lvalue in asm output %d"
 msgstr "Η παράμετρος κινητής υποδιαστολής δεν είναι έγκυρη: %s"
 
-#: gimplify.c:6271
+#: gimplify.c:6274
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr ""
 
-#: gimplify.c:6311 gimplify.c:6320
+#: gimplify.c:6314 gimplify.c:6323
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: gimplify.c:6928
+#: gimplify.c:6931
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in target region"
 msgstr ""
 
-#: gimplify.c:6930
+#: gimplify.c:6933
 #, gcc-internal-format
 msgid "enclosing target region"
 msgstr ""
 
-#: gimplify.c:6942
+#: gimplify.c:6945
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in untied task"
 msgstr ""
 
-#: gimplify.c:6944
+#: gimplify.c:6947
 #, gcc-internal-format
 msgid "enclosing task"
 msgstr ""
 
-#: gimplify.c:7016
+#: gimplify.c:7019
 #, fuzzy, gcc-internal-format
 msgid "%qE not specified in enclosing %qs"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: gimplify.c:7018
+#: gimplify.c:7021
 #, fuzzy, gcc-internal-format
 msgid "enclosing %qs"
 msgstr "σφάλμα ανάγνωσης %s"
 
-#: gimplify.c:7143
+#: gimplify.c:7146
 #, gcc-internal-format
 msgid "%qE not specified in enclosing OpenACC %qs construct"
 msgstr ""
 
-#: gimplify.c:7145
+#: gimplify.c:7148
 #, gcc-internal-format
 msgid "enclosing OpenACC %qs construct"
 msgstr ""
 
-#: gimplify.c:7198
+#: gimplify.c:7201
 #, gcc-internal-format
 msgid "%qE with %<link%> clause used in %<routine%> function"
 msgstr ""
 
-#: gimplify.c:7206
+#: gimplify.c:7209
 #, fuzzy, gcc-internal-format
 #| msgid "%qE undeclared (first use in this function)"
 msgid "%qE requires a %<declare%> directive for use in a %<routine%> function"
 msgstr "%qE δεν έχει διακυρηχθεί (πρώτη χρήση στη συνάρτηση αυτή)"
 
-#: gimplify.c:7272 gimplify.c:7872
+#: gimplify.c:7275 gimplify.c:7875
 #, gcc-internal-format
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr ""
 
-#: gimplify.c:7293
+#: gimplify.c:7296
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr ""
 
 # src/shred.c:1134
-#: gimplify.c:7411 gimplify.c:7443
+#: gimplify.c:7414 gimplify.c:7446
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE is predetermined linear"
 msgstr "%s: το αρχείο είναι πολύ μεγάλο"
 
-#: gimplify.c:7414
+#: gimplify.c:7417
 #, gcc-internal-format
 msgid "iteration variable %qE should be private"
 msgstr ""
 
-#: gimplify.c:7428
+#: gimplify.c:7431
 #, gcc-internal-format
 msgid "iteration variable %qE should not be firstprivate"
 msgstr ""
 
-#: gimplify.c:7431
+#: gimplify.c:7434
 #, gcc-internal-format
 msgid "iteration variable %qE should not be reduction"
 msgstr ""
 
-#: gimplify.c:7434
+#: gimplify.c:7437
 #, gcc-internal-format
 msgid "iteration variable %qE should not be linear"
 msgstr ""
 
-#: gimplify.c:7437
+#: gimplify.c:7440
 #, gcc-internal-format
 msgid "iteration variable %qE should not be lastprivate"
 msgstr ""
 
-#: gimplify.c:7440
+#: gimplify.c:7443
 #, gcc-internal-format
 msgid "iteration variable %qE should not be private"
 msgstr ""
 
-#: gimplify.c:7742
+#: gimplify.c:7745
 #, gcc-internal-format
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr ""
 
-#: gimplify.c:7949
+#: gimplify.c:7952
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr ""
 
-#: gimplify.c:8160
+#: gimplify.c:8163
 #, gcc-internal-format
 msgid "%qE appears more than once in map clauses"
 msgstr ""
 
-#: gimplify.c:8464
+#: gimplify.c:8467
 #, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr ""
 
-#: gimplify.c:8484
+#: gimplify.c:8487
 #, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr ""
 
-#: gimplify.c:8510
+#: gimplify.c:8513
 #, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr ""
 
-#: gimplify.c:8775
+#: gimplify.c:8778
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr ""
 
-#: gimplify.c:8808
+#: gimplify.c:8811
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:9000
+#: gimplify.c:9003
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:9051
+#: gimplify.c:9054
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr ""
 
-#: gimplify.c:9133
+#: gimplify.c:9136
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to present_or_copy"
 msgstr ""
 
-#: gimplify.c:9278
+#: gimplify.c:9281
 #, fuzzy, gcc-internal-format
 msgid "invalid private reduction on %qE"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: gimplify.c:11103 omp-low.c:2791
+#: gimplify.c:11106 omp-low.c:2791
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: gimplify.c:11121
+#: gimplify.c:11124
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr ""
 
-#: gimplify.c:11134
+#: gimplify.c:11137
 #, gcc-internal-format
 msgid "number of variables in %<depend(sink)%> clause does not match number of iteration variables"
 msgstr ""
 
-#: gimplify.c:11147
+#: gimplify.c:11150
 #, gcc-internal-format
 msgid "more than one %<depend(source)%> clause on an %<ordered%> construct"
 msgstr ""
 
-#: gimplify.c:11158
+#: gimplify.c:11161
 #, gcc-internal-format
 msgid "%<depend(source)%> clause specified together with %<depend(sink:)%> clauses on the same construct"
 msgstr ""
 
-#: gimplify.c:12393
+#: gimplify.c:12396
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr ""
 
-#: gimplify.c:12936
+#: gimplify.c:12939
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr ""
 
-#: gimplify.c:12941
+#: gimplify.c:12944
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr ""
 
-#: gimplify.c:12948
+#: gimplify.c:12951
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr ""
@@ -20758,47 +20769,47 @@
 msgid "Max. number of generated reload insns per insn is achieved (%d)\n"
 msgstr ""
 
-#: lto-cgraph.c:1294
+#: lto-cgraph.c:1296
 #, gcc-internal-format, gfc-internal-format
 msgid "bytecode stream: found multiple instances of cgraph node with uid %d"
 msgstr ""
 
-#: lto-cgraph.c:1472
+#: lto-cgraph.c:1474
 #, gcc-internal-format
 msgid "bytecode stream: no caller found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1478
+#: lto-cgraph.c:1480
 #, gcc-internal-format
 msgid "bytecode stream: no callee found while reading edge"
 msgstr ""
 
-#: lto-cgraph.c:1552
+#: lto-cgraph.c:1554
 #, gcc-internal-format
 msgid "bytecode stream: found empty cgraph node"
 msgstr ""
 
-#: lto-cgraph.c:1730
+#: lto-cgraph.c:1732
 #, gcc-internal-format, gfc-internal-format
 msgid "At most %i profile runs is supported. Perhaps corrupted profile?"
 msgstr ""
 
-#: lto-cgraph.c:1817
+#: lto-cgraph.c:1819
 #, gcc-internal-format, gfc-internal-format
 msgid "Profile information in %s corrupted"
 msgstr ""
 
-#: lto-cgraph.c:1855
+#: lto-cgraph.c:1857
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO cgraph in %s"
 msgstr "αδυναμία εκτέλεσης ioctl στο `%s'"
 
-#: lto-cgraph.c:1865
+#: lto-cgraph.c:1867
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO section refs in %s"
 msgstr "αδυναμία ανοίγματος υποδοχής: %s"
 
-#: lto-cgraph.c:1946
+#: lto-cgraph.c:1948
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid offload table in %s"
 msgstr "Μη έγκυρη ημερομηνία `%s'."
@@ -20869,75 +20880,75 @@
 msgid "bytecode stream in file %qs generated with LTO version %d.%d instead of the expected %d.%d"
 msgstr ""
 
-#: lto-wrapper.c:117
+#: lto-wrapper.c:118
 #, fuzzy, gcc-internal-format
 msgid "deleting LTRANS file %s: %m"
 msgstr "αδυναμία ανοίγματος αρχείου εξόδου `%s'"
 
-#: lto-wrapper.c:154
+#: lto-wrapper.c:155
 #, gcc-internal-format
 msgid "malformed COLLECT_GCC_OPTIONS"
 msgstr ""
 
-#: lto-wrapper.c:308
+#: lto-wrapper.c:309
 #, gcc-internal-format, gfc-internal-format
 msgid "Option %s with different values"
 msgstr ""
 
-#: lto-wrapper.c:392
+#: lto-wrapper.c:393
 #, gcc-internal-format, gfc-internal-format
 msgid "Option %s not used consistently in all LTO input files"
 msgstr ""
 
-#: lto-wrapper.c:832
+#: lto-wrapper.c:833
 #, gcc-internal-format, gfc-internal-format
 msgid "problem with building target image for %s\n"
 msgstr ""
 
-#: lto-wrapper.c:852
+#: lto-wrapper.c:853
 #, fuzzy, gcc-internal-format
 #| msgid "no input files"
 msgid "reading input file"
 msgstr "δεν υπάρχουν αρχεία εισόδου"
 
-#: lto-wrapper.c:857
+#: lto-wrapper.c:858
 #, fuzzy, gcc-internal-format
 msgid "writing output file"
 msgstr "%s: Σφάλμα κατά την εγγραφή του %s\n"
 
-#: lto-wrapper.c:889
+#: lto-wrapper.c:890
 #, gcc-internal-format
 msgid "installation error, can't find crtoffloadtable.o"
 msgstr ""
 
 # src/request.c:37
-#: lto-wrapper.c:1000 lto-wrapper.c:1012
+#: lto-wrapper.c:1001 lto-wrapper.c:1013
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s: %s"
 msgid "%s: %s\n"
 msgstr "%s: %s"
 
-#: lto-wrapper.c:1056
+#: lto-wrapper.c:1064
 #, gcc-internal-format
 msgid "environment variable COLLECT_GCC must be set"
 msgstr ""
 
-#: lto-wrapper.c:1060 config/nvptx/mkoffload.c:363
+#: lto-wrapper.c:1068 config/nvptx/mkoffload.c:363
 #, gcc-internal-format
 msgid "environment variable COLLECT_GCC_OPTIONS must be set"
 msgstr ""
 
-#: lto-wrapper.c:1229 lto-wrapper.c:1285
+#: lto-wrapper.c:1237 lto-wrapper.c:1293
 #, fuzzy, gcc-internal-format
 msgid "cannot open %s: %m"
 msgstr "αδυναμία ανοίγματος του `%s'"
 
-#: lto-wrapper.c:1232 lto-wrapper.c:1291
+#: lto-wrapper.c:1240 lto-wrapper.c:1299
 #, fuzzy, gcc-internal-format
 msgid "cannot read %s: %m"
 msgstr "%s: αδυναμία στην ανάγνωση %s: %s\n"
 
-#: lto-wrapper.c:1259
+#: lto-wrapper.c:1267
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid format of %s"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
@@ -20944,12 +20955,17 @@
 
 # src/getopt1.c:132
 # src/getopt1.c:132
-#: lto-wrapper.c:1482
+#: lto-wrapper.c:1491
 #, fuzzy, gcc-internal-format
 #| msgid "fopen %s"
 msgid "fopen: %s: %m"
 msgstr "fopen %s"
 
+#: lto-wrapper.c:1508
+#, fuzzy, gcc-internal-format, gfc-internal-format
+msgid "Corrupted ltrans output file %s"
+msgstr "αδυναμία ανοίγματος αρχείου εξόδου `%s'"
+
 #: multiple_target.c:76
 #, fuzzy, gcc-internal-format
 msgid "the call requires ifunc, which is not supported by this target"
@@ -21301,12 +21317,12 @@
 msgid "unrecognized argument in option %qs"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: opts-common.c:1198 config/i386/i386.c:3206
+#: opts-common.c:1198 config/i386/i386.c:3209
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: opts-common.c:1201 config/i386/i386.c:3209
+#: opts-common.c:1201 config/i386/i386.c:3212
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
@@ -21898,22 +21914,22 @@
 msgid "output operand %d must use %<&%> constraint"
 msgstr ""
 
-#: regcprop.c:1187
+#: regcprop.c:1193
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad next_regno for empty chain (%u)"
 msgstr ""
 
-#: regcprop.c:1199
+#: regcprop.c:1205
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: Loop in regno chain (%u)"
 msgstr ""
 
-#: regcprop.c:1202
+#: regcprop.c:1208
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad oldest_regno (%u)"
 msgstr ""
 
-#: regcprop.c:1214
+#: regcprop.c:1220
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Non-empty reg in chain (%s %u %i)"
 msgstr ""
@@ -21957,7 +21973,7 @@
 msgstr ""
 
 #: reginfo.c:789 config/powerpcspe/powerpcspe.c:32259
-#: config/rs6000/rs6000.c:29453
+#: config/rs6000/rs6000.c:29530
 #, fuzzy, gcc-internal-format
 msgid "conflicts with %qD"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
@@ -22202,152 +22218,157 @@
 msgid "function symbol is not function"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: symtab.c:1006
+#: symtab.c:1005
 #, gcc-internal-format
+msgid "inconsistent `ifunc' attribute"
+msgstr ""
+
+#: symtab.c:1013
+#, gcc-internal-format
 msgid "variable symbol is not variable"
 msgstr ""
 
-#: symtab.c:1012
+#: symtab.c:1019
 #, gcc-internal-format
 msgid "node has unknown type"
 msgstr ""
 
-#: symtab.c:1021
+#: symtab.c:1028
 #, gcc-internal-format
 msgid "node not found node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.c:1029
+#: symtab.c:1036
 #, gcc-internal-format
 msgid "node differs from node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.c:1038
+#: symtab.c:1045
 #, gcc-internal-format
 msgid "assembler name hash list corrupted"
 msgstr ""
 
-#: symtab.c:1051
+#: symtab.c:1058
 #, gcc-internal-format
 msgid "node not found in symtab assembler name hash"
 msgstr ""
 
-#: symtab.c:1058
+#: symtab.c:1065
 #, gcc-internal-format
 msgid "double linked list of assembler names corrupted"
 msgstr ""
 
-#: symtab.c:1063
+#: symtab.c:1070
 #, gcc-internal-format
 msgid "node has body_removed but is definition"
 msgstr ""
 
-#: symtab.c:1068
+#: symtab.c:1075
 #, fuzzy, gcc-internal-format
 msgid "node is analyzed but it is not a definition"
 msgstr "Το επώνυμο αντικείμενο δεν είναι αναζητήσιμο"
 
-#: symtab.c:1073
+#: symtab.c:1080
 #, gcc-internal-format
 msgid "node is alias but not implicit alias"
 msgstr ""
 
-#: symtab.c:1078
+#: symtab.c:1085
 #, fuzzy, gcc-internal-format
 msgid "node is alias but not definition"
 msgstr "έχει παραληφθεί το αρχείο προορισμού"
 
-#: symtab.c:1083
+#: symtab.c:1090
 #, gcc-internal-format
 msgid "node is weakref but not an transparent_alias"
 msgstr ""
 
-#: symtab.c:1088
+#: symtab.c:1095
 #, gcc-internal-format
 msgid "node is transparent_alias but not an alias"
 msgstr ""
 
-#: symtab.c:1097
+#: symtab.c:1104
 #, gcc-internal-format
 msgid "node is in same_comdat_group list but has no comdat_group"
 msgstr ""
 
-#: symtab.c:1102
+#: symtab.c:1109
 #, gcc-internal-format
 msgid "same_comdat_group list across different groups"
 msgstr ""
 
-#: symtab.c:1107
+#: symtab.c:1114
 #, gcc-internal-format
 msgid "mixing different types of symbol in same comdat groups is not supported"
 msgstr ""
 
-#: symtab.c:1112
+#: symtab.c:1119
 #, gcc-internal-format
 msgid "node is alone in a comdat group"
 msgstr ""
 
-#: symtab.c:1119
+#: symtab.c:1126
 #, gcc-internal-format
 msgid "same_comdat_group is not a circular list"
 msgstr ""
 
-#: symtab.c:1134
+#: symtab.c:1141
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local symbol referred to by %s outside its comdat"
 msgstr ""
 
-#: symtab.c:1144
+#: symtab.c:1151
 #, gcc-internal-format
 msgid "implicit_section flag is set but section isn't"
 msgstr ""
 
-#: symtab.c:1151
+#: symtab.c:1158
 #, gcc-internal-format
 msgid "Both section and comdat group is set"
 msgstr ""
 
-#: symtab.c:1163
+#: symtab.c:1170
 #, gcc-internal-format
 msgid "Alias and target's section differs"
 msgstr ""
 
-#: symtab.c:1170
+#: symtab.c:1177
 #, gcc-internal-format
 msgid "Alias and target's comdat groups differs"
 msgstr ""
 
-#: symtab.c:1185
+#: symtab.c:1192
 #, gcc-internal-format
 msgid "Transparent alias and target's assembler names differs"
 msgstr ""
 
-#: symtab.c:1193
+#: symtab.c:1200
 #, gcc-internal-format
 msgid "Chained transparent aliases"
 msgstr ""
 
-#: symtab.c:1216 symtab.c:1253
+#: symtab.c:1223 symtab.c:1260
 #, gcc-internal-format
 msgid "symtab_node::verify failed"
 msgstr ""
 
-#: symtab.c:1249
+#: symtab.c:1256
 #, gcc-internal-format
 msgid "Two symbols with same comdat_group are not linked by the same_comdat_group list."
 msgstr ""
 
-#: symtab.c:1658
+#: symtab.c:1665
 #, fuzzy, gcc-internal-format
 msgid "function %q+D part of alias cycle"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: symtab.c:1660
+#: symtab.c:1667
 #, gcc-internal-format
 msgid "variable %q+D part of alias cycle"
 msgstr ""
 
-#: symtab.c:1688
+#: symtab.c:1695
 #, gcc-internal-format
 msgid "section of alias %q+D must match section of its target"
 msgstr ""
@@ -23148,7 +23169,7 @@
 msgid "the first argument of a VEC_COND_EXPR must be of a boolean vector type of the same number of elements as the result"
 msgstr ""
 
-#: tree-cfg.c:4395 c/c-typeck.c:5212
+#: tree-cfg.c:4395 c/c-typeck.c:5217
 #, gcc-internal-format
 msgid "type mismatch in conditional expression"
 msgstr ""
@@ -23498,22 +23519,22 @@
 msgid "missing edge %i->%i"
 msgstr "έχει παραληφθεί το αρχείο προορισμού"
 
-#: tree-cfg.c:9379
+#: tree-cfg.c:9388
 #, fuzzy, gcc-internal-format
 msgid "%<noreturn%> function does return"
 msgstr "`return' χωρίς τιμή, σε συνάρτηση που επιστρέφει μη-κενό"
 
-#: tree-cfg.c:9400 tree-cfg.c:9432
+#: tree-cfg.c:9409 tree-cfg.c:9441
 #, fuzzy, gcc-internal-format
 msgid "control reaches end of non-void function"
 msgstr "ο έλεγχος φθάνει στο τέλος μη-κενής συνάρτησης"
 
-#: tree-cfg.c:9498 cp/cvt.c:1039
+#: tree-cfg.c:9507 cp/cvt.c:1039
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgstr ""
 
-#: tree-cfg.c:9503 cp/cvt.c:1046
+#: tree-cfg.c:9512 cp/cvt.c:1046
 #, gcc-internal-format
 msgid "ignoring return value of function declared with attribute warn_unused_result"
 msgstr ""
@@ -23779,46 +23800,46 @@
 msgid "stmt volatile flag not up-to-date"
 msgstr ""
 
-#: tree-ssa-strlen.c:1975
+#: tree-ssa-strlen.c:1999
 msgid "%G%qD output truncated before terminating nul copying %E byte from a string of the same length"
 msgid_plural "%G%qD output truncated before terminating nul copying %E bytes from a string of the same length"
 msgstr[0] ""
 msgstr[1] ""
 
-#: tree-ssa-strlen.c:1989
+#: tree-ssa-strlen.c:2013
 msgid "%G%qD output truncated copying %E byte from a string of length %wu"
 msgid_plural "%G%qD output truncated copying %E bytes from a string of length %wu"
 msgstr[0] ""
 msgstr[1] ""
 
-#: tree-ssa-strlen.c:1996
+#: tree-ssa-strlen.c:2020
 msgid "%G%qD output truncated copying between %wu and %wu bytes from a string of length %wu"
 msgstr ""
 
-#: tree-ssa-strlen.c:2008
+#: tree-ssa-strlen.c:2032
 msgid "%G%qD output may be truncated copying %E byte from a string of length %wu"
 msgid_plural "%G%qD output may be truncated copying %E bytes from a string of length %wu"
 msgstr[0] ""
 msgstr[1] ""
 
-#: tree-ssa-strlen.c:2015 tree-ssa-strlen.c:2029
+#: tree-ssa-strlen.c:2039 tree-ssa-strlen.c:2053
 msgid "%G%qD output may be truncated copying between %wu and %wu bytes from a string of length %wu"
 msgstr ""
 
-#: tree-ssa-strlen.c:2150
+#: tree-ssa-strlen.c:2174
 msgid "%G%qD output truncated before terminating nul copying as many bytes from a string as its length"
 msgstr ""
 
-#: tree-ssa-strlen.c:2156
+#: tree-ssa-strlen.c:2180
 msgid "%G%qD specified bound depends on the length of the source argument"
 msgstr ""
 
-#: tree-ssa-strlen.c:2163
+#: tree-ssa-strlen.c:2187
 #, gcc-internal-format
 msgid "length computed here"
 msgstr ""
 
-#: tree-ssa-uninit.c:191 varasm.c:331
+#: tree-ssa-uninit.c:191 varasm.c:342
 #, fuzzy, gcc-internal-format
 msgid "%qD was declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
@@ -23994,27 +24015,27 @@
 msgid "target specific builtin not available"
 msgstr ""
 
-#: tree-vect-generic.c:287
+#: tree-vect-generic.c:283
 #, gcc-internal-format
 msgid "vector operation will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-generic.c:290
+#: tree-vect-generic.c:286
 #, gcc-internal-format
 msgid "vector operation will be expanded in parallel"
 msgstr ""
 
-#: tree-vect-generic.c:341
+#: tree-vect-generic.c:337
 #, gcc-internal-format
 msgid "vector operation will be expanded with a single scalar operation"
 msgstr ""
 
-#: tree-vect-generic.c:941
+#: tree-vect-generic.c:937
 #, gcc-internal-format
 msgid "vector condition will be expanded piecewise"
 msgstr ""
 
-#: tree-vect-generic.c:1373
+#: tree-vect-generic.c:1369
 #, gcc-internal-format
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr ""
@@ -24024,27 +24045,27 @@
 msgid "vectorization did not happen for a simd loop"
 msgstr ""
 
-#: tree-vrp.c:4930 tree-vrp.c:4974
+#: tree-vrp.c:4931 tree-vrp.c:4975
 #, gcc-internal-format
 msgid "array subscript %E is above array bounds of %qT"
 msgstr ""
 
-#: tree-vrp.c:4956
+#: tree-vrp.c:4957
 #, gcc-internal-format
 msgid "array subscript [%E, %E] is outside array bounds of %qT"
 msgstr ""
 
-#: tree-vrp.c:4988
+#: tree-vrp.c:4989
 #, gcc-internal-format
 msgid "array subscript %E is below array bounds of %qT"
 msgstr ""
 
-#: tree-vrp.c:5046
+#: tree-vrp.c:5047
 #, gcc-internal-format
 msgid "array subscript %wi is below array bounds of %qT"
 msgstr ""
 
-#: tree-vrp.c:5060
+#: tree-vrp.c:5061
 #, gcc-internal-format
 msgid "array subscript %wu is above array bounds of %qT"
 msgstr ""
@@ -24059,92 +24080,92 @@
 msgid "side-effects element in no-side-effects CONSTRUCTOR"
 msgstr ""
 
-#: tree.c:7852
+#: tree.c:7856
 #, gcc-internal-format
 msgid "arrays of functions are not meaningful"
 msgstr ""
 
-#: tree.c:8019
+#: tree.c:8023
 #, gcc-internal-format
 msgid "function return type cannot be function"
 msgstr ""
 
-#: tree.c:9327 tree.c:9412 tree.c:9473
+#: tree.c:9331 tree.c:9416 tree.c:9477
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: %s, have %s in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9364
+#: tree.c:9368
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected none of %s, have %s in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9377
+#: tree.c:9381
 #, gcc-internal-format
 msgid "tree check: expected class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9426
+#: tree.c:9430
 #, gcc-internal-format
 msgid "tree check: did not expect class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9439
+#: tree.c:9443
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected omp_clause %s, have %s in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9499
+#: tree.c:9503
 #, gcc-internal-format
 msgid "tree check: expected tree that contains %qs structure, have %qs in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9513
+#: tree.c:9517
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_int_cst with %d elts in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9525
+#: tree.c:9529
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_vec with %d elts in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9538
+#: tree.c:9542
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of %s with %d operands in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:9551
+#: tree.c:9555
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of omp_clause %s with %d operands in %s, at %s:%d"
 msgstr ""
 
-#: tree.c:12446
+#: tree.c:12450
 #, fuzzy, gcc-internal-format
 msgid "%qD is deprecated: %s"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: tree.c:12449
+#: tree.c:12453
 #, fuzzy, gcc-internal-format
 msgid "%qD is deprecated"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: tree.c:12473 tree.c:12495
+#: tree.c:12477 tree.c:12499
 #, fuzzy, gcc-internal-format
 msgid "%qE is deprecated: %s"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: tree.c:12476 tree.c:12498
+#: tree.c:12480 tree.c:12502
 #, fuzzy, gcc-internal-format
 msgid "%qE is deprecated"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: tree.c:12482 tree.c:12503
+#: tree.c:12486 tree.c:12507
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "type is deprecated: %s"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: tree.c:12485 tree.c:12506
+#: tree.c:12489 tree.c:12510
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr ""
@@ -24169,242 +24190,242 @@
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.c:13043
+#: tree.c:13047
 #, gcc-internal-format, gfc-internal-format
 msgid "type variant differs by %s"
 msgstr ""
 
-#: tree.c:13084
+#: tree.c:13088
 #, gcc-internal-format
 msgid "type variant has different TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13086
+#: tree.c:13090
 #, gcc-internal-format
 msgid "type variant's TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13088
+#: tree.c:13092
 #, gcc-internal-format
 msgid "type's TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13108
+#: tree.c:13112
 #, gcc-internal-format
 msgid "type variant with TYPE_ALIAS_SET_KNOWN_P"
 msgstr ""
 
-#: tree.c:13121
+#: tree.c:13125
 #, gcc-internal-format
 msgid "type variant has different TYPE_VFIELD"
 msgstr ""
 
-#: tree.c:13157
+#: tree.c:13161
 #, gcc-internal-format
 msgid "type variant has different TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13159
+#: tree.c:13163
 #, gcc-internal-format
 msgid "type variant's TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13161
+#: tree.c:13165
 #, gcc-internal-format
 msgid "type's TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13199
+#: tree.c:13203
 #, gcc-internal-format
 msgid "type variant has different TYPE_FIELDS"
 msgstr ""
 
-#: tree.c:13201
+#: tree.c:13205
 #, gcc-internal-format
 msgid "first mismatch is field"
 msgstr ""
 
-#: tree.c:13203
+#: tree.c:13207
 #, gcc-internal-format
 msgid "and field"
 msgstr ""
 
-#: tree.c:13220
+#: tree.c:13224
 #, gcc-internal-format
 msgid "type variant has different TREE_TYPE"
 msgstr ""
 
-#: tree.c:13222 tree.c:13233
+#: tree.c:13226 tree.c:13237
 #, gcc-internal-format
 msgid "type variant's TREE_TYPE"
 msgstr ""
 
-#: tree.c:13224 tree.c:13235
+#: tree.c:13228 tree.c:13239
 #, gcc-internal-format
 msgid "type's TREE_TYPE"
 msgstr ""
 
-#: tree.c:13231
+#: tree.c:13235
 #, gcc-internal-format
 msgid "type is not compatible with its variant"
 msgstr ""
 
-#: tree.c:13534
+#: tree.c:13538
 #, gcc-internal-format
 msgid "Main variant is not defined"
 msgstr ""
 
-#: tree.c:13539
+#: tree.c:13543
 #, gcc-internal-format
 msgid "TYPE_MAIN_VARIANT has different TYPE_MAIN_VARIANT"
 msgstr ""
 
-#: tree.c:13551
+#: tree.c:13555
 #, gcc-internal-format
 msgid "TYPE_CANONICAL has different TYPE_CANONICAL"
 msgstr ""
 
-#: tree.c:13569
+#: tree.c:13573
 #, gcc-internal-format
 msgid "TYPE_CANONICAL is not compatible"
 msgstr ""
 
-#: tree.c:13577
+#: tree.c:13581
 #, gcc-internal-format
 msgid "TYPE_MODE of TYPE_CANONICAL is not compatible"
 msgstr ""
 
-#: tree.c:13583
+#: tree.c:13587
 #, gcc-internal-format
 msgid "TYPE_CANONICAL of main variant is not main variant"
 msgstr ""
 
-#: tree.c:13599
+#: tree.c:13603
 #, gcc-internal-format
 msgid "TYPE_VFIELD is not FIELD_DECL nor TREE_LIST"
 msgstr ""
 
-#: tree.c:13609
+#: tree.c:13613
 #, gcc-internal-format
 msgid "TYPE_NEXT_PTR_TO is not POINTER_TYPE"
 msgstr ""
 
-#: tree.c:13619
+#: tree.c:13623
 #, gcc-internal-format
 msgid "TYPE_NEXT_REF_TO is not REFERENCE_TYPE"
 msgstr ""
 
-#: tree.c:13640
+#: tree.c:13644
 #, gcc-internal-format
 msgid "TYPE_BINFO is not TREE_BINFO"
 msgstr ""
 
-#: tree.c:13646
+#: tree.c:13650
 #, gcc-internal-format
 msgid "TYPE_BINFO type is not TYPE_MAIN_VARIANT"
 msgstr ""
 
-#: tree.c:13657
+#: tree.c:13661
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not record nor union"
 msgstr ""
 
-#: tree.c:13668
+#: tree.c:13672
 #, gcc-internal-format
 msgid "TYPE_OFFSET_BASETYPE is not record nor union"
 msgstr ""
 
-#: tree.c:13686
+#: tree.c:13690
 #, gcc-internal-format
 msgid "TYPE_ARRAY_MAX_SIZE not INTEGER_CST"
 msgstr ""
 
-#: tree.c:13693
+#: tree.c:13697
 #, gcc-internal-format
 msgid "TYPE_MAX_VALUE_RAW non-NULL"
 msgstr ""
 
-#: tree.c:13700
+#: tree.c:13704
 #, gcc-internal-format
 msgid "TYPE_LANG_SLOT_1 (binfo) field is non-NULL"
 msgstr ""
 
-#: tree.c:13716
+#: tree.c:13720
 #, gcc-internal-format
 msgid "Enum value is not CONST_DECL or INTEGER_CST"
 msgstr ""
 
-#: tree.c:13724
+#: tree.c:13728
 #, gcc-internal-format
 msgid "Enum value type is not INTEGER_TYPE nor convertible to the enum"
 msgstr ""
 
-#: tree.c:13731
+#: tree.c:13735
 #, gcc-internal-format
 msgid "Enum value name is not IDENTIFIER_NODE"
 msgstr ""
 
-#: tree.c:13741
+#: tree.c:13745
 #, gcc-internal-format
 msgid "Array TYPE_DOMAIN is not integer type"
 msgstr ""
 
-#: tree.c:13750
+#: tree.c:13754
 #, fuzzy, gcc-internal-format
 msgid "TYPE_FIELDS defined in incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: tree.c:13772
+#: tree.c:13776
 #, gcc-internal-format
 msgid "Wrong tree in TYPE_FIELDS list"
 msgstr ""
 
-#: tree.c:13787
+#: tree.c:13791
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is %i while TYPE_CACHED_VALUES is %p"
 msgstr ""
 
-#: tree.c:13793
+#: tree.c:13797
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES is not TREE_VEC"
 msgstr ""
 
-#: tree.c:13806
+#: tree.c:13810
 #, gcc-internal-format
 msgid "wrong TYPE_CACHED_VALUES entry"
 msgstr ""
 
-#: tree.c:13819
+#: tree.c:13823
 #, gcc-internal-format
 msgid "TREE_PURPOSE is non-NULL in TYPE_ARG_TYPES list"
 msgstr ""
 
-#: tree.c:13825
+#: tree.c:13829
 #, gcc-internal-format
 msgid "Wrong entry in TYPE_ARG_TYPES list"
 msgstr ""
 
-#: tree.c:13832
+#: tree.c:13836
 #, gcc-internal-format
 msgid "TYPE_VALUES_RAW field is non-NULL"
 msgstr ""
 
-#: tree.c:13844
+#: tree.c:13848
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is set while it should not"
 msgstr ""
 
-#: tree.c:13850
+#: tree.c:13854
 #, gcc-internal-format
 msgid "TYPE_STRING_FLAG is set on wrong type code"
 msgstr ""
 
-#: tree.c:13860
+#: tree.c:13864
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not main variant"
 msgstr ""
 
-#: tree.c:13867
+#: tree.c:13871
 #, gcc-internal-format
 msgid "verify_type failed"
 msgstr ""
@@ -24429,182 +24450,182 @@
 msgid "corrupted value profile: %s profile counter (%d out of %d) inconsistent with basic-block count (%d)"
 msgstr ""
 
-#: var-tracking.c:7166
+#: var-tracking.c:7184
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded with -fvar-tracking-assignments, retrying without"
 msgstr ""
 
-#: var-tracking.c:7170
+#: var-tracking.c:7188
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded"
 msgstr ""
 
-#: varasm.c:326
+#: varasm.c:337
 #, gcc-internal-format
 msgid "%+qD causes a section type conflict with %qD"
 msgstr ""
 
-#: varasm.c:329
+#: varasm.c:340
 #, gcc-internal-format
 msgid "section type conflict with %qD"
 msgstr ""
 
-#: varasm.c:334
+#: varasm.c:345
 #, fuzzy, gcc-internal-format
 msgid "%+qD causes a section type conflict"
 msgstr "συντακτικό σφάλμα στον καθορισμό σειράς"
 
-#: varasm.c:336
+#: varasm.c:347
 #, gcc-internal-format
 msgid "section type conflict"
 msgstr ""
 
-#: varasm.c:1019
+#: varasm.c:1030
 #, gcc-internal-format
 msgid "alignment of %q+D is greater than maximum object file alignment %d"
 msgstr ""
 
-#: varasm.c:1172
+#: varasm.c:1183
 #, fuzzy, gcc-internal-format
 msgid "only zero initializers are allowed in section %qs"
 msgstr "Δεν ήταν δυνατή η εύρεση ετικέττας για μεταγωγή στο `%s'"
 
-#: varasm.c:1378 varasm.c:1387
+#: varasm.c:1389 varasm.c:1398
 #, fuzzy, gcc-internal-format
 msgid "register name not specified for %q+D"
 msgstr "Εγγραφή ονομάτων των επιλεγμένων λέξεων-κλειδιών"
 
-#: varasm.c:1389
+#: varasm.c:1400
 #, fuzzy, gcc-internal-format
 msgid "invalid register name for %q+D"
 msgstr "μη έγκυρος αριθμός πεδίου: `%s'"
 
-#: varasm.c:1391
+#: varasm.c:1402
 #, gcc-internal-format
 msgid "data type of %q+D isn%'t suitable for a register"
 msgstr ""
 
-#: varasm.c:1394
+#: varasm.c:1405
 #, gcc-internal-format
 msgid "the register specified for %q+D cannot be accessed by the current target"
 msgstr ""
 
-#: varasm.c:1397
+#: varasm.c:1408
 #, gcc-internal-format
 msgid "the register specified for %q+D is not general enough to be used as a register variable"
 msgstr ""
 
-#: varasm.c:1400
+#: varasm.c:1411
 #, gcc-internal-format
 msgid "register specified for %q+D isn%'t suitable for data type"
 msgstr ""
 
-#: varasm.c:1410
+#: varasm.c:1421
 #, gcc-internal-format
 msgid "global register variable has initial value"
 msgstr ""
 
-#: varasm.c:1414
+#: varasm.c:1425
 #, gcc-internal-format
 msgid "optimization may eliminate reads and/or writes to register variables"
 msgstr ""
 
-#: varasm.c:1460
+#: varasm.c:1471
 #, gcc-internal-format
 msgid "register name given for non-register variable %q+D"
 msgstr ""
 
-#: varasm.c:1870
+#: varasm.c:1881
 #, gcc-internal-format
 msgid "Patchable function entry > size"
 msgstr ""
 
-#: varasm.c:2069
+#: varasm.c:2080
 #, gcc-internal-format
 msgid "thread-local COMMON data not implemented"
 msgstr ""
 
-#: varasm.c:2102
+#: varasm.c:2113
 #, gcc-internal-format
 msgid "requested alignment for %q+D is greater than implemented alignment of %wu"
 msgstr ""
 
-#: varasm.c:2205 c/c-decl.c:5027 c/c-parser.c:1534
+#: varasm.c:2216 c/c-decl.c:5027 c/c-parser.c:1534
 #, fuzzy, gcc-internal-format
 msgid "storage size of %q+D isn%'t known"
 msgstr "Το όνομα `%s' είναι άγνωστο\n"
 
-#: varasm.c:4910
+#: varasm.c:4921
 #, gcc-internal-format
 msgid "initializer for integer/fixed-point value is too complicated"
 msgstr ""
 
-#: varasm.c:4915
+#: varasm.c:4926
 #, gcc-internal-format
 msgid "initializer for floating value is not a floating constant"
 msgstr ""
 
-#: varasm.c:5227
+#: varasm.c:5238
 #, fuzzy, gcc-internal-format
 msgid "invalid initial value for member %qE"
 msgstr "μη έγκυρος αριθμός πεδίου: `%s'"
 
-#: varasm.c:5487
+#: varasm.c:5498
 #, fuzzy, gcc-internal-format
 msgid "%+qD declared weak after being used"
 msgstr "%s: διπλός ορισμός έκδοσης κατηγορίας"
 
-#: varasm.c:5539
+#: varasm.c:5550
 #, fuzzy, gcc-internal-format
 msgid "weak declaration of %q+D being applied to a already existing, static definition"
 msgstr "Η λειτουργία δεν υποστηρίζεται"
 
-#: varasm.c:5575
+#: varasm.c:5586
 #, fuzzy, gcc-internal-format
 msgid "weak declaration of %q+D must be public"
 msgstr "Η λειτουργία δεν υποστηρίζεται"
 
-#: varasm.c:5579
+#: varasm.c:5590
 #, fuzzy, gcc-internal-format
 msgid "weak declaration of %q+D not supported"
 msgstr "Η λειτουργία δεν υποστηρίζεται"
 
-#: varasm.c:5608 varasm.c:5912
+#: varasm.c:5619 varasm.c:5926
 #, gcc-internal-format
 msgid "only weak aliases are supported in this configuration"
 msgstr ""
 
-#: varasm.c:5802
+#: varasm.c:5813
 #, fuzzy, gcc-internal-format
 msgid "weakref is not supported in this configuration"
 msgstr "Η οικογένεια διευθύνσεων δεν υποστηρίζεται από την οικογένεια πρωτοκόλλου"
 
-#: varasm.c:5834
+#: varasm.c:5846
 #, fuzzy, gcc-internal-format
 msgid "ifunc is not supported on this target"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: varasm.c:5892
+#: varasm.c:5904
 #, gcc-internal-format
 msgid "weakref %q+D ultimately targets itself"
 msgstr ""
 
-#: varasm.c:5894
+#: varasm.c:5906
 #, gcc-internal-format
 msgid "weakref %q+D must have static linkage"
 msgstr ""
 
-#: varasm.c:5901
+#: varasm.c:5913
 #, fuzzy, gcc-internal-format
 msgid "alias definitions not supported in this configuration"
 msgstr "Η οικογένεια διευθύνσεων δεν υποστηρίζεται από την οικογένεια πρωτοκόλλου"
 
-#: varasm.c:5909
+#: varasm.c:5923
 #, fuzzy, gcc-internal-format
 msgid "ifunc is not supported in this configuration"
 msgstr "Η οικογένεια διευθύνσεων δεν υποστηρίζεται από την οικογένεια πρωτοκόλλου"
 
-#: varasm.c:6127 config/sol2.c:159 config/i386/winnt.c:265
+#: varasm.c:6141 config/sol2.c:159 config/i386/winnt.c:265
 #, fuzzy, gcc-internal-format
 msgid "visibility attribute not supported in this configuration; ignored"
 msgstr "Η οικογένεια διευθύνσεων δεν υποστηρίζεται από την οικογένεια πρωτοκόλλου"
@@ -24680,466 +24701,471 @@
 msgid "bytecode stream: tag %s is not in the expected range [%s, %s]"
 msgstr ""
 
-#: c-family/c-attribs.c:529
+#: c-family/c-attribs.c:524
 #, fuzzy, gcc-internal-format
+msgid "%qE attribute ignored for type %qT"
+msgstr "το `%s' είναι πρόγονος του `%s'"
+
+#: c-family/c-attribs.c:536
+#, fuzzy, gcc-internal-format
 msgid "%qE attribute ignored for field of type %qT"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: c-family/c-attribs.c:696
+#: c-family/c-attribs.c:706
 #, fuzzy, gcc-internal-format
 msgid "no_sanitize argument not a string"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: c-family/c-attribs.c:826 ada/gcc-interface/utils.c:6235
+#: c-family/c-attribs.c:837 ada/gcc-interface/utils.c:6240
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute ignored due to conflict with attribute %qs"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: c-family/c-attribs.c:875
+#: c-family/c-attribs.c:886
 #, gcc-internal-format
 msgid "%qE attribute ignored. Use -fcf-protection option to enable it"
 msgstr ""
 
-#: c-family/c-attribs.c:914 c-family/c-attribs.c:920 c-family/c-attribs.c:3388
-#: c-family/c-attribs.c:3423 c-family/c-attribs.c:3429
+#: c-family/c-attribs.c:925 c-family/c-attribs.c:931 c-family/c-attribs.c:3399
+#: c-family/c-attribs.c:3434 c-family/c-attribs.c:3440
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute ignored due to conflict with %qs attribute"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: c-family/c-attribs.c:976 brig/brig-lang.c:482 lto/lto-lang.c:288
+#: c-family/c-attribs.c:987 brig/brig-lang.c:482 lto/lto-lang.c:288
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute has no effect on unit local functions"
 msgstr "%s: διπλός ορισμός έκδοσης κατηγορίας"
 
-#: c-family/c-attribs.c:1130
+#: c-family/c-attribs.c:1141
 #, gcc-internal-format
 msgid "%qE attribute have effect only on public objects"
 msgstr ""
 
-#: c-family/c-attribs.c:1159
+#: c-family/c-attribs.c:1170
 #, gcc-internal-format
 msgid "%qE attribute only affects top level objects"
 msgstr ""
 
-#: c-family/c-attribs.c:1198 c-family/c-attribs.c:2682
+#: c-family/c-attribs.c:1209 c-family/c-attribs.c:2693
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute on function returning %<void%>"
 msgstr "`return' χωρίς τιμή, σε συνάρτηση που επιστρέφει μη-κενό"
 
-#: c-family/c-attribs.c:1221 c-family/c-pragma.c:419
+#: c-family/c-attribs.c:1232 c-family/c-pragma.c:419
 #, gcc-internal-format
 msgid "scalar_storage_order is not supported because endianness is not uniform"
 msgstr ""
 
-#: c-family/c-attribs.c:1238
+#: c-family/c-attribs.c:1249
 #, gcc-internal-format
 msgid "scalar_storage_order argument must be one of \"big-endian\" or \"little-endian\""
 msgstr ""
 
-#: c-family/c-attribs.c:1334
+#: c-family/c-attribs.c:1345
 #, fuzzy, gcc-internal-format
 msgid "destructor priorities are not supported"
 msgstr "Η λειτουργία δεν υποστηρίζεται"
 
-#: c-family/c-attribs.c:1336
+#: c-family/c-attribs.c:1347
 #, fuzzy, gcc-internal-format
 msgid "constructor priorities are not supported"
 msgstr "Η λειτουργία δεν υποστηρίζεται"
 
-#: c-family/c-attribs.c:1358
+#: c-family/c-attribs.c:1369
 #, gcc-internal-format, gfc-internal-format
 msgid "destructor priorities from 0 to %d are reserved for the implementation"
 msgstr ""
 
-#: c-family/c-attribs.c:1363
+#: c-family/c-attribs.c:1374
 #, gcc-internal-format, gfc-internal-format
 msgid "constructor priorities from 0 to %d are reserved for the implementation"
 msgstr ""
 
-#: c-family/c-attribs.c:1371
+#: c-family/c-attribs.c:1382
 #, gcc-internal-format, gfc-internal-format
 msgid "destructor priorities must be integers from 0 to %d inclusive"
 msgstr ""
 
-#: c-family/c-attribs.c:1374
+#: c-family/c-attribs.c:1385
 #, gcc-internal-format, gfc-internal-format
 msgid "constructor priorities must be integers from 0 to %d inclusive"
 msgstr ""
 
-#: c-family/c-attribs.c:1527
+#: c-family/c-attribs.c:1538
 #, fuzzy, gcc-internal-format
 msgid "unknown machine mode %qE"
 msgstr "άγνωστο σετ `%s'"
 
-#: c-family/c-attribs.c:1557
+#: c-family/c-attribs.c:1568
 #, gcc-internal-format
 msgid "specifying vector types with __attribute__ ((mode)) is deprecated"
 msgstr ""
 
-#: c-family/c-attribs.c:1560
+#: c-family/c-attribs.c:1571
 #, gcc-internal-format
 msgid "use __attribute__ ((vector_size)) instead"
 msgstr ""
 
-#: c-family/c-attribs.c:1569
+#: c-family/c-attribs.c:1580
 #, fuzzy, gcc-internal-format
 msgid "unable to emulate %qs"
 msgstr "Δεν μπόρεσα να ανοίξω το αρχείο %s"
 
-#: c-family/c-attribs.c:1582
+#: c-family/c-attribs.c:1593
 #, fuzzy, gcc-internal-format
 msgid "invalid pointer mode %qs"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: c-family/c-attribs.c:1599
+#: c-family/c-attribs.c:1610
 #, gcc-internal-format
 msgid "signedness of type and machine mode %qs don%'t match"
 msgstr ""
 
-#: c-family/c-attribs.c:1610
+#: c-family/c-attribs.c:1621
 #, fuzzy, gcc-internal-format
 msgid "no data type for mode %qs"
 msgstr "δεν ορίστηκε βαρύτητα για το σύμβολο `%s'"
 
-#: c-family/c-attribs.c:1620
+#: c-family/c-attribs.c:1631
 #, fuzzy, gcc-internal-format
 msgid "cannot use mode %qs for enumeral types"
 msgstr "Δεν είναι δυνατόν να βρεθεί ο τύπος του επεξεργαστή."
 
-#: c-family/c-attribs.c:1647
+#: c-family/c-attribs.c:1658
 #, gcc-internal-format
 msgid "mode %qs applied to inappropriate type"
 msgstr ""
 
-#: c-family/c-attribs.c:1669
+#: c-family/c-attribs.c:1680
 #, fuzzy, gcc-internal-format
 msgid "section attributes are not supported for this target"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: c-family/c-attribs.c:1675
+#: c-family/c-attribs.c:1686
 #, fuzzy, gcc-internal-format
 msgid "section attribute not allowed for %q+D"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: c-family/c-attribs.c:1681
+#: c-family/c-attribs.c:1692
 #, fuzzy, gcc-internal-format
 msgid "section attribute argument not a string constant"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: c-family/c-attribs.c:1690
+#: c-family/c-attribs.c:1701
 #, fuzzy, gcc-internal-format
 msgid "section attribute cannot be specified for local variables"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: c-family/c-attribs.c:1700 config/bfin/bfin.c:4806 config/bfin/bfin.c:4857
+#: c-family/c-attribs.c:1711 config/bfin/bfin.c:4806 config/bfin/bfin.c:4857
 #: config/bfin/bfin.c:4883 config/bfin/bfin.c:4896
 #, fuzzy, gcc-internal-format
 msgid "section of %q+D conflicts with previous declaration"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: c-family/c-attribs.c:1708
+#: c-family/c-attribs.c:1719
 #, fuzzy, gcc-internal-format
 msgid "section of %q+D cannot be overridden"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: c-family/c-attribs.c:1773
+#: c-family/c-attribs.c:1784
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "requested alignment %d is larger than %d"
 msgstr "Κακή αίτηση παραμέτρων"
 
-#: c-family/c-attribs.c:1866
+#: c-family/c-attribs.c:1877
 #, fuzzy, gcc-internal-format
 msgid "alignment may not be specified for %q+D"
 msgstr "μόνο ένα όρισμα μπορεί να δηλωθεί"
 
-#: c-family/c-attribs.c:1886
+#: c-family/c-attribs.c:1897
 #, gcc-internal-format
 msgid "ignoring attribute %<%E (%u)%> because it conflicts with attribute %<%E (%u)%>"
 msgstr ""
 
 #. Do not error out for attribute warn_if_not_aligned.
-#: c-family/c-attribs.c:1891 c-family/c-attribs.c:1920
+#: c-family/c-attribs.c:1902 c-family/c-attribs.c:1931
 #, fuzzy, gcc-internal-format
 msgid "alignment for %q+D must be at least %d"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: c-family/c-attribs.c:1916
+#: c-family/c-attribs.c:1927
 #, gcc-internal-format
 msgid "alignment for %q+D was previously specified as %d and may not be decreased"
 msgstr ""
 
-#: c-family/c-attribs.c:1943
+#: c-family/c-attribs.c:1954
 #, fuzzy, gcc-internal-format
 msgid "%<warn_if_not_aligned%> may not be specified for %q+D"
 msgstr "μόνο ένα όρισμα μπορεί να δηλωθεί"
 
-#: c-family/c-attribs.c:1986
+#: c-family/c-attribs.c:1997
 #, fuzzy, gcc-internal-format
 msgid "inline function %q+D declared weak"
 msgstr "Στη συνάρτηση μέλος `%s':"
 
-#: c-family/c-attribs.c:1991
+#: c-family/c-attribs.c:2002
 #, fuzzy, gcc-internal-format
 msgid "indirect function %q+D cannot be declared weak"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: c-family/c-attribs.c:2015
+#: c-family/c-attribs.c:2026
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is only applicable on functions"
 msgstr "προειδοποίηση: το --pid=PID δεν υποστηρίζεται σε αυτό το σύστημα"
 
-#: c-family/c-attribs.c:2046
+#: c-family/c-attribs.c:2057
 #, gcc-internal-format
 msgid "%q+D defined both normally and as %qE attribute"
 msgstr ""
 
-#: c-family/c-attribs.c:2054
+#: c-family/c-attribs.c:2065
 #, fuzzy, gcc-internal-format
 msgid "weak %q+D cannot be defined %qE"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: c-family/c-attribs.c:2071 c-family/c-attribs.c:2582
+#: c-family/c-attribs.c:2082 c-family/c-attribs.c:2593
 #, fuzzy, gcc-internal-format
 msgid "attribute %qE argument not a string"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: c-family/c-attribs.c:2106
+#: c-family/c-attribs.c:2117
 #, fuzzy, gcc-internal-format
 msgid "%+qD declared alias after being used"
 msgstr "%s: διπλός ορισμός έκδοσης κατηγορίας"
 
-#: c-family/c-attribs.c:2108
+#: c-family/c-attribs.c:2119
 #, fuzzy, gcc-internal-format
 msgid "%+qD declared ifunc after being used"
 msgstr "%s: διπλός ορισμός έκδοσης κατηγορίας"
 
-#: c-family/c-attribs.c:2159
+#: c-family/c-attribs.c:2170
 #, fuzzy, gcc-internal-format
 msgid "indirect function %q+D cannot be declared weakref"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: c-family/c-attribs.c:2181
+#: c-family/c-attribs.c:2192
 #, gcc-internal-format
 msgid "weakref attribute must appear before alias attribute"
 msgstr ""
 
-#: c-family/c-attribs.c:2193
+#: c-family/c-attribs.c:2204
 #, fuzzy, gcc-internal-format
 msgid "%+qD declared weakref after being used"
 msgstr "%s: διπλός ορισμός έκδοσης κατηγορίας"
 
-#: c-family/c-attribs.c:2217
+#: c-family/c-attribs.c:2228
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute ignored on non-class types"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: c-family/c-attribs.c:2223
+#: c-family/c-attribs.c:2234
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute ignored because %qT is already defined"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: c-family/c-attribs.c:2236
+#: c-family/c-attribs.c:2247
 #, fuzzy, gcc-internal-format
 msgid "visibility argument not a string"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: c-family/c-attribs.c:2248
+#: c-family/c-attribs.c:2259
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute ignored on types"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: c-family/c-attribs.c:2264
+#: c-family/c-attribs.c:2275
 #, gcc-internal-format
 msgid "visibility argument must be one of \"default\", \"hidden\", \"protected\" or \"internal\""
 msgstr ""
 
-#: c-family/c-attribs.c:2275
+#: c-family/c-attribs.c:2286
 #, fuzzy, gcc-internal-format
 msgid "%qD redeclared with different visibility"
 msgstr "συντακτικό σφάλμα στον καθορισμό σειράς"
 
-#: c-family/c-attribs.c:2278 c-family/c-attribs.c:2282
+#: c-family/c-attribs.c:2289 c-family/c-attribs.c:2293
 #, gcc-internal-format
 msgid "%qD was declared %qs which implies default visibility"
 msgstr ""
 
-#: c-family/c-attribs.c:2320
+#: c-family/c-attribs.c:2331
 #, fuzzy, gcc-internal-format
 msgid "tls_model argument not a string"
 msgstr "έχουν παραληφθεί ορίσματα"
 
-#: c-family/c-attribs.c:2333
+#: c-family/c-attribs.c:2344
 #, gcc-internal-format
 msgid "tls_model argument must be one of \"local-exec\", \"initial-exec\", \"local-dynamic\" or \"global-dynamic\""
 msgstr ""
 
-#: c-family/c-attribs.c:2353 c-family/c-attribs.c:2656
-#: c-family/c-attribs.c:3497 config/m32c/m32c.c:2944
+#: c-family/c-attribs.c:2364 c-family/c-attribs.c:2667
+#: c-family/c-attribs.c:3508 config/m32c/m32c.c:2944
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applies only to functions"
 msgstr "προειδοποίηση: το --pid=PID δεν υποστηρίζεται σε αυτό το σύστημα"
 
-#: c-family/c-attribs.c:2417
+#: c-family/c-attribs.c:2428
 #, gcc-internal-format
 msgid "alloc_size parameter outside range"
 msgstr ""
 
-#: c-family/c-attribs.c:2443
+#: c-family/c-attribs.c:2454
 #, gcc-internal-format
 msgid "alloc_align parameter outside range"
 msgstr ""
 
-#: c-family/c-attribs.c:2467
+#: c-family/c-attribs.c:2478
 #, fuzzy, gcc-internal-format
 msgid "assume_aligned parameter not integer constant"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: c-family/c-attribs.c:2595
+#: c-family/c-attribs.c:2606
 #, gcc-internal-format
 msgid "only %<inbranch%> and %<notinbranch%> flags are allowed for %<__simd__%> attribute"
 msgstr ""
 
-#: c-family/c-attribs.c:2662 c-family/c-attribs.c:3503
+#: c-family/c-attribs.c:2673 c-family/c-attribs.c:3514
 #, fuzzy, gcc-internal-format
 msgid "can%'t set %qE attribute after definition"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: c-family/c-attribs.c:2727
+#: c-family/c-attribs.c:2738
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute duplicated"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: c-family/c-attribs.c:2729
+#: c-family/c-attribs.c:2740
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute follows %qE"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: c-family/c-attribs.c:2828
+#: c-family/c-attribs.c:2839
 #, fuzzy, gcc-internal-format
 msgid "type was previously declared %qE"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: c-family/c-attribs.c:2841 cp/class.c:4397
+#: c-family/c-attribs.c:2852 cp/class.c:4401
 #, gcc-internal-format
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
 msgstr ""
 
-#: c-family/c-attribs.c:2899
+#: c-family/c-attribs.c:2910
 #, fuzzy, gcc-internal-format
 msgid "%qE argument not an identifier"
 msgstr "διπλός προσδιοριστής μηνύματος"
 
-#: c-family/c-attribs.c:2910
+#: c-family/c-attribs.c:2921
 #, fuzzy, gcc-internal-format
 msgid "%qD is not compatible with %qD"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: c-family/c-attribs.c:2913
+#: c-family/c-attribs.c:2924
 #, fuzzy, gcc-internal-format
 msgid "%qE argument is not a function"
 msgstr "πάρα πολλά ορίσματα"
 
-#: c-family/c-attribs.c:2961
+#: c-family/c-attribs.c:2972
 #, fuzzy, gcc-internal-format
 msgid "deprecated message is not a string"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c-family/c-attribs.c:3002
+#: c-family/c-attribs.c:3013
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute ignored for %qE"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: c-family/c-attribs.c:3065
+#: c-family/c-attribs.c:3076
 #, fuzzy, gcc-internal-format
 msgid "invalid vector type for attribute %qE"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 
-#: c-family/c-attribs.c:3071 ada/gcc-interface/utils.c:3896
+#: c-family/c-attribs.c:3082 ada/gcc-interface/utils.c:3899
 #, gcc-internal-format
 msgid "vector size not an integral multiple of component size"
 msgstr ""
 
-#: c-family/c-attribs.c:3077 ada/gcc-interface/utils.c:3903
+#: c-family/c-attribs.c:3088 ada/gcc-interface/utils.c:3906
 #, gcc-internal-format
 msgid "zero vector size"
 msgstr ""
 
-#: c-family/c-attribs.c:3085
+#: c-family/c-attribs.c:3096
 #, gcc-internal-format
 msgid "number of components of the vector not a power of two"
 msgstr ""
 
-#: c-family/c-attribs.c:3118 ada/gcc-interface/utils.c:6092
+#: c-family/c-attribs.c:3129 ada/gcc-interface/utils.c:6098
 #, gcc-internal-format
 msgid "nonnull attribute without arguments on a non-prototype"
 msgstr ""
 
-#: c-family/c-attribs.c:3137 ada/gcc-interface/utils.c:6106
+#: c-family/c-attribs.c:3148 ada/gcc-interface/utils.c:6112
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument has invalid operand number (argument %lu)"
 msgstr ""
 
-#: c-family/c-attribs.c:3159 ada/gcc-interface/utils.c:6128
+#: c-family/c-attribs.c:3170 ada/gcc-interface/utils.c:6134
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument with out-of-range operand number (argument %lu, operand %lu)"
 msgstr ""
 
-#: c-family/c-attribs.c:3168 ada/gcc-interface/utils.c:6137
+#: c-family/c-attribs.c:3179 ada/gcc-interface/utils.c:6143
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument references non-pointer operand (argument %lu, operand %lu)"
 msgstr ""
 
-#: c-family/c-attribs.c:3208
+#: c-family/c-attribs.c:3219
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute ignored on objects of type %qT"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: c-family/c-attribs.c:3216
+#: c-family/c-attribs.c:3227
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute does not apply to functions"
 msgstr "προειδοποίηση: το --pid=PID δεν υποστηρίζεται σε αυτό το σύστημα"
 
-#: c-family/c-attribs.c:3273
+#: c-family/c-attribs.c:3284
 #, fuzzy, gcc-internal-format
 msgid "cleanup argument not an identifier"
 msgstr "διπλός προσδιοριστής μηνύματος"
 
-#: c-family/c-attribs.c:3280
+#: c-family/c-attribs.c:3291
 #, fuzzy, gcc-internal-format
 msgid "cleanup argument not a function"
 msgstr "πάρα πολλά ορίσματα"
 
-#: c-family/c-attribs.c:3317
+#: c-family/c-attribs.c:3328
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute requires prototypes with named arguments"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: c-family/c-attribs.c:3325
+#: c-family/c-attribs.c:3336
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only applies to variadic functions"
 msgstr "προειδοποίηση: το --pid=PID δεν υποστηρίζεται σε αυτό το σύστημα"
 
-#: c-family/c-attribs.c:3341 ada/gcc-interface/utils.c:6179
+#: c-family/c-attribs.c:3352 ada/gcc-interface/utils.c:6185
 #, fuzzy, gcc-internal-format
 msgid "requested position is not an integer constant"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: c-family/c-attribs.c:3349 ada/gcc-interface/utils.c:6186
+#: c-family/c-attribs.c:3360 ada/gcc-interface/utils.c:6192
 #, gcc-internal-format
 msgid "requested position is less than zero"
 msgstr ""
 
-#: c-family/c-attribs.c:3404
+#: c-family/c-attribs.c:3415
 #, gcc-internal-format
 msgid "empty string in attribute %<target%>"
 msgstr ""
 
-#: c-family/c-attribs.c:3520
+#: c-family/c-attribs.c:3531
 #, fuzzy, gcc-internal-format
 msgid "returns_nonnull attribute on a function not returning a pointer"
 msgstr "`return' χωρίς τιμή, σε συνάρτηση που επιστρέφει μη-κενό"
 
-#: c-family/c-attribs.c:3535
+#: c-family/c-attribs.c:3546
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is only valid on %<struct%> type"
 msgstr "προειδοποίηση: το --pid=PID δεν υποστηρίζεται σε αυτό το σύστημα"
@@ -25184,12 +25210,12 @@
 msgid "__builtin_shuffle argument vector(s) inner type must have the same size as inner type of the mask"
 msgstr ""
 
-#: c-family/c-common.c:1262 c-family/c-warn.c:1194
+#: c-family/c-common.c:1262 c-family/c-warn.c:1202
 #, fuzzy, gcc-internal-format
 msgid "unsigned conversion from %qT to %qT changes value from %qE to %qE"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: c-family/c-common.c:1267 c-family/c-warn.c:1202
+#: c-family/c-common.c:1267 c-family/c-warn.c:1210
 #, fuzzy, gcc-internal-format
 msgid "unsigned conversion from %qT to %qT changes the value of %qE"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
@@ -25327,7 +25353,7 @@
 msgid "suggest parentheses around assignment used as truth value"
 msgstr ""
 
-#: c-family/c-common.c:3518 c/c-decl.c:4325 c/c-decl.c:6430 c/c-typeck.c:14177
+#: c-family/c-common.c:3518 c/c-decl.c:4325 c/c-decl.c:6450 c/c-typeck.c:14182
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr "μη έγκυρος αριθμός από γραμμές"
@@ -25407,7 +25433,7 @@
 msgid "duplicate case value"
 msgstr "διπλός αριθμός μηνύματος"
 
-#: c-family/c-common.c:4867 c-family/c-warn.c:2216
+#: c-family/c-common.c:4867 c-family/c-warn.c:2225
 #, fuzzy, gcc-internal-format
 msgid "previously used here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
@@ -25452,193 +25478,193 @@
 msgid "missing sentinel in function call"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το αρχείο fifo `%s'"
 
-#: c-family/c-common.c:5411
+#: c-family/c-common.c:5409
 #, gcc-internal-format, gfc-internal-format
 msgid "null argument where non-null required (argument %lu)"
 msgstr ""
 
-#: c-family/c-common.c:5506 c-family/c-common.c:5553
+#: c-family/c-common.c:5504 c-family/c-common.c:5551
 #, gcc-internal-format
 msgid "bad option %qs to attribute %<optimize%>"
 msgstr ""
 
-#: c-family/c-common.c:5509 c-family/c-common.c:5557
+#: c-family/c-common.c:5507 c-family/c-common.c:5555
 #, gcc-internal-format
 msgid "bad option %qs to pragma %<optimize%>"
 msgstr ""
 
-#: c-family/c-common.c:5589
+#: c-family/c-common.c:5587
 #, gcc-internal-format
 msgid "%<fallthrough%> attribute specified multiple times"
 msgstr ""
 
-#: c-family/c-common.c:5593
+#: c-family/c-common.c:5591
 #, gcc-internal-format
 msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr ""
 
-#: c-family/c-common.c:5733 c-family/c-common.c:6485 c-family/c-common.c:6558
+#: c-family/c-common.c:5731 c-family/c-common.c:6477 c-family/c-common.c:6550
 #: c/c-typeck.c:3555
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr "πολύ λίγα ορίσματα"
 
-#: c-family/c-common.c:5738 c-family/c-common.c:6584 c/c-typeck.c:3284
+#: c-family/c-common.c:5736 c-family/c-common.c:6576 c/c-typeck.c:3284
 #, fuzzy, gcc-internal-format
 msgid "too many arguments to function %qE"
 msgstr "πάρα πολλά ορίσματα"
 
-#: c-family/c-common.c:5769
+#: c-family/c-common.c:5767
 #, fuzzy, gcc-internal-format
 msgid "third argument to function %qE must be a constant integer"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: c-family/c-common.c:5794
+#: c-family/c-common.c:5792
 #, gcc-internal-format
 msgid "second argument to function %qE must be a constant integer power of 2 between %qi and %qu bits"
 msgstr ""
 
-#: c-family/c-common.c:5815 c-family/c-common.c:5859
+#: c-family/c-common.c:5813 c-family/c-common.c:5857
 #, fuzzy, gcc-internal-format
 msgid "non-floating-point argument in call to function %qE"
 msgstr "πάρα πολλά ορίσματα"
 
-#: c-family/c-common.c:5838
+#: c-family/c-common.c:5836
 #, fuzzy, gcc-internal-format
 msgid "non-floating-point arguments in call to function %qE"
 msgstr "πάρα πολλά ορίσματα"
 
-#: c-family/c-common.c:5852
+#: c-family/c-common.c:5850
 #, fuzzy, gcc-internal-format
 msgid "non-const integer argument %u in call to function %qE"
 msgstr "πάρα πολλά ορίσματα"
 
-#: c-family/c-common.c:5872
+#: c-family/c-common.c:5870
 #, fuzzy, gcc-internal-format
 msgid "non-integer argument 3 in call to function %qE"
 msgstr "πάρα πολλά ορίσματα"
 
-#: c-family/c-common.c:5889 c-family/c-common.c:5925
+#: c-family/c-common.c:5887 c-family/c-common.c:5923
 #, gcc-internal-format
 msgid "argument %u in call to function %qE does not have integral type"
 msgstr ""
 
-#: c-family/c-common.c:5896
+#: c-family/c-common.c:5894
 #, gcc-internal-format
 msgid "argument 3 in call to function %qE does not have pointer to integral type"
 msgstr ""
 
-#: c-family/c-common.c:5902
+#: c-family/c-common.c:5900
 #, fuzzy, gcc-internal-format
 msgid "argument 3 in call to function %qE has pointer to enumerated type"
 msgstr "μη πλήρης εγγραφή"
 
-#: c-family/c-common.c:5908
+#: c-family/c-common.c:5906
 #, gcc-internal-format
 msgid "argument 3 in call to function %qE has pointer to boolean type"
 msgstr ""
 
-#: c-family/c-common.c:5931
+#: c-family/c-common.c:5929
 #, fuzzy, gcc-internal-format
 msgid "argument 3 in call to function %qE has enumerated type"
 msgstr "μη πλήρης εγγραφή"
 
-#: c-family/c-common.c:5937
+#: c-family/c-common.c:5935
 #, gcc-internal-format
 msgid "argument 3 in call to function %qE has boolean type"
 msgstr ""
 
-#: c-family/c-common.c:6184
+#: c-family/c-common.c:6183
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to static data member %qD"
 msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
 
-#: c-family/c-common.c:6189
+#: c-family/c-common.c:6188
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> when %<operator[]%> is overloaded"
 msgstr ""
 
-#: c-family/c-common.c:6196
+#: c-family/c-common.c:6195
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to a non constant address"
 msgstr ""
 
-#: c-family/c-common.c:6209
+#: c-family/c-common.c:6208
 #, fuzzy, gcc-internal-format
 msgid "attempt to take address of bit-field structure member %qD"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το αρχείο fifo `%s'"
 
-#: c-family/c-common.c:6261
+#: c-family/c-common.c:6260
 #, gcc-internal-format
 msgid "index %E denotes an offset greater than size of %qT"
 msgstr ""
 
-#: c-family/c-common.c:6427 cp/init.c:3004 cp/init.c:3023
+#: c-family/c-common.c:6419 cp/init.c:3020 cp/init.c:3039
 #, fuzzy, gcc-internal-format
 msgid "size of array is too large"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: c-family/c-common.c:6517
+#: c-family/c-common.c:6509
 #, fuzzy, gcc-internal-format
 msgid "operand type %qT is incompatible with argument %d of %qE"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: c-family/c-common.c:6651
+#: c-family/c-common.c:6643
 #, fuzzy, gcc-internal-format
 msgid "incorrect number of arguments to function %qE"
 msgstr "πολύ λίγα ορίσματα"
 
-#: c-family/c-common.c:6665
+#: c-family/c-common.c:6657
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qE must be a non-void pointer type"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: c-family/c-common.c:6674
+#: c-family/c-common.c:6666
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a constant size type"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: c-family/c-common.c:6685
+#: c-family/c-common.c:6677
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a nonzero size object"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: c-family/c-common.c:6706
+#: c-family/c-common.c:6698
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must be a pointer type"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: c-family/c-common.c:6714
+#: c-family/c-common.c:6706
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must be a pointer to a constant size type"
 msgstr "%s μετατρέπει ακέραιο σε δείκτη χωρίς μετατροπέα"
 
-#: c-family/c-common.c:6720
+#: c-family/c-common.c:6712
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a function"
 msgstr "%s μετατρέπει ακέραιο σε δείκτη χωρίς μετατροπέα"
 
-#: c-family/c-common.c:6728
+#: c-family/c-common.c:6720
 #, fuzzy, gcc-internal-format
 msgid "size mismatch in argument %d of %qE"
 msgstr "Λείπει παράμετρος για `%s'"
 
-#: c-family/c-common.c:6740
+#: c-family/c-common.c:6732
 #, fuzzy, gcc-internal-format
 msgid "non-integer memory model argument %d of %qE"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: c-family/c-common.c:6753
+#: c-family/c-common.c:6745
 #, fuzzy, gcc-internal-format
 msgid "invalid memory model argument %d of %qE"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: c-family/c-common.c:7672
+#: c-family/c-common.c:7664
 #, fuzzy, gcc-internal-format
 msgid "index value is out of bound"
 msgstr "Η παράμετρος κινητής υποδιαστολής δεν είναι έγκυρη: %s"
 
-#: c-family/c-common.c:7714 c-family/c-common.c:7763 c-family/c-common.c:7779
+#: c-family/c-common.c:7706 c-family/c-common.c:7755 c-family/c-common.c:7771
 #, fuzzy, gcc-internal-format
 msgid "conversion of scalar %qT to vector %qT involves truncation"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
@@ -25645,22 +25671,22 @@
 
 #. Reject arguments that are built-in functions with
 #. no library fallback.
-#: c-family/c-common.c:7867
+#: c-family/c-common.c:7859
 #, gcc-internal-format
 msgid "built-in function %qE must be directly called"
 msgstr ""
 
-#: c-family/c-common.c:7889 c/c-decl.c:6177
+#: c-family/c-common.c:7881 c/c-decl.c:6197
 #, fuzzy, gcc-internal-format
 msgid "size of array %qE is too large"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: c-family/c-common.c:7891 c/c-decl.c:6180
+#: c-family/c-common.c:7883 c/c-decl.c:6200
 #, fuzzy, gcc-internal-format
 msgid "size of unnamed array is too large"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: c-family/c-common.c:7921
+#: c-family/c-common.c:7913
 #, gcc-internal-format
 msgid "environment variable SOURCE_DATE_EPOCH must expand to a non-negative integer less than or equal to %wd"
 msgstr ""
@@ -26182,7 +26208,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr ""
 
-#: c-family/c-omp.c:557 cp/semantics.c:8186
+#: c-family/c-omp.c:557 cp/semantics.c:8189
 #, fuzzy, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
@@ -26197,22 +26223,22 @@
 msgid "%qE is not initialized"
 msgstr "έχει παραληφθεί το αρχείο προορισμού"
 
-#: c-family/c-omp.c:599 cp/semantics.c:8076
+#: c-family/c-omp.c:599 cp/semantics.c:8079
 #, fuzzy, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "Η λειτουργία δεν επιτρέπεται"
 
-#: c-family/c-omp.c:704 cp/semantics.c:7732
+#: c-family/c-omp.c:704 cp/semantics.c:7735
 #, fuzzy, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "μη έγκυρο όνομα μήνα"
 
-#: c-family/c-omp.c:711 cp/semantics.c:8082
+#: c-family/c-omp.c:711 cp/semantics.c:8085
 #, fuzzy, gcc-internal-format
 msgid "missing increment expression"
 msgstr "παράληψη ορίσματος αρχείου"
 
-#: c-family/c-omp.c:775 cp/semantics.c:7847
+#: c-family/c-omp.c:775 cp/semantics.c:7850
 #, fuzzy, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "Μη έγκυρη κανονική έκφραση"
@@ -26267,112 +26293,127 @@
 msgid "%<-Wabi=1%> is not supported, using =2"
 msgstr "Η λειτουργία δεν υποστηρίζεται"
 
-#: c-family/c-opts.c:612 fortran/cpp.c:350
+#: c-family/c-opts.c:610 fortran/cpp.c:350
 #, gcc-internal-format
 msgid "output filename specified twice"
 msgstr ""
 
-#: c-family/c-opts.c:799
+#: c-family/c-opts.c:797
 #, gcc-internal-format
 msgid "-fexcess-precision=standard for C++"
 msgstr ""
 
-#: c-family/c-opts.c:834
+#: c-family/c-opts.c:832
 #, gcc-internal-format
 msgid "-fno-gnu89-inline is only supported in GNU99 or C99 mode"
 msgstr ""
 
-#: c-family/c-opts.c:880
+#: c-family/c-opts.c:878
 #, gcc-internal-format
 msgid "-Wformat-y2k ignored without -Wformat"
 msgstr ""
 
-#: c-family/c-opts.c:882
+#: c-family/c-opts.c:880
 #, gcc-internal-format
 msgid "-Wformat-extra-args ignored without -Wformat"
 msgstr ""
 
-#: c-family/c-opts.c:884
+#: c-family/c-opts.c:882
 #, gcc-internal-format
 msgid "-Wformat-zero-length ignored without -Wformat"
 msgstr ""
 
-#: c-family/c-opts.c:886
+#: c-family/c-opts.c:884
 #, gcc-internal-format
 msgid "-Wformat-nonliteral ignored without -Wformat"
 msgstr ""
 
-#: c-family/c-opts.c:888
+#: c-family/c-opts.c:886
 #, gcc-internal-format
 msgid "-Wformat-contains-nul ignored without -Wformat"
 msgstr ""
 
-#: c-family/c-opts.c:890
+#: c-family/c-opts.c:888
 #, gcc-internal-format
 msgid "-Wformat-security ignored without -Wformat"
 msgstr ""
 
-#: c-family/c-opts.c:928
+#: c-family/c-opts.c:918
 #, fuzzy, gcc-internal-format
 msgid "%<-fabi-compat-version=1%> is not supported, using =2"
 msgstr "Η λειτουργία δεν υποστηρίζεται"
 
-#: c-family/c-opts.c:988
+#: c-family/c-opts.c:944
+#, gcc-internal-format
+msgid "-Wabi won't warn about anything"
+msgstr ""
+
+#: c-family/c-opts.c:946
+#, gcc-internal-format
+msgid "-Wabi warns about differences from the most up-to-date ABI, which is also used by default"
+msgstr ""
+
+#: c-family/c-opts.c:949
+#, gcc-internal-format
+msgid "use e.g. -Wabi=11 to warn about changes from GCC 7"
+msgstr ""
+
+#: c-family/c-opts.c:1003
 #, fuzzy, gcc-internal-format
 msgid "external TLS initialization functions not supported on this target"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: c-family/c-opts.c:1001
+#: c-family/c-opts.c:1016
 #, gcc-internal-format, gfc-internal-format
 msgid "too many filenames given.  Type %s --help for usage"
 msgstr ""
 
-#: c-family/c-opts.c:1016
+#: c-family/c-opts.c:1031
 #, fuzzy, gcc-internal-format
 msgid "opening output file %s: %m"
 msgstr "αδυναμία ανοίγματος αρχείου εξόδου `%s'"
 
-#: c-family/c-opts.c:1036
+#: c-family/c-opts.c:1051
 #, gcc-internal-format, gfc-internal-format
 msgid "the \"%s\" debug format cannot be used with pre-compiled headers"
 msgstr ""
 
-#: c-family/c-opts.c:1190
+#: c-family/c-opts.c:1205
 #, gcc-internal-format
 msgid "opening dependency file %s: %m"
 msgstr ""
 
-#: c-family/c-opts.c:1201
+#: c-family/c-opts.c:1216
 #, gcc-internal-format
 msgid "closing dependency file %s: %m"
 msgstr ""
 
-#: c-family/c-opts.c:1204
+#: c-family/c-opts.c:1219
 #, fuzzy, gcc-internal-format
 msgid "when writing output to %s: %m"
 msgstr "σφάλμα εγγραφής %s"
 
-#: c-family/c-opts.c:1284
+#: c-family/c-opts.c:1299
 #, gcc-internal-format
 msgid "to generate dependencies you must specify either -M or -MM"
 msgstr ""
 
-#: c-family/c-opts.c:1307
+#: c-family/c-opts.c:1322
 #, gcc-internal-format
 msgid "-MG may only be used with -M or -MM"
 msgstr ""
 
-#: c-family/c-opts.c:1340
+#: c-family/c-opts.c:1355
 #, gcc-internal-format
 msgid "-fdirectives-only is incompatible with -Wunused_macros"
 msgstr ""
 
-#: c-family/c-opts.c:1342
+#: c-family/c-opts.c:1357
 #, gcc-internal-format
 msgid "-fdirectives-only is incompatible with -traditional"
 msgstr ""
 
-#: c-family/c-opts.c:1534
+#: c-family/c-opts.c:1549
 #, gcc-internal-format
 msgid "too late for # directive to set debug directory"
 msgstr ""
@@ -26763,725 +26804,725 @@
 msgid "wrong type argument to %s"
 msgstr "λάθος αριθμός ορισμάτων"
 
-#: c-family/c-warn.c:53 c-family/c-warn.c:66 cp/constexpr.c:1847
+#: c-family/c-warn.c:54 c-family/c-warn.c:67 cp/constexpr.c:1847
 #: cp/constexpr.c:4099
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr ""
 
-#: c-family/c-warn.c:93
+#: c-family/c-warn.c:94
 #, fuzzy, gcc-internal-format
 msgid "integer overflow in expression %qE of type %qT results in %qE"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: c-family/c-warn.c:95
+#: c-family/c-warn.c:96
 #, fuzzy, gcc-internal-format
 msgid "integer overflow in expression of type %qT results in %qE"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: c-family/c-warn.c:101
+#: c-family/c-warn.c:102
 #, fuzzy, gcc-internal-format
 msgid "floating point overflow in expression %qE of type %qT results in %qE"
 msgstr "Εξαίρεση κινητής υποδιαστολής"
 
-#: c-family/c-warn.c:103
+#: c-family/c-warn.c:104
 #, fuzzy, gcc-internal-format
 msgid "floating point overflow in expression of type %qT results in %qE"
 msgstr "Εξαίρεση κινητής υποδιαστολής"
 
-#: c-family/c-warn.c:109
+#: c-family/c-warn.c:110
 #, gcc-internal-format
 msgid "fixed-point overflow in expression %qE of type %qT results in %qE"
 msgstr ""
 
-#: c-family/c-warn.c:111
+#: c-family/c-warn.c:112
 #, fuzzy, gcc-internal-format
 msgid "fixed-point overflow in expression of type %qT results in %qE"
 msgstr "Εξαίρεση κινητής υποδιαστολής"
 
-#: c-family/c-warn.c:117
+#: c-family/c-warn.c:118
 #, fuzzy, gcc-internal-format
 msgid "vector overflow in expression %qE of type %qT results in %qE"
 msgstr "Εξαίρεση κινητής υποδιαστολής"
 
-#: c-family/c-warn.c:119
+#: c-family/c-warn.c:120
 #, fuzzy, gcc-internal-format
 msgid "vector overflow in expression of type %qT results in %qE"
 msgstr "Εξαίρεση κινητής υποδιαστολής"
 
-#: c-family/c-warn.c:126
+#: c-family/c-warn.c:127
 #, gcc-internal-format
 msgid "complex integer overflow in expression %qE of type %qT results in %qE"
 msgstr ""
 
-#: c-family/c-warn.c:128
+#: c-family/c-warn.c:129
 #, gcc-internal-format
 msgid "complex integer overflow in expression of type %qT results in %qE"
 msgstr ""
 
-#: c-family/c-warn.c:132
+#: c-family/c-warn.c:133
 #, fuzzy, gcc-internal-format
 msgid "complex floating point overflow in expression %qE of type %qT results in %qE"
 msgstr "Εξαίρεση κινητής υποδιαστολής"
 
-#: c-family/c-warn.c:134
+#: c-family/c-warn.c:135
 #, fuzzy, gcc-internal-format
 msgid "complex floating point overflow in expression of type %qT results in %qE"
 msgstr "Εξαίρεση κινητής υποδιαστολής"
 
-#: c-family/c-warn.c:216
+#: c-family/c-warn.c:217
 #, gcc-internal-format
 msgid "logical %<or%> applied to non-boolean constant"
 msgstr ""
 
-#: c-family/c-warn.c:219
+#: c-family/c-warn.c:220
 #, gcc-internal-format
 msgid "logical %<and%> applied to non-boolean constant"
 msgstr ""
 
-#: c-family/c-warn.c:289
+#: c-family/c-warn.c:290
 #, gcc-internal-format
 msgid "logical %<or%> of collectively exhaustive tests is always true"
 msgstr ""
 
-#: c-family/c-warn.c:293
+#: c-family/c-warn.c:294
 #, gcc-internal-format
 msgid "logical %<and%> of mutually exclusive tests is always false"
 msgstr ""
 
-#: c-family/c-warn.c:303
+#: c-family/c-warn.c:304
 #, gcc-internal-format
 msgid "logical %<or%> of equal expressions"
 msgstr ""
 
-#: c-family/c-warn.c:306
+#: c-family/c-warn.c:307
 #, gcc-internal-format
 msgid "logical %<and%> of equal expressions"
 msgstr ""
 
-#: c-family/c-warn.c:384
+#: c-family/c-warn.c:385
 #, gcc-internal-format
 msgid "bitwise comparison always evaluates to false"
 msgstr ""
 
-#: c-family/c-warn.c:387
+#: c-family/c-warn.c:388
 #, gcc-internal-format
 msgid "bitwise comparison always evaluates to true"
 msgstr ""
 
-#: c-family/c-warn.c:441
+#: c-family/c-warn.c:442
 #, gcc-internal-format
 msgid "self-comparison always evaluates to true"
 msgstr ""
 
-#: c-family/c-warn.c:444
+#: c-family/c-warn.c:445
 #, gcc-internal-format
 msgid "self-comparison always evaluates to false"
 msgstr ""
 
-#: c-family/c-warn.c:494
+#: c-family/c-warn.c:495
 #, gcc-internal-format
 msgid "logical not is only applied to the left hand side of comparison"
 msgstr ""
 
-#: c-family/c-warn.c:502
+#: c-family/c-warn.c:503
 #, gcc-internal-format
 msgid "add parentheses around left hand side expression to silence this warning"
 msgstr ""
 
-#: c-family/c-warn.c:636
+#: c-family/c-warn.c:637
 #, gcc-internal-format
 msgid "type-punning to incomplete type might break strict-aliasing rules"
 msgstr ""
 
-#: c-family/c-warn.c:654
+#: c-family/c-warn.c:655
 #, gcc-internal-format
 msgid "dereferencing type-punned pointer will break strict-aliasing rules"
 msgstr ""
 
-#: c-family/c-warn.c:662 c-family/c-warn.c:680
+#: c-family/c-warn.c:663 c-family/c-warn.c:681
 #, gcc-internal-format
 msgid "dereferencing type-punned pointer might break strict-aliasing rules"
 msgstr ""
 
-#: c-family/c-warn.c:803
+#: c-family/c-warn.c:811
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to use the size of the destination?"
 msgstr ""
 
-#: c-family/c-warn.c:834
+#: c-family/c-warn.c:842
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the destination; did you mean to remove the addressof?"
 msgstr ""
 
-#: c-family/c-warn.c:841
+#: c-family/c-warn.c:849
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the destination; did you mean to provide an explicit length?"
 msgstr ""
 
-#: c-family/c-warn.c:846
+#: c-family/c-warn.c:854
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the destination; did you mean to dereference it?"
 msgstr ""
 
-#: c-family/c-warn.c:858
+#: c-family/c-warn.c:866
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the destination; expected %qT or an explicit length"
 msgstr ""
 
-#: c-family/c-warn.c:874
+#: c-family/c-warn.c:882
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to remove the addressof?"
 msgstr ""
 
-#: c-family/c-warn.c:881
+#: c-family/c-warn.c:889
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to provide an explicit length?"
 msgstr ""
 
-#: c-family/c-warn.c:886
+#: c-family/c-warn.c:894
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to dereference it?"
 msgstr ""
 
-#: c-family/c-warn.c:898
+#: c-family/c-warn.c:906
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the source; expected %qT or an explicit length"
 msgstr ""
 
-#: c-family/c-warn.c:914
+#: c-family/c-warn.c:922
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the first source; did you mean to remove the addressof?"
 msgstr ""
 
-#: c-family/c-warn.c:921
+#: c-family/c-warn.c:929
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the first source; did you mean to provide an explicit length?"
 msgstr ""
 
-#: c-family/c-warn.c:926
+#: c-family/c-warn.c:934
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the first source; did you mean to dereference it?"
 msgstr ""
 
-#: c-family/c-warn.c:938
+#: c-family/c-warn.c:946
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the first source; expected %qT or an explicit length"
 msgstr ""
 
-#: c-family/c-warn.c:954
+#: c-family/c-warn.c:962
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the second source; did you mean to remove the addressof?"
 msgstr ""
 
-#: c-family/c-warn.c:961
+#: c-family/c-warn.c:969
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the second source; did you mean to provide an explicit length?"
 msgstr ""
 
-#: c-family/c-warn.c:966
+#: c-family/c-warn.c:974
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the second source; did you mean to dereference it?"
 msgstr ""
 
-#: c-family/c-warn.c:978
+#: c-family/c-warn.c:986
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the second source; expected %qT or an explicit length"
 msgstr ""
 
-#: c-family/c-warn.c:1007 c-family/c-warn.c:1014
+#: c-family/c-warn.c:1015 c-family/c-warn.c:1022
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%>-qualified parameter type %qT of %q+D"
 msgstr "Μη έγκυρη προτεραιότητα `%s'"
 
-#: c-family/c-warn.c:1024
+#: c-family/c-warn.c:1032
 #, fuzzy, gcc-internal-format
 msgid "first argument of %q+D should be %<int%>"
 msgstr "το πρώτο όρισμα της `%s' πρέπει να είναι `int'"
 
-#: c-family/c-warn.c:1033
+#: c-family/c-warn.c:1041
 #, fuzzy, gcc-internal-format
 msgid "second argument of %q+D should be %<char **%>"
 msgstr "το δεύτερο όρισμα της `%s' πρέπει να είναι `char **'"
 
-#: c-family/c-warn.c:1042
+#: c-family/c-warn.c:1050
 #, fuzzy, gcc-internal-format
 msgid "third argument of %q+D should probably be %<char **%>"
 msgstr "το τρίτο όρισμα της `%s' πρέπει να είναι `char **'"
 
-#: c-family/c-warn.c:1053
+#: c-family/c-warn.c:1061
 #, fuzzy, gcc-internal-format
 msgid "%q+D takes only zero or two arguments"
 msgstr "η `%s' παίρνει είτε κανένα είτε δύο ορίσματα"
 
-#: c-family/c-warn.c:1057
+#: c-family/c-warn.c:1065
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared as variadic function"
 msgstr "%s: διπλός ορισμός έκδοσης κατηγορίας"
 
-#: c-family/c-warn.c:1099
+#: c-family/c-warn.c:1107
 #, fuzzy, gcc-internal-format
 msgid "conversion to %qT from boolean expression"
 msgstr "μη πλήρης εγγραφή"
 
-#: c-family/c-warn.c:1117 c-family/c-warn.c:1192
+#: c-family/c-warn.c:1125 c-family/c-warn.c:1200
 #, fuzzy, gcc-internal-format
 msgid "conversion from %qT to %qT changes value from %qE to %qE"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: c-family/c-warn.c:1121 c-family/c-warn.c:1200
+#: c-family/c-warn.c:1129 c-family/c-warn.c:1208
 #, fuzzy, gcc-internal-format
 msgid "conversion from %qT to %qT changes the value of %qE"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: c-family/c-warn.c:1141
+#: c-family/c-warn.c:1149
 #, fuzzy, gcc-internal-format
 msgid "conversion from %qT to %qT discards imaginary component"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: c-family/c-warn.c:1153
+#: c-family/c-warn.c:1161
 #, fuzzy, gcc-internal-format
 msgid "conversion from %qT to %qT may change value"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: c-family/c-warn.c:1213 c-family/c-warn.c:1230 c-family/c-warn.c:1247
+#: c-family/c-warn.c:1221 c-family/c-warn.c:1238 c-family/c-warn.c:1255
 #, fuzzy, gcc-internal-format
 msgid "overflow in conversion from %qT to %qT changes value from %qE to %qE"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: c-family/c-warn.c:1218 c-family/c-warn.c:1235 c-family/c-warn.c:1252
+#: c-family/c-warn.c:1226 c-family/c-warn.c:1243 c-family/c-warn.c:1260
 #, fuzzy, gcc-internal-format
 msgid "overflow in conversion from %qT to %qT changes the value of %qE"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: c-family/c-warn.c:1282
+#: c-family/c-warn.c:1290
 #, fuzzy, gcc-internal-format
 msgid "case value %qs not in enumerated type"
 msgstr "Δεν είναι δυνατόν να βρεθεί ο τύπος του επεξεργαστή."
 
-#: c-family/c-warn.c:1287
+#: c-family/c-warn.c:1295
 #, fuzzy, gcc-internal-format
 msgid "case value %qs not in enumerated type %qT"
 msgstr "Δεν είναι δυνατόν να βρεθεί ο τύπος του επεξεργαστή."
 
-#: c-family/c-warn.c:1348
+#: c-family/c-warn.c:1356
 #, fuzzy, gcc-internal-format
 msgid "switch missing default case"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: c-family/c-warn.c:1393
+#: c-family/c-warn.c:1401
 #, gcc-internal-format
 msgid "switch condition has boolean value"
 msgstr ""
 
-#: c-family/c-warn.c:1466
+#: c-family/c-warn.c:1474
 #, fuzzy, gcc-internal-format
 msgid "enumeration value %qE not handled in switch"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: c-family/c-warn.c:1494
+#: c-family/c-warn.c:1502
 #, gcc-internal-format
 msgid "the omitted middle operand in ?: will always be %<true%>, suggest explicit middle operand"
 msgstr ""
 
-#: c-family/c-warn.c:1515
+#: c-family/c-warn.c:1523
 #, fuzzy, gcc-internal-format
 msgid "assignment of member %qD in read-only object"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: c-family/c-warn.c:1517
+#: c-family/c-warn.c:1525
 #, fuzzy, gcc-internal-format
 msgid "increment of member %qD in read-only object"
 msgstr "Μη αναγνωρίσιμη μεταβλητή `%s'"
 
-#: c-family/c-warn.c:1519
+#: c-family/c-warn.c:1527
 #, fuzzy, gcc-internal-format
 msgid "decrement of member %qD in read-only object"
 msgstr "Μη αναγνωρίσιμη μεταβλητή `%s'"
 
-#: c-family/c-warn.c:1521
+#: c-family/c-warn.c:1529
 #, gcc-internal-format
 msgid "member %qD in read-only object used as %<asm%> output"
 msgstr ""
 
-#: c-family/c-warn.c:1525
+#: c-family/c-warn.c:1533
 #, fuzzy, gcc-internal-format
 msgid "assignment of read-only member %qD"
 msgstr "Μη αναγνωρίσιμη μεταβλητή `%s'"
 
-#: c-family/c-warn.c:1526
+#: c-family/c-warn.c:1534
 #, fuzzy, gcc-internal-format
 msgid "increment of read-only member %qD"
 msgstr "Μη αναγνωρίσιμη μεταβλητή `%s'"
 
-#: c-family/c-warn.c:1527
+#: c-family/c-warn.c:1535
 #, fuzzy, gcc-internal-format
 msgid "decrement of read-only member %qD"
 msgstr "Μη αναγνωρίσιμη μεταβλητή `%s'"
 
-#: c-family/c-warn.c:1528
+#: c-family/c-warn.c:1536
 #, gcc-internal-format
 msgid "read-only member %qD used as %<asm%> output"
 msgstr ""
 
-#: c-family/c-warn.c:1532
+#: c-family/c-warn.c:1540
 #, fuzzy, gcc-internal-format
 msgid "assignment of read-only variable %qD"
 msgstr "Μη αναγνωρίσιμη μεταβλητή `%s'"
 
-#: c-family/c-warn.c:1533
+#: c-family/c-warn.c:1541
 #, fuzzy, gcc-internal-format
 msgid "increment of read-only variable %qD"
 msgstr "Μη αναγνωρίσιμη μεταβλητή `%s'"
 
-#: c-family/c-warn.c:1534
+#: c-family/c-warn.c:1542
 #, fuzzy, gcc-internal-format
 msgid "decrement of read-only variable %qD"
 msgstr "Μη αναγνωρίσιμη μεταβλητή `%s'"
 
-#: c-family/c-warn.c:1535
+#: c-family/c-warn.c:1543
 #, gcc-internal-format
 msgid "read-only variable %qD used as %<asm%> output"
 msgstr ""
 
-#: c-family/c-warn.c:1538
+#: c-family/c-warn.c:1546
 #, fuzzy, gcc-internal-format
 msgid "assignment of read-only parameter %qD"
 msgstr "Μη αναγνωρίσιμη μεταβλητή `%s'"
 
-#: c-family/c-warn.c:1539
+#: c-family/c-warn.c:1547
 #, fuzzy, gcc-internal-format
 msgid "increment of read-only parameter %qD"
 msgstr "Μη αναγνωρίσιμη μεταβλητή `%s'"
 
-#: c-family/c-warn.c:1540
+#: c-family/c-warn.c:1548
 #, fuzzy, gcc-internal-format
 msgid "decrement of read-only parameter %qD"
 msgstr "Μη αναγνωρίσιμη μεταβλητή `%s'"
 
-#: c-family/c-warn.c:1541
+#: c-family/c-warn.c:1549
 #, gcc-internal-format
 msgid "read-only parameter %qD use as %<asm%> output"
 msgstr ""
 
-#: c-family/c-warn.c:1546
+#: c-family/c-warn.c:1554
 #, fuzzy, gcc-internal-format
 msgid "assignment of read-only named return value %qD"
 msgstr "Μη αναγνωρίσιμη μεταβλητή `%s'"
 
-#: c-family/c-warn.c:1548
+#: c-family/c-warn.c:1556
 #, fuzzy, gcc-internal-format
 msgid "increment of read-only named return value %qD"
 msgstr "Μη αναγνωρίσιμη μεταβλητή `%s'"
 
-#: c-family/c-warn.c:1550
+#: c-family/c-warn.c:1558
 #, fuzzy, gcc-internal-format
 msgid "decrement of read-only named return value %qD"
 msgstr "Μη αναγνωρίσιμη μεταβλητή `%s'"
 
-#: c-family/c-warn.c:1552
+#: c-family/c-warn.c:1560
 #, gcc-internal-format
 msgid "read-only named return value %qD used as %<asm%>output"
 msgstr ""
 
-#: c-family/c-warn.c:1557
+#: c-family/c-warn.c:1565
 #, fuzzy, gcc-internal-format
 msgid "assignment of function %qD"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: c-family/c-warn.c:1558
+#: c-family/c-warn.c:1566
 #, fuzzy, gcc-internal-format
 msgid "increment of function %qD"
 msgstr "πάρα πολλά ορίσματα"
 
-#: c-family/c-warn.c:1559
+#: c-family/c-warn.c:1567
 #, fuzzy, gcc-internal-format
 msgid "decrement of function %qD"
 msgstr "Προειδοποίηση: Πολύ λίγα ορίσματα στο εσωδομημένο `%s'"
 
-#: c-family/c-warn.c:1560
+#: c-family/c-warn.c:1568
 #, gcc-internal-format
 msgid "function %qD used as %<asm%> output"
 msgstr ""
 
-#: c-family/c-warn.c:1563 c/c-typeck.c:4762
+#: c-family/c-warn.c:1571 c/c-typeck.c:4767
 #, fuzzy, gcc-internal-format
 msgid "assignment of read-only location %qE"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: c-family/c-warn.c:1564 c/c-typeck.c:4765
+#: c-family/c-warn.c:1572 c/c-typeck.c:4770
 #, fuzzy, gcc-internal-format
 msgid "increment of read-only location %qE"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: c-family/c-warn.c:1565 c/c-typeck.c:4768
+#: c-family/c-warn.c:1573 c/c-typeck.c:4773
 #, fuzzy, gcc-internal-format
 msgid "decrement of read-only location %qE"
 msgstr "Μη αναγνωρίσιμη μεταβλητή `%s'"
 
-#: c-family/c-warn.c:1566
+#: c-family/c-warn.c:1574
 #, gcc-internal-format
 msgid "read-only location %qE used as %<asm%> output"
 msgstr ""
 
-#: c-family/c-warn.c:1580
+#: c-family/c-warn.c:1588
 #, fuzzy, gcc-internal-format
 msgid "lvalue required as left operand of assignment"
 msgstr "Η παράμετρος κινητής υποδιαστολής δεν είναι έγκυρη: %s"
 
-#: c-family/c-warn.c:1583
+#: c-family/c-warn.c:1591
 #, gcc-internal-format
 msgid "lvalue required as increment operand"
 msgstr ""
 
-#: c-family/c-warn.c:1586
+#: c-family/c-warn.c:1594
 #, gcc-internal-format
 msgid "lvalue required as decrement operand"
 msgstr ""
 
-#: c-family/c-warn.c:1589
+#: c-family/c-warn.c:1597
 #, gcc-internal-format
 msgid "lvalue required as unary %<&%> operand"
 msgstr ""
 
-#: c-family/c-warn.c:1592
+#: c-family/c-warn.c:1600
 #, fuzzy, gcc-internal-format
 msgid "lvalue required in asm statement"
 msgstr "Μη έγκυρη παράμετρος"
 
-#: c-family/c-warn.c:1609
+#: c-family/c-warn.c:1617
 #, fuzzy, gcc-internal-format
 msgid "invalid type argument (have %qT)"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: c-family/c-warn.c:1613
+#: c-family/c-warn.c:1621
 #, fuzzy, gcc-internal-format
 msgid "invalid type argument of array indexing (have %qT)"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: c-family/c-warn.c:1618
+#: c-family/c-warn.c:1626
 #, fuzzy, gcc-internal-format
 msgid "invalid type argument of unary %<*%> (have %qT)"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: c-family/c-warn.c:1623
+#: c-family/c-warn.c:1631
 #, fuzzy, gcc-internal-format
 msgid "invalid type argument of %<->%> (have %qT)"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: c-family/c-warn.c:1628
+#: c-family/c-warn.c:1636
 #, fuzzy, gcc-internal-format
 msgid "invalid type argument of %<->*%> (have %qT)"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: c-family/c-warn.c:1633
+#: c-family/c-warn.c:1641
 #, fuzzy, gcc-internal-format
 msgid "invalid type argument of implicit conversion (have %qT)"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: c-family/c-warn.c:1654
+#: c-family/c-warn.c:1662
 #, gcc-internal-format
 msgid "array subscript has type %<char%>"
 msgstr ""
 
-#: c-family/c-warn.c:1689 c-family/c-warn.c:1692
+#: c-family/c-warn.c:1697 c-family/c-warn.c:1700
 #, gcc-internal-format
 msgid "suggest parentheses around %<+%> inside %<<<%>"
 msgstr ""
 
-#: c-family/c-warn.c:1695 c-family/c-warn.c:1698
+#: c-family/c-warn.c:1703 c-family/c-warn.c:1706
 #, gcc-internal-format
 msgid "suggest parentheses around %<-%> inside %<<<%>"
 msgstr ""
 
-#: c-family/c-warn.c:1704 c-family/c-warn.c:1707
+#: c-family/c-warn.c:1712 c-family/c-warn.c:1715
 #, gcc-internal-format
 msgid "suggest parentheses around %<+%> inside %<>>%>"
 msgstr ""
 
-#: c-family/c-warn.c:1710 c-family/c-warn.c:1713
+#: c-family/c-warn.c:1718 c-family/c-warn.c:1721
 #, gcc-internal-format
 msgid "suggest parentheses around %<-%> inside %<>>%>"
 msgstr ""
 
-#: c-family/c-warn.c:1719 c-family/c-warn.c:1722
+#: c-family/c-warn.c:1727 c-family/c-warn.c:1730
 #, gcc-internal-format
 msgid "suggest parentheses around %<&&%> within %<||%>"
 msgstr ""
 
-#: c-family/c-warn.c:1729 c-family/c-warn.c:1733
+#: c-family/c-warn.c:1737 c-family/c-warn.c:1741
 #, gcc-internal-format
 msgid "suggest parentheses around arithmetic in operand of %<|%>"
 msgstr ""
 
-#: c-family/c-warn.c:1737 c-family/c-warn.c:1740
+#: c-family/c-warn.c:1745 c-family/c-warn.c:1748
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<|%>"
 msgstr ""
 
-#: c-family/c-warn.c:1745
+#: c-family/c-warn.c:1753
 #, gcc-internal-format
 msgid "suggest parentheses around operand of %<!%> or change %<|%> to %<||%> or %<!%> to %<~%>"
 msgstr ""
 
-#: c-family/c-warn.c:1753 c-family/c-warn.c:1757
+#: c-family/c-warn.c:1761 c-family/c-warn.c:1765
 #, gcc-internal-format
 msgid "suggest parentheses around arithmetic in operand of %<^%>"
 msgstr ""
 
-#: c-family/c-warn.c:1761 c-family/c-warn.c:1764
+#: c-family/c-warn.c:1769 c-family/c-warn.c:1772
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<^%>"
 msgstr ""
 
-#: c-family/c-warn.c:1770 c-family/c-warn.c:1773
+#: c-family/c-warn.c:1778 c-family/c-warn.c:1781
 #, gcc-internal-format
 msgid "suggest parentheses around %<+%> in operand of %<&%>"
 msgstr ""
 
-#: c-family/c-warn.c:1776 c-family/c-warn.c:1779
+#: c-family/c-warn.c:1784 c-family/c-warn.c:1787
 #, gcc-internal-format
 msgid "suggest parentheses around %<-%> in operand of %<&%>"
 msgstr ""
 
-#: c-family/c-warn.c:1783 c-family/c-warn.c:1786
+#: c-family/c-warn.c:1791 c-family/c-warn.c:1794
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<&%>"
 msgstr ""
 
-#: c-family/c-warn.c:1791
+#: c-family/c-warn.c:1799
 #, gcc-internal-format
 msgid "suggest parentheses around operand of %<!%> or change %<&%> to %<&&%> or %<!%> to %<~%>"
 msgstr ""
 
-#: c-family/c-warn.c:1798 c-family/c-warn.c:1801
+#: c-family/c-warn.c:1806 c-family/c-warn.c:1809
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<==%>"
 msgstr ""
 
-#: c-family/c-warn.c:1806 c-family/c-warn.c:1809
+#: c-family/c-warn.c:1814 c-family/c-warn.c:1817
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<!=%>"
 msgstr ""
 
-#: c-family/c-warn.c:1819 c-family/c-warn.c:1825
+#: c-family/c-warn.c:1827 c-family/c-warn.c:1833
 #, gcc-internal-format
 msgid "comparisons like %<X<=Y<=Z%> do not have their mathematical meaning"
 msgstr ""
 
-#: c-family/c-warn.c:1841
+#: c-family/c-warn.c:1849
 #, fuzzy, gcc-internal-format
 msgid "label %q+D defined but not used"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: c-family/c-warn.c:1843
+#: c-family/c-warn.c:1851
 #, fuzzy, gcc-internal-format
 msgid "label %q+D declared but not defined"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: c-family/c-warn.c:1866
+#: c-family/c-warn.c:1874
 #, gcc-internal-format
 msgid "division by zero"
 msgstr "διαίρεση με μηδέν"
 
-#: c-family/c-warn.c:1886
+#: c-family/c-warn.c:1894
 #, gcc-internal-format
 msgid "%<memset%> used with constant zero length parameter; this could be due to transposed parameters"
 msgstr ""
 
-#: c-family/c-warn.c:1909
+#: c-family/c-warn.c:1918
 #, gcc-internal-format
 msgid "%<memset%> used with length equal to number of elements without multiplication by element size"
 msgstr ""
 
-#: c-family/c-warn.c:1948 c/c-typeck.c:11499 c/c-typeck.c:11667
+#: c-family/c-warn.c:1957 c/c-typeck.c:11504 c/c-typeck.c:11672
 #: cp/typeck.c:5048
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr ""
 
-#: c-family/c-warn.c:1998
+#: c-family/c-warn.c:2007
 #, gcc-internal-format
 msgid "comparison of integer expressions of different signedness: %qT and %qT"
 msgstr ""
 
-#: c-family/c-warn.c:2051
+#: c-family/c-warn.c:2060
 #, gcc-internal-format
 msgid "promoted ~unsigned is always non-zero"
 msgstr ""
 
-#: c-family/c-warn.c:2054
+#: c-family/c-warn.c:2063
 #, gcc-internal-format
 msgid "comparison of promoted ~unsigned with constant"
 msgstr ""
 
-#: c-family/c-warn.c:2064
+#: c-family/c-warn.c:2073
 #, gcc-internal-format
 msgid "comparison of promoted ~unsigned with unsigned"
 msgstr ""
 
-#: c-family/c-warn.c:2118
+#: c-family/c-warn.c:2127
 #, fuzzy, gcc-internal-format
 msgid "unused parameter %qD"
 msgstr "άγνωστος χαρακτήρας `%s'"
 
-#: c-family/c-warn.c:2180
+#: c-family/c-warn.c:2189
 #, gcc-internal-format
 msgid "typedef %qD locally defined but not used"
 msgstr ""
 
-#: c-family/c-warn.c:2215
+#: c-family/c-warn.c:2224
 #, fuzzy, gcc-internal-format
 msgid "duplicated %<if%> condition"
 msgstr "διπλό κλειδί"
 
-#: c-family/c-warn.c:2244
+#: c-family/c-warn.c:2253
 #, gcc-internal-format
 msgid "optimization attribute on %qD follows definition but the attribute doesn%'t match"
 msgstr ""
 
-#: c-family/c-warn.c:2254
+#: c-family/c-warn.c:2261
 #, fuzzy, gcc-internal-format
 msgid "inline declaration of %qD follows declaration with attribute %qs"
 msgstr "αυτή είναι η θέση του πρώτου ορισμού"
 
-#: c-family/c-warn.c:2259
+#: c-family/c-warn.c:2266
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q+D with attribute %qs follows inline declaration"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: c-family/c-warn.c:2306
+#: c-family/c-warn.c:2313
 #, gcc-internal-format
 msgid "result of %qE requires %u bits to represent, but %qT only has %u bits"
 msgstr ""
 
-#: c-family/c-warn.c:2344 c-family/c-warn.c:2368
+#: c-family/c-warn.c:2351 c-family/c-warn.c:2375
 #, gcc-internal-format
 msgid "comparison of constant %qE with boolean expression is always false"
 msgstr ""
 
-#: c-family/c-warn.c:2347 c-family/c-warn.c:2365
+#: c-family/c-warn.c:2354 c-family/c-warn.c:2372
 #, gcc-internal-format
 msgid "comparison of constant %qE with boolean expression is always true"
 msgstr ""
 
-#: c-family/c-warn.c:2415
+#: c-family/c-warn.c:2422
 msgid "passing argument %i to restrict-qualified parameter aliases with argument %Z"
 msgid_plural "passing argument %i to restrict-qualified parameter aliases with arguments %Z"
 msgstr[0] ""
 msgstr[1] ""
 
-#: c-family/c-warn.c:2480 c/c-typeck.c:5288 cp/call.c:5365
+#: c-family/c-warn.c:2487 c/c-typeck.c:5293 cp/call.c:5365
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr ""
 
-#: c-family/c-warn.c:2586
+#: c-family/c-warn.c:2593
 #, gcc-internal-format
 msgid "macro expands to multiple statements"
 msgstr ""
 
-#: c-family/c-warn.c:2587
+#: c-family/c-warn.c:2594
 #, gcc-internal-format
 msgid "some parts of macro expansion are not guarded by this %qs clause"
 msgstr ""
@@ -27496,7 +27537,7 @@
 msgid "too many input files"
 msgstr "υπερβολικά πολλά αρχεία εισόδου"
 
-#: common/config/aarch64/aarch64-common.c:319 config/aarch64/aarch64.c:10686
+#: common/config/aarch64/aarch64-common.c:319 config/aarch64/aarch64.c:10702
 #, fuzzy, gcc-internal-format
 msgid "unknown value %qs for -mcpu"
 msgstr "Ακατάλληλη τιμή στο ai_flags"
@@ -27527,13 +27568,13 @@
 msgstr ""
 
 #: common/config/arm/arm-common.c:322 common/config/arm/arm-common.c:376
-#: common/config/arm/arm-common.c:423 config/aarch64/aarch64.c:10639
+#: common/config/arm/arm-common.c:423 config/aarch64/aarch64.c:10655
 #, fuzzy, gcc-internal-format
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
 #: common/config/arm/arm-common.c:325 common/config/arm/arm-common.c:379
-#: common/config/arm/arm-common.c:426 config/aarch64/aarch64.c:10642
+#: common/config/arm/arm-common.c:426 config/aarch64/aarch64.c:10658
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
@@ -28013,12 +28054,12 @@
 msgid "profiler support for VxWorks"
 msgstr ""
 
-#: config/aarch64/aarch64-builtins.c:1109 config/arm/arm-builtins.c:2262
+#: config/aarch64/aarch64-builtins.c:1109 config/arm/arm-builtins.c:2272
 #, fuzzy, gcc-internal-format
 msgid "%Kargument %d must be a constant immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/aarch64/aarch64-builtins.c:1180 config/arm/arm-builtins.c:2492
+#: config/aarch64/aarch64-builtins.c:1180 config/arm/arm-builtins.c:2502
 #, fuzzy, gcc-internal-format
 msgid "%Klane index must be a constant immediate"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
@@ -28028,128 +28069,128 @@
 msgid "%Ktotal size and element size must be a non-zero constant immediate"
 msgstr ""
 
-#: config/aarch64/aarch64.c:1053
+#: config/aarch64/aarch64.c:1069
 #, fuzzy, gcc-internal-format
 msgid "%qs is incompatible with %s %s"
 msgstr "μη έγκυρο δικαίωμα"
 
-#: config/aarch64/aarch64.c:1055
+#: config/aarch64/aarch64.c:1071
 #, gcc-internal-format
 msgid "%qs feature modifier is incompatible with %s %s"
 msgstr ""
 
-#: config/aarch64/aarch64.c:3772
+#: config/aarch64/aarch64.c:3788
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10287
+#: config/aarch64/aarch64.c:10303
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown flag passed in -moverride=%s (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10331
+#: config/aarch64/aarch64.c:10347
 #, gcc-internal-format, gfc-internal-format
 msgid "%s string ill-formed\n"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10388
+#: config/aarch64/aarch64.c:10404
 #, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10406
+#: config/aarch64/aarch64.c:10422
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown tuning option (%s)"
 msgstr "άγνωστο σετ `%s'"
 
-#: config/aarch64/aarch64.c:10683
+#: config/aarch64/aarch64.c:10699
 #, gcc-internal-format
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10690
+#: config/aarch64/aarch64.c:10706
 #, fuzzy, gcc-internal-format
 msgid "invalid feature modifier in %<-mcpu=%s%>"
 msgstr "Η παράμετρος κινητής υποδιαστολής δεν είναι έγκυρη: %s"
 
-#: config/aarch64/aarch64.c:10717
+#: config/aarch64/aarch64.c:10733
 #, gcc-internal-format
 msgid "missing arch name in %<-march=%s%>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10720
+#: config/aarch64/aarch64.c:10736
 #, fuzzy, gcc-internal-format
 msgid "unknown value %qs for -march"
 msgstr "Ακατάλληλη τιμή στο ai_flags"
 
-#: config/aarch64/aarch64.c:10724
+#: config/aarch64/aarch64.c:10740
 #, fuzzy, gcc-internal-format
 msgid "invalid feature modifier in %<-march=%s%>"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: config/aarch64/aarch64.c:10750
+#: config/aarch64/aarch64.c:10766
 #, fuzzy, gcc-internal-format
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr "πάρα πολλές δηλώσεις μετατροπής στην κατάληξη"
 
-#: config/aarch64/aarch64.c:10753
+#: config/aarch64/aarch64.c:10769
 #, fuzzy, gcc-internal-format
 msgid "unknown value %qs for -mtune"
 msgstr "Ακατάλληλη τιμή στο ai_flags"
 
-#: config/aarch64/aarch64.c:10871 config/arm/arm.c:3173
+#: config/aarch64/aarch64.c:10887 config/arm/arm.c:3173
 #, gcc-internal-format, gfc-internal-format
 msgid "switch -mcpu=%s conflicts with -march=%s switch"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10906
+#: config/aarch64/aarch64.c:10922
 #, fuzzy, gcc-internal-format
 msgid "assembler does not support -mabi=ilp32"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: config/aarch64/aarch64.c:10913
+#: config/aarch64/aarch64.c:10929
 #, gcc-internal-format
 msgid "return address signing is only supported for -mabi=lp64"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10975
+#: config/aarch64/aarch64.c:10991
 #, gcc-internal-format
 msgid "code model %qs with -f%s"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11138
+#: config/aarch64/aarch64.c:11154
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11141
+#: config/aarch64/aarch64.c:11157
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11145 config/aarch64/aarch64.c:11184
-#: config/aarch64/aarch64.c:11257
+#: config/aarch64/aarch64.c:11161 config/aarch64/aarch64.c:11200
+#: config/aarch64/aarch64.c:11273
 #, gcc-internal-format
 msgid "invalid value (\"%s\") in %<target()%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11177
+#: config/aarch64/aarch64.c:11193
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11180
+#: config/aarch64/aarch64.c:11196
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11213
+#: config/aarch64/aarch64.c:11229
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"tune=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11253
+#: config/aarch64/aarch64.c:11269
 #, gcc-internal-format
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr ""
@@ -28156,49 +28197,49 @@
 
 # src/dfa.c:569 src/dfa.c:583 src/dfa.c:587
 # src/dfa.c:577 src/dfa.c:591 src/dfa.c:595
-#: config/aarch64/aarch64.c:11306 config/aarch64/aarch64.c:11483
+#: config/aarch64/aarch64.c:11322 config/aarch64/aarch64.c:11499
 #, fuzzy, gcc-internal-format
 msgid "malformed %<target()%> pragma or attribute"
 msgstr "κακοσχηματισμένος μετρητής επανάληψης"
 
-#: config/aarch64/aarch64.c:11354
+#: config/aarch64/aarch64.c:11370
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11362
+#: config/aarch64/aarch64.c:11378
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11416
+#: config/aarch64/aarch64.c:11432
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11473 config/arm/arm.c:30742
-#: config/i386/i386.c:5440 config/powerpcspe/powerpcspe.c:39760
-#: config/rs6000/rs6000.c:36904 config/s390/s390.c:15746
+#: config/aarch64/aarch64.c:11489 config/arm/arm.c:30742
+#: config/i386/i386.c:5443 config/powerpcspe/powerpcspe.c:39760
+#: config/rs6000/rs6000.c:36960 config/s390/s390.c:15746
 #, fuzzy, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: config/aarch64/aarch64.c:11500
+#: config/aarch64/aarch64.c:11516
 #, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11509
+#: config/aarch64/aarch64.c:11525
 #, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13571
+#: config/aarch64/aarch64.c:13587
 #, gcc-internal-format
 msgid "%Klane %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/aarch64/aarch64.c:13573
+#: config/aarch64/aarch64.c:13589
 #, fuzzy, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr "%s: αριθμός γραμμής έξω από τα όρια"
@@ -28258,8 +28299,8 @@
 msgid "bad value %qs for -mmemory-latency"
 msgstr "Ακατάλληλη τιμή στο ai_flags"
 
-#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6526
-#: config/arc/arc.c:6800 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
+#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6517
+#: config/arc/arc.c:6791 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
 #: config/tilepro/tilepro.c:3108
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -28370,11 +28411,11 @@
 #: config/arm/arm.c:7029 config/avr/avr.c:9718 config/avr/avr.c:9734
 #: config/bfin/bfin.c:4705 config/bfin/bfin.c:4766 config/bfin/bfin.c:4795
 #: config/epiphany/epiphany.c:491 config/h8300/h8300.c:5459
-#: config/i386/i386.c:6452 config/i386/i386.c:12479 config/i386/i386.c:41424
-#: config/i386/i386.c:41474 config/i386/i386.c:41544 config/m68k/m68k.c:780
+#: config/i386/i386.c:6455 config/i386/i386.c:12482 config/i386/i386.c:41418
+#: config/i386/i386.c:41468 config/i386/i386.c:41538 config/m68k/m68k.c:780
 #: config/mcore/mcore.c:3070 config/nvptx/nvptx.c:4611
 #: config/powerpcspe/powerpcspe.c:35785 config/riscv/riscv.c:2698
-#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:32982
+#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:33038
 #: config/rx/rx.c:2719 config/rx/rx.c:2745 config/s390/s390.c:1056
 #: config/s390/s390.c:1143 config/sh/sh.c:8428 config/sh/sh.c:8446
 #: config/sh/sh.c:8470 config/sh/sh.c:8541 config/sh/sh.c:8564
@@ -28384,133 +28425,133 @@
 msgid "%qE attribute only applies to functions"
 msgstr "προειδοποίηση: το --pid=PID δεν υποστηρίζεται σε αυτό το σύστημα"
 
-#: config/arc/arc.c:6425
+#: config/arc/arc.c:6416
 #, gcc-internal-format
 msgid "__builtin_arc_aligned with non-constant alignment"
 msgstr ""
 
-#: config/arc/arc.c:6433
+#: config/arc/arc.c:6424
 #, fuzzy, gcc-internal-format
 msgid "invalid alignment value for __builtin_arc_aligned"
 msgstr "Η αλυσίδα μορφής δεν είναι έγκυρη: `%s'"
 
-#: config/arc/arc.c:6596
+#: config/arc/arc.c:6587
 #, gcc-internal-format
 msgid "operand 1 should be an unsigned 3-bit immediate"
 msgstr ""
 
-#: config/arc/arc.c:6637 config/arc/arc.c:6734
+#: config/arc/arc.c:6628 config/arc/arc.c:6725
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6670 config/arc/arc.c:6702
+#: config/arc/arc.c:6661 config/arc/arc.c:6693
 #, gcc-internal-format
 msgid "operand 1 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6674 config/arc/arc.c:6706
+#: config/arc/arc.c:6665 config/arc/arc.c:6697
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 8-bit value"
 msgstr ""
 
-#: config/arc/arc.c:6738
+#: config/arc/arc.c:6729
 #, gcc-internal-format
 msgid "operand 3 should be an unsigned 8-bit value"
 msgstr ""
 
-#: config/arc/arc.c:6771
+#: config/arc/arc.c:6762
 #, gcc-internal-format
 msgid "operand 4 should be an unsigned 8-bit value (0-255)"
 msgstr ""
 
-#: config/arc/arc.c:6775
+#: config/arc/arc.c:6766
 #, gcc-internal-format
 msgid "operand 3 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6782
+#: config/arc/arc.c:6773
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (subreg 0-7)"
 msgstr ""
 
-#: config/arc/arc.c:6785
+#: config/arc/arc.c:6776
 #, gcc-internal-format
 msgid "operand 2 should be an even 3-bit value (subreg 0,2,4,6)"
 msgstr ""
 
-#: config/arc/arc.c:6832
+#: config/arc/arc.c:6823
 #, gcc-internal-format, gfc-internal-format
 msgid "builtin requires an immediate for operand %d"
 msgstr ""
 
-#: config/arc/arc.c:6837
+#: config/arc/arc.c:6828
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "operand %d should be a 6 bit unsigned immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/arc/arc.c:6841
+#: config/arc/arc.c:6832
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "operand %d should be a 8 bit unsigned immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/arc/arc.c:6845
+#: config/arc/arc.c:6836
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "operand %d should be a 3 bit unsigned immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/arc/arc.c:6848
+#: config/arc/arc.c:6839
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown builtin immediate operand type for operand %d"
 msgstr ""
 
-#: config/arc/arc.c:6899
+#: config/arc/arc.c:6890
 #, gcc-internal-format
 msgid "register number must be a compile-time constant. Try giving higher optimization levels"
 msgstr ""
 
-#: config/arc/arc.c:7685
+#: config/arc/arc.c:7747
 #, gcc-internal-format
 msgid "Insn addresses not set after shorten_branches"
 msgstr ""
 
-#: config/arc/arc.c:7894
+#: config/arc/arc.c:7956
 #, gcc-internal-format
 msgid "insn addresses not freed"
 msgstr ""
 
-#: config/arc/arc.c:10682
+#: config/arc/arc.c:10670
 #, gcc-internal-format
 msgid "%qE attribute only valid for ARCv2 architecture"
 msgstr ""
 
-#: config/arc/arc.c:10690 config/arc/arc.c:10729
+#: config/arc/arc.c:10678 config/arc/arc.c:10717
 #, fuzzy, gcc-internal-format
 msgid "argument of %qE attribute is missing"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/arc/arc.c:10701 config/arc/arc.c:10740 config/arc/arc.c:10842
+#: config/arc/arc.c:10689 config/arc/arc.c:10728 config/arc/arc.c:10830
 #: config/avr/avr.c:9790
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute allows only an integer constant argument"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: config/arc/arc.c:10721
+#: config/arc/arc.c:10709
 #, gcc-internal-format
 msgid "%qE attribute only valid for ARC EM architecture"
 msgstr ""
 
-#: config/arc/arc.c:10776
+#: config/arc/arc.c:10764
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only applies to types"
 msgstr "προειδοποίηση: το --pid=PID δεν υποστηρίζεται σε αυτό το σύστημα"
 
-#: config/arc/arc.c:10782
+#: config/arc/arc.c:10770
 #, fuzzy, gcc-internal-format
 msgid "argument of %qE attribute ignored"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: config/arc/arc.c:10832 config/avr/avr.c:9777 config/bfin/bfin.c:4827
+#: config/arc/arc.c:10820 config/avr/avr.c:9777 config/bfin/bfin.c:4827
 #: config/i386/winnt.c:63 config/msp430/msp430.c:2018
 #: config/nvptx/nvptx.c:4634
 #, fuzzy, gcc-internal-format
@@ -28517,174 +28558,174 @@
 msgid "%qE attribute only applies to variables"
 msgstr "προειδοποίηση: το --pid=PID δεν υποστηρίζεται σε αυτό το σύστημα"
 
-#: config/arm/arm-builtins.c:2370
+#: config/arm/arm-builtins.c:2380
 #, fuzzy, gcc-internal-format
 msgid "this builtin is not supported for this target"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/arm/arm-builtins.c:2475
+#: config/arm/arm-builtins.c:2485
 #, gcc-internal-format
 msgid "You must enable NEON instructions (e.g. -mfloat-abi=softfp -mfpu=neon) to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2513
+#: config/arm/arm-builtins.c:2523
 #, gcc-internal-format
 msgid "You must enable VFP instructions to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2573
+#: config/arm/arm-builtins.c:2583
 #, gcc-internal-format
 msgid "You must enable crypto instructions (e.g. include -mfloat-abi=softfp -mfpu=crypto-neon...) to use these intrinsics."
 msgstr ""
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:2633 config/arm/arm-builtins.c:2737
+#: config/arm/arm-builtins.c:2643 config/arm/arm-builtins.c:2747
 #, fuzzy, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: config/arm/arm-builtins.c:2641 config/arm/arm-builtins.c:2686
-#: config/arm/arm-builtins.c:2744 config/arm/arm-builtins.c:2753
+#: config/arm/arm-builtins.c:2651 config/arm/arm-builtins.c:2696
+#: config/arm/arm-builtins.c:2754 config/arm/arm-builtins.c:2763
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2646 config/arm/arm-builtins.c:2755
+#: config/arm/arm-builtins.c:2656 config/arm/arm-builtins.c:2765
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2651 config/arm/arm-builtins.c:2757
+#: config/arm/arm-builtins.c:2661 config/arm/arm-builtins.c:2767
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2823
+#: config/arm/arm-builtins.c:2833
 #, fuzzy, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: config/arm/arm-builtins.c:2828
+#: config/arm/arm-builtins.c:2838
 #, gcc-internal-format
 msgid "the range of mask should be in 0 to 255"
 msgstr ""
 
-#: config/arm/arm-builtins.c:3016
+#: config/arm/arm-builtins.c:3026
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3018
+#: config/arm/arm-builtins.c:3028
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3020
+#: config/arm/arm-builtins.c:3030
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3022
+#: config/arm/arm-builtins.c:3032
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3028
+#: config/arm/arm-builtins.c:3038
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3030
+#: config/arm/arm-builtins.c:3040
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3035
+#: config/arm/arm-builtins.c:3045
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3037
+#: config/arm/arm-builtins.c:3047
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3039
+#: config/arm/arm-builtins.c:3049
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3041
+#: config/arm/arm-builtins.c:3051
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3043
+#: config/arm/arm-builtins.c:3053
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3045
+#: config/arm/arm-builtins.c:3055
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3047
+#: config/arm/arm-builtins.c:3057
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3049
+#: config/arm/arm-builtins.c:3059
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3051
+#: config/arm/arm-builtins.c:3061
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3053
+#: config/arm/arm-builtins.c:3063
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3055
+#: config/arm/arm-builtins.c:3065
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3057
+#: config/arm/arm-builtins.c:3067
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3059
+#: config/arm/arm-builtins.c:3069
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3061
+#: config/arm/arm-builtins.c:3071
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3063
+#: config/arm/arm-builtins.c:3073
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3065
+#: config/arm/arm-builtins.c:3075
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3067
+#: config/arm/arm-builtins.c:3077
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3069
+#: config/arm/arm-builtins.c:3079
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr ""
@@ -29599,551 +29640,551 @@
 msgid "can%'t set position in PCH file: %m"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: config/i386/i386.c:3177
+#: config/i386/i386.c:3180
 #, fuzzy, gcc-internal-format
 msgid "wrong argument %qs to option %qs"
 msgstr "πάρα πολλά ορίσματα"
 
-#: config/i386/i386.c:3183
+#: config/i386/i386.c:3186
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr ""
 
-#: config/i386/i386.c:3193
+#: config/i386/i386.c:3196
 #, fuzzy, gcc-internal-format
 msgid "wrong strategy name %qs specified for option %qs"
 msgstr "Εγγραφή ονομάτων των επιλεγμένων λέξεων-κλειδιών"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3219
+#: config/i386/i386.c:3222
 #, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386.c:3232
+#: config/i386/i386.c:3235
 #, fuzzy, gcc-internal-format
 msgid "unknown alignment %qs specified for option %qs"
 msgstr "μόνο ένα όρισμα μπορεί να δηλωθεί"
 
-#: config/i386/i386.c:3242
+#: config/i386/i386.c:3245
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr ""
 
-#: config/i386/i386.c:3249
+#: config/i386/i386.c:3252
 #, fuzzy, gcc-internal-format
 msgid "too many size ranges specified in option %qs"
 msgstr "πάρα πολλά ορίσματα"
 
-#: config/i386/i386.c:3302
+#: config/i386/i386.c:3305
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown parameter to option -mtune-ctrl: %s"
 msgstr "άγνωστος χαρακτήρας `%s'"
 
-#: config/i386/i386.c:3726
+#: config/i386/i386.c:3729
 #, fuzzy, gcc-internal-format
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/i386/i386.c:3775
+#: config/i386/i386.c:3778
 #, gcc-internal-format
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr ""
 
-#: config/i386/i386.c:3777
+#: config/i386/i386.c:3780
 #, gcc-internal-format
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
 msgstr ""
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3804
+#: config/i386/i386.c:3807
 #, gcc-internal-format
 msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgstr ""
 
-#: config/i386/i386.c:3821
+#: config/i386/i386.c:3824
 #, fuzzy, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/i386/i386.c:3833
+#: config/i386/i386.c:3836
 #, fuzzy, gcc-internal-format
 msgid "-mabi=ms not supported with X32 ABI"
 msgstr "Το ai_family δεν υποστηρίζεται"
 
-#: config/i386/i386.c:3851 config/i386/i386.c:3860 config/i386/i386.c:3872
-#: config/i386/i386.c:3883 config/i386/i386.c:3894
+#: config/i386/i386.c:3854 config/i386/i386.c:3863 config/i386/i386.c:3875
+#: config/i386/i386.c:3886 config/i386/i386.c:3897
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/i386/i386.c:3863 config/i386/i386.c:3875
+#: config/i386/i386.c:3866 config/i386/i386.c:3878
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/i386/i386.c:3881 config/i386/i386.c:3890 config/i386/i386.c:5213
+#: config/i386/i386.c:3884 config/i386/i386.c:3893 config/i386/i386.c:5216
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/i386/i386.c:3918
+#: config/i386/i386.c:3921
 #, fuzzy, gcc-internal-format
 msgid "-masm=intel not supported in this configuration"
 msgstr "Η οικογένεια διευθύνσεων δεν υποστηρίζεται από την οικογένεια πρωτοκόλλου"
 
-#: config/i386/i386.c:3923
+#: config/i386/i386.c:3926
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "%s: η υποστήριξη εκσφαλμάτωσης δεν έχει συμπεριληφθεί στη μεταγλώττιση.\n"
 
-#: config/i386/i386.c:3932
+#: config/i386/i386.c:3935
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386.c:3934
+#: config/i386/i386.c:3937
 #, gcc-internal-format
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386.c:3941
+#: config/i386/i386.c:3944
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr ""
 
-#: config/i386/i386.c:3943
+#: config/i386/i386.c:3946
 #, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr ""
 
-#: config/i386/i386.c:3951 config/i386/i386.c:4265
+#: config/i386/i386.c:3954 config/i386/i386.c:4268
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr ""
 
-#: config/i386/i386.c:4197 config/i386/i386.c:4200
+#: config/i386/i386.c:4200 config/i386/i386.c:4203
 #, fuzzy, gcc-internal-format
 msgid "Intel MPX does not support x32"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: config/i386/i386.c:4205
+#: config/i386/i386.c:4208
 #, fuzzy, gcc-internal-format
 msgid "bad value (%qs) for %<-march=%> switch"
 msgstr "Ακατάλληλη τιμή στο ai_flags"
 
-#: config/i386/i386.c:4206
+#: config/i386/i386.c:4209
 #, fuzzy, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"arch=\")%> attribute"
 msgstr "Ακατάλληλη τιμή στο ai_flags"
 
-#: config/i386/i386.c:4228
+#: config/i386/i386.c:4231
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4230
+#: config/i386/i386.c:4233
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4235
+#: config/i386/i386.c:4238
 #, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr ""
 
-#: config/i386/i386.c:4236
+#: config/i386/i386.c:4239
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: config/i386/i386.c:4284
+#: config/i386/i386.c:4287
 #, fuzzy, gcc-internal-format
 msgid "bad value (%qs) for %<-mtune=%> switch"
 msgstr "Ακατάλληλη τιμή στο ai_flags"
 
-#: config/i386/i386.c:4285
+#: config/i386/i386.c:4288
 #, fuzzy, gcc-internal-format
 msgid "bad value (%qs) for %<target(\"tune=\")%> attribute"
 msgstr "Ακατάλληλη τιμή στο ai_flags"
 
-#: config/i386/i386.c:4305
+#: config/i386/i386.c:4308
 #, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4307
+#: config/i386/i386.c:4310
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4312
+#: config/i386/i386.c:4315
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: config/i386/i386.c:4313
+#: config/i386/i386.c:4316
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: config/i386/i386.c:4379
+#: config/i386/i386.c:4382
 #, gcc-internal-format
 msgid "-mregparm is ignored in 64-bit mode"
 msgstr ""
 
-#: config/i386/i386.c:4381
+#: config/i386/i386.c:4384
 #, gcc-internal-format
 msgid "-mregparm is ignored for Intel MCU psABI"
 msgstr ""
 
-#: config/i386/i386.c:4384
+#: config/i386/i386.c:4387
 #, gcc-internal-format, gfc-internal-format
 msgid "-mregparm=%d is not between 0 and %d"
 msgstr ""
 
-#: config/i386/i386.c:4417
+#: config/i386/i386.c:4420
 #, gcc-internal-format
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr ""
 
-#: config/i386/i386.c:4418
+#: config/i386/i386.c:4421
 #, gcc-internal-format
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr ""
 
-#: config/i386/i386.c:4497
+#: config/i386/i386.c:4500
 #, fuzzy, gcc-internal-format
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "το --no-dereference (-h) δεν υποστηρίζεται σε αυτό το σύστημα"
 
-#: config/i386/i386.c:4500
+#: config/i386/i386.c:4503
 #, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr ""
 
-#: config/i386/i386.c:4523
+#: config/i386/i386.c:4526
 #, gcc-internal-format, gfc-internal-format
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr ""
 
-#: config/i386/i386.c:4536
+#: config/i386/i386.c:4539
 #, fuzzy, gcc-internal-format
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "το --no-dereference (-h) δεν υποστηρίζεται σε αυτό το σύστημα"
 
-#: config/i386/i386.c:4539
+#: config/i386/i386.c:4542
 #, fuzzy, gcc-internal-format
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: config/i386/i386.c:4545
+#: config/i386/i386.c:4548
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386.c:4546
+#: config/i386/i386.c:4549
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386.c:4556
+#: config/i386/i386.c:4559
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr ""
 
-#: config/i386/i386.c:4563
+#: config/i386/i386.c:4566
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr ""
 
-#: config/i386/i386.c:4613
+#: config/i386/i386.c:4616
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr ""
 
-#: config/i386/i386.c:4615
+#: config/i386/i386.c:4618
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr ""
 
-#: config/i386/i386.c:4629
+#: config/i386/i386.c:4632
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr ""
 
-#: config/i386/i386.c:4631
+#: config/i386/i386.c:4634
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr ""
 
-#: config/i386/i386.c:4741
+#: config/i386/i386.c:4744
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr ""
 
-#: config/i386/i386.c:4744
+#: config/i386/i386.c:4747
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr ""
 
-#: config/i386/i386.c:4748
+#: config/i386/i386.c:4751
 #, gcc-internal-format
 msgid "-mcall-ms2sysv-xlogues isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386.c:4813 config/powerpcspe/powerpcspe.c:5663
+#: config/i386/i386.c:4816 config/powerpcspe/powerpcspe.c:5663
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown option for -mrecip=%s"
 msgstr "άγνωστο σετ `%s'"
 
-#: config/i386/i386.c:4870 config/powerpcspe/powerpcspe.c:5339
+#: config/i386/i386.c:4873 config/powerpcspe/powerpcspe.c:5339
 #, gcc-internal-format
 msgid "%qs is not a valid number in -mstack-protector-guard-offset="
 msgstr ""
 
-#: config/i386/i386.c:4875 config/powerpcspe/powerpcspe.c:5344
+#: config/i386/i386.c:4878 config/powerpcspe/powerpcspe.c:5344
 #, gcc-internal-format
 msgid "%qs is not a valid offset in -mstack-protector-guard-offset="
 msgstr ""
 
-#: config/i386/i386.c:4907 config/powerpcspe/powerpcspe.c:5356
+#: config/i386/i386.c:4910 config/powerpcspe/powerpcspe.c:5356
 #, gcc-internal-format
 msgid "%qs is not a valid base register in -mstack-protector-guard-reg="
 msgstr ""
 
-#: config/i386/i386.c:5506 config/i386/i386.c:5553 config/s390/s390.c:15812
+#: config/i386/i386.c:5509 config/i386/i386.c:5556 config/s390/s390.c:15812
 #: config/s390/s390.c:15862 config/s390/s390.c:15879
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr ""
 
-#: config/i386/i386.c:5534
+#: config/i386/i386.c:5537
 #, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr ""
 
-#: config/i386/i386.c:5837
+#: config/i386/i386.c:5840
 #, gcc-internal-format
 msgid "interrupt and naked attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5852
+#: config/i386/i386.c:5855
 #, gcc-internal-format
 msgid "Only DWARF debug format is supported for interrupt service routine."
 msgstr ""
 
-#: config/i386/i386.c:5901
+#: config/i386/i386.c:5904
 #, gcc-internal-format
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5913
+#: config/i386/i386.c:5916
 #, gcc-internal-format
 msgid "%<-mindirect-branch=thunk-extern%>, %<-fcf-protection=branch%> and %<-fcheck-pointer-bounds%> are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5949
+#: config/i386/i386.c:5952
 #, gcc-internal-format
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6047
+#: config/i386/i386.c:6050
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in %s service routine"
 msgstr ""
 
-#: config/i386/i386.c:6051
+#: config/i386/i386.c:6054
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in function with no_caller_saved_registers attribute"
 msgstr ""
 
-#: config/i386/i386.c:6465 config/i386/i386.c:6516
+#: config/i386/i386.c:6468 config/i386/i386.c:6519
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6470
+#: config/i386/i386.c:6473
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6477 config/i386/i386.c:41444
+#: config/i386/i386.c:6480 config/i386/i386.c:41438
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: config/i386/i386.c:6483
+#: config/i386/i386.c:6486
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "%s: οι τιμές του πεδίου `%s' δεν πρέπει να είναι μεγαλύτερες από %d"
 
-#: config/i386/i386.c:6508 config/i386/i386.c:6551
+#: config/i386/i386.c:6511 config/i386/i386.c:6554
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6512
+#: config/i386/i386.c:6515
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6520 config/i386/i386.c:6569
+#: config/i386/i386.c:6523 config/i386/i386.c:6572
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6530 config/i386/i386.c:6547
+#: config/i386/i386.c:6533 config/i386/i386.c:6550
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6534
+#: config/i386/i386.c:6537
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6538 config/i386/i386.c:6565
+#: config/i386/i386.c:6541 config/i386/i386.c:6568
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6555 config/i386/i386.c:6573
+#: config/i386/i386.c:6558 config/i386/i386.c:6576
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:6561
+#: config/i386/i386.c:6564
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: config/i386/i386.c:6805
+#: config/i386/i386.c:6808
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:6808
+#: config/i386/i386.c:6811
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:7126
+#: config/i386/i386.c:7129
 #, fuzzy, gcc-internal-format
 msgid "X32 does not support ms_abi attribute"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: config/i386/i386.c:7160
+#: config/i386/i386.c:7163
 #, gcc-internal-format
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr ""
 
-#: config/i386/i386.c:7502
+#: config/i386/i386.c:7505
 #, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7508
+#: config/i386/i386.c:7511
 #, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7522
+#: config/i386/i386.c:7525
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7528
+#: config/i386/i386.c:7531
 #, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7544
+#: config/i386/i386.c:7547
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7550
+#: config/i386/i386.c:7553
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7566
+#: config/i386/i386.c:7569
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7572
+#: config/i386/i386.c:7575
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:7754
+#: config/i386/i386.c:7757
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:7871
+#: config/i386/i386.c:7874
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:7989
+#: config/i386/i386.c:7992
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:8152
+#: config/i386/i386.c:8155
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.c:8158
+#: config/i386/i386.c:8161
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.c:8174
+#: config/i386/i386.c:8177
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr ""
 
-#: config/i386/i386.c:8471 config/i386/i386.c:8750 config/i386/i386.c:9276
+#: config/i386/i386.c:8474 config/i386/i386.c:8753 config/i386/i386.c:9279
 #, gcc-internal-format
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:8473 config/i386/i386.c:8752 config/i386/i386.c:9278
+#: config/i386/i386.c:8476 config/i386/i386.c:8755 config/i386/i386.c:9281
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr ""
 
-#: config/i386/i386.c:9178
+#: config/i386/i386.c:9181
 #, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr ""
 
-#: config/i386/i386.c:11601
+#: config/i386/i386.c:11604
 #, gcc-internal-format, gfc-internal-format
 msgid "-mcall-ms2sysv-xlogues is not compatible with %s"
 msgstr ""
 
-#: config/i386/i386.c:13593
+#: config/i386/i386.c:13596
 #, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr ""
 
-#: config/i386/i386.c:13683
+#: config/i386/i386.c:13686
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr ""
 
-#: config/i386/i386.c:14970
+#: config/i386/i386.c:14973
 #, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr ""
 
-#: config/i386/i386.c:14990
+#: config/i386/i386.c:14993
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
 msgstr ""
@@ -30150,311 +30191,311 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:15001
+#: config/i386/i386.c:15004
 #, fuzzy, gcc-internal-format
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: config/i386/i386.c:17939
+#: config/i386/i386.c:17942
 #, gcc-internal-format
 msgid "'V' modifier on non-integer register"
 msgstr ""
 
-#: config/i386/i386.c:17950 config/i386/i386.c:17964
+#: config/i386/i386.c:17953 config/i386/i386.c:17967
 #, fuzzy, gcc-internal-format
 msgid "unsupported size for integer register"
 msgstr "Εμφάνιση έκδοσης προγράμματος"
 
-#: config/i386/i386.c:17996
+#: config/i386/i386.c:17999
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr ""
 
-#: config/i386/i386.c:18011
+#: config/i386/i386.c:18014
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr ""
 
-#: config/i386/i386.c:18202
+#: config/i386/i386.c:18205
 #, gcc-internal-format
 msgid "non-integer operand used with operand code 'z'"
 msgstr ""
 
-#: config/i386/i386.c:28467
+#: config/i386/i386.c:28470
 #, gcc-internal-format
 msgid "interrupt service routine can't be called directly"
 msgstr ""
 
-#: config/i386/i386.c:29995
+#: config/i386/i386.c:29998
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in -fabi-version=12 (GCC 8)"
 msgstr ""
 
-#: config/i386/i386.c:32435
+#: config/i386/i386.c:32438
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr ""
 
-#: config/i386/i386.c:32485
+#: config/i386/i386.c:32488
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for %s"
 msgstr "Οι ορισμοί πηγή βρίσκονται στο ΑΡΧΕΙΟ"
 
-#: config/i386/i386.c:32495
+#: config/i386/i386.c:32498
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr ""
 
-#: config/i386/i386.c:32657
+#: config/i386/i386.c:32660
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386.c:32662 config/i386/i386.c:32938
-#: config/rs6000/rs6000.c:37850
+#: config/i386/i386.c:32665 config/i386/i386.c:32941
+#: config/rs6000/rs6000.c:37906
 #, fuzzy, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "ειδικά αρχεία μπλοκ δεν υποστηρίζονται"
 
-#: config/i386/i386.c:32795 config/rs6000/rs6000.c:37607
+#: config/i386/i386.c:32798 config/rs6000/rs6000.c:37663
 #, fuzzy, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/i386/i386.c:33207
+#: config/i386/i386.c:33210
 #, fuzzy, gcc-internal-format
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:33232 config/i386/i386.c:33282
+#: config/i386/i386.c:33235 config/i386/i386.c:33285
 #, gcc-internal-format, gfc-internal-format
 msgid "Parameter to builtin not valid: %s"
 msgstr ""
 
-#: config/i386/i386.c:33975 config/i386/i386.c:35415
+#: config/i386/i386.c:33978 config/i386/i386.c:35418
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:34370
+#: config/i386/i386.c:34373
 #, fuzzy, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: config/i386/i386.c:34465
+#: config/i386/i386.c:34468
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:35346
+#: config/i386/i386.c:35349
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:35361
+#: config/i386/i386.c:35364
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:35394
+#: config/i386/i386.c:35397
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:35434
+#: config/i386/i386.c:35437
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:35447
+#: config/i386/i386.c:35450
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:35457
+#: config/i386/i386.c:35460
 #, fuzzy, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:35462 config/i386/i386.c:36249
+#: config/i386/i386.c:35465 config/i386/i386.c:36252
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:35596
+#: config/i386/i386.c:35599
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: config/i386/i386.c:35601
+#: config/i386/i386.c:35604
 #, fuzzy, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr "λάθος συνθηματικό"
 
-#: config/i386/i386.c:35607 config/i386/i386.c:35814
+#: config/i386/i386.c:35610 config/i386/i386.c:35817
 #, fuzzy, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr "λάθος συνθηματικό"
 
-#: config/i386/i386.c:35796
+#: config/i386/i386.c:35799
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:35802
+#: config/i386/i386.c:35805
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:35805
+#: config/i386/i386.c:35808
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:36247
+#: config/i386/i386.c:36250
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:36329 config/powerpcspe/powerpcspe.c:16219
-#: config/rs6000/rs6000.c:15304
+#: config/i386/i386.c:36332 config/powerpcspe/powerpcspe.c:16219
+#: config/rs6000/rs6000.c:15348
 #, fuzzy, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: config/i386/i386.c:36539
+#: config/i386/i386.c:36542
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr ""
 
-#: config/i386/i386.c:36543
+#: config/i386/i386.c:36546
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr ""
 
-#: config/i386/i386.c:37381
+#: config/i386/i386.c:37375
 #, fuzzy, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: config/i386/i386.c:38108 config/i386/i386.c:38290
+#: config/i386/i386.c:38102 config/i386/i386.c:38284
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386.c:38343
+#: config/i386/i386.c:38337
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386.c:38349
+#: config/i386/i386.c:38343
 #, fuzzy, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr "λάθος συνθηματικό"
 
-#: config/i386/i386.c:38368
+#: config/i386/i386.c:38362
 #, fuzzy, gcc-internal-format
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:41431
+#: config/i386/i386.c:41425
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr ""
 
-#: config/i386/i386.c:41452
+#: config/i386/i386.c:41446
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:41485 config/i386/i386.c:41494
+#: config/i386/i386.c:41479 config/i386/i386.c:41488
 #, gcc-internal-format
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:41530 config/powerpcspe/powerpcspe.c:35868
-#: config/rs6000/rs6000.c:33065
+#: config/i386/i386.c:41524 config/powerpcspe/powerpcspe.c:35868
+#: config/rs6000/rs6000.c:33121
 #, fuzzy, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "μη έγκυρο δικαίωμα"
 
-#: config/i386/i386.c:41555 config/i386/i386.c:41577 config/ia64/ia64.c:815
+#: config/i386/i386.c:41549 config/i386/i386.c:41571 config/ia64/ia64.c:815
 #: config/s390/s390.c:1153
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: config/i386/i386.c:41565 config/i386/i386.c:41587 config/s390/s390.c:1182
+#: config/i386/i386.c:41559 config/i386/i386.c:41581 config/s390/s390.c:1182
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:41619
+#: config/i386/i386.c:41613
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386.c:41626
+#: config/i386/i386.c:41620
 #, gcc-internal-format, gfc-internal-format
 msgid "interrupt service routine should have unsigned %sint as the second argument"
 msgstr ""
 
-#: config/i386/i386.c:41636
+#: config/i386/i386.c:41630
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386.c:41639
+#: config/i386/i386.c:41633
 #, gcc-internal-format
 msgid "interrupt service routine can't have non-void return value"
 msgstr ""
 
-#: config/i386/i386.c:44676
+#: config/i386/i386.c:44670
 #, gcc-internal-format
 msgid "alternatives not allowed in asm flag output"
 msgstr ""
 
-#: config/i386/i386.c:44740
+#: config/i386/i386.c:44734
 #, fuzzy, gcc-internal-format
 msgid "unknown asm flag output %qs"
 msgstr "άγνωστο σετ `%s'"
 
-#: config/i386/i386.c:44769
+#: config/i386/i386.c:44763
 #, fuzzy, gcc-internal-format
 msgid "invalid type for asm flag output"
 msgstr "Η παράμετρος κινητής υποδιαστολής δεν είναι έγκυρη: %s"
 
-#: config/i386/i386.c:50634
+#: config/i386/i386.c:50628
 #, gcc-internal-format
 msgid "unknown architecture specific memory model"
 msgstr ""
 
-#: config/i386/i386.c:50641
+#: config/i386/i386.c:50635
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50647
+#: config/i386/i386.c:50641
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50671 config/i386/i386.c:50787
+#: config/i386/i386.c:50665 config/i386/i386.c:50781
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unsupported simdlen %d"
 msgstr "Εμφάνιση έκδοσης προγράμματος"
 
-#: config/i386/i386.c:50690
+#: config/i386/i386.c:50684
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd"
 msgstr ""
 
-#: config/i386/i386.c:50712
+#: config/i386/i386.c:50706
 #, fuzzy, gcc-internal-format
 msgid "unsupported argument type %qT for simd"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: config/i386/i386.c:51033
+#: config/i386/i386.c:51027
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr ""
@@ -30679,7 +30720,7 @@
 msgstr ""
 
 #: config/m68k/m68k.c:1128 config/powerpcspe/powerpcspe.c:28512
-#: config/rs6000/rs6000.c:25791
+#: config/rs6000/rs6000.c:25868
 #, fuzzy, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "ειδικά αρχεία μπλοκ δεν υποστηρίζονται"
@@ -31254,58 +31295,58 @@
 
 #. Trampoline is not supported on reduced-set registers yet.
 #: config/nds32/nds32.c:2327 config/nds32/nds32.c:2381
-#: config/nds32/nds32.c:3127 config/nds32/nds32.c:3201
-#: config/nds32/nds32.c:3216 config/nds32/nds32.c:3222
-#: config/nds32/nds32.c:3284 config/nds32/nds32.c:3290
-#: config/nds32/nds32.c:3322
+#: config/nds32/nds32.c:3128 config/nds32/nds32.c:3202
+#: config/nds32/nds32.c:3217 config/nds32/nds32.c:3223
+#: config/nds32/nds32.c:3285 config/nds32/nds32.c:3291
+#: config/nds32/nds32.c:3323
 #, fuzzy, gcc-internal-format
 msgid "a nested function is not supported for reduced registers"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
 #. The enum index value for array size is out of range.
-#: config/nds32/nds32.c:3025
+#: config/nds32/nds32.c:3026
 #, fuzzy, gcc-internal-format
 msgid "intrinsic register index is out of range"
 msgstr "σχετική θέση αρχείου είναι εκτός ορίων"
 
-#: config/nds32/nds32.c:3041 config/nds32/nds32.c:3048
-#: config/nds32/nds32.c:3055 config/nds32/nds32.c:3062
-#: config/nds32/nds32.c:3069
+#: config/nds32/nds32.c:3042 config/nds32/nds32.c:3049
+#: config/nds32/nds32.c:3056 config/nds32/nds32.c:3063
+#: config/nds32/nds32.c:3070
 #, fuzzy, gcc-internal-format
 msgid "CCTL intrinsic function subtype out of range!"
 msgstr "σχετική θέση αρχείου είναι εκτός ορίων"
 
-#: config/nds32/nds32.c:3508
+#: config/nds32/nds32.c:3509
 #, fuzzy, gcc-internal-format
 msgid "invalid id value for interrupt/exception attribute"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 
-#: config/nds32/nds32.c:3536
+#: config/nds32/nds32.c:3537
 #, fuzzy, gcc-internal-format
 msgid "invalid id value for reset attribute"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: config/nds32/nds32.c:3552
+#: config/nds32/nds32.c:3553
 #, fuzzy, gcc-internal-format
 msgid "invalid nmi function for reset attribute"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: config/nds32/nds32.c:3565
+#: config/nds32/nds32.c:3566
 #, fuzzy, gcc-internal-format
 msgid "invalid warm function for reset attribute"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: config/nds32/nds32.c:3638
+#: config/nds32/nds32.c:3639
 #, gcc-internal-format
 msgid "Disable FPU ISA, the ABI option must be enable '-mfloat-abi=soft'"
 msgstr ""
 
-#: config/nds32/nds32.c:3641
+#: config/nds32/nds32.c:3642
 #, gcc-internal-format
 msgid "'-mabi=2fp+' option only support when FPU available, must be enable '-mext-fpu-sp' or '-mext-fpu-dp'"
 msgstr ""
 
-#: config/nds32/nds32.c:3647
+#: config/nds32/nds32.c:3648
 #, fuzzy, gcc-internal-format
 #| msgid "-pipe not supported"
 msgid "position-independent code not supported"
@@ -31642,12 +31683,12 @@
 msgid "junk at end of #pragma longcall"
 msgstr "μη τερματιζόμενo αλφαριθμητικό"
 
-#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6154
+#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6152
 #, gcc-internal-format
 msgid "vec_lvsl is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6158
+#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6156
 #, gcc-internal-format
 msgid "vec_lvsr is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
@@ -31697,7 +31738,7 @@
 msgid "vec_insert only accepts 3 arguments"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6868
+#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6866
 #, fuzzy, gcc-internal-format
 msgid "passing arg %d of %qE discards qualifiers from pointer target type"
 msgstr "%s μετατρέπει ακέραιο σε δείκτη χωρίς μετατροπέα"
@@ -31782,7 +31823,7 @@
 msgid "target attribute or pragma changes SPE ABI"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4351 config/rs6000/rs6000.c:4223
+#: config/powerpcspe/powerpcspe.c:4351 config/rs6000/rs6000.c:4243
 #, fuzzy, gcc-internal-format
 msgid "AltiVec not supported in this target"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
@@ -31928,7 +31969,7 @@
 msgid "-mvsx-small-integer requires -mpower8-vector, -mupper-regs-di, and -mdirect-move"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4959 config/rs6000/rs6000.c:4601
+#: config/powerpcspe/powerpcspe.c:4959 config/rs6000/rs6000.c:4628
 #, gcc-internal-format
 msgid "target attribute or pragma changes long double size"
 msgstr ""
@@ -31969,22 +32010,22 @@
 msgstr ""
 
 #: config/powerpcspe/powerpcspe.c:5140 config/powerpcspe/powerpcspe.c:5155
-#: config/rs6000/rs6000.c:4766 config/rs6000/rs6000.c:4781
+#: config/rs6000/rs6000.c:4791 config/rs6000/rs6000.c:4806
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:5168 config/rs6000/rs6000.c:4794
+#: config/powerpcspe/powerpcspe.c:5168 config/rs6000/rs6000.c:4819
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:5234 config/rs6000/rs6000.c:4828
+#: config/powerpcspe/powerpcspe.c:5234 config/rs6000/rs6000.c:4853
 #, gcc-internal-format
 msgid "target attribute or pragma changes single precision floating point"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:5237 config/rs6000/rs6000.c:4831
+#: config/powerpcspe/powerpcspe.c:5237 config/rs6000/rs6000.c:4856
 #, gcc-internal-format
 msgid "target attribute or pragma changes double precision floating point"
 msgstr ""
@@ -31994,12 +32035,12 @@
 msgid "-mstack-protector-guard=tls needs a valid base register"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:8415 config/rs6000/rs6000.c:7925
+#: config/powerpcspe/powerpcspe.c:8415 config/rs6000/rs6000.c:7950
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11237
+#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11269
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
@@ -32009,7 +32050,7 @@
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11595
+#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11633
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr ""
@@ -32019,12 +32060,12 @@
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12604
+#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12648
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12779
+#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12823
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
@@ -32034,28 +32075,28 @@
 msgid "internal error: builtin function %s already processed"
 msgstr "εσωτερικό σφάλμα στο %s, γραμμή %u"
 
-#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:13971
+#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:14015
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be an 8-bit field value"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14015
+#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14059
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
 #: config/powerpcspe/powerpcspe.c:14934 config/powerpcspe/powerpcspe.c:16803
-#: config/rs6000/rs6000.c:14101
+#: config/rs6000/rs6000.c:14145
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14119
+#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14163
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14135
+#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14179
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 7-bit unsigned literal"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
@@ -32075,12 +32116,12 @@
 msgid "builtin %s is only valid in 64-bit mode"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14791
+#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14835
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %d must be an unsigned literal"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14793
+#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14837
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
@@ -32102,53 +32143,53 @@
 msgid "hwcap %s is an invalid argument to builtin %s"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15065
+#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15109
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15090
+#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15134
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15110
+#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15154
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15122
+#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15166
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be 0 or 2"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15134
+#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15178
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15148
+#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15192
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15160
+#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15204
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be 0 or 1"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15168
+#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15212
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be in the range 0..15"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15237
-#: config/rs6000/rs6000.c:15569
+#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15281
+#: config/rs6000/rs6000.c:15613
 #, fuzzy, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15394
+#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15438
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr ""
@@ -32274,7 +32315,7 @@
 msgstr ""
 
 # src/shred.c:1134
-#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25758
+#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25835
 #, fuzzy, gcc-internal-format
 msgid "stack frame too large"
 msgstr "%s: το αρχείο είναι πολύ μεγάλο"
@@ -32284,12 +32325,12 @@
 msgid "-fsplit-stack uses register r29"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29459
+#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29536
 #, gcc-internal-format
 msgid "Stack frame larger than 2G is not supported for -fsplit-stack"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30447
+#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30524
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr ""
@@ -32299,22 +32340,22 @@
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32830
+#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32907
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32832
+#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32909
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32834
+#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32911
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32836
+#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32913
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr ""
@@ -32324,7 +32365,7 @@
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32845
+#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32922
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr ""
@@ -32867,71 +32908,71 @@
 "Please use an explicit cpu name.  Valid cpu names are: %s"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6168 config/rs6000/rs6000-c.c:6219
-#: config/rs6000/rs6000-c.c:6489 config/rs6000/rs6000-c.c:6555
-#: config/rs6000/rs6000-c.c:6916 config/rs6000/rs6000-c.c:6963
+#: config/rs6000/rs6000-c.c:6166 config/rs6000/rs6000-c.c:6217
+#: config/rs6000/rs6000-c.c:6487 config/rs6000/rs6000-c.c:6553
+#: config/rs6000/rs6000-c.c:6914 config/rs6000/rs6000-c.c:6961
 #, gcc-internal-format
 msgid "builtin %qs only accepts 2 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6292 config/rs6000/rs6000-c.c:6375
-#: config/rs6000/rs6000-c.c:6736
+#: config/rs6000/rs6000-c.c:6290 config/rs6000/rs6000-c.c:6373
+#: config/rs6000/rs6000-c.c:6734
 #, gcc-internal-format
 msgid "builtin %qs only accepts 3 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6484
+#: config/rs6000/rs6000-c.c:6482
 #, gcc-internal-format
 msgid "builtin %qs only accepts 1 argument"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:7054
+#: config/rs6000/rs6000-c.c:7052
 #, gcc-internal-format
 msgid "builtin %qs requires builtin %qs"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:7058
+#: config/rs6000/rs6000-c.c:7056
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs not supported in this compiler configuration"
 msgstr "Η οικογένεια διευθύνσεων δεν υποστηρίζεται από την οικογένεια πρωτοκόλλου"
 
-#: config/rs6000/rs6000-c.c:7068
+#: config/rs6000/rs6000-c.c:7066
 #, gcc-internal-format
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3754 config/rs6000/rs6000.c:3757
-#: config/rs6000/rs6000.c:3760
+#: config/rs6000/rs6000.c:3772 config/rs6000/rs6000.c:3775
+#: config/rs6000/rs6000.c:3778
 #, fuzzy, gcc-internal-format
 msgid "%qs requires %qs or %qs"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: config/rs6000/rs6000.c:3861
+#: config/rs6000/rs6000.c:3879
 #, gcc-internal-format
 msgid "%qs requires PowerPC64 architecture, enabling"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4037
+#: config/rs6000/rs6000.c:4057
 #, fuzzy, gcc-internal-format
 msgid "%qs command-line option is deprecated"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: config/rs6000/rs6000.c:4048
+#: config/rs6000/rs6000.c:4068
 #, gcc-internal-format
 msgid "%qs is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4147
+#: config/rs6000/rs6000.c:4167
 #, gcc-internal-format
 msgid "will not generate %qs instructions because assembler lacks %qs support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4240
+#: config/rs6000/rs6000.c:4260
 #, fuzzy, gcc-internal-format
 msgid "%qs is not supported on little endian systems"
 msgstr "προειδοποίηση: το --pid=PID δεν υποστηρίζεται σε αυτό το σύστημα"
 
-#: config/rs6000/rs6000.c:4333
+#: config/rs6000/rs6000.c:4353
 #, gcc-internal-format
 msgid "power9 target option is incompatible with %<%s=<xxx>%> for <xxx> less than power9"
 msgstr ""
@@ -32938,7 +32979,7 @@
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:4341
+#: config/rs6000/rs6000.c:4361
 #, fuzzy, gcc-internal-format
 msgid "%qs incompatible with explicitly disabled options"
 msgstr "μη έγκυρο δικαίωμα"
@@ -32947,240 +32988,241 @@
 #. error messages.  However, if users have managed to select
 #. power9-fusion without selecting power8-fusion, they
 #. already know about undocumented flags.
-#: config/rs6000/rs6000.c:4366 config/rs6000/rs6000.c:4373
-#: config/rs6000/rs6000.c:4380 config/rs6000/rs6000.c:4388
-#: config/rs6000/rs6000.c:4407 config/rs6000/rs6000.c:4464
-#: config/rs6000/rs6000.c:4468 config/rs6000/rs6000.c:4485
-#: config/rs6000/rs6000.c:4538 config/rs6000/rs6000.c:4565
-#: config/rs6000/rs6000.c:4580 config/rs6000/rs6000.c:4588
-#: config/rs6000/rs6000.c:4684
+#: config/rs6000/rs6000.c:4386 config/rs6000/rs6000.c:4393
+#: config/rs6000/rs6000.c:4400 config/rs6000/rs6000.c:4408
+#: config/rs6000/rs6000.c:4427 config/rs6000/rs6000.c:4484
+#: config/rs6000/rs6000.c:4488 config/rs6000/rs6000.c:4505
+#: config/rs6000/rs6000.c:4558 config/rs6000/rs6000.c:4585
+#: config/rs6000/rs6000.c:4600 config/rs6000/rs6000.c:4608
+#: config/rs6000/rs6000.c:4709
 #, gcc-internal-format
 msgid "%qs requires %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4625
+#: config/rs6000/rs6000.c:4650
 #, gcc-internal-format
 msgid "Using IEEE extended precision long double"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4627
+#: config/rs6000/rs6000.c:4652
 #, gcc-internal-format
 msgid "Using IBM extended precision long double"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4644
+#: config/rs6000/rs6000.c:4669
 #, fuzzy, gcc-internal-format
 msgid "%qs requires VSX support"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: config/rs6000/rs6000.c:4653
+#: config/rs6000/rs6000.c:4678
 #, gcc-internal-format
 msgid "The -mfloat128 option may not be fully supported"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4676
+#: config/rs6000/rs6000.c:4701
 #, gcc-internal-format
 msgid "%qs requires full ISA 3.0 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4743
+#: config/rs6000/rs6000.c:4768
 #, gcc-internal-format
 msgid "unknown vectorization library ABI type (%qs) for %qs switch"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4930
+#: config/rs6000/rs6000.c:4955
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid number in %qs"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: config/rs6000/rs6000.c:4935
+#: config/rs6000/rs6000.c:4960
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid offset in %qs"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: config/rs6000/rs6000.c:4947
+#: config/rs6000/rs6000.c:4972
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid base register in %qs"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: config/rs6000/rs6000.c:4955
+#: config/rs6000/rs6000.c:4980
 #, gcc-internal-format
 msgid "%qs needs a valid base register"
 msgstr ""
 
-#: config/rs6000/rs6000.c:5253
+#: config/rs6000/rs6000.c:5278
 #, gcc-internal-format
 msgid "unknown option for %<%s=%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:5290
+#: config/rs6000/rs6000.c:5315
 #, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11401
+#: config/rs6000/rs6000.c:11439
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11862
+#: config/rs6000/rs6000.c:11906
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13572
+#: config/rs6000/rs6000.c:13616
 #, fuzzy, gcc-internal-format
 msgid "internal error: builtin function %qs already processed"
 msgstr "εσωτερικό σφάλμα στο %s, γραμμή %u"
 
-#: config/rs6000/rs6000.c:14150
+#: config/rs6000/rs6000.c:14194
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 1-bit unsigned literal"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000.c:14189
+#: config/rs6000/rs6000.c:14233
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qs must be a constant"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000.c:14247 config/rs6000/rs6000.c:15898
+#: config/rs6000/rs6000.c:14291 config/rs6000/rs6000.c:15942
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qs is out of range"
 msgstr "Λείπει παράμετρος για `%s'"
 
-#: config/rs6000/rs6000.c:14742
+#: config/rs6000/rs6000.c:14786
 #, gcc-internal-format
 msgid "builtin %qs is only valid in 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14939
+#: config/rs6000/rs6000.c:14983
 #, gcc-internal-format
 msgid "builtin %qs only accepts a string argument"
 msgstr ""
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000.c:14958
+#: config/rs6000/rs6000.c:15002
 #, fuzzy, gcc-internal-format
 msgid "cpu %qs is an invalid argument to builtin %qs"
 msgstr "πάρα πολλά ορίσματα"
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000.c:14986
+#: config/rs6000/rs6000.c:15030
 #, fuzzy, gcc-internal-format
 msgid "%s %qs is an invalid argument to builtin %qs"
 msgstr "πάρα πολλά ορίσματα"
 
-#: config/rs6000/rs6000.c:15012
+#: config/rs6000/rs6000.c:15056
 #, gcc-internal-format
 msgid "builtin %qs needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15616
+#: config/rs6000/rs6000.c:15660
 #, fuzzy, gcc-internal-format
 msgid "second argument to %qs must be 0..12"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000.c:15631
+#: config/rs6000/rs6000.c:15675
 #, fuzzy, gcc-internal-format
 msgid "third argument to %qs must be 0..12"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000.c:15850
+#: config/rs6000/rs6000.c:15894
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument 1 of %s must be a constant"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000.c:15932
+#: config/rs6000/rs6000.c:15976
 #, gcc-internal-format
 msgid "builtin function %qs is only valid for the cell processor"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15934 config/rs6000/rs6000.c:15936
-#: config/rs6000/rs6000.c:15938 config/rs6000/rs6000.c:15940
-#: config/rs6000/rs6000.c:15946 config/rs6000/rs6000.c:15948
-#: config/rs6000/rs6000.c:15955 config/rs6000/rs6000.c:15962
-#: config/rs6000/rs6000.c:15969 config/rs6000/rs6000.c:15975
+#: config/rs6000/rs6000.c:15978 config/rs6000/rs6000.c:15980
+#: config/rs6000/rs6000.c:15982 config/rs6000/rs6000.c:15984
+#: config/rs6000/rs6000.c:15990 config/rs6000/rs6000.c:15992
+#: config/rs6000/rs6000.c:15999 config/rs6000/rs6000.c:16006
+#: config/rs6000/rs6000.c:16011 config/rs6000/rs6000.c:16014
+#: config/rs6000/rs6000.c:16018 config/rs6000/rs6000.c:16024
 #, gcc-internal-format
 msgid "builtin function %qs requires the %qs option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15943 config/rs6000/rs6000.c:15952
-#: config/rs6000/rs6000.c:15959 config/rs6000/rs6000.c:15966
+#: config/rs6000/rs6000.c:15987 config/rs6000/rs6000.c:15996
+#: config/rs6000/rs6000.c:16003
 #, gcc-internal-format
 msgid "builtin function %qs requires the %qs and %qs options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15972
+#: config/rs6000/rs6000.c:16021
 #, gcc-internal-format
 msgid "builtin function %qs requires ISA 3.0 IEEE 128-bit floating point"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15978
+#: config/rs6000/rs6000.c:16027
 #, gcc-internal-format
 msgid "builtin function %qs requires the %qs (or newer), and %qs or %qs options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15982
+#: config/rs6000/rs6000.c:16031
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs is not supported with the current options"
 msgstr "Η οικογένεια διευθύνσεων δεν υποστηρίζεται από την οικογένεια πρωτοκόλλου"
 
-#: config/rs6000/rs6000.c:18218
+#: config/rs6000/rs6000.c:18290
 #, fuzzy, gcc-internal-format
 msgid "internal error: builtin function %qs had an unexpected return type %qs"
 msgstr "εσωτερικό σφάλμα στο %s, γραμμή %u"
 
-#: config/rs6000/rs6000.c:18235
+#: config/rs6000/rs6000.c:18307
 #, gcc-internal-format
 msgid "internal error: builtin function %qs, argument %d had unexpected argument type %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:29451
+#: config/rs6000/rs6000.c:29528
 #, fuzzy, gcc-internal-format
 msgid "%qs uses register r29"
 msgstr "Δεν είναι δυνατή η καταχώρηση της υπηρεσίας"
 
-#: config/rs6000/rs6000.c:32748
+#: config/rs6000/rs6000.c:32825
 #, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32842
+#: config/rs6000/rs6000.c:32919
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32850
+#: config/rs6000/rs6000.c:32927
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32853
+#: config/rs6000/rs6000.c:32930
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr ""
 
-#: config/rs6000/rs6000.c:36876
+#: config/rs6000/rs6000.c:36932
 #, fuzzy, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "Μη έγκυρη προτεραιότητα `%s'"
 
-#: config/rs6000/rs6000.c:36879
+#: config/rs6000/rs6000.c:36935
 #, fuzzy, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: config/rs6000/rs6000.c:36881
+#: config/rs6000/rs6000.c:36937
 #, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:37416
+#: config/rs6000/rs6000.c:37472
 #, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:37575
+#: config/rs6000/rs6000.c:37631
 #, gcc-internal-format
 msgid "target_clones attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
@@ -33922,49 +33964,49 @@
 msgid "subprogram %q+F not marked Inline"
 msgstr ""
 
-#: ada/gcc-interface/trans.c:6404
+#: ada/gcc-interface/trans.c:6401
 #, gcc-internal-format
 msgid "out-of-bounds access may be optimized away"
 msgstr ""
 
-#: ada/gcc-interface/trans.c:6406
+#: ada/gcc-interface/trans.c:6403
 #, gcc-internal-format
 msgid "containing loop"
 msgstr ""
 
-#: ada/gcc-interface/utils.c:3887
+#: ada/gcc-interface/utils.c:3890
 #, fuzzy, gcc-internal-format
 msgid "invalid element type for attribute %qs"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 
-#: ada/gcc-interface/utils.c:3911
+#: ada/gcc-interface/utils.c:3914
 #, fuzzy, gcc-internal-format
 msgid "number of components of vector not a power of two"
 msgstr "λάθος αριθμός ορισμάτων"
 
-#: ada/gcc-interface/utils.c:6037 ada/gcc-interface/utils.c:6215
-#: ada/gcc-interface/utils.c:6322
+#: ada/gcc-interface/utils.c:6043 ada/gcc-interface/utils.c:6220
+#: ada/gcc-interface/utils.c:6327
 #, fuzzy, gcc-internal-format
 msgid "%qs attribute ignored"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: ada/gcc-interface/utils.c:6158
+#: ada/gcc-interface/utils.c:6164
 #, gcc-internal-format
 msgid "%qs attribute requires prototypes with named arguments"
 msgstr ""
 
-#: ada/gcc-interface/utils.c:6167
+#: ada/gcc-interface/utils.c:6173
 #, gcc-internal-format
 msgid "%qs attribute only applies to variadic functions"
 msgstr ""
 
 # src/request.c:37
-#: ada/gcc-interface/utils.c:6282
+#: ada/gcc-interface/utils.c:6287
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute has no effect"
 msgstr "%s σε %s"
 
-#: ada/gcc-interface/utils.c:6406
+#: ada/gcc-interface/utils.c:6411
 #, fuzzy, gcc-internal-format
 msgid "attribute %qs applies to array types only"
 msgstr "προειδοποίηση: το --pid=PID δεν υποστηρίζεται σε αυτό το σύστημα"
@@ -33979,7 +34021,7 @@
 #. an unprototyped function, it is compile-time undefined;
 #. making it a constraint in that case was rejected in
 #. DR#252.
-#: c/c-convert.c:101 c/c-typeck.c:2175 c/c-typeck.c:6507 c/c-typeck.c:12138
+#: c/c-convert.c:101 c/c-typeck.c:2175 c/c-typeck.c:6512 c/c-typeck.c:12143
 #: cp/typeck.c:2027 cp/typeck.c:7977 cp/typeck.c:8742
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
@@ -34040,7 +34082,7 @@
 msgid "type of array %q+D completed incompatibly with implicit initialization"
 msgstr ""
 
-#: c/c-decl.c:1567 c/c-decl.c:6701 c/c-decl.c:7574 c/c-decl.c:8381
+#: c/c-decl.c:1567 c/c-decl.c:6721 c/c-decl.c:7594 c/c-decl.c:8401
 #, fuzzy, gcc-internal-format
 msgid "originally defined here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
@@ -34447,16 +34489,11 @@
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.c:4548 c/c-decl.c:7147
+#: c/c-decl.c:4548 c/c-decl.c:7167
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr ""
 
-#: c/c-decl.c:4635 cp/decl2.c:1520
-#, gcc-internal-format
-msgid "%q+D in declare target directive does not have mappable type"
-msgstr ""
-
 #: c/c-decl.c:4693
 #, fuzzy, gcc-internal-format
 msgid "%q+D is usually a function"
@@ -34482,7 +34519,7 @@
 #. of VLAs themselves count as VLAs, it does not make
 #. sense to permit them to be initialized given that
 #. ordinary VLAs may not be initialized.
-#: c/c-decl.c:4732 c/c-decl.c:4747 c/c-typeck.c:7630
+#: c/c-decl.c:4732 c/c-decl.c:4747 c/c-typeck.c:7635
 #, gcc-internal-format
 msgid "variable-sized object may not be initialized"
 msgstr ""
@@ -34543,203 +34580,208 @@
 msgid "uninitialized const %qD is invalid in C++"
 msgstr "μη αρχικοποιημένη σταθερά const %qD"
 
-#: c/c-decl.c:5268
+#: c/c-decl.c:5224 cp/decl.c:7318
 #, gcc-internal-format
+msgid "%q+D in declare target directive does not have mappable type"
+msgstr ""
+
+#: c/c-decl.c:5288
+#, gcc-internal-format
 msgid "ISO C forbids forward parameter declarations"
 msgstr ""
 
-#: c/c-decl.c:5371
+#: c/c-decl.c:5391
 #, gcc-internal-format
 msgid "defining a type in a compound literal is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:5425 c/c-decl.c:5440
+#: c/c-decl.c:5445 c/c-decl.c:5460
 #, fuzzy, gcc-internal-format
 msgid "bit-field %qs width not an integer constant"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: c/c-decl.c:5435
+#: c/c-decl.c:5455
 #, fuzzy, gcc-internal-format
 msgid "bit-field %qs width not an integer constant expression"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: c/c-decl.c:5446
+#: c/c-decl.c:5466
 #, fuzzy, gcc-internal-format
 msgid "negative width in bit-field %qs"
 msgstr "Αρνητικό πλάτος στην αποτίμηση"
 
-#: c/c-decl.c:5451
+#: c/c-decl.c:5471
 #, fuzzy, gcc-internal-format
 msgid "zero width for bit-field %qs"
 msgstr "Αρνητικό πλάτος στην αποτίμηση"
 
-#: c/c-decl.c:5461
+#: c/c-decl.c:5481
 #, gcc-internal-format
 msgid "bit-field %qs has invalid type"
 msgstr ""
 
-#: c/c-decl.c:5467
+#: c/c-decl.c:5487
 #, fuzzy, gcc-internal-format
 msgid "cannot declare bit-field %qs with %<warn_if_not_aligned%> type"
 msgstr "άγνωστος χαρακτήρας στο πεδίο `%s' της κατηγορίας `%s'"
 
-#: c/c-decl.c:5478
+#: c/c-decl.c:5498
 #, gcc-internal-format
 msgid "type of bit-field %qs is a GCC extension"
 msgstr ""
 
-#: c/c-decl.c:5484
+#: c/c-decl.c:5504
 #, gcc-internal-format
 msgid "width of %qs exceeds its type"
 msgstr ""
 
-#: c/c-decl.c:5497
+#: c/c-decl.c:5517
 #, fuzzy, gcc-internal-format
 msgid "%qs is narrower than values of its type"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: c/c-decl.c:5512
+#: c/c-decl.c:5532
 #, gcc-internal-format
 msgid "ISO C90 forbids array %qE whose size can%'t be evaluated"
 msgstr ""
 
-#: c/c-decl.c:5515
+#: c/c-decl.c:5535
 #, gcc-internal-format
 msgid "ISO C90 forbids array whose size can%'t be evaluated"
 msgstr ""
 
-#: c/c-decl.c:5522
+#: c/c-decl.c:5542
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array %qE"
 msgstr ""
 
-#: c/c-decl.c:5524
+#: c/c-decl.c:5544
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array"
 msgstr ""
 
-#: c/c-decl.c:5733 c/c-decl.c:6107 c/c-decl.c:6117
+#: c/c-decl.c:5753 c/c-decl.c:6127 c/c-decl.c:6137
 #, fuzzy, gcc-internal-format
 msgid "variably modified %qE at file scope"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: c/c-decl.c:5735
+#: c/c-decl.c:5755
 #, gcc-internal-format
 msgid "variably modified field at file scope"
 msgstr ""
 
-#: c/c-decl.c:5755
+#: c/c-decl.c:5775
 #, fuzzy, gcc-internal-format
 msgid "type defaults to %<int%> in declaration of %qE"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: c/c-decl.c:5759
+#: c/c-decl.c:5779
 #, fuzzy, gcc-internal-format
 msgid "type defaults to %<int%> in type name"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: c/c-decl.c:5791
+#: c/c-decl.c:5811
 #, fuzzy, gcc-internal-format
 msgid "duplicate %<const%>"
 msgstr "διπλό κλειδί"
 
-#: c/c-decl.c:5793
+#: c/c-decl.c:5813
 #, fuzzy, gcc-internal-format
 msgid "duplicate %<restrict%>"
 msgstr "διπλό κλειδί"
 
-#: c/c-decl.c:5795
+#: c/c-decl.c:5815
 #, fuzzy, gcc-internal-format
 msgid "duplicate %<volatile%>"
 msgstr "διπλό κλειδί"
 
-#: c/c-decl.c:5797
+#: c/c-decl.c:5817
 #, fuzzy, gcc-internal-format
 msgid "duplicate %<_Atomic%>"
 msgstr "διπλό κλειδί"
 
 # src/request.c:806 src/request.c:912
-#: c/c-decl.c:5800
+#: c/c-decl.c:5820
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "conflicting named address spaces (%s vs %s)"
 msgstr "Μη αναγνωρίσημο όνομα επιφάνειας `%s'"
 
-#: c/c-decl.c:5823 c/c-parser.c:2821
+#: c/c-decl.c:5843 c/c-parser.c:2821
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified array type"
 msgstr ""
 
-#: c/c-decl.c:5837
+#: c/c-decl.c:5857
 #, gcc-internal-format
 msgid "function definition declared %<auto%>"
 msgstr ""
 
-#: c/c-decl.c:5839
+#: c/c-decl.c:5859
 #, gcc-internal-format
 msgid "function definition declared %<register%>"
 msgstr ""
 
-#: c/c-decl.c:5841
+#: c/c-decl.c:5861
 #, gcc-internal-format
 msgid "function definition declared %<typedef%>"
 msgstr ""
 
-#: c/c-decl.c:5843
+#: c/c-decl.c:5863
 #, fuzzy, gcc-internal-format
 msgid "function definition declared %qs"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: c/c-decl.c:5861
+#: c/c-decl.c:5881
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for structure field %qE"
 msgstr "Εγγραφή ονομάτων των επιλεγμένων λέξεων-κλειδιών"
 
-#: c/c-decl.c:5864
+#: c/c-decl.c:5884
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for structure field"
 msgstr "Εγγραφή ονομάτων των επιλεγμένων λέξεων-κλειδιών"
 
-#: c/c-decl.c:5868
+#: c/c-decl.c:5888
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for parameter %qE"
 msgstr "Εγγραφή ονομάτων των επιλεγμένων λέξεων-κλειδιών"
 
-#: c/c-decl.c:5871
+#: c/c-decl.c:5891
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for unnamed parameter"
 msgstr "Εγγραφή ονομάτων των επιλεγμένων λέξεων-κλειδιών"
 
-#: c/c-decl.c:5874 cp/decl.c:10935
+#: c/c-decl.c:5894 cp/decl.c:10959
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr ""
 
-#: c/c-decl.c:5891
+#: c/c-decl.c:5911
 #, gcc-internal-format
 msgid "%qE initialized and declared %<extern%>"
 msgstr ""
 
-#: c/c-decl.c:5895
+#: c/c-decl.c:5915
 #, gcc-internal-format
 msgid "%qE has both %<extern%> and initializer"
 msgstr ""
 
-#: c/c-decl.c:5900
+#: c/c-decl.c:5920
 #, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<auto%>"
 msgstr ""
 
-#: c/c-decl.c:5904
+#: c/c-decl.c:5924
 #, fuzzy, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<register%>"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: c/c-decl.c:5909
+#: c/c-decl.c:5929
 #, fuzzy, gcc-internal-format
 msgid "nested function %qE declared %<extern%>"
 msgstr "Στη συνάρτηση μέλος `%s':"
 
-#: c/c-decl.c:5912
+#: c/c-decl.c:5932
 #, gcc-internal-format
 msgid "function-scope %qE implicitly auto and declared %qs"
 msgstr ""
@@ -34747,703 +34789,703 @@
 #. Only the innermost declarator (making a parameter be of
 #. array type which is converted to pointer type)
 #. may have static or type qualifiers.
-#: c/c-decl.c:5959 c/c-decl.c:6328
+#: c/c-decl.c:5979 c/c-decl.c:6348
 #, gcc-internal-format
 msgid "static or type qualifiers in non-parameter array declarator"
 msgstr ""
 
-#: c/c-decl.c:6007
+#: c/c-decl.c:6027
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qE as array of voids"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: c/c-decl.c:6009
+#: c/c-decl.c:6029
 #, fuzzy, gcc-internal-format
 msgid "declaration of type name as array of voids"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: c/c-decl.c:6016
+#: c/c-decl.c:6036
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qE as array of functions"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: c/c-decl.c:6019
+#: c/c-decl.c:6039
 #, fuzzy, gcc-internal-format
 msgid "declaration of type name as array of functions"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: c/c-decl.c:6027 c/c-decl.c:8085
+#: c/c-decl.c:6047 c/c-decl.c:8105
 #, fuzzy, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: c/c-decl.c:6053
+#: c/c-decl.c:6073
 #, fuzzy, gcc-internal-format
 msgid "size of array %qE has non-integer type"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: c/c-decl.c:6057
+#: c/c-decl.c:6077
 #, fuzzy, gcc-internal-format
 msgid "size of unnamed array has non-integer type"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: c/c-decl.c:6064
+#: c/c-decl.c:6084
 #, fuzzy, gcc-internal-format
 msgid "size of array %qE has incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: c/c-decl.c:6067
+#: c/c-decl.c:6087
 #, fuzzy, gcc-internal-format
 msgid "size of unnamed array has incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: c/c-decl.c:6078
+#: c/c-decl.c:6098
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array %qE"
 msgstr ""
 
-#: c/c-decl.c:6081
+#: c/c-decl.c:6101
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array"
 msgstr ""
 
-#: c/c-decl.c:6090
+#: c/c-decl.c:6110
 #, fuzzy, gcc-internal-format
 msgid "size of array %qE is negative"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: c/c-decl.c:6092
+#: c/c-decl.c:6112
 #, fuzzy, gcc-internal-format
 msgid "size of unnamed array is negative"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: c/c-decl.c:6216 c/c-decl.c:6871
+#: c/c-decl.c:6236 c/c-decl.c:6891
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support flexible array members"
 msgstr "μη έγκυρη ώρα της μέρας"
 
 #. C99 6.7.5.2p4
-#: c/c-decl.c:6238
+#: c/c-decl.c:6258
 #, fuzzy, gcc-internal-format
 msgid "%<[*]%> not in a declaration"
 msgstr "κενό αλφαριθμητικό"
 
-#: c/c-decl.c:6251
+#: c/c-decl.c:6271
 #, fuzzy, gcc-internal-format
 msgid "array type has incomplete element type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: c/c-decl.c:6257
+#: c/c-decl.c:6277
 #, gcc-internal-format
 msgid "declaration of %qE as multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: c/c-decl.c:6261
+#: c/c-decl.c:6281
 #, gcc-internal-format
 msgid "declaration of multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: c/c-decl.c:6364
+#: c/c-decl.c:6384
 #, fuzzy, gcc-internal-format
 msgid "%qE declared as function returning a function"
 msgstr "%s: διπλός ορισμός έκδοσης κατηγορίας"
 
-#: c/c-decl.c:6367
+#: c/c-decl.c:6387
 #, fuzzy, gcc-internal-format
 msgid "type name declared as function returning a function"
 msgstr "%s: διπλός ορισμός έκδοσης κατηγορίας"
 
-#: c/c-decl.c:6374
+#: c/c-decl.c:6394
 #, fuzzy, gcc-internal-format
 msgid "%qE declared as function returning an array"
 msgstr "%s: διπλός ορισμός έκδοσης κατηγορίας"
 
-#: c/c-decl.c:6377
+#: c/c-decl.c:6397
 #, fuzzy, gcc-internal-format
 msgid "type name declared as function returning an array"
 msgstr "%s: διπλός ορισμός έκδοσης κατηγορίας"
 
-#: c/c-decl.c:6418
+#: c/c-decl.c:6438
 #, fuzzy, gcc-internal-format
 msgid "function definition has qualified void return type"
 msgstr "μη έγκυρος αριθμός αρχείου στη δήλωση πεδίου: `%s'"
 
-#: c/c-decl.c:6421 cp/decl.c:11201
+#: c/c-decl.c:6441 cp/decl.c:11225
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr ""
 
-#: c/c-decl.c:6459 c/c-decl.c:6668 c/c-decl.c:6721 c/c-decl.c:6805
-#: c/c-decl.c:6926 c/c-parser.c:2823
+#: c/c-decl.c:6479 c/c-decl.c:6688 c/c-decl.c:6741 c/c-decl.c:6825
+#: c/c-decl.c:6946 c/c-parser.c:2823
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified function type"
 msgstr ""
 
-#: c/c-decl.c:6465 c/c-decl.c:6674 c/c-decl.c:6810 c/c-decl.c:6931
+#: c/c-decl.c:6485 c/c-decl.c:6694 c/c-decl.c:6830 c/c-decl.c:6951
 #, gcc-internal-format
 msgid "ISO C forbids qualified function types"
 msgstr ""
 
-#: c/c-decl.c:6559
+#: c/c-decl.c:6579
 #, fuzzy, gcc-internal-format
 msgid "%qs combined with %<auto%> qualifier for %qE"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 
-#: c/c-decl.c:6563
+#: c/c-decl.c:6583
 #, fuzzy, gcc-internal-format
 msgid "%qs combined with %<register%> qualifier for %qE"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 
-#: c/c-decl.c:6569
+#: c/c-decl.c:6589
 #, gcc-internal-format
 msgid "%qs specified for auto variable %qE"
 msgstr ""
 
-#: c/c-decl.c:6585
+#: c/c-decl.c:6605
 #, fuzzy, gcc-internal-format
 msgid "%qs specified for parameter %qE"
 msgstr "άγνωστος χαρακτήρας `%s'"
 
-#: c/c-decl.c:6588
+#: c/c-decl.c:6608
 #, gcc-internal-format
 msgid "%qs specified for unnamed parameter"
 msgstr ""
 
-#: c/c-decl.c:6594
+#: c/c-decl.c:6614
 #, gcc-internal-format
 msgid "%qs specified for structure field %qE"
 msgstr ""
 
-#: c/c-decl.c:6597
+#: c/c-decl.c:6617
 #, gcc-internal-format
 msgid "%qs specified for structure field"
 msgstr ""
 
-#: c/c-decl.c:6612
+#: c/c-decl.c:6632
 #, fuzzy, gcc-internal-format
 msgid "bit-field %qE has atomic type"
 msgstr "μη πλήρης εγγραφή"
 
-#: c/c-decl.c:6614
+#: c/c-decl.c:6634
 #, fuzzy, gcc-internal-format
 msgid "bit-field has atomic type"
 msgstr "μη πλήρης εγγραφή"
 
-#: c/c-decl.c:6623
+#: c/c-decl.c:6643
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for typedef %qE"
 msgstr "μόνο ένα όρισμα μπορεί να δηλωθεί"
 
-#: c/c-decl.c:6625
+#: c/c-decl.c:6645
 #, gcc-internal-format
 msgid "alignment specified for %<register%> object %qE"
 msgstr ""
 
-#: c/c-decl.c:6630
+#: c/c-decl.c:6650
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for parameter %qE"
 msgstr "μόνο ένα όρισμα μπορεί να δηλωθεί"
 
-#: c/c-decl.c:6632
+#: c/c-decl.c:6652
 #, gcc-internal-format
 msgid "alignment specified for unnamed parameter"
 msgstr ""
 
-#: c/c-decl.c:6637
+#: c/c-decl.c:6657
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for bit-field %qE"
 msgstr "μόνο ένα όρισμα μπορεί να δηλωθεί"
 
-#: c/c-decl.c:6639
+#: c/c-decl.c:6659
 #, gcc-internal-format
 msgid "alignment specified for unnamed bit-field"
 msgstr ""
 
-#: c/c-decl.c:6642
+#: c/c-decl.c:6662
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for function %qE"
 msgstr "Δεν ήταν δυνατή η εύρεση ετικέττας για μεταγωγή στο `%s'"
 
-#: c/c-decl.c:6649
+#: c/c-decl.c:6669
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of %qE"
 msgstr ""
 
-#: c/c-decl.c:6652
+#: c/c-decl.c:6672
 #, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of unnamed field"
 msgstr ""
 
-#: c/c-decl.c:6683
+#: c/c-decl.c:6703
 #, fuzzy, gcc-internal-format
 msgid "typedef %q+D declared %<inline%>"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: c/c-decl.c:6685
+#: c/c-decl.c:6705
 #, fuzzy, gcc-internal-format
 msgid "typedef %q+D declared %<_Noreturn%>"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: c/c-decl.c:6727
+#: c/c-decl.c:6747
 #, gcc-internal-format
 msgid "ISO C forbids const or volatile function types"
 msgstr ""
 
 #. C99 6.7.2.1p8
-#: c/c-decl.c:6738
+#: c/c-decl.c:6758
 #, gcc-internal-format
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr ""
 
-#: c/c-decl.c:6755 cp/decl.c:9989
+#: c/c-decl.c:6775 cp/decl.c:10010
 #, fuzzy, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: c/c-decl.c:6795
+#: c/c-decl.c:6815
 #, gcc-internal-format
 msgid "attributes in parameter array declarator ignored"
 msgstr ""
 
-#: c/c-decl.c:6837
+#: c/c-decl.c:6857
 #, fuzzy, gcc-internal-format
 msgid "parameter %q+D declared %<inline%>"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: c/c-decl.c:6839
+#: c/c-decl.c:6859
 #, fuzzy, gcc-internal-format
 msgid "parameter %q+D declared %<_Noreturn%>"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: c/c-decl.c:6852
+#: c/c-decl.c:6872
 #, fuzzy, gcc-internal-format
 msgid "field %qE declared as a function"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: c/c-decl.c:6859
+#: c/c-decl.c:6879
 #, fuzzy, gcc-internal-format
 msgid "field %qE has incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: c/c-decl.c:6861
+#: c/c-decl.c:6881
 #, fuzzy, gcc-internal-format
 msgid "unnamed field has incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: c/c-decl.c:6897 c/c-decl.c:6908 c/c-decl.c:6911
+#: c/c-decl.c:6917 c/c-decl.c:6928 c/c-decl.c:6931
 #, fuzzy, gcc-internal-format
 msgid "invalid storage class for function %qE"
 msgstr "μη έγκυρη τάξη χαρακτήρων `%s'"
 
-#: c/c-decl.c:6968
+#: c/c-decl.c:6988
 #, fuzzy, gcc-internal-format
 msgid "cannot inline function %<main%>"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το αρχείο fifo `%s'"
 
-#: c/c-decl.c:6970
+#: c/c-decl.c:6990
 #, gcc-internal-format
 msgid "%<main%> declared %<_Noreturn%>"
 msgstr ""
 
-#: c/c-decl.c:6981
+#: c/c-decl.c:7001
 #, fuzzy, gcc-internal-format
 msgid "ISO C99 does not support %<_Noreturn%>"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.c:6984
+#: c/c-decl.c:7004
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support %<_Noreturn%>"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.c:7013
+#: c/c-decl.c:7033
 #, gcc-internal-format
 msgid "variable previously declared %<static%> redeclared %<extern%>"
 msgstr ""
 
-#: c/c-decl.c:7023
+#: c/c-decl.c:7043
 #, fuzzy, gcc-internal-format
 msgid "variable %q+D declared %<inline%>"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: c/c-decl.c:7025
+#: c/c-decl.c:7045
 #, fuzzy, gcc-internal-format
 msgid "variable %q+D declared %<_Noreturn%>"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: c/c-decl.c:7060
+#: c/c-decl.c:7080
 #, gcc-internal-format
 msgid "non-nested function with variably modified type"
 msgstr ""
 
-#: c/c-decl.c:7062
+#: c/c-decl.c:7082
 #, gcc-internal-format
 msgid "object with variably modified type must have no linkage"
 msgstr ""
 
-#: c/c-decl.c:7153 c/c-decl.c:8821
+#: c/c-decl.c:7173 c/c-decl.c:8841
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr ""
 
-#: c/c-decl.c:7163
+#: c/c-decl.c:7183
 #, gcc-internal-format
 msgid "parameter names (without types) in function declaration"
 msgstr ""
 
-#: c/c-decl.c:7201
+#: c/c-decl.c:7221
 #, fuzzy, gcc-internal-format
 msgid "parameter %u (%q+D) has incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: c/c-decl.c:7205
+#: c/c-decl.c:7225
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: c/c-decl.c:7216
+#: c/c-decl.c:7236
 #, fuzzy, gcc-internal-format
 msgid "parameter %u (%q+D) has void type"
 msgstr "μη πλήρης εγγραφή"
 
-#: c/c-decl.c:7220
+#: c/c-decl.c:7240
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has void type"
 msgstr "μη πλήρης εγγραφή"
 
-#: c/c-decl.c:7294
+#: c/c-decl.c:7314
 #, gcc-internal-format
 msgid "%<void%> as only parameter may not be qualified"
 msgstr ""
 
-#: c/c-decl.c:7298 c/c-decl.c:7334
+#: c/c-decl.c:7318 c/c-decl.c:7354
 #, gcc-internal-format
 msgid "%<void%> must be the only parameter"
 msgstr ""
 
-#: c/c-decl.c:7328
+#: c/c-decl.c:7348
 #, gcc-internal-format
 msgid "parameter %q+D has just a forward declaration"
 msgstr ""
 
-#: c/c-decl.c:7374
+#: c/c-decl.c:7394
 #, gcc-internal-format
 msgid "%<%s %E%> declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr ""
 
-#: c/c-decl.c:7380
+#: c/c-decl.c:7400
 #, gcc-internal-format, gfc-internal-format
 msgid "anonymous %s declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr ""
 
-#: c/c-decl.c:7482
+#: c/c-decl.c:7502
 #, fuzzy, gcc-internal-format
 msgid "enum type defined here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: c/c-decl.c:7488
+#: c/c-decl.c:7508
 #, fuzzy, gcc-internal-format
 msgid "struct defined here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: c/c-decl.c:7494
+#: c/c-decl.c:7514
 #, fuzzy, gcc-internal-format
 msgid "union defined here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: c/c-decl.c:7570
+#: c/c-decl.c:7590
 #, fuzzy, gcc-internal-format
 msgid "redefinition of %<union %E%>"
 msgstr "Οι ορισμοί πηγή βρίσκονται στο ΑΡΧΕΙΟ"
 
-#: c/c-decl.c:7572
+#: c/c-decl.c:7592
 #, fuzzy, gcc-internal-format
 msgid "redefinition of %<struct %E%>"
 msgstr "κανένας ορισμός του `UNDEFINED'"
 
-#: c/c-decl.c:7581
+#: c/c-decl.c:7601
 #, fuzzy, gcc-internal-format
 msgid "nested redefinition of %<union %E%>"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: c/c-decl.c:7583
+#: c/c-decl.c:7603
 #, fuzzy, gcc-internal-format
 msgid "nested redefinition of %<struct %E%>"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: c/c-decl.c:7613 c/c-decl.c:8400
+#: c/c-decl.c:7633 c/c-decl.c:8420
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr ""
 
-#: c/c-decl.c:7680 cp/decl.c:4802
+#: c/c-decl.c:7700 cp/decl.c:4802
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr ""
 
-#: c/c-decl.c:7685
+#: c/c-decl.c:7705
 #, fuzzy, gcc-internal-format
 msgid "ISO C99 doesn%'t support unnamed structs/unions"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.c:7688
+#: c/c-decl.c:7708
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 doesn%'t support unnamed structs/unions"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.c:7781 c/c-decl.c:7799 c/c-decl.c:7860
+#: c/c-decl.c:7801 c/c-decl.c:7819 c/c-decl.c:7880
 #, fuzzy, gcc-internal-format
 msgid "duplicate member %q+D"
 msgstr "διπλός αριθμός μηνύματος"
 
-#: c/c-decl.c:7886
+#: c/c-decl.c:7906
 #, gcc-internal-format
 msgid "empty struct has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.c:7889
+#: c/c-decl.c:7909
 #, gcc-internal-format
 msgid "empty union has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.c:7994
+#: c/c-decl.c:8014
 #, fuzzy, gcc-internal-format
 msgid "union has no named members"
 msgstr "επώνυμα μέλη"
 
-#: c/c-decl.c:7996
+#: c/c-decl.c:8016
 #, fuzzy, gcc-internal-format
 msgid "union has no members"
 msgstr "επώνυμα μέλη"
 
-#: c/c-decl.c:8001
+#: c/c-decl.c:8021
 #, fuzzy, gcc-internal-format
 msgid "struct has no named members"
 msgstr "επώνυμα μέλη"
 
 # src/request.c:37
-#: c/c-decl.c:8003
+#: c/c-decl.c:8023
 #, fuzzy, gcc-internal-format
 msgid "struct has no members"
 msgstr "%s σε %s"
 
-#: c/c-decl.c:8064 cp/decl.c:12069
+#: c/c-decl.c:8084 cp/decl.c:12093
 #, fuzzy, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: c/c-decl.c:8070
+#: c/c-decl.c:8090
 #, fuzzy, gcc-internal-format
 msgid "flexible array member not at end of struct"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: c/c-decl.c:8076
+#: c/c-decl.c:8096
 #, fuzzy, gcc-internal-format
 msgid "flexible array member in a struct with no named members"
 msgstr "μη έγκυρη ώρα της μέρας"
 
 # src/shred.c:1134
-#: c/c-decl.c:8107
+#: c/c-decl.c:8127
 #, fuzzy, gcc-internal-format
 msgid "type %qT is too large"
 msgstr "%s: το αρχείο είναι πολύ μεγάλο"
 
-#: c/c-decl.c:8230
+#: c/c-decl.c:8250
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr ""
 
-#: c/c-decl.c:8372
+#: c/c-decl.c:8392
 #, fuzzy, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
 #. This enum is a named one that has been declared already.
-#: c/c-decl.c:8379
+#: c/c-decl.c:8399
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: c/c-decl.c:8458 cp/decl.c:14423
+#: c/c-decl.c:8478 cp/decl.c:14447
 #, gcc-internal-format
 msgid "specified mode too small for enumeral values"
 msgstr ""
 
-#: c/c-decl.c:8473
+#: c/c-decl.c:8493
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr ""
 
-#: c/c-decl.c:8587 c/c-decl.c:8603
+#: c/c-decl.c:8607 c/c-decl.c:8623
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: c/c-decl.c:8598
+#: c/c-decl.c:8618
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: c/c-decl.c:8622
+#: c/c-decl.c:8642
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr ""
 
-#: c/c-decl.c:8630
+#: c/c-decl.c:8650
 #, gcc-internal-format
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr ""
 
-#: c/c-decl.c:8715 cp/decl.c:5104 cp/decl.c:14955
+#: c/c-decl.c:8735 cp/decl.c:5104 cp/decl.c:14979
 #, fuzzy, gcc-internal-format
 msgid "inline function %qD given attribute noinline"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: c/c-decl.c:8733
+#: c/c-decl.c:8753
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr ""
 
-#: c/c-decl.c:8744
+#: c/c-decl.c:8764
 #, fuzzy, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr "ο επιστρεφόμενος τύπος προκαθορίζεται σε `int'"
 
-#: c/c-decl.c:8771
+#: c/c-decl.c:8791
 #, gcc-internal-format
 msgid "%q+D defined as variadic function without prototype"
 msgstr ""
 
-#: c/c-decl.c:8830
+#: c/c-decl.c:8850
 #, fuzzy, gcc-internal-format
 msgid "no previous prototype for %qD"
 msgstr "διατήρηση ωρών στο %s"
 
-#: c/c-decl.c:8839
+#: c/c-decl.c:8859
 #, fuzzy, gcc-internal-format
 msgid "%qD was used with no prototype before its definition"
 msgstr "αυτή είναι η θέση του πρώτου ορισμού"
 
-#: c/c-decl.c:8847 cp/decl.c:15090
+#: c/c-decl.c:8867 cp/decl.c:15114
 #, fuzzy, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: c/c-decl.c:8857
+#: c/c-decl.c:8877
 #, fuzzy, gcc-internal-format
 msgid "%qD was used with no declaration before its definition"
 msgstr "αυτή είναι η θέση του πρώτου ορισμού"
 
-#: c/c-decl.c:8876
+#: c/c-decl.c:8896
 #, fuzzy, gcc-internal-format
 msgid "return type of %qD is not %<int%>"
 msgstr "η επιστρεφόμενη τιμή της `%s' δεν είναι `int'"
 
-#: c/c-decl.c:8878
+#: c/c-decl.c:8898
 #, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr ""
 
-#: c/c-decl.c:8885
+#: c/c-decl.c:8905
 #, fuzzy, gcc-internal-format
 msgid "%qD is normally a non-static function"
 msgstr "η `%s' είναι συνήθως μη-στατική συνάρτηση"
 
-#: c/c-decl.c:8922
+#: c/c-decl.c:8942
 #, gcc-internal-format
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr ""
 
-#: c/c-decl.c:8937
+#: c/c-decl.c:8957
 #, gcc-internal-format
 msgid "traditional C rejects ISO C style function definitions"
 msgstr ""
 
-#: c/c-decl.c:8953
+#: c/c-decl.c:8973
 #, fuzzy, gcc-internal-format
 msgid "parameter name omitted"
 msgstr "έχει παραληφθεί το όνομα της παραμέτρου"
 
-#: c/c-decl.c:8990
+#: c/c-decl.c:9010
 #, fuzzy, gcc-internal-format
 msgid "old-style function definition"
 msgstr "Μη έγκυρη ανταλλαγή"
 
-#: c/c-decl.c:8999
+#: c/c-decl.c:9019
 #, fuzzy, gcc-internal-format
 msgid "parameter name missing from parameter list"
 msgstr "Ελλιπής ή κακοσχηματισμένη ιδιότητα"
 
-#: c/c-decl.c:9015
+#: c/c-decl.c:9035
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a non-parameter"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: c/c-decl.c:9023
+#: c/c-decl.c:9043
 #, fuzzy, gcc-internal-format
 msgid "multiple parameters named %qD"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: c/c-decl.c:9032
+#: c/c-decl.c:9052
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD declared with void type"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: c/c-decl.c:9061 c/c-decl.c:9066
+#: c/c-decl.c:9081 c/c-decl.c:9086
 #, fuzzy, gcc-internal-format
 msgid "type of %qD defaults to %<int%>"
 msgstr "ο επιστρεφόμενος τύπος προκαθορίζεται σε `int'"
 
-#: c/c-decl.c:9086
+#: c/c-decl.c:9106
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD has incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: c/c-decl.c:9093
+#: c/c-decl.c:9113
 #, fuzzy, gcc-internal-format
 msgid "declaration for parameter %qD but no such parameter"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: c/c-decl.c:9146
+#: c/c-decl.c:9166
 #, fuzzy, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr "λάθος αριθμός ορισμάτων"
 
-#: c/c-decl.c:9157
+#: c/c-decl.c:9177
 #, fuzzy, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr "λάθος αριθμός ορισμάτων"
 
-#: c/c-decl.c:9160 c/c-decl.c:9207 c/c-decl.c:9221
+#: c/c-decl.c:9180 c/c-decl.c:9227 c/c-decl.c:9241
 #, fuzzy, gcc-internal-format
 msgid "prototype declaration"
 msgstr "κενό αλφαριθμητικό"
 
-#: c/c-decl.c:9199
+#: c/c-decl.c:9219
 #, fuzzy, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr "λάθος αριθμός ορισμάτων"
 
-#: c/c-decl.c:9204
+#: c/c-decl.c:9224
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr ""
 
-#: c/c-decl.c:9214
+#: c/c-decl.c:9234
 #, fuzzy, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr "λάθος αριθμός ορισμάτων"
 
-#: c/c-decl.c:9219
+#: c/c-decl.c:9239
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr ""
 
-#: c/c-decl.c:9470 cp/decl.c:15873
+#: c/c-decl.c:9490 cp/decl.c:15897
 #, fuzzy, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "`return' χωρίς τιμή, σε συνάρτηση που επιστρέφει μη-κενό"
 
-#: c/c-decl.c:9490 cp/decl.c:15905
+#: c/c-decl.c:9510 cp/decl.c:15929
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "έχουν παραληφθεί ορίσματα"
@@ -35451,247 +35493,247 @@
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:9586
+#: c/c-decl.c:9606
 #, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr ""
 
-#: c/c-decl.c:9591
+#: c/c-decl.c:9611
 #, gcc-internal-format
 msgid "use option -std=c99, -std=gnu99, -std=c11 or -std=gnu11 to compile your code"
 msgstr ""
 
-#: c/c-decl.c:9626
+#: c/c-decl.c:9646
 #, fuzzy, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: c/c-decl.c:9630
+#: c/c-decl.c:9650
 #, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:9637
+#: c/c-decl.c:9657
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:9642
+#: c/c-decl.c:9662
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:9646
+#: c/c-decl.c:9666
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:9650
+#: c/c-decl.c:9670
 #, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr ""
 
-#: c/c-decl.c:9900
+#: c/c-decl.c:9920
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr ""
 
-#: c/c-decl.c:9958 c/c-decl.c:9965
+#: c/c-decl.c:9978 c/c-decl.c:9985
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qE declaration specifier"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: c/c-decl.c:9992 c/c-decl.c:10376 c/c-decl.c:10766
+#: c/c-decl.c:10012 c/c-decl.c:10396 c/c-decl.c:10786
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr ""
 
-#: c/c-decl.c:10004 cp/parser.c:28261
+#: c/c-decl.c:10024 cp/parser.c:28258
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr ""
 
-#: c/c-decl.c:10017
+#: c/c-decl.c:10037
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.c:10246 c/c-parser.c:8848
+#: c/c-decl.c:10266 c/c-parser.c:8848
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.c:10292
+#: c/c-decl.c:10312
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.c:10363 c/c-decl.c:10923
+#: c/c-decl.c:10383 c/c-decl.c:10943
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "διπλό κλειδί"
 
-#: c/c-decl.c:10419
+#: c/c-decl.c:10439
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.c:10441
+#: c/c-decl.c:10461
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: c/c-decl.c:10484
+#: c/c-decl.c:10504
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support boolean types"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.c:10603
+#: c/c-decl.c:10623
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support the %<_Float%d%s%> type"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.c:10653
+#: c/c-decl.c:10673
 #, fuzzy, gcc-internal-format
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: c/c-decl.c:10724
+#: c/c-decl.c:10744
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support decimal floating point"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.c:10747 c/c-decl.c:11013 c/c-parser.c:7842
+#: c/c-decl.c:10767 c/c-decl.c:11033 c/c-parser.c:7842
 #, fuzzy, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: c/c-decl.c:10749
+#: c/c-decl.c:10769
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.c:10784
+#: c/c-decl.c:10804
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr ""
 
-#: c/c-decl.c:10797
+#: c/c-decl.c:10817
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr ""
 
-#: c/c-decl.c:10845
+#: c/c-decl.c:10865
 #, fuzzy, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: c/c-decl.c:10866
+#: c/c-decl.c:10886
 #, fuzzy, gcc-internal-format
 msgid "%qE used with %<auto%>"
 msgstr "σφάλμα εγγραφής %s"
 
-#: c/c-decl.c:10868
+#: c/c-decl.c:10888
 #, gcc-internal-format
 msgid "%qE used with %<register%>"
 msgstr ""
 
-#: c/c-decl.c:10870
+#: c/c-decl.c:10890
 #, gcc-internal-format
 msgid "%qE used with %<typedef%>"
 msgstr ""
 
-#: c/c-decl.c:10884 c/c-parser.c:7360
+#: c/c-decl.c:10904 c/c-parser.c:7360
 #, fuzzy, gcc-internal-format
 msgid "ISO C99 does not support %qE"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.c:10887 c/c-parser.c:7363
+#: c/c-decl.c:10907 c/c-parser.c:7363
 #, fuzzy, gcc-internal-format
 msgid "ISO C90 does not support %qE"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-decl.c:10899
+#: c/c-decl.c:10919
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr ""
 
-#: c/c-decl.c:10908
+#: c/c-decl.c:10928
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr ""
 
-#: c/c-decl.c:10921
+#: c/c-decl.c:10941
 #, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr ""
 
-#: c/c-decl.c:10929
+#: c/c-decl.c:10949
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr ""
 
-#: c/c-decl.c:10937
+#: c/c-decl.c:10957
 #, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr ""
 
-#: c/c-decl.c:11010
+#: c/c-decl.c:11030
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr ""
 
-#: c/c-decl.c:11025
+#: c/c-decl.c:11045
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr ""
 
-#: c/c-decl.c:11076 c/c-decl.c:11092 c/c-decl.c:11118
+#: c/c-decl.c:11096 c/c-decl.c:11112 c/c-decl.c:11138
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr ""
 
-#: c/c-decl.c:11514 cp/semantics.c:5348
+#: c/c-decl.c:11534 cp/semantics.c:5351
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:11518 cp/semantics.c:5352
+#: c/c-decl.c:11538 cp/semantics.c:5355
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.c:385 c/c-typeck.c:11426 cp/typeck.c:4680
+#: c/c-fold.c:385 c/c-typeck.c:11431 cp/typeck.c:4680
 #, gcc-internal-format
 msgid "left shift of negative value"
 msgstr ""
 
-#: c/c-fold.c:395 c/c-typeck.c:11435 cp/typeck.c:4688
+#: c/c-fold.c:395 c/c-typeck.c:11440 cp/typeck.c:4688
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr ""
 
-#: c/c-fold.c:396 c/c-typeck.c:11365 cp/typeck.c:4633
+#: c/c-fold.c:396 c/c-typeck.c:11370 cp/typeck.c:4633
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr ""
 
-#: c/c-fold.c:404 c/c-typeck.c:11454 cp/typeck.c:4696
+#: c/c-fold.c:404 c/c-typeck.c:11459 cp/typeck.c:4696
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr ""
 
-#: c/c-fold.c:405 c/c-typeck.c:11389 cp/typeck.c:4641
+#: c/c-fold.c:405 c/c-typeck.c:11394 cp/typeck.c:4641
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr ""
 
-#: c/c-fold.c:412 c/c-typeck.c:11446
+#: c/c-fold.c:412 c/c-typeck.c:11451
 #, gcc-internal-format
 msgid "left shift count >= width of vector element"
 msgstr ""
 
-#: c/c-fold.c:413 c/c-typeck.c:11376
+#: c/c-fold.c:413 c/c-typeck.c:11381
 #, gcc-internal-format
 msgid "right shift count >= width of vector element"
 msgstr ""
@@ -35711,7 +35753,7 @@
 msgid "to match this %qs"
 msgstr ""
 
-#: c/c-parser.c:1216 cp/parser.c:28484
+#: c/c-parser.c:1216 cp/parser.c:28481
 #, fuzzy, gcc-internal-format
 msgid "expected end of line"
 msgstr "Μη ορισμένο όνομα %s"
@@ -35752,7 +35794,7 @@
 msgstr "άγνωστος χαρακτήρας `%s'"
 
 #: c/c-parser.c:1848 c/c-parser.c:11129 c/c-parser.c:16147 c/c-parser.c:16585
-#: c/c-parser.c:17061 cp/parser.c:36007 cp/parser.c:38993
+#: c/c-parser.c:17061 cp/parser.c:36004 cp/parser.c:38990
 #, fuzzy, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "δημιουργία αρχείου `%s'\n"
@@ -35767,7 +35809,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr ""
 
-#: c/c-parser.c:1906 cp/parser.c:30161 cp/parser.c:30235
+#: c/c-parser.c:1906 cp/parser.c:30158 cp/parser.c:30232
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "το `%s' είναι πρόγονος του `%s'"
@@ -35821,7 +35863,7 @@
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr ""
 
-#: c/c-parser.c:2220 cp/parser.c:13002 cp/parser.c:13159
+#: c/c-parser.c:2220 cp/parser.c:12999 cp/parser.c:13156
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr ""
@@ -35849,7 +35891,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38634
+#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38631
 #, fuzzy, gcc-internal-format
 msgid "expected string literal"
 msgstr "μη τερματιζόμενo αλφαριθμητικό"
@@ -35913,13 +35955,13 @@
 #: c/c-parser.c:10745 c/c-parser.c:10798 c/c-parser.c:10814 c/c-parser.c:10860
 #: c/c-parser.c:11496 c/c-parser.c:11537 c/c-parser.c:13445 c/c-parser.c:13681
 #: c/c-parser.c:15544 c/c-parser.c:18218 c/gimple-parser.c:1058
-#: c/gimple-parser.c:1096 cp/parser.c:28487 cp/parser.c:31013
-#: cp/parser.c:31043 cp/parser.c:31113 cp/parser.c:33230 cp/parser.c:38350
+#: c/gimple-parser.c:1096 cp/parser.c:28484 cp/parser.c:31010
+#: cp/parser.c:31040 cp/parser.c:31110 cp/parser.c:33227 cp/parser.c:38347
 #, fuzzy, gcc-internal-format
 msgid "expected identifier"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c/c-parser.c:2995 cp/parser.c:18384
+#: c/c-parser.c:2995 cp/parser.c:18381
 #, fuzzy, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "σκουπίδια στο τέλος του αριθμού"
@@ -36088,12 +36130,12 @@
 msgid "expected statement"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c/c-parser.c:5639 cp/parser.c:12516
+#: c/c-parser.c:5639 cp/parser.c:12513
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr ""
 
-#: c/c-parser.c:5681 cp/parser.c:12519
+#: c/c-parser.c:5681 cp/parser.c:12516
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr ""
@@ -36432,7 +36474,7 @@
 msgid "%<__builtin_complex%> operands of different types"
 msgstr ""
 
-#: c/c-parser.c:8891 cp/parser.c:6918
+#: c/c-parser.c:8891 cp/parser.c:6921
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_shuffle%>"
 msgstr "λάθος αριθμός ορισμάτων"
@@ -36492,76 +36534,76 @@
 msgid "no type or storage class may be specified here,"
 msgstr "Εγγραφή ονομάτων των επιλεγμένων λέξεων-κλειδιών"
 
-#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31073
+#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31070
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr ""
 
-#: c/c-parser.c:10682 cp/parser.c:31033
+#: c/c-parser.c:10682 cp/parser.c:31030
 #, fuzzy, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "κακοδιαμορφωμένη γραμμή αγνοήθηκε"
 
-#: c/c-parser.c:10685 cp/parser.c:31036
+#: c/c-parser.c:10685 cp/parser.c:31033
 #, fuzzy, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "κακοδιαμορφωμένη γραμμή αγνοήθηκε"
 
-#: c/c-parser.c:10699 cp/parser.c:31051
+#: c/c-parser.c:10699 cp/parser.c:31048
 #, fuzzy, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: c/c-parser.c:10704 cp/parser.c:31057
+#: c/c-parser.c:10704 cp/parser.c:31054
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.c:10711 cp/parser.c:31065
+#: c/c-parser.c:10711 cp/parser.c:31062
 #, fuzzy, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: c/c-parser.c:10905 cp/parser.c:38674
+#: c/c-parser.c:10905 cp/parser.c:38671
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
 #: c/c-parser.c:10949 c/c-parser.c:16582 c/c-parser.c:16840 c/c-parser.c:16899
-#: c/c-parser.c:16983 cp/parser.c:36004 cp/parser.c:36298 cp/parser.c:36386
-#: cp/parser.c:36457 cp/parser.c:38721 cp/parser.c:38736 cp/parser.c:38752
-#: cp/parser.c:38768 cp/parser.c:38784 cp/parser.c:38811 cp/parser.c:38824
-#: cp/parser.c:38847 cp/parser.c:38860
+#: c/c-parser.c:16983 cp/parser.c:36001 cp/parser.c:36295 cp/parser.c:36383
+#: cp/parser.c:36454 cp/parser.c:38718 cp/parser.c:38733 cp/parser.c:38749
+#: cp/parser.c:38765 cp/parser.c:38781 cp/parser.c:38808 cp/parser.c:38821
+#: cp/parser.c:38844 cp/parser.c:38857
 #, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:10972 cp/parser.c:38837
+#: c/c-parser.c:10972 cp/parser.c:38834
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr ""
 
-#: c/c-parser.c:11050 cp/parser.c:38918
+#: c/c-parser.c:11050 cp/parser.c:38915
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr ""
 
-#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38947 cp/parser.c:38980
+#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38944 cp/parser.c:38977
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr ""
 
-#: c/c-parser.c:11111 cp/parser.c:38711
+#: c/c-parser.c:11111 cp/parser.c:38708
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "κακοδιαμορφωμένη γραμμή αγνοήθηκε"
 
-#: c/c-parser.c:11421 cp/parser.c:31457
+#: c/c-parser.c:11421 cp/parser.c:31454
 #, fuzzy, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "πάρα πολλά ορίσματα"
 
-#: c/c-parser.c:11443 cp/parser.c:31994
+#: c/c-parser.c:11443 cp/parser.c:31991
 #, fuzzy, gcc-internal-format
 msgid "expected integer expression before ')'"
 msgstr "Μη έγκυρη κανονική έκφραση"
@@ -36576,53 +36618,53 @@
 msgid "%qD is not a variable"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: c/c-parser.c:11746 cp/semantics.c:6808
+#: c/c-parser.c:11746 cp/semantics.c:6811
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: c/c-parser.c:11788 cp/parser.c:32073
+#: c/c-parser.c:11788 cp/parser.c:32070
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:11865 cp/parser.c:32137
+#: c/c-parser.c:11865 cp/parser.c:32134
 #, gcc-internal-format
 msgid "expected %<none%> or %<present%>"
 msgstr ""
 
-#: c/c-parser.c:11867 cp/parser.c:32139
+#: c/c-parser.c:11867 cp/parser.c:32136
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr ""
 
-#: c/c-parser.c:11968 cp/parser.c:32242
+#: c/c-parser.c:11968 cp/parser.c:32239
 #, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr ""
 
-#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32260
-#: cp/parser.c:36290 cp/parser.c:36378
+#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32257
+#: cp/parser.c:36287 cp/parser.c:36375
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c/c-parser.c:12035 cp/parser.c:32313
+#: c/c-parser.c:12035 cp/parser.c:32310
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:12042 cp/parser.c:32320
+#: c/c-parser.c:12042 cp/parser.c:32317
 #, fuzzy, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr "πάρα πολλά ορίσματα"
 
-#: c/c-parser.c:12044 cp/parser.c:32322
+#: c/c-parser.c:12044 cp/parser.c:32319
 #, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr ""
 
-#: c/c-parser.c:12050 cp/parser.c:32328
+#: c/c-parser.c:12050 cp/parser.c:32325
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -36644,82 +36686,82 @@
 msgid "%<num_tasks%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:12229 cp/semantics.c:6992
+#: c/c-parser.c:12229 cp/semantics.c:6995
 #, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:12276 cp/semantics.c:7021
+#: c/c-parser.c:12276 cp/semantics.c:7024
 #, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr ""
 
-#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32545 cp/parser.c:32552
+#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32542 cp/parser.c:32549
 #, gcc-internal-format
 msgid "expected %<tofrom%>"
 msgstr ""
 
-#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32561 cp/parser.c:32568
+#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32558 cp/parser.c:32565
 #, gcc-internal-format
 msgid "expected %<scalar%>"
 msgstr ""
 
-#: c/c-parser.c:12425 cp/semantics.c:6299
+#: c/c-parser.c:12425 cp/semantics.c:6302
 #, fuzzy, gcc-internal-format
 msgid "%qs expression must be integral"
 msgstr "Λάθος έκφραση στην αποτίμηση: %s"
 
-#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6331
+#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6334
 #, gcc-internal-format
 msgid "%qs value must be positive"
 msgstr ""
 
-#: c/c-parser.c:12499 cp/parser.c:31853
+#: c/c-parser.c:12499 cp/parser.c:31850
 #, fuzzy, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "πάρα πολλά ορίσματα"
 
-#: c/c-parser.c:12533 cp/parser.c:31886
+#: c/c-parser.c:12533 cp/parser.c:31883
 #, fuzzy, gcc-internal-format
 msgid "unexpected argument"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: c/c-parser.c:12699 cp/semantics.c:7120
+#: c/c-parser.c:12699 cp/semantics.c:7123
 #, fuzzy, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: c/c-parser.c:12765 cp/parser.c:32626
+#: c/c-parser.c:12765 cp/parser.c:32623
 #, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37643
+#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37640
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr ""
 
-#: c/c-parser.c:12967 cp/parser.c:32840
+#: c/c-parser.c:12967 cp/parser.c:32837
 #, fuzzy, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "μη έγκυρος δηλωτής πεδίου: `%s'"
 
-#: c/c-parser.c:13021 cp/parser.c:32856
+#: c/c-parser.c:13021 cp/parser.c:32853
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:13025 cp/parser.c:32859
+#: c/c-parser.c:13025 cp/parser.c:32856
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:13037 cp/semantics.c:6389
+#: c/c-parser.c:13037 cp/semantics.c:6392
 #, gcc-internal-format
 msgid "chunk size value must be positive"
 msgstr ""
 
-#: c/c-parser.c:13060 cp/parser.c:32879
+#: c/c-parser.c:13060 cp/parser.c:32876
 #, fuzzy, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "μη έγκυρο δικαίωμα"
@@ -36729,12 +36771,12 @@
 msgid "%<num_teams%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:13226 cp/semantics.c:6479
+#: c/c-parser.c:13226 cp/semantics.c:6482
 #, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:13271 cp/semantics.c:6589
+#: c/c-parser.c:13271 cp/semantics.c:6592
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr ""
@@ -36754,17 +36796,17 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:13584 cp/parser.c:33374 cp/parser.c:33599
+#: c/c-parser.c:13584 cp/parser.c:33371 cp/parser.c:33596
 #, fuzzy, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "μη έγκυρος χρήστης"
 
-#: c/c-parser.c:13669 cp/parser.c:33447
+#: c/c-parser.c:13669 cp/parser.c:33444
 #, fuzzy, gcc-internal-format
 msgid "invalid map kind"
 msgstr "μη έγκυρος χρήστης"
 
-#: c/c-parser.c:13767 cp/parser.c:33546
+#: c/c-parser.c:13767 cp/parser.c:33543
 #, fuzzy, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "Μη έγκυρη ημερομηνία `%s'."
@@ -36774,67 +36816,67 @@
 msgid "invalid proc_bind kind"
 msgstr "Μη έγκυρη ημερομηνία `%s'."
 
-#: c/c-parser.c:14059 cp/parser.c:33825
+#: c/c-parser.c:14059 cp/parser.c:33822
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33836 cp/parser.c:34143
+#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33833 cp/parser.c:34140
 #, fuzzy, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: c/c-parser.c:14214 cp/parser.c:34010
+#: c/c-parser.c:14214 cp/parser.c:34007
 #, fuzzy, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: c/c-parser.c:14334 cp/parser.c:34132
+#: c/c-parser.c:14334 cp/parser.c:34129
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c/c-parser.c:14472 cp/parser.c:36803
+#: c/c-parser.c:14472 cp/parser.c:36800
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14482 cp/parser.c:36813
+#: c/c-parser.c:14482 cp/parser.c:36810
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14502 cp/parser.c:36833
+#: c/c-parser.c:14502 cp/parser.c:36830
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr ""
 
-#: c/c-parser.c:14513 cp/parser.c:36844
+#: c/c-parser.c:14513 cp/parser.c:36841
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr ""
 
-#: c/c-parser.c:14520 cp/parser.c:36851
+#: c/c-parser.c:14520 cp/parser.c:36848
 #, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14528 cp/parser.c:36859
+#: c/c-parser.c:14528 cp/parser.c:36856
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: c/c-parser.c:14540 cp/parser.c:36871
+#: c/c-parser.c:14540 cp/parser.c:36868
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14632 cp/parser.c:36957
+#: c/c-parser.c:14632 cp/parser.c:36954
 #, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr ""
 
-#: c/c-parser.c:14648 cp/parser.c:36974
+#: c/c-parser.c:14648 cp/parser.c:36971
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr ""
@@ -36849,7 +36891,7 @@
 msgid "expected function name"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c/c-parser.c:14893 cp/parser.c:38064
+#: c/c-parser.c:14893 cp/parser.c:38061
 #, fuzzy, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr "Το `%s' δεν είναι κατάλογος."
@@ -36859,42 +36901,42 @@
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14953 cp/parser.c:38118 cp/parser.c:38160
+#: c/c-parser.c:14953 cp/parser.c:38115 cp/parser.c:38157
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14970 cp/parser.c:38174
+#: c/c-parser.c:14970 cp/parser.c:38171
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> already applied to %qD"
 msgstr ""
 
-#: c/c-parser.c:14979 cp/parser.c:38183
+#: c/c-parser.c:14979 cp/parser.c:38180
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr ""
 
-#: c/c-parser.c:14980 cp/parser.c:38184
+#: c/c-parser.c:14980 cp/parser.c:38181
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr ""
 
-#: c/c-parser.c:15023 cp/parser.c:37152
+#: c/c-parser.c:15023 cp/parser.c:37149
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
 
-#: c/c-parser.c:15435 cp/parser.c:34511 cp/parser.c:34537
+#: c/c-parser.c:15435 cp/parser.c:34508 cp/parser.c:34534
 #, fuzzy, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "κακοδιαμορφωμένη γραμμή αγνοήθηκε"
 
-#: c/c-parser.c:15439 cp/parser.c:34568 cp/parser.c:34584
+#: c/c-parser.c:15439 cp/parser.c:34565 cp/parser.c:34581
 #, fuzzy, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "κακοδιαμορφωμένη γραμμή αγνοήθηκε"
 
-#: c/c-parser.c:15488 cp/semantics.c:8401 cp/semantics.c:8411
+#: c/c-parser.c:15488 cp/semantics.c:8404 cp/semantics.c:8414
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
@@ -36904,22 +36946,22 @@
 msgid "expected %<(%> or end of line"
 msgstr ""
 
-#: c/c-parser.c:15619 cp/parser.c:35103
+#: c/c-parser.c:15619 cp/parser.c:35100
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:15630 cp/parser.c:35114
+#: c/c-parser.c:15630 cp/parser.c:35111
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:15648 cp/parser.c:35141
+#: c/c-parser.c:15648 cp/parser.c:35138
 #, fuzzy, gcc-internal-format
 msgid "for statement expected"
 msgstr "αναμενόταν ')'\n"
 
-#: c/c-parser.c:15718 cp/semantics.c:8066 cp/semantics.c:8153
+#: c/c-parser.c:15718 cp/semantics.c:8069 cp/semantics.c:8156
 #, fuzzy, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
@@ -36929,72 +36971,72 @@
 msgid "not enough perfectly nested loops"
 msgstr ""
 
-#: c/c-parser.c:15862 cp/parser.c:35364
+#: c/c-parser.c:15862 cp/parser.c:35361
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.c:15909 cp/parser.c:35184 cp/parser.c:35226 cp/pt.c:16385
+#: c/c-parser.c:15909 cp/parser.c:35181 cp/parser.c:35223 cp/pt.c:16407
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr ""
 
-#: c/c-parser.c:16000 cp/parser.c:35437
+#: c/c-parser.c:16000 cp/parser.c:35434
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr ""
 
-#: c/c-parser.c:16166 cp/parser.c:35600
+#: c/c-parser.c:16166 cp/parser.c:35597
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:16374 cp/parser.c:35799
+#: c/c-parser.c:16374 cp/parser.c:35796
 #, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr ""
 
-#: c/c-parser.c:16573 cp/parser.c:35995
+#: c/c-parser.c:16573 cp/parser.c:35992
 #, fuzzy, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: c/c-parser.c:16793 cp/parser.c:36232
+#: c/c-parser.c:16793 cp/parser.c:36229
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16806 cp/parser.c:36245
+#: c/c-parser.c:16806 cp/parser.c:36242
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16853 cp/parser.c:36470
+#: c/c-parser.c:16853 cp/parser.c:36467
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:16925 cp/parser.c:36325
+#: c/c-parser.c:16925 cp/parser.c:36322
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16937 cp/parser.c:36337
+#: c/c-parser.c:16937 cp/parser.c:36334
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17011 cp/parser.c:36414
+#: c/c-parser.c:17011 cp/parser.c:36411
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17024 cp/parser.c:36427
+#: c/c-parser.c:17024 cp/parser.c:36424
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:17238 cp/parser.c:36680
+#: c/c-parser.c:17238 cp/parser.c:36677
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -37014,32 +37056,32 @@
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17395 cp/parser.c:37273
+#: c/c-parser.c:17395 cp/parser.c:37270
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17474 cp/parser.c:37343
+#: c/c-parser.c:17474 cp/parser.c:37340
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> with clauses in between %<#pragma omp declare target%> without clauses and %<#pragma omp end declare target%>"
 msgstr ""
 
-#: c/c-parser.c:17493 cp/parser.c:37362
+#: c/c-parser.c:17493 cp/parser.c:37359
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17534 cp/parser.c:37409
+#: c/c-parser.c:17534 cp/parser.c:37406
 #, fuzzy, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c/c-parser.c:17541 cp/parser.c:37416
+#: c/c-parser.c:17541 cp/parser.c:37413
 #, fuzzy, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c/c-parser.c:17547 cp/parser.c:37423
+#: c/c-parser.c:17547 cp/parser.c:37420
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr ""
@@ -37094,47 +37136,47 @@
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:17947 cp/parser.c:37868
+#: c/c-parser.c:17947 cp/parser.c:37865
 #, gcc-internal-format
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr ""
 
-#: c/c-parser.c:18162 cp/semantics.c:7531
+#: c/c-parser.c:18162 cp/semantics.c:7534
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr ""
 
-#: c/c-parser.c:18164 cp/semantics.c:7533
+#: c/c-parser.c:18164 cp/semantics.c:7536
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr ""
 
-#: c/c-parser.c:18168 cp/semantics.c:7535
+#: c/c-parser.c:18168 cp/semantics.c:7538
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: c/c-parser.c:18368 cp/parser.c:38565
+#: c/c-parser.c:18368 cp/parser.c:38562
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:18374 cp/parser.c:38571
+#: c/c-parser.c:18374 cp/parser.c:38568
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
 
-#: c/c-parser.c:18383 cp/parser.c:38580
+#: c/c-parser.c:18383 cp/parser.c:38577
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.c:18385 cp/parser.c:38583
+#: c/c-parser.c:18385 cp/parser.c:38580
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.c:18391 cp/parser.c:38589
+#: c/c-parser.c:18391 cp/parser.c:38586
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
@@ -37149,7 +37191,7 @@
 msgid "%qD has an incomplete type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: c/c-typeck.c:237 c/c-typeck.c:9994 c/c-typeck.c:10036 cp/call.c:4147
+#: c/c-typeck.c:237 c/c-typeck.c:9999 c/c-typeck.c:10041 cp/call.c:4147
 #, fuzzy, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "Μη έγκυρη κανονική έκφραση"
@@ -37226,13 +37268,13 @@
 msgstr ""
 
 # src/main.c:697 src/main.c:751
-#: c/c-typeck.c:2417 c/c-typeck.c:8641
+#: c/c-typeck.c:2417 c/c-typeck.c:8646
 #, fuzzy, gcc-internal-format
 msgid "%qT has no member named %qE; did you mean %qE?"
 msgstr "Άγνωστη γλώσσα `%s'"
 
 # src/main.c:697 src/main.c:751
-#: c/c-typeck.c:2421 c/c-typeck.c:8645
+#: c/c-typeck.c:2421 c/c-typeck.c:8650
 #, fuzzy, gcc-internal-format
 msgid "%qT has no member named %qE"
 msgstr "Άγνωστη γλώσσα `%s'"
@@ -37432,464 +37474,464 @@
 msgid "pointer to a function used in subtraction"
 msgstr ""
 
-#: c/c-typeck.c:3847
+#: c/c-typeck.c:3852
 #, gcc-internal-format
 msgid "arithmetic on pointer to an incomplete type"
 msgstr ""
 
-#: c/c-typeck.c:3852 cp/typeck.c:5562
+#: c/c-typeck.c:3857 cp/typeck.c:5562
 #, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr ""
 
-#: c/c-typeck.c:4283
+#: c/c-typeck.c:4288
 #, fuzzy, gcc-internal-format
 msgid "%<~%> on a boolean expression"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
-#: c/c-typeck.c:4287
+#: c/c-typeck.c:4292
 #, gcc-internal-format
 msgid "did you mean to use logical not?"
 msgstr ""
 
-#: c/c-typeck.c:4296
+#: c/c-typeck.c:4301
 #, gcc-internal-format
 msgid "ISO C does not support %<~%> for complex conjugation"
 msgstr ""
 
-#: c/c-typeck.c:4335
+#: c/c-typeck.c:4340
 #, gcc-internal-format
 msgid "wrong type argument to unary exclamation mark"
 msgstr ""
 
-#: c/c-typeck.c:4393
+#: c/c-typeck.c:4398
 #, gcc-internal-format
 msgid "increment of enumeration value is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:4396
+#: c/c-typeck.c:4401
 #, gcc-internal-format
 msgid "decrement of enumeration value is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:4403
+#: c/c-typeck.c:4408
 #, fuzzy, gcc-internal-format
 msgid "increment of a boolean expression"
 msgstr "Μη αναγνωρίσιμη μεταβλητή `%s'"
 
-#: c/c-typeck.c:4406
+#: c/c-typeck.c:4411
 #, fuzzy, gcc-internal-format
 msgid "decrement of a boolean expression"
 msgstr "Εξαίρεση κινητής υποδιαστολής"
 
-#: c/c-typeck.c:4422
+#: c/c-typeck.c:4427
 #, gcc-internal-format
 msgid "ISO C does not support %<++%> and %<--%> on complex types"
 msgstr ""
 
-#: c/c-typeck.c:4447 c/c-typeck.c:4481
+#: c/c-typeck.c:4452 c/c-typeck.c:4486
 #, gcc-internal-format
 msgid "wrong type argument to increment"
 msgstr ""
 
-#: c/c-typeck.c:4449 c/c-typeck.c:4484
+#: c/c-typeck.c:4454 c/c-typeck.c:4489
 #, gcc-internal-format
 msgid "wrong type argument to decrement"
 msgstr ""
 
-#: c/c-typeck.c:4469
+#: c/c-typeck.c:4474
 #, fuzzy, gcc-internal-format
 msgid "increment of pointer to an incomplete type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: c/c-typeck.c:4473
+#: c/c-typeck.c:4478
 #, fuzzy, gcc-internal-format
 msgid "decrement of pointer to an incomplete type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: c/c-typeck.c:4577
+#: c/c-typeck.c:4582
 #, fuzzy, gcc-internal-format
 msgid "taking address of expression of type %<void%>"
 msgstr "αδυναμία ανάγνωσης καταλόγου locale `%s'"
 
-#: c/c-typeck.c:4636
+#: c/c-typeck.c:4641
 #, fuzzy, gcc-internal-format
 msgid "cannot take address of bit-field %qD"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το αρχείο fifo `%s'"
 
-#: c/c-typeck.c:4649
+#: c/c-typeck.c:4654
 #, gcc-internal-format
 msgid "cannot take address of scalar with reverse storage order"
 msgstr ""
 
-#: c/c-typeck.c:4657
+#: c/c-typeck.c:4662
 #, gcc-internal-format
 msgid "address of array with reverse scalar storage order requested"
 msgstr ""
 
-#: c/c-typeck.c:4838
+#: c/c-typeck.c:4843
 #, gcc-internal-format
 msgid "global register variable %qD used in nested function"
 msgstr ""
 
-#: c/c-typeck.c:4841
+#: c/c-typeck.c:4846
 #, gcc-internal-format
 msgid "register variable %qD used in nested function"
 msgstr ""
 
-#: c/c-typeck.c:4846
+#: c/c-typeck.c:4851
 #, gcc-internal-format
 msgid "address of global register variable %qD requested"
 msgstr ""
 
-#: c/c-typeck.c:4848
+#: c/c-typeck.c:4853
 #, gcc-internal-format
 msgid "address of register variable %qD requested"
 msgstr ""
 
-#: c/c-typeck.c:4951
+#: c/c-typeck.c:4956
 #, fuzzy, gcc-internal-format
 msgid "non-lvalue array in conditional expression"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
-#: c/c-typeck.c:5033
+#: c/c-typeck.c:5038
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other result of conditional"
 msgstr ""
 
-#: c/c-typeck.c:5092 c/c-typeck.c:5098
+#: c/c-typeck.c:5097 c/c-typeck.c:5103
 #, gcc-internal-format
 msgid "operand of ?: changes signedness from %qT to %qT due to unsignedness of other operand"
 msgstr ""
 
-#: c/c-typeck.c:5115
+#: c/c-typeck.c:5120
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr with only one void side"
 msgstr ""
 
-#: c/c-typeck.c:5132
+#: c/c-typeck.c:5137
 #, fuzzy, gcc-internal-format
 msgid "pointers to disjoint address spaces used in conditional expression"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
-#: c/c-typeck.c:5143 c/c-typeck.c:5160
+#: c/c-typeck.c:5148 c/c-typeck.c:5165
 #, fuzzy, gcc-internal-format
 msgid "pointer to array loses qualifier in conditional expression"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
-#: c/c-typeck.c:5148 c/c-typeck.c:5165
+#: c/c-typeck.c:5153 c/c-typeck.c:5170
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr between %<void *%> and function pointer"
 msgstr ""
 
-#: c/c-typeck.c:5178
+#: c/c-typeck.c:5183
 #, gcc-internal-format
 msgid "pointer type mismatch in conditional expression"
 msgstr ""
 
-#: c/c-typeck.c:5187 c/c-typeck.c:5198
+#: c/c-typeck.c:5192 c/c-typeck.c:5203
 #, gcc-internal-format
 msgid "pointer/integer type mismatch in conditional expression"
 msgstr ""
 
-#: c/c-typeck.c:5336
+#: c/c-typeck.c:5341
 #, gcc-internal-format
 msgid "left-hand operand of comma expression has no effect"
 msgstr ""
 
-#: c/c-typeck.c:5354 c/c-typeck.c:10636
+#: c/c-typeck.c:5359 c/c-typeck.c:10641
 #, gcc-internal-format
 msgid "right-hand operand of comma expression has no effect"
 msgstr ""
 
-#: c/c-typeck.c:5423
+#: c/c-typeck.c:5428
 msgid "cast adds %q#v qualifier to function type"
 msgstr ""
 
-#: c/c-typeck.c:5429
+#: c/c-typeck.c:5434
 msgid "cast discards %qv qualifier from pointer target type"
 msgstr ""
 
-#: c/c-typeck.c:5464
+#: c/c-typeck.c:5469
 #, gcc-internal-format
 msgid "to be safe all intermediate pointers in cast from %qT to %qT must be %<const%> qualified"
 msgstr ""
 
-#: c/c-typeck.c:5554
+#: c/c-typeck.c:5559
 #, gcc-internal-format
 msgid "cast specifies array type"
 msgstr ""
 
-#: c/c-typeck.c:5560
+#: c/c-typeck.c:5565
 #, gcc-internal-format
 msgid "cast specifies function type"
 msgstr ""
 
-#: c/c-typeck.c:5575
+#: c/c-typeck.c:5580
 #, gcc-internal-format
 msgid "ISO C forbids casting nonscalar to the same type"
 msgstr ""
 
-#: c/c-typeck.c:5595
+#: c/c-typeck.c:5600
 #, gcc-internal-format
 msgid "ISO C forbids casts to union type"
 msgstr ""
 
-#: c/c-typeck.c:5605
+#: c/c-typeck.c:5610
 #, gcc-internal-format
 msgid "cast to union type from type not present in union"
 msgstr ""
 
-#: c/c-typeck.c:5640
+#: c/c-typeck.c:5645
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint generic address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5645
+#: c/c-typeck.c:5650
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to generic address space pointer from disjoint %s address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5650
+#: c/c-typeck.c:5655
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint %s address space pointer"
 msgstr ""
 
-#: c/c-typeck.c:5670
+#: c/c-typeck.c:5675
 #, gcc-internal-format
 msgid "cast increases required alignment of target type"
 msgstr ""
 
-#: c/c-typeck.c:5681
+#: c/c-typeck.c:5686
 #, gcc-internal-format
 msgid "cast from pointer to integer of different size"
 msgstr ""
 
-#: c/c-typeck.c:5686
+#: c/c-typeck.c:5691
 #, gcc-internal-format
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr ""
 
-#: c/c-typeck.c:5695 cp/typeck.c:7811
+#: c/c-typeck.c:5700 cp/typeck.c:7811
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr ""
 
-#: c/c-typeck.c:5709
+#: c/c-typeck.c:5714
 #, gcc-internal-format
 msgid "ISO C forbids conversion of function pointer to object pointer type"
 msgstr ""
 
-#: c/c-typeck.c:5718
+#: c/c-typeck.c:5723
 #, gcc-internal-format
 msgid "ISO C forbids conversion of object pointer to function pointer type"
 msgstr ""
 
-#: c/c-typeck.c:5728
+#: c/c-typeck.c:5733
 #, fuzzy, gcc-internal-format
 msgid "cast between incompatible function types from %qT to %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: c/c-typeck.c:5815
+#: c/c-typeck.c:5820
 #, gcc-internal-format
 msgid "defining a type in a cast is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:5856
+#: c/c-typeck.c:5861
 #, gcc-internal-format
 msgid "assignment to expression with array type"
 msgstr ""
 
-#: c/c-typeck.c:5982
+#: c/c-typeck.c:5987
 #, gcc-internal-format
 msgid "enum conversion in assignment is invalid in C++"
 msgstr ""
 
 # src/request.c:263
-#: c/c-typeck.c:6180 c/c-typeck.c:6202 c/c-typeck.c:6226
+#: c/c-typeck.c:6185 c/c-typeck.c:6207 c/c-typeck.c:6231
 #, fuzzy, gcc-internal-format
 msgid "(near initialization for %qs)"
 msgstr "Το βήμα αρχικοποίησης απέτυχε"
 
-#: c/c-typeck.c:6241
+#: c/c-typeck.c:6246
 #, fuzzy, gcc-internal-format
 msgid "array initialized from parenthesized string constant"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: c/c-typeck.c:6284 c/c-typeck.c:6476 c/c-typeck.c:6908
+#: c/c-typeck.c:6289 c/c-typeck.c:6481 c/c-typeck.c:6913
 #, fuzzy, gcc-internal-format
 msgid "expected %qT but argument is of type %qT"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: c/c-typeck.c:6471
+#: c/c-typeck.c:6476
 #, gcc-internal-format
 msgid "enum conversion when passing argument %d of %qE is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:6480
+#: c/c-typeck.c:6485
 #, fuzzy, gcc-internal-format
 msgid "enum conversion from %qT to %qT in assignment is invalid in C++"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: c/c-typeck.c:6484
+#: c/c-typeck.c:6489
 #, fuzzy, gcc-internal-format
 msgid "enum conversion from %qT to %qT in initialization is invalid in C++"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: c/c-typeck.c:6489
+#: c/c-typeck.c:6494
 #, fuzzy, gcc-internal-format
 msgid "enum conversion from %qT to %qT in return is invalid in C++"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: c/c-typeck.c:6523
+#: c/c-typeck.c:6528
 #, fuzzy, gcc-internal-format
 msgid "cannot pass rvalue to reference parameter"
 msgstr "δεν είναι δυνατόν να γίνει `stat' το locale αρχείο `%s'"
 
-#: c/c-typeck.c:6656 c/c-typeck.c:6942
+#: c/c-typeck.c:6661 c/c-typeck.c:6947
 #, fuzzy
 msgid "passing argument %d of %qE makes %q#v qualified function pointer from unqualified"
 msgstr "%s μετατρέπει ακέραιο σε δείκτη χωρίς μετατροπέα"
 
-#: c/c-typeck.c:6659 c/c-typeck.c:6945
+#: c/c-typeck.c:6664 c/c-typeck.c:6950
 msgid "assignment makes %q#v qualified function pointer from unqualified"
 msgstr ""
 
-#: c/c-typeck.c:6662 c/c-typeck.c:6947
+#: c/c-typeck.c:6667 c/c-typeck.c:6952
 #, fuzzy
 msgid "initialization makes %q#v qualified function pointer from unqualified"
 msgstr "%s μετατρέπει ακέραιο σε δείκτη χωρίς μετατροπέα"
 
-#: c/c-typeck.c:6665 c/c-typeck.c:6949
+#: c/c-typeck.c:6670 c/c-typeck.c:6954
 msgid "return makes %q#v qualified function pointer from unqualified"
 msgstr ""
 
-#: c/c-typeck.c:6673 c/c-typeck.c:6840 c/c-typeck.c:6883
+#: c/c-typeck.c:6678 c/c-typeck.c:6845 c/c-typeck.c:6888
 #, fuzzy
 msgid "passing argument %d of %qE discards %qv qualifier from pointer target type"
 msgstr "%s μετατρέπει ακέραιο σε δείκτη χωρίς μετατροπέα"
 
-#: c/c-typeck.c:6675 c/c-typeck.c:6842 c/c-typeck.c:6885
+#: c/c-typeck.c:6680 c/c-typeck.c:6847 c/c-typeck.c:6890
 #, fuzzy
 msgid "assignment discards %qv qualifier from pointer target type"
 msgstr "%s μετατρέπει ακέραιο σε δείκτη χωρίς μετατροπέα"
 
-#: c/c-typeck.c:6677 c/c-typeck.c:6844 c/c-typeck.c:6887
+#: c/c-typeck.c:6682 c/c-typeck.c:6849 c/c-typeck.c:6892
 #, fuzzy
 msgid "initialization discards %qv qualifier from pointer target type"
 msgstr "%s μετατρέπει ακέραιο σε δείκτη χωρίς μετατροπέα"
 
-#: c/c-typeck.c:6679 c/c-typeck.c:6846 c/c-typeck.c:6889
+#: c/c-typeck.c:6684 c/c-typeck.c:6851 c/c-typeck.c:6894
 #, fuzzy
 msgid "return discards %qv qualifier from pointer target type"
 msgstr "%s μετατρέπει ακέραιο σε δείκτη χωρίς μετατροπέα"
 
-#: c/c-typeck.c:6688
+#: c/c-typeck.c:6693
 #, gcc-internal-format
 msgid "ISO C prohibits argument conversion to union type"
 msgstr ""
 
-#: c/c-typeck.c:6750
+#: c/c-typeck.c:6755
 #, fuzzy, gcc-internal-format
 msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: c/c-typeck.c:6762
+#: c/c-typeck.c:6767
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE from pointer to non-enclosed address space"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: c/c-typeck.c:6766
+#: c/c-typeck.c:6771
 #, gcc-internal-format
 msgid "assignment from pointer to non-enclosed address space"
 msgstr ""
 
-#: c/c-typeck.c:6770
+#: c/c-typeck.c:6775
 #, fuzzy, gcc-internal-format
 msgid "initialization from pointer to non-enclosed address space"
 msgstr "%s μετατρέπει ακέραιο σε δείκτη χωρίς μετατροπέα"
 
-#: c/c-typeck.c:6774
+#: c/c-typeck.c:6779
 #, gcc-internal-format
 msgid "return from pointer to non-enclosed address space"
 msgstr ""
 
-#: c/c-typeck.c:6792
+#: c/c-typeck.c:6797
 #, gcc-internal-format
 msgid "argument %d of %qE might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:6798
+#: c/c-typeck.c:6803
 #, gcc-internal-format
 msgid "assignment left-hand side might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:6803
+#: c/c-typeck.c:6808
 #, gcc-internal-format
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:6808 cp/typeck.c:8891
+#: c/c-typeck.c:6813 cp/typeck.c:8891
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:6857
+#: c/c-typeck.c:6862
 #, gcc-internal-format
 msgid "ISO C forbids passing argument %d of %qE between function pointer and %<void *%>"
 msgstr ""
 
-#: c/c-typeck.c:6860
+#: c/c-typeck.c:6865
 #, gcc-internal-format
 msgid "ISO C forbids assignment between function pointer and %<void *%>"
 msgstr ""
 
-#: c/c-typeck.c:6862
+#: c/c-typeck.c:6867
 #, gcc-internal-format
 msgid "ISO C forbids initialization between function pointer and %<void *%>"
 msgstr ""
 
-#: c/c-typeck.c:6864
+#: c/c-typeck.c:6869
 #, gcc-internal-format
 msgid "ISO C forbids return between function pointer and %<void *%>"
 msgstr ""
 
-#: c/c-typeck.c:6904
+#: c/c-typeck.c:6909
 #, gcc-internal-format
 msgid "pointer targets in passing argument %d of %qE differ in signedness"
 msgstr ""
 
-#: c/c-typeck.c:6913
+#: c/c-typeck.c:6918
 #, fuzzy, gcc-internal-format
 msgid "pointer targets in assignment from %qT to %qT differ in signedness"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: c/c-typeck.c:6918
+#: c/c-typeck.c:6923
 #, gcc-internal-format
 msgid "pointer targets in initialization of %qT from %qT differ in signedness"
 msgstr ""
 
-#: c/c-typeck.c:6923
+#: c/c-typeck.c:6928
 #, gcc-internal-format
 msgid "pointer targets in returning %qT from a function with return type %qT differ in signedness"
 msgstr ""
 
-#: c/c-typeck.c:6961
+#: c/c-typeck.c:6966
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE from incompatible pointer type"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: c/c-typeck.c:6967
+#: c/c-typeck.c:6972
 #, fuzzy, gcc-internal-format
 msgid "assignment to %qT from incompatible pointer type %qT"
 msgstr "Δεν είναι δυνατόν να βρεθεί ο τύπος του επεξεργαστή."
 
-#: c/c-typeck.c:6972
+#: c/c-typeck.c:6977
 #, fuzzy, gcc-internal-format
 msgid "initialization of %qT from incompatible pointer type %qT"
 msgstr "μη έγκυρος δεύτερος τελεστής σε κατάσταση συμβατότητας `%s'"
 
-#: c/c-typeck.c:6977
+#: c/c-typeck.c:6982
 #, fuzzy, gcc-internal-format
 msgid "returning %qT from a function with incompatible return type %qT"
 msgstr "μη πλήρης εγγραφή"
@@ -37896,782 +37938,782 @@
 
 #. ??? This should not be an error when inlining calls to
 #. unprototyped functions.
-#: c/c-typeck.c:6991 c/c-typeck.c:7514 cp/typeck.c:2063
+#: c/c-typeck.c:6996 c/c-typeck.c:7519 cp/typeck.c:2063
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: c/c-typeck.c:7004
+#: c/c-typeck.c:7009
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE makes pointer from integer without a cast"
 msgstr "%s μετατρέπει ακέραιο σε δείκτη χωρίς μετατροπέα"
 
-#: c/c-typeck.c:7010
+#: c/c-typeck.c:7015
 #, fuzzy, gcc-internal-format
 msgid "assignment to %qT from %qT makes pointer from integer without a cast"
 msgstr "%s μετατρέπει ακέραιο σε δείκτη χωρίς μετατροπέα"
 
-#: c/c-typeck.c:7015
+#: c/c-typeck.c:7020
 #, fuzzy, gcc-internal-format
 msgid "initialization of %qT from %qT makes pointer from integer without a cast"
 msgstr "%s μετατρέπει ακέραιο σε δείκτη χωρίς μετατροπέα"
 
-#: c/c-typeck.c:7019
+#: c/c-typeck.c:7024
 #, fuzzy, gcc-internal-format
 msgid "returning %qT from a function with return type %qT makes pointer from integer without a cast"
 msgstr "%s μετατρέπει ακέραιο σε δείκτη χωρίς μετατροπέα"
 
-#: c/c-typeck.c:7035
+#: c/c-typeck.c:7040
 #, fuzzy, gcc-internal-format
 msgid "passing argument %d of %qE makes integer from pointer without a cast"
 msgstr "%s μετατρέπει ακέραιο σε δείκτη χωρίς μετατροπέα"
 
-#: c/c-typeck.c:7041
+#: c/c-typeck.c:7046
 #, fuzzy, gcc-internal-format
 msgid "assignment to %qT from %qT makes integer from pointer without a cast"
 msgstr "%s μετατρέπει ακέραιο σε δείκτη χωρίς μετατροπέα"
 
-#: c/c-typeck.c:7046
+#: c/c-typeck.c:7051
 #, fuzzy, gcc-internal-format
 msgid "initialization of %qT from %qT makes integer from pointer without a cast"
 msgstr "%s μετατρέπει ακέραιο σε δείκτη χωρίς μετατροπέα"
 
-#: c/c-typeck.c:7050
+#: c/c-typeck.c:7055
 #, fuzzy, gcc-internal-format
 msgid "returning %qT from a function with return type %qT makes integer from pointer without a cast"
 msgstr "%s μετατρέπει ακέραιο σε δείκτη χωρίς μετατροπέα"
 
-#: c/c-typeck.c:7073
+#: c/c-typeck.c:7078
 #, fuzzy, gcc-internal-format
 msgid "incompatible type for argument %d of %qE"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: c/c-typeck.c:7078
+#: c/c-typeck.c:7083
 #, fuzzy, gcc-internal-format
 msgid "incompatible types when assigning to type %qT from type %qT"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: c/c-typeck.c:7083
+#: c/c-typeck.c:7088
 #, fuzzy, gcc-internal-format
 msgid "incompatible types when initializing type %qT using type %qT"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 
-#: c/c-typeck.c:7088
+#: c/c-typeck.c:7093
 #, fuzzy, gcc-internal-format
 msgid "incompatible types when returning type %qT but %qT was expected"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: c/c-typeck.c:7152
+#: c/c-typeck.c:7157
 #, gcc-internal-format
 msgid "traditional C rejects automatic aggregate initialization"
 msgstr ""
 
-#: c/c-typeck.c:7388 c/c-typeck.c:8284 cp/typeck2.c:1045
+#: c/c-typeck.c:7393 c/c-typeck.c:8289 cp/typeck2.c:1045
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr ""
 
-#: c/c-typeck.c:7398 cp/typeck2.c:1059
+#: c/c-typeck.c:7403 cp/typeck2.c:1059
 #, gcc-internal-format
 msgid "char-array initialized from wide string"
 msgstr ""
 
-#: c/c-typeck.c:7407
+#: c/c-typeck.c:7412
 #, fuzzy, gcc-internal-format
 msgid "wide character array initialized from non-wide string"
 msgstr "Η αλυσίδα μορφής δεν είναι έγκυρη: `%s'"
 
-#: c/c-typeck.c:7413
+#: c/c-typeck.c:7418
 #, fuzzy, gcc-internal-format
 msgid "wide character array initialized from incompatible wide string"
 msgstr "Η αλυσίδα μορφής δεν είναι έγκυρη: `%s'"
 
-#: c/c-typeck.c:7446
+#: c/c-typeck.c:7451
 #, gcc-internal-format
 msgid "array of inappropriate type initialized from string constant"
 msgstr ""
 
-#: c/c-typeck.c:7533 c/c-typeck.c:7557 c/c-typeck.c:7560 c/c-typeck.c:7568
-#: c/c-typeck.c:7608 c/c-typeck.c:9131 c/c-typeck.c:9181
+#: c/c-typeck.c:7538 c/c-typeck.c:7562 c/c-typeck.c:7565 c/c-typeck.c:7573
+#: c/c-typeck.c:7613 c/c-typeck.c:9136 c/c-typeck.c:9186
 #, fuzzy, gcc-internal-format
 msgid "initializer element is not constant"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: c/c-typeck.c:7542
+#: c/c-typeck.c:7547
 #, gcc-internal-format
 msgid "array initialized from non-constant array expression"
 msgstr ""
 
-#: c/c-typeck.c:7573 c/c-typeck.c:7621 c/c-typeck.c:9191
+#: c/c-typeck.c:7578 c/c-typeck.c:7626 c/c-typeck.c:9196
 #, fuzzy, gcc-internal-format
 msgid "initializer element is not a constant expression"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: c/c-typeck.c:7615 c/c-typeck.c:9186
+#: c/c-typeck.c:7620 c/c-typeck.c:9191
 #, gcc-internal-format
 msgid "initializer element is not computable at load time"
 msgstr ""
 
-#: c/c-typeck.c:7634
+#: c/c-typeck.c:7639
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer"
 msgstr "μη έγκυρο μέγεθος οριζόντιου στηλοθέτη: %s"
 
-#: c/c-typeck.c:7912 cp/decl.c:6396
+#: c/c-typeck.c:7917 cp/decl.c:6396
 #, fuzzy, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: c/c-typeck.c:8132
+#: c/c-typeck.c:8137
 #, fuzzy, gcc-internal-format
 msgid "extra brace group at end of initializer"
 msgstr "ακολουθούν σκουπίδια στο τέλος της γραμμής"
 
-#: c/c-typeck.c:8215
+#: c/c-typeck.c:8220
 #, gcc-internal-format
 msgid "braces around scalar initializer"
 msgstr ""
 
-#: c/c-typeck.c:8281 c/c-typeck.c:9615 cp/typeck2.c:1084 cp/typeck2.c:1297
+#: c/c-typeck.c:8286 c/c-typeck.c:9620 cp/typeck2.c:1084 cp/typeck2.c:1297
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr ""
 
-#: c/c-typeck.c:8318
+#: c/c-typeck.c:8323
 #, gcc-internal-format
 msgid "missing braces around initializer"
 msgstr ""
 
-#: c/c-typeck.c:8341
+#: c/c-typeck.c:8346
 #, fuzzy, gcc-internal-format
 msgid "missing initializer for field %qD of %qT"
 msgstr "έχει παραληφθεί το αρχείο προορισμού"
 
-#: c/c-typeck.c:8365
+#: c/c-typeck.c:8370
 #, gcc-internal-format
 msgid "empty scalar initializer"
 msgstr ""
 
-#: c/c-typeck.c:8370
+#: c/c-typeck.c:8375
 #, gcc-internal-format
 msgid "extra elements in scalar initializer"
 msgstr ""
 
-#: c/c-typeck.c:8483 c/c-typeck.c:8565
+#: c/c-typeck.c:8488 c/c-typeck.c:8570
 #, gcc-internal-format
 msgid "array index in non-array initializer"
 msgstr ""
 
-#: c/c-typeck.c:8488 c/c-typeck.c:8627
+#: c/c-typeck.c:8493 c/c-typeck.c:8632
 #, gcc-internal-format
 msgid "field name not in record or union initializer"
 msgstr ""
 
-#: c/c-typeck.c:8538
+#: c/c-typeck.c:8543
 #, gcc-internal-format
 msgid "array index in initializer not of integer type"
 msgstr ""
 
-#: c/c-typeck.c:8547 c/c-typeck.c:8556
+#: c/c-typeck.c:8552 c/c-typeck.c:8561
 #, fuzzy, gcc-internal-format
 msgid "array index in initializer is not an integer constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: c/c-typeck.c:8561 c/c-typeck.c:8563
+#: c/c-typeck.c:8566 c/c-typeck.c:8568
 #, gcc-internal-format
 msgid "nonconstant array index in initializer"
 msgstr ""
 
-#: c/c-typeck.c:8567 c/c-typeck.c:8570
+#: c/c-typeck.c:8572 c/c-typeck.c:8575
 #, gcc-internal-format
 msgid "array index in initializer exceeds array bounds"
 msgstr ""
 
-#: c/c-typeck.c:8589
+#: c/c-typeck.c:8594
 #, gcc-internal-format
 msgid "empty index range in initializer"
 msgstr ""
 
-#: c/c-typeck.c:8598
+#: c/c-typeck.c:8603
 #, gcc-internal-format
 msgid "array index range in initializer exceeds array bounds"
 msgstr ""
 
-#: c/c-typeck.c:8700 c/c-typeck.c:8730 c/c-typeck.c:9274
+#: c/c-typeck.c:8705 c/c-typeck.c:8735 c/c-typeck.c:9279
 #, gcc-internal-format
 msgid "initialized field with side-effects overwritten"
 msgstr ""
 
-#: c/c-typeck.c:8704 c/c-typeck.c:8734 c/c-typeck.c:9277
+#: c/c-typeck.c:8709 c/c-typeck.c:8739 c/c-typeck.c:9282
 #, gcc-internal-format
 msgid "initialized field overwritten"
 msgstr ""
 
-#: c/c-typeck.c:9208
+#: c/c-typeck.c:9213
 #, gcc-internal-format
 msgid "enum conversion in initialization is invalid in C++"
 msgstr ""
 
-#: c/c-typeck.c:9496
+#: c/c-typeck.c:9501
 #, gcc-internal-format
 msgid "excess elements in char array initializer"
 msgstr ""
 
-#: c/c-typeck.c:9503 c/c-typeck.c:9574
+#: c/c-typeck.c:9508 c/c-typeck.c:9579
 #, gcc-internal-format
 msgid "excess elements in struct initializer"
 msgstr ""
 
-#: c/c-typeck.c:9518
+#: c/c-typeck.c:9523
 #, gcc-internal-format
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr ""
 
-#: c/c-typeck.c:9589
+#: c/c-typeck.c:9594
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr ""
 
-#: c/c-typeck.c:9687
+#: c/c-typeck.c:9692
 #, gcc-internal-format
 msgid "excess elements in union initializer"
 msgstr ""
 
-#: c/c-typeck.c:9709
+#: c/c-typeck.c:9714
 #, gcc-internal-format
 msgid "traditional C rejects initialization of unions"
 msgstr ""
 
-#: c/c-typeck.c:9777
+#: c/c-typeck.c:9782
 #, gcc-internal-format
 msgid "excess elements in array initializer"
 msgstr ""
 
-#: c/c-typeck.c:9811
+#: c/c-typeck.c:9816
 #, gcc-internal-format
 msgid "excess elements in vector initializer"
 msgstr ""
 
-#: c/c-typeck.c:9843
+#: c/c-typeck.c:9848
 #, gcc-internal-format
 msgid "excess elements in scalar initializer"
 msgstr ""
 
-#: c/c-typeck.c:10086
+#: c/c-typeck.c:10091
 #, gcc-internal-format
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr ""
 
-#: c/c-typeck.c:10113 c/gimple-parser.c:1604 cp/typeck.c:9113
+#: c/c-typeck.c:10118 c/gimple-parser.c:1604 cp/typeck.c:9113
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr ""
 
-#: c/c-typeck.c:10139 c/c-typeck.c:10143
+#: c/c-typeck.c:10144 c/c-typeck.c:10148
 #, fuzzy, gcc-internal-format
 msgid "%<return%> with no value, in function returning non-void"
 msgstr "`return' χωρίς τιμή, σε συνάρτηση που επιστρέφει μη-κενό"
 
-#: c/c-typeck.c:10157 c/gimple-parser.c:1614
+#: c/c-typeck.c:10162 c/gimple-parser.c:1614
 #, fuzzy, gcc-internal-format
 msgid "%<return%> with a value, in function returning void"
 msgstr "`return' χωρίς τιμή, σε συνάρτηση που επιστρέφει μη-κενό"
 
-#: c/c-typeck.c:10160
+#: c/c-typeck.c:10165
 #, fuzzy, gcc-internal-format
 msgid "ISO C forbids %<return%> with expression, in function returning void"
 msgstr "`return' χωρίς τιμή, σε συνάρτηση που επιστρέφει μη-κενό"
 
-#: c/c-typeck.c:10236
+#: c/c-typeck.c:10241
 #, gcc-internal-format
 msgid "function returns address of label"
 msgstr ""
 
-#: c/c-typeck.c:10327 cp/semantics.c:1171
+#: c/c-typeck.c:10332 cp/semantics.c:1171
 #, gcc-internal-format
 msgid "switch quantity not an integer"
 msgstr ""
 
-#: c/c-typeck.c:10352
+#: c/c-typeck.c:10357
 #, gcc-internal-format
 msgid "%<long%> switch expression not converted to %<int%> in ISO C"
 msgstr ""
 
-#: c/c-typeck.c:10390 c/c-typeck.c:10398
+#: c/c-typeck.c:10395 c/c-typeck.c:10403
 #, fuzzy, gcc-internal-format
 msgid "case label is not an integer constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: c/c-typeck.c:10404 cp/parser.c:11067
+#: c/c-typeck.c:10409 cp/parser.c:11067
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr ""
 
-#: c/c-typeck.c:10406
+#: c/c-typeck.c:10411
 #, gcc-internal-format
 msgid "%<default%> label not within a switch statement"
 msgstr ""
 
-#: c/c-typeck.c:10578 cp/parser.c:12356
+#: c/c-typeck.c:10583 cp/parser.c:12353
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr ""
 
-#: c/c-typeck.c:10580 cp/parser.c:12379
+#: c/c-typeck.c:10585 cp/parser.c:12376
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr ""
 
-#: c/c-typeck.c:10585 cp/parser.c:12369
+#: c/c-typeck.c:10590 cp/parser.c:12366
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr ""
 
-#: c/c-typeck.c:10590
+#: c/c-typeck.c:10595
 #, gcc-internal-format
 msgid "break statement within %<#pragma simd%> loop body"
 msgstr ""
 
-#: c/c-typeck.c:10592
+#: c/c-typeck.c:10597
 #, gcc-internal-format
 msgid "continue statement within %<#pragma simd%> loop body"
 msgstr ""
 
-#: c/c-typeck.c:10618 cp/cp-gimplify.c:432
+#: c/c-typeck.c:10623 cp/cp-gimplify.c:432
 #, gcc-internal-format
 msgid "statement with no effect"
 msgstr ""
 
-#: c/c-typeck.c:10662
+#: c/c-typeck.c:10667
 #, gcc-internal-format
 msgid "expression statement has incomplete type"
 msgstr ""
 
-#: c/c-typeck.c:11476 c/c-typeck.c:11644 cp/typeck.c:5017
+#: c/c-typeck.c:11481 c/c-typeck.c:11649 cp/typeck.c:5017
 #, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr ""
 
-#: c/c-typeck.c:11484 c/c-typeck.c:11652 cp/typeck.c:5030
+#: c/c-typeck.c:11489 c/c-typeck.c:11657 cp/typeck.c:5030
 #, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr ""
 
-#: c/c-typeck.c:11509 c/c-typeck.c:11677 cp/typeck.c:5058
+#: c/c-typeck.c:11514 c/c-typeck.c:11682 cp/typeck.c:5058
 #, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr ""
 
-#: c/c-typeck.c:11523 cp/typeck.c:4743
+#: c/c-typeck.c:11528 cp/typeck.c:4743
 #, gcc-internal-format
 msgid "comparing floating point with == or != is unsafe"
 msgstr ""
 
-#: c/c-typeck.c:11541 c/c-typeck.c:11562
+#: c/c-typeck.c:11546 c/c-typeck.c:11567
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<false%> for the address of %qD will never be NULL"
 msgstr ""
 
-#: c/c-typeck.c:11547 c/c-typeck.c:11568
+#: c/c-typeck.c:11552 c/c-typeck.c:11573
 #, gcc-internal-format
 msgid "the comparison will always evaluate as %<true%> for the address of %qD will never be NULL"
 msgstr ""
 
-#: c/c-typeck.c:11589 c/c-typeck.c:11718
+#: c/c-typeck.c:11594 c/c-typeck.c:11723
 #, gcc-internal-format
 msgid "comparison of pointers to disjoint address spaces"
 msgstr ""
 
-#: c/c-typeck.c:11596 c/c-typeck.c:11602
+#: c/c-typeck.c:11601 c/c-typeck.c:11607
 #, gcc-internal-format
 msgid "ISO C forbids comparison of %<void *%> with function pointer"
 msgstr ""
 
-#: c/c-typeck.c:11609 c/c-typeck.c:11728
+#: c/c-typeck.c:11614 c/c-typeck.c:11733
 #, gcc-internal-format
 msgid "comparison of distinct pointer types lacks a cast"
 msgstr ""
 
-#: c/c-typeck.c:11621 c/c-typeck.c:11626 c/c-typeck.c:11754 c/c-typeck.c:11759
+#: c/c-typeck.c:11626 c/c-typeck.c:11631 c/c-typeck.c:11759 c/c-typeck.c:11764
 #, gcc-internal-format
 msgid "comparison between pointer and integer"
 msgstr ""
 
-#: c/c-typeck.c:11706
+#: c/c-typeck.c:11711
 #, gcc-internal-format
 msgid "comparison of complete and incomplete pointers"
 msgstr ""
 
-#: c/c-typeck.c:11708
+#: c/c-typeck.c:11713
 #, gcc-internal-format
 msgid "ISO C forbids ordered comparisons of pointers to functions"
 msgstr ""
 
-#: c/c-typeck.c:11713
+#: c/c-typeck.c:11718
 #, fuzzy, gcc-internal-format
 msgid "ordered comparison of pointer with null pointer"
 msgstr "Η παράμετρος κινητής υποδιαστολής δεν είναι έγκυρη: %s"
 
-#: c/c-typeck.c:11736 c/c-typeck.c:11739 c/c-typeck.c:11746 c/c-typeck.c:11749
+#: c/c-typeck.c:11741 c/c-typeck.c:11744 c/c-typeck.c:11751 c/c-typeck.c:11754
 #: cp/typeck.c:5081 cp/typeck.c:5088
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr ""
 
-#: c/c-typeck.c:11811
+#: c/c-typeck.c:11816
 #, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
 msgstr ""
 
-#: c/c-typeck.c:12126
+#: c/c-typeck.c:12131
 #, gcc-internal-format
 msgid "used array that cannot be converted to pointer where scalar is required"
 msgstr ""
 
-#: c/c-typeck.c:12130
+#: c/c-typeck.c:12135
 #, gcc-internal-format
 msgid "used struct type value where scalar is required"
 msgstr ""
 
-#: c/c-typeck.c:12134
+#: c/c-typeck.c:12139
 #, gcc-internal-format
 msgid "used union type value where scalar is required"
 msgstr ""
 
-#: c/c-typeck.c:12150
+#: c/c-typeck.c:12155
 #, gcc-internal-format
 msgid "used vector type where scalar is required"
 msgstr ""
 
-#: c/c-typeck.c:12340 cp/semantics.c:8508
+#: c/c-typeck.c:12345 cp/semantics.c:8511
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12379 cp/semantics.c:8545
+#: c/c-typeck.c:12384 cp/semantics.c:8548
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12423 c/c-typeck.c:13581 c/c-typeck.c:13642 c/c-typeck.c:13704
+#: c/c-typeck.c:12428 c/c-typeck.c:13586 c/c-typeck.c:13647 c/c-typeck.c:13709
 #, gcc-internal-format
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12436 c/c-typeck.c:13628 cp/semantics.c:4546
-#: cp/semantics.c:6717
+#: c/c-typeck.c:12441 c/c-typeck.c:13633 cp/semantics.c:4549
+#: cp/semantics.c:6720
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12445 c/c-typeck.c:13652 cp/semantics.c:4556
-#: cp/semantics.c:6735
+#: c/c-typeck.c:12450 c/c-typeck.c:13657 cp/semantics.c:4559
+#: cp/semantics.c:6738
 #, fuzzy, gcc-internal-format
 msgid "%qE is a member of a union"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: c/c-typeck.c:12455 cp/semantics.c:4570 cp/semantics.c:6760
+#: c/c-typeck.c:12460 cp/semantics.c:4573 cp/semantics.c:6763
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: c/c-typeck.c:12459 c/c-typeck.c:13669 cp/semantics.c:4574
-#: cp/semantics.c:6763
+#: c/c-typeck.c:12464 c/c-typeck.c:13674 cp/semantics.c:4577
+#: cp/semantics.c:6766
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: c/c-typeck.c:12466
+#: c/c-typeck.c:12471
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12475 c/c-typeck.c:13676 c/c-typeck.c:13778
-#: cp/semantics.c:4591 cp/semantics.c:6769 cp/semantics.c:6931
+#: c/c-typeck.c:12480 c/c-typeck.c:13681 c/c-typeck.c:13783
+#: cp/semantics.c:4594 cp/semantics.c:6772 cp/semantics.c:6934
 #, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12511 cp/semantics.c:4623
+#: c/c-typeck.c:12516 cp/semantics.c:4626
 #, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr ""
 
-#: c/c-typeck.c:12518 cp/semantics.c:4630
+#: c/c-typeck.c:12523 cp/semantics.c:4633
 #, fuzzy, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: c/c-typeck.c:12545 c/c-typeck.c:12609 c/c-typeck.c:12867
-#: cp/semantics.c:4666 cp/semantics.c:4730
+#: c/c-typeck.c:12550 c/c-typeck.c:12614 c/c-typeck.c:12872
+#: cp/semantics.c:4669 cp/semantics.c:4733
 #, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12564 cp/semantics.c:4685
+#: c/c-typeck.c:12569 cp/semantics.c:4688
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12572 cp/semantics.c:4693
+#: c/c-typeck.c:12577 cp/semantics.c:4696
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12581 c/c-typeck.c:12691 cp/semantics.c:4702
-#: cp/semantics.c:4812
+#: c/c-typeck.c:12586 c/c-typeck.c:12696 cp/semantics.c:4705
+#: cp/semantics.c:4815
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12598 cp/semantics.c:4719
+#: c/c-typeck.c:12603 cp/semantics.c:4722
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12635 cp/semantics.c:4756
+#: c/c-typeck.c:12640 cp/semantics.c:4759
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12650 cp/semantics.c:4771
+#: c/c-typeck.c:12655 cp/semantics.c:4774
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12683 cp/semantics.c:4804
+#: c/c-typeck.c:12688 cp/semantics.c:4807
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12701 c/c-typeck.c:12810 cp/semantics.c:4822
-#: cp/semantics.c:4934
+#: c/c-typeck.c:12706 c/c-typeck.c:12815 cp/semantics.c:4825
+#: cp/semantics.c:4937
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12709 cp/semantics.c:4830
+#: c/c-typeck.c:12714 cp/semantics.c:4833
 #, fuzzy, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: c/c-typeck.c:13103 c/c-typeck.c:13113
+#: c/c-typeck.c:13108 c/c-typeck.c:13118
 #, gcc-internal-format
 msgid "%qD in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: c/c-typeck.c:13130
+#: c/c-typeck.c:13135
 #, gcc-internal-format
 msgid "%<_Atomic%> %qE in %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13178
+#: c/c-typeck.c:13183
 #, gcc-internal-format
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr ""
 
-#: c/c-typeck.c:13187 cp/semantics.c:5755
+#: c/c-typeck.c:13192 cp/semantics.c:5758
 #, fuzzy, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr "Οι ορισμοί πηγή βρίσκονται στο ΑΡΧΕΙΟ"
 
-#: c/c-typeck.c:13275
+#: c/c-typeck.c:13280
 #, gcc-internal-format
 msgid "variable length element type in array %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13293 c/c-typeck.c:13836 cp/semantics.c:7249
+#: c/c-typeck.c:13298 c/c-typeck.c:13841 cp/semantics.c:7252
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13305 cp/semantics.c:7289
+#: c/c-typeck.c:13310 cp/semantics.c:7292
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr ""
 
-#: c/c-typeck.c:13319 cp/semantics.c:5929
+#: c/c-typeck.c:13324 cp/semantics.c:5932
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr ""
 
-#: c/c-typeck.c:13327
+#: c/c-typeck.c:13332
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with type %qT"
 msgstr ""
 
-#: c/c-typeck.c:13335
+#: c/c-typeck.c:13340
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13354 cp/semantics.c:5999
+#: c/c-typeck.c:13359 cp/semantics.c:6002
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
-#: c/c-typeck.c:13384 c/c-typeck.c:13771 cp/semantics.c:6083
-#: cp/semantics.c:6924
+#: c/c-typeck.c:13389 c/c-typeck.c:13776 cp/semantics.c:6086
+#: cp/semantics.c:6927
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: c/c-typeck.c:13393 cp/semantics.c:6092
+#: c/c-typeck.c:13398 cp/semantics.c:6095
 #, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr ""
 
-#: c/c-typeck.c:13404 c/c-typeck.c:13434 c/c-typeck.c:13463
+#: c/c-typeck.c:13409 c/c-typeck.c:13439 c/c-typeck.c:13468
 #, gcc-internal-format
 msgid "%qE appears more than once in data clauses"
 msgstr ""
 
-#: c/c-typeck.c:13411 c/c-typeck.c:13440 c/c-typeck.c:13600 c/c-typeck.c:13714
-#: c/c-typeck.c:13720 c/c-typeck.c:13733 c/c-typeck.c:13742
-#: cp/semantics.c:6102 cp/semantics.c:6109 cp/semantics.c:6160
-#: cp/semantics.c:6166 cp/semantics.c:6203 cp/semantics.c:6680
-#: cp/semantics.c:6817 cp/semantics.c:6823 cp/semantics.c:6836
-#: cp/semantics.c:6845
+#: c/c-typeck.c:13416 c/c-typeck.c:13445 c/c-typeck.c:13605 c/c-typeck.c:13719
+#: c/c-typeck.c:13725 c/c-typeck.c:13738 c/c-typeck.c:13747
+#: cp/semantics.c:6105 cp/semantics.c:6112 cp/semantics.c:6163
+#: cp/semantics.c:6169 cp/semantics.c:6206 cp/semantics.c:6683
+#: cp/semantics.c:6820 cp/semantics.c:6826 cp/semantics.c:6839
+#: cp/semantics.c:6848
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
-#: c/c-typeck.c:13413 c/c-typeck.c:13442 c/c-typeck.c:13722 c/c-typeck.c:13744
-#: cp/semantics.c:6111 cp/semantics.c:6168 cp/semantics.c:6825
-#: cp/semantics.c:6847
+#: c/c-typeck.c:13418 c/c-typeck.c:13447 c/c-typeck.c:13727 c/c-typeck.c:13749
+#: cp/semantics.c:6114 cp/semantics.c:6171 cp/semantics.c:6828
+#: cp/semantics.c:6850
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr ""
 
-#: c/c-typeck.c:13427 cp/semantics.c:6154
+#: c/c-typeck.c:13432 cp/semantics.c:6157
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13456 cp/semantics.c:6197
+#: c/c-typeck.c:13461 cp/semantics.c:6200
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13475 cp/semantics.c:6545
+#: c/c-typeck.c:13480 cp/semantics.c:6548
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: c/c-typeck.c:13482
+#: c/c-typeck.c:13487
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array"
 msgstr ""
 
-#: c/c-typeck.c:13489
+#: c/c-typeck.c:13494
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<aligned%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13496
+#: c/c-typeck.c:13501
 #, gcc-internal-format
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:13551 cp/semantics.c:6627
+#: c/c-typeck.c:13556 cp/semantics.c:6630
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: c/c-typeck.c:13573 cp/semantics.c:6658
+#: c/c-typeck.c:13578 cp/semantics.c:6661
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13597 c/c-typeck.c:13731 cp/semantics.c:6677
-#: cp/semantics.c:6834
+#: c/c-typeck.c:13602 c/c-typeck.c:13736 cp/semantics.c:6680
+#: cp/semantics.c:6837
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr ""
 
-#: c/c-typeck.c:13603 c/c-typeck.c:13735 cp/semantics.c:6683
-#: cp/semantics.c:6838
+#: c/c-typeck.c:13608 c/c-typeck.c:13740 cp/semantics.c:6686
+#: cp/semantics.c:6841
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr ""
 
-#: c/c-typeck.c:13635 cp/semantics.c:6724
+#: c/c-typeck.c:13640 cp/semantics.c:6727
 #, fuzzy, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: c/c-typeck.c:13695 c/c-typeck.c:13785 cp/semantics.c:6799
-#: cp/semantics.c:6938
+#: c/c-typeck.c:13700 c/c-typeck.c:13790 cp/semantics.c:6802
+#: cp/semantics.c:6941
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: c/c-typeck.c:13766 cp/semantics.c:6918
+#: c/c-typeck.c:13771 cp/semantics.c:6921
 #, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr ""
 
-#: c/c-typeck.c:13794 cp/semantics.c:6947
+#: c/c-typeck.c:13799 cp/semantics.c:6950
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr ""
 
-#: c/c-typeck.c:13808 cp/semantics.c:6962
+#: c/c-typeck.c:13813 cp/semantics.c:6965
 #, fuzzy, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: c/c-typeck.c:13811 cp/semantics.c:6964
+#: c/c-typeck.c:13816 cp/semantics.c:6967
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13826
+#: c/c-typeck.c:13831
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer nor an array"
 msgstr ""
 
-#: c/c-typeck.c:13900 cp/semantics.c:6359
+#: c/c-typeck.c:13905 cp/semantics.c:6362
 #, gcc-internal-format
 msgid "%<nonmonotonic%> modifier specified for %qs schedule kind"
 msgstr ""
 
-#: c/c-typeck.c:13931 cp/semantics.c:7141
+#: c/c-typeck.c:13936 cp/semantics.c:7144
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:13981 cp/semantics.c:7332
+#: c/c-typeck.c:13986 cp/semantics.c:7335
 #, fuzzy, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: c/c-typeck.c:14001 cp/semantics.c:7223
+#: c/c-typeck.c:14006 cp/semantics.c:7226
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:14013 cp/semantics.c:7236
+#: c/c-typeck.c:14018 cp/semantics.c:7239
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14031 cp/semantics.c:7203
+#: c/c-typeck.c:14036 cp/semantics.c:7206
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14204
+#: c/c-typeck.c:14209
 #, gcc-internal-format
 msgid "cannot use %<va_arg%> with reverse storage order"
 msgstr ""
 
-#: c/c-typeck.c:14209
+#: c/c-typeck.c:14214
 #, fuzzy, gcc-internal-format
 msgid "second argument to %<va_arg%> is of incomplete type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: c/c-typeck.c:14215
+#: c/c-typeck.c:14220
 #, gcc-internal-format
 msgid "C++ requires promoted type, not enum type, in %<va_arg%>"
 msgstr ""
@@ -38787,7 +38829,7 @@
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/call.c:3441 cp/pt.c:6495
+#: cp/call.c:3441 cp/pt.c:6509
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -39085,7 +39127,7 @@
 msgid "%q#D is private within this context"
 msgstr ""
 
-#: cp/call.c:6478 cp/decl.c:7343
+#: cp/call.c:6478 cp/decl.c:7364
 #, fuzzy, gcc-internal-format
 msgid "declared private here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
@@ -39095,7 +39137,7 @@
 msgid "%q#D is protected within this context"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/call.c:6486 cp/decl.c:7344
+#: cp/call.c:6486 cp/decl.c:7365
 #, fuzzy, gcc-internal-format
 msgid "declared protected here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
@@ -39398,7 +39440,7 @@
 msgid "call to non-function %qD"
 msgstr "κλήση σε μη-συνάρτηση %qD"
 
-#: cp/call.c:9119 cp/pt.c:15053 cp/typeck.c:2901
+#: cp/call.c:9119 cp/pt.c:15075 cp/typeck.c:2901
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
@@ -39614,262 +39656,262 @@
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/class.c:2098
+#: cp/class.c:2103
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr ""
 
-#: cp/class.c:2110
+#: cp/class.c:2115
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr ""
 
-#: cp/class.c:2152
+#: cp/class.c:2156
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr ""
 
-#: cp/class.c:2156
+#: cp/class.c:2160
 #, gcc-internal-format
 msgid "%q#D is public, but requires an existing %q#T object"
 msgstr ""
 
-#: cp/class.c:2430
+#: cp/class.c:2434
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr ""
 
-#: cp/class.c:2785
+#: cp/class.c:2789
 #, fuzzy, gcc-internal-format
 msgid "%qD can be marked override"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/class.c:2797
+#: cp/class.c:2801
 #, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr ""
 
-#: cp/class.c:2799
+#: cp/class.c:2803
 #, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr ""
 
-#: cp/class.c:2861
+#: cp/class.c:2865
 #, gcc-internal-format
 msgid "%qD was hidden"
 msgstr ""
 
-#: cp/class.c:2863
+#: cp/class.c:2867
 #, fuzzy, gcc-internal-format
 msgid "  by %qD"
 msgstr "  κατά `%D'"
 
-#: cp/class.c:2896
+#: cp/class.c:2900
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr ""
 
-#: cp/class.c:2906 cp/name-lookup.c:3293 cp/parser.c:19720
+#: cp/class.c:2910 cp/name-lookup.c:3293 cp/parser.c:19717
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
 
-#: cp/class.c:3097
+#: cp/class.c:3101
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr ""
 
-#: cp/class.c:3213
+#: cp/class.c:3217
 #, fuzzy, gcc-internal-format
 msgid "bit-field %q+#D with non-integral type"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: cp/class.c:3229
+#: cp/class.c:3233
 #, fuzzy, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: cp/class.c:3234
+#: cp/class.c:3238
 #, fuzzy, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr "Αρνητικό πλάτος στην αποτίμηση"
 
-#: cp/class.c:3239
+#: cp/class.c:3243
 #, fuzzy, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr "Αρνητικό πλάτος στην αποτίμηση"
 
-#: cp/class.c:3249
+#: cp/class.c:3253
 #, gcc-internal-format
 msgid "width of %qD exceeds its type"
 msgstr ""
 
-#: cp/class.c:3255
+#: cp/class.c:3259
 #, gcc-internal-format
 msgid "%qD is too small to hold all values of %q#T"
 msgstr ""
 
-#: cp/class.c:3316
+#: cp/class.c:3320
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr ""
 
-#: cp/class.c:3319
+#: cp/class.c:3323
 #, fuzzy, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr "%s: οι τιμές του πεδίου `%s' δεν πρέπει να είναι μεγαλύτερες από %d"
 
-#: cp/class.c:3321
+#: cp/class.c:3325
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr ""
 
-#: cp/class.c:3325
+#: cp/class.c:3329
 #, gcc-internal-format
 msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/class.c:3453
+#: cp/class.c:3457
 #, gcc-internal-format
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr ""
 
-#: cp/class.c:3460
+#: cp/class.c:3464
 #, gcc-internal-format
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr ""
 
-#: cp/class.c:3470
+#: cp/class.c:3474
 #, fuzzy, gcc-internal-format
 msgid "field %q+D invalidly declared function type"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/class.c:3476
+#: cp/class.c:3480
 #, fuzzy, gcc-internal-format
 msgid "field %q+D invalidly declared method type"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/class.c:3536
+#: cp/class.c:3540
 #, gcc-internal-format
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr ""
 
-#: cp/class.c:3585
+#: cp/class.c:3589
 #, fuzzy, gcc-internal-format
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/class.c:3591
+#: cp/class.c:3595
 #, fuzzy, gcc-internal-format
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/class.c:3617
+#: cp/class.c:3621
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr ""
 
-#: cp/class.c:3658
+#: cp/class.c:3662
 #, fuzzy, gcc-internal-format
 msgid "field %q#D with same name as class"
 msgstr "Υπάρχει αντικείμενο με το ίδιο όνομα"
 
-#: cp/class.c:3681
+#: cp/class.c:3685
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr ""
 
-#: cp/class.c:3686
+#: cp/class.c:3690
 #, gcc-internal-format
 msgid "  but does not override %<%T(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:3688
+#: cp/class.c:3692
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:3692
+#: cp/class.c:3696
 #, gcc-internal-format
 msgid "  but does not override %<operator=(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:4097
+#: cp/class.c:4101
 #, gcc-internal-format
 msgid "alignment of %qD increased in -fabi-version=9 (GCC 5.2)"
 msgstr ""
 
-#: cp/class.c:4100
+#: cp/class.c:4104
 #, gcc-internal-format
 msgid "alignment of %qD will increase in -fabi-version=9"
 msgstr ""
 
-#: cp/class.c:4378
+#: cp/class.c:4382
 #, fuzzy, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: cp/class.c:4813
+#: cp/class.c:4817
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr ""
 
-#: cp/class.c:4834
+#: cp/class.c:4838
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr ""
 
-#: cp/class.c:5350 cp/constexpr.c:237
+#: cp/class.c:5367 cp/constexpr.c:237
 #, gcc-internal-format
 msgid "enclosing class of %<constexpr%> non-static member function %q+#D is not a literal type"
 msgstr ""
 
-#: cp/class.c:5374
+#: cp/class.c:5391
 #, fuzzy, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/class.c:5377
+#: cp/class.c:5394
 #, gcc-internal-format
 msgid "  %qT is a closure type, which is only literal in C++17 and later"
 msgstr ""
 
-#: cp/class.c:5380
+#: cp/class.c:5397
 #, fuzzy, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/class.c:5387
+#: cp/class.c:5404
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no %<constexpr%> constructor that is not a copy or move constructor"
 msgstr ""
 
-#: cp/class.c:5420
+#: cp/class.c:5437
 #, fuzzy, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/class.c:5435
+#: cp/class.c:5452
 #, fuzzy, gcc-internal-format
 msgid "  non-static data member %qD has non-literal type"
 msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
 
-#: cp/class.c:5442
+#: cp/class.c:5459
 #, fuzzy, gcc-internal-format
 msgid "  non-static data member %qD has volatile type"
 msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
 
-#: cp/class.c:5561
+#: cp/class.c:5578
 #, fuzzy, gcc-internal-format
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/class.c:5590
+#: cp/class.c:5607
 #, gcc-internal-format
 msgid "non-static reference %q#D in class without a constructor"
 msgstr ""
 
-#: cp/class.c:5596
+#: cp/class.c:5613
 #, gcc-internal-format
 msgid "non-static const member %q#D in class without a constructor"
 msgstr ""
@@ -39876,152 +39918,152 @@
 
 #. If the function is defaulted outside the class, we just
 #. give the synthesis error.
-#: cp/class.c:5624
+#: cp/class.c:5641
 #, gcc-internal-format
 msgid "%q+D declared to take const reference, but implicit declaration would take non-const"
 msgstr ""
 
-#: cp/class.c:5898
+#: cp/class.c:5915
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:5910
+#: cp/class.c:5927
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:6133
+#: cp/class.c:6150
 #, gcc-internal-format
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr ""
 
-#: cp/class.c:6291
+#: cp/class.c:6308
 #, fuzzy, gcc-internal-format
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: cp/class.c:6576
+#: cp/class.c:6593
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: cp/class.c:6578
+#: cp/class.c:6595
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: cp/class.c:6583
+#: cp/class.c:6600
 #, fuzzy, gcc-internal-format
 msgid "array member %q#D declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/class.c:6610
+#: cp/class.c:6627
 #, gcc-internal-format
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr ""
 
-#: cp/class.c:6612
+#: cp/class.c:6629
 #, gcc-internal-format
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr ""
 
-#: cp/class.c:6620 cp/class.c:6650
+#: cp/class.c:6637 cp/class.c:6667
 #, fuzzy, gcc-internal-format
 msgid "in the definition of %q#T"
 msgstr "κανένας ορισμός του `UNDEFINED'"
 
-#: cp/class.c:6628
+#: cp/class.c:6645
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD not at end of %q#T"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: cp/class.c:6630
+#: cp/class.c:6647
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: cp/class.c:6648
+#: cp/class.c:6665
 #, fuzzy, gcc-internal-format
 msgid "next member %q#D declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/class.c:6760 cp/parser.c:23239
+#: cp/class.c:6777 cp/parser.c:23236
 #, fuzzy, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "κανένας ορισμός του `UNDEFINED'"
 
-#: cp/class.c:6897
+#: cp/class.c:6914
 #, fuzzy, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/class.c:6925
+#: cp/class.c:6942
 #, fuzzy, gcc-internal-format
 msgid "type transparent %q#T does not have any fields"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/class.c:6931
+#: cp/class.c:6948
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr ""
 
-#: cp/class.c:6935
+#: cp/class.c:6952
 #, fuzzy, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/class.c:6941
+#: cp/class.c:6958
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:7071
+#: cp/class.c:7088
 #, gcc-internal-format
 msgid "definition of %qD does not match %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/class.c:7082
+#: cp/class.c:7099
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr ""
 
-#: cp/class.c:7582
+#: cp/class.c:7599
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr ""
 
-#: cp/class.c:7672
+#: cp/class.c:7689
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr ""
 
-#: cp/class.c:7817
+#: cp/class.c:7834
 #, fuzzy, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/class.c:7844
+#: cp/class.c:7861
 #, fuzzy, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/class.c:7870
+#: cp/class.c:7887
 #, fuzzy, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/class.c:7873
+#: cp/class.c:7890
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr ""
 
-#: cp/class.c:7948 cp/class.c:7990
+#: cp/class.c:7965 cp/class.c:8007
 #, fuzzy, gcc-internal-format
 msgid "not enough type information"
 msgstr "εμφάνιση πληροφοριών προόδου"
 
-#: cp/class.c:7968
+#: cp/class.c:7985
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
@@ -40031,12 +40073,12 @@
 #. A name N used in a class S shall refer to the same declaration
 #. in its context and when re-evaluated in the completed scope of
 #. S.
-#: cp/class.c:8235
+#: cp/class.c:8252
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/class.c:8237
+#: cp/class.c:8254
 #, gcc-internal-format
 msgid "changes meaning of %qD from %q#D"
 msgstr ""
@@ -40429,17 +40471,17 @@
 msgid "unexpected AST of kind %s"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/cp-gimplify.c:1415
+#: cp/cp-gimplify.c:1416
 #, gcc-internal-format
 msgid "throw will always call terminate()"
 msgstr ""
 
-#: cp/cp-gimplify.c:1418
+#: cp/cp-gimplify.c:1419
 #, gcc-internal-format
 msgid "in C++11 destructors default to noexcept"
 msgstr ""
 
-#: cp/cp-gimplify.c:1429
+#: cp/cp-gimplify.c:1430
 #, gcc-internal-format
 msgid "in C++11 this throw will terminate because destructors default to noexcept"
 msgstr ""
@@ -40851,7 +40893,7 @@
 msgid "redeclaration %qD differs in %<constexpr%> from previous declaration"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: cp/decl.c:1304 cp/decl.c:13843
+#: cp/decl.c:1304 cp/decl.c:13867
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr "αυτός είναι ο πρώτος ορισμός"
@@ -41178,7 +41220,7 @@
 msgid "  enters OpenMP structured block"
 msgstr ""
 
-#: cp/decl.c:3434 cp/parser.c:12366 cp/parser.c:12387
+#: cp/decl.c:3434 cp/parser.c:12363 cp/parser.c:12384
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr ""
@@ -41188,7 +41230,7 @@
 msgid "%qD is not a type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/decl.c:3838 cp/parser.c:6366
+#: cp/decl.c:3838 cp/parser.c:6369
 #, fuzzy, gcc-internal-format
 msgid "%qD used without template parameters"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
@@ -41565,8 +41607,8 @@
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr ""
 
-#: cp/decl.c:6011 cp/decl.c:6234 cp/typeck2.c:1310 cp/typeck2.c:1590
-#: cp/typeck2.c:1638 cp/typeck2.c:1685
+#: cp/decl.c:6011 cp/decl.c:6234 cp/typeck2.c:1310 cp/typeck2.c:1593
+#: cp/typeck2.c:1641 cp/typeck2.c:1688
 #, fuzzy, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "υπερβολικά πολλά αρχεία εισόδου"
@@ -41641,12 +41683,12 @@
 msgid "assignment (not initialization) in declaration"
 msgstr ""
 
-#: cp/decl.c:6873 cp/decl.c:12605
+#: cp/decl.c:6873 cp/decl.c:12629
 #, gcc-internal-format
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr ""
 
-#: cp/decl.c:6877 cp/decl.c:12609
+#: cp/decl.c:6877 cp/decl.c:12633
 #, fuzzy, gcc-internal-format
 msgid "%<register%> storage class specifier used"
 msgstr "Εγγραφή ονομάτων των επιλεγμένων λέξεων-κλειδιών"
@@ -41671,42 +41713,42 @@
 msgid "function %q#D is initialized like a variable"
 msgstr ""
 
-#: cp/decl.c:7329
+#: cp/decl.c:7350
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr ""
 
-#: cp/decl.c:7332
+#: cp/decl.c:7353
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.c:7339
+#: cp/decl.c:7360
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/decl.c:7365
+#: cp/decl.c:7386
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:7374
+#: cp/decl.c:7395
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:7592
+#: cp/decl.c:7613
 #, fuzzy, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/decl.c:7608
+#: cp/decl.c:7629
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose variable length array %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/decl.c:7617 cp/decl.c:7702
+#: cp/decl.c:7638 cp/decl.c:7723
 #, gcc-internal-format, gfc-internal-format
 msgid "%u name provided for structured binding"
 msgid_plural "%u names provided for structured binding"
@@ -41713,7 +41755,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:7621
+#: cp/decl.c:7642
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
@@ -41720,7 +41762,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:7624
+#: cp/decl.c:7645
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
@@ -41727,878 +41769,878 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/decl.c:7669
+#: cp/decl.c:7690
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose variable length vector %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/decl.c:7695
+#: cp/decl.c:7716
 #, fuzzy, gcc-internal-format
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/decl.c:7704
+#: cp/decl.c:7725
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.c:7725
+#: cp/decl.c:7746
 #, gcc-internal-format
 msgid "in initialization of structured binding variable %qD"
 msgstr ""
 
-#: cp/decl.c:7751
+#: cp/decl.c:7772
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose union type %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/decl.c:7756
+#: cp/decl.c:7777
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/decl.c:7761
+#: cp/decl.c:7782
 #, fuzzy, gcc-internal-format
 msgid "cannot decompose lambda closure type %qT"
 msgstr "Δεν είναι δυνατή η εκχώρηση της ζητηθήσας διεύθυνσης"
 
-#: cp/decl.c:7765
+#: cp/decl.c:7786
 #, fuzzy, gcc-internal-format
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/decl.c:7774
+#: cp/decl.c:7795
 #, gcc-internal-format
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr ""
 
-#: cp/decl.c:8213
+#: cp/decl.c:8234
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:8216
+#: cp/decl.c:8237
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr ""
 
-#: cp/decl.c:8222
+#: cp/decl.c:8243
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:8450
+#: cp/decl.c:8471
 #, fuzzy, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/decl.c:8454
+#: cp/decl.c:8475
 #, fuzzy, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "σφάλμα κατά το κλείσιμο της εισόδου `%s'"
 
-#: cp/decl.c:8457
+#: cp/decl.c:8478
 #, fuzzy, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.c:8473
+#: cp/decl.c:8494
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.c:8475
+#: cp/decl.c:8496
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr ""
 
-#: cp/decl.c:8499
+#: cp/decl.c:8520
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr ""
 
-#: cp/decl.c:8501
+#: cp/decl.c:8522
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr ""
 
-#: cp/decl.c:8506
+#: cp/decl.c:8527
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr ""
 
-#: cp/decl.c:8508
+#: cp/decl.c:8529
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "συνεχίζεται στο τμήμα"
 
-#: cp/decl.c:8510
+#: cp/decl.c:8531
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:8515
+#: cp/decl.c:8536
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/decl.c:8517
+#: cp/decl.c:8538
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: cp/decl.c:8519
+#: cp/decl.c:8540
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr ""
 
-#: cp/decl.c:8524
+#: cp/decl.c:8545
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr ""
 
-#: cp/decl.c:8526
+#: cp/decl.c:8547
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: cp/decl.c:8528
+#: cp/decl.c:8549
 #, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr ""
 
-#: cp/decl.c:8535
+#: cp/decl.c:8556
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/decl.c:8542
+#: cp/decl.c:8563
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "συντακτικό σφάλμα στον καθορισμό σειράς"
 
-#: cp/decl.c:8574
+#: cp/decl.c:8595
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr ""
 
-#: cp/decl.c:8614
+#: cp/decl.c:8635
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr ""
 
-#: cp/decl.c:8624
+#: cp/decl.c:8645
 #, fuzzy, gcc-internal-format
 msgid "concept %q#D declared with function parameters"
 msgstr "συνεχίζεται στο τμήμα"
 
-#: cp/decl.c:8630
+#: cp/decl.c:8651
 #, fuzzy, gcc-internal-format
 msgid "concept %q#D declared with a deduced return type"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: cp/decl.c:8632
+#: cp/decl.c:8653
 #, gcc-internal-format
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr ""
 
-#: cp/decl.c:8703
+#: cp/decl.c:8724
 #, fuzzy, gcc-internal-format
 msgid "concept %qD has no definition"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: cp/decl.c:8772
+#: cp/decl.c:8793
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr ""
 
 #. Something like `template <class T> friend void f<T>()'.
-#: cp/decl.c:8782
+#: cp/decl.c:8803
 #, fuzzy, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
-#: cp/decl.c:8800
+#: cp/decl.c:8821
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:8808
+#: cp/decl.c:8829
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr ""
 
-#: cp/decl.c:8857
+#: cp/decl.c:8878
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/decl.c:8859
+#: cp/decl.c:8880
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "αδυναμία αλλαγής στο κατάλογο %s"
 
-#: cp/decl.c:8861
+#: cp/decl.c:8882
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be %<constexpr%>"
 msgstr "αδυναμία αλλαγής στο κατάλογο %s"
 
-#: cp/decl.c:8863
+#: cp/decl.c:8884
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "αδυναμία αλλαγής στο κατάλογο %s"
 
-#: cp/decl.c:8920
+#: cp/decl.c:8941
 #, fuzzy, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/decl.c:8921
+#: cp/decl.c:8942
 #, fuzzy, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/decl.c:8929
+#: cp/decl.c:8950
 #, fuzzy, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/decl.c:8930
+#: cp/decl.c:8951
 #, fuzzy, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/decl.c:8940
+#: cp/decl.c:8961
 #, gcc-internal-format
 msgid "deduction guide %qD must be declared at namespace scope"
 msgstr ""
 
-#: cp/decl.c:8946
+#: cp/decl.c:8967
 #, fuzzy, gcc-internal-format
 msgid "deduction guide %qD must not have a function body"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: cp/decl.c:8959
+#: cp/decl.c:8980
 #, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr ""
 
-#: cp/decl.c:8969
+#: cp/decl.c:8990
 #, fuzzy, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/decl.c:8977
+#: cp/decl.c:8998
 #, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:8983
+#: cp/decl.c:9004
 #, gcc-internal-format
 msgid "floating point suffix %qs shadowed by implementation"
 msgstr ""
 
-#: cp/decl.c:8991
+#: cp/decl.c:9012
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/decl.c:8996
+#: cp/decl.c:9017
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "η `%s' είναι συνήθως μη-στατική συνάρτηση"
 
-#: cp/decl.c:9076
+#: cp/decl.c:9097
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%> πρέπει να επιστρέψει %<int%>"
 
-#: cp/decl.c:9116
+#: cp/decl.c:9137
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr ""
 
-#: cp/decl.c:9121
+#: cp/decl.c:9142
 #, fuzzy, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "κανένας ορισμός του `UNDEFINED'"
 
-#: cp/decl.c:9123
+#: cp/decl.c:9144
 #, fuzzy, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/decl.c:9140
+#: cp/decl.c:9161
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr ""
 
-#: cp/decl.c:9329
+#: cp/decl.c:9350
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/decl.c:9337
+#: cp/decl.c:9358
 #, fuzzy, gcc-internal-format
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/decl.c:9344
+#: cp/decl.c:9365
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.c:9464
+#: cp/decl.c:9485
 #, fuzzy, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "μη έγκυρος δεύτερος τελεστής σε κατάσταση συμβατότητας `%s'"
 
-#: cp/decl.c:9468
+#: cp/decl.c:9489
 #, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr ""
 
-#: cp/decl.c:9472
+#: cp/decl.c:9493
 #, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr ""
 
-#: cp/decl.c:9486
+#: cp/decl.c:9507
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:9493
+#: cp/decl.c:9514
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr ""
 
-#: cp/decl.c:9498
+#: cp/decl.c:9519
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:9598
+#: cp/decl.c:9619
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:9600
+#: cp/decl.c:9621
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr ""
 
-#: cp/decl.c:9630 cp/decl.c:9680
+#: cp/decl.c:9651 cp/decl.c:9701
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr ""
 
-#: cp/decl.c:9646
+#: cp/decl.c:9667
 #, fuzzy, gcc-internal-format
 msgid "size of array %qD is negative"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: cp/decl.c:9648 cp/init.c:3651
+#: cp/decl.c:9669 cp/init.c:3667
 #, gcc-internal-format
 msgid "size of array is negative"
 msgstr ""
 
-#: cp/decl.c:9662
+#: cp/decl.c:9683
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr ""
 
-#: cp/decl.c:9664
+#: cp/decl.c:9685
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr ""
 
-#: cp/decl.c:9677
+#: cp/decl.c:9698
 #, fuzzy, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/decl.c:9686
+#: cp/decl.c:9707
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr ""
 
-#: cp/decl.c:9688
+#: cp/decl.c:9709
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr ""
 
-#: cp/decl.c:9694
+#: cp/decl.c:9715
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr ""
 
-#: cp/decl.c:9697
+#: cp/decl.c:9718
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr ""
 
-#: cp/decl.c:9746
+#: cp/decl.c:9767
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr ""
 
-#: cp/decl.c:9799
+#: cp/decl.c:9820
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as array of %qT"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.c:9809
+#: cp/decl.c:9830
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: cp/decl.c:9811
+#: cp/decl.c:9832
 #, fuzzy, gcc-internal-format
 msgid "creating array of void"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.c:9816
+#: cp/decl.c:9837
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: cp/decl.c:9818
+#: cp/decl.c:9839
 #, fuzzy, gcc-internal-format
 msgid "creating array of functions"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.c:9823
+#: cp/decl.c:9844
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: cp/decl.c:9825
+#: cp/decl.c:9846
 #, fuzzy, gcc-internal-format
 msgid "creating array of references"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.c:9830
+#: cp/decl.c:9851
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: cp/decl.c:9832
+#: cp/decl.c:9853
 #, fuzzy, gcc-internal-format
 msgid "creating array of function members"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: cp/decl.c:9846
+#: cp/decl.c:9867
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.c:9850
+#: cp/decl.c:9871
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr ""
 
-#: cp/decl.c:9909
+#: cp/decl.c:9930
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr ""
 
-#: cp/decl.c:9912
+#: cp/decl.c:9933
 #, gcc-internal-format
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr ""
 
-#: cp/decl.c:9922
+#: cp/decl.c:9943
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr ""
 
-#: cp/decl.c:9925
+#: cp/decl.c:9946
 #, fuzzy, gcc-internal-format
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "κενό αλφαριθμητικό"
 
-#: cp/decl.c:9937
+#: cp/decl.c:9958
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr ""
 
-#: cp/decl.c:9940
+#: cp/decl.c:9961
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr ""
 
-#: cp/decl.c:9948
+#: cp/decl.c:9969
 #, fuzzy, gcc-internal-format
 msgid "return type specified for deduction guide"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 
-#: cp/decl.c:9951
+#: cp/decl.c:9972
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr ""
 
-#: cp/decl.c:9955
+#: cp/decl.c:9976
 #, fuzzy, gcc-internal-format
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "Προειδοποίηση: Πολύ λίγα ορίσματα στο εσωδομημένο `%s'"
 
-#: cp/decl.c:9964
+#: cp/decl.c:9985
 #, fuzzy, gcc-internal-format
 msgid "decl-specifier in declaration of deduction guide"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: cp/decl.c:9985
+#: cp/decl.c:10006
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr ""
 
-#: cp/decl.c:9992
+#: cp/decl.c:10013
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr ""
 
-#: cp/decl.c:10007
+#: cp/decl.c:10028
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr ""
 
-#: cp/decl.c:10013
+#: cp/decl.c:10034
 #, gcc-internal-format
 msgid "inline variables are only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/decl.c:10268
+#: cp/decl.c:10292
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "μη έγκυρος χρήστης"
 
-#: cp/decl.c:10271 cp/decl.c:10291
+#: cp/decl.c:10295 cp/decl.c:10315
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/decl.c:10274
+#: cp/decl.c:10298
 #, fuzzy, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/decl.c:10283
+#: cp/decl.c:10307
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a class or a namespace"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/decl.c:10305 cp/decl.c:10398 cp/decl.c:10407 cp/decl.c:11970
+#: cp/decl.c:10329 cp/decl.c:10422 cp/decl.c:10431 cp/decl.c:11994
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: cp/decl.c:10311
+#: cp/decl.c:10335
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as non-member"
 msgstr "Η λειτουργία δεν υποστηρίζεται"
 
-#: cp/decl.c:10339
+#: cp/decl.c:10363
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr ""
 
-#: cp/decl.c:10390
+#: cp/decl.c:10414
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr ""
 
-#: cp/decl.c:10415
+#: cp/decl.c:10439
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.c:10420
+#: cp/decl.c:10444
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.c:10454
+#: cp/decl.c:10478
 #, gcc-internal-format
 msgid "%<concept%> cannot appear in a typedef declaration"
 msgstr ""
 
-#: cp/decl.c:10460
+#: cp/decl.c:10484
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/decl.c:10468
+#: cp/decl.c:10492
 #, fuzzy, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "Προειδοποίηση: Πολύ λίγα ορίσματα στο εσωδομημένο `%s'"
 
-#: cp/decl.c:10474
+#: cp/decl.c:10498
 #, fuzzy, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr "Μη έγκυρη ανταλλαγή"
 
-#: cp/decl.c:10515
+#: cp/decl.c:10539
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: cp/decl.c:10564 cp/decl.c:10567 cp/decl.c:10570
+#: cp/decl.c:10588 cp/decl.c:10591 cp/decl.c:10594
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr ""
 
-#: cp/decl.c:10586
+#: cp/decl.c:10610
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: cp/decl.c:10592
+#: cp/decl.c:10616
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: cp/decl.c:10614 cp/decl.c:10634
+#: cp/decl.c:10638 cp/decl.c:10658
 #, fuzzy, gcc-internal-format
 msgid "%<signed%> or %<unsigned%> invalid for %qs"
 msgstr "μη έγκυρος δηλωτής πεδίου: `%s'"
 
-#: cp/decl.c:10616
+#: cp/decl.c:10640
 #, fuzzy, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgstr "μη έγκυρος δηλωτής πεδίου: `%s'"
 
-#: cp/decl.c:10618
+#: cp/decl.c:10642
 #, fuzzy, gcc-internal-format
 msgid "%<long long%> invalid for %qs"
 msgstr "Μη έγκυρη προτεραιότητα `%s'"
 
-#: cp/decl.c:10620
+#: cp/decl.c:10644
 #, fuzzy, gcc-internal-format
 msgid "%<long%> invalid for %qs"
 msgstr "Μη έγκυρη προτεραιότητα `%s'"
 
-#: cp/decl.c:10622
+#: cp/decl.c:10646
 #, fuzzy, gcc-internal-format
 msgid "%<short%> invalid for %qs"
 msgstr "Μη έγκυρη προτεραιότητα `%s'"
 
-#: cp/decl.c:10624
+#: cp/decl.c:10648
 #, fuzzy, gcc-internal-format
 msgid "%<long%> or %<short%> invalid for %qs"
 msgstr "μη έγκυρος δηλωτής πεδίου: `%s'"
 
-#: cp/decl.c:10626
+#: cp/decl.c:10650
 #, fuzzy, gcc-internal-format
 msgid "%<long%>, %<int%>, %<short%>, or %<char%> invalid for %qs"
 msgstr "μη έγκυρος δηλωτής πεδίου: `%s'"
 
-#: cp/decl.c:10628
+#: cp/decl.c:10652
 #, fuzzy, gcc-internal-format
 msgid "%<long%> or %<short%> specified with char for %qs"
 msgstr "μόνο ένα όρισμα μπορεί να δηλωθεί"
 
-#: cp/decl.c:10630
+#: cp/decl.c:10654
 #, fuzzy, gcc-internal-format
 msgid "%<long%> and %<short%> specified together for %qs"
 msgstr "μόνο ένα όρισμα μπορεί να δηλωθεί"
 
-#: cp/decl.c:10636
+#: cp/decl.c:10660
 #, fuzzy, gcc-internal-format
 msgid "%<short%> or %<long%> invalid for %qs"
 msgstr "μη έγκυρος δηλωτής πεδίου: `%s'"
 
-#: cp/decl.c:10644
+#: cp/decl.c:10668
 #, fuzzy, gcc-internal-format
 msgid "long, short, signed or unsigned used invalidly for %qs"
 msgstr "μη έγκυρος δηλωτής πεδίου: `%s'"
 
-#: cp/decl.c:10712
+#: cp/decl.c:10736
 #, fuzzy, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "Μη έγκυρη προτεραιότητα `%s'"
 
-#: cp/decl.c:10751
+#: cp/decl.c:10775
 #, gcc-internal-format
 msgid "template placeholder type %qT must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.c:10769
+#: cp/decl.c:10793
 #, fuzzy, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/decl.c:10775
+#: cp/decl.c:10799
 #, gcc-internal-format
 msgid "member %qD cannot be declared both %<virtual%> and %<constexpr%>"
 msgstr ""
 
-#: cp/decl.c:10785
+#: cp/decl.c:10809
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr ""
 
-#: cp/decl.c:10790
+#: cp/decl.c:10814
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "Εγγραφή ονομάτων των επιλεγμένων λέξεων-κλειδιών"
 
-#: cp/decl.c:10796
+#: cp/decl.c:10820
 #, gcc-internal-format
 msgid "storage class specifiers invalid in parameter declarations"
 msgstr ""
 
-#: cp/decl.c:10800
+#: cp/decl.c:10824
 #, fuzzy, gcc-internal-format
 msgid "a parameter cannot be declared %<concept%>"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: cp/decl.c:10805
+#: cp/decl.c:10829
 #, fuzzy, gcc-internal-format
 msgid "a parameter cannot be declared %<constexpr%>"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/decl.c:10815
+#: cp/decl.c:10839
 #, fuzzy, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "κενό αλφαριθμητικό"
 
-#: cp/decl.c:10825
+#: cp/decl.c:10849
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<inline%>"
 msgstr ""
 
-#: cp/decl.c:10828
+#: cp/decl.c:10852
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<typedef%>"
 msgstr ""
 
-#: cp/decl.c:10830
+#: cp/decl.c:10854
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<constexpr%>"
 msgstr ""
 
-#: cp/decl.c:10834
+#: cp/decl.c:10858
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr "αδυναμία ανάγνωσης κεφαλίδας από το `%s'"
 
-#: cp/decl.c:10839
+#: cp/decl.c:10863
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<concept%>"
 msgstr ""
 
-#: cp/decl.c:10845
+#: cp/decl.c:10869
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %<register%>"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/decl.c:10849
+#: cp/decl.c:10873
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %<static%>"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/decl.c:10853
+#: cp/decl.c:10877
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %<extern%>"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/decl.c:10857
+#: cp/decl.c:10881
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %<mutable%>"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/decl.c:10861
+#: cp/decl.c:10885
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10872
+#: cp/decl.c:10896
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr "αδυναμία ανάγνωσης κεφαλίδας από το `%s'"
 
-#: cp/decl.c:10875
+#: cp/decl.c:10899
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10906
+#: cp/decl.c:10930
 #, fuzzy, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/decl.c:10929
+#: cp/decl.c:10953
 #, fuzzy, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "Εγγραφή ονομάτων των επιλεγμένων λέξεων-κλειδιών"
 
-#: cp/decl.c:10933
+#: cp/decl.c:10957
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr ""
 
-#: cp/decl.c:10946
+#: cp/decl.c:10970
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr ""
 
-#: cp/decl.c:10950
+#: cp/decl.c:10974
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10957
+#: cp/decl.c:10981
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr ""
 
-#: cp/decl.c:10969
+#: cp/decl.c:10993
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr ""
 
-#: cp/decl.c:11050
+#: cp/decl.c:11074
 #, fuzzy, gcc-internal-format
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/decl.c:11098
+#: cp/decl.c:11122
 #, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr ""
 
-#: cp/decl.c:11118
+#: cp/decl.c:11142
 #, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr ""
 
-#: cp/decl.c:11121
+#: cp/decl.c:11145
 #, gcc-internal-format
 msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/decl.c:11127
+#: cp/decl.c:11151
 #, fuzzy, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/decl.c:11134
+#: cp/decl.c:11158
 #, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr ""
 
-#: cp/decl.c:11147
+#: cp/decl.c:11171
 #, fuzzy, gcc-internal-format
 msgid "deduced class type %qD in function return type"
 msgstr "άγνωστος χαρακτήρας στο πεδίο `%s' της κατηγορίας `%s'"
 
-#: cp/decl.c:11156
+#: cp/decl.c:11180
 #, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr ""
 
-#: cp/decl.c:11169
+#: cp/decl.c:11193
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
@@ -42605,283 +42647,283 @@
 
 #. Not using maybe_warn_cpp0x because this should
 #. always be an error.
-#: cp/decl.c:11180
+#: cp/decl.c:11204
 #, gcc-internal-format
 msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/decl.c:11183
+#: cp/decl.c:11207
 #, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr ""
 
-#: cp/decl.c:11212
+#: cp/decl.c:11236
 #, fuzzy, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%s: διπλός ορισμός έκδοσης κατηγορίας"
 
-#: cp/decl.c:11218
+#: cp/decl.c:11242
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr ""
 
-#: cp/decl.c:11247
+#: cp/decl.c:11271
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.c:11248
+#: cp/decl.c:11272
 #, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr ""
 
-#: cp/decl.c:11252
+#: cp/decl.c:11276
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.c:11253
+#: cp/decl.c:11277
 #, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr ""
 
-#: cp/decl.c:11261
+#: cp/decl.c:11285
 #, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr ""
 
-#: cp/decl.c:11262
+#: cp/decl.c:11286
 #, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr ""
 
-#: cp/decl.c:11280
+#: cp/decl.c:11304
 #, fuzzy, gcc-internal-format
 msgid "constructors cannot be declared %<virtual%>"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
 #. Cannot be both friend and virtual.
-#: cp/decl.c:11295
+#: cp/decl.c:11319
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr ""
 
-#: cp/decl.c:11299
+#: cp/decl.c:11323
 #, fuzzy, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/decl.c:11301
+#: cp/decl.c:11325
 #, fuzzy, gcc-internal-format
 msgid "can%'t define friend function %qs in a local class definition"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/decl.c:11313
+#: cp/decl.c:11337
 #, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr ""
 
-#: cp/decl.c:11339
+#: cp/decl.c:11363
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr ""
 
-#: cp/decl.c:11379
+#: cp/decl.c:11403
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/decl.c:11392 cp/decl.c:11399
+#: cp/decl.c:11416 cp/decl.c:11423
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "αδυναμία αλλαγής στο κατάλογο %s"
 
-#: cp/decl.c:11401
+#: cp/decl.c:11425
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "δεν είναι δυνατόν να γίνει `stat' το locale αρχείο `%s'"
 
-#: cp/decl.c:11430
+#: cp/decl.c:11454
 #, fuzzy, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "αδυναμία αλλαγής στο κατάλογο %s"
 
-#: cp/decl.c:11431
+#: cp/decl.c:11455
 #, fuzzy, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "άγνωστος χαρακτήρας στο πεδίο `%s' της κατηγορίας `%s'"
 
-#: cp/decl.c:11504
+#: cp/decl.c:11528
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr ""
 
-#: cp/decl.c:11574
+#: cp/decl.c:11598
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr ""
 
-#: cp/decl.c:11599
+#: cp/decl.c:11623
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr ""
 
-#: cp/decl.c:11605
+#: cp/decl.c:11629
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr ""
 
-#: cp/decl.c:11635
+#: cp/decl.c:11659
 #, fuzzy, gcc-internal-format
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/decl.c:11637
+#: cp/decl.c:11661
 #, fuzzy, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/decl.c:11645
+#: cp/decl.c:11669
 #, fuzzy, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/decl.c:11685
+#: cp/decl.c:11709
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr ""
 
-#: cp/decl.c:11693
+#: cp/decl.c:11717
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.c:11695
+#: cp/decl.c:11719
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr ""
 
-#: cp/decl.c:11706
+#: cp/decl.c:11730
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/decl.c:11709
+#: cp/decl.c:11733
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr "κενό αλφαριθμητικό"
 
-#: cp/decl.c:11712
+#: cp/decl.c:11736
 #, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr ""
 
-#: cp/decl.c:11721
+#: cp/decl.c:11745
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:11726
+#: cp/decl.c:11750
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr ""
 
-#: cp/decl.c:11732
+#: cp/decl.c:11756
 #, fuzzy, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/decl.c:11737
+#: cp/decl.c:11761
 #, fuzzy, gcc-internal-format
 msgid "static %qs cannot be declared %<mutable%>"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/decl.c:11742
+#: cp/decl.c:11766
 #, fuzzy, gcc-internal-format
 msgid "const %qs cannot be declared %<mutable%>"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/decl.c:11747
+#: cp/decl.c:11771
 #, fuzzy, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/decl.c:11778
+#: cp/decl.c:11802
 #, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr ""
 
-#: cp/decl.c:11783
+#: cp/decl.c:11807
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.c:11787
+#: cp/decl.c:11811
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr ""
 
-#: cp/decl.c:11813
+#: cp/decl.c:11837
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "Υπάρχει αντικείμενο με το ίδιο όνομα"
 
-#: cp/decl.c:11900
+#: cp/decl.c:11924
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr ""
 
-#: cp/decl.c:11908
+#: cp/decl.c:11932
 #, fuzzy, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/decl.c:11910
+#: cp/decl.c:11934
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr ""
 
-#: cp/decl.c:11914
+#: cp/decl.c:11938
 #, fuzzy, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/decl.c:11927
+#: cp/decl.c:11951
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr ""
 
-#: cp/decl.c:11947
+#: cp/decl.c:11971
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr ""
 
-#: cp/decl.c:11951
+#: cp/decl.c:11975
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.c:11961
+#: cp/decl.c:11985
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr ""
 
-#: cp/decl.c:11976
+#: cp/decl.c:12000
 #, fuzzy, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.c:11995
+#: cp/decl.c:12019
 #, fuzzy, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "αδυναμία εισαγωγής στοιχείο παραβολής `%.*s'"
 
-#: cp/decl.c:12001
+#: cp/decl.c:12025
 #, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr ""
 
-#: cp/decl.c:12003
+#: cp/decl.c:12027
 #, fuzzy, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
@@ -42888,178 +42930,178 @@
 
 # src/grep.c:785 src/grep.c:792
 # src/grep.c:1060 src/grep.c:1067 src/grep.c:1076
-#: cp/decl.c:12052 cp/parser.c:3270
+#: cp/decl.c:12076 cp/parser.c:3270
 #, fuzzy, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "μη έγκυρο όρισμα μήκους περιεχομένου"
 
-#: cp/decl.c:12056
+#: cp/decl.c:12080
 #, fuzzy, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/decl.c:12080
+#: cp/decl.c:12104
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: cp/decl.c:12083
+#: cp/decl.c:12107
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids flexible array members"
 msgstr "μη έγκυρη ώρα της μέρας"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:12099
+#: cp/decl.c:12123
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "μη έγκυρος χρήστης"
 
-#: cp/decl.c:12121
+#: cp/decl.c:12145
 #, fuzzy, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%#D'"
 
-#: cp/decl.c:12130
+#: cp/decl.c:12154
 #, fuzzy, gcc-internal-format
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/decl.c:12139
+#: cp/decl.c:12163
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/decl.c:12153
+#: cp/decl.c:12177
 #, fuzzy, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/decl.c:12160
+#: cp/decl.c:12184
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/decl.c:12166
+#: cp/decl.c:12190
 #, gcc-internal-format
 msgid "a destructor cannot be %<concept%>"
 msgstr ""
 
-#: cp/decl.c:12171
+#: cp/decl.c:12195
 #, gcc-internal-format
 msgid "a destructor cannot be %<constexpr%>"
 msgstr ""
 
-#: cp/decl.c:12177
+#: cp/decl.c:12201
 #, fuzzy, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/decl.c:12185
+#: cp/decl.c:12209
 #, gcc-internal-format
 msgid "a constructor cannot be %<concept%>"
 msgstr ""
 
-#: cp/decl.c:12190
+#: cp/decl.c:12214
 #, fuzzy, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr "Το επώνυμο αντικείμενο δεν είναι αναζητήσιμο"
 
-#: cp/decl.c:12199
+#: cp/decl.c:12223
 #, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr ""
 
-#: cp/decl.c:12202
+#: cp/decl.c:12226
 #, fuzzy, gcc-internal-format
 msgid "variable template declared here"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: cp/decl.c:12257
+#: cp/decl.c:12281
 #, fuzzy, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/decl.c:12262
+#: cp/decl.c:12286
 #, fuzzy, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/decl.c:12272
+#: cp/decl.c:12296
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr ""
 
-#: cp/decl.c:12318
+#: cp/decl.c:12342
 #, fuzzy, gcc-internal-format
 msgid "static data member %qE declared %<concept%>"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/decl.c:12322
+#: cp/decl.c:12346
 #, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr ""
 
-#: cp/decl.c:12350
+#: cp/decl.c:12374
 #, fuzzy, gcc-internal-format
 msgid "non-static data member %qE declared %<concept%>"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/decl.c:12354
+#: cp/decl.c:12378
 #, fuzzy, gcc-internal-format
 msgid "non-static data member %qE declared %<constexpr%>"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/decl.c:12409
+#: cp/decl.c:12433
 #, fuzzy, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "μη έγκυρη τάξη χαρακτήρων `%s'"
 
-#: cp/decl.c:12411
+#: cp/decl.c:12435
 #, fuzzy, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "μη έγκυρη τάξη χαρακτήρων `%s'"
 
-#: cp/decl.c:12415
+#: cp/decl.c:12439
 #, fuzzy, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "μη έγκυρη τάξη χαρακτήρων `%s'"
 
-#: cp/decl.c:12418
+#: cp/decl.c:12442
 #, fuzzy, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "μη έγκυρη τάξη χαρακτήρων `%s'"
 
-#: cp/decl.c:12423
+#: cp/decl.c:12447
 #, fuzzy, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/decl.c:12434
+#: cp/decl.c:12458
 #, gcc-internal-format
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.c:12438
+#: cp/decl.c:12462
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr ""
 
-#: cp/decl.c:12446
+#: cp/decl.c:12470
 #, fuzzy, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "μη έγκυρη τάξη χαρακτήρων `%s'"
 
-#: cp/decl.c:12453
+#: cp/decl.c:12477
 #, fuzzy, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/decl.c:12454
+#: cp/decl.c:12478
 #, fuzzy, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/decl.c:12489
+#: cp/decl.c:12513
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr ""
@@ -43066,77 +43108,77 @@
 
 #. 7.1.1: There can be no static function declarations within a
 #. block.
-#: cp/decl.c:12497
+#: cp/decl.c:12521
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr ""
 
-#: cp/decl.c:12533
+#: cp/decl.c:12557
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr ""
 
-#: cp/decl.c:12540
+#: cp/decl.c:12564
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr ""
 
-#: cp/decl.c:12546
+#: cp/decl.c:12570
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr ""
 
-#: cp/decl.c:12553
+#: cp/decl.c:12577
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/decl.c:12574
+#: cp/decl.c:12598
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "αυτονόητη διακύρηξη της συνάρτησης `%s'"
 
-#: cp/decl.c:12585
+#: cp/decl.c:12609
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr ""
 
-#: cp/decl.c:12589
+#: cp/decl.c:12613
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr ""
 
-#: cp/decl.c:12754
+#: cp/decl.c:12778
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: cp/decl.c:12757
+#: cp/decl.c:12781
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: cp/decl.c:12841
+#: cp/decl.c:12865
 #, fuzzy, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/decl.c:12845
+#: cp/decl.c:12869
 #, fuzzy, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/decl.c:12868
+#: cp/decl.c:12892
 #, fuzzy, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: cp/decl.c:12895
+#: cp/decl.c:12919
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr ""
 
-#: cp/decl.c:12897
+#: cp/decl.c:12921
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr ""
@@ -43156,169 +43198,169 @@
 #. or implicitly defined), there's no need to worry about their
 #. existence.  Theoretically, they should never even be
 #. instantiated, but that's hard to forestall.
-#: cp/decl.c:13150
+#: cp/decl.c:13174
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr ""
 
-#: cp/decl.c:13228
+#: cp/decl.c:13252
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr ""
 
-#: cp/decl.c:13234
+#: cp/decl.c:13258
 #, fuzzy, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/decl.c:13261
+#: cp/decl.c:13285
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr "η `%s' είναι συνήθως μη-στατική συνάρτηση"
 
-#: cp/decl.c:13267
+#: cp/decl.c:13291
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr ""
 
-#: cp/decl.c:13277
+#: cp/decl.c:13301
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr ""
 
 #. 13.4.0.3
-#: cp/decl.c:13303
+#: cp/decl.c:13327
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading operator ?:"
 msgstr ""
 
 #. Variadic.
-#: cp/decl.c:13314
+#: cp/decl.c:13338
 #, fuzzy, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "η `%s' παίρνει είτε κανένα είτε δύο ορίσματα"
 
-#: cp/decl.c:13338
+#: cp/decl.c:13362
 #, fuzzy, gcc-internal-format
 msgid "%qD must have either zero or one argument"
 msgstr "η `%s' παίρνει είτε κανένα είτε δύο ορίσματα"
 
-#: cp/decl.c:13339
+#: cp/decl.c:13363
 #, fuzzy, gcc-internal-format
 msgid "%qD must have either one or two arguments"
 msgstr "η `%s' παίρνει είτε κανένα είτε δύο ορίσματα"
 
-#: cp/decl.c:13350
+#: cp/decl.c:13374
 #, fuzzy, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "η `%s' παίρνει είτε κανένα είτε δύο ορίσματα"
 
-#: cp/decl.c:13351
+#: cp/decl.c:13375
 #, fuzzy, gcc-internal-format
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "η `%s' παίρνει είτε κανένα είτε δύο ορίσματα"
 
-#: cp/decl.c:13361
+#: cp/decl.c:13385
 #, fuzzy, gcc-internal-format
 msgid "%qD must have no arguments"
 msgstr "η `%s' παίρνει είτε κανένα είτε δύο ορίσματα"
 
-#: cp/decl.c:13362 cp/decl.c:13371
+#: cp/decl.c:13386 cp/decl.c:13395
 #, fuzzy, gcc-internal-format
 msgid "%qD must have exactly one argument"
 msgstr "η `%s' παίρνει είτε κανένα είτε δύο ορίσματα"
 
-#: cp/decl.c:13372
+#: cp/decl.c:13396
 #, fuzzy, gcc-internal-format
 msgid "%qD must have exactly two arguments"
 msgstr "η `%s' παίρνει είτε κανένα είτε δύο ορίσματα"
 
-#: cp/decl.c:13389 cp/decl.c:13392
+#: cp/decl.c:13413 cp/decl.c:13416
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/decl.c:13419
+#: cp/decl.c:13443
 #, gcc-internal-format
 msgid "conversion to a reference to void will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13421
+#: cp/decl.c:13445
 #, gcc-internal-format
 msgid "conversion to void will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13428
+#: cp/decl.c:13452
 #, gcc-internal-format
 msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13430
+#: cp/decl.c:13454
 #, gcc-internal-format
 msgid "conversion to the same type will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13438
+#: cp/decl.c:13462
 #, gcc-internal-format
 msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13440
+#: cp/decl.c:13464
 #, gcc-internal-format
 msgid "conversion to a base class will never use a type conversion operator"
 msgstr ""
 
-#: cp/decl.c:13455
+#: cp/decl.c:13479
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr ""
 
-#: cp/decl.c:13474
+#: cp/decl.c:13498
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.c:13480
+#: cp/decl.c:13504
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr ""
 
-#: cp/decl.c:13492
+#: cp/decl.c:13516
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr ""
 
-#: cp/decl.c:13547
+#: cp/decl.c:13571
 #, fuzzy, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/decl.c:13570
+#: cp/decl.c:13594
 #, fuzzy, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/decl.c:13573
+#: cp/decl.c:13597
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr ""
 
-#: cp/decl.c:13575
+#: cp/decl.c:13599
 #, fuzzy, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: cp/decl.c:13583
+#: cp/decl.c:13607
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr ""
 
-#: cp/decl.c:13584 cp/decl.c:13591
+#: cp/decl.c:13608 cp/decl.c:13615
 #, fuzzy, gcc-internal-format
 msgid "%qT has a previous declaration here"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: cp/decl.c:13590
+#: cp/decl.c:13614
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr ""
@@ -43330,23 +43372,23 @@
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:13605
+#: cp/decl.c:13629
 #, fuzzy, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "έχουν παραληφθεί ορίσματα"
 
-#: cp/decl.c:13659 cp/name-lookup.c:4652
+#: cp/decl.c:13683 cp/name-lookup.c:4652
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr ""
 
-#: cp/decl.c:13689 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6425
-#: cp/pt.c:9209
+#: cp/decl.c:13713 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6428
+#: cp/pt.c:9223
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/decl.c:13694
+#: cp/decl.c:13718
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
@@ -43353,73 +43395,73 @@
 
 # src/getopt.c:628
 # src/getopt.c:628
-#: cp/decl.c:13703 cp/name-lookup.c:4079 cp/name-lookup.c:4086
-#: cp/name-lookup.c:4939 cp/parser.c:6376 cp/parser.c:26300
+#: cp/decl.c:13727 cp/name-lookup.c:4079 cp/name-lookup.c:4086
+#: cp/name-lookup.c:4939 cp/parser.c:6379 cp/parser.c:26297
 #, fuzzy, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "%s: η επιλογή `%s' είναι ασαφής\n"
 
-#: cp/decl.c:13806
+#: cp/decl.c:13830
 #, fuzzy, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: cp/decl.c:13842
+#: cp/decl.c:13866
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "Η λειτουργία δεν υποστηρίζεται"
 
-#: cp/decl.c:13982
+#: cp/decl.c:14006
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr ""
 
-#: cp/decl.c:13989
+#: cp/decl.c:14013
 #, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr ""
 
-#: cp/decl.c:14000
+#: cp/decl.c:14024
 #, fuzzy, gcc-internal-format
 msgid "%qT defined with direct virtual base"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/decl.c:14025
+#: cp/decl.c:14049
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr ""
 
-#: cp/decl.c:14055
+#: cp/decl.c:14079
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr ""
 
-#: cp/decl.c:14057
+#: cp/decl.c:14081
 #, fuzzy, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "διπλός ορισμός συνόλου"
 
-#: cp/decl.c:14202
+#: cp/decl.c:14226
 #, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14205 cp/decl.c:14213 cp/decl.c:14225 cp/parser.c:18284
+#: cp/decl.c:14229 cp/decl.c:14237 cp/decl.c:14249 cp/parser.c:18281
 #, fuzzy, gcc-internal-format
 msgid "previous definition here"
 msgstr "κανένας ορισμός του `UNDEFINED'"
 
-#: cp/decl.c:14210
+#: cp/decl.c:14234
 #, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14222
+#: cp/decl.c:14246
 #, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14300
+#: cp/decl.c:14324
 #, gcc-internal-format
 msgid "underlying type %qT of %qT must be an integral type"
 msgstr ""
@@ -43428,77 +43470,77 @@
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:14447
+#: cp/decl.c:14471
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr ""
 
-#: cp/decl.c:14619
+#: cp/decl.c:14643
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: cp/decl.c:14629
+#: cp/decl.c:14653
 #, fuzzy, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: cp/decl.c:14678
+#: cp/decl.c:14702
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr ""
 
-#: cp/decl.c:14679
+#: cp/decl.c:14703
 #, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr ""
 
-#: cp/decl.c:14690
+#: cp/decl.c:14714
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr ""
 
-#: cp/decl.c:14710
+#: cp/decl.c:14734
 #, fuzzy, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: cp/decl.c:14821
+#: cp/decl.c:14845
 #, fuzzy, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "η επιστρεφόμενη τιμή της `%s' δεν είναι `int'"
 
-#: cp/decl.c:14999 cp/typeck.c:9286
+#: cp/decl.c:15023 cp/typeck.c:9286
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr ""
 
-#: cp/decl.c:15344
+#: cp/decl.c:15368
 #, fuzzy, gcc-internal-format
 msgid "invalid function declaration"
 msgstr "Μη έγκυρη ανταλλαγή"
 
-#: cp/decl.c:15786
+#: cp/decl.c:15810
 #, fuzzy, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr "`return' χωρίς τιμή, σε συνάρτηση που επιστρέφει μη-κενό"
 
-#: cp/decl.c:15788 cp/typeck.c:9166
+#: cp/decl.c:15812 cp/typeck.c:9166
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr ""
 
-#: cp/decl.c:15996
+#: cp/decl.c:16020
 #, fuzzy, gcc-internal-format
 msgid "invalid member function declaration"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/decl.c:16010
+#: cp/decl.c:16034
 #, fuzzy, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/decl.c:16386
+#: cp/decl.c:16410
 #, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr ""
@@ -43538,7 +43580,7 @@
 msgid "deleting %qT is undefined"
 msgstr ""
 
-#: cp/decl2.c:585 cp/pt.c:5552
+#: cp/decl2.c:585 cp/pt.c:5566
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "δημιουργία αρχείου `%s'\n"
@@ -43551,7 +43593,7 @@
 #. [temp.mem]
 #.
 #. A destructor shall not be a member template.
-#: cp/decl2.c:640 cp/pt.c:5511
+#: cp/decl2.c:640 cp/pt.c:5525
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr ""
@@ -43726,47 +43768,47 @@
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr ""
 
-#: cp/decl2.c:2660
+#: cp/decl2.c:2650
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2664
+#: cp/decl2.c:2654
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2669
+#: cp/decl2.c:2659
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2677
+#: cp/decl2.c:2667
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr ""
 
-#: cp/decl2.c:2695
+#: cp/decl2.c:2685
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2699
+#: cp/decl2.c:2689
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2704
+#: cp/decl2.c:2694
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2711
+#: cp/decl2.c:2701
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr ""
 
-#: cp/decl2.c:4309
+#: cp/decl2.c:4299
 #, gcc-internal-format
 msgid "%q#D, declared using unnamed type, is used but never defined"
 msgstr ""
@@ -43775,62 +43817,62 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4318
+#: cp/decl2.c:4308
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4322
+#: cp/decl2.c:4312
 #, fuzzy, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/decl2.c:4326
+#: cp/decl2.c:4316
 #, gcc-internal-format
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr ""
 
-#: cp/decl2.c:4334
+#: cp/decl2.c:4324
 #, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr ""
 
-#: cp/decl2.c:4338
+#: cp/decl2.c:4328
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4341
+#: cp/decl2.c:4331
 #, fuzzy, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/decl2.c:4529
+#: cp/decl2.c:4519
 #, fuzzy, gcc-internal-format
 msgid "mangling of %q#D as %qE conflicts with a previous mangle"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: cp/decl2.c:4532
+#: cp/decl2.c:4522
 #, fuzzy, gcc-internal-format
 msgid "previous mangling %q#D"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: cp/decl2.c:4534
+#: cp/decl2.c:4524
 #, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr ""
 
-#: cp/decl2.c:4606 cp/decl2.c:4609
+#: cp/decl2.c:4596 cp/decl2.c:4599
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.c:4956
+#: cp/decl2.c:4946
 #, gcc-internal-format
 msgid "inline function %qD used but never defined"
 msgstr ""
 
-#: cp/decl2.c:5143
+#: cp/decl2.c:5133
 #, fuzzy, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr "έχουν παραληφθεί ορίσματα"
@@ -43837,17 +43879,17 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5251
+#: cp/decl2.c:5241
 #, gcc-internal-format
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.c:5254
+#: cp/decl2.c:5244
 #, fuzzy, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
 
-#: cp/decl2.c:5307
+#: cp/decl2.c:5297
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr ""
@@ -44136,250 +44178,250 @@
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: cp/init.c:613
+#: cp/init.c:629
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr ""
 
-#: cp/init.c:615
+#: cp/init.c:631
 #, fuzzy, gcc-internal-format
 msgid "defined here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/init.c:673
+#: cp/init.c:689
 #, fuzzy, gcc-internal-format
 msgid "initializer for flexible array member %q#D"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: cp/init.c:699
+#: cp/init.c:715
 #, gcc-internal-format
 msgid "%qD should be initialized in the member initialization list"
 msgstr ""
 
-#: cp/init.c:720
+#: cp/init.c:736
 #, fuzzy, gcc-internal-format
 msgid "%qD is initialized with itself"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/init.c:831
+#: cp/init.c:847
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for array member %q#D"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: cp/init.c:845 cp/init.c:869 cp/init.c:2410 cp/method.c:1368
+#: cp/init.c:861 cp/init.c:885 cp/init.c:2427 cp/method.c:1368
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/init.c:847 cp/init.c:864 cp/init.c:871 cp/init.c:2395 cp/init.c:2423
+#: cp/init.c:863 cp/init.c:880 cp/init.c:887 cp/init.c:2412 cp/init.c:2440
 #: cp/method.c:1371 cp/method.c:1382
 #, fuzzy, gcc-internal-format
 msgid "%q#D should be initialized"
 msgstr "η κλάση χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: cp/init.c:862 cp/init.c:2382 cp/method.c:1379
+#: cp/init.c:878 cp/init.c:2399 cp/method.c:1379
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr "δεν είναι δυνατόν να γίνει `stat' το locale αρχείο `%s'"
 
-#: cp/init.c:1041
+#: cp/init.c:1057
 #, gcc-internal-format
 msgid "%qD will be initialized after"
 msgstr ""
 
-#: cp/init.c:1044
+#: cp/init.c:1060
 #, fuzzy, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr "η κλάση χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: cp/init.c:1048
+#: cp/init.c:1064
 #, gcc-internal-format
 msgid "  %q#D"
 msgstr ""
 
-#: cp/init.c:1050
+#: cp/init.c:1066
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr ""
 
-#: cp/init.c:1052
+#: cp/init.c:1068
 #, fuzzy, gcc-internal-format
 msgid "  when initialized here"
 msgstr "η κλάση χαρακτήρων `%s' ορίστηκε ήδη"
 
 # src/request.c:263
-#: cp/init.c:1069
+#: cp/init.c:1085
 #, fuzzy, gcc-internal-format
 msgid "multiple initializations given for %qD"
 msgstr "Το βήμα αρχικοποίησης απέτυχε"
 
 # src/request.c:263
-#: cp/init.c:1073
+#: cp/init.c:1089
 #, fuzzy, gcc-internal-format
 msgid "multiple initializations given for base %qT"
 msgstr "Το βήμα αρχικοποίησης απέτυχε"
 
-#: cp/init.c:1158
+#: cp/init.c:1174
 #, fuzzy, gcc-internal-format
 msgid "initializations for multiple members of %qT"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/init.c:1255
+#: cp/init.c:1271
 #, gcc-internal-format
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr ""
 
-#: cp/init.c:1482 cp/init.c:1501
+#: cp/init.c:1498 cp/init.c:1517
 #, fuzzy, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/init.c:1488
+#: cp/init.c:1504
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr ""
 
-#: cp/init.c:1495
+#: cp/init.c:1511
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/init.c:1534
+#: cp/init.c:1550
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr ""
 
-#: cp/init.c:1542
+#: cp/init.c:1558
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr ""
 
-#: cp/init.c:1589
+#: cp/init.c:1605
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr ""
 
-#: cp/init.c:1597
+#: cp/init.c:1613
 #, fuzzy, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/init.c:1600
+#: cp/init.c:1616
 #, fuzzy, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/init.c:1710 cp/init.c:4386 cp/typeck2.c:1175
+#: cp/init.c:1727 cp/init.c:4402 cp/typeck2.c:1175
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
 
-#: cp/init.c:2019 cp/semantics.c:3268
+#: cp/init.c:2036 cp/semantics.c:3271
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/init.c:2075
+#: cp/init.c:2092
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr ""
 
-#: cp/init.c:2089
+#: cp/init.c:2106
 #, fuzzy, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr "ακατάλληλος τύπος δικτύου :`%s'\n"
 
-#: cp/init.c:2175 cp/typeck.c:1893
+#: cp/init.c:2192 cp/typeck.c:1893
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
 
-#: cp/init.c:2182 cp/semantics.c:1835
+#: cp/init.c:2199 cp/semantics.c:1835
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
 
-#: cp/init.c:2379
+#: cp/init.c:2396
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2387
+#: cp/init.c:2404
 #, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2391
+#: cp/init.c:2408
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr "δεν είναι δυνατόν να γίνει `stat' το locale αρχείο `%s'"
 
-#: cp/init.c:2407
+#: cp/init.c:2424
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/init.c:2415
+#: cp/init.c:2432
 #, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr ""
 
-#: cp/init.c:2419
+#: cp/init.c:2436
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/init.c:2710
+#: cp/init.c:2727
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2721
+#: cp/init.c:2738
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2732
+#: cp/init.c:2749
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2880
+#: cp/init.c:2896
 #, fuzzy, gcc-internal-format
 msgid "integer overflow in array size"
 msgstr "Εξαίρεση κινητής υποδιαστολής"
 
-#: cp/init.c:2890
+#: cp/init.c:2906
 #, gcc-internal-format
 msgid "array size in new-expression must be constant"
 msgstr ""
 
-#: cp/init.c:2904
+#: cp/init.c:2920
 #, gcc-internal-format
 msgid "variably modified type not allowed in new-expression"
 msgstr ""
 
-#: cp/init.c:2920
+#: cp/init.c:2936
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by typedef"
 msgstr ""
 
-#: cp/init.c:2922
+#: cp/init.c:2938
 #, gcc-internal-format
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr ""
 
-#: cp/init.c:2932
+#: cp/init.c:2948
 #, fuzzy, gcc-internal-format
 msgid "invalid type %<void%> for new"
 msgstr "μη έγκυρη κατάσταση για την dlopen()"
 
-#: cp/init.c:2975
+#: cp/init.c:2991
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/init.c:3101
+#: cp/init.c:3117
 #, fuzzy, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr "το `%s' είναι πρόγονος του `%s'"
@@ -44386,87 +44428,87 @@
 
 # src/getopt.c:628
 # src/getopt.c:628
-#: cp/init.c:3108 cp/search.c:1023
+#: cp/init.c:3124 cp/search.c:1026
 #, fuzzy, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "%s: η επιλογή `%s' είναι ασαφής\n"
 
-#: cp/init.c:3181
+#: cp/init.c:3197
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr ""
 
-#: cp/init.c:3184
+#: cp/init.c:3200
 #, fuzzy, gcc-internal-format
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/init.c:3187
+#: cp/init.c:3203
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr ""
 
-#: cp/init.c:3370
+#: cp/init.c:3386
 #, gcc-internal-format
 msgid "parenthesized initializer in array new"
 msgstr ""
 
-#: cp/init.c:3633
+#: cp/init.c:3649
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr ""
 
-#: cp/init.c:3665
+#: cp/init.c:3681
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr ""
 
-#: cp/init.c:3674
+#: cp/init.c:3690
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr ""
 
-#: cp/init.c:3743
+#: cp/init.c:3759
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete [] operator:"
 msgstr ""
 
-#: cp/init.c:3747
+#: cp/init.c:3763
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete [] will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4295
+#: cp/init.c:4311
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr ""
 
-#: cp/init.c:4599
+#: cp/init.c:4615
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr ""
 
-#: cp/init.c:4623
+#: cp/init.c:4639
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete operator:"
 msgstr ""
 
-#: cp/init.c:4628
+#: cp/init.c:4644
 #, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
 msgstr ""
 
-#: cp/init.c:4642
+#: cp/init.c:4658
 #, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4647
+#: cp/init.c:4663
 #, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr ""
 
-#: cp/init.c:4954
+#: cp/init.c:4970
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr ""
@@ -44942,7 +44984,7 @@
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr ""
 
-#: cp/name-lookup.c:5111 cp/name-lookup.c:7065
+#: cp/name-lookup.c:5111 cp/name-lookup.c:7073
 #, fuzzy, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "το `%s' είναι πρόγονος του `%s'"
@@ -44989,53 +45031,53 @@
 msgid "it was later defined here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/name-lookup.c:6687
+#: cp/name-lookup.c:6695
 #, gcc-internal-format
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn't a template"
 msgstr ""
 
-#: cp/name-lookup.c:7059
+#: cp/name-lookup.c:7067
 #, fuzzy, gcc-internal-format
 msgid "strong using directive no longer supported"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: cp/name-lookup.c:7062
+#: cp/name-lookup.c:7070
 #, gcc-internal-format
 msgid "you may use an inline namespace instead"
 msgstr ""
 
-#: cp/name-lookup.c:7079
+#: cp/name-lookup.c:7087
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on local using directive"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/name-lookup.c:7163
+#: cp/name-lookup.c:7171
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr ""
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:7183
+#: cp/name-lookup.c:7191
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot nest more than %d namespaces"
 msgstr "δεν είναι δυνατό να μετανομαστεί το `.' ή το `..'"
 
-#: cp/name-lookup.c:7218
+#: cp/name-lookup.c:7226
 #, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr ""
 
-#: cp/name-lookup.c:7219
+#: cp/name-lookup.c:7227
 #, fuzzy, gcc-internal-format
 msgid "%qD defined here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/name-lookup.c:7292
+#: cp/name-lookup.c:7300
 #, gcc-internal-format
 msgid "XXX entering pop_everything ()\n"
 msgstr ""
 
-#: cp/name-lookup.c:7301
+#: cp/name-lookup.c:7309
 #, gcc-internal-format
 msgid "XXX leaving pop_everything ()\n"
 msgstr ""
@@ -45055,7 +45097,7 @@
 msgid "LEXER_DEBUGGING_ENABLED_P is not set to true"
 msgstr ""
 
-#: cp/parser.c:1352 cp/parser.c:37254
+#: cp/parser.c:1352 cp/parser.c:37251
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -45080,7 +45122,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/parser.c:2949 cp/parser.c:18221
+#: cp/parser.c:2949 cp/parser.c:18218
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
@@ -45160,7 +45202,7 @@
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/parser.c:3143 cp/pt.c:17853
+#: cp/parser.c:3143 cp/pt.c:17890
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr ""
@@ -45382,7 +45424,7 @@
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr ""
 
-#: cp/parser.c:4587 cp/parser.c:12940
+#: cp/parser.c:4587 cp/parser.c:12937
 #, fuzzy, gcc-internal-format
 msgid "expected declaration"
 msgstr "κενό αλφαριθμητικό"
@@ -45432,7 +45474,7 @@
 msgid "fold-expressions only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:5275 cp/parser.c:5452 cp/parser.c:5630 cp/semantics.c:3612
+#: cp/parser.c:5275 cp/parser.c:5452 cp/parser.c:5633 cp/semantics.c:3615
 #, fuzzy, gcc-internal-format
 msgid "expected primary-expression"
 msgstr "Μη έγκυρη προπορευόμενη κανονική έκφραση"
@@ -45452,92 +45494,92 @@
 msgid "local variable %qD may not appear in this context"
 msgstr ""
 
-#: cp/parser.c:5787
+#: cp/parser.c:5790
 #, fuzzy, gcc-internal-format
 msgid "expected id-expression"
 msgstr "Μη έγκυρη προπορευόμενη κανονική έκφραση"
 
-#: cp/parser.c:5919
+#: cp/parser.c:5922
 #, fuzzy, gcc-internal-format
 msgid "scope %qT before %<~%> is not a class-name"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/parser.c:5948 cp/parser.c:7860
+#: cp/parser.c:5951 cp/parser.c:7860
 #, gcc-internal-format
 msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:6059
+#: cp/parser.c:6062
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<~%T%> as member of %qT"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/parser.c:6074
+#: cp/parser.c:6077
 #, gcc-internal-format
 msgid "typedef-name %qD used as destructor declarator"
 msgstr ""
 
-#: cp/parser.c:6111 cp/parser.c:20249
+#: cp/parser.c:6114 cp/parser.c:20246
 #, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr ""
 
-#: cp/parser.c:6220
+#: cp/parser.c:6223
 #, gcc-internal-format
 msgid "found %<:%> in nested-name-specifier, expected %<::%>"
 msgstr ""
 
-#: cp/parser.c:6288
+#: cp/parser.c:6291
 #, gcc-internal-format
 msgid "decltype evaluates to %qT, which is not a class or enumeration type"
 msgstr ""
 
-#: cp/parser.c:6314
+#: cp/parser.c:6317
 #, gcc-internal-format
 msgid "function template-id %qD in nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:6322
+#: cp/parser.c:6325
 #, gcc-internal-format
 msgid "variable template-id %qD in nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:6426 cp/typeck.c:2684 cp/typeck.c:2687 cp/typeck.c:2704
+#: cp/parser.c:6429 cp/typeck.c:2684 cp/typeck.c:2687 cp/typeck.c:2704
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/parser.c:6504
+#: cp/parser.c:6507
 #, fuzzy, gcc-internal-format
 msgid "expected nested-name-specifier"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:6711 cp/parser.c:8950
+#: cp/parser.c:6714 cp/parser.c:8950
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/parser.c:6797
+#: cp/parser.c:6800
 #, gcc-internal-format
 msgid "types may not be defined in a %<typeid%> expression"
 msgstr ""
 
-#: cp/parser.c:6889
+#: cp/parser.c:6892
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "Λείπει παράμετρος για `%s'"
 
-#: cp/parser.c:6901 cp/pt.c:18416
+#: cp/parser.c:6904 cp/pt.c:18453
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "λάθος αριθμός ορισμάτων"
 
-#: cp/parser.c:6995
+#: cp/parser.c:6998
 #, gcc-internal-format
 msgid "ISO C++ forbids compound-literals"
 msgstr ""
 
-#: cp/parser.c:7054
+#: cp/parser.c:7057
 #, gcc-internal-format
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
@@ -45667,7 +45709,7 @@
 msgid "capture of non-variable %qE"
 msgstr "Μη αναγνωρίσιμη μεταβλητή `%s'"
 
-#: cp/parser.c:10391 cp/parser.c:10401 cp/semantics.c:3453 cp/semantics.c:3465
+#: cp/parser.c:10391 cp/parser.c:10401 cp/semantics.c:3456 cp/semantics.c:3468
 #, fuzzy, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
@@ -45752,7 +45794,7 @@
 msgid "init-statement in selection statements only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:11546 cp/parser.c:28490
+#: cp/parser.c:11546 cp/parser.c:28487
 #, fuzzy, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
@@ -45772,306 +45814,306 @@
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:12250 cp/parser.c:28493
+#: cp/parser.c:12250 cp/parser.c:28490
 #, fuzzy, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:12298
+#: cp/parser.c:12297
 #, gcc-internal-format
 msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/parser.c:12426
+#: cp/parser.c:12423
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr ""
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:12434
+#: cp/parser.c:12431
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr ""
 
-#: cp/parser.c:12447 cp/parser.c:28496
+#: cp/parser.c:12444 cp/parser.c:28493
 #, fuzzy, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:12620 cp/parser.c:23584
+#: cp/parser.c:12617 cp/parser.c:23581
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr ""
 
-#: cp/parser.c:12863
+#: cp/parser.c:12860
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr ""
 
-#: cp/parser.c:13083
+#: cp/parser.c:13080
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:13103
+#: cp/parser.c:13100
 #, fuzzy, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr "μη έγκυρος αριθμός αρχείου στη δήλωση πεδίου: `%s'"
 
-#: cp/parser.c:13124
+#: cp/parser.c:13121
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr ""
 
-#: cp/parser.c:13148
+#: cp/parser.c:13145
 #, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr ""
 
-#: cp/parser.c:13203
+#: cp/parser.c:13200
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13206
+#: cp/parser.c:13203
 #, fuzzy, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr "πολλαπλός αριθμός επιλογών την εντολή `s'"
 
-#: cp/parser.c:13257
+#: cp/parser.c:13254
 #, gcc-internal-format
 msgid "structured bindings only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:13306
+#: cp/parser.c:13303
 #, fuzzy, gcc-internal-format
 msgid "empty structured binding declaration"
 msgstr "κενό αλφαριθμητικό"
 
-#: cp/parser.c:13324
+#: cp/parser.c:13321
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for structured binding declaration"
 msgstr "Η αλυσίδα μορφής δεν είναι έγκυρη: `%s'"
 
-#: cp/parser.c:13491
+#: cp/parser.c:13488
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr ""
 
-#: cp/parser.c:13558
+#: cp/parser.c:13555
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr ""
 
-#: cp/parser.c:13594
+#: cp/parser.c:13591
 #, gcc-internal-format
 msgid "decl-specifier invalid in condition"
 msgstr ""
 
-#: cp/parser.c:13600
+#: cp/parser.c:13597
 #, fuzzy, gcc-internal-format
 msgid "%qD invalid in lambda"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/parser.c:13693
+#: cp/parser.c:13690
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr ""
 
-#: cp/parser.c:13763 cp/parser.c:24064
+#: cp/parser.c:13760 cp/parser.c:24061
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:13805
+#: cp/parser.c:13802
 #, fuzzy, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr "Μη έγκυρη ρύθμιση θύρας (port)"
 
-#: cp/parser.c:13909
+#: cp/parser.c:13906
 #, gcc-internal-format
 msgid "static_assert without a message only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:14111
+#: cp/parser.c:14108
 #, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr ""
 
-#: cp/parser.c:14264
+#: cp/parser.c:14261
 #, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr ""
 
-#: cp/parser.c:14291
+#: cp/parser.c:14288
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "μη έγκυρος αριθμός πεδίου: `%s'"
 
-#: cp/parser.c:14295
+#: cp/parser.c:14292
 #, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr ""
 
-#: cp/parser.c:14379
+#: cp/parser.c:14376
 #, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr ""
 
-#: cp/parser.c:14406
+#: cp/parser.c:14403
 #, fuzzy, gcc-internal-format
 msgid "cannot expand initializer for member %qD"
 msgstr "έχει παραληφθεί το αρχείο προορισμού"
 
-#: cp/parser.c:14418 cp/pt.c:24255
+#: cp/parser.c:14415 cp/pt.c:24333
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr ""
 
-#: cp/parser.c:14430 cp/pt.c:24267
+#: cp/parser.c:14427 cp/pt.c:24345
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
 
-#: cp/parser.c:14482
+#: cp/parser.c:14479
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr ""
 
-#: cp/parser.c:14552
+#: cp/parser.c:14549
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:14927
+#: cp/parser.c:14924
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr ""
 
-#: cp/parser.c:14933
+#: cp/parser.c:14930
 #, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr ""
 
-#: cp/parser.c:14942
+#: cp/parser.c:14939
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr ""
 
-#: cp/parser.c:14948
+#: cp/parser.c:14945
 #, fuzzy, gcc-internal-format
 msgid "invalid encoding prefix in literal operator"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/parser.c:14975
+#: cp/parser.c:14972
 #, fuzzy, gcc-internal-format
 msgid "expected operator"
 msgstr "Μη ορισμένο όνομα %s"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:15020
+#: cp/parser.c:15017
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr ""
 
-#: cp/parser.c:15190
+#: cp/parser.c:15187
 #, fuzzy, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr "Μη έγκυρος χαρακτήρας παραβολής"
 
-#: cp/parser.c:15198
+#: cp/parser.c:15195
 #, fuzzy, gcc-internal-format
 msgid "cv-qualified type parameter"
 msgstr "Μη έγκυρος χαρακτήρας παραβολής"
 
-#: cp/parser.c:15283
+#: cp/parser.c:15280
 #, gcc-internal-format
 msgid "variadic constraint introduced without %<...%>"
 msgstr ""
 
-#: cp/parser.c:15347
+#: cp/parser.c:15344
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/parser.c:15582 cp/parser.c:15668 cp/parser.c:21694
+#: cp/parser.c:15579 cp/parser.c:15665 cp/parser.c:21691
 #, fuzzy, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/parser.c:15586 cp/parser.c:15672
+#: cp/parser.c:15583 cp/parser.c:15669
 #, fuzzy, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/parser.c:15738
+#: cp/parser.c:15735
 #, fuzzy, gcc-internal-format
 msgid "expected template-id"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:15798
+#: cp/parser.c:15795
 #, fuzzy, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/parser.c:15802
+#: cp/parser.c:15799
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr ""
 
-#: cp/parser.c:15806
+#: cp/parser.c:15803
 #, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr ""
 
-#: cp/parser.c:15924
+#: cp/parser.c:15921
 #, fuzzy, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
 #. The name does not name a template.
-#: cp/parser.c:15992 cp/parser.c:16122 cp/parser.c:16337
+#: cp/parser.c:15989 cp/parser.c:16119 cp/parser.c:16334
 #, fuzzy, gcc-internal-format
 msgid "expected template-name"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
 #. Explain what went wrong.
-#: cp/parser.c:16038
+#: cp/parser.c:16035
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr ""
 
-#: cp/parser.c:16040
+#: cp/parser.c:16037
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr ""
 
-#: cp/parser.c:16189
+#: cp/parser.c:16186
 #, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr ""
 
-#: cp/parser.c:16298 cp/parser.c:16316 cp/parser.c:16483
+#: cp/parser.c:16295 cp/parser.c:16313 cp/parser.c:16480
 #, fuzzy, gcc-internal-format
 msgid "expected template-argument"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:16458
+#: cp/parser.c:16455
 #, fuzzy, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr "Μη έγκυρη παράμετρος"
 
-#: cp/parser.c:16585
+#: cp/parser.c:16582
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/parser.c:16589
+#: cp/parser.c:16586
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/parser.c:16648
+#: cp/parser.c:16645
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr ""
@@ -46078,253 +46120,253 @@
 
 # src/dfa.c:962
 # src/dfa.c:970
-#: cp/parser.c:16869
+#: cp/parser.c:16866
 #, fuzzy, gcc-internal-format
 msgid "expected type specifier"
 msgstr "Δεν ορίστηκε συντακτικό"
 
-#: cp/parser.c:17053
+#: cp/parser.c:17050
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:17059
+#: cp/parser.c:17056
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:17064
+#: cp/parser.c:17061
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -fconcepts"
 msgstr ""
 
-#: cp/parser.c:17209
+#: cp/parser.c:17206
 #, fuzzy, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: cp/parser.c:17278
+#: cp/parser.c:17275
 #, fuzzy, gcc-internal-format
 msgid "expected type-name"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:17631
+#: cp/parser.c:17628
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr ""
 
-#: cp/parser.c:17854
+#: cp/parser.c:17851
 #, fuzzy, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/parser.c:17942
+#: cp/parser.c:17939
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/parser.c:17946
+#: cp/parser.c:17943
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "αδυναμία ανάγνωσης κεφαλίδας από το `%s'"
 
-#: cp/parser.c:17951
+#: cp/parser.c:17948
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr ""
 
-#: cp/parser.c:18085
+#: cp/parser.c:18082
 #, fuzzy, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/parser.c:18096
+#: cp/parser.c:18093
 #, fuzzy, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/parser.c:18111
+#: cp/parser.c:18108
 #, fuzzy, gcc-internal-format
 msgid "unnamed scoped enum is not allowed"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/parser.c:18166
+#: cp/parser.c:18163
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr ""
 
-#: cp/parser.c:18215
+#: cp/parser.c:18212
 #, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr ""
 
-#: cp/parser.c:18229
+#: cp/parser.c:18226
 #, fuzzy, gcc-internal-format
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/parser.c:18241 cp/parser.c:23070
+#: cp/parser.c:18238 cp/parser.c:23067
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/parser.c:18246 cp/parser.c:23075
+#: cp/parser.c:18243 cp/parser.c:23072
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr ""
 
-#: cp/parser.c:18258 cp/parser.c:23089
+#: cp/parser.c:18255 cp/parser.c:23086
 #, fuzzy, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/parser.c:18282
+#: cp/parser.c:18279
 #, fuzzy, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/parser.c:18295
+#: cp/parser.c:18292
 #, gcc-internal-format
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr ""
 
-#: cp/parser.c:18315
+#: cp/parser.c:18312
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:18318
+#: cp/parser.c:18315
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:18497
+#: cp/parser.c:18494
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/parser.c:18503
+#: cp/parser.c:18500
 #, fuzzy, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:18570
+#: cp/parser.c:18567
 #, gcc-internal-format
 msgid "nested namespace definitions only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:18578
+#: cp/parser.c:18575
 #, gcc-internal-format
 msgid "nested namespace name required"
 msgstr ""
 
-#: cp/parser.c:18583
+#: cp/parser.c:18580
 #, gcc-internal-format
 msgid "namespace name required"
 msgstr ""
 
-#: cp/parser.c:18587
+#: cp/parser.c:18584
 #, gcc-internal-format
 msgid "a nested namespace definition cannot have attributes"
 msgstr ""
 
-#: cp/parser.c:18590
+#: cp/parser.c:18587
 #, gcc-internal-format
 msgid "a nested namespace definition cannot be inline"
 msgstr ""
 
-#: cp/parser.c:18597
+#: cp/parser.c:18594
 #, fuzzy, gcc-internal-format
 msgid "namespace %qD entered"
 msgstr "άγνωστο σετ `%s'"
 
-#: cp/parser.c:18652
+#: cp/parser.c:18649
 #, fuzzy, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/parser.c:18803
+#: cp/parser.c:18800
 #, gcc-internal-format
 msgid "pack expansion in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:18818
+#: cp/parser.c:18815
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr ""
 
-#: cp/parser.c:18865
+#: cp/parser.c:18862
 #, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:18875
+#: cp/parser.c:18872
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:18940
+#: cp/parser.c:18937
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "αδυναμία ανάγνωσης κεφαλίδας από το `%s'"
 
-#: cp/parser.c:19106
+#: cp/parser.c:19103
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:19493
+#: cp/parser.c:19490
 #, fuzzy, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "μη έγκυρος αριθμός αρχείου στη δήλωση πεδίου: `%s'"
 
-#: cp/parser.c:19504
+#: cp/parser.c:19501
 #, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr ""
 
-#: cp/parser.c:19508
+#: cp/parser.c:19505
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr ""
 
-#: cp/parser.c:19559
+#: cp/parser.c:19556
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
 #. Anything else is an error.
-#: cp/parser.c:19598 cp/parser.c:21906
+#: cp/parser.c:19595 cp/parser.c:21903
 #, fuzzy, gcc-internal-format
 msgid "expected initializer"
 msgstr "μη έγκυρο μέγεθος οριζόντιου στηλοθέτη: %s"
 
-#: cp/parser.c:19679
+#: cp/parser.c:19676
 #, fuzzy, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "Δεν ήταν δυνατή η εύρεση ετικέττας για μεταγωγή στο `%s'"
 
-#: cp/parser.c:19713
+#: cp/parser.c:19710
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr ""
 
-#: cp/parser.c:19727
+#: cp/parser.c:19724
 #, fuzzy, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/parser.c:20169
+#: cp/parser.c:20166
 #, fuzzy, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: cp/parser.c:20295
+#: cp/parser.c:20292
 #, fuzzy, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/parser.c:20299
+#: cp/parser.c:20296
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
@@ -46333,17 +46375,17 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:20328
+#: cp/parser.c:20325
 #, fuzzy, gcc-internal-format
 msgid "invalid declarator"
 msgstr "μη έγκυρος χρήστης"
 
-#: cp/parser.c:20336
+#: cp/parser.c:20333
 #, fuzzy, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "μη έγκυρος αριθμός από γραμμές"
 
-#: cp/parser.c:20338
+#: cp/parser.c:20335
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr ""
@@ -46350,382 +46392,382 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:20410
+#: cp/parser.c:20407
 #, fuzzy, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr "Μη έγκυρη ανταλλαγή"
 
-#: cp/parser.c:20435
+#: cp/parser.c:20432
 #, fuzzy, gcc-internal-format
 msgid "expected declarator"
 msgstr "κενό αλφαριθμητικό"
 
-#: cp/parser.c:20554
+#: cp/parser.c:20551
 #, fuzzy, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/parser.c:20556
+#: cp/parser.c:20553
 #, fuzzy, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/parser.c:20577
+#: cp/parser.c:20574
 #, fuzzy, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:20638
+#: cp/parser.c:20635
 #, fuzzy, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "διπλός αριθμός μηνύματος"
 
-#: cp/parser.c:20692
+#: cp/parser.c:20689
 #, fuzzy, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr "διπλός αριθμός μηνύματος"
 
-#: cp/parser.c:20729
+#: cp/parser.c:20726
 #, gcc-internal-format
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr ""
 
-#: cp/parser.c:20787
+#: cp/parser.c:20784
 #, fuzzy, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "διπλός αριθμός μηνύματος"
 
-#: cp/parser.c:21025
+#: cp/parser.c:21022
 #, fuzzy, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr "Ελλιπής ή κακοσχηματισμένη ιδιότητα"
 
-#: cp/parser.c:21031 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2090
+#: cp/parser.c:21028 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2093
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr "μη έγκυρος χρήστης"
 
-#: cp/parser.c:21052
+#: cp/parser.c:21049
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/parser.c:21057
+#: cp/parser.c:21054
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/parser.c:21145
+#: cp/parser.c:21142
 #, fuzzy, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:21429
+#: cp/parser.c:21426
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr ""
 
-#: cp/parser.c:21504
+#: cp/parser.c:21501
 #, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr ""
 
-#: cp/parser.c:21678
+#: cp/parser.c:21675
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr ""
 
-#: cp/parser.c:21696
+#: cp/parser.c:21693
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/parser.c:21702
+#: cp/parser.c:21699
 #, fuzzy, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/parser.c:21704
+#: cp/parser.c:21701
 #, fuzzy, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/parser.c:22131
+#: cp/parser.c:22128
 #, gcc-internal-format
 msgid "C++ designated initializers only available with -std=c++2a or -std=gnu++2a"
 msgstr ""
 
-#: cp/parser.c:22151
+#: cp/parser.c:22148
 #, gcc-internal-format
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr ""
 
-#: cp/parser.c:22189
+#: cp/parser.c:22186
 #, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr ""
 
-#: cp/parser.c:22203
+#: cp/parser.c:22200
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr ""
 
-#: cp/parser.c:22228
+#: cp/parser.c:22225
 #, gcc-internal-format
 msgid "%<...%> not allowed in designated initializer list"
 msgstr ""
 
-#: cp/parser.c:22266
+#: cp/parser.c:22263
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr ""
 
-#: cp/parser.c:22322 cp/parser.c:22448
+#: cp/parser.c:22319 cp/parser.c:22445
 #, fuzzy, gcc-internal-format
 msgid "expected class-name"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:22650
+#: cp/parser.c:22647
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "%s: διπλός ορισμός έκδοσης κατηγορίας"
 
-#: cp/parser.c:22653
+#: cp/parser.c:22650
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "%s: διπλός ορισμός έκδοσης κατηγορίας"
 
-#: cp/parser.c:22656
+#: cp/parser.c:22653
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "%s: διπλός ορισμός έκδοσης κατηγορίας"
 
-#: cp/parser.c:23012
+#: cp/parser.c:23009
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr ""
 
-#: cp/parser.c:23023
+#: cp/parser.c:23020
 #, fuzzy, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "δε βρέθηκε ο προεπεξεργαστής C: %s \n"
 
-#: cp/parser.c:23031
+#: cp/parser.c:23028
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:23038
+#: cp/parser.c:23035
 #, fuzzy, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/parser.c:23050
+#: cp/parser.c:23047
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr ""
 
-#: cp/parser.c:23056
+#: cp/parser.c:23053
 #, fuzzy, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/parser.c:23114
+#: cp/parser.c:23111
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr ""
 
-#: cp/parser.c:23146
+#: cp/parser.c:23143
 #, fuzzy, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/parser.c:23182
+#: cp/parser.c:23179
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr ""
 
-#: cp/parser.c:23241
+#: cp/parser.c:23238
 #, fuzzy, gcc-internal-format
 msgid "previous definition of %q#T"
 msgstr "κανένας ορισμός του `UNDEFINED'"
 
-#: cp/parser.c:23331 cp/parser.c:28499
+#: cp/parser.c:23328 cp/parser.c:28496
 #, fuzzy, gcc-internal-format
 msgid "expected class-key"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:23355
+#: cp/parser.c:23352
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:23359
+#: cp/parser.c:23356
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:23605
+#: cp/parser.c:23602
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr ""
 
-#: cp/parser.c:23623
+#: cp/parser.c:23620
 #, fuzzy, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/parser.c:23641
+#: cp/parser.c:23638
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:23738
+#: cp/parser.c:23735
 #, gcc-internal-format
 msgid "default member initializers for bit-fields only available with -std=c++2a or -std=gnu++2a"
 msgstr ""
 
-#: cp/parser.c:23745
+#: cp/parser.c:23742
 #, gcc-internal-format
 msgid "default member initializer for unnamed bit-field"
 msgstr ""
 
-#: cp/parser.c:23758
+#: cp/parser.c:23755
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr ""
 
-#: cp/parser.c:23903
+#: cp/parser.c:23900
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr ""
 
-#: cp/parser.c:23923
+#: cp/parser.c:23920
 #, gcc-internal-format
 msgid "extra %<;%> after in-class function definition"
 msgstr ""
 
-#: cp/parser.c:23970
+#: cp/parser.c:23967
 #, fuzzy, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr "αδυναμία εισαγωγής στοιχείο παραβολής `%.*s'"
 
-#: cp/parser.c:23984
+#: cp/parser.c:23981
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "αδυναμία εισαγωγής στοιχείο παραβολής `%.*s'"
 
-#: cp/parser.c:24058
+#: cp/parser.c:24055
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr ""
 
-#: cp/parser.c:24093
+#: cp/parser.c:24090
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr ""
 
-#: cp/parser.c:24223
+#: cp/parser.c:24220
 #, gcc-internal-format
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr ""
 
-#: cp/parser.c:24243
+#: cp/parser.c:24240
 #, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr ""
 
-#: cp/parser.c:24267
+#: cp/parser.c:24264
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr ""
 
-#: cp/parser.c:24270
+#: cp/parser.c:24267
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:24364 cp/parser.c:24442
+#: cp/parser.c:24361 cp/parser.c:24439
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "συντακτικό σφάλμα στον καθορισμό σειράς"
 
-#: cp/parser.c:24450
+#: cp/parser.c:24447
 #, fuzzy, gcc-internal-format
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "συντακτικό σφάλμα στον καθορισμό σειράς"
 
-#: cp/parser.c:24456
+#: cp/parser.c:24453
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr ""
 
-#: cp/parser.c:24500
+#: cp/parser.c:24497
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "μη έγκυρος αριθμός πεδίου: `%s'"
 
-#: cp/parser.c:24539
+#: cp/parser.c:24536
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:24650
+#: cp/parser.c:24647
 #, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr ""
 
-#: cp/parser.c:25203
+#: cp/parser.c:25200
 #, gcc-internal-format
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr ""
 
-#: cp/parser.c:25217
+#: cp/parser.c:25214
 #, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr ""
 
-#: cp/parser.c:25301
+#: cp/parser.c:25298
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:25305
+#: cp/parser.c:25302
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:25342
+#: cp/parser.c:25339
 #, fuzzy, gcc-internal-format
 msgid "expected attribute before %<...%>"
 msgstr "Κακή αίτηση παραμέτρων"
 
-#: cp/parser.c:25403
+#: cp/parser.c:25400
 #, gcc-internal-format
 msgid "attribute using prefix only available with -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:25721
+#: cp/parser.c:25718
 #, gcc-internal-format
 msgid "%<requires%> only available with -fconcepts"
 msgstr ""
 
-#: cp/parser.c:25753
+#: cp/parser.c:25750
 #, gcc-internal-format
 msgid "a requires expression cannot appear outside a template"
 msgstr ""
 
-#: cp/parser.c:26467
+#: cp/parser.c:26464
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:26472
+#: cp/parser.c:26469
 #, fuzzy, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/parser.c:26476
+#: cp/parser.c:26473
 #, fuzzy, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
@@ -46734,262 +46776,262 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:26483
+#: cp/parser.c:26480
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr ""
 
-#: cp/parser.c:26832
+#: cp/parser.c:26829
 #, fuzzy, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: cp/parser.c:26991
+#: cp/parser.c:26988
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr ""
 
-#: cp/parser.c:26996
+#: cp/parser.c:26993
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr ""
 
-#: cp/parser.c:27066
+#: cp/parser.c:27063
 #, fuzzy, gcc-internal-format
 msgid "empty introduction-list"
 msgstr "κενό αλφαριθμητικό"
 
-#: cp/parser.c:27090
+#: cp/parser.c:27087
 #, fuzzy, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr "Ο έλεγχος μονοπατιού για το `%s' βρήκε `%s'"
 
-#: cp/parser.c:27112
+#: cp/parser.c:27109
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr ""
 
-#: cp/parser.c:27121
+#: cp/parser.c:27118
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr ""
 
-#: cp/parser.c:27141
+#: cp/parser.c:27138
 #, fuzzy, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "Μη έγκυρη ρύθμιση θύρας (port)"
 
-#: cp/parser.c:27245
+#: cp/parser.c:27242
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/parser.c:27296
+#: cp/parser.c:27293
 #, gcc-internal-format
 msgid "a class template declaration must not declare anything else"
 msgstr ""
 
-#: cp/parser.c:27342
+#: cp/parser.c:27339
 #, fuzzy, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/parser.c:27650
+#: cp/parser.c:27647
 #, fuzzy, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/parser.c:27663
+#: cp/parser.c:27660
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr ""
 
-#: cp/parser.c:27958
+#: cp/parser.c:27955
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:28118
+#: cp/parser.c:28115
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "Μη έγκυρη ρύθμιση θύρας (port)"
 
-#: cp/parser.c:28133
+#: cp/parser.c:28130
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr ""
 
-#: cp/parser.c:28267
+#: cp/parser.c:28264
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: cp/parser.c:28275
+#: cp/parser.c:28272
 #, fuzzy, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "μη έγκυρος δηλωτής πεδίου: `%s'"
 
-#: cp/parser.c:28280
+#: cp/parser.c:28277
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "διπλό κλειδί"
 
-#: cp/parser.c:28304
+#: cp/parser.c:28301
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "διπλό κλειδί"
 
-#: cp/parser.c:28356
+#: cp/parser.c:28353
 #, fuzzy, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:28359
+#: cp/parser.c:28356
 #, fuzzy, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:28362
+#: cp/parser.c:28359
 #, fuzzy, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:28368
+#: cp/parser.c:28365
 #, fuzzy, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:28371
+#: cp/parser.c:28368
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr ""
 
-#: cp/parser.c:28374
+#: cp/parser.c:28371
 #, fuzzy, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:28377
+#: cp/parser.c:28374
 #, fuzzy, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:28380
+#: cp/parser.c:28377
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr ""
 
-#: cp/parser.c:28383
+#: cp/parser.c:28380
 #, fuzzy, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:28386
+#: cp/parser.c:28383
 #, fuzzy, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:28389
+#: cp/parser.c:28386
 #, fuzzy, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:28392
+#: cp/parser.c:28389
 #, fuzzy, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:28395
+#: cp/parser.c:28392
 #, fuzzy, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:28398
+#: cp/parser.c:28395
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr ""
 
-#: cp/parser.c:28401
+#: cp/parser.c:28398
 #, fuzzy, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:28404
+#: cp/parser.c:28401
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr ""
 
-#: cp/parser.c:28407
+#: cp/parser.c:28404
 #, fuzzy, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:28410
+#: cp/parser.c:28407
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr ""
 
-#: cp/parser.c:28413
+#: cp/parser.c:28410
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr ""
 
-#: cp/parser.c:28416
+#: cp/parser.c:28413
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.c:28419
+#: cp/parser.c:28416
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr ""
 
-#: cp/parser.c:28451
+#: cp/parser.c:28448
 #, fuzzy, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:28463
+#: cp/parser.c:28460
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr ""
 
-#: cp/parser.c:28466
+#: cp/parser.c:28463
 #, fuzzy, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:28469
+#: cp/parser.c:28466
 #, fuzzy, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:28475
+#: cp/parser.c:28472
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr ""
 
-#: cp/parser.c:28502
+#: cp/parser.c:28499
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr ""
 
-#: cp/parser.c:28772
+#: cp/parser.c:28769
 #, fuzzy, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/parser.c:28777
+#: cp/parser.c:28774
 #, fuzzy, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/parser.c:28798
+#: cp/parser.c:28795
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr ""
 
-#: cp/parser.c:28819
+#: cp/parser.c:28816
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr ""
@@ -46996,193 +47038,193 @@
 
 # src/grep.c:785 src/grep.c:792
 # src/grep.c:1060 src/grep.c:1067 src/grep.c:1076
-#: cp/parser.c:29062
+#: cp/parser.c:29059
 #, fuzzy, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "μη έγκυρο όρισμα μήκους περιεχομένου"
 
-#: cp/parser.c:29303 cp/parser.c:30620 cp/parser.c:30808
+#: cp/parser.c:29300 cp/parser.c:30617 cp/parser.c:30805
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr ""
 
-#: cp/parser.c:29372
+#: cp/parser.c:29369
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr ""
 
-#: cp/parser.c:29442
+#: cp/parser.c:29439
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:29473
+#: cp/parser.c:29470
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr ""
 
-#: cp/parser.c:29883
+#: cp/parser.c:29880
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr ""
 
-#: cp/parser.c:29958 cp/parser.c:29976
+#: cp/parser.c:29955 cp/parser.c:29973
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr ""
 
-#: cp/parser.c:29970 cp/parser.c:30035
+#: cp/parser.c:29967 cp/parser.c:30032
 #, fuzzy, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: cp/parser.c:30078
+#: cp/parser.c:30075
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:30284 cp/parser.c:30291 cp/parser.c:30298
+#: cp/parser.c:30281 cp/parser.c:30288 cp/parser.c:30295
 #, fuzzy, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "Ακατάλληλη τιμή στο ai_flags"
 
-#: cp/parser.c:30413
+#: cp/parser.c:30410
 #, fuzzy, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "Προσδιοριστής αφαιρέθηκε"
 
-#: cp/parser.c:30585
+#: cp/parser.c:30582
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:30592
+#: cp/parser.c:30589
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/parser.c:30867 cp/parser.c:30874 cp/parser.c:30881
+#: cp/parser.c:30864 cp/parser.c:30871 cp/parser.c:30878
 #, fuzzy, gcc-internal-format
 msgid "invalid type for property"
 msgstr "Μη έγκυρη παράμετρος"
 
-#: cp/parser.c:32011
+#: cp/parser.c:32008
 #, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr ""
 
-#: cp/parser.c:32724
+#: cp/parser.c:32721
 #, fuzzy, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr "μη έγκυρο μέγεθος οριζόντιου στηλοθέτη: %s"
 
-#: cp/parser.c:34911
+#: cp/parser.c:34908
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:35231 cp/pt.c:16392
+#: cp/parser.c:35228 cp/pt.c:16414
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr ""
 
-#: cp/parser.c:35316
+#: cp/parser.c:35313
 #, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr ""
 
-#: cp/parser.c:37521
+#: cp/parser.c:37518
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr "μη έγκυρο μέγεθος οριζόντιου στηλοθέτη: %s"
 
-#: cp/parser.c:37549
+#: cp/parser.c:37546
 #, fuzzy, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "Μη έγκυρη προπορευόμενη κανονική έκφραση"
 
-#: cp/parser.c:37561
+#: cp/parser.c:37558
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:37662
+#: cp/parser.c:37659
 #, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr ""
 
-#: cp/parser.c:37682 cp/semantics.c:5405
+#: cp/parser.c:37679 cp/semantics.c:5408
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37687 cp/semantics.c:5414
+#: cp/parser.c:37684 cp/semantics.c:5417
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37690 cp/pt.c:12944 cp/semantics.c:5420
+#: cp/parser.c:37687 cp/pt.c:12966 cp/semantics.c:5423
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37693 cp/semantics.c:5426
+#: cp/parser.c:37690 cp/semantics.c:5429
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:38047
+#: cp/parser.c:38044
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:38057
+#: cp/parser.c:38054
 #, fuzzy, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:38392
+#: cp/parser.c:38389
 #, gcc-internal-format
 msgid "atomic_cancel"
 msgstr ""
 
-#: cp/parser.c:38435 cp/semantics.c:8575
+#: cp/parser.c:38432 cp/semantics.c:8578
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:38437 cp/semantics.c:8577
+#: cp/parser.c:38434 cp/semantics.c:8580
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:38631
+#: cp/parser.c:38628
 #, fuzzy, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "μη τερματιζόμενo αλφαριθμητικό"
 
-#: cp/parser.c:38927
+#: cp/parser.c:38924
 #, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr ""
 
-#: cp/parser.c:38959
+#: cp/parser.c:38956
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr ""
 
-#: cp/parser.c:39039
+#: cp/parser.c:39036
 #, fuzzy, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/parser.c:39295
+#: cp/parser.c:39292
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:39351
+#: cp/parser.c:39348
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
@@ -47270,7 +47312,7 @@
 msgstr ""
 
 # src/request.c:37
-#: cp/pt.c:1954 cp/semantics.c:5274
+#: cp/pt.c:1954 cp/semantics.c:5277
 #, fuzzy, gcc-internal-format
 msgid "%s %#qD"
 msgstr "%s: %s"
@@ -47436,107 +47478,107 @@
 msgid "argument to __integer_pack must be between 0 and %d"
 msgstr ""
 
-#: cp/pt.c:3942
+#: cp/pt.c:3955
 #, gcc-internal-format
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr ""
 
-#: cp/pt.c:4010
+#: cp/pt.c:4023
 #, gcc-internal-format
 msgid "expansion pattern %qT contains no argument packs"
 msgstr ""
 
-#: cp/pt.c:4012
+#: cp/pt.c:4025
 #, gcc-internal-format
 msgid "expansion pattern %qE contains no argument packs"
 msgstr ""
 
-#: cp/pt.c:4063
+#: cp/pt.c:4077
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr ""
 
-#: cp/pt.c:4080 cp/pt.c:4835
+#: cp/pt.c:4094 cp/pt.c:4849
 #, fuzzy, gcc-internal-format
 msgid "        %qD"
 msgstr "        `%D'"
 
-#: cp/pt.c:4082
+#: cp/pt.c:4096
 #, fuzzy, gcc-internal-format
 msgid "        <anonymous>"
 msgstr "((ανώνυμο))"
 
-#: cp/pt.c:4208
+#: cp/pt.c:4222
 #, fuzzy, gcc-internal-format
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/pt.c:4211
+#: cp/pt.c:4225
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q+#D shadows template parameter"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/pt.c:4213
+#: cp/pt.c:4227
 #, fuzzy, gcc-internal-format
 msgid "template parameter %qD declared here"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/pt.c:4771
+#: cp/pt.c:4785
 #, fuzzy, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/pt.c:4830
+#: cp/pt.c:4844
 #, fuzzy, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/pt.c:4854
+#: cp/pt.c:4868
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:4858
+#: cp/pt.c:4872
 #, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr ""
 
-#: cp/pt.c:4862 cp/pt.c:4873
+#: cp/pt.c:4876 cp/pt.c:4887
 #, gcc-internal-format
 msgid "primary template here"
 msgstr ""
 
-#: cp/pt.c:4870
+#: cp/pt.c:4884
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:4885
+#: cp/pt.c:4899
 #, gcc-internal-format
 msgid "partial specialization %qD is not more specialized than"
 msgstr ""
 
-#: cp/pt.c:4887
+#: cp/pt.c:4901
 #, fuzzy, gcc-internal-format
 msgid "primary template %qD"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/pt.c:4934
+#: cp/pt.c:4948
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:4937
+#: cp/pt.c:4951
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr ""
 
-#: cp/pt.c:4958
+#: cp/pt.c:4972
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr ""
 
-#: cp/pt.c:5004
+#: cp/pt.c:5018
 #, fuzzy, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
@@ -47543,17 +47585,17 @@
 msgstr[0] "%s' δεν είναι ισχύων θετικός ακέραιος."
 msgstr[1] "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:5066
+#: cp/pt.c:5080
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "διπλός ορισμός συνόλου"
 
-#: cp/pt.c:5070
+#: cp/pt.c:5084
 #, fuzzy, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/pt.c:5247
+#: cp/pt.c:5261
 #, fuzzy, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
@@ -47561,47 +47603,47 @@
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5269
+#: cp/pt.c:5283
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/pt.c:5305
+#: cp/pt.c:5319
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr ""
 
-#: cp/pt.c:5308
+#: cp/pt.c:5322
 #, gcc-internal-format
 msgid "default template arguments may not be used in template friend declarations"
 msgstr ""
 
-#: cp/pt.c:5311
+#: cp/pt.c:5325
 #, gcc-internal-format
 msgid "default template arguments may not be used in function templates without -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/pt.c:5314
+#: cp/pt.c:5328
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr ""
 
-#: cp/pt.c:5317 cp/pt.c:5375
+#: cp/pt.c:5331 cp/pt.c:5389
 #, fuzzy, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: cp/pt.c:5489
+#: cp/pt.c:5503
 #, fuzzy, gcc-internal-format
 msgid "template %qD declared"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: cp/pt.c:5496
+#: cp/pt.c:5510
 #, fuzzy, gcc-internal-format
 msgid "template class without a name"
 msgstr "μη τερματιζόμενο όνομα βάρους"
 
-#: cp/pt.c:5504
+#: cp/pt.c:5518
 #, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr ""
@@ -47611,57 +47653,57 @@
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5526
+#: cp/pt.c:5540
 #, fuzzy, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/pt.c:5669
+#: cp/pt.c:5683
 #, fuzzy, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/pt.c:5712
+#: cp/pt.c:5726
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr ""
 
-#: cp/pt.c:5726
+#: cp/pt.c:5740
 #, fuzzy, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/pt.c:5729
+#: cp/pt.c:5743
 #, fuzzy, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/pt.c:5731
+#: cp/pt.c:5745
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "  αλλά %d απαιτούνται"
 
-#: cp/pt.c:5752
+#: cp/pt.c:5766
 #, fuzzy, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/pt.c:5755
+#: cp/pt.c:5769
 #, gcc-internal-format
 msgid "use %<template<>%> for an explicit specialization"
 msgstr ""
 
-#: cp/pt.c:5882
+#: cp/pt.c:5896
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/pt.c:5895
+#: cp/pt.c:5909
 #, fuzzy, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "Προειδοποίηση: Πολύ λίγα ορίσματα στο εσωδομημένο `%s'"
 
-#: cp/pt.c:5906
+#: cp/pt.c:5920
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
@@ -47668,7 +47710,7 @@
 msgstr[0] "διπλό όνομα χαρακτήρα `%s'"
 msgstr[1] "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/pt.c:5910
+#: cp/pt.c:5924
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD used %d template parameter"
 msgid_plural "previous declaration %qD used %d template parameters"
@@ -47675,12 +47717,12 @@
 msgstr[0] "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 msgstr[1] "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/pt.c:5947
+#: cp/pt.c:5961
 #, fuzzy, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/pt.c:5948
+#: cp/pt.c:5962
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr ""
@@ -47689,117 +47731,117 @@
 #.
 #. A template-parameter may not be given default arguments
 #. by two different declarations in the same scope.
-#: cp/pt.c:5958
+#: cp/pt.c:5972
 #, fuzzy, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: cp/pt.c:5960
+#: cp/pt.c:5974
 #, fuzzy, gcc-internal-format
 msgid "original definition appeared here"
 msgstr "κανένας ορισμός του `UNDEFINED'"
 
-#: cp/pt.c:5988
+#: cp/pt.c:6002
 #, fuzzy, gcc-internal-format
 msgid "redeclaration %q#D with different constraints"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/pt.c:5991
+#: cp/pt.c:6005
 #, fuzzy, gcc-internal-format
 msgid "original declaration appeared here"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/pt.c:6250 cp/pt.c:6318
+#: cp/pt.c:6264 cp/pt.c:6332
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:6253
+#: cp/pt.c:6267
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6256
+#: cp/pt.c:6270
 #, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr ""
 
-#: cp/pt.c:6268
+#: cp/pt.c:6282
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:6272
+#: cp/pt.c:6286
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:6321
+#: cp/pt.c:6335
 #, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr ""
 
-#: cp/pt.c:6323
+#: cp/pt.c:6337
 #, fuzzy, gcc-internal-format
 msgid "because it is a member of %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.c:6383
+#: cp/pt.c:6397
 #, fuzzy, gcc-internal-format
 msgid "  couldn't deduce template parameter %qD"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/pt.c:6392
+#: cp/pt.c:6406
 #, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr ""
 
-#: cp/pt.c:6401
+#: cp/pt.c:6415
 #, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:6410
+#: cp/pt.c:6424
 #, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr ""
 
-#: cp/pt.c:6421
+#: cp/pt.c:6435
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/pt.c:6431
+#: cp/pt.c:6445
 #, fuzzy, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/pt.c:6440
+#: cp/pt.c:6454
 #, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr ""
 
-#: cp/pt.c:6452
+#: cp/pt.c:6466
 #, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr ""
 
-#: cp/pt.c:6456
+#: cp/pt.c:6470
 #, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr ""
 
-#: cp/pt.c:6467
+#: cp/pt.c:6481
 #, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6478
+#: cp/pt.c:6492
 #, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6490
+#: cp/pt.c:6504
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
@@ -47806,292 +47848,292 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/pt.c:6521
+#: cp/pt.c:6535
 #, fuzzy, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/pt.c:6534
+#: cp/pt.c:6548
 #, fuzzy, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/pt.c:6538
+#: cp/pt.c:6552
 #, fuzzy, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.c:6549
+#: cp/pt.c:6563
 #, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr ""
 
-#: cp/pt.c:6559
+#: cp/pt.c:6573
 #, fuzzy, gcc-internal-format
 msgid "  can't deduce a template for %qT from non-template type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/pt.c:6569
+#: cp/pt.c:6583
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/pt.c:6609
+#: cp/pt.c:6623
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr ""
 
-#: cp/pt.c:6758
+#: cp/pt.c:6772
 #, fuzzy, gcc-internal-format
 msgid "in template argument for type %qT"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: cp/pt.c:6772
+#: cp/pt.c:6786
 #, fuzzy, gcc-internal-format
 msgid "template argument %qE for type %qT not a constant integer"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:6833
+#: cp/pt.c:6847
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:6841
+#: cp/pt.c:6855
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:6857
+#: cp/pt.c:6871
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:6864
+#: cp/pt.c:6878
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:6873
+#: cp/pt.c:6887
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:6888
+#: cp/pt.c:6902
 #, gcc-internal-format
 msgid "the address of %qD is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6897
+#: cp/pt.c:6911
 #, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr ""
 
-#: cp/pt.c:6904
+#: cp/pt.c:6918
 #, fuzzy, gcc-internal-format
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:6933
+#: cp/pt.c:6947
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr ""
 
-#: cp/pt.c:6941
+#: cp/pt.c:6955
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:6959
+#: cp/pt.c:6973
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:6975
+#: cp/pt.c:6989
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an object with linkage"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:6986
+#: cp/pt.c:7000
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because object %qD does not have linkage"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:7036
+#: cp/pt.c:7050
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:7038
+#: cp/pt.c:7052
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr ""
 
-#: cp/pt.c:7092
+#: cp/pt.c:7106
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:7654
+#: cp/pt.c:7668
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/pt.c:7670
+#: cp/pt.c:7684
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/pt.c:7805
+#: cp/pt.c:7819
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr ""
 
-#: cp/pt.c:7834
+#: cp/pt.c:7848
 #, fuzzy, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "μη έγκυρος αριθμός από γραμμές"
 
-#: cp/pt.c:7839
+#: cp/pt.c:7853
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr ""
 
-#: cp/pt.c:7855 cp/pt.c:7877 cp/pt.c:7931
+#: cp/pt.c:7869 cp/pt.c:7891 cp/pt.c:7945
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.c:7860
+#: cp/pt.c:7874
 #, fuzzy, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: cp/pt.c:7865
+#: cp/pt.c:7879
 #, fuzzy, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: cp/pt.c:7868
+#: cp/pt.c:7882
 #, fuzzy, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: cp/pt.c:7882
+#: cp/pt.c:7896
 #, fuzzy, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: cp/pt.c:7885
+#: cp/pt.c:7899
 #, fuzzy, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: cp/pt.c:7935
+#: cp/pt.c:7949
 #, fuzzy, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: cp/pt.c:7949
+#: cp/pt.c:7963
 #, fuzzy, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/pt.c:7952
+#: cp/pt.c:7966
 #, fuzzy, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: cp/pt.c:8012
+#: cp/pt.c:8026
 #, fuzzy, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/pt.c:8149 cp/pt.c:8465
+#: cp/pt.c:8163 cp/pt.c:8479
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "έχουν παραληφθεί ορίσματα"
 
-#: cp/pt.c:8164 cp/pt.c:8298
+#: cp/pt.c:8178 cp/pt.c:8312
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "λάθος αριθμός ορισμάτων"
 
-#: cp/pt.c:8294
+#: cp/pt.c:8308
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "λάθος αριθμός ορισμάτων"
 
-#: cp/pt.c:8303
+#: cp/pt.c:8317
 #, gcc-internal-format
 msgid "provided for %qD"
 msgstr ""
 
-#: cp/pt.c:8328
+#: cp/pt.c:8342
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:8332
+#: cp/pt.c:8346
 #, fuzzy, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: cp/pt.c:8431
+#: cp/pt.c:8445
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:9054
+#: cp/pt.c:9068
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/pt.c:9221
+#: cp/pt.c:9235
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr ""
 
-#: cp/pt.c:9223
+#: cp/pt.c:9237
 #, fuzzy, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/pt.c:9346
+#: cp/pt.c:9360
 #, fuzzy, gcc-internal-format
 msgid "template constraint failure"
 msgstr "εσωτερικό σφάλμα gcc"
 
-#: cp/pt.c:9697
+#: cp/pt.c:9718
 #, fuzzy, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr "Μη έγκυρη προτεραιότητα `%s'"
 
-#: cp/pt.c:10125
+#: cp/pt.c:10148
 #, gcc-internal-format, gfc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:11202
+#: cp/pt.c:11225
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD in union"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: cp/pt.c:11691
+#: cp/pt.c:11713
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:12160
+#: cp/pt.c:12182
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr ""
 
-#: cp/pt.c:12163
+#: cp/pt.c:12185
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr ""
 
-#: cp/pt.c:12747
+#: cp/pt.c:12769
 #, fuzzy, gcc-internal-format
 msgid "  when instantiating default argument for call to %qD"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
@@ -48109,278 +48151,278 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:13708
+#: cp/pt.c:13730
 #, fuzzy, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/pt.c:13881
+#: cp/pt.c:13903
 #, fuzzy, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "Μη έγκυρη προτεραιότητα `%s'"
 
-#: cp/pt.c:13883
+#: cp/pt.c:13905
 #, fuzzy, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/pt.c:14001
+#: cp/pt.c:14023
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr ""
 
-#: cp/pt.c:14003
+#: cp/pt.c:14025
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr ""
 
-#: cp/pt.c:14043
+#: cp/pt.c:14065
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.c:14637
+#: cp/pt.c:14659
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr ""
 
-#: cp/pt.c:14639
+#: cp/pt.c:14661
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.c:14641
+#: cp/pt.c:14663
 #, fuzzy, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.c:14654
+#: cp/pt.c:14676
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.c:14657
+#: cp/pt.c:14679
 #, fuzzy, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.c:14705
+#: cp/pt.c:14727
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.c:14711
+#: cp/pt.c:14733
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.c:14717
+#: cp/pt.c:14739
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.c:14783
+#: cp/pt.c:14805
 #, fuzzy, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/pt.c:14816
+#: cp/pt.c:14838
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/pt.c:14853
+#: cp/pt.c:14875
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr ""
 
-#: cp/pt.c:14861
+#: cp/pt.c:14883
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr ""
 
-#: cp/pt.c:14925
+#: cp/pt.c:14947
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.c:15000
+#: cp/pt.c:15022
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr ""
 
-#: cp/pt.c:15178
+#: cp/pt.c:15200
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/pt.c:15193
+#: cp/pt.c:15215
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr ""
 
-#: cp/pt.c:15195
+#: cp/pt.c:15217
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr ""
 
-#: cp/pt.c:15394
+#: cp/pt.c:15416
 #, fuzzy, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "έχει παραληφθεί η λίστα με τα πεδία"
 
-#: cp/pt.c:15883 cp/pt.c:17386
+#: cp/pt.c:15905 cp/pt.c:17408
 #, fuzzy, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
-#: cp/pt.c:15887 cp/pt.c:17390
+#: cp/pt.c:15909 cp/pt.c:17412
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr ""
 
-#: cp/pt.c:18334
+#: cp/pt.c:18371
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:18362
+#: cp/pt.c:18399
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:18367
+#: cp/pt.c:18404
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.c:18370
+#: cp/pt.c:18407
 #, fuzzy, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/pt.c:18375
+#: cp/pt.c:18412
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "Το επώνυμο αντικείμενο δεν είναι αναζητήσιμο"
 
-#: cp/pt.c:18712
+#: cp/pt.c:18752
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/pt.c:18715
+#: cp/pt.c:18755
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/pt.c:19026
+#: cp/pt.c:19066
 #, fuzzy, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/pt.c:19028
+#: cp/pt.c:19068
 #, fuzzy, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: cp/pt.c:19038
+#: cp/pt.c:19078
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr ""
 
-#: cp/pt.c:19053
+#: cp/pt.c:19093
 #, fuzzy, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/pt.c:19071
+#: cp/pt.c:19111
 #, fuzzy, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/pt.c:22972
+#: cp/pt.c:23050
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "διπλός ορισμός συνόλου"
 
-#: cp/pt.c:22974
+#: cp/pt.c:23052
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "διπλός ορισμός συνόλου"
 
 # src/request.c:37
-#: cp/pt.c:22980
+#: cp/pt.c:23058
 #, fuzzy
 msgid "%s %#qS"
 msgstr "%s: %s"
 
-#: cp/pt.c:23004 cp/pt.c:23091
+#: cp/pt.c:23082 cp/pt.c:23169
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/pt.c:23023
+#: cp/pt.c:23101
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/pt.c:23029 cp/pt.c:23086
+#: cp/pt.c:23107 cp/pt.c:23164
 #, fuzzy, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "Ο έλεγχος μονοπατιού για το `%s' βρήκε `%s'"
 
-#: cp/pt.c:23034
+#: cp/pt.c:23112
 #, fuzzy, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/pt.c:23042
+#: cp/pt.c:23120
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "διπλός ορισμός συνόλου"
 
-#: cp/pt.c:23078
+#: cp/pt.c:23156
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "διπλός ορισμός συνόλου"
 
-#: cp/pt.c:23101 cp/pt.c:23187
+#: cp/pt.c:23179 cp/pt.c:23265
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr ""
 
-#: cp/pt.c:23106 cp/pt.c:23204
+#: cp/pt.c:23184 cp/pt.c:23282
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr ""
 
-#: cp/pt.c:23163
+#: cp/pt.c:23241
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/pt.c:23165
+#: cp/pt.c:23243
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/pt.c:23174
+#: cp/pt.c:23252
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr ""
 
-#: cp/pt.c:23192
+#: cp/pt.c:23270
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr ""
 
-#: cp/pt.c:23238
+#: cp/pt.c:23316
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "διπλός ορισμός συνόλου"
 
-#: cp/pt.c:23536
+#: cp/pt.c:23614
 #, fuzzy, gcc-internal-format
 msgid "exception specification of %qD depends on itself"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
@@ -48392,102 +48434,102 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:23842
+#: cp/pt.c:23920
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr ""
 
-#: cp/pt.c:24043
+#: cp/pt.c:24121
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:24418
+#: cp/pt.c:24496
 #, fuzzy, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "Μη έγκυρος χαρακτήρας παραβολής"
 
-#: cp/pt.c:24420
+#: cp/pt.c:24498
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:25723
+#: cp/pt.c:25802
 #, gcc-internal-format
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr ""
 
-#: cp/pt.c:25961
+#: cp/pt.c:26040
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr ""
 
-#: cp/pt.c:26440
+#: cp/pt.c:26519
 #, fuzzy, gcc-internal-format
 msgid "non-class template %qT used without template arguments"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/pt.c:26586
+#: cp/pt.c:26665
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:26593
+#: cp/pt.c:26672
 #, fuzzy, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:26607
+#: cp/pt.c:26686
 #, fuzzy, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "έχουν παραληφθεί ορίσματα"
 
-#: cp/pt.c:26614
+#: cp/pt.c:26693
 #, fuzzy, gcc-internal-format
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/pt.c:26676
+#: cp/pt.c:26755
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:26679
+#: cp/pt.c:26758
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:26711
+#: cp/pt.c:26790
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/pt.c:26746
+#: cp/pt.c:26825
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: cp/pt.c:26748
+#: cp/pt.c:26827
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "Δεν μπόρεσα να ανοίξω το αρχείο %s"
 
-#: cp/pt.c:26781
+#: cp/pt.c:26860
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:26785
+#: cp/pt.c:26864
 #, fuzzy, gcc-internal-format
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/pt.c:26789
+#: cp/pt.c:26868
 #, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.c:26793
+#: cp/pt.c:26872
 #, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr ""
@@ -48494,7 +48536,7 @@
 
 # src/grep.c:785 src/grep.c:792
 # src/grep.c:1060 src/grep.c:1067 src/grep.c:1076
-#: cp/pt.c:26912
+#: cp/pt.c:26991
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr "μη έγκυρο όρισμα μήκους περιεχομένου"
@@ -48549,78 +48591,78 @@
 msgid "cannot dynamic_cast %qE (of type %q#T) to type %q#T (%s)"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/search.c:240
+#: cp/search.c:243
 #, fuzzy, gcc-internal-format
 msgid "%qT is an ambiguous base of %qT"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/search.c:256
+#: cp/search.c:259
 #, fuzzy, gcc-internal-format
 msgid "%qT is an inaccessible base of %qT"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/search.c:1905
+#: cp/search.c:1908
 #, fuzzy, gcc-internal-format
 msgid "invalid covariant return type for %q#D"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: cp/search.c:1907 cp/search.c:1922 cp/search.c:1928 cp/search.c:1957
+#: cp/search.c:1910 cp/search.c:1925 cp/search.c:1931 cp/search.c:1960
 #, fuzzy, gcc-internal-format
 msgid "overridden function is %q#D"
 msgstr "αντιγράφεται από πάνω"
 
-#: cp/search.c:1920
+#: cp/search.c:1923
 #, fuzzy, gcc-internal-format
 msgid "invalid covariant return type for %q+#D"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: cp/search.c:1926
+#: cp/search.c:1929
 #, fuzzy, gcc-internal-format
 msgid "conflicting return type specified for %q+#D"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 
-#: cp/search.c:1942
+#: cp/search.c:1945
 #, fuzzy, gcc-internal-format
 msgid "looser throw specifier for %q+#F"
 msgstr "Εγγραφή ονομάτων των επιλεγμένων λέξεων-κλειδιών"
 
-#: cp/search.c:1944
+#: cp/search.c:1947
 #, fuzzy, gcc-internal-format
 msgid "overridden function is %q#F"
 msgstr "αντιγράφεται από πάνω"
 
-#: cp/search.c:1955
+#: cp/search.c:1958
 #, fuzzy, gcc-internal-format
 msgid "conflicting type attributes specified for %q+#D"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 
-#: cp/search.c:1972
+#: cp/search.c:1975
 #, gcc-internal-format
 msgid "%qD declared %<transaction_safe_dynamic%>"
 msgstr ""
 
-#: cp/search.c:1974
+#: cp/search.c:1977
 #, fuzzy, gcc-internal-format
 msgid "overriding %qD declared %<transaction_safe%>"
 msgstr "ο χάρτης χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: cp/search.c:1981
+#: cp/search.c:1984
 #, fuzzy, gcc-internal-format
 msgid "deleted function %q+D overriding non-deleted function"
 msgstr "%s: διπλός ορισμός έκδοσης κατηγορίας"
 
-#: cp/search.c:1984 cp/search.c:1992 cp/search.c:2000
+#: cp/search.c:1987 cp/search.c:1995 cp/search.c:2003
 #, fuzzy, gcc-internal-format
 #| msgid "In function %qs:"
 msgid "overridden function is %qD"
 msgstr "Στη συνάρτηση %qs:"
 
-#: cp/search.c:1989
+#: cp/search.c:1992
 #, fuzzy, gcc-internal-format
 msgid "non-deleted function %q+D overriding deleted function"
 msgstr "%s: διπλός ορισμός έκδοσης κατηγορίας"
 
-#: cp/search.c:1998
+#: cp/search.c:2001
 #, fuzzy, gcc-internal-format
 msgid "virtual function %q+D overriding final function"
 msgstr "%s: διπλός ορισμός έκδοσης κατηγορίας"
@@ -48627,12 +48669,12 @@
 
 #. A static member function cannot match an inherited
 #. virtual member function.
-#: cp/search.c:2082
+#: cp/search.c:2085
 #, fuzzy, gcc-internal-format
 msgid "%q+#D cannot be declared"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/search.c:2083
+#: cp/search.c:2086
 #, fuzzy, gcc-internal-format
 msgid "  since %q+#D declared in base class"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
@@ -48672,191 +48714,191 @@
 msgid "invalid use of member %qD in static member function"
 msgstr "μη έγκυρος αριθμός πεδίου: `%s'"
 
-#: cp/semantics.c:2153
+#: cp/semantics.c:2156
 #, gcc-internal-format
 msgid "a statement expression is an insufficient context for overload resolution"
 msgstr ""
 
-#: cp/semantics.c:2540
+#: cp/semantics.c:2543
 #, fuzzy, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr "%s: οι τιμές του πεδίου `%s' δεν πρέπει να είναι μεγαλύτερες από %d"
 
-#: cp/semantics.c:2622
+#: cp/semantics.c:2625
 #, fuzzy, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr "η `%s' είναι συνήθως μη-στατική συνάρτηση"
 
-#: cp/semantics.c:2624
+#: cp/semantics.c:2627
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr "μη έγκυρος αριθμός πεδίου: `%s'"
 
-#: cp/semantics.c:2626
+#: cp/semantics.c:2629
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr "μη έγκυρος χρήστης"
 
-#: cp/semantics.c:2648
+#: cp/semantics.c:2651
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr ""
 
-#: cp/semantics.c:2656 cp/typeck.c:2604
+#: cp/semantics.c:2659 cp/typeck.c:2604
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/semantics.c:2678
+#: cp/semantics.c:2681
 #, fuzzy, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/semantics.c:2751
+#: cp/semantics.c:2754
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr ""
 
-#: cp/semantics.c:2892
+#: cp/semantics.c:2895
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr ""
 
-#: cp/semantics.c:2942
+#: cp/semantics.c:2945
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr ""
 
-#: cp/semantics.c:2945
+#: cp/semantics.c:2948
 #, fuzzy, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/semantics.c:2962
+#: cp/semantics.c:2965
 #, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr ""
 
-#: cp/semantics.c:2993
+#: cp/semantics.c:2996
 #, fuzzy, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr "μη έγκυρος αριθμός αρχείου στη δήλωση πεδίου: `%s'"
 
-#: cp/semantics.c:3263
+#: cp/semantics.c:3266
 #, fuzzy, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "Μη έγκυρη ρύθμιση θύρας (port)"
 
-#: cp/semantics.c:3423
+#: cp/semantics.c:3426
 #, gcc-internal-format
 msgid "cannot capture member %qD of anonymous union"
 msgstr ""
 
-#: cp/semantics.c:3443 cp/semantics.c:9269
+#: cp/semantics.c:3446 cp/semantics.c:9272
 #, fuzzy, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/semantics.c:3448
+#: cp/semantics.c:3451
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.c:3450
+#: cp/semantics.c:3453
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.c:3462
+#: cp/semantics.c:3465
 #, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr ""
 
-#: cp/semantics.c:3464
+#: cp/semantics.c:3467
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr ""
 
-#: cp/semantics.c:3596
+#: cp/semantics.c:3599
 #, gcc-internal-format
 msgid "use of parameter outside function body"
 msgstr ""
 
-#: cp/semantics.c:3606
+#: cp/semantics.c:3609
 #, fuzzy, gcc-internal-format
 msgid "missing template arguments"
 msgstr "Ελλιπής ή κακοσχηματισμένη ιδιότητα"
 
-#: cp/semantics.c:3633
+#: cp/semantics.c:3636
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr ""
 
-#: cp/semantics.c:3664
+#: cp/semantics.c:3667
 #, fuzzy, gcc-internal-format
 msgid "use of namespace %qD as expression"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
-#: cp/semantics.c:3669
+#: cp/semantics.c:3672
 #, fuzzy, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:3675
+#: cp/semantics.c:3678
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr ""
 
-#: cp/semantics.c:3702
+#: cp/semantics.c:3705
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/semantics.c:3841
+#: cp/semantics.c:3844
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr ""
 
-#: cp/semantics.c:3870
+#: cp/semantics.c:3873
 #, fuzzy, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4009
+#: cp/semantics.c:4012
 #, gcc-internal-format
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr ""
 
-#: cp/semantics.c:4038
+#: cp/semantics.c:4041
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr ""
 
-#: cp/semantics.c:4052
+#: cp/semantics.c:4055
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
 
-#: cp/semantics.c:4056
+#: cp/semantics.c:4059
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function"
 msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
 
-#: cp/semantics.c:4061
+#: cp/semantics.c:4064
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr ""
 
-#: cp/semantics.c:4072
+#: cp/semantics.c:4075
 #, gcc-internal-format
 msgid "offsetof within non-standard-layout type %qT is conditionally-supported"
 msgstr ""
 
-#: cp/semantics.c:4583 cp/semantics.c:6069 cp/semantics.c:6140
-#: cp/semantics.c:6183 cp/semantics.c:6533 cp/semantics.c:6632
-#: cp/semantics.c:6775
+#: cp/semantics.c:4586 cp/semantics.c:6072 cp/semantics.c:6143
+#: cp/semantics.c:6186 cp/semantics.c:6536 cp/semantics.c:6635
+#: cp/semantics.c:6778
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
@@ -48863,387 +48905,402 @@
 
 # src/getopt.c:628
 # src/getopt.c:628
-#: cp/semantics.c:5271
+#: cp/semantics.c:5274
 #, fuzzy, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr "%s: η επιλογή `%s' είναι ασαφής\n"
 
-#: cp/semantics.c:5544
+#: cp/semantics.c:5547
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: cp/semantics.c:5592
+#: cp/semantics.c:5595
 #, gcc-internal-format
 msgid "%qE has const type for %<reduction%>"
 msgstr ""
 
-#: cp/semantics.c:5707
+#: cp/semantics.c:5710
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:5941
+#: cp/semantics.c:5944
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5955
+#: cp/semantics.c:5958
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5977
+#: cp/semantics.c:5980
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6080
+#: cp/semantics.c:6083
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/semantics.c:6152
+#: cp/semantics.c:6155
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr ""
 
-#: cp/semantics.c:6195
+#: cp/semantics.c:6198
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr ""
 
-#: cp/semantics.c:6240
+#: cp/semantics.c:6243
 #, gcc-internal-format
 msgid "%<gang%> static expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6254
+#: cp/semantics.c:6257
 #, gcc-internal-format
 msgid "%<gang%> static value must be positive"
 msgstr ""
 
-#: cp/semantics.c:6288
+#: cp/semantics.c:6291
 #, gcc-internal-format
 msgid "%<gang%> num expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6291
+#: cp/semantics.c:6294
 #, gcc-internal-format
 msgid "%<vector%> length expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6295
+#: cp/semantics.c:6298
 #, gcc-internal-format
 msgid "%<worker%> num expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6317
+#: cp/semantics.c:6320
 #, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr ""
 
-#: cp/semantics.c:6321
+#: cp/semantics.c:6324
 #, gcc-internal-format
 msgid "%<vector%> length value must be positive"
 msgstr ""
 
-#: cp/semantics.c:6326
+#: cp/semantics.c:6329
 #, gcc-internal-format
 msgid "%<worker%> num value must be positive"
 msgstr ""
 
-#: cp/semantics.c:6376
+#: cp/semantics.c:6379
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6406
+#: cp/semantics.c:6409
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6419
+#: cp/semantics.c:6422
 #, fuzzy, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "Λάθος έκφραση στην αποτίμηση: %s"
 
-#: cp/semantics.c:6438
+#: cp/semantics.c:6441
 #, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6466
+#: cp/semantics.c:6469
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6495
+#: cp/semantics.c:6498
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr ""
 
-#: cp/semantics.c:6516
+#: cp/semantics.c:6519
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6543
+#: cp/semantics.c:6546
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/semantics.c:6557
+#: cp/semantics.c:6560
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:6563
+#: cp/semantics.c:6566
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: cp/semantics.c:6576
+#: cp/semantics.c:6579
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6625
+#: cp/semantics.c:6628
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/semantics.c:6910
+#: cp/semantics.c:6913
 #, fuzzy, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr "αποτυχία κατά την εγγραφή δεδομένων για την κατηγορία `%s'"
 
-#: cp/semantics.c:6914
+#: cp/semantics.c:6917
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6979
+#: cp/semantics.c:6982
 #, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7008
+#: cp/semantics.c:7011
 #, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7037
+#: cp/semantics.c:7040
 #, gcc-internal-format
 msgid "%<num_tasks%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7066
+#: cp/semantics.c:7069
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:7105
+#: cp/semantics.c:7108
 #, gcc-internal-format
 msgid "%<tile%> argument needs integral type"
 msgstr ""
 
-#: cp/semantics.c:7524
+#: cp/semantics.c:7527
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.c:7538
+#: cp/semantics.c:7541
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr ""
 
-#: cp/semantics.c:7743
+#: cp/semantics.c:7746
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.c:8171
+#: cp/semantics.c:8174
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.c:8398 cp/semantics.c:8408
+#: cp/semantics.c:8401 cp/semantics.c:8411
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.c:8702
+#: cp/semantics.c:8705
 #, gcc-internal-format
 msgid "static assertion failed"
 msgstr ""
 
-#: cp/semantics.c:8704
+#: cp/semantics.c:8707
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr ""
 
-#: cp/semantics.c:8709
+#: cp/semantics.c:8712
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr ""
 
-#: cp/semantics.c:8739
+#: cp/semantics.c:8742
 #, fuzzy, gcc-internal-format
 msgid "argument to decltype must be an expression"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: cp/semantics.c:8767
+#: cp/semantics.c:8770
 #, gcc-internal-format
 msgid "decltype cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/semantics.c:9308
+#: cp/semantics.c:9311
 #, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.c:9361
+#: cp/semantics.c:9364
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.c:9363
+#: cp/semantics.c:9366
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:9381
+#: cp/semantics.c:9384
 #, fuzzy, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "Λείπει παράμετρος για `%s'"
 
-#: cp/tree.c:1276
+#: cp/tree.c:1295
 #, fuzzy, gcc-internal-format
 msgid "%qV qualifiers cannot be applied to %qT"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/tree.c:1788
+#: cp/tree.c:1807
 #, fuzzy, gcc-internal-format
 msgid "lambda-expression in a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/tree.c:1792
+#: cp/tree.c:1811
 #, fuzzy, gcc-internal-format
 msgid "statement-expression in a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/tree.c:4050
+#: cp/tree.c:4083
 #, gcc-internal-format
-msgid "the calling convention for %qT changes in -fabi-version=12 (GCC 8)"
+msgid "-fabi-version=13 (GCC 8.2) fixes the calling convention for %qT, which was accidentally changed in 8.1"
 msgstr ""
 
-#: cp/tree.c:4055
+#: cp/tree.c:4087
 #, gcc-internal-format
+msgid "-fabi-version=12 (GCC 8.1) accidentally changes the calling convention for %qT"
+msgstr ""
+
+#: cp/tree.c:4090
+#, fuzzy, gcc-internal-format
+msgid " declared here"
+msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
+
+#: cp/tree.c:4094
+#, gcc-internal-format
+msgid "the calling convention for %qT changes in -fabi-version=13 (GCC 8.2)"
+msgstr ""
+
+#: cp/tree.c:4096
+#, gcc-internal-format
 msgid " because all of its copy and move constructors are deleted"
 msgstr ""
 
-#: cp/tree.c:4416
+#: cp/tree.c:4464
 #, gcc-internal-format
 msgid "%qE attribute applied to %qD with void return type"
 msgstr ""
 
-#: cp/tree.c:4423
+#: cp/tree.c:4471
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr ""
 
-#: cp/tree.c:4475
+#: cp/tree.c:4523
 #, gcc-internal-format
 msgid "requested init_priority is not an integer constant"
 msgstr ""
 
-#: cp/tree.c:4497
+#: cp/tree.c:4545
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr ""
 
-#: cp/tree.c:4505
+#: cp/tree.c:4553
 #, gcc-internal-format
 msgid "requested init_priority is out of range"
 msgstr ""
 
-#: cp/tree.c:4515
+#: cp/tree.c:4563
 #, gcc-internal-format
 msgid "requested init_priority is reserved for internal use"
 msgstr ""
 
-#: cp/tree.c:4526
+#: cp/tree.c:4574
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr "προειδοποίηση: το --pid=PID δεν υποστηρίζεται σε αυτό το σύστημα"
 
-#: cp/tree.c:4553
+#: cp/tree.c:4601
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %qE"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/tree.c:4573
+#: cp/tree.c:4621
 #, fuzzy, gcc-internal-format
 msgid "the %qE attribute requires arguments"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/tree.c:4584
+#: cp/tree.c:4632
 #, fuzzy, gcc-internal-format
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: cp/tree.c:4597 cp/tree.c:4610
+#: cp/tree.c:4645 cp/tree.c:4658
 #, fuzzy, gcc-internal-format
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: cp/tree.c:4599
+#: cp/tree.c:4647
 #, fuzzy, gcc-internal-format
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/tree.c:4612
+#: cp/tree.c:4660
 #, fuzzy, gcc-internal-format
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/tree.c:4636
+#: cp/tree.c:4684
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/tree.c:4642
+#: cp/tree.c:4690
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "%s: διπλός ορισμός έκδοσης κατηγορίας"
 
-#: cp/tree.c:4649
+#: cp/tree.c:4697
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "διπλός ορισμός συνόλου"
 
-#: cp/tree.c:4656
+#: cp/tree.c:4704
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr ""
 
-#: cp/tree.c:4678
+#: cp/tree.c:4726
 #, gcc-internal-format
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr ""
 
-#: cp/tree.c:4684
+#: cp/tree.c:4732
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "αδυναμία ανάγνωσης κεφαλίδας από το `%s'"
 
-#: cp/tree.c:5440
+#: cp/tree.c:5488
 #, fuzzy, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: cp/tree.c:5453
+#: cp/tree.c:5501
 #, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr ""
@@ -50337,107 +50394,107 @@
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr ""
 
-#: cp/typeck2.c:1496 cp/typeck2.c:1523
+#: cp/typeck2.c:1499 cp/typeck2.c:1526
 #, fuzzy, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "έχει παραληφθεί το αρχείο προορισμού"
 
-#: cp/typeck2.c:1504
+#: cp/typeck2.c:1507
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr ""
 
-#: cp/typeck2.c:1511
+#: cp/typeck2.c:1514
 #, fuzzy, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/typeck2.c:1587
+#: cp/typeck2.c:1590
 #, fuzzy, gcc-internal-format
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "το αρχείο δεδομένων προφίλ `%s' δεν ταιριάζει με το διαμοιραζόμενο αντικείμενο `%s'"
 
-#: cp/typeck2.c:1660
+#: cp/typeck2.c:1663
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr ""
 
-#: cp/typeck2.c:1671
+#: cp/typeck2.c:1674
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr ""
 
-#: cp/typeck2.c:1858
+#: cp/typeck2.c:1861
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr ""
 
-#: cp/typeck2.c:1872
+#: cp/typeck2.c:1875
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr ""
 
-#: cp/typeck2.c:1898
+#: cp/typeck2.c:1901
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr ""
 
-#: cp/typeck2.c:1900
+#: cp/typeck2.c:1903
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr ""
 
-#: cp/typeck2.c:1927
+#: cp/typeck2.c:1930
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr ""
 
-#: cp/typeck2.c:1936
+#: cp/typeck2.c:1939
 #, fuzzy, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/typeck2.c:1958
+#: cp/typeck2.c:1961
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr ""
 
-#: cp/typeck2.c:2018
+#: cp/typeck2.c:2021
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr ""
 
-#: cp/typeck2.c:2029
+#: cp/typeck2.c:2032
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr ""
 
-#: cp/typeck2.c:2037
+#: cp/typeck2.c:2040
 #, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++2a"
 msgstr ""
 
-#: cp/typeck2.c:2080
+#: cp/typeck2.c:2083
 #, fuzzy, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/typeck2.c:2096
+#: cp/typeck2.c:2099
 #, fuzzy, gcc-internal-format
 msgid "cannot deduce template arguments for %qT from ()"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/typeck2.c:2114
+#: cp/typeck2.c:2117
 #, fuzzy, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "μη έγκυρος αριθμός αρχείου στη δήλωση πεδίου: `%s'"
 
-#: cp/typeck2.c:2341
+#: cp/typeck2.c:2344
 #, fuzzy, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/typeck2.c:2344
+#: cp/typeck2.c:2347
 #, fuzzy, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "μη πλήρης εγγραφή"
@@ -50652,11 +50709,11 @@
 msgstr ""
 
 #: fortran/array.c:221 fortran/array.c:661 fortran/check.c:2849
-#: fortran/check.c:5222 fortran/check.c:5260 fortran/check.c:5302
-#: fortran/check.c:5329 fortran/check.c:5529 fortran/match.c:1821
+#: fortran/check.c:5225 fortran/check.c:5263 fortran/check.c:5305
+#: fortran/check.c:5332 fortran/check.c:5532 fortran/match.c:1821
 #: fortran/match.c:3174 fortran/match.c:3516 fortran/match.c:3712
-#: fortran/simplify.c:2909 fortran/simplify.c:2939 fortran/simplify.c:5764
-#: fortran/simplify.c:7658
+#: fortran/simplify.c:2909 fortran/simplify.c:2939 fortran/simplify.c:5769
+#: fortran/simplify.c:7663
 #, gcc-internal-format
 msgid "Coarrays disabled at %C, use %<-fcoarray=%> to enable"
 msgstr ""
@@ -50791,118 +50848,123 @@
 msgid "DO-iterator %qs at %L is inside iterator of the same name"
 msgstr ""
 
-#: fortran/array.c:1073 fortran/array.c:1255
+#: fortran/array.c:1073 fortran/array.c:1264
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in array constructor at %C"
 msgstr "συντακτικό σφάλμα στον καθορισμό σειράς"
 
-#: fortran/array.c:1129
+#: fortran/array.c:1105
+#, fuzzy, gcc-internal-format, gfc-internal-format
+msgid "NULL() at %C cannot appear in an array constructor"
+msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
+
+#: fortran/array.c:1138
 #, gcc-internal-format, gfc-internal-format
 msgid "[...] style array constructors at %C"
 msgstr ""
 
-#: fortran/array.c:1149
+#: fortran/array.c:1158
 #, gcc-internal-format, gfc-internal-format
 msgid "Array constructor including type specification at %C"
 msgstr ""
 
-#: fortran/array.c:1155 fortran/match.c:4148
+#: fortran/array.c:1164 fortran/match.c:4148
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-spec at %L cannot contain a deferred type parameter"
 msgstr ""
 
-#: fortran/array.c:1163
+#: fortran/array.c:1172
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-spec at %L cannot contain an asterisk for a type parameter"
 msgstr ""
 
-#: fortran/array.c:1181
+#: fortran/array.c:1190
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Empty array constructor at %C is not allowed"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: fortran/array.c:1218 fortran/array.c:1228
+#: fortran/array.c:1227 fortran/array.c:1237
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Incompatible typespec for array element at %L"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: fortran/array.c:1302
+#: fortran/array.c:1311
 #, gcc-internal-format, gfc-internal-format
 msgid "Element in %s array constructor at %L is %s"
 msgstr ""
 
-#: fortran/array.c:1633
+#: fortran/array.c:1642
 #, gcc-internal-format, gfc-internal-format
 msgid "Iterator step at %L cannot be zero"
 msgstr ""
 
-#: fortran/array.c:1770
+#: fortran/array.c:1779
 #, gcc-internal-format
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit.   See %<-fmax-array-constructor%> option"
 msgstr ""
 
-#: fortran/array.c:1940
+#: fortran/array.c:1949
 #, gcc-internal-format, gfc-internal-format
 msgid "AC-IMPLIED-DO initial expression references control variable at %L"
 msgstr ""
 
-#: fortran/array.c:1947
+#: fortran/array.c:1956
 #, gcc-internal-format, gfc-internal-format
 msgid "AC-IMPLIED-DO final expression references control variable at %L"
 msgstr ""
 
-#: fortran/array.c:1954
+#: fortran/array.c:1963
 #, gcc-internal-format, gfc-internal-format
 msgid "AC-IMPLIED-DO step expression references control variable at %L"
 msgstr ""
 
-#: fortran/array.c:1966
+#: fortran/array.c:1975
 #, gcc-internal-format, gfc-internal-format
 msgid "Array constructor value at %L shall not be unlimited polymorphic [F2008: C4106]"
 msgstr ""
 
-#: fortran/array.c:2055
+#: fortran/array.c:2067
 #, gcc-internal-format, gfc-internal-format
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor at %L"
 msgstr ""
 
-#: fortran/array.c:2174
+#: fortran/array.c:2186
 #, gcc-internal-format
 msgid "spec_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2233
+#: fortran/array.c:2245
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2237
+#: fortran/array.c:2249
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array dimension at %L"
 msgstr ""
 
-#: fortran/array.c:2264 fortran/data.c:552 fortran/data.c:571
-#: fortran/data.c:585 fortran/data.c:714
+#: fortran/array.c:2276 fortran/data.c:563 fortran/data.c:582
+#: fortran/data.c:596 fortran/data.c:725
 #, gcc-internal-format
 msgid "Simplification error"
 msgstr ""
 
-#: fortran/array.c:2376
+#: fortran/array.c:2388
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimen_type"
 msgstr ""
 
-#: fortran/array.c:2427
+#: fortran/array.c:2439
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2472
+#: fortran/array.c:2484
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad EXPR_ARRAY expr"
 msgstr ""
 
-#: fortran/array.c:2620
+#: fortran/array.c:2632
 #, gcc-internal-format
 msgid "gfc_find_array_ref(): No ref found"
 msgstr ""
@@ -50953,7 +51015,7 @@
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or PROCEDURE"
 msgstr ""
 
-#: fortran/check.c:205 fortran/check.c:6658
+#: fortran/check.c:205 fortran/check.c:6661
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a constant"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
@@ -51068,7 +51130,7 @@
 msgid "Unequal character lengths (%ld/%ld) in %s at %L"
 msgstr ""
 
-#: fortran/check.c:946 fortran/check.c:6602
+#: fortran/check.c:946 fortran/check.c:6605
 #, gcc-internal-format
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have the same type"
 msgstr ""
@@ -51303,9 +51365,9 @@
 msgstr ""
 
 #: fortran/check.c:1939 fortran/check.c:2525 fortran/check.c:2628
-#: fortran/check.c:2835 fortran/check.c:2880 fortran/check.c:4256
-#: fortran/check.c:4390 fortran/check.c:4445 fortran/check.c:5515
-#: fortran/check.c:5644
+#: fortran/check.c:2835 fortran/check.c:2880 fortran/check.c:4259
+#: fortran/check.c:4393 fortran/check.c:4448 fortran/check.c:5518
+#: fortran/check.c:5647
 #, gcc-internal-format
 msgid "%qs intrinsic with KIND argument at %L"
 msgstr ""
@@ -51500,7 +51562,7 @@
 msgid "NULL intrinsic with allocatable MOLD at %L"
 msgstr ""
 
-#: fortran/check.c:3768 fortran/check.c:5591
+#: fortran/check.c:3768 fortran/check.c:5594
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must provide at least as many elements as there are .TRUE. values in %qs (%ld/%d)"
 msgstr ""
@@ -51520,372 +51582,372 @@
 msgid "%qs argument of %qs intrinsic at %L must not be a subobject of %qs"
 msgstr ""
 
-#: fortran/check.c:3901
+#: fortran/check.c:3904
 #, gcc-internal-format, gfc-internal-format
 msgid "The argument of the RANK intrinsic at %L must be a data object"
 msgstr ""
 
-#: fortran/check.c:4005
+#: fortran/check.c:4008
 #, gcc-internal-format
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L must be an array of constant size"
 msgstr ""
 
-#: fortran/check.c:4015
+#: fortran/check.c:4018
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L is empty"
 msgstr ""
 
-#: fortran/check.c:4022
+#: fortran/check.c:4025
 #, gcc-internal-format
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L has more than %d elements"
 msgstr ""
 
-#: fortran/check.c:4039
+#: fortran/check.c:4042
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has negative element (%d)"
 msgstr ""
 
-#: fortran/check.c:4071
+#: fortran/check.c:4074
 #, gcc-internal-format, gfc-internal-format
 msgid "Element %d of actual argument of RESHAPE at %L cannot be negative"
 msgstr ""
 
-#: fortran/check.c:4109
+#: fortran/check.c:4112
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has wrong number of elements (%d/%d)"
 msgstr ""
 
-#: fortran/check.c:4127
+#: fortran/check.c:4130
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has out-of-range dimension (%d)"
 msgstr ""
 
-#: fortran/check.c:4136
+#: fortran/check.c:4139
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has invalid permutation of dimensions (dimension %qd duplicated)"
 msgstr ""
 
-#: fortran/check.c:4172
+#: fortran/check.c:4175
 #, gcc-internal-format, gfc-internal-format
 msgid "Without padding, there are not enough elements in the intrinsic RESHAPE source at %L to match the shape"
 msgstr ""
 
-#: fortran/check.c:4189 fortran/check.c:4208
+#: fortran/check.c:4192 fortran/check.c:4211
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L cannot be of type %s"
 msgstr ""
 
-#: fortran/check.c:4199 fortran/check.c:4218
+#: fortran/check.c:4202 fortran/check.c:4221
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of an extensible type"
 msgstr ""
 
-#: fortran/check.c:4317
+#: fortran/check.c:4320
 #, gcc-internal-format
 msgid "SELECTED_REAL_KIND with neither %<P%> nor %<R%> argument at %L"
 msgstr ""
 
-#: fortran/check.c:4348
+#: fortran/check.c:4351
 #, gcc-internal-format
 msgid "%qs intrinsic with RADIX argument at %L"
 msgstr ""
 
-#: fortran/check.c:4383
+#: fortran/check.c:4386
 #, gcc-internal-format
 msgid "%<source%> argument of %<shape%> intrinsic at %L must not be an assumed size array"
 msgstr ""
 
-#: fortran/check.c:4460 fortran/check.c:6641
+#: fortran/check.c:4463 fortran/check.c:6644
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be a procedure"
 msgstr ""
 
-#: fortran/check.c:4473 fortran/check.c:4612 fortran/check.c:6633
+#: fortran/check.c:4476 fortran/check.c:4615 fortran/check.c:6636
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be TYPE(*)"
 msgstr ""
 
-#: fortran/check.c:4484 fortran/check.c:4624
+#: fortran/check.c:4487 fortran/check.c:4627
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be an assumed-size array"
 msgstr ""
 
-#: fortran/check.c:4554
+#: fortran/check.c:4557
 #, gcc-internal-format
 msgid "is_c_interoperable(): gfc_simplify_expr failed"
 msgstr ""
 
-#: fortran/check.c:4603
+#: fortran/check.c:4606
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be an interoperable data entity: %s"
 msgstr ""
 
-#: fortran/check.c:4642
+#: fortran/check.c:4645
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_1 at %L to C_ASSOCIATED shall have the type TYPE(C_PTR) or TYPE(C_FUNPTR)"
 msgstr ""
 
-#: fortran/check.c:4656
+#: fortran/check.c:4659
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_2 at %L to C_ASSOCIATED shall have the same type as C_PTR_1: %s instead of %s"
 msgstr ""
 
-#: fortran/check.c:4680
+#: fortran/check.c:4683
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_POINTER shall have the type TYPE(C_PTR)"
 msgstr ""
 
-#: fortran/check.c:4692
+#: fortran/check.c:4695
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER must be a pointer"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: fortran/check.c:4699
+#: fortran/check.c:4702
 #, gcc-internal-format, gfc-internal-format
 msgid "FPTR argument at %L to C_F_POINTER shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:4706
+#: fortran/check.c:4709
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:4713
+#: fortran/check.c:4716
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected SHAPE argument at %L to C_F_POINTER with scalar FPTR"
 msgstr ""
 
-#: fortran/check.c:4719
+#: fortran/check.c:4722
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected SHAPE argument to C_F_POINTER with array FPTR at %L"
 msgstr ""
 
-#: fortran/check.c:4738
+#: fortran/check.c:4741
 #, gcc-internal-format, gfc-internal-format
 msgid "SHAPE argument at %L to C_F_POINTER must have the same size as the RANK of FPTR"
 msgstr ""
 
-#: fortran/check.c:4748
+#: fortran/check.c:4751
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic FPTR at %L to C_F_POINTER"
 msgstr ""
 
-#: fortran/check.c:4753
+#: fortran/check.c:4756
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array FPTR at %L to C_F_POINTER: %s"
 msgstr ""
 
-#: fortran/check.c:4769
+#: fortran/check.c:4772
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_PROCPOINTER shall have the type TYPE(C_FUNPTR)"
 msgstr ""
 
-#: fortran/check.c:4781
+#: fortran/check.c:4784
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall be a procedure pointer"
 msgstr ""
 
-#: fortran/check.c:4788
+#: fortran/check.c:4791
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:4794
+#: fortran/check.c:4797
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure pointer at %L to C_F_PROCPOINTER"
 msgstr ""
 
-#: fortran/check.c:4808
+#: fortran/check.c:4811
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:4823
+#: fortran/check.c:4826
 #, gcc-internal-format
 msgid "Function result %qs at %L is invalid as X argument to C_FUNLOC"
 msgstr ""
 
-#: fortran/check.c:4831
+#: fortran/check.c:4834
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall be a procedure or a procedure pointer"
 msgstr ""
 
-#: fortran/check.c:4837
+#: fortran/check.c:4840
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure at %L to C_FUNLOC"
 msgstr ""
 
-#: fortran/check.c:4851
+#: fortran/check.c:4854
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall not be coindexed"
 msgstr ""
 
-#: fortran/check.c:4857
+#: fortran/check.c:4860
 #, gcc-internal-format, gfc-internal-format
 msgid "X argument at %L to C_LOC shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:4868
+#: fortran/check.c:4871
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall have either the POINTER or the TARGET attribute"
 msgstr ""
 
-#: fortran/check.c:4876
+#: fortran/check.c:4879
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall be not be a zero-sized string"
 msgstr ""
 
-#: fortran/check.c:4885
+#: fortran/check.c:4888
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument at %L to C_LOC shall not be polymorphic"
 msgstr ""
 
-#: fortran/check.c:4892
+#: fortran/check.c:4895
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array at %L as argument to C_LOC: %s"
 msgstr ""
 
-#: fortran/check.c:4903
+#: fortran/check.c:4906
 #, gcc-internal-format, gfc-internal-format
 msgid "Array of interoperable type at %L to C_LOC which is nonallocatable and neither assumed size nor explicit size"
 msgstr ""
 
-#: fortran/check.c:4908
+#: fortran/check.c:4911
 #, gcc-internal-format, gfc-internal-format
 msgid "Array section at %L to C_LOC"
 msgstr ""
 
-#: fortran/check.c:4936
+#: fortran/check.c:4939
 #, gcc-internal-format, gfc-internal-format
 msgid "non double precision REAL argument to %s intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:4949
+#: fortran/check.c:4952
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be less than rank %d"
 msgstr "%s: οι τιμές του πεδίου `%s' δεν πρέπει να είναι μεγαλύτερες από %d"
 
-#: fortran/check.c:4968
+#: fortran/check.c:4971
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L is not a valid dimension index"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: fortran/check.c:5231
+#: fortran/check.c:5234
 #, gcc-internal-format, gfc-internal-format
 msgid "%s argument to IMAGE_INDEX must be a rank one array at %L"
 msgstr ""
 
-#: fortran/check.c:5242
+#: fortran/check.c:5245
 #, gcc-internal-format, gfc-internal-format
 msgid "The number of array elements of the SUB argument to IMAGE_INDEX at %L shall be %d (corank) not %d"
 msgstr ""
 
-#: fortran/check.c:5275
+#: fortran/check.c:5278
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to NUM_IMAGES at %L"
 msgstr ""
 
-#: fortran/check.c:5288
+#: fortran/check.c:5291
 #, gcc-internal-format, gfc-internal-format
 msgid "FAILED= argument to NUM_IMAGES at %L"
 msgstr ""
 
-#: fortran/check.c:5312
+#: fortran/check.c:5315
 #, gcc-internal-format, gfc-internal-format
 msgid "TEAM argument at %L to the intrinsic TEAM_NUMBER shall be of type TEAM_TYPE"
 msgstr ""
 
-#: fortran/check.c:5338
+#: fortran/check.c:5341
 #, gcc-internal-format, gfc-internal-format
 msgid "DIM argument without COARRAY argument not allowed for THIS_IMAGE intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:5345
+#: fortran/check.c:5348
 #, gcc-internal-format, gfc-internal-format
 msgid "The DISTANCE argument may not be specified together with the COARRAY or DIM argument in intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:5356
+#: fortran/check.c:5359
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected DIM argument with noncoarray argument at %L"
 msgstr ""
 
-#: fortran/check.c:5374
+#: fortran/check.c:5377
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to THIS_IMAGE at %L"
 msgstr ""
 
-#: fortran/check.c:5454
+#: fortran/check.c:5457
 #, gcc-internal-format
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L must not be %s"
 msgstr ""
 
-#: fortran/check.c:5483
+#: fortran/check.c:5486
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic TRANSFER at %L has partly undefined result: source size %ld < result size %ld"
 msgstr ""
 
-#: fortran/check.c:5605
+#: fortran/check.c:5608
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must have the same rank as %qs or be a scalar"
 msgstr ""
 
-#: fortran/check.c:5618
+#: fortran/check.c:5621
 #, gcc-internal-format
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have identical shape."
 msgstr ""
 
-#: fortran/check.c:5861 fortran/check.c:5893
+#: fortran/check.c:5864 fortran/check.c:5896
 #, gcc-internal-format
 msgid "Size of %qs argument of %qs intrinsic at %L too small (%i/%i)"
 msgstr ""
 
-#: fortran/check.c:5901
+#: fortran/check.c:5904
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Too many arguments to %s at %L"
 msgstr "πάρα πολλά ορίσματα"
 
-#: fortran/check.c:5919
+#: fortran/check.c:5922
 #, gcc-internal-format
 msgid "fe_runtime_error string must be null terminated"
 msgstr ""
 
-#: fortran/check.c:5931
+#: fortran/check.c:5934
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "fe_runtime_error: Wrong number of arguments (%d instead of %d)"
 msgstr "λάθος αριθμός ορισμάτων"
 
-#: fortran/check.c:5971
+#: fortran/check.c:5974
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:5990
+#: fortran/check.c:5993
 #, gcc-internal-format, gfc-internal-format
 msgid "Real COUNT_RATE argument to SYSTEM_CLOCK at %L"
 msgstr ""
 
-#: fortran/check.c:6000
+#: fortran/check.c:6003
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT_RATE argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:6017
+#: fortran/check.c:6020
 #, gcc-internal-format, gfc-internal-format
 msgid "COUNT_MAX argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr ""
 
-#: fortran/check.c:6234
+#: fortran/check.c:6237
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of a kind not wider than the default kind (%d)"
 msgstr ""
 
-#: fortran/check.c:6586 fortran/check.c:6594
+#: fortran/check.c:6589 fortran/check.c:6597
 #, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or LOGICAL"
 msgstr ""
 
-#: fortran/check.c:6625
+#: fortran/check.c:6628
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic function NULL at %L cannot be an actual argument to STORAGE_SIZE, because it returns a disassociated pointer"
 msgstr ""
@@ -51897,7 +51959,7 @@
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:727 fortran/decl.c:3636 fortran/decl.c:10066
+#: fortran/class.c:727 fortran/decl.c:3655 fortran/decl.c:10091
 #, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr ""
@@ -51922,44 +51984,49 @@
 msgid "non-constant array in DATA statement %L"
 msgstr ""
 
-#: fortran/data.c:137
+#: fortran/data.c:140
 #, gcc-internal-format, gfc-internal-format
 msgid "failure to simplify substring reference in DATA statement at %L"
 msgstr ""
 
-#: fortran/data.c:170
+#: fortran/data.c:173
 #, gcc-internal-format, gfc-internal-format
 msgid "Unused initialization string at %L because variable has zero length"
 msgstr ""
 
-#: fortran/data.c:176
+#: fortran/data.c:179
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization string at %L was truncated to fit the variable (%ld/%ld)"
 msgstr ""
 
-#: fortran/data.c:265
+#: fortran/data.c:268
 #, gcc-internal-format
 msgid "%qs at %L already is initialized at %L"
 msgstr ""
 
-#: fortran/data.c:289
+#: fortran/data.c:292
 #, gcc-internal-format, gfc-internal-format
 msgid "Data element below array lower bound at %L"
 msgstr ""
 
-#: fortran/data.c:306 fortran/data.c:395
+#: fortran/data.c:309 fortran/data.c:398
 #, gcc-internal-format, gfc-internal-format
 msgid "Data element above array upper bound at %L"
 msgstr ""
 
 # src/request.c:263
-#: fortran/data.c:336 fortran/data.c:505
+#: fortran/data.c:339 fortran/data.c:496
 #, fuzzy, gcc-internal-format
 msgid "re-initialization of %qs at %L"
 msgstr "Το βήμα αρχικοποίησης απέτυχε"
 
-#: fortran/data.c:727
+#: fortran/data.c:515
 #, gcc-internal-format
+msgid "Nonpointer object %qs with default initialization shall not appear in a DATA statement at %L"
+msgstr ""
+
+#: fortran/data.c:738
+#, gcc-internal-format
 msgid "TODO: Vector sections in data statements"
 msgstr ""
 
@@ -51983,510 +52050,510 @@
 msgid "Invalid initializer %s in Data statement at %C"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: fortran/decl.c:536
+#: fortran/decl.c:537
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:573
+#: fortran/decl.c:574
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %C cannot appear within an INTERFACE"
 msgstr ""
 
-#: fortran/decl.c:597
+#: fortran/decl.c:598
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid substring in data-implied-do at %L in DATA statement"
 msgstr ""
 
-#: fortran/decl.c:619
+#: fortran/decl.c:620
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:664
+#: fortran/decl.c:662
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty old style initializer list at %C"
 msgstr ""
 
-#: fortran/decl.c:684
+#: fortran/decl.c:671
+#, gcc-internal-format, gfc-internal-format
+msgid "Array in initializer list at %L must have an explicit shape"
+msgstr ""
+
+#: fortran/decl.c:694
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Repeat spec invalid in scalar initializer at %C"
 msgstr "ακολουθούν σκουπίδια στο τέλος της γραμμής"
 
-#: fortran/decl.c:689
+#: fortran/decl.c:699
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Repeat spec must be an integer at %C"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: fortran/decl.c:698
+#: fortran/decl.c:710
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected data constant after repeat spec at %C"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: fortran/decl.c:729
+#: fortran/decl.c:742
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "End of scalar initializer expected at %C"
 msgstr "ακολουθούν σκουπίδια στο τέλος της γραμμής"
 
-#: fortran/decl.c:758
+#: fortran/decl.c:773
 #, gcc-internal-format, gfc-internal-format
-msgid "Expected constant array-spec in initializer list at %L"
-msgstr ""
-
-#: fortran/decl.c:767
-#, gcc-internal-format, gfc-internal-format
 msgid "Not enough elements in array initializer at %C"
 msgstr ""
 
-#: fortran/decl.c:769
+#: fortran/decl.c:775
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Too many elements in array initializer at %C"
 msgstr "υπερβολικά πολλά αρχεία εισόδου"
 
-#: fortran/decl.c:790
+#: fortran/decl.c:795
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in old style initializer list at %C"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: fortran/decl.c:812
+#: fortran/decl.c:821
 #, gcc-internal-format, gfc-internal-format
 msgid "The assumed-rank array at %C shall not have a codimension"
 msgstr ""
 
-#: fortran/decl.c:876
+#: fortran/decl.c:885
 #, gcc-internal-format, gfc-internal-format
 msgid "Sum of array rank %d and corank %d at %C exceeds maximum allowed dimensions of %d"
 msgstr ""
 
-#: fortran/decl.c:900
+#: fortran/decl.c:909
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad INTENT specification at %C"
 msgstr ""
 
-#: fortran/decl.c:921
+#: fortran/decl.c:930
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "deferred type parameter at %C"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: fortran/decl.c:1004 fortran/resolve.c:11705
+#: fortran/decl.c:1013 fortran/resolve.c:11725
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
 
-#: fortran/decl.c:1030
+#: fortran/decl.c:1039
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Old-style character length at %C"
 msgstr "κενό αλφαριθμητικό"
 
-#: fortran/decl.c:1061
+#: fortran/decl.c:1070
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in character length specification at %C"
 msgstr ""
 
-#: fortran/decl.c:1212 fortran/decl.c:1217 fortran/decl.c:1266
+#: fortran/decl.c:1221 fortran/decl.c:1226 fortran/decl.c:1275
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %C is already defined at %L"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: fortran/decl.c:1222
+#: fortran/decl.c:1231
 #, gcc-internal-format
 msgid "Contained procedure %qs at %C clashes with procedure defined at %L"
 msgstr ""
 
-#: fortran/decl.c:1231
+#: fortran/decl.c:1240
 #, gcc-internal-format
 msgid "Name %qs at %C is already defined as a generic interface at %L"
 msgstr ""
 
-#: fortran/decl.c:1244
+#: fortran/decl.c:1253
 #, gcc-internal-format
 msgid "Procedure %qs at %C has an explicit interface from a previous declaration"
 msgstr ""
 
-#: fortran/decl.c:1257
+#: fortran/decl.c:1266
 #, gcc-internal-format
 msgid "Procedure %qs defined in interface body at %L clashes with internal procedure defined at %C"
 msgstr ""
 
-#: fortran/decl.c:1335
+#: fortran/decl.c:1344
 #, gcc-internal-format
 msgid "Procedure %qs at %L must have the BIND(C) attribute to be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:1362
+#: fortran/decl.c:1371
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because derived type %qs is not C interoperable"
 msgstr ""
 
-#: fortran/decl.c:1369
+#: fortran/decl.c:1378
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because it is polymorphic"
 msgstr ""
 
-#: fortran/decl.c:1376
+#: fortran/decl.c:1385
 #, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument of the BIND(C) procedure %qs but may not be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:1391
+#: fortran/decl.c:1400
 #, gcc-internal-format
 msgid "Character argument %qs at %L must be length 1 because procedure %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1404
+#: fortran/decl.c:1413
 #, gcc-internal-format
 msgid "Variable %qs at %L with ALLOCATABLE attribute in procedure %qs with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1412
+#: fortran/decl.c:1421
 #, gcc-internal-format
 msgid "Variable %qs at %L with POINTER attribute in procedure %qs with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1421
+#: fortran/decl.c:1430
 #, gcc-internal-format
 msgid "Scalar variable %qs at %L with POINTER or ALLOCATABLE in procedure %qs with BIND(C) is not yet supported"
 msgstr ""
 
-#: fortran/decl.c:1430
+#: fortran/decl.c:1439
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the OPTIONAL and the VALUE attribute because procedure %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1437
+#: fortran/decl.c:1446
 #, gcc-internal-format
 msgid "Variable %qs at %L with OPTIONAL attribute in procedure %qs which is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1448
+#: fortran/decl.c:1457
 #, gcc-internal-format
 msgid "Assumed-shape array %qs at %L as dummy argument to the BIND(C) procedure %qs at %L"
 msgstr ""
 
-#: fortran/decl.c:1516
+#: fortran/decl.c:1525
 #, gcc-internal-format
 msgid "Symbol %qs at %C also declared as a type at %L"
 msgstr ""
 
-#: fortran/decl.c:1575
+#: fortran/decl.c:1584
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %C must be declared with a C interoperable kind since common block %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:1615
+#: fortran/decl.c:1624
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER length must be a constant at %L"
 msgstr ""
 
-#: fortran/decl.c:1630
+#: fortran/decl.c:1639
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression at %L is being truncated (%ld/%ld)"
 msgstr ""
 
-#: fortran/decl.c:1638
+#: fortran/decl.c:1647
 #, gcc-internal-format, gfc-internal-format
 msgid "The CHARACTER elements of the array constructor at %L must have the same length (%ld/%ld)"
 msgstr ""
 
-#: fortran/decl.c:1729
+#: fortran/decl.c:1738
 #, gcc-internal-format
 msgid "Initializer not allowed for PARAMETER %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:1739
+#: fortran/decl.c:1748
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER at %L is missing an initializer"
 msgstr "έχει παραληφθεί το αρχείο προορισμού"
 
-#: fortran/decl.c:1749
+#: fortran/decl.c:1758
 #, gcc-internal-format
 msgid "Variable %qs at %C with an initializer already appears in a DATA statement"
 msgstr ""
 
-#: fortran/decl.c:1792
+#: fortran/decl.c:1801
 #, gcc-internal-format, gfc-internal-format
 msgid "Cannot initialize parameter array at %L with variable length elements"
 msgstr ""
 
-#: fortran/decl.c:1861
+#: fortran/decl.c:1870
 #, gcc-internal-format, gfc-internal-format
 msgid "Can't initialize implied-shape array at %L with scalar"
 msgstr ""
 
-#: fortran/decl.c:1896
+#: fortran/decl.c:1905
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-constant lower bound in implied-shape declaration at %L"
 msgstr ""
 
-#: fortran/decl.c:1982 fortran/decl.c:1989
+#: fortran/decl.c:1991 fortran/decl.c:1998
 #, gcc-internal-format, gfc-internal-format
 msgid "Component at %C must have the POINTER attribute"
 msgstr ""
 
-#: fortran/decl.c:1998
+#: fortran/decl.c:2007
 #, gcc-internal-format
 msgid "Component %qs with CLASS at %C must be allocatable or pointer"
 msgstr ""
 
-#: fortran/decl.c:2007
+#: fortran/decl.c:2016
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr ""
 
-#: fortran/decl.c:2031 fortran/symbol.c:2230
+#: fortran/decl.c:2040 fortran/symbol.c:2244
 #, gcc-internal-format
 msgid "Component %qs at %C already declared at %L"
 msgstr ""
 
-#: fortran/decl.c:2079
+#: fortran/decl.c:2088
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer array component of structure at %C must have a deferred shape"
 msgstr ""
 
-#: fortran/decl.c:2088
+#: fortran/decl.c:2097
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component of structure at %C must have a deferred shape"
 msgstr ""
 
-#: fortran/decl.c:2097
+#: fortran/decl.c:2106
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have an explicit shape"
 msgstr ""
 
-#: fortran/decl.c:2114
+#: fortran/decl.c:2123
 #, gcc-internal-format
 msgid "Type parameter %qs at %C has no corresponding entry in the type parameter name list at %L"
 msgstr ""
 
-#: fortran/decl.c:2171
+#: fortran/decl.c:2180
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C is ambiguous"
 msgstr ""
 
-#: fortran/decl.c:2188
+#: fortran/decl.c:2197
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C may not have MOLD"
 msgstr ""
 
-#: fortran/decl.c:2205
+#: fortran/decl.c:2214
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of pointer at %C is not allowed in a PURE procedure"
 msgstr ""
 
 # src/request.c:263
-#: fortran/decl.c:2226
+#: fortran/decl.c:2235
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Error in pointer initialization at %C"
 msgstr "Το βήμα αρχικοποίησης απέτυχε"
 
 # src/request.c:263
-#: fortran/decl.c:2233
+#: fortran/decl.c:2242
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "non-NULL pointer initialization at %C"
 msgstr "Το βήμα αρχικοποίησης απέτυχε"
 
-#: fortran/decl.c:2256
+#: fortran/decl.c:2265
 #, gcc-internal-format
 msgid "RESULT variable %qs at %L prohibits FUNCTION name %qs at %C from appearing in a specification statement"
 msgstr ""
 
-#: fortran/decl.c:2318
+#: fortran/decl.c:2327
 #, gcc-internal-format
 msgid "%qs not allowed outside STRUCTURE at %C"
 msgstr ""
 
-#: fortran/decl.c:2320
+#: fortran/decl.c:2329
 #, gcc-internal-format
 msgid "%qs at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr ""
 
-#: fortran/decl.c:2327
+#: fortran/decl.c:2336
 #, gcc-internal-format
 msgid "%qs entity cannot have attributes at %C"
 msgstr ""
 
-#: fortran/decl.c:2367
+#: fortran/decl.c:2376
 #, gcc-internal-format
 msgid "Non-PARAMETER symbol %qs at %L can't be implied-shape"
 msgstr ""
 
-#: fortran/decl.c:2377
+#: fortran/decl.c:2386
 #, gcc-internal-format, gfc-internal-format
 msgid "Implied-shape array at %L"
 msgstr ""
 
-#: fortran/decl.c:2422
+#: fortran/decl.c:2431
 #, gcc-internal-format, gfc-internal-format
 msgid "Explicit shaped array with nonconstant bounds at %C"
 msgstr ""
 
-#: fortran/decl.c:2501
+#: fortran/decl.c:2510
 #, gcc-internal-format
 msgid "%qs at %C is a redefinition of the declaration in the corresponding interface for MODULE PROCEDURE %qs"
 msgstr ""
 
-#: fortran/decl.c:2512
+#: fortran/decl.c:2521
 #, fuzzy, gcc-internal-format
 msgid "%qs entity cannot have an initializer at %C"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: fortran/decl.c:2538 fortran/decl.c:8369
+#: fortran/decl.c:2547 fortran/decl.c:8388
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr ""
 
-#: fortran/decl.c:2546
+#: fortran/decl.c:2555
 #, gcc-internal-format
 msgid "Couldn't set pointee array spec."
 msgstr ""
 
 # src/request.c:263
-#: fortran/decl.c:2609
+#: fortran/decl.c:2618
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Old-style initialization at %C"
 msgstr "Το βήμα αρχικοποίησης απέτυχε"
 
-#: fortran/decl.c:2617
+#: fortran/decl.c:2626
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr ""
 
-#: fortran/decl.c:2630
+#: fortran/decl.c:2639
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in old style initialization of %s at %C"
 msgstr ""
 
-#: fortran/decl.c:2650 fortran/decl.c:6661
+#: fortran/decl.c:2659 fortran/decl.c:6680
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr "%s μετατρέπει ακέραιο σε δείκτη χωρίς μετατροπέα"
 
-#: fortran/decl.c:2663
+#: fortran/decl.c:2672
 #, gcc-internal-format
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr ""
 
-#: fortran/decl.c:2672 fortran/decl.c:10240
+#: fortran/decl.c:2681 fortran/decl.c:10265
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
-#: fortran/decl.c:2679
+#: fortran/decl.c:2688
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr ""
 
-#: fortran/decl.c:2696
+#: fortran/decl.c:2705
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr ""
 
-#: fortran/decl.c:2710
+#: fortran/decl.c:2719
 #, gcc-internal-format, gfc-internal-format
 msgid "The component with KIND or LEN attribute at %C does not not appear in the type parameter list at %L"
 msgstr ""
 
-#: fortran/decl.c:2718
+#: fortran/decl.c:2727
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C that appears in the type parameter list at %L has neither the KIND nor LEN attribute"
 msgstr ""
 
-#: fortran/decl.c:2726
+#: fortran/decl.c:2735
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C which is a type parameter must be a scalar"
 msgstr ""
 
-#: fortran/decl.c:2789 fortran/decl.c:2825
+#: fortran/decl.c:2798 fortran/decl.c:2834
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr "Η λειτουργία δεν υποστηρίζεται"
 
-#: fortran/decl.c:2831
+#: fortran/decl.c:2840
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: fortran/decl.c:2890 fortran/decl.c:2967
+#: fortran/decl.c:2899 fortran/decl.c:2976
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis at %C"
 msgstr "ορισμός δικαιωμάτων στο %s"
 
-#: fortran/decl.c:2903 fortran/decl.c:3038
+#: fortran/decl.c:2912 fortran/decl.c:3047
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
-#: fortran/decl.c:2911 fortran/decl.c:3044
+#: fortran/decl.c:2920 fortran/decl.c:3053
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr ""
 
-#: fortran/decl.c:2941 fortran/decl.c:3657
+#: fortran/decl.c:2950 fortran/decl.c:3676
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr "Το servname δεν υποστηρίζεται από το ai_socktype"
 
-#: fortran/decl.c:2954
+#: fortran/decl.c:2963
 #, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr ""
 
-#: fortran/decl.c:2965
+#: fortran/decl.c:2974
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr ""
 
-#: fortran/decl.c:3070
+#: fortran/decl.c:3079
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr "Το servname δεν υποστηρίζεται από το ai_socktype"
 
-#: fortran/decl.c:3202
+#: fortran/decl.c:3211
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr "συντακτικό σφάλμα στο ορισμό του %s: %s"
 
-#: fortran/decl.c:3291
+#: fortran/decl.c:3310
 #, gcc-internal-format, gfc-internal-format
 msgid "RECORD at %C is an extension, enable it with -fdec-structure"
 msgstr ""
 
-#: fortran/decl.c:3304
+#: fortran/decl.c:3323
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected after RECORD at %C"
 msgstr ""
 
-#: fortran/decl.c:3417
+#: fortran/decl.c:3436
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C cannot contain both ASSUMED and DEFERRED parameters"
 msgstr ""
 
-#: fortran/decl.c:3441
+#: fortran/decl.c:3460
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C does not contain enough parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3465
+#: fortran/decl.c:3484
 #, gcc-internal-format
 msgid "The derived parameter %qs at %C does not have a default value"
 msgstr ""
 
-#: fortran/decl.c:3497
+#: fortran/decl.c:3516
 #, gcc-internal-format, gfc-internal-format
 msgid "The parameter expression at %C must be of INTEGER type and not %s type"
 msgstr ""
 
-#: fortran/decl.c:3525
+#: fortran/decl.c:3544
 #, gcc-internal-format
 msgid "The KIND parameter %qs at %C cannot either be ASSUMED or DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:3532
+#: fortran/decl.c:3551
 #, gcc-internal-format
 msgid "The value for the KIND parameter %qs at %C does not reduce to a constant expression"
 msgstr ""
 
-#: fortran/decl.c:3547
+#: fortran/decl.c:3566
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C contains too many parameter expressions"
 msgstr ""
@@ -52493,38 +52560,38 @@
 
 # src/getopt.c:628
 # src/getopt.c:628
-#: fortran/decl.c:3556
+#: fortran/decl.c:3575
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Parameterized derived type at %C is ambiguous"
 msgstr "%s: η επιλογή `%s' είναι ασαφής\n"
 
-#: fortran/decl.c:3819
+#: fortran/decl.c:3838
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type at %C"
 msgstr ""
 
-#: fortran/decl.c:3824
+#: fortran/decl.c:3843
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr ""
 
-#: fortran/decl.c:3846
+#: fortran/decl.c:3865
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C is not allowed for components"
 msgstr ""
 
-#: fortran/decl.c:3849
+#: fortran/decl.c:3868
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr ""
 
-#: fortran/decl.c:3872 fortran/decl.c:3903 fortran/decl.c:3932
-#: fortran/decl.c:4216
+#: fortran/decl.c:3891 fortran/decl.c:3922 fortran/decl.c:3951
+#: fortran/decl.c:4235
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr ""
 
-#: fortran/decl.c:3928
+#: fortran/decl.c:3947
 #, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr ""
@@ -52531,243 +52598,243 @@
 
 # src/getopt.c:628
 # src/getopt.c:628
-#: fortran/decl.c:3971 fortran/decl.c:4107 fortran/decl.c:4119
-#: fortran/decl.c:4133 fortran/decl.c:4611 fortran/decl.c:4619
+#: fortran/decl.c:3990 fortran/decl.c:4126 fortran/decl.c:4138
+#: fortran/decl.c:4152 fortran/decl.c:4630 fortran/decl.c:4638
 #, fuzzy, gcc-internal-format
 msgid "Type name %qs at %C is ambiguous"
 msgstr "%s: η επιλογή `%s' είναι ασαφής\n"
 
-#: fortran/decl.c:4066
+#: fortran/decl.c:4085
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4148
+#: fortran/decl.c:4167
 #, gcc-internal-format
 msgid "Type name %qs at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr ""
 
-#: fortran/decl.c:4287
+#: fortran/decl.c:4306
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4296
+#: fortran/decl.c:4315
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr ""
 
-#: fortran/decl.c:4355
+#: fortran/decl.c:4374
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr ""
 
-#: fortran/decl.c:4401
+#: fortran/decl.c:4420
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4454
+#: fortran/decl.c:4473
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr ""
 
-#: fortran/decl.c:4464
+#: fortran/decl.c:4483
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4570
+#: fortran/decl.c:4589
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr ""
 
-#: fortran/decl.c:4577
+#: fortran/decl.c:4596
 #, gcc-internal-format, gfc-internal-format
 msgid "F2008: C1210 IMPORT statement at %C is not permitted in a module procedure interface body"
 msgstr ""
 
-#: fortran/decl.c:4582
+#: fortran/decl.c:4601
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C"
 msgstr ""
 
-#: fortran/decl.c:4596
+#: fortran/decl.c:4615
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr ""
 
-#: fortran/decl.c:4625
+#: fortran/decl.c:4644
 #, gcc-internal-format
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr ""
 
-#: fortran/decl.c:4632
+#: fortran/decl.c:4651
 #, gcc-internal-format
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr ""
 
-#: fortran/decl.c:4673
+#: fortran/decl.c:4692
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IMPORT statement at %C"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: fortran/decl.c:5010
+#: fortran/decl.c:5029
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing codimension specification at %C"
 msgstr ""
 
-#: fortran/decl.c:5012
+#: fortran/decl.c:5031
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr "έχει παραληφθεί το αρχείο προορισμού"
 
-#: fortran/decl.c:5107
+#: fortran/decl.c:5126
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: fortran/decl.c:5124
+#: fortran/decl.c:5143
 #, gcc-internal-format
 msgid "%s at %L is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:5141
+#: fortran/decl.c:5160
 #, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5150
+#: fortran/decl.c:5169
 #, gcc-internal-format, gfc-internal-format
 msgid "KIND attribute at %C in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5158
+#: fortran/decl.c:5177
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be INTEGER"
 msgstr ""
 
-#: fortran/decl.c:5165
+#: fortran/decl.c:5184
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5174
+#: fortran/decl.c:5193
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LEN attribute at %C in a TYPE definition"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: fortran/decl.c:5182
+#: fortran/decl.c:5201
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be INTEGER"
 msgstr ""
 
-#: fortran/decl.c:5189
+#: fortran/decl.c:5208
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5198
+#: fortran/decl.c:5217
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5216
+#: fortran/decl.c:5235
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5226
+#: fortran/decl.c:5245
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:5236
+#: fortran/decl.c:5255
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed outside a TYPE definition"
 msgstr ""
 
-#: fortran/decl.c:5249
+#: fortran/decl.c:5268
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5260
+#: fortran/decl.c:5279
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5315 fortran/decl.c:8673
+#: fortran/decl.c:5334 fortran/decl.c:8692
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:5321
+#: fortran/decl.c:5340
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5355
+#: fortran/decl.c:5374
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5362
+#: fortran/decl.c:5381
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:5369
+#: fortran/decl.c:5388
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr ""
 
-#: fortran/decl.c:5410
+#: fortran/decl.c:5429
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:5508
+#: fortran/decl.c:5527
 #, gcc-internal-format
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/decl.c:5530
+#: fortran/decl.c:5549
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5539
+#: fortran/decl.c:5558
 #, gcc-internal-format
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5543
+#: fortran/decl.c:5562
 #, gcc-internal-format
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:5555
+#: fortran/decl.c:5574
 #, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr ""
 
-#: fortran/decl.c:5569
+#: fortran/decl.c:5588
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr ""
 
-#: fortran/decl.c:5577
+#: fortran/decl.c:5596
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr ""
 
-#: fortran/decl.c:5589
+#: fortran/decl.c:5608
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr ""
 
-#: fortran/decl.c:5597
+#: fortran/decl.c:5616
 #, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be a character string"
 msgstr ""
@@ -52774,952 +52841,957 @@
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:5608
+#: fortran/decl.c:5627
 #, gcc-internal-format
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr ""
 
-#: fortran/decl.c:5682
+#: fortran/decl.c:5701
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5727
+#: fortran/decl.c:5746
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5734
+#: fortran/decl.c:5753
 #, fuzzy, gcc-internal-format
 msgid "Missing symbol"
 msgstr "Έχει παραληφθεί εντολή"
 
-#: fortran/decl.c:5763
+#: fortran/decl.c:5782
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) statement at %C"
 msgstr ""
 
-#: fortran/decl.c:5850
+#: fortran/decl.c:5869
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr ""
 
-#: fortran/decl.c:5892
+#: fortran/decl.c:5911
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in anonymous structure declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:5901
+#: fortran/decl.c:5920
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr "συντακτικό σφάλμα στον καθορισμό σειράς"
 
-#: fortran/decl.c:5951
+#: fortran/decl.c:5970
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C"
 msgstr ""
 
-#: fortran/decl.c:5996
+#: fortran/decl.c:6015
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPURE procedure at %C"
 msgstr ""
 
-#: fortran/decl.c:6008
+#: fortran/decl.c:6027
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr ""
 
-#: fortran/decl.c:6054
+#: fortran/decl.c:6073
 #, gcc-internal-format, gfc-internal-format
 msgid "ELEMENTAL prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6061
+#: fortran/decl.c:6080
 #, gcc-internal-format, gfc-internal-format
 msgid "PURE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6068
+#: fortran/decl.c:6087
 #, gcc-internal-format, gfc-internal-format
 msgid "RECURSIVE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6134 fortran/primary.c:1820
+#: fortran/decl.c:6153 fortran/primary.c:1820
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate-return argument at %C"
 msgstr ""
 
-#: fortran/decl.c:6140 fortran/decl.c:6148
+#: fortran/decl.c:6159 fortran/decl.c:6167
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "A parameter name is required at %C"
 msgstr "έχει παραληφθεί το όνομα της παραμέτρου"
 
-#: fortran/decl.c:6188
+#: fortran/decl.c:6207
 #, gcc-internal-format
 msgid "Name %qs at %C is the name of the procedure"
 msgstr ""
 
-#: fortran/decl.c:6201
+#: fortran/decl.c:6220
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected parameter list in type declaration at %C"
 msgstr "Προειδοποίηση: Πολύ λίγα ορίσματα στο εσωδομημένο `%s'"
 
-#: fortran/decl.c:6204
+#: fortran/decl.c:6223
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr ""
 
-#: fortran/decl.c:6222
+#: fortran/decl.c:6241
 #, fuzzy, gcc-internal-format
 msgid "Duplicate name %qs in parameter list at %C"
 msgstr "Ελλιπής ή κακοσχηματισμένη ιδιότητα"
 
-#: fortran/decl.c:6225
+#: fortran/decl.c:6244
 #, gcc-internal-format
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr ""
 
-#: fortran/decl.c:6264
+#: fortran/decl.c:6283
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in MODULE PROCEDURE formal argument names (%s/%s) at %C"
 msgstr ""
 
-#: fortran/decl.c:6270
+#: fortran/decl.c:6289
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in number of MODULE PROCEDURE formal arguments at %C"
 msgstr ""
 
-#: fortran/decl.c:6309
+#: fortran/decl.c:6328
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr ""
 
-#: fortran/decl.c:6386
+#: fortran/decl.c:6405
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: fortran/decl.c:6396 fortran/decl.c:7494
+#: fortran/decl.c:6415 fortran/decl.c:7513
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: fortran/decl.c:6600
+#: fortran/decl.c:6619
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:6607
+#: fortran/decl.c:6626
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:6613
+#: fortran/decl.c:6632
 #, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr ""
 
-#: fortran/decl.c:6636
+#: fortran/decl.c:6655
 #, gcc-internal-format
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr ""
 
-#: fortran/decl.c:6682 fortran/decl.c:6870 fortran/decl.c:10723
+#: fortran/decl.c:6701 fortran/decl.c:6889 fortran/decl.c:10748
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6731 fortran/decl.c:10623
+#: fortran/decl.c:6750 fortran/decl.c:10648
 #, gcc-internal-format
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr ""
 
-#: fortran/decl.c:6738
+#: fortran/decl.c:6757
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr ""
 
-#: fortran/decl.c:6742
+#: fortran/decl.c:6761
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:6814
+#: fortran/decl.c:6833
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in procedure pointer component at %C"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: fortran/decl.c:6832
+#: fortran/decl.c:6851
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr ""
 
-#: fortran/decl.c:6841 fortran/decl.c:9392
+#: fortran/decl.c:6860 fortran/decl.c:9411
 #, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr ""
 
-#: fortran/decl.c:6911
+#: fortran/decl.c:6930
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:6983
+#: fortran/decl.c:7002
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr ""
 
-#: fortran/decl.c:7007 fortran/decl.c:7011 fortran/decl.c:7266
-#: fortran/decl.c:7270 fortran/decl.c:7462 fortran/decl.c:7466
-#: fortran/symbol.c:1875
+#: fortran/decl.c:7026 fortran/decl.c:7030 fortran/decl.c:7285
+#: fortran/decl.c:7289 fortran/decl.c:7481 fortran/decl.c:7485
+#: fortran/symbol.c:1889
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr ""
 
-#: fortran/decl.c:7164
+#: fortran/decl.c:7183
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7173
+#: fortran/decl.c:7192
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr ""
 
-#: fortran/decl.c:7176
+#: fortran/decl.c:7195
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr ""
 
-#: fortran/decl.c:7179
+#: fortran/decl.c:7198
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SUBMODULE"
 msgstr ""
 
-#: fortran/decl.c:7182
+#: fortran/decl.c:7201
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr ""
 
-#: fortran/decl.c:7186 fortran/decl.c:7231
+#: fortran/decl.c:7205 fortran/decl.c:7250
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr ""
 
-#: fortran/decl.c:7190
+#: fortran/decl.c:7209
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a STRUCTURE block"
 msgstr ""
 
-#: fortran/decl.c:7194
+#: fortran/decl.c:7213
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr ""
 
-#: fortran/decl.c:7198
+#: fortran/decl.c:7217
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr ""
 
-#: fortran/decl.c:7203
+#: fortran/decl.c:7222
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr ""
 
-#: fortran/decl.c:7207
+#: fortran/decl.c:7226
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr ""
 
-#: fortran/decl.c:7211
+#: fortran/decl.c:7230
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr ""
 
-#: fortran/decl.c:7215
+#: fortran/decl.c:7234
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr ""
 
-#: fortran/decl.c:7219
+#: fortran/decl.c:7238
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr ""
 
-#: fortran/decl.c:7223
+#: fortran/decl.c:7242
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected ENTRY statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7244
+#: fortran/decl.c:7263
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: fortran/decl.c:7295 fortran/decl.c:7501
+#: fortran/decl.c:7314 fortran/decl.c:7520
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7563 fortran/decl.c:7570
+#: fortran/decl.c:7582 fortran/decl.c:7589
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:7610
+#: fortran/decl.c:7629
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr ""
 
-#: fortran/decl.c:7626
+#: fortran/decl.c:7645
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: fortran/decl.c:7634
+#: fortran/decl.c:7653
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr ""
 
-#: fortran/decl.c:7653
+#: fortran/decl.c:7672
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing closing paren for binding label at %C"
 msgstr "Αγνωστος δυαδικός χειριστής."
 
-#: fortran/decl.c:7659
+#: fortran/decl.c:7678
 #, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7665
+#: fortran/decl.c:7684
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr ""
 
-#: fortran/decl.c:7694
+#: fortran/decl.c:7713
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr ""
 
-#: fortran/decl.c:7939
+#: fortran/decl.c:7958
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr ""
 
-#: fortran/decl.c:7948
+#: fortran/decl.c:7967
 #, gcc-internal-format, gfc-internal-format
 msgid "END statement instead of %s statement at %L"
 msgstr ""
 
 #. We would have required END [something].
-#: fortran/decl.c:7957
+#: fortran/decl.c:7976
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr ""
 
-#: fortran/decl.c:7968
+#: fortran/decl.c:7987
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s statement at %L"
 msgstr ""
 
-#: fortran/decl.c:7988
+#: fortran/decl.c:8007
 #, gcc-internal-format
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr ""
 
-#: fortran/decl.c:8005
+#: fortran/decl.c:8024
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr ""
 
-#: fortran/decl.c:8019 fortran/decl.c:8027
+#: fortran/decl.c:8038 fortran/decl.c:8046
 #, gcc-internal-format
 msgid "Expected label %qs for %s statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8126
+#: fortran/decl.c:8145
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr ""
 
-#: fortran/decl.c:8134
+#: fortran/decl.c:8153
 #, gcc-internal-format, gfc-internal-format
 msgid "Dimensions specified for %s at %L after its initialization"
 msgstr ""
 
-#: fortran/decl.c:8142
+#: fortran/decl.c:8161
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr ""
 
-#: fortran/decl.c:8151
+#: fortran/decl.c:8170
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr ""
 
-#: fortran/decl.c:8249
+#: fortran/decl.c:8268
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr ""
 
-#: fortran/decl.c:8286
+#: fortran/decl.c:8305
 #, gcc-internal-format
 msgid "Expected %<(%> at %C"
 msgstr ""
 
-#: fortran/decl.c:8300 fortran/decl.c:8340
+#: fortran/decl.c:8319 fortran/decl.c:8359
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: fortran/decl.c:8316
+#: fortran/decl.c:8335
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C must be an integer"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: fortran/decl.c:8320
+#: fortran/decl.c:8339
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr ""
 
-#: fortran/decl.c:8326
+#: fortran/decl.c:8345
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr ""
 
-#: fortran/decl.c:8365
+#: fortran/decl.c:8384
 #, gcc-internal-format
 msgid "Couldn't set Cray pointee array spec."
 msgstr ""
 
-#: fortran/decl.c:8389
+#: fortran/decl.c:8408
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr ""
 
-#: fortran/decl.c:8401
+#: fortran/decl.c:8420
 #, gcc-internal-format
 msgid "Expected %<,%> or end of statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8427
+#: fortran/decl.c:8446
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:8459
+#: fortran/decl.c:8478
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:8478
+#: fortran/decl.c:8497
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer declaration at %C requires -fcray-pointer flag"
 msgstr ""
 
-#: fortran/decl.c:8517
+#: fortran/decl.c:8536
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8623
+#: fortran/decl.c:8642
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:8640
+#: fortran/decl.c:8659
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr ""
 
-#: fortran/decl.c:8679
+#: fortran/decl.c:8698
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8717
+#: fortran/decl.c:8736
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8741
+#: fortran/decl.c:8760
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:8778
+#: fortran/decl.c:8797
 #, gcc-internal-format, gfc-internal-format
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:8806
+#: fortran/decl.c:8825
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr ""
 
-#: fortran/decl.c:8813
+#: fortran/decl.c:8832
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8819
+#: fortran/decl.c:8838
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr ""
 
-#: fortran/decl.c:8839
+#: fortran/decl.c:8858
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Initializing already initialized variable at %C"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
 #. With legacy PARAMETER statements, don't expect a terminating ')'.
-#: fortran/decl.c:8864
+#: fortran/decl.c:8883
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER without '()' at %C"
 msgstr ""
 
-#: fortran/decl.c:8880
+#: fortran/decl.c:8899
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8899 fortran/decl.c:8955
+#: fortran/decl.c:8918 fortran/decl.c:8974
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:8934
+#: fortran/decl.c:8953
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in AUTOMATIC statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8941
+#: fortran/decl.c:8960
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in AUTOMATIC statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8990
+#: fortran/decl.c:9009
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected entity-list in STATIC statement at %C"
 msgstr ""
 
-#: fortran/decl.c:8997
+#: fortran/decl.c:9016
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in STATIC statement at %C"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: fortran/decl.c:9016
+#: fortran/decl.c:9035
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:9027
+#: fortran/decl.c:9046
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr ""
 
-#: fortran/decl.c:9073
+#: fortran/decl.c:9092
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr "συντακτικό σφάλμα στον καθορισμό σειράς"
 
-#: fortran/decl.c:9087
+#: fortran/decl.c:9106
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/decl.c:9091
+#: fortran/decl.c:9110
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9129
+#: fortran/decl.c:9148
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VALUE statement at %C"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: fortran/decl.c:9141
+#: fortran/decl.c:9160
 #, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9168
+#: fortran/decl.c:9187
 #, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr ""
 
-#: fortran/decl.c:9193
+#: fortran/decl.c:9212
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9205
+#: fortran/decl.c:9224
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9249
+#: fortran/decl.c:9268
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9274
+#: fortran/decl.c:9293
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:9367
+#: fortran/decl.c:9386
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr ""
 
-#: fortran/decl.c:9425
+#: fortran/decl.c:9444
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr ""
 
-#: fortran/decl.c:9474
+#: fortran/decl.c:9493
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr ""
 
-#: fortran/decl.c:9483
+#: fortran/decl.c:9502
 #, gcc-internal-format
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr ""
 
-#: fortran/decl.c:9489
+#: fortran/decl.c:9508
 #, gcc-internal-format
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr ""
 
-#: fortran/decl.c:9496
+#: fortran/decl.c:9515
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr ""
 
-#: fortran/decl.c:9503
+#: fortran/decl.c:9522
 #, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr ""
 
-#: fortran/decl.c:9526
+#: fortran/decl.c:9545
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:9538
+#: fortran/decl.c:9557
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr ""
 
-#: fortran/decl.c:9559
+#: fortran/decl.c:9578
 #, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
 msgstr ""
 
-#: fortran/decl.c:9605
+#: fortran/decl.c:9624
 #, gcc-internal-format, gfc-internal-format
 msgid "Failed to create structure type '%s' at %C"
 msgstr ""
 
-#: fortran/decl.c:9611
+#: fortran/decl.c:9630
 #, gcc-internal-format
 msgid "Type definition of %qs at %C was already defined at %L"
 msgstr ""
 
-#: fortran/decl.c:9658
+#: fortran/decl.c:9677
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after MAP statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9691
+#: fortran/decl.c:9710
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after UNION statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9726
+#: fortran/decl.c:9745
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr ""
 
-#: fortran/decl.c:9740
+#: fortran/decl.c:9759
 #, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected in non-nested structure declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:9758
+#: fortran/decl.c:9777
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after non-nested STRUCTURE statement at %C"
 msgstr ""
 
-#: fortran/decl.c:9765
+#: fortran/decl.c:9784
 #, gcc-internal-format
 msgid "Structure name %qs at %C cannot be the same as an intrinsic type"
 msgstr ""
 
-#: fortran/decl.c:9926
+#: fortran/decl.c:9947
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr ""
 
-#: fortran/decl.c:9954
+#: fortran/decl.c:9975
 #, gcc-internal-format
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr ""
 
-#: fortran/decl.c:9964
+#: fortran/decl.c:9986
 #, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr ""
 
-#: fortran/decl.c:9981
+#: fortran/decl.c:9989
 #, gcc-internal-format
+msgid "Derived type name %qs at %C already has a basic type"
+msgstr ""
+
+#: fortran/decl.c:10006
+#, gcc-internal-format
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr ""
 
-#: fortran/decl.c:10042
+#: fortran/decl.c:10067
 #, gcc-internal-format, gfc-internal-format
 msgid "Garbage after PARAMETERIZED TYPE declaration at %C"
 msgstr ""
 
-#: fortran/decl.c:10126
+#: fortran/decl.c:10151
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr ""
 
-#: fortran/decl.c:10146
+#: fortran/decl.c:10171
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM and ENUMERATOR at %C"
 msgstr ""
 
-#: fortran/decl.c:10178
+#: fortran/decl.c:10203
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr ""
 
-#: fortran/decl.c:10257
+#: fortran/decl.c:10282
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr ""
 
-#: fortran/decl.c:10305
+#: fortran/decl.c:10330
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr "Εγγραφή ονομάτων των επιλεγμένων κατηγοριών"
 
-#: fortran/decl.c:10341
+#: fortran/decl.c:10366
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr "συντακτικό σφάλμα στο ορισμό του %s: %s"
 
-#: fortran/decl.c:10388 fortran/decl.c:10403
+#: fortran/decl.c:10413 fortran/decl.c:10428
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate access-specifier at %C"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: fortran/decl.c:10423
+#: fortran/decl.c:10448
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10443
+#: fortran/decl.c:10468
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr ""
 
-#: fortran/decl.c:10470
+#: fortran/decl.c:10495
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate POINTER attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:10488
+#: fortran/decl.c:10513
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr ""
 
-#: fortran/decl.c:10504
+#: fortran/decl.c:10529
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DEFERRED at %C"
 msgstr ""
 
-#: fortran/decl.c:10517
+#: fortran/decl.c:10542
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected access-specifier at %C"
 msgstr ""
 
-#: fortran/decl.c:10519
+#: fortran/decl.c:10544
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr ""
 
-#: fortran/decl.c:10527
+#: fortran/decl.c:10552
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED can't both appear at %C"
 msgstr ""
 
-#: fortran/decl.c:10539
+#: fortran/decl.c:10564
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr ""
 
-#: fortran/decl.c:10581
+#: fortran/decl.c:10606
 #, gcc-internal-format
 msgid "Interface-name expected after %<(%> at %C"
 msgstr ""
 
-#: fortran/decl.c:10587
+#: fortran/decl.c:10612
 #, fuzzy, gcc-internal-format
 #| msgid "')' expected"
 msgid "%<)%> expected at %C"
 msgstr "αναμενόταν '('"
 
-#: fortran/decl.c:10607
+#: fortran/decl.c:10632
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:10612
+#: fortran/decl.c:10637
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:10635
+#: fortran/decl.c:10660
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr ""
 
-#: fortran/decl.c:10639
+#: fortran/decl.c:10664
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
 msgstr ""
 
-#: fortran/decl.c:10651
+#: fortran/decl.c:10676
 #, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr ""
 
-#: fortran/decl.c:10657
+#: fortran/decl.c:10682
 #, gcc-internal-format
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr ""
 
-#: fortran/decl.c:10667
+#: fortran/decl.c:10692
 #, gcc-internal-format
 msgid "Expected binding target after %<=>%> at %C"
 msgstr ""
 
-#: fortran/decl.c:10684
+#: fortran/decl.c:10709
 #, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr ""
 
-#: fortran/decl.c:10695
+#: fortran/decl.c:10720
 #, gcc-internal-format
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:10746
+#: fortran/decl.c:10771
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr ""
 
-#: fortran/decl.c:10766
+#: fortran/decl.c:10791
 #, gcc-internal-format
 msgid "Expected %<::%> at %C"
 msgstr ""
 
-#: fortran/decl.c:10778
+#: fortran/decl.c:10803
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected generic name or operator descriptor at %C"
 msgstr ""
 
-#: fortran/decl.c:10799
+#: fortran/decl.c:10824
 #, gcc-internal-format, gfc-internal-format
 msgid "Malformed GENERIC statement at %C"
 msgstr ""
 
-#: fortran/decl.c:10810
+#: fortran/decl.c:10835
 #, gcc-internal-format
 msgid "Expected %<=>%> at %C"
 msgstr ""
 
-#: fortran/decl.c:10846
+#: fortran/decl.c:10871
 #, gcc-internal-format
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:10854
+#: fortran/decl.c:10879
 #, gcc-internal-format
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr ""
 
-#: fortran/decl.c:10902
+#: fortran/decl.c:10927
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr ""
 
-#: fortran/decl.c:10912
+#: fortran/decl.c:10937
 #, gcc-internal-format
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr ""
 
-#: fortran/decl.c:10930
+#: fortran/decl.c:10955
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr ""
 
-#: fortran/decl.c:10965
+#: fortran/decl.c:10990
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr ""
 
-#: fortran/decl.c:10976
+#: fortran/decl.c:11001
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr ""
 
-#: fortran/decl.c:10998
+#: fortran/decl.c:11023
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr ""
 
-#: fortran/decl.c:11005
+#: fortran/decl.c:11030
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr ""
 
-#: fortran/decl.c:11015
+#: fortran/decl.c:11040
 #, gcc-internal-format
 msgid "Expected %<,%> at %C"
 msgstr ""
 
-#: fortran/decl.c:11021
+#: fortran/decl.c:11046
 #, fuzzy, gcc-internal-format
 msgid "Unknown procedure name %qs at %C"
 msgstr "άγνωστος χαρακτήρας στο πεδίο `%s' της κατηγορίας `%s'"
 
-#: fortran/decl.c:11034
+#: fortran/decl.c:11059
 #, fuzzy, gcc-internal-format
 msgid "%qs at %C is already defined as FINAL procedure"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: fortran/decl.c:11104
+#: fortran/decl.c:11129
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr ""
 
-#: fortran/decl.c:11150
+#: fortran/decl.c:11175
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr ""
 
-#: fortran/decl.c:11170
+#: fortran/decl.c:11195
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive requires a non-negative integral constant less than or equal to %u at %C"
 msgstr ""
 
-#: fortran/decl.c:11184
+#: fortran/decl.c:11209
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ UNROLL directive at %C"
 msgstr ""
@@ -54056,27 +54128,27 @@
 msgid "BOZ literal at %L used to initialize non-integer variable %qs"
 msgstr ""
 
-#: fortran/expr.c:3369 fortran/resolve.c:10197
+#: fortran/expr.c:3369 fortran/resolve.c:10210
 #, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal at %L outside a DATA statement and outside INT/REAL/DBLE/CMPLX"
 msgstr ""
 
-#: fortran/expr.c:3380 fortran/resolve.c:10208
+#: fortran/expr.c:3380 fortran/resolve.c:10221
 #, gcc-internal-format
 msgid "BOZ literal at %L is bitwise transferred non-integer symbol %qs"
 msgstr ""
 
-#: fortran/expr.c:3388 fortran/resolve.c:10217
+#: fortran/expr.c:3388 fortran/resolve.c:10230
 #, gcc-internal-format
 msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3392 fortran/resolve.c:10221
+#: fortran/expr.c:3392 fortran/resolve.c:10234
 #, gcc-internal-format
 msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
 
-#: fortran/expr.c:3396 fortran/resolve.c:10225
+#: fortran/expr.c:3396 fortran/resolve.c:10238
 #, gcc-internal-format
 msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr ""
@@ -54086,147 +54158,147 @@
 msgid "The assignment to a KIND or LEN component of a parameterized type at %L is not allowed"
 msgstr ""
 
-#: fortran/expr.c:3426
+#: fortran/expr.c:3429
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Incompatible types in DATA statement at %L; attempted conversion of %s to %s"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: fortran/expr.c:3465
+#: fortran/expr.c:3468
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is not a POINTER at %L"
 msgstr ""
 
-#: fortran/expr.c:3473
+#: fortran/expr.c:3476
 #, gcc-internal-format
 msgid "%qs in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgstr ""
 
-#: fortran/expr.c:3496
+#: fortran/expr.c:3499
 #, fuzzy, gcc-internal-format
 msgid "Expected bounds specification for %qs at %L"
 msgstr "%s: Μη έγκυρη ρύθμιση `%s'.\n"
 
-#: fortran/expr.c:3501
+#: fortran/expr.c:3504
 #, gcc-internal-format
 msgid "Bounds specification for %qs in pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3514
+#: fortran/expr.c:3517
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower bound has to be present at %L"
 msgstr ""
 
-#: fortran/expr.c:3520
+#: fortran/expr.c:3523
 #, gcc-internal-format, gfc-internal-format
 msgid "Stride must not be present at %L"
 msgstr ""
 
-#: fortran/expr.c:3532
+#: fortran/expr.c:3535
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the upper bounds must be specified at %L"
 msgstr ""
 
-#: fortran/expr.c:3558
+#: fortran/expr.c:3561
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %L shall not have a coindex"
 msgstr ""
 
-#: fortran/expr.c:3579
+#: fortran/expr.c:3582
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure pointer assignment at %L"
 msgstr "Η παράμετρος κινητής υποδιαστολής δεν είναι έγκυρη: %s"
 
-#: fortran/expr.c:3603
+#: fortran/expr.c:3606
 #, gcc-internal-format
 msgid "Function result %qs is invalid as proc-target in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3612
+#: fortran/expr.c:3615
 #, gcc-internal-format
 msgid "Abstract interface %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3622
+#: fortran/expr.c:3625
 #, gcc-internal-format
 msgid "Statement function %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3628
+#: fortran/expr.c:3631
 #, gcc-internal-format
 msgid "Internal procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3635
+#: fortran/expr.c:3638
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L is invalid in procedure pointer assignment"
 msgstr ""
 
-#: fortran/expr.c:3643
+#: fortran/expr.c:3646
 #, gcc-internal-format
 msgid "Nonintrinsic elemental procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3666
+#: fortran/expr.c:3669
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in the procedure pointer assignment at %L: mismatch in the calling convention"
 msgstr ""
 
-#: fortran/expr.c:3719
+#: fortran/expr.c:3722
 #, gcc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %qs is not a subroutine"
 msgstr ""
 
-#: fortran/expr.c:3729 fortran/expr.c:3744
+#: fortran/expr.c:3732 fortran/expr.c:3747
 #, gcc-internal-format
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr ""
 
-#: fortran/expr.c:3735 fortran/expr.c:3750 fortran/resolve.c:2566
+#: fortran/expr.c:3738 fortran/expr.c:3753 fortran/resolve.c:2566
 #, fuzzy, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: fortran/expr.c:3762
+#: fortran/expr.c:3765
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %s"
 msgstr ""
 
-#: fortran/expr.c:3771
+#: fortran/expr.c:3774
 #, gcc-internal-format
 msgid "Procedure pointer target %qs at %L must be either an intrinsic, host or use associated, referenced or have the EXTERNAL attribute"
 msgstr ""
 
-#: fortran/expr.c:3788
+#: fortran/expr.c:3791
 #, gcc-internal-format, gfc-internal-format
 msgid "Data-pointer-object at %L must be unlimited polymorphic, or of a type with the BIND or SEQUENCE attribute, to be compatible with an unlimited polymorphic target"
 msgstr ""
 
-#: fortran/expr.c:3793
+#: fortran/expr.c:3796
 #, gcc-internal-format, gfc-internal-format
 msgid "Different types in pointer assignment at %L; attempted assignment of %s to %s"
 msgstr ""
 
-#: fortran/expr.c:3802
+#: fortran/expr.c:3805
 #, gcc-internal-format, gfc-internal-format
 msgid "Different kind type parameters in pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3809
+#: fortran/expr.c:3812
 #, gcc-internal-format, gfc-internal-format
 msgid "Different ranks in pointer assignment at %L"
 msgstr ""
 
-#: fortran/expr.c:3828
+#: fortran/expr.c:3831
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is smaller than size of the pointer (%ld < %ld) at %L"
 msgstr ""
 
-#: fortran/expr.c:3841
+#: fortran/expr.c:3844
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target must be rank 1 or simply contiguous at %L"
 msgstr ""
 
-#: fortran/expr.c:3845
+#: fortran/expr.c:3848
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is not rank 1 at %L"
 msgstr ""
@@ -54234,147 +54306,152 @@
 #. The test above might need to be extend when F08, Note 5.4 has to be
 #. interpreted in the way that target and pointer with the same coindex
 #. are allowed.
-#: fortran/expr.c:3877 fortran/expr.c:3925
+#: fortran/expr.c:3880 fortran/expr.c:3928
 #, gcc-internal-format, gfc-internal-format
 msgid "Data target at %L shall not have a coindex"
 msgstr ""
 
-#: fortran/expr.c:3880
+#: fortran/expr.c:3883
 #, gcc-internal-format, gfc-internal-format
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr ""
 
-#: fortran/expr.c:3888
+#: fortran/expr.c:3891
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr ""
 
-#: fortran/expr.c:3895
+#: fortran/expr.c:3898
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr ""
 
-#: fortran/expr.c:3904
+#: fortran/expr.c:3907
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr ""
 
-#: fortran/expr.c:3912
+#: fortran/expr.c:3915
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/expr.c:3936
+#: fortran/expr.c:3939
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to contiguous pointer from non-contiguous target at %L"
 msgstr ""
 
-#: fortran/expr.c:3975
+#: fortran/expr.c:3978
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr ""
 
-#: fortran/expr.c:4051 fortran/resolve.c:1452
+#: fortran/expr.c:4054 fortran/resolve.c:1452
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/expr.c:4057
+#: fortran/expr.c:4060
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr ""
 
-#: fortran/expr.c:4072 fortran/resolve.c:1458
+#: fortran/expr.c:4075 fortran/resolve.c:1458
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr ""
 
-#: fortran/expr.c:4084
+#: fortran/expr.c:4087
 #, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr ""
 
-#: fortran/expr.c:5512
+#: fortran/expr.c:4557
+#, gcc-internal-format
+msgid "generate_isocbinding_initializer(): bad iso_c_binding type, expected %<c_ptr%> or %<c_funptr%>"
+msgstr ""
+
+#: fortran/expr.c:5568
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5520
+#: fortran/expr.c:5576
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5528
+#: fortran/expr.c:5584
 #, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5537
+#: fortran/expr.c:5593
 #, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr ""
 
-#: fortran/expr.c:5548
+#: fortran/expr.c:5604
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5557
+#: fortran/expr.c:5613
 #, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5570
+#: fortran/expr.c:5626
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5583
+#: fortran/expr.c:5639
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5613
+#: fortran/expr.c:5669
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5621
+#: fortran/expr.c:5677
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5634
+#: fortran/expr.c:5690
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5642
+#: fortran/expr.c:5698
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5654
+#: fortran/expr.c:5710
 #, gcc-internal-format
 msgid "Variable %qs can not appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr ""
 
-#: fortran/expr.c:5713
+#: fortran/expr.c:5769
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:5717
+#: fortran/expr.c:5773
 #, gcc-internal-format
 msgid "%qs at %L associated to expression can not be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:5728
+#: fortran/expr.c:5784
 #, gcc-internal-format
 msgid "Associate-name %qs can not appear in a variable definition context (%s) at %L because its target at %L can not, either"
 msgstr ""
 
-#: fortran/expr.c:5770
+#: fortran/expr.c:5826
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr ""
@@ -54384,22 +54461,22 @@
 msgid "can't open input file: %s"
 msgstr "αδυναμία ανοίγματος αρχείου εισόδου `%s'"
 
-#: fortran/frontend-passes.c:190
+#: fortran/frontend-passes.c:192
 #, fuzzy, gcc-internal-format
 msgid "No location in statement"
 msgstr "Μη έγκυρη παράμετρος"
 
-#: fortran/frontend-passes.c:205
+#: fortran/frontend-passes.c:207
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "No location in expression near %L"
 msgstr "υπερβολικά πολλά δευτερόλεπτα αναπήδησης"
 
-#: fortran/frontend-passes.c:409
+#: fortran/frontend-passes.c:414
 #, gcc-internal-format
 msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
-#: fortran/frontend-passes.c:817 fortran/trans-array.c:1182
+#: fortran/frontend-passes.c:822 fortran/trans-array.c:1182
 #: fortran/trans-array.c:6440 fortran/trans-array.c:7864
 #: fortran/trans-intrinsic.c:7307
 #, fuzzy, gcc-internal-format, gfc-internal-format
@@ -54406,68 +54483,68 @@
 msgid "Creating array temporary at %L"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: fortran/frontend-passes.c:842 fortran/frontend-passes.c:846
+#: fortran/frontend-passes.c:847 fortran/frontend-passes.c:851
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "Removing call to function %qs at %L"
 msgstr "κλήση σε μη-συνάρτηση %qD"
 
-#: fortran/frontend-passes.c:1273 fortran/frontend-passes.c:1312
+#: fortran/frontend-passes.c:1278 fortran/frontend-passes.c:1317
 #, fuzzy, gcc-internal-format
 msgid "bad expression"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
-#: fortran/frontend-passes.c:1308
+#: fortran/frontend-passes.c:1313
 #, fuzzy, gcc-internal-format
 msgid "bad op"
 msgstr "μη έγκυρος χρήστης"
 
-#: fortran/frontend-passes.c:2161
+#: fortran/frontend-passes.c:2166
 #, gcc-internal-format
 msgid "illegal OP in optimize_comparison"
 msgstr ""
 
-#: fortran/frontend-passes.c:2407
+#: fortran/frontend-passes.c:2412
 #, gcc-internal-format
 msgid "Variable %qs at %L set to undefined value inside loop  beginning at %L as INTENT(OUT) argument to subroutine %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:2414
+#: fortran/frontend-passes.c:2419
 #, gcc-internal-format
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to subroutine %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:2637 fortran/frontend-passes.c:2661
+#: fortran/frontend-passes.c:2642 fortran/frontend-passes.c:2666
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L out of bounds (%ld < %ld) in loop beginning at %L"
 msgstr ""
 
-#: fortran/frontend-passes.c:2646 fortran/frontend-passes.c:2670
+#: fortran/frontend-passes.c:2651 fortran/frontend-passes.c:2675
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L out of bounds (%ld > %ld) in loop beginning at %L"
 msgstr ""
 
-#: fortran/frontend-passes.c:2730
+#: fortran/frontend-passes.c:2735
 #, gcc-internal-format
 msgid "Variable %qs at %L set to undefined value inside loop beginning at %L as INTENT(OUT) argument to function %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:2736
+#: fortran/frontend-passes.c:2741
 #, gcc-internal-format
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr ""
 
-#: fortran/frontend-passes.c:3128 fortran/trans-expr.c:1581
+#: fortran/frontend-passes.c:3133 fortran/trans-expr.c:1581
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr ""
 
-#: fortran/frontend-passes.c:3637
+#: fortran/frontend-passes.c:3642
 #, gcc-internal-format
 msgid "Scalarization using DIMEN_RANGE unimplemented"
 msgstr ""
 
-#: fortran/frontend-passes.c:4429
+#: fortran/frontend-passes.c:4434
 #, gcc-internal-format, gfc-internal-format
 msgid "Interchanging loops at %L"
 msgstr ""
@@ -54587,12 +54664,12 @@
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:970 fortran/resolve.c:16351
+#: fortran/interface.c:970 fortran/resolve.c:16378
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:977 fortran/resolve.c:16369
+#: fortran/interface.c:977 fortran/resolve.c:16396
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
@@ -55785,7 +55862,7 @@
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr ""
 
-#: fortran/io.c:3369 fortran/resolve.c:14263
+#: fortran/io.c:3369 fortran/resolve.c:14283
 #, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr ""
@@ -55952,7 +56029,7 @@
 msgid "Integer too large at %C"
 msgstr "σχετική θέση αρχείου είναι εκτός ορίων"
 
-#: fortran/match.c:580 fortran/parse.c:1132
+#: fortran/match.c:580 fortran/parse.c:1136
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many digits in statement label at %C"
 msgstr ""
@@ -56715,57 +56792,57 @@
 msgid "Expected block name %qs of SELECT construct at %C"
 msgstr ""
 
-#: fortran/match.c:6186
+#: fortran/match.c:6201
 #, gcc-internal-format, gfc-internal-format
 msgid "parse error in SELECT TYPE statement at %C"
 msgstr ""
 
-#: fortran/match.c:6211
+#: fortran/match.c:6226
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr ""
 
-#: fortran/match.c:6249
+#: fortran/match.c:6264
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr ""
 
-#: fortran/match.c:6301
+#: fortran/match.c:6316
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CASE specification at %C"
 msgstr "συντακτικό σφάλμα στο ορισμό του %s: %s"
 
-#: fortran/match.c:6319
+#: fortran/match.c:6334
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected TYPE IS statement at %C"
 msgstr ""
 
-#: fortran/match.c:6351
+#: fortran/match.c:6366
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr ""
 
-#: fortran/match.c:6362
+#: fortran/match.c:6377
 #, gcc-internal-format, gfc-internal-format
 msgid "All the LEN type parameters in the TYPE IS statement at %C must be ASSUMED"
 msgstr ""
 
-#: fortran/match.c:6373
+#: fortran/match.c:6388
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr "συντακτικό σφάλμα στο ορισμό του %s: %s"
 
-#: fortran/match.c:6449
+#: fortran/match.c:6464
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr "συντακτικό σφάλμα στο ορισμό του %s: %s"
 
-#: fortran/match.c:6572
+#: fortran/match.c:6587
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr ""
 
-#: fortran/match.c:6610
+#: fortran/match.c:6625
 #, fuzzy, gcc-internal-format
 msgid "Label %qs at %C doesn't match WHERE label %qs"
 msgstr "το αρχείο δεδομένων προφίλ `%s' δεν ταιριάζει με το διαμοιραζόμενο αντικείμενο `%s'"
@@ -56916,188 +56993,188 @@
 msgid "mio_array_ref(): Unknown array ref"
 msgstr ""
 
-#: fortran/module.c:3716
+#: fortran/module.c:3718
 #, gcc-internal-format, gfc-internal-format
 msgid "Namelist %s cannot be renamed by USE association to %s"
 msgstr ""
 
-#: fortran/module.c:4832
+#: fortran/module.c:4834
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4835
+#: fortran/module.c:4837
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:5029
+#: fortran/module.c:5031
 #, gcc-internal-format
 msgid "%qs of module %qs, imported at %C, is also the name of the current program unit"
 msgstr ""
 
-#: fortran/module.c:5381
+#: fortran/module.c:5383
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5388
+#: fortran/module.c:5390
 #, gcc-internal-format
 msgid "User operator %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5393
+#: fortran/module.c:5395
 #, gcc-internal-format
 msgid "Intrinsic operator %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5628
+#: fortran/module.c:5630
 #, gcc-internal-format
 msgid "write_symbol(): bad module symbol %qs"
 msgstr ""
 
-#: fortran/module.c:5961
+#: fortran/module.c:5963
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr ""
 
-#: fortran/module.c:6148
+#: fortran/module.c:6150
 #, fuzzy, gcc-internal-format
 msgid "Can't open module file %qs for writing at %C: %s"
 msgstr "%s: Σφάλμα εγγραφής "
 
-#: fortran/module.c:6169
+#: fortran/module.c:6171
 #, fuzzy, gcc-internal-format
 msgid "Error writing module file %qs for writing: %s"
 msgstr "%s: Σφάλμα κατά την εγγραφή του %s\n"
 
-#: fortran/module.c:6180
+#: fortran/module.c:6182
 #, fuzzy, gcc-internal-format
 msgid "Can't delete module file %qs: %s"
 msgstr "%s: Δεν είναι δυνατόν να δημιουργηθεί %s: %s\n"
 
-#: fortran/module.c:6183
+#: fortran/module.c:6185
 #, fuzzy, gcc-internal-format
 msgid "Can't rename module file %qs to %qs: %s"
 msgstr "%s: Προειδοποίηση: η uname απέτυχε: %s\n"
 
-#: fortran/module.c:6189
+#: fortran/module.c:6191
 #, fuzzy, gcc-internal-format
 msgid "Can't delete temporary module file %qs: %s"
 msgstr "%s: Δε μπορεί να διαγραφεί το %s: %s\n"
 
-#: fortran/module.c:6246
+#: fortran/module.c:6248
 #, gcc-internal-format
 msgid "Symbol %qs at %C already declared"
 msgstr ""
 
-#: fortran/module.c:6317
+#: fortran/module.c:6319
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr ""
 
-#: fortran/module.c:6425 fortran/module.c:6769
+#: fortran/module.c:6427 fortran/module.c:6771
 #, gcc-internal-format
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr ""
 
-#: fortran/module.c:6553
+#: fortran/module.c:6555
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr ""
 
-#: fortran/module.c:6574 fortran/module.c:6607 fortran/module.c:6649
+#: fortran/module.c:6576 fortran/module.c:6609 fortran/module.c:6651
 #, gcc-internal-format
 msgid "Symbol %qs already declared"
 msgstr ""
 
-#: fortran/module.c:6754
+#: fortran/module.c:6756
 #, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:6776
+#: fortran/module.c:6778
 #, gcc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr ""
 
-#: fortran/module.c:6844
+#: fortran/module.c:6846
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr ""
 
-#: fortran/module.c:6898
+#: fortran/module.c:6900
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr ""
 
-#: fortran/module.c:6924
+#: fortran/module.c:6926
 #, gcc-internal-format, gfc-internal-format
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr ""
 
-#: fortran/module.c:6953
+#: fortran/module.c:6955
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr ""
 
-#: fortran/module.c:6965
+#: fortran/module.c:6967
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
 msgstr ""
 
-#: fortran/module.c:6978
+#: fortran/module.c:6980
 #, gcc-internal-format
 msgid "Can't find an intrinsic module named %qs at %C"
 msgstr ""
 
-#: fortran/module.c:6984
+#: fortran/module.c:6986
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr ""
 
-#: fortran/module.c:6990
+#: fortran/module.c:6992
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr ""
 
-#: fortran/module.c:6996
+#: fortran/module.c:6998
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr ""
 
-#: fortran/module.c:7006
+#: fortran/module.c:7008
 #, fuzzy, gcc-internal-format
 msgid "Can't open module file %qs for reading at %C: %s"
 msgstr "%s: Δεν είναι δυνατόν να ανοιχτεί το %s: %s\n"
 
-#: fortran/module.c:7009
+#: fortran/module.c:7011
 #, gcc-internal-format
 msgid "Module file %qs has not been generated, either because the module does not contain a MODULE PROCEDURE or there is an error in the module."
 msgstr ""
 
-#: fortran/module.c:7020
+#: fortran/module.c:7022
 #, gcc-internal-format
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:7043
+#: fortran/module.c:7045
 #, gcc-internal-format
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr ""
 
-#: fortran/module.c:7051
+#: fortran/module.c:7053
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr ""
 
-#: fortran/module.c:7066
+#: fortran/module.c:7068
 #, gcc-internal-format, gfc-internal-format
 msgid "Can't USE the same %smodule we're building"
 msgstr ""
 
 #: fortran/openmp.c:296 fortran/openmp.c:397 fortran/openmp.c:692
-#: fortran/openmp.c:3167
+#: fortran/openmp.c:3166
 #, gcc-internal-format, gfc-internal-format
 msgid "COMMON block /%s/ not found at %C"
 msgstr ""
@@ -57174,859 +57251,859 @@
 
 #: fortran/openmp.c:2180
 #, fuzzy, gcc-internal-format, gfc-internal-format
-msgid "Invalid argument to !$ACC WAIT at %L"
+msgid "Invalid argument to !$ACC WAIT at %C"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: fortran/openmp.c:2188
+#: fortran/openmp.c:2187
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT clause at %L requires a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/openmp.c:2221
+#: fortran/openmp.c:2220
 #, gcc-internal-format, gfc-internal-format
 msgid "ACC CACHE directive must be inside of loop %C"
 msgstr ""
 
-#: fortran/openmp.c:2252
+#: fortran/openmp.c:2251
 #, gcc-internal-format
 msgid "Multiple loop axes specified for routine"
 msgstr ""
 
-#: fortran/openmp.c:2278
+#: fortran/openmp.c:2277
 #, gcc-internal-format, gfc-internal-format
 msgid "Only the !$ACC ROUTINE form without list is allowed in interface block at %C"
 msgstr ""
 
-#: fortran/openmp.c:2306
+#: fortran/openmp.c:2305
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$ACC ROUTINE ( NAME ) at %C, invalid function name %s"
 msgstr ""
 
-#: fortran/openmp.c:2315
+#: fortran/openmp.c:2314
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$ACC ROUTINE ( NAME ) at %C"
 msgstr ""
 
-#: fortran/openmp.c:2322
+#: fortran/openmp.c:2321
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$ACC ROUTINE ( NAME ) at %C, expecting ')' after NAME"
 msgstr ""
 
-#: fortran/openmp.c:2457 fortran/openmp.c:2481
+#: fortran/openmp.c:2456 fortran/openmp.c:2480
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP CRITICAL statement at %C"
 msgstr ""
 
-#: fortran/openmp.c:2548
+#: fortran/openmp.c:2547
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP FLUSH statement at %C"
 msgstr ""
 
-#: fortran/openmp.c:2942 fortran/openmp.c:6225
+#: fortran/openmp.c:2941 fortran/openmp.c:6230
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined %s !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2946 fortran/openmp.c:6229
+#: fortran/openmp.c:2945 fortran/openmp.c:6234
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2951
+#: fortran/openmp.c:2950
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2953
+#: fortran/openmp.c:2952
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2973
+#: fortran/openmp.c:2972
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after !$OMP DECLARE REDUCTION at %C"
 msgstr ""
 
-#: fortran/openmp.c:3010
+#: fortran/openmp.c:3009
 #, gcc-internal-format, gfc-internal-format
 msgid "Only the !$OMP DECLARE TARGET form without clauses is allowed in interface block at %C"
 msgstr ""
 
-#: fortran/openmp.c:3025
+#: fortran/openmp.c:3024
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after !$OMP DECLARE TARGET at %C"
 msgstr ""
 
-#: fortran/openmp.c:3048
+#: fortran/openmp.c:3047
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET variable at %L is an element of a COMMON block"
 msgstr ""
 
-#: fortran/openmp.c:3053
+#: fortran/openmp.c:3052
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET variable at %L previously mentioned in LINK clause and later in TO clause"
 msgstr ""
 
-#: fortran/openmp.c:3059
+#: fortran/openmp.c:3058
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET variable at %L previously mentioned in TO clause and later in LINK clause"
 msgstr ""
 
-#: fortran/openmp.c:3063
+#: fortran/openmp.c:3062
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable at %L mentioned multiple times in clauses of the same OMP DECLARE TARGET directive"
 msgstr ""
 
-#: fortran/openmp.c:3078
+#: fortran/openmp.c:3077
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET COMMON at %L previously mentioned in LINK clause and later in TO clause"
 msgstr ""
 
-#: fortran/openmp.c:3084
+#: fortran/openmp.c:3083
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET COMMON at %L previously mentioned in TO clause and later in LINK clause"
 msgstr ""
 
-#: fortran/openmp.c:3088
+#: fortran/openmp.c:3087
 #, gcc-internal-format, gfc-internal-format
 msgid "COMMON at %L mentioned multiple times in clauses of the same OMP DECLARE TARGET directive"
 msgstr ""
 
-#: fortran/openmp.c:3115
+#: fortran/openmp.c:3114
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$OMP DECLARE TARGET list at %C"
 msgstr ""
 
-#: fortran/openmp.c:3147
+#: fortran/openmp.c:3146
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate variable at %C is an element of a COMMON block"
 msgstr ""
 
-#: fortran/openmp.c:3184
+#: fortran/openmp.c:3183
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after OMP THREADPRIVATE at %C"
 msgstr ""
 
-#: fortran/openmp.c:3191
+#: fortran/openmp.c:3190
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$OMP THREADPRIVATE list at %C"
 msgstr ""
 
-#: fortran/openmp.c:3405
+#: fortran/openmp.c:3404
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after TASKWAIT clause at %C"
 msgstr ""
 
-#: fortran/openmp.c:3419
+#: fortran/openmp.c:3418
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after TASKYIELD clause at %C"
 msgstr ""
 
-#: fortran/openmp.c:3478
+#: fortran/openmp.c:3477
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP WORKSHARE statement at %C"
 msgstr ""
 
-#: fortran/openmp.c:3492
+#: fortran/openmp.c:3491
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP MASTER statement at %C"
 msgstr ""
 
-#: fortran/openmp.c:3551
+#: fortran/openmp.c:3550
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP ATOMIC statement at %C"
 msgstr ""
 
-#: fortran/openmp.c:3578
+#: fortran/openmp.c:3577
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP BARRIER statement at %C"
 msgstr ""
 
-#: fortran/openmp.c:3592
+#: fortran/openmp.c:3591
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP TASKGROUP statement at %C"
 msgstr ""
 
-#: fortran/openmp.c:3642
+#: fortran/openmp.c:3641
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP CANCELLATION POINT statement at %C"
 msgstr ""
 
-#: fortran/openmp.c:3662
+#: fortran/openmp.c:3661
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after NOWAIT clause at %C"
 msgstr ""
 
-#: fortran/openmp.c:3704
+#: fortran/openmp.c:3703
 #, gcc-internal-format, gfc-internal-format
 msgid "%s clause at %L requires a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/openmp.c:3715
+#: fortran/openmp.c:3714
 #, gcc-internal-format, gfc-internal-format
 msgid "INTEGER expression of %s clause at %L must be positive"
 msgstr ""
 
-#: fortran/openmp.c:3726
+#: fortran/openmp.c:3725
 #, gcc-internal-format, gfc-internal-format
 msgid "INTEGER expression of %s clause at %L must be non-negative"
 msgstr ""
 
-#: fortran/openmp.c:3737
+#: fortran/openmp.c:3736
 #, gcc-internal-format
 msgid "POINTER object %qs of derived type in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3740
+#: fortran/openmp.c:3739
 #, gcc-internal-format
 msgid "Cray pointer object %qs of derived type in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3743
+#: fortran/openmp.c:3742
 #, gcc-internal-format
 msgid "Cray pointee object %qs of derived type in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3749 fortran/openmp.c:4687
+#: fortran/openmp.c:3748 fortran/openmp.c:4686
 #, gcc-internal-format
 msgid "POINTER object %qs of polymorphic type in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3754
+#: fortran/openmp.c:3753
 #, gcc-internal-format
 msgid "Cray pointer object %qs of polymorphic type in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3759
+#: fortran/openmp.c:3758
 #, gcc-internal-format
 msgid "Cray pointee object %qs of polymorphic type in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3769 fortran/openmp.c:4385 fortran/openmp.c:4490
+#: fortran/openmp.c:3768 fortran/openmp.c:4384 fortran/openmp.c:4489
 #, fuzzy, gcc-internal-format
 msgid "Assumed size array %qs in %s clause at %L"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: fortran/openmp.c:3772
+#: fortran/openmp.c:3771
 #, fuzzy, gcc-internal-format
 msgid "Assumed rank array %qs in %s clause at %L"
 msgstr "εσωτερικό σφάλμα στο %s, γραμμή %u"
 
-#: fortran/openmp.c:3776
+#: fortran/openmp.c:3775
 #, gcc-internal-format
 msgid "Noncontiguous deferred shape array %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3784
+#: fortran/openmp.c:3783
 #, gcc-internal-format
 msgid "ALLOCATABLE object %qs of derived type in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3789
+#: fortran/openmp.c:3788
 #, gcc-internal-format
 msgid "ALLOCATABLE object %qs of polymorphic type in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3801 fortran/openmp.c:4480
+#: fortran/openmp.c:3800 fortran/openmp.c:4479
 #, gcc-internal-format
 msgid "POINTER object %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3806 fortran/openmp.c:4691
+#: fortran/openmp.c:3805 fortran/openmp.c:4690
 #, gcc-internal-format
 msgid "Cray pointer object %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3811 fortran/openmp.c:4694
+#: fortran/openmp.c:3810 fortran/openmp.c:4693
 #, gcc-internal-format
 msgid "Cray pointee object %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3816 fortran/openmp.c:4682
+#: fortran/openmp.c:3815 fortran/openmp.c:4681
 #, gcc-internal-format
 msgid "ALLOCATABLE object %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3819
+#: fortran/openmp.c:3818
 #, gcc-internal-format
 msgid "VALUE object %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:3862
+#: fortran/openmp.c:3861
 #, gcc-internal-format, gfc-internal-format
 msgid "Implicitly declared function %s used in !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:3911
+#: fortran/openmp.c:3910
 #, gcc-internal-format, gfc-internal-format
 msgid "Implicitly declared subroutine %s used in !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:3944
+#: fortran/openmp.c:3943
 #, gcc-internal-format, gfc-internal-format
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:3952 fortran/openmp.c:3963 fortran/resolve.c:10028
-#: fortran/resolve.c:11295
+#: fortran/openmp.c:3951 fortran/openmp.c:3962 fortran/resolve.c:10041
+#: fortran/resolve.c:11315
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/openmp.c:3967
+#: fortran/openmp.c:3966
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause without modifier at %L used together with IF clauses with modifiers"
 msgstr ""
 
-#: fortran/openmp.c:4044
+#: fortran/openmp.c:4043
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause modifier %s at %L not appropriate for the current OpenMP construct"
 msgstr ""
 
-#: fortran/openmp.c:4054
+#: fortran/openmp.c:4053
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/openmp.c:4064
+#: fortran/openmp.c:4063
 #, gcc-internal-format, gfc-internal-format
 msgid "SCHEDULE clause's chunk_size at %L requires a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/openmp.c:4069
+#: fortran/openmp.c:4068
 #, gcc-internal-format, gfc-internal-format
 msgid "INTEGER expression of SCHEDULE clause's chunk_size at %L must be positive"
 msgstr ""
 
-#: fortran/openmp.c:4084
+#: fortran/openmp.c:4083
 #, gcc-internal-format
 msgid "Variable %qs is not a dummy argument at %L"
 msgstr ""
 
-#: fortran/openmp.c:4116
+#: fortran/openmp.c:4115 fortran/openmp.c:5998
 #, fuzzy, gcc-internal-format
 msgid "Object %qs is not a variable at %L"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: fortran/openmp.c:4132 fortran/openmp.c:4143 fortran/openmp.c:4151
-#: fortran/openmp.c:4162 fortran/openmp.c:4174 fortran/openmp.c:4189
-#: fortran/openmp.c:6023
+#: fortran/openmp.c:4131 fortran/openmp.c:4142 fortran/openmp.c:4150
+#: fortran/openmp.c:4161 fortran/openmp.c:4173 fortran/openmp.c:4188
+#: fortran/openmp.c:6028
 #, gcc-internal-format
 msgid "Symbol %qs present on multiple clauses at %L"
 msgstr ""
 
-#: fortran/openmp.c:4196
+#: fortran/openmp.c:4195
 #, gcc-internal-format
 msgid "Array %qs is not permitted in reduction at %L"
 msgstr ""
 
-#: fortran/openmp.c:4209
+#: fortran/openmp.c:4208
 #, gcc-internal-format
 msgid "Symbol %qs present on both FROM and TO clauses at %L"
 msgstr ""
 
-#: fortran/openmp.c:4231
+#: fortran/openmp.c:4230
 #, gcc-internal-format
 msgid "Non-THREADPRIVATE object %qs in COPYIN clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4239
+#: fortran/openmp.c:4238
 #, gcc-internal-format
 msgid "Assumed size array %qs in COPYPRIVATE clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4242
+#: fortran/openmp.c:4241
 #, gcc-internal-format
 msgid "INTENT(IN) POINTER %qs in COPYPRIVATE clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4250
+#: fortran/openmp.c:4249
 #, gcc-internal-format
 msgid "THREADPRIVATE object %qs in SHARED clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4253
+#: fortran/openmp.c:4252
 #, gcc-internal-format
 msgid "Cray pointee %qs in SHARED clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4256
+#: fortran/openmp.c:4255
 #, gcc-internal-format
 msgid "ASSOCIATE name %qs in SHARED clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4271
+#: fortran/openmp.c:4270
 #, gcc-internal-format
 msgid "%qs in ALIGNED clause must be POINTER, ALLOCATABLE, Cray pointer or C_PTR at %L"
 msgstr ""
 
-#: fortran/openmp.c:4283
+#: fortran/openmp.c:4282
 #, gcc-internal-format
 msgid "%qs in ALIGNED clause at %L requires a scalar positive constant integer alignment expression"
 msgstr ""
 
-#: fortran/openmp.c:4302
+#: fortran/openmp.c:4301
 #, gcc-internal-format, gfc-internal-format
 msgid "SINK dependence type only allowed on ORDERED directive at %L"
 msgstr ""
 
-#: fortran/openmp.c:4306
+#: fortran/openmp.c:4305
 #, gcc-internal-format, gfc-internal-format
 msgid "DEPEND SINK used together with DEPEND SOURCE on the same construct at %L"
 msgstr ""
 
-#: fortran/openmp.c:4316
+#: fortran/openmp.c:4315
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SINK addend not a constant integer at %L"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: fortran/openmp.c:4322
+#: fortran/openmp.c:4321
 #, gcc-internal-format, gfc-internal-format
 msgid "Only SOURCE or SINK dependence types are allowed on ORDERED directive at %L"
 msgstr ""
 
-#: fortran/openmp.c:4333 fortran/openmp.c:4354
+#: fortran/openmp.c:4332 fortran/openmp.c:4353
 #, gcc-internal-format
 msgid "%qs in %s clause at %L is not a proper array section"
 msgstr ""
 
-#: fortran/openmp.c:4337
+#: fortran/openmp.c:4336
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coarrays not supported in %s clause at %L"
 msgstr "Η οικογένεια διευθύνσεων δεν υποστηρίζεται από την οικογένεια πρωτοκόλλου"
 
-#: fortran/openmp.c:4346
+#: fortran/openmp.c:4345
 #, gcc-internal-format, gfc-internal-format
 msgid "Stride should not be specified for array section in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4367
+#: fortran/openmp.c:4366
 #, gcc-internal-format
 msgid "%qs in DEPEND clause at %L is a zero size array section"
 msgstr ""
 
-#: fortran/openmp.c:4403
+#: fortran/openmp.c:4402
 #, gcc-internal-format, gfc-internal-format
 msgid "TARGET%s with map-type other than TO, FROM, TOFROM, or ALLOC on MAP clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4419
+#: fortran/openmp.c:4418
 #, gcc-internal-format, gfc-internal-format
 msgid "TARGET ENTER DATA with map-type other than TO, or ALLOC on MAP clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4434
+#: fortran/openmp.c:4433
 #, gcc-internal-format, gfc-internal-format
 msgid "TARGET EXIT DATA with map-type other than FROM, RELEASE, or DELETE on MAP clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4450 fortran/openmp.c:4466
+#: fortran/openmp.c:4449 fortran/openmp.c:4465
 #, gcc-internal-format
 msgid "THREADPRIVATE object %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4453 fortran/openmp.c:4469
+#: fortran/openmp.c:4452 fortran/openmp.c:4468
 #, gcc-internal-format
 msgid "Cray pointee %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4472
+#: fortran/openmp.c:4471
 #, gcc-internal-format
 msgid "ASSOCIATE name %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4477
+#: fortran/openmp.c:4476
 #, gcc-internal-format
 msgid "Procedure pointer %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4483
+#: fortran/openmp.c:4482
 #, gcc-internal-format
 msgid "Cray pointer %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4493
+#: fortran/openmp.c:4492
 #, gcc-internal-format
 msgid "Variable %qs in %s clause is used in NAMELIST statement at %L"
 msgstr ""
 
 #. case OMP_LIST_REDUCTION:
-#: fortran/openmp.c:4503
+#: fortran/openmp.c:4502
 #, gcc-internal-format
 msgid "INTENT(IN) POINTER %qs in %s clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4596
+#: fortran/openmp.c:4595
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP DECLARE REDUCTION %s not found for type %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:4622
+#: fortran/openmp.c:4621
 #, gcc-internal-format, gfc-internal-format
 msgid "LINEAR clause modifier used on DO or SIMD construct at %L"
 msgstr ""
 
-#: fortran/openmp.c:4627
+#: fortran/openmp.c:4626
 #, gcc-internal-format, gfc-internal-format
 msgid "LINEAR clause specified together with ORDERED clause with argument at %L"
 msgstr ""
 
-#: fortran/openmp.c:4632
+#: fortran/openmp.c:4631
 #, gcc-internal-format
 msgid "LINEAR variable %qs must be INTEGER at %L"
 msgstr ""
 
-#: fortran/openmp.c:4637
+#: fortran/openmp.c:4636
 #, gcc-internal-format
 msgid "LINEAR dummy argument %qs with VALUE attribute with %s modifier at %L"
 msgstr ""
 
-#: fortran/openmp.c:4648
+#: fortran/openmp.c:4647
 #, gcc-internal-format
 msgid "%qs in LINEAR clause at %L requires a scalar integer linear-step expression"
 msgstr ""
 
-#: fortran/openmp.c:4665
+#: fortran/openmp.c:4664
 #, gcc-internal-format
 msgid "%qs in LINEAR clause at %L requires a constant integer linear-step expression or dummy argument specified in UNIFORM clause"
 msgstr ""
 
-#: fortran/openmp.c:4699
+#: fortran/openmp.c:4698
 #, gcc-internal-format
 msgid "%s clause variable %qs at %L is neither a POINTER nor an array"
 msgstr ""
 
-#: fortran/openmp.c:4731
+#: fortran/openmp.c:4730
 #, gcc-internal-format, gfc-internal-format
 msgid "DIST_SCHEDULE clause's chunk_size at %L requires a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/openmp.c:4763
+#: fortran/openmp.c:4762
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible use of TILE and COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:4765
+#: fortran/openmp.c:4764
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE dependence type only allowed on ORDERED directive at %L"
 msgstr ""
 
-#: fortran/openmp.c:4778
+#: fortran/openmp.c:4777
 #, gcc-internal-format, gfc-internal-format
 msgid "%s must contain at least one MAP clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4875
+#: fortran/openmp.c:4874
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unexpected !$OMP ATOMIC expression at %L"
 msgstr "Μη έγκυρη προπορευόμενη κανονική έκφραση"
 
-#: fortran/openmp.c:4904
+#: fortran/openmp.c:4903
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC statement must set a scalar variable of intrinsic type at %L"
 msgstr ""
 
-#: fortran/openmp.c:4929
+#: fortran/openmp.c:4928
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC READ statement must read from a scalar variable of intrinsic type at %L"
 msgstr ""
 
-#: fortran/openmp.c:4934
+#: fortran/openmp.c:4933
 #, gcc-internal-format, gfc-internal-format
 msgid "expr in !$OMP ATOMIC WRITE assignment var = expr must be scalar and cannot reference var at %L"
 msgstr ""
 
-#: fortran/openmp.c:4956 fortran/openmp.c:5247
+#: fortran/openmp.c:4955 fortran/openmp.c:5246
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE capture statement must read from a scalar variable of intrinsic type at %L"
 msgstr ""
 
-#: fortran/openmp.c:4971
+#: fortran/openmp.c:4970
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE update statement must set a scalar variable of intrinsic type at %L"
 msgstr ""
 
-#: fortran/openmp.c:4978 fortran/openmp.c:5254
+#: fortran/openmp.c:4977 fortran/openmp.c:5253
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE capture statement reads from different variable than update statement writes into at %L"
 msgstr ""
 
-#: fortran/openmp.c:4994
+#: fortran/openmp.c:4993
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC with ALLOCATABLE variable at %L"
 msgstr ""
 
-#: fortran/openmp.c:5036
+#: fortran/openmp.c:5035
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment operator must be binary +, *, -, /, .AND., .OR., .EQV. or .NEQV. at %L"
 msgstr ""
 
-#: fortran/openmp.c:5084
+#: fortran/openmp.c:5083
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment must be var = var op expr or var = expr op var at %L"
 msgstr ""
 
-#: fortran/openmp.c:5098
+#: fortran/openmp.c:5097
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC var = var op expr not mathematically equivalent to var = var op (expr) at %L"
 msgstr ""
 
-#: fortran/openmp.c:5130
+#: fortran/openmp.c:5129
 #, gcc-internal-format, gfc-internal-format
 msgid "expr in !$OMP ATOMIC assignment var = var op expr must be scalar and cannot reference var at %L"
 msgstr ""
 
-#: fortran/openmp.c:5154
+#: fortran/openmp.c:5153
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment intrinsic IAND, IOR or IEOR must have two arguments at %L"
 msgstr ""
 
-#: fortran/openmp.c:5161
+#: fortran/openmp.c:5160
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment intrinsic must be MIN, MAX, IAND, IOR or IEOR at %L"
 msgstr ""
 
-#: fortran/openmp.c:5178
+#: fortran/openmp.c:5177
 #, gcc-internal-format
 msgid "!$OMP ATOMIC intrinsic arguments except one must not reference %qs at %L"
 msgstr ""
 
-#: fortran/openmp.c:5185
+#: fortran/openmp.c:5184
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC intrinsic arguments must be scalar at %L"
 msgstr ""
 
-#: fortran/openmp.c:5193
+#: fortran/openmp.c:5192
 #, gcc-internal-format
 msgid "First or last !$OMP ATOMIC intrinsic argument must be %qs at %L"
 msgstr ""
 
-#: fortran/openmp.c:5211
+#: fortran/openmp.c:5210
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment must have an operator or intrinsic on right hand side at %L"
 msgstr ""
 
-#: fortran/openmp.c:5225
+#: fortran/openmp.c:5224
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE capture statement must set a scalar variable of intrinsic type at %L"
 msgstr ""
 
-#: fortran/openmp.c:5544
+#: fortran/openmp.c:5543
 #, gcc-internal-format, gfc-internal-format
 msgid "%s cannot be a DO WHILE or DO without loop control at %L"
 msgstr ""
 
-#: fortran/openmp.c:5550
+#: fortran/openmp.c:5549
 #, gcc-internal-format, gfc-internal-format
 msgid "%s cannot be a DO CONCURRENT loop at %L"
 msgstr ""
 
-#: fortran/openmp.c:5556
+#: fortran/openmp.c:5555
 #, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable must be of type integer at %L"
 msgstr ""
 
-#: fortran/openmp.c:5560
+#: fortran/openmp.c:5559
 #, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable must not be THREADPRIVATE at %L"
 msgstr ""
 
-#: fortran/openmp.c:5573
+#: fortran/openmp.c:5572
 #, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable present on clause other than PRIVATE or LASTPRIVATE at %L"
 msgstr ""
 
-#: fortran/openmp.c:5577
+#: fortran/openmp.c:5576
 #, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable present on clause other than LASTPRIVATE at %L"
 msgstr ""
 
-#: fortran/openmp.c:5581
+#: fortran/openmp.c:5580
 #, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable present on clause other than LINEAR at %L"
 msgstr ""
 
-#: fortran/openmp.c:5599
+#: fortran/openmp.c:5598
 #, gcc-internal-format, gfc-internal-format
 msgid "%s collapsed loops don't form rectangular iteration space at %L"
 msgstr ""
 
-#: fortran/openmp.c:5611
+#: fortran/openmp.c:5610
 #, gcc-internal-format, gfc-internal-format
 msgid "collapsed %s loops not perfectly nested at %L"
 msgstr ""
 
-#: fortran/openmp.c:5620 fortran/openmp.c:5628
+#: fortran/openmp.c:5619 fortran/openmp.c:5627
 #, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for collapsed %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:5712 fortran/openmp.c:5725
+#: fortran/openmp.c:5711 fortran/openmp.c:5724
 #, gcc-internal-format, gfc-internal-format
 msgid "The %s directive cannot be specified within a %s region at %L"
 msgstr ""
 
-#: fortran/openmp.c:5744
+#: fortran/openmp.c:5743
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP cannot be a DO WHILE or DO without loop control at %L"
 msgstr ""
 
-#: fortran/openmp.c:5750
+#: fortran/openmp.c:5749
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP iteration variable must be of type integer at %L"
 msgstr ""
 
-#: fortran/openmp.c:5766
+#: fortran/openmp.c:5765
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s loops don't form rectangular iteration space at %L"
 msgstr ""
 
-#: fortran/openmp.c:5778
+#: fortran/openmp.c:5777
 #, gcc-internal-format, gfc-internal-format
 msgid "%s !$ACC LOOP loops not perfectly nested at %L"
 msgstr ""
 
-#: fortran/openmp.c:5788 fortran/openmp.c:5797
+#: fortran/openmp.c:5787 fortran/openmp.c:5796
 #, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for %s !$ACC LOOP at %L"
 msgstr ""
 
-#: fortran/openmp.c:5812 fortran/openmp.c:5819
+#: fortran/openmp.c:5811 fortran/openmp.c:5818
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s in PARALLEL region doesn't allow %s arguments at %L"
 msgstr ""
 
-#: fortran/openmp.c:5841
+#: fortran/openmp.c:5840
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside another loop parallelized across gangs at %L"
 msgstr ""
 
-#: fortran/openmp.c:5845 fortran/openmp.c:5849
+#: fortran/openmp.c:5844 fortran/openmp.c:5848
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside loop parallelized across workers at %L"
 msgstr ""
 
-#: fortran/openmp.c:5856
+#: fortran/openmp.c:5855
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across workers at %L"
 msgstr ""
 
-#: fortran/openmp.c:5860
+#: fortran/openmp.c:5859
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across vectors at %L"
 msgstr ""
 
-#: fortran/openmp.c:5866
+#: fortran/openmp.c:5865
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across vectors is not allowed inside another loop parallelized across vectors at %L"
 msgstr ""
 
-#: fortran/openmp.c:5878
+#: fortran/openmp.c:5877
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with INDEPENDENT at %L"
 msgstr ""
 
-#: fortran/openmp.c:5880
+#: fortran/openmp.c:5879
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with GANG at %L"
 msgstr ""
 
-#: fortran/openmp.c:5882
+#: fortran/openmp.c:5881
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with WORKER at %L"
 msgstr ""
 
-#: fortran/openmp.c:5884
+#: fortran/openmp.c:5883
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with VECTOR at %L"
 msgstr ""
 
-#: fortran/openmp.c:5886
+#: fortran/openmp.c:5885
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with AUTO at %L"
 msgstr ""
 
-#: fortran/openmp.c:5891
+#: fortran/openmp.c:5890
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with GANG at %L"
 msgstr ""
 
-#: fortran/openmp.c:5893
+#: fortran/openmp.c:5892
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with WORKER at %L"
 msgstr ""
 
-#: fortran/openmp.c:5895
+#: fortran/openmp.c:5894
 #, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with VECTOR at %L"
 msgstr ""
 
-#: fortran/openmp.c:5899
+#: fortran/openmp.c:5898
 #, gcc-internal-format, gfc-internal-format
 msgid "Tiled loop cannot be parallelized across gangs, workers and vectors at the same time at %L"
 msgstr ""
 
-#: fortran/openmp.c:5934
+#: fortran/openmp.c:5933
 #, gcc-internal-format, gfc-internal-format
 msgid "TILE requires constant expression at %L"
 msgstr ""
 
-#: fortran/openmp.c:5999
+#: fortran/openmp.c:6004
 #, gcc-internal-format
 msgid "PARAMETER object %qs is not allowed at %L"
 msgstr ""
 
-#: fortran/openmp.c:6006
+#: fortran/openmp.c:6011
 #, gcc-internal-format
 msgid "Array sections: %qs not allowed in !$ACC DECLARE at %L"
 msgstr ""
 
-#: fortran/openmp.c:6133
+#: fortran/openmp.c:6138
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP TARGET UPDATE at %L requires at least one TO or FROM clause"
 msgstr ""
 
-#: fortran/openmp.c:6155
+#: fortran/openmp.c:6160
 #, gcc-internal-format
 msgid "!$OMP DECLARE SIMD should refer to containing procedure %qs at %L"
 msgstr ""
 
-#: fortran/openmp.c:6179
+#: fortran/openmp.c:6184
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_PRIV or OMP_ORIG used in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6187
+#: fortran/openmp.c:6192
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_OUT or OMP_IN used in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6216
+#: fortran/openmp.c:6221
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid operator for !$OMP DECLARE REDUCTION %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:6238
+#: fortran/openmp.c:6243
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER length in !$OMP DECLARE REDUCTION %s not constant at %L"
 msgstr ""
 
-#: fortran/openmp.c:6254
+#: fortran/openmp.c:6259
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6269
+#: fortran/openmp.c:6274
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6279
+#: fortran/openmp.c:6284
 #, gcc-internal-format, gfc-internal-format
 msgid "One of actual subroutine arguments in INITIALIZER clause of !$OMP DECLARE REDUCTION must be OMP_PRIV at %L"
 msgstr ""
 
-#: fortran/openmp.c:6287
+#: fortran/openmp.c:6292
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing INITIALIZER clause for !$OMP DECLARE REDUCTION of derived type without default initializer at %L"
 msgstr ""
@@ -58136,492 +58213,492 @@
 msgid "Unclassifiable statement at %C"
 msgstr "Μη έγκυρη παράμετρος"
 
-#: fortran/parse.c:629
+#: fortran/parse.c:631
 #, gcc-internal-format, gfc-internal-format
 msgid "OpenACC directives at %C may not appear in PURE procedures"
 msgstr ""
 
-#: fortran/parse.c:705
+#: fortran/parse.c:707
 #, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable OpenACC directive at %C"
 msgstr ""
 
-#: fortran/parse.c:831 fortran/parse.c:1040
+#: fortran/parse.c:835 fortran/parse.c:1044
 #, gcc-internal-format, gfc-internal-format
 msgid "OpenMP directives other than SIMD or DECLARE TARGET at %C may not appear in PURE or ELEMENTAL procedures"
 msgstr ""
 
-#: fortran/parse.c:1024
+#: fortran/parse.c:1028
 #, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable OpenMP directive at %C"
 msgstr ""
 
-#: fortran/parse.c:1076
+#: fortran/parse.c:1080
 #, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable GCC directive at %C"
 msgstr ""
 
-#: fortran/parse.c:1135 fortran/parse.c:1362
+#: fortran/parse.c:1139 fortran/parse.c:1366
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Zero is not a valid statement label at %C"
 msgstr "Μη έγκυρη παράμετρος"
 
-#: fortran/parse.c:1142 fortran/parse.c:1354
+#: fortran/parse.c:1146 fortran/parse.c:1358
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-numeric character in statement label at %C"
 msgstr "κενό αλφαριθμητικό"
 
-#: fortran/parse.c:1154 fortran/parse.c:1403
+#: fortran/parse.c:1158 fortran/parse.c:1407
 #, gcc-internal-format, gfc-internal-format
 msgid "Semicolon at %C needs to be preceded by statement"
 msgstr ""
 
-#: fortran/parse.c:1161 fortran/parse.c:1418
+#: fortran/parse.c:1165 fortran/parse.c:1422
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label without statement at %L"
 msgstr ""
 
-#: fortran/parse.c:1224 fortran/parse.c:1405
+#: fortran/parse.c:1228 fortran/parse.c:1409
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Semicolon at %C without preceding statement"
 msgstr ""
 
-#: fortran/parse.c:1247 fortran/parse.c:1381
+#: fortran/parse.c:1251 fortran/parse.c:1385
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad continuation line at %C"
 msgstr ""
 
-#: fortran/parse.c:1679
+#: fortran/parse.c:1683
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT statement at %L does not have a statement label"
 msgstr ""
 
-#: fortran/parse.c:2435
+#: fortran/parse.c:2439
 #, gcc-internal-format
 msgid "gfc_ascii_statement(): Bad statement code"
 msgstr ""
 
-#: fortran/parse.c:2577
+#: fortran/parse.c:2581
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement at %C"
 msgstr "Μη έγκυρη παράμετρος"
 
-#: fortran/parse.c:2732
+#: fortran/parse.c:2736
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot follow %s statement at %L"
 msgstr ""
 
-#: fortran/parse.c:2749
+#: fortran/parse.c:2753
 #, gcc-internal-format
 msgid "Unexpected end of file in %qs"
 msgstr ""
 
-#: fortran/parse.c:2784
+#: fortran/parse.c:2788
 #, gcc-internal-format
 msgid "Derived-type %qs with SEQUENCE must not have a CONTAINS section at %C"
 msgstr ""
 
-#: fortran/parse.c:2787
+#: fortran/parse.c:2791
 #, gcc-internal-format
 msgid "Derived-type %qs with BIND(C) must not have a CONTAINS section at %C"
 msgstr ""
 
-#: fortran/parse.c:2807
+#: fortran/parse.c:2811
 #, gcc-internal-format, gfc-internal-format
 msgid "Components in TYPE at %C must precede CONTAINS"
 msgstr ""
 
-#: fortran/parse.c:2811
+#: fortran/parse.c:2815
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound procedure at %C"
 msgstr ""
 
-#: fortran/parse.c:2819
+#: fortran/parse.c:2823
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC binding at %C"
 msgstr ""
 
-#: fortran/parse.c:2827
+#: fortran/parse.c:2831
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure declaration at %C"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: fortran/parse.c:2839
+#: fortran/parse.c:2843
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type definition at %C with empty CONTAINS section"
 msgstr ""
 
-#: fortran/parse.c:2849 fortran/parse.c:3304
+#: fortran/parse.c:2853 fortran/parse.c:3308
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement in TYPE at %C must be inside a MODULE"
 msgstr ""
 
-#: fortran/parse.c:2856
+#: fortran/parse.c:2860
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede procedure bindings"
 msgstr ""
 
-#: fortran/parse.c:2863 fortran/parse.c:3317
+#: fortran/parse.c:2867 fortran/parse.c:3321
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PRIVATE statement at %C"
 msgstr ""
 
-#: fortran/parse.c:2873
+#: fortran/parse.c:2877
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede CONTAINS"
 msgstr ""
 
-#: fortran/parse.c:2877
+#: fortran/parse.c:2881
 #, gcc-internal-format, gfc-internal-format
 msgid "Already inside a CONTAINS block at %C"
 msgstr ""
 
-#: fortran/parse.c:2996
+#: fortran/parse.c:3000
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s at %L of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray, which is not possible as the component has the pointer attribute"
 msgstr ""
 
-#: fortran/parse.c:3002
+#: fortran/parse.c:3006
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer component %s at %L has a noncoarray subcomponent of type LOCK_TYPE, which must have a codimension or be a subcomponent of a coarray"
 msgstr ""
 
-#: fortran/parse.c:3007
+#: fortran/parse.c:3011
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L of type LOCK_TYPE must have a codimension"
 msgstr ""
 
-#: fortran/parse.c:3011
+#: fortran/parse.c:3015
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L must have a codimension as it has a noncoarray subcomponent of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/parse.c:3016
+#: fortran/parse.c:3020
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as already a coarray subcomponent exists)"
 msgstr ""
 
-#: fortran/parse.c:3023
+#: fortran/parse.c:3027
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as %s at %L has a codimension or a coarray subcomponent)"
 msgstr ""
 
-#: fortran/parse.c:3033
+#: fortran/parse.c:3037
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s at %L of type EVENT_TYPE must have a codimension or be a subcomponent of a coarray, which is not possible as the component has the pointer attribute"
 msgstr ""
 
-#: fortran/parse.c:3039
+#: fortran/parse.c:3043
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer component %s at %L has a noncoarray subcomponent of type EVENT_TYPE, which must have a codimension or be a subcomponent of a coarray"
 msgstr ""
 
-#: fortran/parse.c:3044
+#: fortran/parse.c:3048
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L of type EVENT_TYPE must have a codimension"
 msgstr ""
 
-#: fortran/parse.c:3048
+#: fortran/parse.c:3052
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L must have a codimension as it has a noncoarray subcomponent of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/parse.c:3053
+#: fortran/parse.c:3057
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as already a coarray subcomponent exists)"
 msgstr ""
 
-#: fortran/parse.c:3060
+#: fortran/parse.c:3064
 #, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as %s at %L has a codimension or a coarray subcomponent)"
 msgstr ""
 
-#: fortran/parse.c:3112
+#: fortran/parse.c:3116
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to create map component '%s'"
 msgstr ""
 
-#: fortran/parse.c:3145
+#: fortran/parse.c:3149
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to create union component '%s'"
 msgstr ""
 
-#: fortran/parse.c:3200
+#: fortran/parse.c:3204
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in nested structure declaration at %C"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: fortran/parse.c:3287
+#: fortran/parse.c:3291
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside CONTAINS"
 msgstr ""
 
-#: fortran/parse.c:3295
+#: fortran/parse.c:3299
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type definition at %C without components"
 msgstr ""
 
-#: fortran/parse.c:3311
+#: fortran/parse.c:3315
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede structure components"
 msgstr ""
 
-#: fortran/parse.c:3328
+#: fortran/parse.c:3332
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede structure components"
 msgstr ""
 
-#: fortran/parse.c:3334
+#: fortran/parse.c:3338
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE attribute at %C already specified in TYPE statement"
 msgstr ""
 
-#: fortran/parse.c:3339
+#: fortran/parse.c:3343
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SEQUENCE statement at %C"
 msgstr ""
 
-#: fortran/parse.c:3349
+#: fortran/parse.c:3353
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS block in derived type definition at %C"
 msgstr ""
 
-#: fortran/parse.c:3407
+#: fortran/parse.c:3411
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM declaration at %C has no ENUMERATORS"
 msgstr ""
 
-#: fortran/parse.c:3494
+#: fortran/parse.c:3498
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in INTERFACE block at %C"
 msgstr ""
 
-#: fortran/parse.c:3518
+#: fortran/parse.c:3522
 #, gcc-internal-format
 msgid "Name %qs of ABSTRACT INTERFACE at %C cannot be the same as an intrinsic type"
 msgstr ""
 
-#: fortran/parse.c:3552
+#: fortran/parse.c:3556
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement at %C in INTERFACE body"
 msgstr ""
 
-#: fortran/parse.c:3570
+#: fortran/parse.c:3574
 #, gcc-internal-format
 msgid "INTERFACE procedure %qs at %L has the same name as the enclosing procedure"
 msgstr ""
 
-#: fortran/parse.c:3700
+#: fortran/parse.c:3704
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement is not allowed inside of BLOCK at %C"
 msgstr ""
 
-#: fortran/parse.c:3732
+#: fortran/parse.c:3736
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement is not allowed inside of BLOCK DATA at %C"
 msgstr ""
 
-#: fortran/parse.c:3822
+#: fortran/parse.c:3826
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement must appear in a MODULE"
 msgstr ""
 
-#: fortran/parse.c:3830
+#: fortran/parse.c:3834
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C follows another accessibility specification"
 msgstr ""
 
-#: fortran/parse.c:3882
+#: fortran/parse.c:3886
 #, fuzzy, gcc-internal-format
 msgid "Bad kind expression for function %qs at %L"
 msgstr "μη έγκυρη τάξη χαρακτήρων `%s'"
 
-#: fortran/parse.c:3886
+#: fortran/parse.c:3890
 #, gcc-internal-format
 msgid "The type for function %qs at %L is not accessible"
 msgstr ""
 
-#: fortran/parse.c:3946
+#: fortran/parse.c:3950
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C follows previous unmasked ELSEWHERE"
 msgstr ""
 
-#: fortran/parse.c:3968
+#: fortran/parse.c:3972
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in WHERE block at %C"
 msgstr ""
 
-#: fortran/parse.c:4027
+#: fortran/parse.c:4031
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in FORALL block at %C"
 msgstr ""
 
-#: fortran/parse.c:4078
+#: fortran/parse.c:4082
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSE IF statement at %C cannot follow ELSE statement at %L"
 msgstr ""
 
-#: fortran/parse.c:4096
+#: fortran/parse.c:4100
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ELSE statements at %L and %C"
 msgstr ""
 
-#: fortran/parse.c:4157
+#: fortran/parse.c:4161
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected a CASE or END SELECT statement following SELECT CASE at %C"
 msgstr ""
 
-#: fortran/parse.c:4241
+#: fortran/parse.c:4245
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected TYPE IS, CLASS IS or END SELECT statement following SELECT TYPE at %C"
 msgstr ""
 
-#: fortran/parse.c:4303
+#: fortran/parse.c:4307
 #, gcc-internal-format
 msgid "Variable %qs at %C cannot be redefined inside loop beginning at %L"
 msgstr ""
 
-#: fortran/parse.c:4336
+#: fortran/parse.c:4340
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is within another block"
 msgstr ""
 
-#: fortran/parse.c:4346
+#: fortran/parse.c:4350
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is interwoven with another DO loop"
 msgstr ""
 
-#: fortran/parse.c:4372
+#: fortran/parse.c:4376
 #, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL block inside of OpenACC region at %C"
 msgstr ""
 
-#: fortran/parse.c:4373
+#: fortran/parse.c:4377
 #, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL block inside of OpenMP region at %C"
 msgstr ""
 
-#: fortran/parse.c:4399
+#: fortran/parse.c:4403
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label in END CRITICAL at %C does not match CRITICAL label"
 msgstr ""
 
-#: fortran/parse.c:4468
+#: fortran/parse.c:4472
 #, gcc-internal-format, gfc-internal-format
 msgid "BLOCK construct at %C"
 msgstr ""
 
-#: fortran/parse.c:4502
+#: fortran/parse.c:4506
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSOCIATE construct at %C"
 msgstr ""
 
-#: fortran/parse.c:4690
+#: fortran/parse.c:4694
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label in ENDDO at %C doesn't match DO label"
 msgstr ""
 
-#: fortran/parse.c:4706
+#: fortran/parse.c:4710
 #, gcc-internal-format, gfc-internal-format
 msgid "Named block DO at %L requires matching ENDDO name"
 msgstr ""
 
-#: fortran/parse.c:4897
+#: fortran/parse.c:4901
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing !$OMP END ATOMIC after !$OMP ATOMIC CAPTURE at %C"
 msgstr ""
 
-#: fortran/parse.c:4913 fortran/parse.c:4972
+#: fortran/parse.c:4917 fortran/parse.c:4976
 #, gcc-internal-format, gfc-internal-format
 msgid "OpenACC directive inside of CRITICAL block at %C"
 msgstr ""
 
-#: fortran/parse.c:4947
+#: fortran/parse.c:4951
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s at %C"
 msgstr ""
 
-#: fortran/parse.c:4991
+#: fortran/parse.c:4995
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected DO loop at %C"
 msgstr ""
 
-#: fortran/parse.c:5011
+#: fortran/parse.c:5015
 #, gcc-internal-format, gfc-internal-format
 msgid "Redundant !$ACC END LOOP at %C"
 msgstr ""
 
-#: fortran/parse.c:5225
+#: fortran/parse.c:5229
 #, gcc-internal-format, gfc-internal-format
 msgid "Name after !$omp critical and !$omp end critical does not match at %C"
 msgstr ""
 
-#: fortran/parse.c:5283
+#: fortran/parse.c:5287
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot terminate a non-block DO loop"
 msgstr ""
 
-#: fortran/parse.c:5297
+#: fortran/parse.c:5301
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %C after the first executable statement"
 msgstr ""
 
-#: fortran/parse.c:5423
+#: fortran/parse.c:5427
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive does not commence a loop at %C"
 msgstr ""
 
-#: fortran/parse.c:5538
+#: fortran/parse.c:5542
 #, fuzzy, gcc-internal-format
 msgid "Contained procedure %qs at %C is already ambiguous"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: fortran/parse.c:5595
+#: fortran/parse.c:5599
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in CONTAINS section at %C"
 msgstr ""
 
-#: fortran/parse.c:5620
+#: fortran/parse.c:5624
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS statement without FUNCTION or SUBROUTINE statement at %L"
 msgstr ""
 
-#: fortran/parse.c:5732
+#: fortran/parse.c:5736
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS statement at %C is already in a contained program unit"
 msgstr ""
 
-#: fortran/parse.c:5784
+#: fortran/parse.c:5788
 #, gcc-internal-format
 msgid "Global binding name %qs at %L is already being used as a %s at %L"
 msgstr ""
 
-#: fortran/parse.c:5788
+#: fortran/parse.c:5792
 #, gcc-internal-format
 msgid "Global name %qs at %L is already being used as a %s at %L"
 msgstr ""
 
-#: fortran/parse.c:5794
+#: fortran/parse.c:5798
 #, gcc-internal-format
 msgid "Global binding name %qs at %L is already being used at %L"
 msgstr ""
 
-#: fortran/parse.c:5797
+#: fortran/parse.c:5801
 #, gcc-internal-format
 msgid "Global name %qs at %L is already being used at %L"
 msgstr ""
 
-#: fortran/parse.c:5819
+#: fortran/parse.c:5823
 #, gcc-internal-format, gfc-internal-format
 msgid "Blank BLOCK DATA at %C conflicts with prior BLOCK DATA at %L"
 msgstr ""
 
-#: fortran/parse.c:5845
+#: fortran/parse.c:5849
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in BLOCK DATA at %C"
 msgstr ""
 
-#: fortran/parse.c:5949
+#: fortran/parse.c:5953
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in MODULE at %C"
 msgstr ""
@@ -58629,7 +58706,7 @@
 #. If we see a duplicate main program, shut down.  If the second
 #. instance is an implied main program, i.e. data decls or executable
 #. statements, we're in for lots of errors.
-#: fortran/parse.c:6333
+#: fortran/parse.c:6337
 #, gcc-internal-format, gfc-internal-format
 msgid "Two main PROGRAMs at %L and %C"
 msgstr ""
@@ -59379,7 +59456,7 @@
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr ""
 
-#: fortran/resolve.c:1893 fortran/resolve.c:9560 fortran/resolve.c:11225
+#: fortran/resolve.c:1893 fortran/resolve.c:9573 fortran/resolve.c:11245
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr ""
@@ -59491,7 +59568,7 @@
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr ""
 
-#: fortran/resolve.c:2905 fortran/resolve.c:16283
+#: fortran/resolve.c:2905 fortran/resolve.c:16310
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr ""
@@ -59612,197 +59689,197 @@
 msgid "logical_to_bitwise(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:4059
+#: fortran/resolve.c:4065
 #, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr ""
 
-#: fortran/resolve.c:4229 fortran/resolve.c:4252
+#: fortran/resolve.c:4235 fortran/resolve.c:4258
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:4347
+#: fortran/resolve.c:4353
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4352
+#: fortran/resolve.c:4358
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4362
+#: fortran/resolve.c:4368
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4367
+#: fortran/resolve.c:4373
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4387
+#: fortran/resolve.c:4393
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr ""
 
-#: fortran/resolve.c:4404
+#: fortran/resolve.c:4410
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4412
+#: fortran/resolve.c:4418
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4428
+#: fortran/resolve.c:4434
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4437
+#: fortran/resolve.c:4443
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr ""
 
-#: fortran/resolve.c:4453
+#: fortran/resolve.c:4459
 #, gcc-internal-format
 msgid "check_dimension(): Bad array reference"
 msgstr ""
 
-#: fortran/resolve.c:4476
+#: fortran/resolve.c:4482
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:4486
+#: fortran/resolve.c:4492
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.c:4494
+#: fortran/resolve.c:4500
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr ""
 
-#: fortran/resolve.c:4510
+#: fortran/resolve.c:4516
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr ""
 
-#: fortran/resolve.c:4538
+#: fortran/resolve.c:4544
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4544
+#: fortran/resolve.c:4550
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr ""
 
-#: fortran/resolve.c:4550
+#: fortran/resolve.c:4556
 #, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr ""
 
-#: fortran/resolve.c:4589
+#: fortran/resolve.c:4595
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: fortran/resolve.c:4596
+#: fortran/resolve.c:4602
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: fortran/resolve.c:4641
+#: fortran/resolve.c:4647
 #, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr ""
 
-#: fortran/resolve.c:4652
+#: fortran/resolve.c:4658
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.c:4663
+#: fortran/resolve.c:4669
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.c:4706
+#: fortran/resolve.c:4712
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: fortran/resolve.c:4804
+#: fortran/resolve.c:4810
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:4811
+#: fortran/resolve.c:4817
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4820
+#: fortran/resolve.c:4826
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr ""
 
-#: fortran/resolve.c:4833
+#: fortran/resolve.c:4839
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:4840
+#: fortran/resolve.c:4846
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:4850
+#: fortran/resolve.c:4856
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr ""
 
-#: fortran/resolve.c:4860
+#: fortran/resolve.c:4866
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr "Κακή αίτηση παραμέτρων"
 
-#: fortran/resolve.c:5013
+#: fortran/resolve.c:5019
 #, gcc-internal-format
 msgid "resolve_ref(): Bad array reference"
 msgstr ""
 
-#: fortran/resolve.c:5027
+#: fortran/resolve.c:5033
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:5037
+#: fortran/resolve.c:5043
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:5056
+#: fortran/resolve.c:5062
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr ""
 
-#: fortran/resolve.c:5154
+#: fortran/resolve.c:5160
 #, gcc-internal-format
 msgid "expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.c:5236
+#: fortran/resolve.c:5242
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr ""
 
-#: fortran/resolve.c:5246
+#: fortran/resolve.c:5252
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -59811,12 +59888,12 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5256
+#: fortran/resolve.c:5262
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5271
+#: fortran/resolve.c:5277
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr ""
@@ -59825,268 +59902,268 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5281
+#: fortran/resolve.c:5287
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5292
+#: fortran/resolve.c:5298
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5301
+#: fortran/resolve.c:5307
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5316
+#: fortran/resolve.c:5322
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr ""
 
-#: fortran/resolve.c:5478
+#: fortran/resolve.c:5484
 #, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5483
+#: fortran/resolve.c:5489
 #, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr ""
 
-#: fortran/resolve.c:5553
+#: fortran/resolve.c:5559
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr ""
 
-#: fortran/resolve.c:5566
+#: fortran/resolve.c:5572
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr ""
 
-#: fortran/resolve.c:5919
+#: fortran/resolve.c:5925
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:5926
+#: fortran/resolve.c:5932
 #, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5961
+#: fortran/resolve.c:5967
 #, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr ""
 
-#: fortran/resolve.c:5970
+#: fortran/resolve.c:5976
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr ""
 
 #. Nothing matching found!
-#: fortran/resolve.c:6158
+#: fortran/resolve.c:6164
 #, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:6185
+#: fortran/resolve.c:6191
 #, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:6236
+#: fortran/resolve.c:6242
 #, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:6786
+#: fortran/resolve.c:6792
 #, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr ""
 
-#: fortran/resolve.c:6812
+#: fortran/resolve.c:6818
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr ""
 
-#: fortran/resolve.c:6822
+#: fortran/resolve.c:6828
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: fortran/resolve.c:6826 fortran/resolve.c:6833
+#: fortran/resolve.c:6832 fortran/resolve.c:6839
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:6875
+#: fortran/resolve.c:6881
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:6911
+#: fortran/resolve.c:6917
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr ""
 
-#: fortran/resolve.c:6928
+#: fortran/resolve.c:6934
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.c:6934
+#: fortran/resolve.c:6940
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.c:6995
+#: fortran/resolve.c:7001
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7000
+#: fortran/resolve.c:7006
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7007
+#: fortran/resolve.c:7013
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr ""
 
-#: fortran/resolve.c:7015
+#: fortran/resolve.c:7021
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr ""
 
-#: fortran/resolve.c:7020
+#: fortran/resolve.c:7026
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr ""
 
-#: fortran/resolve.c:7033
+#: fortran/resolve.c:7039
 #, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr ""
 
-#: fortran/resolve.c:7136 fortran/resolve.c:7428
+#: fortran/resolve.c:7142 fortran/resolve.c:7434
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:7144 fortran/resolve.c:7393
+#: fortran/resolve.c:7150 fortran/resolve.c:7399
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7250
+#: fortran/resolve.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr ""
 
-#: fortran/resolve.c:7281
+#: fortran/resolve.c:7287
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr ""
 
-#: fortran/resolve.c:7439
+#: fortran/resolve.c:7445
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr ""
 
-#: fortran/resolve.c:7451
+#: fortran/resolve.c:7457
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr ""
 
-#: fortran/resolve.c:7465
+#: fortran/resolve.c:7471
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7480
+#: fortran/resolve.c:7486
 #, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr ""
 
-#: fortran/resolve.c:7493
+#: fortran/resolve.c:7499
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr ""
 
-#: fortran/resolve.c:7511
+#: fortran/resolve.c:7517
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr ""
 
-#: fortran/resolve.c:7592 fortran/resolve.c:7607
+#: fortran/resolve.c:7598 fortran/resolve.c:7613
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7599
+#: fortran/resolve.c:7605
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7622
+#: fortran/resolve.c:7628
 #, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7649
+#: fortran/resolve.c:7655
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7668
+#: fortran/resolve.c:7674
 #, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr ""
 
-#: fortran/resolve.c:7683
+#: fortran/resolve.c:7689
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7694
+#: fortran/resolve.c:7700
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:7726
+#: fortran/resolve.c:7732
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:7749
+#: fortran/resolve.c:7755
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:7760
+#: fortran/resolve.c:7766
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr ""
 
-#: fortran/resolve.c:7771
+#: fortran/resolve.c:7782
 #, gcc-internal-format, gfc-internal-format
-msgid "Errmsg-variable at %L must be a scalar CHARACTER variable"
+msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:7794
+#: fortran/resolve.c:7805
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr ""
 
-#: fortran/resolve.c:7824
+#: fortran/resolve.c:7835
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr ""
 
-#: fortran/resolve.c:7830 fortran/resolve.c:7836
+#: fortran/resolve.c:7841 fortran/resolve.c:7847
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr ""
@@ -60095,232 +60172,232 @@
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8064
+#: fortran/resolve.c:8075
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr ""
 
-#: fortran/resolve.c:8115
+#: fortran/resolve.c:8126
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr ""
 
-#: fortran/resolve.c:8126
+#: fortran/resolve.c:8137
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr ""
 
-#: fortran/resolve.c:8139
+#: fortran/resolve.c:8150
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:8185
+#: fortran/resolve.c:8196
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr ""
 
-#: fortran/resolve.c:8204
+#: fortran/resolve.c:8215
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr ""
 
-#: fortran/resolve.c:8214
+#: fortran/resolve.c:8225
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr ""
 
-#: fortran/resolve.c:8232 fortran/resolve.c:8240
+#: fortran/resolve.c:8243 fortran/resolve.c:8251
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr ""
 
-#: fortran/resolve.c:8302 fortran/resolve.c:8873
+#: fortran/resolve.c:8313 fortran/resolve.c:8884
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr ""
 
-#: fortran/resolve.c:8328
+#: fortran/resolve.c:8339
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:8340
+#: fortran/resolve.c:8351
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr ""
 
-#: fortran/resolve.c:8355
+#: fortran/resolve.c:8366
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr ""
 
-#: fortran/resolve.c:8458
+#: fortran/resolve.c:8469
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr ""
 
-#: fortran/resolve.c:8518
+#: fortran/resolve.c:8529
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr ""
 
-#: fortran/resolve.c:8523
+#: fortran/resolve.c:8534
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr ""
 
-#: fortran/resolve.c:8545
+#: fortran/resolve.c:8556
 #, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr ""
 
-#: fortran/resolve.c:8556
+#: fortran/resolve.c:8567
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:8763
+#: fortran/resolve.c:8774
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:8783 fortran/resolve.c:8795
+#: fortran/resolve.c:8794 fortran/resolve.c:8806
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr ""
 
-#: fortran/resolve.c:8824
+#: fortran/resolve.c:8835
 #, gcc-internal-format, gfc-internal-format
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr ""
 
-#: fortran/resolve.c:8836
+#: fortran/resolve.c:8847
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr ""
 
-#: fortran/resolve.c:8848
+#: fortran/resolve.c:8859
 #, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr ""
 
-#: fortran/resolve.c:8851
+#: fortran/resolve.c:8862
 #, fuzzy, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: fortran/resolve.c:8861
+#: fortran/resolve.c:8872
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr ""
 
-#: fortran/resolve.c:9108
+#: fortran/resolve.c:9119
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9204
+#: fortran/resolve.c:9215
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr ""
 
-#: fortran/resolve.c:9257
+#: fortran/resolve.c:9268
 #, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr ""
 
-#: fortran/resolve.c:9267
+#: fortran/resolve.c:9278
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9280
+#: fortran/resolve.c:9291
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9289
+#: fortran/resolve.c:9300
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr ""
 
-#: fortran/resolve.c:9296
+#: fortran/resolve.c:9307
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9307
+#: fortran/resolve.c:9318
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr ""
 
-#: fortran/resolve.c:9313
+#: fortran/resolve.c:9324
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr ""
 
-#: fortran/resolve.c:9328
+#: fortran/resolve.c:9339
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:9388
+#: fortran/resolve.c:9399
 #, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:9398
+#: fortran/resolve.c:9409
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr ""
 
-#: fortran/resolve.c:9402
+#: fortran/resolve.c:9413
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr ""
 
-#: fortran/resolve.c:9405
+#: fortran/resolve.c:9416
 #, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr ""
 
-#: fortran/resolve.c:9412 fortran/resolve.c:9533
+#: fortran/resolve.c:9423 fortran/resolve.c:9545
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: fortran/resolve.c:9424 fortran/resolve.c:9540
+#: fortran/resolve.c:9435 fortran/resolve.c:9553
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr ""
 
-#: fortran/resolve.c:9436
+#: fortran/resolve.c:9447
 #, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr ""
 
-#: fortran/resolve.c:9449
+#: fortran/resolve.c:9460
 #, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:9510
+#: fortran/resolve.c:9521
 #, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:9514 fortran/resolve.c:9524
+#: fortran/resolve.c:9525 fortran/resolve.c:9535
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: fortran/resolve.c:9567
+#: fortran/resolve.c:9580
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9577
+#: fortran/resolve.c:9590
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr ""
@@ -60327,12 +60404,12 @@
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:9594 fortran/resolve.c:9617
+#: fortran/resolve.c:9607 fortran/resolve.c:9630
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr ""
 
-#: fortran/resolve.c:9598 fortran/resolve.c:9623
+#: fortran/resolve.c:9611 fortran/resolve.c:9636
 #, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr ""
@@ -60340,107 +60417,107 @@
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:9638
+#: fortran/resolve.c:9651
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:9710
+#: fortran/resolve.c:9723
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:9726
+#: fortran/resolve.c:9739
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr ""
 
-#: fortran/resolve.c:9734 fortran/resolve.c:9821
+#: fortran/resolve.c:9747 fortran/resolve.c:9834
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:9744 fortran/resolve.c:9831
+#: fortran/resolve.c:9757 fortran/resolve.c:9844
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr ""
 
-#: fortran/resolve.c:9775
+#: fortran/resolve.c:9788
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "Μη αναγνωρίσιμη μεταβλητή `%s'"
 
-#: fortran/resolve.c:9784
+#: fortran/resolve.c:9797
 #, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr ""
 
-#: fortran/resolve.c:9949
+#: fortran/resolve.c:9962
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr ""
 
-#: fortran/resolve.c:9959
+#: fortran/resolve.c:9972
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr ""
 
-#: fortran/resolve.c:10036
+#: fortran/resolve.c:10049
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr ""
 
-#: fortran/resolve.c:10138
+#: fortran/resolve.c:10151
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:10251
+#: fortran/resolve.c:10264
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr ""
 
-#: fortran/resolve.c:10283
+#: fortran/resolve.c:10296
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:10288
+#: fortran/resolve.c:10301
 #, gcc-internal-format, gfc-internal-format
 msgid "The impure variable at %L is assigned to a derived type variable with a POINTER component in a PURE procedure (12.6)"
 msgstr ""
 
-#: fortran/resolve.c:10298
+#: fortran/resolve.c:10311
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr ""
 
-#: fortran/resolve.c:10330
+#: fortran/resolve.c:10343
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:10334
+#: fortran/resolve.c:10347
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr ""
 
-#: fortran/resolve.c:10339
+#: fortran/resolve.c:10352
 #, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr ""
 
-#: fortran/resolve.c:10346
+#: fortran/resolve.c:10359
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr ""
 
-#: fortran/resolve.c:10357
+#: fortran/resolve.c:10370
 #, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:10663
+#: fortran/resolve.c:10683
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
@@ -60447,67 +60524,67 @@
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:10905
+#: fortran/resolve.c:10925
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer procedure assignment at %L"
 msgstr ""
 
-#: fortran/resolve.c:10917
+#: fortran/resolve.c:10937
 #, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr ""
 
-#: fortran/resolve.c:11157
+#: fortran/resolve.c:11177
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:11160
+#: fortran/resolve.c:11180
 #, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr ""
 
-#: fortran/resolve.c:11171
+#: fortran/resolve.c:11191
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr ""
 
-#: fortran/resolve.c:11233
+#: fortran/resolve.c:11253
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr ""
 
-#: fortran/resolve.c:11278
+#: fortran/resolve.c:11298
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid NULL at %L"
 msgstr ""
 
-#: fortran/resolve.c:11282
+#: fortran/resolve.c:11302
 #, gcc-internal-format, gfc-internal-format
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr ""
 
-#: fortran/resolve.c:11339
+#: fortran/resolve.c:11359
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:11344
+#: fortran/resolve.c:11364
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:11428
+#: fortran/resolve.c:11448
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr ""
 
-#: fortran/resolve.c:11507
+#: fortran/resolve.c:11527
 #, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr ""
 
-#: fortran/resolve.c:11617
+#: fortran/resolve.c:11637
 #, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
@@ -60514,7 +60591,7 @@
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:11630
+#: fortran/resolve.c:11650
 #, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr ""
@@ -60522,57 +60599,57 @@
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:11647
+#: fortran/resolve.c:11667
 #, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr ""
 
-#: fortran/resolve.c:11732
+#: fortran/resolve.c:11752
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "σχετική θέση αρχείου είναι εκτός ορίων"
 
-#: fortran/resolve.c:11961
+#: fortran/resolve.c:11981
 #, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:11965
+#: fortran/resolve.c:11985
 #, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:11973
+#: fortran/resolve.c:11993
 #, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr ""
 
-#: fortran/resolve.c:11983
+#: fortran/resolve.c:12003
 #, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:11998
+#: fortran/resolve.c:12018
 #, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr ""
 
-#: fortran/resolve.c:12010
+#: fortran/resolve.c:12030
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr ""
 
-#: fortran/resolve.c:12041
+#: fortran/resolve.c:12061
 #, gcc-internal-format
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr ""
 
-#: fortran/resolve.c:12063
+#: fortran/resolve.c:12083
 #, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr ""
 
-#: fortran/resolve.c:12090
+#: fortran/resolve.c:12110
 #, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr ""
@@ -60579,889 +60656,894 @@
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12131
+#: fortran/resolve.c:12151
 #, gcc-internal-format
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr ""
 
-#: fortran/resolve.c:12150
+#: fortran/resolve.c:12170
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr ""
 
-#: fortran/resolve.c:12171
+#: fortran/resolve.c:12191
 #, gcc-internal-format
 msgid "%qs at %L must have constant character length in this context"
 msgstr ""
 
-#: fortran/resolve.c:12178
+#: fortran/resolve.c:12198
 #, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr ""
 
-#: fortran/resolve.c:12225
+#: fortran/resolve.c:12245
 #, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12228
+#: fortran/resolve.c:12248
 #, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12232
+#: fortran/resolve.c:12252
 #, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12235
+#: fortran/resolve.c:12255
 #, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12238
+#: fortran/resolve.c:12258
 #, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12241
+#: fortran/resolve.c:12261
 #, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr ""
 
 # src/request.c:37
-#: fortran/resolve.c:12283
+#: fortran/resolve.c:12303
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "fstat %s"
 msgid "%s at %L"
 msgstr "fstat %s"
 
-#: fortran/resolve.c:12310
+#: fortran/resolve.c:12330
 #, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:12332
+#: fortran/resolve.c:12352
 #, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:12354
+#: fortran/resolve.c:12374
 #, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr ""
 
-#: fortran/resolve.c:12372
+#: fortran/resolve.c:12392
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: fortran/resolve.c:12381
+#: fortran/resolve.c:12401
 #, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr ""
 
-#: fortran/resolve.c:12389
+#: fortran/resolve.c:12409
 #, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr ""
 
-#: fortran/resolve.c:12399
+#: fortran/resolve.c:12419
 #, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr ""
 
-#: fortran/resolve.c:12418
+#: fortran/resolve.c:12438
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr ""
 
-#: fortran/resolve.c:12422
+#: fortran/resolve.c:12442
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr ""
 
-#: fortran/resolve.c:12426
+#: fortran/resolve.c:12446
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr ""
 
-#: fortran/resolve.c:12430
+#: fortran/resolve.c:12450
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: fortran/resolve.c:12443
+#: fortran/resolve.c:12463
 #, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12452
+#: fortran/resolve.c:12472
 #, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:12458
+#: fortran/resolve.c:12478
 #, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr ""
 
-#: fortran/resolve.c:12470
+#: fortran/resolve.c:12490
 #, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:12527
+#: fortran/resolve.c:12547
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12533
+#: fortran/resolve.c:12553
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12539
+#: fortran/resolve.c:12559
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12547
+#: fortran/resolve.c:12567
 #, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12553
+#: fortran/resolve.c:12573
 #, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr ""
 
-#: fortran/resolve.c:12596
+#: fortran/resolve.c:12616
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12604
+#: fortran/resolve.c:12624
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12612
+#: fortran/resolve.c:12632
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12621
+#: fortran/resolve.c:12641
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.c:12705
+#: fortran/resolve.c:12725
 #, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr ""
 
-#: fortran/resolve.c:12714
+#: fortran/resolve.c:12734
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "η `%s' παίρνει είτε κανένα είτε δύο ορίσματα"
 
-#: fortran/resolve.c:12723
+#: fortran/resolve.c:12743
 #, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr ""
 
-#: fortran/resolve.c:12731
+#: fortran/resolve.c:12751
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr ""
 
-#: fortran/resolve.c:12737
+#: fortran/resolve.c:12757
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:12743
+#: fortran/resolve.c:12763
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr ""
 
-#: fortran/resolve.c:12751
+#: fortran/resolve.c:12771
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:12760
+#: fortran/resolve.c:12780
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr ""
 
-#: fortran/resolve.c:12782
+#: fortran/resolve.c:12802
 #, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr ""
 
-#: fortran/resolve.c:12819
+#: fortran/resolve.c:12839
 #, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr ""
 
-#: fortran/resolve.c:12859
+#: fortran/resolve.c:12879
 #, gcc-internal-format
 msgid "%qs and %qs can't be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12895
+#: fortran/resolve.c:12915
 #, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr ""
 
-#: fortran/resolve.c:12954
+#: fortran/resolve.c:12974
 #, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:12966
+#: fortran/resolve.c:12986
 #, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr ""
 
-#: fortran/resolve.c:12994
+#: fortran/resolve.c:13014
 #, gcc-internal-format
 msgid "GENERIC %qs at %L can't overwrite specific binding with the same name"
 msgstr ""
 
-#: fortran/resolve.c:13050
+#: fortran/resolve.c:13070
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L can't be NOPASS"
 msgstr ""
 
-#: fortran/resolve.c:13242
+#: fortran/resolve.c:13262
 #, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr ""
 
-#: fortran/resolve.c:13284
+#: fortran/resolve.c:13304
 #, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:13298
+#: fortran/resolve.c:13318
 #, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:13312 fortran/resolve.c:13778
+#: fortran/resolve.c:13332 fortran/resolve.c:13798
 #, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13320
+#: fortran/resolve.c:13340
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr ""
 
-#: fortran/resolve.c:13329
+#: fortran/resolve.c:13349
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:13335
+#: fortran/resolve.c:13355
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13341
+#: fortran/resolve.c:13361
 #, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr ""
 
-#: fortran/resolve.c:13370
+#: fortran/resolve.c:13390
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:13380
+#: fortran/resolve.c:13400
 #, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr ""
 
-#: fortran/resolve.c:13472
+#: fortran/resolve.c:13492
 #, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr ""
 
-#: fortran/resolve.c:13574
+#: fortran/resolve.c:13594
 #, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:13583
+#: fortran/resolve.c:13603
 #, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:13593
+#: fortran/resolve.c:13613
 #, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr ""
 
-#: fortran/resolve.c:13602
+#: fortran/resolve.c:13622
 #, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr ""
 
-#: fortran/resolve.c:13613
+#: fortran/resolve.c:13633
 #, gcc-internal-format
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.c:13711
+#: fortran/resolve.c:13731
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr ""
 
-#: fortran/resolve.c:13725
+#: fortran/resolve.c:13745
 #, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:13741
+#: fortran/resolve.c:13761
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:13751
+#: fortran/resolve.c:13771
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr ""
 
-#: fortran/resolve.c:13760
+#: fortran/resolve.c:13780
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr ""
 
-#: fortran/resolve.c:13769
+#: fortran/resolve.c:13789
 #, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13811
+#: fortran/resolve.c:13831
 #, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr ""
 
-#: fortran/resolve.c:13824
+#: fortran/resolve.c:13844
 #, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr ""
 
-#: fortran/resolve.c:13835
+#: fortran/resolve.c:13855
 #, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr ""
 
-#: fortran/resolve.c:13868
+#: fortran/resolve.c:13888
 #, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr ""
 
-#: fortran/resolve.c:13876
+#: fortran/resolve.c:13896
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr ""
 
-#: fortran/resolve.c:13885
+#: fortran/resolve.c:13905
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr ""
 
-#: fortran/resolve.c:13903 fortran/resolve.c:13915
+#: fortran/resolve.c:13923 fortran/resolve.c:13935
 #, gcc-internal-format
 msgid "The pointer component %qs of %qs at %L is a type that has not been declared"
 msgstr ""
 
-#: fortran/resolve.c:13989
+#: fortran/resolve.c:14009
 #, gcc-internal-format, gfc-internal-format
 msgid "Conflicting initializers in union at %L and %L"
 msgstr ""
 
-#: fortran/resolve.c:14034
+#: fortran/resolve.c:14054
 #, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr ""
 
-#: fortran/resolve.c:14047
+#: fortran/resolve.c:14067
 #, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr ""
 
-#: fortran/resolve.c:14111
+#: fortran/resolve.c:14131
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14144
+#: fortran/resolve.c:14164
 #, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.c:14216
+#: fortran/resolve.c:14236
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:14222
+#: fortran/resolve.c:14242
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14228
+#: fortran/resolve.c:14248
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14236
+#: fortran/resolve.c:14256
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14253
+#: fortran/resolve.c:14273
 #, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14275
+#: fortran/resolve.c:14295
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14286
+#: fortran/resolve.c:14306
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14313
+#: fortran/resolve.c:14333
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14337
+#: fortran/resolve.c:14357
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:14353
+#: fortran/resolve.c:14373
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:14364
+#: fortran/resolve.c:14384
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr ""
 
-#: fortran/resolve.c:14372
+#: fortran/resolve.c:14392
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr ""
 
-#: fortran/resolve.c:14423
+#: fortran/resolve.c:14443
 #, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr ""
 
-#: fortran/resolve.c:14434
+#: fortran/resolve.c:14454
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.c:14441
+#: fortran/resolve.c:14461
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.c:14480
+#: fortran/resolve.c:14500
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:14544
+#: fortran/resolve.c:14564
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:14547
+#: fortran/resolve.c:14567
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:14643
+#: fortran/resolve.c:14663
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:14664
+#: fortran/resolve.c:14684
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad specification for assumed size array at %L"
 msgstr ""
 
-#: fortran/resolve.c:14677
+#: fortran/resolve.c:14697
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14680
+#: fortran/resolve.c:14700
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14688
+#: fortran/resolve.c:14708
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14695
+#: fortran/resolve.c:14715
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:14708
+#: fortran/resolve.c:14728
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr ""
 
-#: fortran/resolve.c:14714
+#: fortran/resolve.c:14734
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14724
+#: fortran/resolve.c:14744
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:14733
+#: fortran/resolve.c:14753
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.c:14746 fortran/resolve.c:14923
+#: fortran/resolve.c:14766 fortran/resolve.c:14943
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.c:14760
+#: fortran/resolve.c:14780
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14769
+#: fortran/resolve.c:14789
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:14778
+#: fortran/resolve.c:14798
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14786
+#: fortran/resolve.c:14806
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:14793
+#: fortran/resolve.c:14813
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:14813
+#: fortran/resolve.c:14833
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.c:14820
+#: fortran/resolve.c:14840
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14827
+#: fortran/resolve.c:14847
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:14834
+#: fortran/resolve.c:14854
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:14860
+#: fortran/resolve.c:14880
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:14870
+#: fortran/resolve.c:14890
 #, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr ""
 
-#: fortran/resolve.c:14949
+#: fortran/resolve.c:14969
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:14964
+#: fortran/resolve.c:14984
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14977
+#: fortran/resolve.c:14997
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14995
+#: fortran/resolve.c:15015
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.c:15007
+#: fortran/resolve.c:15027
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:15016
+#: fortran/resolve.c:15036
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:15028
+#: fortran/resolve.c:15048
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr ""
 
-#: fortran/resolve.c:15037
+#: fortran/resolve.c:15057
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15049
+#: fortran/resolve.c:15069
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:15065
+#: fortran/resolve.c:15085
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:15073
+#: fortran/resolve.c:15093
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15080
+#: fortran/resolve.c:15100
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:15092
+#: fortran/resolve.c:15112
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.c:15101
+#: fortran/resolve.c:15121
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15117
+#: fortran/resolve.c:15137
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15123
+#: fortran/resolve.c:15143
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15148
+#: fortran/resolve.c:15168
 #, gcc-internal-format
 msgid "Namelist %qs can not be an argument to subroutine or function at %L"
 msgstr ""
 
-#: fortran/resolve.c:15218
+#: fortran/resolve.c:15238
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:15229
+#: fortran/resolve.c:15249
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:15333
+#: fortran/resolve.c:15353
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:15339
+#: fortran/resolve.c:15359
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:15345
+#: fortran/resolve.c:15365
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.c:15354
+#: fortran/resolve.c:15374
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr ""
 
-#: fortran/resolve.c:15368
+#: fortran/resolve.c:15388
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:15414
+#: fortran/resolve.c:15434
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.c:15427
+#: fortran/resolve.c:15447
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.c:15526
+#: fortran/resolve.c:15546
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15534
+#: fortran/resolve.c:15554
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15542
+#: fortran/resolve.c:15562
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15667
+#: fortran/resolve.c:15687
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.c:15832
+#: fortran/resolve.c:15852
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: fortran/resolve.c:15838
+#: fortran/resolve.c:15858
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr ""
 
-#: fortran/resolve.c:15922
+#: fortran/resolve.c:15942
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15931
+#: fortran/resolve.c:15951
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15939
+#: fortran/resolve.c:15959
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:15955
+#: fortran/resolve.c:15975
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16058
+#: fortran/resolve.c:16078
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:16073
+#: fortran/resolve.c:16093
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:16098
+#: fortran/resolve.c:16118
 #, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:16107
+#: fortran/resolve.c:16127
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16180
+#: fortran/resolve.c:16200
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16191
+#: fortran/resolve.c:16211
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:16202
+#: fortran/resolve.c:16222
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr ""
 
-#: fortran/resolve.c:16293
+#: fortran/resolve.c:16253
 #, gcc-internal-format
+msgid "Self reference in character length expression for %qs at %L"
+msgstr ""
+
+#: fortran/resolve.c:16320
+#, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.c:16306
+#: fortran/resolve.c:16333
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:16326
+#: fortran/resolve.c:16353
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:16336
+#: fortran/resolve.c:16363
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr ""
 
-#: fortran/resolve.c:16344
+#: fortran/resolve.c:16371
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:16358
+#: fortran/resolve.c:16385
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:16376
+#: fortran/resolve.c:16403
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:16383
+#: fortran/resolve.c:16410
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr ""
 
-#: fortran/resolve.c:16461
+#: fortran/resolve.c:16488
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -61787,19 +61869,12 @@
 msgid "simplify_min_max(): Bad type in arglist"
 msgstr ""
 
-#. Result is processor-dependent.
-#: fortran/simplify.c:5472
-#, gcc-internal-format, gfc-internal-format
-msgid "Second argument MOD at %L is zero"
+#: fortran/simplify.c:5470 fortran/simplify.c:5478
+#, gcc-internal-format
+msgid "Argument %qs of MOD at %L shall not be zero"
 msgstr ""
 
-#. Result is processor-dependent.
-#: fortran/simplify.c:5483
-#, gcc-internal-format, gfc-internal-format
-msgid "Second argument of MOD at %L is zero"
-msgstr ""
-
-#: fortran/simplify.c:5494
+#: fortran/simplify.c:5484
 #, gcc-internal-format
 msgid "gfc_simplify_mod(): Bad arguments"
 msgstr ""
@@ -61807,97 +61882,97 @@
 #. Result is processor-dependent. This processor just opts
 #. to not handle it at all.
 #. Result is processor-dependent.
-#: fortran/simplify.c:5520 fortran/simplify.c:5532
+#: fortran/simplify.c:5525 fortran/simplify.c:5537
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of MODULO at %L is zero"
 msgstr ""
 
-#: fortran/simplify.c:5552
+#: fortran/simplify.c:5557
 #, gcc-internal-format
 msgid "gfc_simplify_modulo(): Bad arguments"
 msgstr ""
 
-#: fortran/simplify.c:5600
+#: fortran/simplify.c:5605
 #, gcc-internal-format, gfc-internal-format
 msgid "Result of NEAREST is NaN at %L"
 msgstr ""
 
-#: fortran/simplify.c:6081
+#: fortran/simplify.c:6086
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative at %L"
 msgstr ""
 
-#: fortran/simplify.c:6137
+#: fortran/simplify.c:6142
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument NCOPIES of REPEAT intrinsic is too large at %L"
 msgstr ""
 
-#: fortran/simplify.c:6174
+#: fortran/simplify.c:6179
 #, gcc-internal-format, gfc-internal-format
 msgid "Evaluation of string longer than 2**28 at %L deferred to runtime, expect bugs"
 msgstr ""
 
-#: fortran/simplify.c:6302
+#: fortran/simplify.c:6307
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Reshaped array too large at %C"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: fortran/simplify.c:6416
+#: fortran/simplify.c:6421
 #, gcc-internal-format, gfc-internal-format
 msgid "Result of SCALE overflows its kind at %L"
 msgstr ""
 
-#: fortran/simplify.c:6995
+#: fortran/simplify.c:7000
 #, gcc-internal-format
 msgid "Bad type in gfc_simplify_sign"
 msgstr ""
 
-#: fortran/simplify.c:7024
+#: fortran/simplify.c:7029
 #, gcc-internal-format
 msgid "in gfc_simplify_sin(): Bad type"
 msgstr ""
 
-#: fortran/simplify.c:7151 fortran/simplify.c:7431
+#: fortran/simplify.c:7156 fortran/simplify.c:7436
 #, gcc-internal-format
 msgid "Failure getting length of a constant array."
 msgstr ""
 
-#: fortran/simplify.c:7161
+#: fortran/simplify.c:7166
 #, gcc-internal-format
 msgid "The number of elements (%d) in the array constructor at %L requires an increase of the allowed %d upper limit.  See %<-fmax-array-constructor%> option."
 msgstr ""
 
-#: fortran/simplify.c:7227
+#: fortran/simplify.c:7232
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Simplification of SPREAD at %C not yet implemented"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: fortran/simplify.c:7251
+#: fortran/simplify.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SQRT at %L has a negative value"
 msgstr ""
 
-#: fortran/simplify.c:7267
+#: fortran/simplify.c:7272
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid argument of SQRT at %L"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: fortran/simplify.c:7598
+#: fortran/simplify.c:7603
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY lower bound is %ld)"
 msgstr ""
 
-#: fortran/simplify.c:7621
+#: fortran/simplify.c:7626
 #, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY upper bound is %ld)"
 msgstr ""
 
-#: fortran/simplify.c:7993
+#: fortran/simplify.c:7998
 #, gcc-internal-format
 msgid "gfc_convert_constant(): Unexpected type"
 msgstr ""
 
-#: fortran/simplify.c:8078
+#: fortran/simplify.c:8083
 #, gcc-internal-format
 msgid "Character %qs in string at %L cannot be converted into character kind %d"
 msgstr ""
@@ -62000,7 +62075,7 @@
 msgid "BIND(C) applied to %s %s at %L"
 msgstr ""
 
-#: fortran/symbol.c:901 fortran/symbol.c:912 fortran/symbol.c:1762
+#: fortran/symbol.c:901 fortran/symbol.c:912 fortran/symbol.c:1776
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s attribute conflicts with %s attribute at %L"
 msgstr "%s: οι τιμές του πεδίου `%s' δεν πρέπει να είναι μεγαλύτερες από %d"
@@ -62075,17 +62150,22 @@
 msgid "Duplicate VOLATILE attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1367
+#: fortran/symbol.c:1360
 #, gcc-internal-format, gfc-internal-format
+msgid "VOLATILE attribute at %L cannot be specified in a PURE procedure"
+msgstr ""
+
+#: fortran/symbol.c:1381
+#, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ASYNCHRONOUS attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1758
+#: fortran/symbol.c:1772
 #, fuzzy, gcc-internal-format
 msgid "%s attribute of %qs conflicts with %s attribute at %L"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
-#: fortran/symbol.c:1794
+#: fortran/symbol.c:1808
 #, gcc-internal-format, gfc-internal-format
 msgid ""
 "%s procedure at %L is already declared as %s procedure. \n"
@@ -62092,72 +62172,72 @@
 "F2008: A pointer function assignment is ambiguous if it is the first executable statement after the specification block. Please add any other kind of executable statement before it. FIXME"
 msgstr ""
 
-#: fortran/symbol.c:1802
+#: fortran/symbol.c:1816
 #, gcc-internal-format, gfc-internal-format
 msgid "%s procedure at %L is already declared as %s procedure"
 msgstr ""
 
-#: fortran/symbol.c:1837
+#: fortran/symbol.c:1851
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgstr ""
 
-#: fortran/symbol.c:1861
+#: fortran/symbol.c:1875
 #, gcc-internal-format, gfc-internal-format
 msgid "ACCESS specification at %L was already specified"
 msgstr ""
 
-#: fortran/symbol.c:1878
+#: fortran/symbol.c:1892
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate BIND attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1885
+#: fortran/symbol.c:1899
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) at %L"
 msgstr ""
 
-#: fortran/symbol.c:1901
+#: fortran/symbol.c:1915
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate EXTENDS attribute specified at %L"
 msgstr ""
 
-#: fortran/symbol.c:1905
+#: fortran/symbol.c:1919
 #, gcc-internal-format, gfc-internal-format
 msgid "EXTENDS at %L"
 msgstr ""
 
-#: fortran/symbol.c:1931
+#: fortran/symbol.c:1945
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has an explicit interface"
 msgstr ""
 
-#: fortran/symbol.c:1938
+#: fortran/symbol.c:1952
 #, gcc-internal-format
 msgid "%qs at %L has attributes specified outside its INTERFACE body"
 msgstr ""
 
-#: fortran/symbol.c:1976
+#: fortran/symbol.c:1990
 #, gcc-internal-format
 msgid "Symbol %qs at %L conflicts with symbol from module %qs, use-associated at %L"
 msgstr ""
 
-#: fortran/symbol.c:1980
+#: fortran/symbol.c:1994
 #, gcc-internal-format
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr ""
 
-#: fortran/symbol.c:1987
+#: fortran/symbol.c:2001
 #, gcc-internal-format
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr ""
 
-#: fortran/symbol.c:1999
+#: fortran/symbol.c:2013
 #, gcc-internal-format
 msgid "Symbol %qs at %L cannot have a type"
 msgstr ""
 
-#: fortran/symbol.c:2242
+#: fortran/symbol.c:2256
 #, gcc-internal-format
 msgid "Component %qs at %C already in the parent type at %L"
 msgstr ""
@@ -62164,138 +62244,138 @@
 
 # src/getopt.c:628
 # src/getopt.c:628
-#: fortran/symbol.c:2327
+#: fortran/symbol.c:2341
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C is ambiguous"
 msgstr "%s: η επιλογή `%s' είναι ασαφής\n"
 
-#: fortran/symbol.c:2359
+#: fortran/symbol.c:2373
 #, gcc-internal-format
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr ""
 
-#: fortran/symbol.c:2508
+#: fortran/symbol.c:2522
 #, gcc-internal-format
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr ""
 
-#: fortran/symbol.c:2529
+#: fortran/symbol.c:2543
 #, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure; did you mean %qs?"
 msgstr ""
 
-#: fortran/symbol.c:2533
+#: fortran/symbol.c:2547
 #, fuzzy, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: fortran/symbol.c:2697
+#: fortran/symbol.c:2711
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr "διπλός αριθμός μηνύματος"
 
-#: fortran/symbol.c:2708
+#: fortran/symbol.c:2722
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr ""
 
-#: fortran/symbol.c:2718
+#: fortran/symbol.c:2732
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr ""
 
-#: fortran/symbol.c:2724
+#: fortran/symbol.c:2738
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:2766
+#: fortran/symbol.c:2780
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr ""
 
-#: fortran/symbol.c:2775
+#: fortran/symbol.c:2789
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr ""
 
-#: fortran/symbol.c:2781
+#: fortran/symbol.c:2795
 #, gcc-internal-format, gfc-internal-format
 msgid "Shared DO termination label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:3110
+#: fortran/symbol.c:3124
 #, gcc-internal-format
 msgid "new_symbol(): Symbol name too long"
 msgstr ""
 
-#: fortran/symbol.c:3135
+#: fortran/symbol.c:3149
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr ""
 
-#: fortran/symbol.c:3138
+#: fortran/symbol.c:3152
 #, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
 msgstr ""
 
 #. Symbol is from another namespace.
-#: fortran/symbol.c:3381
+#: fortran/symbol.c:3395
 #, gcc-internal-format
 msgid "Symbol %qs at %C has already been host associated"
 msgstr ""
 
-#: fortran/symbol.c:4397
+#: fortran/symbol.c:4411
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr ""
 
-#: fortran/symbol.c:4410
+#: fortran/symbol.c:4424
 #, gcc-internal-format
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr ""
 
-#: fortran/symbol.c:4428
+#: fortran/symbol.c:4442
 #, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr ""
 
-#: fortran/symbol.c:4449
+#: fortran/symbol.c:4463
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:4459
+#: fortran/symbol.c:4473
 #, gcc-internal-format
 msgid "Procedure pointer component %qs at %L cannot be a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:4470
+#: fortran/symbol.c:4484
 #, gcc-internal-format
 msgid "Component %qs at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr ""
 
-#: fortran/symbol.c:4509
+#: fortran/symbol.c:4523
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.c:4519
+#: fortran/symbol.c:4533
 #, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr ""
 
-#: fortran/symbol.c:4533
+#: fortran/symbol.c:4547
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot be declared with both PRIVATE and BIND(C) attributes"
 msgstr ""
 
-#: fortran/symbol.c:4541
+#: fortran/symbol.c:4555
 #, gcc-internal-format
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr ""
 
-#: fortran/symbol.c:5018 fortran/symbol.c:5023
+#: fortran/symbol.c:5032 fortran/symbol.c:5037
 #, gcc-internal-format
 msgid "Symbol %qs is used before it is typed at %L"
 msgstr ""
@@ -62342,7 +62422,7 @@
 msgid "Creating array temporary at %L for argument %qs"
 msgstr ""
 
-#: fortran/trans-array.c:10693
+#: fortran/trans-array.c:10724
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr ""
@@ -62547,12 +62627,12 @@
 msgid "%<dim%> argument of %s intrinsic at %L is not a valid dimension index"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:10572 fortran/trans-stmt.c:1050
+#: fortran/trans-intrinsic.c:10574 fortran/trans-stmt.c:1050
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, the event component of derived type at %L is not yet supported"
 msgstr ""
 
-#: fortran/trans-intrinsic.c:10579
+#: fortran/trans-intrinsic.c:10581
 #, gcc-internal-format, gfc-internal-format
 msgid "The event variable at %L shall not be coindexed"
 msgstr ""
@@ -62592,7 +62672,7 @@
 msgid "Sorry, only support for integer kind %d implemented for image-set at %L"
 msgstr ""
 
-#: fortran/trans-stmt.c:3346
+#: fortran/trans-stmt.c:3343
 #, gcc-internal-format
 msgid "gfc_trans_select(): Bad type for case expr."
 msgstr ""
@@ -62722,7 +62802,7 @@
 msgid "two or more sections for %s"
 msgstr "Προειδοποίηση: Πολύ λίγα ορίσματα στο εσωδομημένο `%s'"
 
-#: lto/lto-partition.c:516
+#: lto/lto-partition.c:570
 #, gcc-internal-format
 msgid "min partition size cannot be greater than max partition size"
 msgstr ""
@@ -62857,57 +62937,57 @@
 msgid "Cannot read %s"
 msgstr "αδυναμία ανοίγματος του `%s'"
 
-#: lto/lto.c:2369
+#: lto/lto.c:2337
 #, gcc-internal-format
 msgid "lto_obj_file_open() failed"
 msgstr ""
 
-#: lto/lto.c:2394
+#: lto/lto.c:2362
 #, gcc-internal-format
 msgid "waitpid failed"
 msgstr ""
 
-#: lto/lto.c:2397
+#: lto/lto.c:2365
 #, gcc-internal-format
 msgid "streaming subprocess failed"
 msgstr ""
 
-#: lto/lto.c:2400
+#: lto/lto.c:2368
 #, gcc-internal-format
 msgid "streaming subprocess was killed by signal"
 msgstr ""
 
-#: lto/lto.c:2476
+#: lto/lto.c:2445
 #, gcc-internal-format
 msgid "no LTRANS output list filename provided"
 msgstr ""
 
-#: lto/lto.c:2564
+#: lto/lto.c:2525
 #, fuzzy, gcc-internal-format
 msgid "opening LTRANS output list %s: %m"
 msgstr "αδυναμία ανοίγματος αρχείου εξόδου `%s'"
 
-#: lto/lto.c:2570
+#: lto/lto.c:2532
 #, fuzzy, gcc-internal-format
 msgid "writing to LTRANS output list %s: %m"
 msgstr "σφάλμα εγγραφής %s"
 
-#: lto/lto.c:2581
+#: lto/lto.c:2542
 #, fuzzy, gcc-internal-format
 msgid "closing LTRANS output list %s: %m"
 msgstr "αδυναμία ανοίγματος αρχείου εξόδου `%s'"
 
-#: lto/lto.c:2833
+#: lto/lto.c:2794
 #, fuzzy, gcc-internal-format
 msgid "could not open symbol resolution file: %m"
 msgstr "Δεν μπόρεσα να ανοίξω το αρχείο %s"
 
-#: lto/lto.c:2954
+#: lto/lto.c:2915
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "missing resolution data for %s"
 msgstr "Λείπει παράμετρος για `%s'"
 
-#: lto/lto.c:2986
+#: lto/lto.c:2947
 #, gcc-internal-format
 msgid "errors during merging of translation units"
 msgstr ""
Index: gcc/po/zh_CN.po
===================================================================
--- gcc/po/zh_CN.po	(.../tags/gcc_8_2_0_release)
+++ gcc/po/zh_CN.po	(.../branches/gcc-8-branch)
@@ -32,7 +32,7 @@
 msgstr ""
 "Project-Id-Version: gcc 6.1.0\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2018-05-01 20:30+0000\n"
+"POT-Creation-Date: 2018-07-25 14:25+0000\n"
 "PO-Revision-Date: 2016-04-30 17:13-0400\n"
 "Last-Translator: Mingye Wang (Arthur2e5) <arthur200126@gmail.com>\n"
 "Language-Team: Chinese (simplified) <i18n-zh@googlegroups.com>\n"
@@ -66,35 +66,35 @@
 msgid "[cannot find %s]"
 msgstr "[找不到 %s]"
 
-#: collect2.c:1557
+#: collect2.c:1585
 #, c-format
 msgid "collect2 version %s\n"
 msgstr "collect2 版本 %s\n"
 
-#: collect2.c:1664
+#: collect2.c:1692
 #, c-format
 msgid "%d constructor found\n"
 msgid_plural "%d constructors found\n"
 msgstr[0] "找到 %d 个构造函数\n"
 
-#: collect2.c:1668
+#: collect2.c:1696
 #, c-format
 msgid "%d destructor found\n"
 msgid_plural "%d destructors found\n"
 msgstr[0] "找到 %d 个析构函数\n"
 
-#: collect2.c:1672
+#: collect2.c:1700
 #, c-format
 msgid "%d frame table found\n"
 msgid_plural "%d frame tables found\n"
 msgstr[0] "找到 %d 个框架表\n"
 
-#: collect2.c:1836
+#: collect2.c:1864
 #, c-format
 msgid "[Leaving %s]\n"
 msgstr "[离开 %s]\n"
 
-#: collect2.c:2068
+#: collect2.c:2094
 #, c-format
 msgid ""
 "\n"
@@ -103,7 +103,7 @@
 "\n"
 "write_c_file - 输出名为 %s，前缀为 %s\n"
 
-#: collect2.c:2584
+#: collect2.c:2610
 #, c-format
 msgid ""
 "\n"
@@ -126,7 +126,7 @@
 msgid "%s: some warnings being treated as errors"
 msgstr "%s：有些警告被当作是错误"
 
-#: diagnostic.c:324 input.c:222 input.c:1834 c-family/c-opts.c:1377
+#: diagnostic.c:324 input.c:222 input.c:1834 c-family/c-opts.c:1392
 #: fortran/cpp.c:576 fortran/error.c:1008 fortran/error.c:1028
 msgid "<built-in>"
 msgstr "<built-in>"
@@ -218,13 +218,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:4164 config/arc/arc.c:5784 config/i386/i386.c:17302
+#: final.c:4164 config/arc/arc.c:5775 config/i386/i386.c:17305
 #: config/pdp11/pdp11.c:1715
 #, c-format
 msgid "floating constant misused"
 msgstr "错误地使用了浮点常量"
 
-#: final.c:4222 config/arc/arc.c:5881 config/i386/i386.c:17393
+#: final.c:4222 config/arc/arc.c:5872 config/i386/i386.c:17396
 #: config/pdp11/pdp11.c:1756
 #, c-format
 msgid "invalid expression as operand"
@@ -1132,7 +1132,7 @@
 msgid "GCSE disabled"
 msgstr "GCSE 被禁用"
 
-#: gimple-ssa-isolate-paths.c:542 c/c-typeck.c:10240
+#: gimple-ssa-isolate-paths.c:542 c/c-typeck.c:10245
 #, gcc-internal-format
 msgid "function returns address of local variable"
 msgstr "函数返回局部变量的地址"
@@ -1435,7 +1435,7 @@
 msgid "options enabled: "
 msgstr "启用的选项："
 
-#: tree-diagnostic.c:299 c/c-decl.c:5419 c/c-typeck.c:7259 cp/error.c:1042
+#: tree-diagnostic.c:299 c/c-decl.c:5439 c/c-typeck.c:7264 cp/error.c:1042
 #: c-family/c-pretty-print.c:413
 #, gcc-internal-format
 msgid "<anonymous>"
@@ -3009,65 +3009,65 @@
 msgstr "strfmon 格式的长度修饰符"
 
 #. Handle deferred options from command-line.
-#: c-family/c-opts.c:1402 fortran/cpp.c:590
+#: c-family/c-opts.c:1417 fortran/cpp.c:590
 msgid "<command-line>"
 msgstr "<命令行>"
 
-#: config/aarch64/aarch64.c:6613
+#: config/aarch64/aarch64.c:6629
 #, fuzzy, c-format
 msgid "unsupported operand for code '%c'"
 msgstr "代码‘%c’的操作数无效"
 
-#: config/aarch64/aarch64.c:6624 config/aarch64/aarch64.c:6640
-#: config/aarch64/aarch64.c:6652 config/aarch64/aarch64.c:6663
-#: config/aarch64/aarch64.c:6673 config/aarch64/aarch64.c:6694
-#: config/aarch64/aarch64.c:6764 config/aarch64/aarch64.c:6775
-#: config/aarch64/aarch64.c:6789 config/aarch64/aarch64.c:7011
-#: config/aarch64/aarch64.c:7029
+#: config/aarch64/aarch64.c:6640 config/aarch64/aarch64.c:6656
+#: config/aarch64/aarch64.c:6668 config/aarch64/aarch64.c:6679
+#: config/aarch64/aarch64.c:6689 config/aarch64/aarch64.c:6710
+#: config/aarch64/aarch64.c:6780 config/aarch64/aarch64.c:6791
+#: config/aarch64/aarch64.c:6805 config/aarch64/aarch64.c:7027
+#: config/aarch64/aarch64.c:7045
 #, fuzzy, c-format
 msgid "invalid operand for '%%%c'"
 msgstr "无效的操作数代码‘%c’"
 
-#: config/aarch64/aarch64.c:6709 config/aarch64/aarch64.c:6720
-#: config/aarch64/aarch64.c:6871 config/aarch64/aarch64.c:6882
+#: config/aarch64/aarch64.c:6725 config/aarch64/aarch64.c:6736
+#: config/aarch64/aarch64.c:6887 config/aarch64/aarch64.c:6898
 #, fuzzy, c-format
 msgid "invalid vector constant"
 msgstr "%<#pragma pack%>中有无效常量 - 已忽略"
 
-#: config/aarch64/aarch64.c:6732 config/aarch64/aarch64.c:6744
-#: config/aarch64/aarch64.c:6755
+#: config/aarch64/aarch64.c:6748 config/aarch64/aarch64.c:6760
+#: config/aarch64/aarch64.c:6771
 #, c-format
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:6823 config/arm/arm.c:22704
+#: config/aarch64/aarch64.c:6839 config/arm/arm.c:22704
 #, c-format
 msgid "missing operand"
 msgstr "缺少操作数"
 
-#: config/aarch64/aarch64.c:6908
+#: config/aarch64/aarch64.c:6924
 #, fuzzy, c-format
 msgid "invalid constant"
 msgstr "%<#pragma pack%>中有无效常量 - 已忽略"
 
-#: config/aarch64/aarch64.c:6911
+#: config/aarch64/aarch64.c:6927
 #, fuzzy, c-format
 msgid "invalid operand"
 msgstr "%%R 代码的操作数无效"
 
-#: config/aarch64/aarch64.c:7040 config/aarch64/aarch64.c:7045
+#: config/aarch64/aarch64.c:7056 config/aarch64/aarch64.c:7061
 #, fuzzy, c-format
 msgid "invalid operand prefix '%%%c'"
 msgstr "‘%%%c’不是一个有效的操作数前缀"
 
-#: config/aarch64/aarch64.c:7062
+#: config/aarch64/aarch64.c:7078
 #, fuzzy, c-format
 #| msgid "invalid addressing mode"
 msgid "invalid address mode"
 msgstr "无效寻址模式"
 
-#: config/alpha/alpha.c:5125 config/i386/i386.c:18558
-#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21798
+#: config/alpha/alpha.c:5125 config/i386/i386.c:18561
+#: config/powerpcspe/powerpcspe.c:24333 config/rs6000/rs6000.c:21875
 #: config/sparc/sparc.c:9290
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
@@ -3084,7 +3084,7 @@
 msgstr "无效 %%r 值"
 
 #: config/alpha/alpha.c:5223 config/ia64/ia64.c:5534
-#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21506
+#: config/powerpcspe/powerpcspe.c:24013 config/rs6000/rs6000.c:21583
 #: config/xtensa/xtensa.c:2429
 #, c-format
 msgid "invalid %%R value"
@@ -3091,13 +3091,13 @@
 msgstr "无效 %%R 值"
 
 #: config/alpha/alpha.c:5229 config/powerpcspe/powerpcspe.c:23933
-#: config/rs6000/rs6000.c:21426 config/xtensa/xtensa.c:2396
+#: config/rs6000/rs6000.c:21503 config/xtensa/xtensa.c:2396
 #, c-format
 msgid "invalid %%N value"
 msgstr "无效 %%N 值"
 
 #: config/alpha/alpha.c:5237 config/powerpcspe/powerpcspe.c:23961
-#: config/rs6000/rs6000.c:21454
+#: config/rs6000/rs6000.c:21531
 #, c-format
 msgid "invalid %%P value"
 msgstr "无效 %%P 值"
@@ -3128,7 +3128,7 @@
 msgstr "无效 %%U 值"
 
 #: config/alpha/alpha.c:5323 config/powerpcspe/powerpcspe.c:24021
-#: config/rs6000/rs6000.c:21514
+#: config/rs6000/rs6000.c:21591
 #, c-format
 msgid "invalid %%s value"
 msgstr "无效 %%s 值"
@@ -3139,7 +3139,7 @@
 msgstr "无效 %%C 值"
 
 #: config/alpha/alpha.c:5371 config/powerpcspe/powerpcspe.c:23797
-#: config/rs6000/rs6000.c:21290
+#: config/rs6000/rs6000.c:21367
 #, c-format
 msgid "invalid %%E value"
 msgstr "无效 %%E 值"
@@ -3150,7 +3150,7 @@
 msgstr "未指定未知的重定位方式"
 
 #: config/alpha/alpha.c:5405 config/cr16/cr16.c:1569
-#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21803
+#: config/powerpcspe/powerpcspe.c:24338 config/rs6000/rs6000.c:21880
 #: config/spu/spu.c:1458
 #, c-format
 msgid "invalid %%xn code"
@@ -3161,58 +3161,58 @@
 msgid "invalid operand address"
 msgstr "fr30_print_operand：未处理的指针"
 
-#: config/arc/arc.c:3810
+#: config/arc/arc.c:3808
 #, c-format
 msgid "invalid operand to %%Z code"
 msgstr "%%Z 代码的操作数无效"
 
-#: config/arc/arc.c:3818
+#: config/arc/arc.c:3816
 #, c-format
 msgid "invalid operand to %%z code"
 msgstr "%%z 代码的操作数无效"
 
-#: config/arc/arc.c:3826
+#: config/arc/arc.c:3824
 #, fuzzy, c-format
 #| msgid "invalid operand to %%Z code"
 msgid "invalid operands to %%c code"
 msgstr "%%Z 代码的操作数无效"
 
-#: config/arc/arc.c:3834
+#: config/arc/arc.c:3832
 #, c-format
 msgid "invalid operand to %%M code"
 msgstr "%%M 代码的操作数无效"
 
-#: config/arc/arc.c:3842 config/m32r/m32r.c:2100
+#: config/arc/arc.c:3840 config/m32r/m32r.c:2100
 #, c-format
 msgid "invalid operand to %%p code"
 msgstr "%%p 代码的操作数无效"
 
-#: config/arc/arc.c:3853 config/m32r/m32r.c:2093
+#: config/arc/arc.c:3851 config/m32r/m32r.c:2093
 #, c-format
 msgid "invalid operand to %%s code"
 msgstr "%%s 代码的操作数无效"
 
-#: config/arc/arc.c:4001 config/m32r/m32r.c:2126
+#: config/arc/arc.c:3999 config/m32r/m32r.c:2126
 #, c-format
 msgid "invalid operand to %%R code"
 msgstr "%%R 代码的操作数无效"
 
-#: config/arc/arc.c:4077 config/m32r/m32r.c:2149
+#: config/arc/arc.c:4075 config/m32r/m32r.c:2149
 #, c-format
 msgid "invalid operand to %%H/%%L code"
 msgstr "%%H/%%L 代码的操作数无效"
 
-#: config/arc/arc.c:4145 config/m32r/m32r.c:2220
+#: config/arc/arc.c:4143 config/m32r/m32r.c:2220
 #, c-format
 msgid "invalid operand to %%U code"
 msgstr "%%U 代码的操作数无效"
 
-#: config/arc/arc.c:4157
+#: config/arc/arc.c:4155
 #, c-format
 msgid "invalid operand to %%V code"
 msgstr "%%V 代码的操作数无效"
 
-#: config/arc/arc.c:4214
+#: config/arc/arc.c:4212
 #, c-format
 msgid "invalid operand to %%O code"
 msgstr "%%O 代码的操作数无效"
@@ -3219,18 +3219,18 @@
 
 #. Unknown flag.
 #. Undocumented flag.
-#: config/arc/arc.c:4240 config/epiphany/epiphany.c:1305
-#: config/m32r/m32r.c:2247 config/nds32/nds32.c:3079 config/sparc/sparc.c:9569
+#: config/arc/arc.c:4238 config/epiphany/epiphany.c:1305
+#: config/m32r/m32r.c:2247 config/nds32/nds32.c:3080 config/sparc/sparc.c:9569
 #, c-format
 msgid "invalid operand output code"
 msgstr "无效的操作数输出代码"
 
-#: config/arc/arc.c:5869
+#: config/arc/arc.c:5860
 #, fuzzy, c-format
 msgid "invalid UNSPEC as operand: %d"
 msgstr "无效的 UNSPEC 用作操作数"
 
-#: config/arc/arc.c:6158 config/cris/cris.c:2568
+#: config/arc/arc.c:6149 config/cris/cris.c:2568
 msgid "unrecognized supposed constant"
 msgstr "预期的常量无法识别"
 
@@ -3265,7 +3265,7 @@
 #: config/arm/arm.c:22685 config/arm/arm.c:22692 config/bfin/bfin.c:1441
 #: config/bfin/bfin.c:1448 config/bfin/bfin.c:1455 config/bfin/bfin.c:1462
 #: config/bfin/bfin.c:1471 config/bfin/bfin.c:1478 config/bfin/bfin.c:1485
-#: config/bfin/bfin.c:1492 config/nds32/nds32.c:3098
+#: config/bfin/bfin.c:1492 config/nds32/nds32.c:3099
 #, c-format
 msgid "invalid operand for code '%c'"
 msgstr "代码‘%c’的操作数无效"
@@ -3620,103 +3620,103 @@
 msgid "bad output_condmove_single operand"
 msgstr "错误的 output_condmove_single 操作数"
 
-#: config/i386/i386.c:17387
+#: config/i386/i386.c:17390
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "无效的 UNSPEC 用作操作数"
 
-#: config/i386/i386.c:17925
+#: config/i386/i386.c:17928
 #, fuzzy, c-format
 #| msgid "invalid use of %<restrict%>"
 msgid "invalid use of register '%s'"
 msgstr "错误地使用了%<restrict%>"
 
-#: config/i386/i386.c:17930
+#: config/i386/i386.c:17933
 #, fuzzy, c-format
 msgid "invalid use of asm flag output"
 msgstr "向函数类型%qT的转换无效"
 
-#: config/i386/i386.c:18160
+#: config/i386/i386.c:18163
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr "fr30_print_operand：%%A 代码操作数无效"
 
-#: config/i386/i386.c:18195
+#: config/i386/i386.c:18198
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr "‘z’修饰符的操作数无效"
 
-#: config/i386/i386.c:18264
+#: config/i386/i386.c:18267
 #, fuzzy, c-format
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "操作数代码‘%c’的操作数类型无效"
 
-#: config/i386/i386.c:18269
+#: config/i386/i386.c:18272
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'Z'"
 msgstr "‘z’修饰符的操作数无效"
 
-#: config/i386/i386.c:18346
+#: config/i386/i386.c:18349
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "操作数不是一个条件码，无效的操作数代码‘Y’"
 
-#: config/i386/i386.c:18425
+#: config/i386/i386.c:18428
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "操作数不是一个条件码，无效的操作数代码‘D’"
 
-#: config/i386/i386.c:18443
+#: config/i386/i386.c:18446
 #, fuzzy, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "操作数不是一个条件码，无效的操作数代码‘D’"
 
-#: config/i386/i386.c:18456
+#: config/i386/i386.c:18459
 #, fuzzy, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "操作数不是一个条件码，无效的操作数代码‘D’"
 
-#: config/i386/i386.c:18471
+#: config/i386/i386.c:18474
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'Y'"
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr "操作数不是一个条件码，无效的操作数代码‘Y’"
 
-#: config/i386/i386.c:18499
+#: config/i386/i386.c:18502
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'Y'"
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr "操作数不是一个条件码，无效的操作数代码‘Y’"
 
-#: config/i386/i386.c:18517
+#: config/i386/i386.c:18520
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'Y'"
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr "操作数不是一个条件码，无效的操作数代码‘Y’"
 
-#: config/i386/i386.c:18540
+#: config/i386/i386.c:18543
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'Y'"
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "操作数不是一个条件码，无效的操作数代码‘Y’"
 
-#: config/i386/i386.c:18626
+#: config/i386/i386.c:18629
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "无效的操作数代码‘%c’"
 
-#: config/i386/i386.c:18688
+#: config/i386/i386.c:18691
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "操作数的约束无效"
 
-#: config/i386/i386.c:18738
+#: config/i386/i386.c:18741
 #, fuzzy, c-format
 #| msgid "invalid controlling predicate"
 msgid "invalid vector immediate"
 msgstr "无效的控制谓词"
 
-#: config/i386/i386.c:29572
+#: config/i386/i386.c:29575
 msgid "unknown insn mode"
 msgstr "未知的指令模式"
 
@@ -3755,7 +3755,7 @@
 msgstr "无效的 %%P 操作数"
 
 #: config/iq2000/iq2000.c:3185 config/powerpcspe/powerpcspe.c:23951
-#: config/rs6000/rs6000.c:21444
+#: config/rs6000/rs6000.c:21521
 #, c-format
 msgid "invalid %%p value"
 msgstr "无效的 %%p 值"
@@ -3809,7 +3809,7 @@
 msgstr "后自增地址不是一个寄存器"
 
 #: config/m32r/m32r.c:2350 config/m32r/m32r.c:2365
-#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33292
+#: config/powerpcspe/powerpcspe.c:36090 config/rs6000/rs6000.c:33348
 msgid "bad address"
 msgstr "错误地址"
 
@@ -3928,191 +3928,191 @@
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr "尝试在命令解释器中运行‘%s’以提升它的极限。\n"
 
-#: config/powerpcspe/powerpcspe.c:4411 config/rs6000/rs6000.c:4258
+#: config/powerpcspe/powerpcspe.c:4411 config/rs6000/rs6000.c:4278
 msgid "-maltivec=le not allowed for big-endian targets"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4423 config/rs6000/rs6000.c:4273
+#: config/powerpcspe/powerpcspe.c:4423 config/rs6000/rs6000.c:4293
 msgid "-mvsx requires hardware floating point"
 msgstr "-mvsx 需要硬件浮点"
 
-#: config/powerpcspe/powerpcspe.c:4431 config/rs6000/rs6000.c:4281
+#: config/powerpcspe/powerpcspe.c:4431 config/rs6000/rs6000.c:4301
 msgid "-mvsx and -mpaired are incompatible"
 msgstr "-mvsx 与 -mpaired 互不兼容"
 
-#: config/powerpcspe/powerpcspe.c:4433 config/rs6000/rs6000.c:4283
+#: config/powerpcspe/powerpcspe.c:4433 config/rs6000/rs6000.c:4303
 msgid "-mvsx needs indexed addressing"
 msgstr "-mvsx 需要变址寻址"
 
-#: config/powerpcspe/powerpcspe.c:4438 config/rs6000/rs6000.c:4288
+#: config/powerpcspe/powerpcspe.c:4438 config/rs6000/rs6000.c:4308
 msgid "-mvsx and -mno-altivec are incompatible"
 msgstr "-mvsx 与 -mno-altivec 互不兼容"
 
-#: config/powerpcspe/powerpcspe.c:4440 config/rs6000/rs6000.c:4290
+#: config/powerpcspe/powerpcspe.c:4440 config/rs6000/rs6000.c:4310
 msgid "-mno-altivec disables vsx"
 msgstr "-mno-altivec 禁用了 VSX"
 
-#: config/powerpcspe/powerpcspe.c:4648 config/rs6000/rs6000.c:4416
+#: config/powerpcspe/powerpcspe.c:4648 config/rs6000/rs6000.c:4436
 msgid "-mquad-memory requires 64-bit mode"
 msgstr "-mquad-memory 需要 64 位模式"
 
-#: config/powerpcspe/powerpcspe.c:4651 config/rs6000/rs6000.c:4419
+#: config/powerpcspe/powerpcspe.c:4651 config/rs6000/rs6000.c:4439
 msgid "-mquad-memory-atomic requires 64-bit mode"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4663 config/rs6000/rs6000.c:4431
+#: config/powerpcspe/powerpcspe.c:4663 config/rs6000/rs6000.c:4451
 #, fuzzy
 msgid "-mquad-memory is not available in little endian mode"
 msgstr "生成小端在前的代码"
 
-#: config/powerpcspe/powerpcspe.c:4735 config/rs6000/rs6000.c:4512
+#: config/powerpcspe/powerpcspe.c:4735 config/rs6000/rs6000.c:4532
 #, fuzzy
 #| msgid "-mquad-memory requires 64-bit mode"
 msgid "-mtoc-fusion requires 64-bit"
 msgstr "-mquad-memory 需要 64 位模式"
 
-#: config/powerpcspe/powerpcspe.c:4742 config/rs6000/rs6000.c:4519
+#: config/powerpcspe/powerpcspe.c:4742 config/rs6000/rs6000.c:4539
 msgid "-mtoc-fusion requires medium/large code model"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10915
+#: config/powerpcspe/powerpcspe.c:11492 config/rs6000/rs6000.c:10947
 msgid "bad move"
 msgstr "错误的移动"
 
-#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21087
+#: config/powerpcspe/powerpcspe.c:23594 config/rs6000/rs6000.c:21164
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21278
+#: config/powerpcspe/powerpcspe.c:23785 config/rs6000/rs6000.c:21355
 #, c-format
 msgid "invalid %%e value"
 msgstr "无效 %%e 值"
 
-#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21299
+#: config/powerpcspe/powerpcspe.c:23806 config/rs6000/rs6000.c:21376
 #, c-format
 msgid "invalid %%f value"
 msgstr "无效 %%f 值"
 
-#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21308
+#: config/powerpcspe/powerpcspe.c:23815 config/rs6000/rs6000.c:21385
 #, c-format
 msgid "invalid %%F value"
 msgstr "无效 %%F 值"
 
-#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21317
+#: config/powerpcspe/powerpcspe.c:23824 config/rs6000/rs6000.c:21394
 #, c-format
 msgid "invalid %%G value"
 msgstr "无效 %%G 值"
 
-#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21352
+#: config/powerpcspe/powerpcspe.c:23859 config/rs6000/rs6000.c:21429
 #, c-format
 msgid "invalid %%j code"
 msgstr "无效 %%j 代码"
 
-#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21362
+#: config/powerpcspe/powerpcspe.c:23869 config/rs6000/rs6000.c:21439
 #, c-format
 msgid "invalid %%J code"
 msgstr "无效 %%J 代码"
 
-#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21372
+#: config/powerpcspe/powerpcspe.c:23879 config/rs6000/rs6000.c:21449
 #, c-format
 msgid "invalid %%k value"
 msgstr "无效 %%k 值"
 
-#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21387
+#: config/powerpcspe/powerpcspe.c:23894 config/rs6000/rs6000.c:21464
 #: config/xtensa/xtensa.c:2415
 #, c-format
 msgid "invalid %%K value"
 msgstr "无效 %%K 值"
 
-#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21434
+#: config/powerpcspe/powerpcspe.c:23941 config/rs6000/rs6000.c:21511
 #, c-format
 msgid "invalid %%O value"
 msgstr "无效 %%O 值"
 
-#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21481
+#: config/powerpcspe/powerpcspe.c:23988 config/rs6000/rs6000.c:21558
 #, c-format
 msgid "invalid %%q value"
 msgstr "无效 %%q 值"
 
-#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21534
+#: config/powerpcspe/powerpcspe.c:24041 config/rs6000/rs6000.c:21611
 #, c-format
 msgid "invalid %%T value"
 msgstr "无效 %%T 值"
 
-#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21546
+#: config/powerpcspe/powerpcspe.c:24053 config/rs6000/rs6000.c:21623
 #, c-format
 msgid "invalid %%u value"
 msgstr "无效 %%u 值"
 
-#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21560
+#: config/powerpcspe/powerpcspe.c:24067 config/rs6000/rs6000.c:21637
 #: config/xtensa/xtensa.c:2384
 #, c-format
 msgid "invalid %%v value"
 msgstr "无效 %%v 值"
 
-#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21627
+#: config/powerpcspe/powerpcspe.c:24134 config/rs6000/rs6000.c:21704
 #: config/xtensa/xtensa.c:2436
 #, c-format
 msgid "invalid %%x value"
 msgstr "无效的 %%x 值"
 
-#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21747
+#: config/powerpcspe/powerpcspe.c:24282 config/rs6000/rs6000.c:21824
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "无效 %%y 值，请试用“Z”约束"
 
-#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22282
+#: config/powerpcspe/powerpcspe.c:24996 config/rs6000/rs6000.c:22359
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22288
+#: config/powerpcspe/powerpcspe.c:25002 config/rs6000/rs6000.c:22365
 #, fuzzy
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr "对声明中的过时用法给出警告"
 
-#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22294
+#: config/powerpcspe/powerpcspe.c:25008 config/rs6000/rs6000.c:22371
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36572
+#: config/powerpcspe/powerpcspe.c:39380 config/rs6000/rs6000.c:36628
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "传递 AltiVec 参数给无原型的函数"
 
-#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38739
+#: config/powerpcspe/powerpcspe.c:41186 config/rs6000/rs6000.c:38795
 #, fuzzy
 msgid "Could not generate addis value for fusion"
 msgstr "不为每个函数生成单一的退出点"
 
-#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38809
+#: config/powerpcspe/powerpcspe.c:41258 config/rs6000/rs6000.c:38865
 #, fuzzy
 msgid "Unable to generate load/store offset for fusion"
 msgstr "无法生成重新载入，为："
 
-#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38908
+#: config/powerpcspe/powerpcspe.c:41362 config/rs6000/rs6000.c:38964
 msgid "Bad GPR fusion"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39126
+#: config/powerpcspe/powerpcspe.c:41580 config/rs6000/rs6000.c:39182
 msgid "emit_fusion_p9_load, bad reg #1"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39172
+#: config/powerpcspe/powerpcspe.c:41626 config/rs6000/rs6000.c:39228
 msgid "emit_fusion_p9_load, bad reg #2"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39175
+#: config/powerpcspe/powerpcspe.c:41629 config/rs6000/rs6000.c:39231
 msgid "emit_fusion_p9_load not MEM"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39213
+#: config/powerpcspe/powerpcspe.c:41667 config/rs6000/rs6000.c:39269
 msgid "emit_fusion_p9_store, bad reg #1"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39259
+#: config/powerpcspe/powerpcspe.c:41713 config/rs6000/rs6000.c:39315
 msgid "emit_fusion_p9_store, bad reg #2"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39262
+#: config/powerpcspe/powerpcspe.c:41716 config/rs6000/rs6000.c:39318
 msgid "emit_fusion_p9_store not MEM"
 msgstr ""
 
@@ -4500,14 +4500,14 @@
 #: c/gimple-parser.c:188 c/gimple-parser.c:197 c/gimple-parser.c:226
 #: c/gimple-parser.c:1375 c/gimple-parser.c:1404 c/gimple-parser.c:1484
 #: c/gimple-parser.c:1511 c/c-parser.c:3204 c/c-parser.c:9967
-#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27841
-#: cp/parser.c:28430
+#: c/gimple-parser.c:1278 c/gimple-parser.c:1317 cp/parser.c:27838
+#: cp/parser.c:28427
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "需要%<;%>"
 
 #: c/c-parser.c:2431 c/c-parser.c:7573 c/c-parser.c:8015 c/c-parser.c:8058
-#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27839 cp/parser.c:28448
+#: c/c-parser.c:8196 c/c-parser.c:12669 cp/parser.c:27836 cp/parser.c:28445
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "需要 %<,%>"
@@ -4522,7 +4522,7 @@
 #: c/gimple-parser.c:821 c/gimple-parser.c:837 c/gimple-parser.c:853
 #: c/gimple-parser.c:880 c/gimple-parser.c:915 c/gimple-parser.c:1038
 #: c/gimple-parser.c:1209 c/gimple-parser.c:1220 c/gimple-parser.c:1342
-#: c/gimple-parser.c:1441 cp/parser.c:28478
+#: c/gimple-parser.c:1441 cp/parser.c:28475
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "需要%<)%>"
@@ -4530,7 +4530,7 @@
 #: c/c-parser.c:3824 c/c-parser.c:4733 c/c-parser.c:4769 c/c-parser.c:6441
 #: c/c-parser.c:8125 c/c-parser.c:8983 c/c-parser.c:9127 c/c-parser.c:11588
 #: c/c-parser.c:18220 c/c-parser.c:18222 c/gimple-parser.c:1015
-#: cp/parser.c:28442
+#: cp/parser.c:28439
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "需要%<]%>"
@@ -4544,7 +4544,7 @@
 #: c/c-parser.c:17792 c/gimple-parser.c:363 c/gimple-parser.c:811
 #: c/gimple-parser.c:873 c/gimple-parser.c:911 c/gimple-parser.c:1198
 #: c/gimple-parser.c:1339 c/gimple-parser.c:1438 c/c-parser.c:11911
-#: cp/parser.c:28433
+#: cp/parser.c:28430
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "需要%<(%>"
@@ -4551,7 +4551,7 @@
 
 #: c/c-parser.c:4903 c/c-parser.c:10310 c/c-parser.c:16212 c/c-parser.c:18449
 #: c/gimple-parser.c:141 c/gimple-parser.c:1444 c/c-parser.c:3018
-#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18155 cp/parser.c:28439
+#: c/c-parser.c:3225 c/c-parser.c:9862 cp/parser.c:18152 cp/parser.c:28436
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "需要%<{%>"
@@ -4561,13 +4561,13 @@
 #: c/c-parser.c:12351 c/c-parser.c:12493 c/c-parser.c:12864 c/c-parser.c:12957
 #: c/c-parser.c:13566 c/c-parser.c:17636 c/c-parser.c:17695
 #: c/gimple-parser.c:431 c/gimple-parser.c:1492 c/gimple-parser.c:1519
-#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28472 cp/parser.c:29597
-#: cp/parser.c:32279
+#: c/c-parser.c:6347 c/c-parser.c:12006 cp/parser.c:28469 cp/parser.c:29594
+#: cp/parser.c:32276
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "需要 %<:%>"
 
-#: c/c-parser.c:5974 cp/parser.c:28365
+#: c/c-parser.c:5974 cp/parser.c:28362
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "需要 %<while%>"
@@ -4576,18 +4576,18 @@
 msgid "expected %<.%>"
 msgstr "需要%<.%>"
 
-#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30172
-#: cp/parser.c:30246
+#: c/c-parser.c:9533 c/c-parser.c:9565 c/c-parser.c:9805 cp/parser.c:30169
+#: cp/parser.c:30243
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "需要 %<@end%>"
 
-#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28457
+#: c/c-parser.c:10223 c/gimple-parser.c:806 cp/parser.c:28454
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "需要 %<>%>"
 
-#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28481
+#: c/c-parser.c:13049 c/c-parser.c:13787 cp/parser.c:28478
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "需要 %<,%> 或 %<)%>"
@@ -4595,32 +4595,32 @@
 #. All following cases are statements with LHS.
 #: c/c-parser.c:15190 c/c-parser.c:15234 c/c-parser.c:15466 c/c-parser.c:15701
 #: c/c-parser.c:17833 c/gimple-parser.c:286 c/c-parser.c:4792
-#: cp/parser.c:28460
+#: cp/parser.c:28457
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "需要%<=%>"
 
-#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28436
-#: cp/parser.c:30389
+#: c/c-parser.c:15482 c/gimple-parser.c:1553 cp/parser.c:28433
+#: cp/parser.c:30386
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "需要 %<}%>"
 
-#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35674
+#: c/c-parser.c:16255 c/c-parser.c:16245 cp/parser.c:35671
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "需要%<#pragma omp section%>或%<}%>"
 
-#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28445 cp/parser.c:31535
+#: c/c-parser.c:18208 c/c-parser.c:11523 cp/parser.c:28442 cp/parser.c:31532
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "需要%<[%>"
 
-#: c/c-typeck.c:7847
+#: c/c-typeck.c:7852
 msgid "(anonymous)"
 msgstr "(匿名)"
 
-#: c/gimple-parser.c:795 cp/parser.c:15791 cp/parser.c:28454
+#: c/gimple-parser.c:795 cp/parser.c:15788 cp/parser.c:28451
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "需要%<<%>"
@@ -4897,11 +4897,11 @@
 msgid "%r%s:%d:%R   in %<constexpr%> expansion of %qs"
 msgstr "%s:%d：在%qs的广义常表达式扩展中"
 
-#: cp/pt.c:1949 cp/semantics.c:5268
+#: cp/pt.c:1949 cp/semantics.c:5271
 msgid "candidates are:"
 msgstr "备选为："
 
-#: cp/pt.c:1951 cp/pt.c:22975
+#: cp/pt.c:1951 cp/pt.c:23053
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "备选是："
@@ -4946,27 +4946,27 @@
 msgid "source type is not polymorphic"
 msgstr "源类型不是多态的"
 
-#: cp/typeck.c:6083 c/c-typeck.c:4261
+#: cp/typeck.c:6083 c/c-typeck.c:4266
 #, gcc-internal-format
 msgid "wrong type argument to unary minus"
 msgstr "单目减的操作数类型错误"
 
-#: cp/typeck.c:6084 c/c-typeck.c:4248
+#: cp/typeck.c:6084 c/c-typeck.c:4253
 #, gcc-internal-format
 msgid "wrong type argument to unary plus"
 msgstr "单目加的操作数类型错误"
 
-#: cp/typeck.c:6111 c/c-typeck.c:4302
+#: cp/typeck.c:6111 c/c-typeck.c:4307
 #, gcc-internal-format
 msgid "wrong type argument to bit-complement"
 msgstr "按位取反的参数类型错误"
 
-#: cp/typeck.c:6128 c/c-typeck.c:4310
+#: cp/typeck.c:6128 c/c-typeck.c:4315
 #, gcc-internal-format
 msgid "wrong type argument to abs"
 msgstr "不能对该类型的参数求绝对值"
 
-#: cp/typeck.c:6140 c/c-typeck.c:4322
+#: cp/typeck.c:6140 c/c-typeck.c:4327
 #, gcc-internal-format
 msgid "wrong type argument to conjugation"
 msgstr "不能对该类型的参数求共轭"
@@ -5218,67 +5218,67 @@
 msgid "Expected attribute bit name"
 msgstr "需要属性位名"
 
-#: fortran/module.c:3223
+#: fortran/module.c:3225
 msgid "Expected integer string"
 msgstr "需要整数字符串"
 
-#: fortran/module.c:3227
+#: fortran/module.c:3229
 msgid "Error converting integer"
 msgstr "转换整数时出错"
 
-#: fortran/module.c:3249
+#: fortran/module.c:3251
 msgid "Expected real string"
 msgstr "需要实数字符串"
 
-#: fortran/module.c:3474
+#: fortran/module.c:3476
 msgid "Expected expression type"
 msgstr "需要表达式类型"
 
-#: fortran/module.c:3554
+#: fortran/module.c:3556
 msgid "Bad operator"
 msgstr "错误的运算符"
 
-#: fortran/module.c:3671
+#: fortran/module.c:3673
 msgid "Bad type in constant expression"
 msgstr "常量表达式中类型错误"
 
-#: fortran/module.c:7038
+#: fortran/module.c:7040
 msgid "Unexpected end of module"
 msgstr "非预期的模块结束"
 
-#: fortran/parse.c:1757
+#: fortran/parse.c:1761
 msgid "arithmetic IF"
 msgstr "算术 IF"
 
-#: fortran/parse.c:1766
+#: fortran/parse.c:1770
 msgid "attribute declaration"
 msgstr "属性声明"
 
-#: fortran/parse.c:1802
+#: fortran/parse.c:1806
 msgid "data declaration"
 msgstr "数据声明"
 
-#: fortran/parse.c:1820
+#: fortran/parse.c:1824
 msgid "derived type declaration"
 msgstr "派生的类型声明"
 
-#: fortran/parse.c:1947
+#: fortran/parse.c:1951
 msgid "block IF"
 msgstr "块 IF"
 
-#: fortran/parse.c:1956
+#: fortran/parse.c:1960
 msgid "implied END DO"
 msgstr "暗示的 END DO"
 
-#: fortran/parse.c:2050 fortran/resolve.c:11199
+#: fortran/parse.c:2054 fortran/resolve.c:11219
 msgid "assignment"
 msgstr "赋值"
 
-#: fortran/parse.c:2053 fortran/resolve.c:11250 fortran/resolve.c:11253
+#: fortran/parse.c:2057 fortran/resolve.c:11270 fortran/resolve.c:11273
 msgid "pointer assignment"
 msgstr "指针赋值"
 
-#: fortran/parse.c:2071
+#: fortran/parse.c:2075
 msgid "simple IF"
 msgstr "简单的 IF"
 
@@ -5386,119 +5386,125 @@
 msgid "Operand of unary numeric operator %%<%s%%> at %%L is %s"
 msgstr "单目数值运算符‘%s’(位于 %%L)的操作数为 %s"
 
-#: fortran/resolve.c:3878
+#: fortran/resolve.c:3879
 #, fuzzy, c-format
 #| msgid "Operands of binary numeric operator '%s' at %%L are %s/%s"
+msgid "Unexpected derived-type entities in binary intrinsic numeric operator %%<%s%%> at %%L"
+msgstr "二元数值运算符‘%s’(位于 %%L)的操作数为 %s/%s"
+
+#: fortran/resolve.c:3884
+#, fuzzy, c-format
+#| msgid "Operands of binary numeric operator '%s' at %%L are %s/%s"
 msgid "Operands of binary numeric operator %%<%s%%> at %%L are %s/%s"
 msgstr "二元数值运算符‘%s’(位于 %%L)的操作数为 %s/%s"
 
-#: fortran/resolve.c:3893
+#: fortran/resolve.c:3899
 #, c-format
 msgid "Operands of string concatenation operator at %%L are %s/%s"
 msgstr "字符串毗连运算符(位于 %%L)的操作数为 %s/%s"
 
-#: fortran/resolve.c:3926
+#: fortran/resolve.c:3932
 #, fuzzy, c-format
 #| msgid "Operands of logical operator '%s' at %%L are %s/%s"
 msgid "Operands of logical operator %%<%s%%> at %%L are %s/%s"
 msgstr "逻辑运算符‘%s’(位于 %%L)的操作数为 %s/%s"
 
-#: fortran/resolve.c:3949
+#: fortran/resolve.c:3955
 #, c-format
 msgid "Operand of .not. operator at %%L is %s"
 msgstr "%%L处的 .not. 运算符的操作数为 %s"
 
-#: fortran/resolve.c:3963
+#: fortran/resolve.c:3969
 msgid "COMPLEX quantities cannot be compared at %L"
 msgstr "%L处复数不能比较大小"
 
-#: fortran/resolve.c:4015
+#: fortran/resolve.c:4021
 #, c-format
 msgid "Logicals at %%L must be compared with %s instead of %s"
 msgstr "%%L处逻辑值必须与 %s 比较，而不是 %s"
 
-#: fortran/resolve.c:4021
+#: fortran/resolve.c:4027
 #, fuzzy, c-format
 #| msgid "Operands of comparison operator '%s' at %%L are %s/%s"
 msgid "Operands of comparison operator %%<%s%%> at %%L are %s/%s"
 msgstr "比较运算符‘%s’(位于 %%L)的操作数为 %s/%s"
 
-#: fortran/resolve.c:4034
+#: fortran/resolve.c:4040
 #, fuzzy, c-format
 #| msgid "Unknown operator '%s' at %%L"
 msgid "Unknown operator %%<%s%%> at %%L; did you mean '%s'?"
 msgstr "未知的运算符‘%s’在 %%L处"
 
-#: fortran/resolve.c:4037
+#: fortran/resolve.c:4043
 #, fuzzy, c-format
 #| msgid "Unknown operator '%s' at %%L"
 msgid "Unknown operator %%<%s%%> at %%L"
 msgstr "未知的运算符‘%s’在 %%L处"
 
-#: fortran/resolve.c:4040
+#: fortran/resolve.c:4046
 #, fuzzy, c-format
 #| msgid "Operand of user operator '%s' at %%L is %s"
 msgid "Operand of user operator %%<%s%%> at %%L is %s"
 msgstr "用户运算符‘%s’(位于 %%L)的操作数为 %s"
 
-#: fortran/resolve.c:4044
+#: fortran/resolve.c:4050
 #, fuzzy, c-format
 #| msgid "Operands of user operator '%s' at %%L are %s/%s"
 msgid "Operands of user operator %%<%s%%> at %%L are %s/%s"
 msgstr "用户运算符‘%s’(位于 %%L)的操作数为 %s/%s"
 
-#: fortran/resolve.c:4132
+#: fortran/resolve.c:4138
 #, c-format
 msgid "Inconsistent ranks for operator at %%L and %%L"
 msgstr "%%L和%%L处的操作数的秩不一致"
 
-#: fortran/resolve.c:6849
+#: fortran/resolve.c:6855
 msgid "Loop variable"
 msgstr "循环变量"
 
-#: fortran/resolve.c:6853
+#: fortran/resolve.c:6859
 #, fuzzy
 msgid "iterator variable"
 msgstr "变量"
 
-#: fortran/resolve.c:6857
+#: fortran/resolve.c:6863
 msgid "Start expression in DO loop"
 msgstr "DO 循环中的开始表达式"
 
-#: fortran/resolve.c:6861
+#: fortran/resolve.c:6867
 msgid "End expression in DO loop"
 msgstr "DO 循环中结束表达式"
 
-#: fortran/resolve.c:6865
+#: fortran/resolve.c:6871
 msgid "Step expression in DO loop"
 msgstr "DO 循环中的步进表达式"
 
-#: fortran/resolve.c:7150 fortran/resolve.c:7153
+#: fortran/resolve.c:7156 fortran/resolve.c:7159
 #, fuzzy
 msgid "DEALLOCATE object"
 msgstr "试图 DEALLOCATE 未分配的‘%s’"
 
-#: fortran/resolve.c:7525 fortran/resolve.c:7528
+#: fortran/resolve.c:7531 fortran/resolve.c:7534
 #, fuzzy
 msgid "ALLOCATE object"
 msgstr "%L处的源表达式和%L处的分配对象必须有相同的外形"
 
-#: fortran/resolve.c:7720 fortran/resolve.c:9417
+#: fortran/resolve.c:7726 fortran/resolve.c:9428
 #, fuzzy
 msgid "STAT variable"
 msgstr "%1$L处的统计变量不能在同一个 %3$s 语句中被 %2$s"
 
-#: fortran/resolve.c:7764 fortran/resolve.c:9429
+#: fortran/resolve.c:7770 fortran/resolve.c:9440
 #, fuzzy
 msgid "ERRMSG variable"
 msgstr "%1$L处的错误信息变量不能在同一 %3$s 语句中被 %2$s"
 
-#: fortran/resolve.c:9219
+#: fortran/resolve.c:9230
 #, fuzzy
 msgid "item in READ"
 msgstr "读取概要："
 
-#: fortran/resolve.c:9441
+#: fortran/resolve.c:9452
 #, fuzzy
 msgid "ACQUIRED_LOCK variable"
 msgstr "无法锁定新归档文件"
@@ -5533,7 +5539,7 @@
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr "目标的分级重新映射太小 (%ld<%ld)"
 
-#: fortran/trans-expr.c:10154
+#: fortran/trans-expr.c:10157
 msgid "Assignment of scalar to unallocated array"
 msgstr ""
 
@@ -5542,12 +5548,12 @@
 msgid "Unequal character lengths (%ld/%ld) in %s"
 msgstr "%3$s 中字符长度不相等 (%1$ld/%2$ld)"
 
-#: fortran/trans-intrinsic.c:8088
+#: fortran/trans-intrinsic.c:8090
 #, fuzzy, c-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative (its value is %ld)"
 msgstr "内建函数 REPEAT 的 NCOPIES 参数为负(其值是 %lld)"
 
-#: fortran/trans-intrinsic.c:8120
+#: fortran/trans-intrinsic.c:8122
 msgid "Argument NCOPIES of REPEAT intrinsic is too large"
 msgstr "内建函数 REPEAT 的 NCOPIES 参数太大"
 
@@ -5568,15 +5574,15 @@
 msgid "Invalid image number %d in SYNC IMAGES"
 msgstr "无效的影像号码 %d 在中同步影像"
 
-#: fortran/trans-stmt.c:2180
+#: fortran/trans-stmt.c:2177
 msgid "Loop iterates infinitely"
 msgstr ""
 
-#: fortran/trans-stmt.c:2200 fortran/trans-stmt.c:2456
+#: fortran/trans-stmt.c:2197 fortran/trans-stmt.c:2453
 msgid "Loop variable has been modified"
 msgstr "循环变量已被修改"
 
-#: fortran/trans-stmt.c:2309
+#: fortran/trans-stmt.c:2306
 msgid "DO step value is zero"
 msgstr "DO 步进值为零"
 
@@ -6260,10 +6266,10 @@
 msgid "Allow dollar signs in entity names."
 msgstr "允许在实体名中使用美元符号"
 
-#: fortran/lang.opt:485 config/alpha/alpha.opt:31 common.opt:783
-#: common.opt:985 common.opt:989 common.opt:993 common.opt:997 common.opt:1532
-#: common.opt:1588 common.opt:1712 common.opt:1716 common.opt:1946
-#: common.opt:2116 common.opt:2792
+#: fortran/lang.opt:485 config/alpha/alpha.opt:31 common.opt:649
+#: common.opt:783 common.opt:989 common.opt:993 common.opt:997 common.opt:1001
+#: common.opt:1536 common.opt:1592 common.opt:1716 common.opt:1720
+#: common.opt:1950 common.opt:2120 common.opt:2796
 msgid "Does nothing. Preserved for backward compatibility."
 msgstr "不起作用。为向前兼容保留的选项。"
 
@@ -6562,12 +6568,12 @@
 msgstr "为外部可见的名字添加下划线"
 
 #: fortran/lang.opt:751 c-family/c.opt:1356 c-family/c.opt:1384
-#: c-family/c.opt:1634 config/pa/pa.opt:42 config/pa/pa.opt:70 common.opt:1154
-#: common.opt:1333 common.opt:1408 common.opt:1676 common.opt:1799
-#: common.opt:2169 common.opt:2205 common.opt:2298 common.opt:2302
-#: common.opt:2407 common.opt:2498 common.opt:2506 common.opt:2514
-#: common.opt:2522 common.opt:2623 common.opt:2675 common.opt:2755
-#: common.opt:2893 common.opt:2897 common.opt:2901 common.opt:2905
+#: c-family/c.opt:1634 config/pa/pa.opt:42 config/pa/pa.opt:70 common.opt:1158
+#: common.opt:1337 common.opt:1412 common.opt:1680 common.opt:1803
+#: common.opt:2173 common.opt:2209 common.opt:2302 common.opt:2306
+#: common.opt:2411 common.opt:2502 common.opt:2510 common.opt:2518
+#: common.opt:2526 common.opt:2627 common.opt:2679 common.opt:2759
+#: common.opt:2897 common.opt:2901 common.opt:2905 common.opt:2909
 msgid "Does nothing.  Preserved for backward compatibility."
 msgstr "不起作用。为向前兼容保留的选项。"
 
@@ -6633,7 +6639,7 @@
 #: c-family/c.opt:70 c-family/c.opt:73 c-family/c.opt:76 c-family/c.opt:79
 #: c-family/c.opt:175 c-family/c.opt:178 c-family/c.opt:220 c-family/c.opt:224
 #: c-family/c.opt:236 c-family/c.opt:1855 c-family/c.opt:1863 brig/lang.opt:39
-#: config/darwin.opt:56 common.opt:338 common.opt:341 common.opt:3046
+#: config/darwin.opt:56 common.opt:338 common.opt:341 common.opt:3050
 #, c-format
 msgid "missing filename after %qs"
 msgstr "%qs后缺少文件名"
@@ -7400,7 +7406,7 @@
 #: c-family/c.opt:1525 c-family/c.opt:1528 c-family/c.opt:1569
 #: c-family/c.opt:1704 c-family/c.opt:1731 c-family/c.opt:1771
 #: c-family/c.opt:1802 c-family/c.opt:1806 c-family/c.opt:1822
-#: config/ia64/ia64.opt:167 config/ia64/ia64.opt:170 c-family/c-opts.c:434
+#: config/ia64/ia64.opt:167 config/ia64/ia64.opt:170 c-family/c-opts.c:432
 #, gcc-internal-format
 msgid "switch %qs is no longer supported"
 msgstr "开关%qs不再被支持"
@@ -16724,10 +16730,6 @@
 msgid "Warn if dereferencing a NULL pointer may lead to erroneous or undefined behavior."
 msgstr ""
 
-#: common.opt:649
-msgid "Warn if the loop cannot be optimized due to nontrivial assumptions."
-msgstr "当循环因为不平凡的假定而不能被优化时给出警告"
-
 #: common.opt:656
 msgid "Warn about some C++ One Definition Rule violations during link time optimization."
 msgstr ""
@@ -16959,2263 +16961,2263 @@
 msgid "-dumpdir <dir>\tSet the directory name to be used for dumps."
 msgstr "-dumpdir <目录>\t设定内存转储使用的目录名"
 
-#: common.opt:946
+#: common.opt:950
 #, fuzzy
 msgid "The version of the C++ ABI in use."
 msgstr "ELF 文件 ABI 版本无效"
 
-#: common.opt:950
+#: common.opt:954
 msgid "Aggressively optimize loops using language constraints."
 msgstr ""
 
-#: common.opt:954
+#: common.opt:958
 #, fuzzy
 #| msgid "Align the start of functions"
 msgid "Align the start of functions."
 msgstr "对齐函数入口"
 
-#: common.opt:964
+#: common.opt:968
 #, fuzzy
 #| msgid "Align labels which are only reached by jumping"
 msgid "Align labels which are only reached by jumping."
 msgstr "对齐只能为跳转所到达的标号"
 
-#: common.opt:971
+#: common.opt:975
 #, fuzzy
 #| msgid "Align all labels"
 msgid "Align all labels."
 msgstr "对齐所有的标号"
 
-#: common.opt:978
+#: common.opt:982
 #, fuzzy
 #| msgid "Align the start of loops"
 msgid "Align the start of loops."
 msgstr "对齐循环入口"
 
-#: common.opt:1001
+#: common.opt:1005
 #, fuzzy
 msgid "Select what to sanitize."
 msgstr "要显示什么以代替标记"
 
-#: common.opt:1005
+#: common.opt:1009
 #, fuzzy
 msgid "Select type of coverage sanitization."
 msgstr "要显示什么以代替标记"
 
-#: common.opt:1009
+#: common.opt:1013
 msgid "-fasan-shadow-offset=<number>\tUse custom shadow memory offset."
 msgstr ""
 
-#: common.opt:1013
+#: common.opt:1017
 msgid "-fsanitize-sections=<sec1,sec2,...>\tSanitize global variables in user-defined sections."
 msgstr ""
 
-#: common.opt:1018
+#: common.opt:1022
 msgid "After diagnosing undefined behavior attempt to continue execution."
 msgstr ""
 
-#: common.opt:1022
+#: common.opt:1026
 #, fuzzy
 msgid "This switch is deprecated; use -fsanitize-recover= instead."
 msgstr "已弃用此开关；请改用 -Wextra"
 
-#: common.opt:1029
+#: common.opt:1033
 msgid "Use trap instead of a library function for undefined behavior sanitization."
 msgstr ""
 
-#: common.opt:1033
+#: common.opt:1037
 #, fuzzy
 #| msgid "Generate unwind tables that are exact at each instruction boundary"
 msgid "Generate unwind tables that are exact at each instruction boundary."
 msgstr "生成精确到每条指令边界的堆栈展开表"
 
-#: common.opt:1037
+#: common.opt:1041
 #, fuzzy
 #| msgid "Generate auto-inc/dec instructions"
 msgid "Generate auto-inc/dec instructions."
 msgstr "生成 auto-inc/dec指令"
 
-#: common.opt:1041
+#: common.opt:1045
 #, fuzzy
 msgid "Use sample profile information for call graph node weights. The default profile file is fbdata.afdo in 'pwd'."
 msgstr "为分支概率使用取样信息"
 
-#: common.opt:1046
+#: common.opt:1050
 #, fuzzy
 msgid "Use sample profile information for call graph node weights. The profile file is specified in the argument."
 msgstr "为分支概率使用取样信息"
 
-#: common.opt:1055
+#: common.opt:1059
 #, fuzzy
 #| msgid "Generate code to check bounds before indexing arrays"
 msgid "Generate code to check bounds before indexing arrays."
 msgstr "生成检查数组访问是否越界的代码"
 
-#: common.opt:1059
+#: common.opt:1063
 #, fuzzy
 #| msgid "Replace add, compare, branch with branch on count register"
 msgid "Replace add, compare, branch with branch on count register."
 msgstr "将加/减法、比较、跳转指令序列替换为根据计数寄存器跳转指令"
 
-#: common.opt:1063
+#: common.opt:1067
 #, fuzzy
 #| msgid "Use profiling information for branch probabilities"
 msgid "Use profiling information for branch probabilities."
 msgstr "为分支概率使用取样信息"
 
-#: common.opt:1067
+#: common.opt:1071
 #, fuzzy
 #| msgid "Perform branch target load optimization before prologue / epilogue threading"
 msgid "Perform branch target load optimization before prologue / epilogue threading."
 msgstr "在开始/结末线程前进行分支目标载入优化"
 
-#: common.opt:1071
+#: common.opt:1075
 #, fuzzy
 #| msgid "Perform branch target load optimization after prologue / epilogue threading"
 msgid "Perform branch target load optimization after prologue / epilogue threading."
 msgstr "在开始/结末线程后进行分支目标载入优化"
 
-#: common.opt:1075
+#: common.opt:1079
 #, fuzzy
 #| msgid "Restrict target load migration not to re-use registers in any basic block"
 msgid "Restrict target load migration not to re-use registers in any basic block."
 msgstr "限制目标载入融合不重用任何基本块中的寄存器"
 
-#: common.opt:1079
+#: common.opt:1083
 #, fuzzy
 #| msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions"
 msgid "-fcall-saved-<register>\tMark <register> as being preserved across functions."
 msgstr "-fcall-saved-<寄存器>\t认为寄存器在函数调用后值不变"
 
-#: common.opt:1083
+#: common.opt:1087
 #, fuzzy
 #| msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls"
 msgid "-fcall-used-<register>\tMark <register> as being corrupted by function calls."
 msgstr "-fcall-used-<寄存器>\t认为寄存器的值将被函数调用所改变"
 
-#: common.opt:1090
+#: common.opt:1094
 #, fuzzy
 #| msgid "Save registers around function calls"
 msgid "Save registers around function calls."
 msgstr "函数调用前后保存/恢复寄存器值"
 
-#: common.opt:1094
+#: common.opt:1098
 #, fuzzy
 #| msgid "This switch is deprecated; use -Wextra instead"
 msgid "This switch is deprecated; do not use."
 msgstr "已弃用此开关；请改用 -Wextra"
 
-#: common.opt:1098
+#: common.opt:1102
 #, fuzzy
 msgid "Check the return value of new in C++."
 msgstr "检查 new 的返回值"
 
-#: common.opt:1102 common.opt:1106
+#: common.opt:1106 common.opt:1110
 #, fuzzy
 #| msgid "internal consistency failure"
 msgid "Perform internal consistency checkings."
 msgstr "内部一致性错误"
 
-#: common.opt:1110
+#: common.opt:1114
 #, fuzzy
 #| msgid "Enable dead store elimination"
 msgid "Enable code hoisting."
 msgstr "删除死存储"
 
-#: common.opt:1114
+#: common.opt:1118
 #, fuzzy
 msgid "Looks for opportunities to reduce stack adjustments and stack references."
 msgstr "找寻机会到缩小堆叠调整和堆叠参考。"
 
-#: common.opt:1118
+#: common.opt:1122
 #, fuzzy
 #| msgid "Do not put uninitialized globals in the common section"
 msgid "Do not put uninitialized globals in the common section."
 msgstr "不将未初始化的全局数据放在公共节中"
 
-#: common.opt:1126
+#: common.opt:1130
 #, fuzzy
 #| msgid "-fcompare-debug[=<opts>]\tCompile with and without e.g. -gtoggle, and compare the final-insns dump"
 msgid "-fcompare-debug[=<opts>]\tCompile with and without e.g. -gtoggle, and compare the final-insns dump."
 msgstr "-fcompare-debug[=<选项>]\t分别在带与不带“选项”，例如 -gtoggle，的情况下编译，然后比较最后的指令输出"
 
-#: common.opt:1130
+#: common.opt:1134
 #, fuzzy
 #| msgid "Run only the second compilation of -fcompare-debug"
 msgid "Run only the second compilation of -fcompare-debug."
 msgstr "只为 -fcompare-debug 运行第二遍编译"
 
-#: common.opt:1134
+#: common.opt:1138
 #, fuzzy
 msgid "Perform comparison elimination after register allocation has finished."
 msgstr "在分配寄存器后进行全局公共子表达式消除"
 
-#: common.opt:1138
+#: common.opt:1142
 #, fuzzy
 #| msgid "Do not perform optimizations increasing noticeably stack usage"
 msgid "Do not perform optimizations increasing noticeably stack usage."
 msgstr "不进行可能导致堆栈使用明显增长的优化"
 
-#: common.opt:1142
+#: common.opt:1146
 #, fuzzy
 #| msgid "Perform a register copy-propagation optimization pass"
 msgid "Perform a register copy-propagation optimization pass."
 msgstr "进行一趟寄存器副本传递优化"
 
-#: common.opt:1146
+#: common.opt:1150
 #, fuzzy
 #| msgid "Perform cross-jumping optimization"
 msgid "Perform cross-jumping optimization."
 msgstr "进行跨跳转优化"
 
-#: common.opt:1150
+#: common.opt:1154
 #, fuzzy
 #| msgid "When running CSE, follow jumps to their targets"
 msgid "When running CSE, follow jumps to their targets."
 msgstr "进行 CSE 时，跟随跳转至目标"
 
-#: common.opt:1158
+#: common.opt:1162
 #, fuzzy
 #| msgid "Omit range reduction step when performing complex division"
 msgid "Omit range reduction step when performing complex division."
 msgstr "当进行复数除法时省略缩减范围的步骤"
 
-#: common.opt:1162
+#: common.opt:1166
 #, fuzzy
 #| msgid "Complex multiplication and division follow Fortran rules"
 msgid "Complex multiplication and division follow Fortran rules."
 msgstr "复数乘除遵循 Fortran 规则"
 
-#: common.opt:1166
+#: common.opt:1170
 #, fuzzy
 #| msgid "Place data items into their own section"
 msgid "Place data items into their own section."
 msgstr "将每个数据项分别放在它们各自的节中"
 
-#: common.opt:1170
+#: common.opt:1174
 msgid "List all available debugging counters with their limits and counts."
 msgstr "列出所有可用的调试计数器及其极限和计数。"
 
-#: common.opt:1174
+#: common.opt:1178
 #, fuzzy
 #| msgid "-fdbg-cnt=<counter>:<limit>[,<counter>:<limit>,...]\tSet the debug counter limit.   "
 msgid "-fdbg-cnt=<counter>:<limit>[,<counter>:<limit>,...]\tSet the debug counter limit."
 msgstr "-fdbg-cnt=<计数器>:<极限>[,<计数器>:<极限>,...]\t设定调试计数器极限。"
 
-#: common.opt:1178
+#: common.opt:1182
 #, fuzzy
 #| msgid "Map one directory name to another in debug information"
 msgid "-fdebug-prefix-map=<old>=<new> Map one directory name to another in debug information."
 msgstr "在调试信息中将一个目录名映射到另一个"
 
-#: common.opt:1182
+#: common.opt:1186
 #, fuzzy
 #| msgid "Map one directory name to another in debug information"
 msgid "-ffile-prefix-map=<old>=<new> Map one directory name to another in compilation result."
 msgstr "在调试信息中将一个目录名映射到另一个"
 
-#: common.opt:1186
+#: common.opt:1190
 msgid "Output .debug_types section when using DWARF v4 debuginfo."
 msgstr "使用 DWARF v4 debuginfo 时输出 .debug_types 区段。"
 
-#: common.opt:1192
+#: common.opt:1196
 #, fuzzy
 #| msgid "Defer popping functions args from stack until later"
 msgid "Defer popping functions args from stack until later."
 msgstr "延迟将函数实参弹栈"
 
-#: common.opt:1196
+#: common.opt:1200
 #, fuzzy
 #| msgid "Attempt to fill delay slots of branch instructions"
 msgid "Attempt to fill delay slots of branch instructions."
 msgstr "尝试填充分支指令的延迟槽"
 
-#: common.opt:1200
+#: common.opt:1204
 msgid "Delete dead instructions that may throw exceptions."
 msgstr ""
 
-#: common.opt:1204
+#: common.opt:1208
 #, fuzzy
 #| msgid "Delete useless null pointer checks"
 msgid "Delete useless null pointer checks."
 msgstr "删除无用的空指针检查"
 
-#: common.opt:1208
+#: common.opt:1212
 msgid "Stream extra data to support more aggressive devirtualization in LTO local transformation mode."
 msgstr ""
 
-#: common.opt:1212
+#: common.opt:1216
 #, fuzzy
 msgid "Perform speculative devirtualization."
 msgstr "允许非载入的投机移动"
 
-#: common.opt:1216
+#: common.opt:1220
 #, fuzzy
 msgid "Try to convert virtual calls to direct ones."
 msgstr "允许链接器将 PIC 调用转化为直接调用"
 
-#: common.opt:1220
+#: common.opt:1224
 #, fuzzy
 #| msgid "-fdiagnostics-show-location=[once|every-line]\tHow often to emit source location at the beginning of line-wrapped diagnostics"
 msgid "-fdiagnostics-show-location=[once|every-line]\tHow often to emit source location at the beginning of line-wrapped diagnostics."
 msgstr "-fdiagnostics-show-location=[once|every-line]\t指定在自动换行的诊断信息开始给出源位置的频率"
 
-#: common.opt:1237
+#: common.opt:1241
 msgid "Show the source line with a caret indicating the column."
 msgstr ""
 
-#: common.opt:1245
+#: common.opt:1249
 msgid "-fdiagnostics-color=[never|always|auto]\tColorize diagnostics."
 msgstr ""
 
-#: common.opt:1265
+#: common.opt:1269
 msgid "Print fix-it hints in machine-readable form."
 msgstr ""
 
-#: common.opt:1269
+#: common.opt:1273
 msgid "Print fix-it hints to stderr in unified diff format."
 msgstr ""
 
-#: common.opt:1273
+#: common.opt:1277
 #, fuzzy
 #| msgid "Amend appropriate diagnostic messages with the command line option that controls them"
 msgid "Amend appropriate diagnostic messages with the command line option that controls them."
 msgstr "在诊断信息后输出控制它们的命令行选项"
 
-#: common.opt:1277
+#: common.opt:1281
 #, fuzzy
 msgid "-fdisable-[tree|rtl|ipa]-<pass>=range1+range2 disables an optimization pass."
 msgstr "-fdisable-[ 树|rtl|ipa ]-<pass>=range1+range2 停用最佳化回合"
 
-#: common.opt:1281
+#: common.opt:1285
 #, fuzzy
 msgid "-fenable-[tree|rtl|ipa]-<pass>=range1+range2 enables an optimization pass."
 msgstr "-fenable-[ 树|rtl|ipa ]-<pass>=range1+range2 启用最佳化回合"
 
-#: common.opt:1285
+#: common.opt:1289
 #, fuzzy
 #| msgid "-fdump-<type>\tDump various compiler internals to a file"
 msgid "-fdump-<type>\tDump various compiler internals to a file."
 msgstr "-fdump-<类型>\t将一些编译器内部信息转储到一个文件里"
 
-#: common.opt:1292
+#: common.opt:1296
 #, fuzzy
 #| msgid "-fdump-final-insns=filename\tDump to filename the insns at the end of translation"
 msgid "-fdump-final-insns=filename\tDump to filename the insns at the end of translation."
 msgstr "-fdump-final-insns=文件名\t在翻译完毕后将指令输出到文件中"
 
-#: common.opt:1296
+#: common.opt:1300
 #, fuzzy
 msgid "-fdump-go-spec=filename\tWrite all declarations to file as Go code."
 msgstr "-fdump-go-spec=文件名\t写入所有声明到文件作为前往编码"
 
-#: common.opt:1300
+#: common.opt:1304
 #, fuzzy
 #| msgid "Suppress output of addresses in debugging dumps"
 msgid "Suppress output of addresses in debugging dumps."
 msgstr "在调试转储中不输出地址"
 
-#: common.opt:1304
+#: common.opt:1308
 msgid "Collect and dump debug information into temporary file if ICE in C/C++ compiler occurred."
 msgstr ""
 
-#: common.opt:1309
+#: common.opt:1313
 msgid "Dump detailed information on GCC's internal representation of source code locations."
 msgstr ""
 
-#: common.opt:1313
+#: common.opt:1317
 #, fuzzy
 msgid "Dump optimization passes."
 msgstr "调出基本的文件信息"
 
-#: common.opt:1317
+#: common.opt:1321
 #, fuzzy
 #| msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps"
 msgid "Suppress output of instruction numbers, line number notes and addresses in debugging dumps."
 msgstr "在调试转储中不输出指令数、行号标记和地址"
 
-#: common.opt:1321
+#: common.opt:1325
 #, fuzzy
 #| msgid "Suppress output of previous and next insn numbers in debugging dumps"
 msgid "Suppress output of previous and next insn numbers in debugging dumps."
 msgstr "在调试转储中不输出前一条和后一条指令号码"
 
-#: common.opt:1325
+#: common.opt:1329
 msgid "Enable CFI tables via GAS assembler directives."
 msgstr "用 GAS 汇编指示来启用 CFI 表"
 
-#: common.opt:1329
+#: common.opt:1333
 #, fuzzy
 #| msgid "Perform early inlining"
 msgid "Perform early inlining."
 msgstr "进行早内联"
 
-#: common.opt:1337
+#: common.opt:1341
 #, fuzzy
 #| msgid "Perform interprocedural reduction of aggregates"
 msgid "Perform interprocedural reduction of aggregates."
 msgstr "为聚合类型进行跨进程标量替换"
 
-#: common.opt:1341
+#: common.opt:1345
 #, fuzzy
 msgid "Perform unused symbol elimination in debug info."
 msgstr "在调试信息中进行无用类型消除"
 
-#: common.opt:1345
+#: common.opt:1349
 #, fuzzy
 #| msgid "Perform unused type elimination in debug info"
 msgid "Perform unused type elimination in debug info."
 msgstr "在调试信息中进行无用类型消除"
 
-#: common.opt:1349
+#: common.opt:1353
 msgid "Do not suppress C++ class debug information."
 msgstr "保留 C++ 类调试信息。"
 
-#: common.opt:1353
+#: common.opt:1357
 #, fuzzy
 #| msgid "Enable exception handling"
 msgid "Enable exception handling."
 msgstr "启用异常处理"
 
-#: common.opt:1357
+#: common.opt:1361
 #, fuzzy
 #| msgid "Perform a number of minor, expensive optimizations"
 msgid "Perform a number of minor, expensive optimizations."
 msgstr "进行一些细微的、代价高昂的优化"
 
-#: common.opt:1361
+#: common.opt:1365
 #, fuzzy
 #| msgid "-fexcess-precision=[fast|standard]\tSpecify handling of excess floating-point precision"
 msgid "-fexcess-precision=[fast|standard]\tSpecify handling of excess floating-point precision."
 msgstr "-fexcess-precision=[fast|standard]\t指定如何处理有额外精度的浮点数"
 
-#: common.opt:1364
+#: common.opt:1368
 #, fuzzy, c-format
 msgid "unknown excess precision style %qs"
 msgstr "未知的额外精度风格“%s”"
 
-#: common.opt:1376
+#: common.opt:1380
 msgid "-fpermitted-flt-eval-methods=[c11|ts-18661]\tSpecify which values of FLT_EVAL_METHOD are permitted."
 msgstr ""
 
-#: common.opt:1379
+#: common.opt:1383
 #, c-format
 msgid "unknown specification for the set of FLT_EVAL_METHOD values to permit %qs"
 msgstr ""
 
-#: common.opt:1392
+#: common.opt:1396
 #, fuzzy
 msgid "Output lto objects containing both the intermediate language and binary output."
 msgstr "输出 lto 对象包含两者中介语言和二进制输出。"
 
-#: common.opt:1396
+#: common.opt:1400
 #, fuzzy
 #| msgid "Assume no NaNs or infinities are generated"
 msgid "Assume no NaNs or infinities are generated."
 msgstr "假定结果不会是 NaN 或无穷大浮点数"
 
-#: common.opt:1400
+#: common.opt:1404
 #, fuzzy
 #| msgid "-ffixed-<register>\tMark <register> as being unavailable to the compiler"
 msgid "-ffixed-<register>\tMark <register> as being unavailable to the compiler."
 msgstr "-ffixed-<寄存器>\t认为寄存器对编译器而言不可用"
 
-#: common.opt:1404
+#: common.opt:1408
 #, fuzzy
 #| msgid "Don't allocate floats and doubles in extended-precision registers"
 msgid "Don't allocate floats and doubles in extended-precision registers."
 msgstr "不将单精度和双精度浮点数分配到扩展精度的寄存器中"
 
-#: common.opt:1412
+#: common.opt:1416
 #, fuzzy
 #| msgid "Perform a forward propagation pass on RTL"
 msgid "Perform a forward propagation pass on RTL."
 msgstr "进行 RTL 上的前向传递"
 
-#: common.opt:1416
+#: common.opt:1420
 #, fuzzy
 msgid "-ffp-contract=[off|on|fast]\tPerform floating-point expression contraction."
 msgstr "-ffp-contract=[关闭|于|快速] 施行浮点运算式合约。"
 
-#: common.opt:1419
+#: common.opt:1423
 #, fuzzy, c-format
 msgid "unknown floating point contraction style %qs"
 msgstr "在 TOC 中存放浮点常量"
 
-#: common.opt:1433
+#: common.opt:1437
 msgid "Allow built-in functions ceil, floor, round, trunc to raise \"inexact\" exceptions."
 msgstr ""
 
-#: common.opt:1440
+#: common.opt:1444
 #, fuzzy
 #| msgid "Allow function addresses to be held in registers"
 msgid "Allow function addresses to be held in registers."
 msgstr "允许将函数地址保存在寄存器中"
 
-#: common.opt:1444
+#: common.opt:1448
 #, fuzzy
 #| msgid "Place each function into its own section"
 msgid "Place each function into its own section."
 msgstr "将每个函数分别放在它们各自的节中"
 
-#: common.opt:1448
+#: common.opt:1452
 #, fuzzy
 #| msgid "Perform global common subexpression elimination"
 msgid "Perform global common subexpression elimination."
 msgstr "进行全局公共子表达式消除"
 
-#: common.opt:1452
+#: common.opt:1456
 #, fuzzy
 #| msgid "Perform enhanced load motion during global common subexpression elimination"
 msgid "Perform enhanced load motion during global common subexpression elimination."
 msgstr "在全局公共子表达式消除中进行增强的读转移优化"
 
-#: common.opt:1456
+#: common.opt:1460
 #, fuzzy
 #| msgid "Perform store motion after global common subexpression elimination"
 msgid "Perform store motion after global common subexpression elimination."
 msgstr "在全局公共子表达式消除后进行存储转移"
 
-#: common.opt:1460
+#: common.opt:1464
 #, fuzzy
 #| msgid "Perform redundant load after store elimination in global common subexpression"
 msgid "Perform redundant load after store elimination in global common subexpression elimination."
 msgstr "在全局公共子表达式消除中进行冗余的写后读消除"
 
-#: common.opt:1465
+#: common.opt:1469
 #, fuzzy
 #| msgid "Perform global common subexpression elimination after register allocation"
 msgid "Perform global common subexpression elimination after register allocation has finished."
 msgstr "在分配寄存器后进行全局公共子表达式消除"
 
-#: common.opt:1482
+#: common.opt:1486
 msgid "-fgnat-encodings=[all|gdb|minimal]\tSelect the balance between GNAT encodings and standard DWARF emitted in the debug information"
 msgstr ""
 
-#: common.opt:1487
+#: common.opt:1491
 #, fuzzy
 #| msgid "Enable in and out of Graphite representation"
 msgid "Enable in and out of Graphite representation."
 msgstr "启用 Graphite 表示的输入输出"
 
-#: common.opt:1491
+#: common.opt:1495
 #, fuzzy
 #| msgid "Enable Graphite Identity transformation"
 msgid "Enable Graphite Identity transformation."
 msgstr "启用 Graphite 身份转换"
 
-#: common.opt:1495
+#: common.opt:1499
 #, fuzzy
 msgid "Enable hoisting adjacent loads to encourage generating conditional move instructions."
 msgstr "为条件指针外提内存读取操作。"
 
-#: common.opt:1504
+#: common.opt:1508
 #, fuzzy
 #| msgid "Mark all loops as parallel"
 msgid "Mark all loops as parallel."
 msgstr "将所有循环标记为并行"
 
-#: common.opt:1508 common.opt:1516 common.opt:2587
+#: common.opt:1512 common.opt:1520 common.opt:2591
 #, fuzzy
 msgid "Enable loop nest transforms.  Same as -floop-nest-optimize."
 msgstr "启用循环交换转换"
 
-#: common.opt:1512
+#: common.opt:1516
 #, fuzzy
 #| msgid "Enable loop header copying on trees"
 msgid "Enable loop interchange on trees."
 msgstr "启用树上的循环不变量转移"
 
-#: common.opt:1520
+#: common.opt:1524
 #, fuzzy
 #| msgid "Perform loop unrolling for all loops"
 msgid "Perform unroll-and-jam on loops."
 msgstr "展开所有循环"
 
-#: common.opt:1524
+#: common.opt:1528
 #, fuzzy
 msgid "Enable support for GNU transactional memory."
 msgstr "启用支持用于 GNU transactional 内存"
 
-#: common.opt:1528
+#: common.opt:1532
 msgid "Use STB_GNU_UNIQUE if supported by the assembler."
 msgstr ""
 
-#: common.opt:1536
+#: common.opt:1540
 #, fuzzy
 #| msgid "Enable label alignment optimizations"
 msgid "Enable the loop nest optimizer."
 msgstr "启用标号对齐优化"
 
-#: common.opt:1540
+#: common.opt:1544
 #, fuzzy
 msgid "Force bitfield accesses to match their type width."
 msgstr "强制 bitfield 访问到匹配它们的类型宽度"
 
-#: common.opt:1544
+#: common.opt:1548
 msgid "Merge adjacent stores."
 msgstr ""
 
-#: common.opt:1548
+#: common.opt:1552
 #, fuzzy
 #| msgid "Enable guessing of branch probabilities"
 msgid "Enable guessing of branch probabilities."
 msgstr "启用分支概率猜测"
 
-#: common.opt:1556
+#: common.opt:1560
 #, fuzzy
 #| msgid "Process #ident directives"
 msgid "Process #ident directives."
 msgstr "处理 #ident 指令"
 
-#: common.opt:1560
+#: common.opt:1564
 #, fuzzy
 #| msgid "Perform conversion of conditional jumps to branchless equivalents"
 msgid "Perform conversion of conditional jumps to branchless equivalents."
 msgstr "将条件跳转替换为没有跳转的等值表示"
 
-#: common.opt:1564
+#: common.opt:1568
 #, fuzzy
 #| msgid "Perform conversion of conditional jumps to conditional execution"
 msgid "Perform conversion of conditional jumps to conditional execution."
 msgstr "将条件跳转替换为条件执行"
 
-#: common.opt:1568
+#: common.opt:1572
 msgid "-fstack-reuse=[all|named_vars|none]\tSet stack reuse level for local variables."
 msgstr ""
 
-#: common.opt:1571
+#: common.opt:1575
 #, c-format
 msgid "unknown Stack Reuse Level %qs"
 msgstr "未知的栈重用级别%qs"
 
-#: common.opt:1584
+#: common.opt:1588
 #, fuzzy
 msgid "Convert conditional jumps in innermost loops to branchless equivalents."
 msgstr "将条件跳转替换为没有跳转的等值表示"
 
-#: common.opt:1596
+#: common.opt:1600
 #, fuzzy
 #| msgid "Do not generate .size directives"
 msgid "Do not generate .size directives."
 msgstr "不生成 .size 伪指令"
 
-#: common.opt:1600
+#: common.opt:1604
 #, fuzzy
 #| msgid "Perform indirect inlining"
 msgid "Perform indirect inlining."
 msgstr "进行间接内联"
 
-#: common.opt:1606
+#: common.opt:1610
 #, fuzzy
 msgid "Enable inlining of function declared \"inline\", disabling disables all inlining."
 msgstr "启用内联的函数声明“内联”，停用全部停用内联"
 
-#: common.opt:1610
+#: common.opt:1614
 #, fuzzy
 msgid "Integrate functions into their callers when code size is known not to grow."
 msgstr "在不导致代码膨胀的情况下将简单函数集成到它们的调用者中"
 
-#: common.opt:1614
+#: common.opt:1618
 #, fuzzy
 msgid "Integrate functions not declared \"inline\" into their callers when profitable."
 msgstr "将只被调用一次的函数集成到它们的调用者中"
 
-#: common.opt:1618
+#: common.opt:1622
 #, fuzzy
 msgid "Integrate functions only required by their single caller."
 msgstr "将只被调用一次的函数集成到它们的调用者中"
 
-#: common.opt:1625
+#: common.opt:1629
 #, fuzzy
 #| msgid "-finline-limit=<number>\tLimit the size of inlined functions to <number>"
 msgid "-finline-limit=<number>\tLimit the size of inlined functions to <number>."
 msgstr "-finline-limit=<N>\t将内联函数的大小限制在 N 以内"
 
-#: common.opt:1629
+#: common.opt:1633
 #, fuzzy
 msgid "Inline __atomic operations when a lock free instruction sequence is available."
 msgstr "内联 __atomic 计算时锁定自由指令串行是可用。"
 
-#: common.opt:1636
+#: common.opt:1640
 msgid "-fcf-protection=[full|branch|return|none]\tInstrument functions with checks to verify jump/call/return control-flow transfer instructions have valid targets."
 msgstr ""
 
-#: common.opt:1640
+#: common.opt:1644
 #, fuzzy, c-format
 #| msgid "unknown Stack Reuse Level %qs"
 msgid "unknown Control-Flow Protection Level %qs"
 msgstr "未知的栈重用级别%qs"
 
-#: common.opt:1656
+#: common.opt:1660
 #, fuzzy
 #| msgid "Instrument function entry and exit with profiling calls"
 msgid "Instrument function entry and exit with profiling calls."
 msgstr "在函数入口和出口加入取样调用"
 
-#: common.opt:1660
+#: common.opt:1664
 #, fuzzy
 #| msgid "-finstrument-functions-exclude-function-list=name,...  Do not instrument listed functions"
 msgid "-finstrument-functions-exclude-function-list=name,...  Do not instrument listed functions."
 msgstr "-finstrument-functions-exclude-function-list=函数名,...  取样时排除列出的函数"
 
-#: common.opt:1664
+#: common.opt:1668
 #, fuzzy
 #| msgid "-finstrument-functions-exclude-file-list=filename,...  Do not instrument functions listed in files"
 msgid "-finstrument-functions-exclude-file-list=filename,...  Do not instrument functions listed in files."
 msgstr "-finstrument-functions-exclude-file-list=文件名,...  取样时排除列出的文件中的函数"
 
-#: common.opt:1668
+#: common.opt:1672
 #, fuzzy
 msgid "Perform interprocedural constant propagation."
 msgstr "进行进程间的复写传递"
 
-#: common.opt:1672
+#: common.opt:1676
 #, fuzzy
 #| msgid "Perform cloning to make Interprocedural constant propagation stronger"
 msgid "Perform cloning to make Interprocedural constant propagation stronger."
 msgstr "进行复制以使跨进程常量传递更有效"
 
-#: common.opt:1680
+#: common.opt:1684
 #, fuzzy
 msgid "Perform interprocedural bitwise constant propagation."
 msgstr "进行进程间的复写传递"
 
-#: common.opt:1684
+#: common.opt:1688
 #, fuzzy
 msgid "Perform interprocedural profile propagation."
 msgstr "进行进程间的复写传递"
 
-#: common.opt:1688
+#: common.opt:1692
 #, fuzzy
 #| msgid "Perform interprocedural points-to analysis"
 msgid "Perform interprocedural points-to analysis."
 msgstr "进行进程间的指向分析"
 
-#: common.opt:1692
+#: common.opt:1696
 #, fuzzy
 #| msgid "Discover pure and const functions"
 msgid "Discover pure and const functions."
 msgstr "发现纯函数和常函数"
 
-#: common.opt:1696
+#: common.opt:1700
 #, fuzzy
 msgid "Perform Identical Code Folding for functions and read-only variables."
 msgstr "展开所有循环"
 
-#: common.opt:1700
+#: common.opt:1704
 #, fuzzy
 msgid "Perform Identical Code Folding for functions."
 msgstr "展开所有循环"
 
-#: common.opt:1704
+#: common.opt:1708
 #, fuzzy
 msgid "Perform Identical Code Folding for variables."
 msgstr "展开所有循环"
 
-#: common.opt:1708
+#: common.opt:1712
 #, fuzzy
 #| msgid "Discover readonly and non addressable static variables"
 msgid "Discover readonly and non addressable static variables."
 msgstr "发现只读和不可寻址静态变量"
 
-#: common.opt:1720
+#: common.opt:1724
 #, fuzzy
 #| msgid "Perform Value Range Propagation on trees"
 msgid "Perform IPA Value Range Propagation."
 msgstr "进行树上的值域传递"
 
-#: common.opt:1724
+#: common.opt:1728
 #, fuzzy
 #| msgid "-fira-algorithm=[CB|priority] Set the used IRA algorithm"
 msgid "-fira-algorithm=[CB|priority]\tSet the used IRA algorithm."
 msgstr "-fira-algorithm=|CB|priority] 设置使用的 IRA 算法"
 
-#: common.opt:1727
+#: common.opt:1731
 #, fuzzy, c-format
 msgid "unknown IRA algorithm %qs"
 msgstr "未知的 TLS 模型%qs"
 
-#: common.opt:1737
+#: common.opt:1741
 #, fuzzy
 #| msgid "-fira-region=[one|all|mixed] Set regions for IRA"
 msgid "-fira-region=[one|all|mixed]\tSet regions for IRA."
 msgstr "-fira-region=[one|all|mixed] 设置 IRA 的区域"
 
-#: common.opt:1740
+#: common.opt:1744
 #, fuzzy, c-format
 msgid "unknown IRA region %qs"
 msgstr "未知的 TLS 模型%qs"
 
-#: common.opt:1753
+#: common.opt:1757
 #, fuzzy
 #| msgid "Use IRA based register pressure calculation"
 msgid "Use IRA based register pressure calculation in RTL hoist optimizations."
 msgstr "使用基于 IRA 的寄存器压力计算"
 
-#: common.opt:1758
+#: common.opt:1762
 #, fuzzy
 #| msgid "Use IRA based register pressure calculation"
 msgid "Use IRA based register pressure calculation in RTL loop optimizations."
 msgstr "使用基于 IRA 的寄存器压力计算"
 
-#: common.opt:1763
+#: common.opt:1767
 msgid "Share slots for saving different hard registers."
 msgstr "为保存不同的硬寄存器的共享槽。"
 
-#: common.opt:1767
+#: common.opt:1771
 msgid "Share stack slots for spilled pseudo-registers."
 msgstr "为溢出的伪寄存器共享堆栈槽。"
 
-#: common.opt:1771
+#: common.opt:1775
 msgid "-fira-verbose=<number>\tControl IRA's level of diagnostic messages."
 msgstr "-fira-verbose=<N>\t控制 IRA 诊断信息的级别。"
 
-#: common.opt:1775
+#: common.opt:1779
 #, fuzzy
 #| msgid "Optimize induction variables on trees"
 msgid "Optimize induction variables on trees."
 msgstr "在树上优化归纳变量"
 
-#: common.opt:1779
+#: common.opt:1783
 #, fuzzy
 #| msgid "Use jump tables for sufficiently large switch statements"
 msgid "Use jump tables for sufficiently large switch statements."
 msgstr "为足够大的 switch 语句使用跳转表"
 
-#: common.opt:1783
+#: common.opt:1787
 #, fuzzy
 #| msgid "Generate code for functions even if they are fully inlined"
 msgid "Generate code for functions even if they are fully inlined."
 msgstr "为完全内联的函数生成代码"
 
-#: common.opt:1787
+#: common.opt:1791
 #, fuzzy
 #| msgid "Generate code for functions even if they are fully inlined"
 msgid "Generate code for static functions even if they are never called."
 msgstr "为完全内联的函数生成代码"
 
-#: common.opt:1791
+#: common.opt:1795
 #, fuzzy
 #| msgid "Emit static const variables even if they are not used"
 msgid "Emit static const variables even if they are not used."
 msgstr "保留未用到的静态常量"
 
-#: common.opt:1795
+#: common.opt:1799
 #, fuzzy
 #| msgid "Give external symbols a leading underscore"
 msgid "Give external symbols a leading underscore."
 msgstr "给外部符号添加起始的下划线"
 
-#: common.opt:1803
+#: common.opt:1807
 msgid "Do CFG-sensitive rematerialization in LRA."
 msgstr ""
 
-#: common.opt:1807
+#: common.opt:1811
 msgid "Enable link-time optimization."
 msgstr "启用链接时优化。"
 
-#: common.opt:1811
+#: common.opt:1815
 #, fuzzy
 msgid "Link-time optimization with number of parallel jobs or jobserver."
 msgstr "Link-time 最佳化与平行工作编号的或 jobserver。"
 
-#: common.opt:1814
+#: common.opt:1818
 #, fuzzy, c-format
 msgid "unknown LTO partitioning model %qs"
 msgstr "未知的 TLS 模型%qs"
 
-#: common.opt:1833
+#: common.opt:1837
 msgid "Specify the algorithm to partition symbols and vars at linktime."
 msgstr ""
 
-#: common.opt:1838
+#: common.opt:1842
 #, fuzzy
 #| msgid "-flto-compression-level=<number>\tUse zlib compression level <number> for IL"
 msgid "-flto-compression-level=<number>\tUse zlib compression level <number> for IL."
 msgstr "-flto-compression-level=<N>\t为 IL 使用 zlib 压缩级别 N"
 
-#: common.opt:1842
+#: common.opt:1846
 msgid "Merge C++ types using One Definition Rule."
 msgstr ""
 
-#: common.opt:1846
+#: common.opt:1850
 #, fuzzy
 #| msgid "Report various link-time optimization statistics"
 msgid "Report various link-time optimization statistics."
 msgstr "报告各种链接时优化统计"
 
-#: common.opt:1850
+#: common.opt:1854
 #, fuzzy
 msgid "Report various link-time optimization statistics for WPA only."
 msgstr "报告各种链接时优化统计"
 
-#: common.opt:1854
+#: common.opt:1858
 #, fuzzy
 #| msgid "Set errno after built-in math functions"
 msgid "Set errno after built-in math functions."
 msgstr "执行内建数学函数后设置 errno"
 
-#: common.opt:1858
+#: common.opt:1862
 #, fuzzy
 #| msgid "-fmax-errors=<number>\tMaximum number of errors to report"
 msgid "-fmax-errors=<number>\tMaximum number of errors to report."
 msgstr "-fmax-errors=<n>\t报告错误数量的上限值"
 
-#: common.opt:1862
+#: common.opt:1866
 #, fuzzy
 #| msgid "Report on permanent memory allocation"
 msgid "Report on permanent memory allocation."
 msgstr "报告永久性内存分配"
 
-#: common.opt:1866
+#: common.opt:1870
 #, fuzzy
 msgid "Report on permanent memory allocation in WPA only."
 msgstr "报告永久性内存分配"
 
-#: common.opt:1873
+#: common.opt:1877
 #, fuzzy
 #| msgid "Attempt to merge identical constants and constant variables"
 msgid "Attempt to merge identical constants and constant variables."
 msgstr "试图合并相同的常量和常变量"
 
-#: common.opt:1877
+#: common.opt:1881
 #, fuzzy
 #| msgid "Attempt to merge identical constants across compilation units"
 msgid "Attempt to merge identical constants across compilation units."
 msgstr "试图合并不同编译单元中的相同常量"
 
-#: common.opt:1881
+#: common.opt:1885
 #, fuzzy
 #| msgid "Attempt to merge identical debug strings across compilation units"
 msgid "Attempt to merge identical debug strings across compilation units."
 msgstr "试图合并不同编译单元中的相同调试字符串"
 
-#: common.opt:1885
+#: common.opt:1889
 #, fuzzy
 #| msgid "-fmessage-length=<number>\tLimit diagnostics to <number> characters per line.  0 suppresses line-wrapping"
 msgid "-fmessage-length=<number>\tLimit diagnostics to <number> characters per line.  0 suppresses line-wrapping."
 msgstr "-fmessage-length=<N>\t将诊断信息限制在每行 N 个字符。0 取消自动换行"
 
-#: common.opt:1889
+#: common.opt:1893
 #, fuzzy
 #| msgid "Perform SMS based modulo scheduling before the first scheduling pass"
 msgid "Perform SMS based modulo scheduling before the first scheduling pass."
 msgstr "在首趟调度前进行基于 SMS 的模调度"
 
-#: common.opt:1893
+#: common.opt:1897
 #, fuzzy
 #| msgid "Perform SMS based modulo scheduling with register moves allowed"
 msgid "Perform SMS based modulo scheduling with register moves allowed."
 msgstr "进行基于 SMS 且允许寄存器转移的模调度"
 
-#: common.opt:1897
+#: common.opt:1901
 #, fuzzy
 #| msgid "Move loop invariant computations out of loops"
 msgid "Move loop invariant computations out of loops."
 msgstr "将每次循环中不变的计算外提"
 
-#: common.opt:1901
+#: common.opt:1905
 #, fuzzy
 #| msgid "Use the RTL dead code elimination pass"
 msgid "Use the RTL dead code elimination pass."
 msgstr "使用 RTL 死代码清除"
 
-#: common.opt:1905
+#: common.opt:1909
 #, fuzzy
 #| msgid "Use the RTL dead store elimination pass"
 msgid "Use the RTL dead store elimination pass."
 msgstr "使用 RTL 死存储清除"
 
-#: common.opt:1909
+#: common.opt:1913
 #, fuzzy
 #| msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling"
 msgid "Enable/Disable the traditional scheduling in loops that already passed modulo scheduling."
 msgstr "启用/禁用已经通过模调度的循环中的传统调度"
 
-#: common.opt:1913
+#: common.opt:1917
 #, fuzzy
 #| msgid "Support synchronous non-call exceptions"
 msgid "Support synchronous non-call exceptions."
 msgstr "支持同步非调用异常"
 
-#: common.opt:1916
+#: common.opt:1920
 #, fuzzy, c-format
 msgid "options or targets missing after %qs"
 msgstr "%qs后缺少文件名"
 
-#: common.opt:1917
+#: common.opt:1921
 msgid "-foffload=<targets>=<options>  Specify offloading targets and options for them."
 msgstr ""
 
-#: common.opt:1921
+#: common.opt:1925
 msgid "-foffload-abi=[lp64|ilp32]     Set the ABI to use in an offload compiler."
 msgstr ""
 
-#: common.opt:1924
+#: common.opt:1928
 #, fuzzy, c-format
 msgid "unknown offload ABI %qs"
 msgstr "，未知 ABI"
 
-#: common.opt:1934
+#: common.opt:1938
 #, fuzzy
 #| msgid "When possible do not generate stack frames"
 msgid "When possible do not generate stack frames."
 msgstr "尽可能不生成栈帧"
 
-#: common.opt:1938
+#: common.opt:1942
 #, fuzzy
 msgid "Enable all optimization info dumps on stderr."
 msgstr "在树级别进行循环优化"
 
-#: common.opt:1942
+#: common.opt:1946
 msgid "-fopt-info[-<type>=filename]\tDump compiler optimization details."
 msgstr ""
 
-#: common.opt:1950
+#: common.opt:1954
 #, fuzzy
 #| msgid "Optimize sibling and tail recursive calls"
 msgid "Optimize sibling and tail recursive calls."
 msgstr "优化同级递归和尾递归"
 
-#: common.opt:1954
+#: common.opt:1958
 #, fuzzy
 #| msgid "Perform partial inlining"
 msgid "Perform partial inlining."
 msgstr "进行部分内联"
 
-#: common.opt:1958 common.opt:1962
+#: common.opt:1962 common.opt:1966
 #, fuzzy
 #| msgid "Report on memory allocation before interprocedural optimization"
 msgid "Report on memory allocation before interprocedural optimization."
 msgstr "在跨进程优化前报告内存分配"
 
-#: common.opt:1966
+#: common.opt:1970
 #, fuzzy
 #| msgid "Pack structure members together without holes"
 msgid "Pack structure members together without holes."
 msgstr "将结构成员不带间隔地紧实存放"
 
-#: common.opt:1970
+#: common.opt:1974
 #, fuzzy
 #| msgid "-fpack-struct=<number>\tSet initial maximum structure member alignment"
 msgid "-fpack-struct=<number>\tSet initial maximum structure member alignment."
 msgstr "-fpack-struct=<N>\t设定结构成员最大对齐边界的初始值"
 
-#: common.opt:1974
+#: common.opt:1978
 #, fuzzy
 #| msgid "Return small aggregates in memory, not registers"
 msgid "Return small aggregates in memory, not registers."
 msgstr "在内存而不是寄存器中返回小聚合"
 
-#: common.opt:1978
+#: common.opt:1982
 #, fuzzy
 #| msgid "Perform loop peeling"
 msgid "Perform loop peeling."
 msgstr "进行循环剥离"
 
-#: common.opt:1982
+#: common.opt:1986
 #, fuzzy
 #| msgid "Enable machine specific peephole optimizations"
 msgid "Enable machine specific peephole optimizations."
 msgstr "启用机器相关的窥孔优化"
 
-#: common.opt:1986
+#: common.opt:1990
 #, fuzzy
 #| msgid "Enable an RTL peephole pass before sched2"
 msgid "Enable an RTL peephole pass before sched2."
 msgstr "在 sched2 前进行一趟 RTL 窥孔优化"
 
-#: common.opt:1990
+#: common.opt:1994
 #, fuzzy
 #| msgid "Generate position-independent code if possible (large mode)"
 msgid "Generate position-independent code if possible (large mode)."
 msgstr "尽可能生成与位置无关的代码(大模式)"
 
-#: common.opt:1994
+#: common.opt:1998
 #, fuzzy
 #| msgid "Generate position-independent code for executables if possible (large mode)"
 msgid "Generate position-independent code for executables if possible (large mode)."
 msgstr "为可执行文件尽可能生成与位置无关的代码(大模式)"
 
-#: common.opt:1998
+#: common.opt:2002
 #, fuzzy
 #| msgid "Generate position-independent code if possible (small mode)"
 msgid "Generate position-independent code if possible (small mode)."
 msgstr "尽可能生成与位置无关的代码(小模式)"
 
-#: common.opt:2002
+#: common.opt:2006
 #, fuzzy
 #| msgid "Generate position-independent code for executables if possible (small mode)"
 msgid "Generate position-independent code for executables if possible (small mode)."
 msgstr "为可执行文件尽可能生成与位置无关的代码(小模式)"
 
-#: common.opt:2006
+#: common.opt:2010
 msgid "Use PLT for PIC calls (-fno-plt: load the address from GOT at call site)."
 msgstr ""
 
-#: common.opt:2010
+#: common.opt:2014
 #, fuzzy
 #| msgid "Specify a plugin to load"
 msgid "Specify a plugin to load."
 msgstr "指定要加载的插件"
 
-#: common.opt:2014
+#: common.opt:2018
 #, fuzzy
 #| msgid "-fplugin-arg-<name>-<key>[=<value>]\tSpecify argument <key>=<value> for plugin <name>"
 msgid "-fplugin-arg-<name>-<key>[=<value>]\tSpecify argument <key>=<value> for plugin <name>."
 msgstr "-fplugin-arg-<插件>-<键>[=<值>]\t为插件指定参数键=值"
 
-#: common.opt:2018
+#: common.opt:2022
 msgid "Run predictive commoning optimization."
 msgstr "启用预测公因子优化。"
 
-#: common.opt:2022
+#: common.opt:2026
 #, fuzzy
 #| msgid "Generate prefetch instructions, if available, for arrays in loops"
 msgid "Generate prefetch instructions, if available, for arrays in loops."
 msgstr "如果可用，为循环中的数组生成预取指令"
 
-#: common.opt:2026
+#: common.opt:2030
 #, fuzzy
 #| msgid "Enable basic program profiling code"
 msgid "Enable basic program profiling code."
 msgstr "启用基本程序取样代码"
 
-#: common.opt:2030
+#: common.opt:2034
 #, fuzzy
 msgid "Generate absolute source path names for gcov."
 msgstr "生成快速间接调用"
 
-#: common.opt:2034
+#: common.opt:2038
 #, fuzzy
 #| msgid "Insert arc-based program profiling code"
 msgid "Insert arc-based program profiling code."
 msgstr "插入基于弧的程序取样代码"
 
-#: common.opt:2038
+#: common.opt:2042
 #, fuzzy
 #| msgid "Set the top-level directory for storing the profile data."
 msgid "Set the top-level directory for storing the profile data. The default is 'pwd'."
 msgstr "指定存储的取样数据的顶级目录"
 
-#: common.opt:2043
+#: common.opt:2047
 #, fuzzy
 #| msgid "Enable correction of flow inconsistent profile data input"
 msgid "Enable correction of flow inconsistent profile data input."
 msgstr "启用对流不一致取样数据输入的修正"
 
-#: common.opt:2047
+#: common.opt:2051
 msgid "-fprofile-update=[single|atomic|prefer-atomic]\tSet the profile update method."
 msgstr ""
 
-#: common.opt:2050
+#: common.opt:2054
 #, fuzzy, c-format
 msgid "unknown profile update method %qs"
 msgstr "未知的 TLS 模型%qs"
 
-#: common.opt:2063
+#: common.opt:2067
 #, fuzzy
 #| msgid "Enable common options for generating profile info for profile feedback directed optimizations"
 msgid "Enable common options for generating profile info for profile feedback directed optimizations."
 msgstr "启用一些公共选项来生成样本文件，以便进行基于取样的优化"
 
-#: common.opt:2067
+#: common.opt:2071
 #, fuzzy
 #| msgid "Enable common options for generating profile info for profile feedback directed optimizations, and set -fprofile-dir="
 msgid "Enable common options for generating profile info for profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr "启用生成取样信息的公共选项以支持基于取样反馈的优化，同时设置 -fprofile-dir="
 
-#: common.opt:2071
+#: common.opt:2075
 #, fuzzy
 #| msgid "Enable common options for performing profile feedback directed optimizations"
 msgid "Enable common options for performing profile feedback directed optimizations."
 msgstr "启用一些公共选项以进行基于取样的优化"
 
-#: common.opt:2075
+#: common.opt:2079
 #, fuzzy
 #| msgid "Enable common options for performing profile feedback directed optimizations, and set -fprofile-dir="
 msgid "Enable common options for performing profile feedback directed optimizations, and set -fprofile-dir=."
 msgstr "启用公共选项以进行基于取样反馈的优化，同时设置 -fprofile-dir="
 
-#: common.opt:2079
+#: common.opt:2083
 #, fuzzy
 #| msgid "Insert code to profile values of expressions"
 msgid "Insert code to profile values of expressions."
 msgstr "为取样表达式的值插入相关代码"
 
-#: common.opt:2083
+#: common.opt:2087
 #, fuzzy
 msgid "Report on consistency of profile."
 msgstr "内部一致性错误"
 
-#: common.opt:2087
+#: common.opt:2091
 #, fuzzy
 msgid "Enable function reordering that improves code placement."
 msgstr "函数重新排序以改善代码布局"
 
-#: common.opt:2091
+#: common.opt:2095
 #, fuzzy
 #| msgid "Generate cld instruction in the function prologue."
 msgid "Insert NOP instructions at each function entry."
 msgstr "在函数序言中生成 cld 指令"
 
-#: common.opt:2098
+#: common.opt:2102
 #, fuzzy
 #| msgid "-frandom-seed=<number>\tMake compile reproducible using <number>"
 msgid "-frandom-seed=<string>\tMake compile reproducible using <string>."
 msgstr "-frandom-seed=<数字>\t使用 <数字> 以使编译可复现"
 
-#: common.opt:2108
+#: common.opt:2112
 msgid "Record gcc command line switches in the object file."
 msgstr "在目标文件中记录 gcc 命令行开关。"
 
-#: common.opt:2112
+#: common.opt:2116
 #, fuzzy
 #| msgid "Return small aggregates in registers"
 msgid "Return small aggregates in registers."
 msgstr "在寄存器中返回小聚合"
 
-#: common.opt:2120
+#: common.opt:2124
 msgid "Tell DSE that the storage for a C++ object is dead when the constructor starts and when the destructor finishes."
 msgstr ""
 
-#: common.opt:2128
+#: common.opt:2132
 #, fuzzy
 msgid "Relief of register pressure through live range shrinkage."
 msgstr "启用对寄存器压力敏感的指令调度"
 
-#: common.opt:2132
+#: common.opt:2136
 #, fuzzy
 #| msgid "Perform a register renaming optimization pass"
 msgid "Perform a register renaming optimization pass."
 msgstr "进行寄存器重命名优化"
 
-#: common.opt:2136
+#: common.opt:2140
 #, fuzzy
 msgid "Perform a target dependent instruction fusion optimization pass."
 msgstr "进行寄存器重命名优化"
 
-#: common.opt:2140
+#: common.opt:2144
 #, fuzzy
 #| msgid "Reorder basic blocks to improve code placement"
 msgid "Reorder basic blocks to improve code placement."
 msgstr "基本块重新排序以改善代码布局"
 
-#: common.opt:2144
+#: common.opt:2148
 msgid "-freorder-blocks-algorithm=[simple|stc]\tSet the used basic block reordering algorithm."
 msgstr ""
 
-#: common.opt:2147
+#: common.opt:2151
 #, fuzzy, c-format
 msgid "unknown basic block reordering algorithm %qs"
 msgstr "未知的 TLS 模型%qs"
 
-#: common.opt:2157
+#: common.opt:2161
 #, fuzzy
 #| msgid "Reorder basic blocks and partition into hot and cold sections"
 msgid "Reorder basic blocks and partition into hot and cold sections."
 msgstr "对基本块重新排序并划分为热区和冷区"
 
-#: common.opt:2161
+#: common.opt:2165
 #, fuzzy
 #| msgid "Reorder functions to improve code placement"
 msgid "Reorder functions to improve code placement."
 msgstr "函数重新排序以改善代码布局"
 
-#: common.opt:2165
+#: common.opt:2169
 #, fuzzy
 #| msgid "Add a common subexpression elimination pass after loop optimizations"
 msgid "Add a common subexpression elimination pass after loop optimizations."
 msgstr "在循环优化结束后增加一趟公共子表达式消除"
 
-#: common.opt:2173
+#: common.opt:2177
 #, fuzzy
 #| msgid "Disable optimizations that assume default FP rounding behavior"
 msgid "Disable optimizations that assume default FP rounding behavior."
 msgstr "禁用假定默认浮点舍入行为的优化"
 
-#: common.opt:2177
+#: common.opt:2181
 #, fuzzy
 #| msgid "Enable scheduling across basic blocks"
 msgid "Enable scheduling across basic blocks."
 msgstr "启用基本块间的调度"
 
-#: common.opt:2181
+#: common.opt:2185
 #, fuzzy
 #| msgid "Enable register pressure sensitive insn scheduling"
 msgid "Enable register pressure sensitive insn scheduling."
 msgstr "启用对寄存器压力敏感的指令调度"
 
-#: common.opt:2185
+#: common.opt:2189
 #, fuzzy
 #| msgid "Allow speculative motion of non-loads"
 msgid "Allow speculative motion of non-loads."
 msgstr "允许非载入的投机移动"
 
-#: common.opt:2189
+#: common.opt:2193
 #, fuzzy
 #| msgid "Allow speculative motion of some loads"
 msgid "Allow speculative motion of some loads."
 msgstr "允许一些载入的投机移动"
 
-#: common.opt:2193
+#: common.opt:2197
 #, fuzzy
 #| msgid "Allow speculative motion of more loads"
 msgid "Allow speculative motion of more loads."
 msgstr "允许更多载入的投机移动"
 
-#: common.opt:2197
+#: common.opt:2201
 #, fuzzy
 #| msgid "-fsched-verbose=<number>\tSet the verbosity level of the scheduler"
 msgid "-fsched-verbose=<number>\tSet the verbosity level of the scheduler."
 msgstr "-fsched-verbose=<N>\t指定调度器的冗余级别"
 
-#: common.opt:2201
+#: common.opt:2205
 #, fuzzy
 #| msgid "If scheduling post reload, do superblock scheduling"
 msgid "If scheduling post reload, do superblock scheduling."
 msgstr "在重载后调度中使用跨基本块调度"
 
-#: common.opt:2209
+#: common.opt:2213
 #, fuzzy
 #| msgid "Reschedule instructions before register allocation"
 msgid "Reschedule instructions before register allocation."
 msgstr "分配寄存器前重新调度指令"
 
-#: common.opt:2213
+#: common.opt:2217
 #, fuzzy
 #| msgid "Reschedule instructions after register allocation"
 msgid "Reschedule instructions after register allocation."
 msgstr "分配寄存器后重新调度指令"
 
-#: common.opt:2220
+#: common.opt:2224
 #, fuzzy
 #| msgid "Schedule instructions using selective scheduling algorithm"
 msgid "Schedule instructions using selective scheduling algorithm."
 msgstr "用选择性调度算法调度指令"
 
-#: common.opt:2224
+#: common.opt:2228
 #, fuzzy
 #| msgid "Run selective scheduling after reload"
 msgid "Run selective scheduling after reload."
 msgstr "在重加载后使用选择性调度"
 
-#: common.opt:2228
+#: common.opt:2232
 msgid "Run self-tests, using the given path to locate test files."
 msgstr ""
 
-#: common.opt:2232
+#: common.opt:2236
 #, fuzzy
 #| msgid "Perform software pipelining of inner loops during selective scheduling"
 msgid "Perform software pipelining of inner loops during selective scheduling."
 msgstr "在选择性调度中对内层循环进行软件流水化"
 
-#: common.opt:2236
+#: common.opt:2240
 #, fuzzy
 #| msgid "Perform software pipelining of outer loops during selective scheduling"
 msgid "Perform software pipelining of outer loops during selective scheduling."
 msgstr "在选择性调度中对外层循环进行软件流水化"
 
-#: common.opt:2240
+#: common.opt:2244
 #, fuzzy
 #| msgid "Reschedule pipelined regions without pipelining"
 msgid "Reschedule pipelined regions without pipelining."
 msgstr "重新调度没有被流水线化的流水线区域"
 
-#: common.opt:2244
+#: common.opt:2248
 msgid "Allow interposing function (or variables) by ones with different semantics (or initializer) respectively by dynamic linker."
 msgstr ""
 
-#: common.opt:2250
+#: common.opt:2254
 #, fuzzy
 #| msgid "Allow premature scheduling of queued insns"
 msgid "Allow premature scheduling of queued insns."
 msgstr "允许对队列中的指令进行早调度"
 
-#: common.opt:2254
+#: common.opt:2258
 #, fuzzy
 #| msgid "-fsched-stalled-insns=<number>\tSet number of queued insns that can be prematurely scheduled"
 msgid "-fsched-stalled-insns=<number>\tSet number of queued insns that can be prematurely scheduled."
 msgstr "-fsched-stalled-insns=<N>\t指定能被早期调度的在排队中的指令的最大数量"
 
-#: common.opt:2262
+#: common.opt:2266
 #, fuzzy
 #| msgid "Set dependence distance checking in premature scheduling of queued insns"
 msgid "Set dependence distance checking in premature scheduling of queued insns."
 msgstr "设置排队中指令的进行早调度的依赖距离检查"
 
-#: common.opt:2266
+#: common.opt:2270
 #, fuzzy
 #| msgid "-fsched-stalled-insns-dep=<number>\tSet dependence distance checking in premature scheduling of queued insns"
 msgid "-fsched-stalled-insns-dep=<number>\tSet dependence distance checking in premature scheduling of queued insns."
 msgstr "-fsched-stalled-insns-dep=<N>\t设置排队中指令的进行早调度的依赖距离检查"
 
-#: common.opt:2270
+#: common.opt:2274
 #, fuzzy
 #| msgid "Enable the group heuristic in the scheduler"
 msgid "Enable the group heuristic in the scheduler."
 msgstr "在调度器中启用组启发"
 
-#: common.opt:2274
+#: common.opt:2278
 #, fuzzy
 #| msgid "Enable the critical path heuristic in the scheduler"
 msgid "Enable the critical path heuristic in the scheduler."
 msgstr "为调度器启用关键路径启发式发现"
 
-#: common.opt:2278
+#: common.opt:2282
 #, fuzzy
 #| msgid "Enable the speculative instruction heuristic in the scheduler"
 msgid "Enable the speculative instruction heuristic in the scheduler."
 msgstr "为调度器启用投机指令启发式发现"
 
-#: common.opt:2282
+#: common.opt:2286
 #, fuzzy
 #| msgid "Enable the rank heuristic in the scheduler"
 msgid "Enable the rank heuristic in the scheduler."
 msgstr "在调度器中启用秩启发"
 
-#: common.opt:2286
+#: common.opt:2290
 #, fuzzy
 #| msgid "Enable the last instruction heuristic in the scheduler"
 msgid "Enable the last instruction heuristic in the scheduler."
 msgstr "为调度器启用最近指令启发式发现"
 
-#: common.opt:2290
+#: common.opt:2294
 #, fuzzy
 #| msgid "Enable the dependent count heuristic in the scheduler"
 msgid "Enable the dependent count heuristic in the scheduler."
 msgstr "为调度器启用依赖计数启发式发现"
 
-#: common.opt:2294
+#: common.opt:2298
 #, fuzzy
 #| msgid "Access data in the same section from shared anchor points"
 msgid "Access data in the same section from shared anchor points."
 msgstr "从共享的锚点访问在同样的节中的数据"
 
-#: common.opt:2306
+#: common.opt:2310
 #, fuzzy
 msgid "Turn on Redundant Extensions Elimination pass."
 msgstr "打开冗余延伸 Elimination 回合。"
 
-#: common.opt:2310
+#: common.opt:2314
 #, fuzzy
 #| msgid "Show column numbers in diagnostics, when available.  Default on"
 msgid "Show column numbers in diagnostics, when available.  Default on."
 msgstr "诊断信息中给出行号。默认打开"
 
-#: common.opt:2314
+#: common.opt:2318
 #, fuzzy
 msgid "Emit function prologues only before parts of the function that need it, rather than at the top of the function."
 msgstr "Emit 函数 prologues 只有之前零件的函数该需要它，"
 
-#: common.opt:2319
+#: common.opt:2323
 msgid "Shrink-wrap parts of the prologue and epilogue separately."
 msgstr ""
 
-#: common.opt:2323
+#: common.opt:2327
 #, fuzzy
 #| msgid "Disable optimizations observable by IEEE signaling NaNs"
 msgid "Disable optimizations observable by IEEE signaling NaNs."
 msgstr "禁用为 IEEE NaN 可见的优化"
 
-#: common.opt:2327
+#: common.opt:2331
 #, fuzzy
 #| msgid "Disable floating point optimizations that ignore the IEEE signedness of zero"
 msgid "Disable floating point optimizations that ignore the IEEE signedness of zero."
 msgstr "禁用忽略 IEEE 中零的符号的浮点优化"
 
-#: common.opt:2331
+#: common.opt:2335
 #, fuzzy
 #| msgid "Convert floating point constants to single precision constants"
 msgid "Convert floating point constants to single precision constants."
 msgstr "将浮点常量转换为单精度常量"
 
-#: common.opt:2335
+#: common.opt:2339
 #, fuzzy
 #| msgid "Split lifetimes of induction variables when loops are unrolled"
 msgid "Split lifetimes of induction variables when loops are unrolled."
 msgstr "展开循环时分离归纳变量的生存期"
 
-#: common.opt:2339
+#: common.opt:2343
 #, fuzzy
 msgid "Generate discontiguous stack frames."
 msgstr "生成与 APCS 相容的栈帧"
 
-#: common.opt:2343
+#: common.opt:2347
 #, fuzzy
 #| msgid "Split wide types into independent registers"
 msgid "Split wide types into independent registers."
 msgstr "将宽类型分割到独立的寄存器中"
 
-#: common.opt:2347
+#: common.opt:2351
 #, fuzzy
 #| msgid "Enable forward propagation on trees"
 msgid "Enable backward propagation of use properties at the SSA level."
 msgstr "在树级别进行前向复写传递"
 
-#: common.opt:2351
+#: common.opt:2355
 msgid "Optimize conditional patterns using SSA PHI nodes."
 msgstr ""
 
-#: common.opt:2355
+#: common.opt:2359
 #, fuzzy
 msgid "Optimize amount of stdarg registers saved to stack at start of function."
 msgstr "用以传递整数参数的寄存器个数"
 
-#: common.opt:2359
+#: common.opt:2363
 #, fuzzy
 #| msgid "Apply variable expansion when loops are unrolled"
 msgid "Apply variable expansion when loops are unrolled."
 msgstr "展开循环时也展开变量"
 
-#: common.opt:2363
+#: common.opt:2367
 #, fuzzy
 #| msgid "-fstack-check=[no|generic|specific]\tInsert stack checking code into the program"
 msgid "-fstack-check=[no|generic|specific]\tInsert stack checking code into the program."
 msgstr "-fstack-check=[no|generic|specific]\t在程序中插入检查栈溢出的代码"
 
-#: common.opt:2367
+#: common.opt:2371
 #, fuzzy
 #| msgid "Insert stack checking code into the program.  Same as -fstack-check=specific"
 msgid "Insert stack checking code into the program.  Same as -fstack-check=specific."
 msgstr "在程序中插入检查栈溢出的代码。与 fstack-check=specific 相同"
 
-#: common.opt:2371
+#: common.opt:2375
 msgid "Insert code to probe each page of stack space as it is allocated to protect from stack-clash style attacks."
 msgstr ""
 
-#: common.opt:2379
+#: common.opt:2383
 #, fuzzy
 #| msgid "-fstack-limit-register=<register>\tTrap if the stack goes past <register>"
 msgid "-fstack-limit-register=<register>\tTrap if the stack goes past <register>."
 msgstr "-fstack-limit-symbol=<寄存器>\t当堆栈越过寄存器时引发陷阱"
 
-#: common.opt:2383
+#: common.opt:2387
 #, fuzzy
 #| msgid "-fstack-limit-symbol=<name>\tTrap if the stack goes past symbol <name>"
 msgid "-fstack-limit-symbol=<name>\tTrap if the stack goes past symbol <name>."
 msgstr "-fstack-limit-symbol=<符号>\t当堆栈越过符号时引发陷阱"
 
-#: common.opt:2387
+#: common.opt:2391
 #, fuzzy
 #| msgid "Use propolice as a stack protection method"
 msgid "Use propolice as a stack protection method."
 msgstr "使用 propolice 来保护堆栈"
 
-#: common.opt:2391
+#: common.opt:2395
 #, fuzzy
 #| msgid "Use a stack protection method for every function"
 msgid "Use a stack protection method for every function."
 msgstr "为每个函数使用堆栈保护机制"
 
-#: common.opt:2395
+#: common.opt:2399
 #, fuzzy
 msgid "Use a smart stack protection method for certain functions."
 msgstr "为每个函数使用堆栈保护机制"
 
-#: common.opt:2399
+#: common.opt:2403
 #, fuzzy
 msgid "Use stack protection method only for functions with the stack_protect attribute."
 msgstr "为每个函数使用堆栈保护机制"
 
-#: common.opt:2403
+#: common.opt:2407
 #, fuzzy
 msgid "Output stack usage information on a per-function basis."
 msgstr "为每个函数重用 r30"
 
-#: common.opt:2415
+#: common.opt:2419
 #, fuzzy
 #| msgid "Assume strict aliasing rules apply"
 msgid "Assume strict aliasing rules apply."
 msgstr "假定应用强重叠规则"
 
-#: common.opt:2419
+#: common.opt:2423
 #, fuzzy
 #| msgid "Treat signed overflow as undefined"
 msgid "Treat signed overflow as undefined.  Negated as -fwrapv -fwrapv-pointer."
 msgstr "将有符号数溢出的行为视为未定义的"
 
-#: common.opt:2423
+#: common.opt:2427
 msgid "Implement __atomic operations via libcalls to legacy __sync functions."
 msgstr ""
 
-#: common.opt:2427
+#: common.opt:2431
 #, fuzzy
 #| msgid "Check for syntax errors, then stop"
 msgid "Check for syntax errors, then stop."
 msgstr "检查语法错误，然后停止"
 
-#: common.opt:2431
+#: common.opt:2435
 #, fuzzy
 #| msgid "Create data files needed by \"gcov\""
 msgid "Create data files needed by \"gcov\"."
 msgstr "生成“gcov”需要的数据文件"
 
-#: common.opt:2435
+#: common.opt:2439
 #, fuzzy
 #| msgid "Perform jump threading optimizations"
 msgid "Perform jump threading optimizations."
 msgstr "进行跳转线程优化"
 
-#: common.opt:2439
+#: common.opt:2443
 #, fuzzy
 #| msgid "Report the time taken by each compiler pass"
 msgid "Report the time taken by each compiler pass."
 msgstr "报告每趟汇编的耗时"
 
-#: common.opt:2443
+#: common.opt:2447
 msgid "Record times taken by sub-phases separately."
 msgstr ""
 
-#: common.opt:2447
+#: common.opt:2451
 #, fuzzy
 #| msgid "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tSet the default thread-local storage code generation model"
 msgid "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\tSet the default thread-local storage code generation model."
 msgstr "-ftls-model=[global-dynamic|local-dynamic|initial-exec|local-exec]\t设定默认的线程局部存储代码生成模式"
 
-#: common.opt:2450
+#: common.opt:2454
 #, c-format
 msgid "unknown TLS model %qs"
 msgstr "未知的 TLS 模型%qs"
 
-#: common.opt:2466
+#: common.opt:2470
 #, fuzzy
 #| msgid "Reorder top level functions, variables, and asms"
 msgid "Reorder top level functions, variables, and asms."
 msgstr "重新排序文件作用域的函数、变量和汇编"
 
-#: common.opt:2470
+#: common.opt:2474
 #, fuzzy
 #| msgid "Perform superblock formation via tail duplication"
 msgid "Perform superblock formation via tail duplication."
 msgstr "通过尾复制进行超块合成"
 
-#: common.opt:2474
+#: common.opt:2478
 msgid "For targets that normally need trampolines for nested functions, always generate them instead of using descriptors."
 msgstr ""
 
-#: common.opt:2482
+#: common.opt:2486
 #, fuzzy
 #| msgid "Assume floating-point operations can trap"
 msgid "Assume floating-point operations can trap."
 msgstr "假定浮点运算可能引发陷阱"
 
-#: common.opt:2486
+#: common.opt:2490
 #, fuzzy
 #| msgid "Trap for signed overflow in addition, subtraction and multiplication"
 msgid "Trap for signed overflow in addition, subtraction and multiplication."
 msgstr "加法、减法或乘法溢出时激活陷阱"
 
-#: common.opt:2490
+#: common.opt:2494
 #, fuzzy
 #| msgid "Enable SSA-CCP optimization on trees"
 msgid "Enable SSA-CCP optimization on trees."
 msgstr "启用树上的 SSA-CCP 优化"
 
-#: common.opt:2494
+#: common.opt:2498
 #, fuzzy
 msgid "Enable SSA-BIT-CCP optimization on trees."
 msgstr "启用树上的 SSA-CCP 优化"
 
-#: common.opt:2502
+#: common.opt:2506
 #, fuzzy
 #| msgid "Enable loop header copying on trees"
 msgid "Enable loop header copying on trees."
 msgstr "启用树上的循环不变量转移"
 
-#: common.opt:2510
+#: common.opt:2514
 #, fuzzy
 msgid "Enable SSA coalescing of user variables."
 msgstr "进行变量追踪并且标记未被初始化的变量"
 
-#: common.opt:2518
+#: common.opt:2522
 #, fuzzy
 #| msgid "Enable copy propagation on trees"
 msgid "Enable copy propagation on trees."
 msgstr "在树级别进行复写传递"
 
-#: common.opt:2526
+#: common.opt:2530
 #, fuzzy
 #| msgid "Transform condition stores into unconditional ones"
 msgid "Transform condition stores into unconditional ones."
 msgstr "将条件存储转换为非条件存储"
 
-#: common.opt:2530
+#: common.opt:2534
 msgid "Perform conversions of switch initializations."
 msgstr "转换开关初始化"
 
-#: common.opt:2534
+#: common.opt:2538
 #, fuzzy
 #| msgid "Enable SSA dead code elimination optimization on trees"
 msgid "Enable SSA dead code elimination optimization on trees."
 msgstr "启用树上的 SSA 死代码消除优化"
 
-#: common.opt:2538
+#: common.opt:2542
 #, fuzzy
 #| msgid "Enable dominator optimizations"
 msgid "Enable dominator optimizations."
 msgstr "启用主导优化"
 
-#: common.opt:2542
+#: common.opt:2546
 #, fuzzy
 msgid "Enable tail merging on trees."
 msgstr "在树级别进行复写传递"
 
-#: common.opt:2546
+#: common.opt:2550
 #, fuzzy
 #| msgid "Enable dead store elimination"
 msgid "Enable dead store elimination."
 msgstr "删除死存储"
 
-#: common.opt:2550
+#: common.opt:2554
 #, fuzzy
 #| msgid "Enable forward propagation on trees"
 msgid "Enable forward propagation on trees."
 msgstr "在树级别进行前向复写传递"
 
-#: common.opt:2554
+#: common.opt:2558
 #, fuzzy
 #| msgid "Enable Full Redundancy Elimination (FRE) on trees"
 msgid "Enable Full Redundancy Elimination (FRE) on trees."
 msgstr "启用树上的完全冗余消除(FRE)"
 
-#: common.opt:2558
+#: common.opt:2562
 #, fuzzy
 msgid "Enable string length optimizations on trees."
 msgstr "启用树上的 SSA-CCP 优化"
 
-#: common.opt:2562
+#: common.opt:2566
 msgid "Detect paths that trigger erroneous or undefined behavior due to dereferencing a null pointer.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
-#: common.opt:2568
+#: common.opt:2572
 msgid "Detect paths that trigger erroneous or undefined behavior due to a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
-#: common.opt:2575
+#: common.opt:2579
 #, fuzzy
 #| msgid "Enable loop distribution on trees"
 msgid "Enable loop distribution on trees."
 msgstr "在树上进行循环分配"
 
-#: common.opt:2579
+#: common.opt:2583
 #, fuzzy
 msgid "Enable loop distribution for patterns transformed into a library call."
 msgstr "在树上进行循环分配"
 
-#: common.opt:2583
+#: common.opt:2587
 #, fuzzy
 #| msgid "Enable loop invariant motion on trees"
 msgid "Enable loop invariant motion on trees."
 msgstr "启用树上的循环不变量转移"
 
-#: common.opt:2591
+#: common.opt:2595
 #, fuzzy
 #| msgid "Create canonical induction variables in loops"
 msgid "Create canonical induction variables in loops."
 msgstr "在循环中生成正规的归纳变量"
 
-#: common.opt:2595
+#: common.opt:2599
 #, fuzzy
 #| msgid "Enable loop optimizations on tree level"
 msgid "Enable loop optimizations on tree level."
 msgstr "在树级别进行循环优化"
 
-#: common.opt:2599
+#: common.opt:2603
 #, fuzzy
 #| msgid "Enable automatic parallelization of loops"
 msgid "-ftree-parallelize-loops=<number>\tEnable automatic parallelization of loops."
 msgstr "启用循环的自动并行化"
 
-#: common.opt:2603
+#: common.opt:2607
 msgid "Enable hoisting loads from conditional pointers."
 msgstr "为条件指针外提内存读取操作。"
 
-#: common.opt:2607
+#: common.opt:2611
 #, fuzzy
 #| msgid "Enable SSA-PRE optimization on trees"
 msgid "Enable SSA-PRE optimization on trees."
 msgstr "启用树上的 SSA-PRE 优化"
 
-#: common.opt:2611
+#: common.opt:2615
 msgid "In SSA-PRE optimization on trees, enable partial-partial redundancy elimination."
 msgstr ""
 
-#: common.opt:2615
+#: common.opt:2619
 msgid "Perform function-local points-to analysis on trees."
 msgstr "在树上进行函数内的指向分析。"
 
-#: common.opt:2619
+#: common.opt:2623
 #, fuzzy
 #| msgid "Enable reassociation on tree level"
 msgid "Enable reassociation on tree level."
 msgstr "在树级别进行重结合"
 
-#: common.opt:2627
+#: common.opt:2631
 #, fuzzy
 #| msgid "Enable SSA code sinking on trees"
 msgid "Enable SSA code sinking on trees."
 msgstr "启用树上的 SSA 代码下沉优化"
 
-#: common.opt:2631
+#: common.opt:2635
 #, fuzzy
 msgid "Perform straight-line strength reduction."
 msgstr "进行强度削减最佳化"
 
-#: common.opt:2635
+#: common.opt:2639
 #, fuzzy
 #| msgid "Perform scalar replacement of aggregates"
 msgid "Perform scalar replacement of aggregates."
 msgstr "为聚合类型进行标量替换"
 
-#: common.opt:2639
+#: common.opt:2643
 #, fuzzy
 #| msgid "Replace temporary expressions in the SSA->normal pass"
 msgid "Replace temporary expressions in the SSA->normal pass."
 msgstr "在 SSA->normal 过程中替换临时表达式"
 
-#: common.opt:2643
+#: common.opt:2647
 #, fuzzy
 #| msgid "Perform live range splitting during the SSA->normal pass"
 msgid "Perform live range splitting during the SSA->normal pass."
 msgstr "在 SSA->normal 过程中分离活动范围"
 
-#: common.opt:2647
+#: common.opt:2651
 #, fuzzy
 #| msgid "Perform Value Range Propagation on trees"
 msgid "Perform Value Range Propagation on trees."
 msgstr "进行树上的值域传递"
 
-#: common.opt:2651
+#: common.opt:2655
 msgid "Split paths leading to loop backedges."
 msgstr ""
 
-#: common.opt:2655
+#: common.opt:2659
 msgid "Assume common declarations may be overridden with ones with a larger trailing array."
 msgstr ""
 
-#: common.opt:2660
+#: common.opt:2664
 #, fuzzy
 #| msgid "Compile whole compilation unit at a time"
 msgid "Compile whole compilation unit at a time."
 msgstr "一次编译一整个编译单元"
 
-#: common.opt:2664
+#: common.opt:2668
 #, fuzzy
 #| msgid "Perform loop unrolling when iteration count is known"
 msgid "Perform loop unrolling when iteration count is known."
 msgstr "展开所有迭代次数已知的循环"
 
-#: common.opt:2668
+#: common.opt:2672
 #, fuzzy
 #| msgid "Perform loop unrolling for all loops"
 msgid "Perform loop unrolling for all loops."
 msgstr "展开所有循环"
 
-#: common.opt:2679
+#: common.opt:2683
 #, fuzzy
 #| msgid "Allow optimization for floating-point arithmetic which may change the"
 msgid "Allow optimization for floating-point arithmetic which may change the result of the operation due to rounding."
 msgstr "允许可能因不同舍入模式而改变结果的浮点算术优化。"
 
-#: common.opt:2684
+#: common.opt:2688
 msgid "Same as -fassociative-math for expressions which include division."
 msgstr "与 -fassociative-math 相同，作用于包含除法的表达式。"
 
-#: common.opt:2692
+#: common.opt:2696
 #, fuzzy
 #| msgid "Allow math optimizations that may violate IEEE or ISO standards"
 msgid "Allow math optimizations that may violate IEEE or ISO standards."
 msgstr "允许可能违反 IEEE 或 ISO 标准的优化"
 
-#: common.opt:2696
+#: common.opt:2700
 #, fuzzy
 #| msgid "Perform loop unswitching"
 msgid "Perform loop unswitching."
 msgstr "外提循环内的测试语句"
 
-#: common.opt:2700
+#: common.opt:2704
 #, fuzzy
 #| msgid "Perform loop peeling"
 msgid "Perform loop splitting."
 msgstr "进行循环剥离"
 
-#: common.opt:2704
+#: common.opt:2708
 #, fuzzy
 #| msgid "Just generate unwind tables for exception handling"
 msgid "Just generate unwind tables for exception handling."
 msgstr "仅为异常处理生成堆栈展开表"
 
-#: common.opt:2708
+#: common.opt:2712
 #, fuzzy
 msgid "Use the bfd linker instead of the default linker."
 msgstr "使用硬件桶型移位器代替仿真"
 
-#: common.opt:2712
+#: common.opt:2716
 #, fuzzy
 msgid "Use the gold linker instead of the default linker."
 msgstr "使用硬件桶型移位器代替仿真"
 
-#: common.opt:2724
+#: common.opt:2728
 #, fuzzy
 #| msgid "Perform variable tracking"
 msgid "Perform variable tracking."
 msgstr "进行变量跟踪"
 
-#: common.opt:2732
+#: common.opt:2736
 #, fuzzy
 #| msgid "Perform variable tracking by annotating assignments"
 msgid "Perform variable tracking by annotating assignments."
 msgstr "评注赋值以进行变量跟踪"
 
-#: common.opt:2738
+#: common.opt:2742
 #, fuzzy
 #| msgid "Toggle -fvar-tracking-assignments"
 msgid "Toggle -fvar-tracking-assignments."
 msgstr "切换 -fvar-tracking-assignments"
 
-#: common.opt:2746
+#: common.opt:2750
 #, fuzzy
 #| msgid "Perform variable tracking and also tag variables that are uninitialized"
 msgid "Perform variable tracking and also tag variables that are uninitialized."
 msgstr "进行变量追踪并且标记未被初始化的变量"
 
-#: common.opt:2751
+#: common.opt:2755
 #, fuzzy
 msgid "Enable vectorization on trees."
 msgstr "在树上进行循环向量化"
 
-#: common.opt:2759
+#: common.opt:2763
 #, fuzzy
 #| msgid "Enable loop vectorization on trees"
 msgid "Enable loop vectorization on trees."
 msgstr "在树上进行循环向量化"
 
-#: common.opt:2763
+#: common.opt:2767
 #, fuzzy
 #| msgid "Enable basic block vectorization (SLP) on trees"
 msgid "Enable basic block vectorization (SLP) on trees."
 msgstr "在树上进行基本块向量化(SLP)"
 
-#: common.opt:2767
+#: common.opt:2771
 msgid "Specifies the cost model for vectorization. -fvect-cost-model=[unlimited|dynamic|cheap]\tSpecifies the cost model for vectorization."
 msgstr ""
 
-#: common.opt:2772
+#: common.opt:2776
 #, fuzzy
 msgid "-fsimd-cost-model=[unlimited|dynamic|cheap]\tSpecifies the vectorization cost model for code marked with a simd directive."
 msgstr "启用向量化开销模型"
 
-#: common.opt:2775
+#: common.opt:2779
 #, fuzzy, c-format
 msgid "unknown vectorizer cost model %qs"
 msgstr "未知的 TLS 模型%qs"
 
-#: common.opt:2788
+#: common.opt:2792
 #, fuzzy
 msgid "Enables the dynamic vectorizer cost model.  Preserved for backward compatibility."
 msgstr "不起作用。为向前兼容保留的选项。"
 
-#: common.opt:2796
+#: common.opt:2800
 msgid "Enable copy propagation of scalar-evolution information."
 msgstr "为标量演化信息进行复写传递。"
 
-#: common.opt:2806
+#: common.opt:2810
 #, fuzzy
 #| msgid "Add extra commentary to assembler output"
 msgid "Add extra commentary to assembler output."
 msgstr "为汇编输出添加额外注释"
 
-#: common.opt:2810
+#: common.opt:2814
 #, fuzzy
 #| msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility"
 msgid "-fvisibility=[default|internal|hidden|protected]\tSet the default symbol visibility."
 msgstr "-fvisibility=[default|internal|hidden|protected]\t设置符号的默认可见性"
 
-#: common.opt:2813
+#: common.opt:2817
 #, fuzzy, c-format
 msgid "unrecognized visibility value %qs"
 msgstr "不可识别的寄存名%qs"
 
-#: common.opt:2829
+#: common.opt:2833
 msgid "Validate vtable pointers before using them."
 msgstr ""
 
-#: common.opt:2832
+#: common.opt:2836
 #, fuzzy, c-format
 msgid "unknown vtable verify initialization priority %qs"
 msgstr "(在%qs的初始化附近)"
 
-#: common.opt:2845
+#: common.opt:2849
 msgid "Output vtable verification counters."
 msgstr ""
 
-#: common.opt:2849
+#: common.opt:2853
 msgid "Output vtable verification pointer sets information."
 msgstr ""
 
-#: common.opt:2853
+#: common.opt:2857
 #, fuzzy
 #| msgid "Use expression value profiles in optimizations"
 msgid "Use expression value profiles in optimizations."
 msgstr "在优化中使用表达式值样本提供的信息"
 
-#: common.opt:2857
+#: common.opt:2861
 #, fuzzy
 #| msgid "Construct webs and split unrelated uses of single variable"
 msgid "Construct webs and split unrelated uses of single variable."
 msgstr "建立关系网并且分离对同一变量的无关应用"
 
-#: common.opt:2861
+#: common.opt:2865
 #, fuzzy
 #| msgid "Enable conditional dead code elimination for builtin calls"
 msgid "Enable conditional dead code elimination for builtin calls."
 msgstr "为内建函数启用有条件的死代码消除优化"
 
-#: common.opt:2865
+#: common.opt:2869
 #, fuzzy
 #| msgid "Perform whole program optimizations"
 msgid "Perform whole program optimizations."
 msgstr "进行全程序优化"
 
-#: common.opt:2869
+#: common.opt:2873
 #, fuzzy
 #| msgid "Assume signed arithmetic overflow wraps around"
 msgid "Assume pointer overflow wraps around."
 msgstr "假定有符号运算溢出时回绕"
 
-#: common.opt:2873
+#: common.opt:2877
 #, fuzzy
 #| msgid "Assume signed arithmetic overflow wraps around"
 msgid "Assume signed arithmetic overflow wraps around."
 msgstr "假定有符号运算溢出时回绕"
 
-#: common.opt:2877
+#: common.opt:2881
 #, fuzzy
 #| msgid "Put zero initialized data in the bss section"
 msgid "Put zero initialized data in the bss section."
 msgstr "将初始化为零的数据存放在 bss 节中"
 
-#: common.opt:2881
+#: common.opt:2885
 #, fuzzy
 #| msgid "Generate debug information in default format"
 msgid "Generate debug information in default format."
 msgstr "生成默认格式的调试信息"
 
-#: common.opt:2885
+#: common.opt:2889
 #, fuzzy
 #| msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgid "Assume assembler support for (DWARF2+) .loc directives"
 msgstr "%<-fsplit-stack%>需要汇编器支持 CFI 伪指令"
 
-#: common.opt:2889
+#: common.opt:2893
 #, fuzzy
 #| msgid "%<-fsplit-stack%> requires assembler support for CFI directives"
 msgid "Assume assembler support for view in (DWARF2+) .loc directives"
 msgstr "%<-fsplit-stack%>需要汇编器支持 CFI 伪指令"
 
-#: common.opt:2892 common.opt:2896 common.opt:2900 common.opt:2904
+#: common.opt:2896 common.opt:2900 common.opt:2904 common.opt:2908
 #, fuzzy, c-format
 #| msgid "switch %qs is no longer supported"
 msgid "switch %qs no longer supported"
 msgstr "开关%qs不再被支持"
 
-#: common.opt:2909
+#: common.opt:2913
 msgid "Record DW_AT_decl_column and DW_AT_call_column in DWARF."
 msgstr ""
 
-#: common.opt:2913
+#: common.opt:2917
 #, fuzzy
 msgid "Generate debug information in default version of DWARF format."
 msgstr "生成 DWARF v2(或更新)格式的调试信息"
 
-#: common.opt:2917
+#: common.opt:2921
 #, fuzzy
 #| msgid "Generate debug information in DWARF v2 (or later) format"
 msgid "Generate debug information in DWARF v2 (or later) format."
 msgstr "生成 DWARF v2(或更新)格式的调试信息"
 
-#: common.opt:2921
+#: common.opt:2925
 #, fuzzy
 #| msgid "Generate debug information in default extended format"
 msgid "Generate debug information in default extended format."
 msgstr "生成默认扩展格式的调试信息"
 
-#: common.opt:2925
+#: common.opt:2929
 #, fuzzy
 #| msgid "Generate a single exit point for each function"
 msgid "Generate extended entry point information for inlined functions"
 msgstr "为每个函数生成单一的退出点"
 
-#: common.opt:2929
+#: common.opt:2933
 msgid "Compute locview reset points based on insn length estimates"
 msgstr ""
 
-#: common.opt:2937
+#: common.opt:2941
 msgid "Don't generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:2941
+#: common.opt:2945
 msgid "Generate DWARF pubnames and pubtypes sections."
 msgstr ""
 
-#: common.opt:2945
+#: common.opt:2949
 msgid "Generate DWARF pubnames and pubtypes sections with GNU extensions."
 msgstr ""
 
-#: common.opt:2949
+#: common.opt:2953
 #, fuzzy
 msgid "Record gcc command line switches in DWARF DW_AT_producer."
 msgstr "在目标文件中记录 gcc 命令行开关。"
 
-#: common.opt:2953
+#: common.opt:2957
 #, fuzzy
 msgid "Generate debug information in separate .dwo files."
 msgstr "生成默认格式的调试信息"
 
-#: common.opt:2957
+#: common.opt:2961
 #, fuzzy
 #| msgid "Generate debug information in STABS format"
 msgid "Generate debug information in STABS format."
 msgstr "生成 STABS 格式的调试信息"
 
-#: common.opt:2961
+#: common.opt:2965
 #, fuzzy
 #| msgid "Generate debug information in extended STABS format"
 msgid "Generate debug information in extended STABS format."
 msgstr "生成扩展 STABS 格式的调试信息"
 
-#: common.opt:2965
+#: common.opt:2969
 msgid "Emit progressive recommended breakpoint locations."
 msgstr ""
 
-#: common.opt:2969
+#: common.opt:2973
 #, fuzzy
 #| msgid "Don't emit DWARF additions beyond selected version"
 msgid "Don't emit DWARF additions beyond selected version."
 msgstr "不生成较所选版本更先进的 DWARF 附加信息"
 
-#: common.opt:2973
+#: common.opt:2977
 #, fuzzy
 #| msgid "Toggle debug information generation"
 msgid "Toggle debug information generation."
 msgstr "切换调试信息生成"
 
-#: common.opt:2977
+#: common.opt:2981
 msgid "Augment variable location lists with progressive views."
 msgstr ""
 
-#: common.opt:2984
+#: common.opt:2988
 #, fuzzy
 #| msgid "Generate debug information in VMS format"
 msgid "Generate debug information in VMS format."
 msgstr "生成 VMS 格式的调试信息"
 
-#: common.opt:2988
+#: common.opt:2992
 #, fuzzy
 #| msgid "Generate debug information in XCOFF format"
 msgid "Generate debug information in XCOFF format."
 msgstr "生成 XCOFF 格式的调试信息"
 
-#: common.opt:2992
+#: common.opt:2996
 #, fuzzy
 #| msgid "Generate debug information in extended XCOFF format"
 msgid "Generate debug information in extended XCOFF format."
 msgstr "生成 XCOFF 扩展格式的调试信息"
 
-#: common.opt:3010
+#: common.opt:3014
 #, fuzzy
 msgid "Generate compressed debug sections."
 msgstr "生成 VMS 格式的调试信息"
 
-#: common.opt:3014
+#: common.opt:3018
 #, fuzzy
 msgid "-gz=<format>\tGenerate compressed debug sections in format <format>."
 msgstr "生成默认格式的调试信息"
 
-#: common.opt:3021
+#: common.opt:3025
 #, fuzzy
 #| msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory"
 msgid "-iplugindir=<dir>\tSet <dir> to be the default plugin directory."
 msgstr "-iplugindir=<目录>\t将目录设定为默认的插件子目录"
 
-#: common.opt:3025
+#: common.opt:3029
 #, fuzzy
 msgid "-imultiarch <dir>\tSet <dir> to be the multiarch include subdirectory."
 msgstr "-imultilib <目录>\t将目录设定为 multilib 的包含子目录"
 
-#: common.opt:3047
+#: common.opt:3051
 #, fuzzy
 #| msgid "-o <file>\tPlace output into <file>"
 msgid "-o <file>\tPlace output into <file>."
 msgstr "-o <文件>\t将输出写入文件"
 
-#: common.opt:3051
+#: common.opt:3055
 #, fuzzy
 #| msgid "Enable function profiling"
 msgid "Enable function profiling."
 msgstr "启用函数取样"
 
-#: common.opt:3061
+#: common.opt:3065
 #, fuzzy
 #| msgid "Like -pedantic but issue them as errors"
 msgid "Like -pedantic but issue them as errors."
 msgstr "与 -pedantic 类似，但将它们视作错误"
 
-#: common.opt:3101
+#: common.opt:3105
 #, fuzzy
 #| msgid "Do not display functions compiled or elapsed time"
 msgid "Do not display functions compiled or elapsed time."
 msgstr "不显示编译的函数或逝去的时间"
 
-#: common.opt:3133
+#: common.opt:3137
 #, fuzzy
 #| msgid "Enable verbose output"
 msgid "Enable verbose output."
 msgstr "启用详细输出"
 
-#: common.opt:3137
+#: common.opt:3141
 #, fuzzy
 #| msgid "Display the compiler's version"
 msgid "Display the compiler's version."
 msgstr "显示编译器版本"
 
-#: common.opt:3141
+#: common.opt:3145
 #, fuzzy
 #| msgid "Suppress warnings"
 msgid "Suppress warnings."
 msgstr "不显示警告"
 
-#: common.opt:3151
+#: common.opt:3155
 #, fuzzy
 #| msgid "Create a shared library"
 msgid "Create a shared library."
 msgstr "生成一个共享库"
 
-#: common.opt:3196
+#: common.opt:3200
 #, fuzzy
 #| msgid "Create a position independent executable"
 msgid "Don't create a dynamically linked position independent executable."
 msgstr "生成位置无关可执行文件"
 
-#: common.opt:3200
+#: common.opt:3204
 #, fuzzy
 #| msgid "Create a position independent executable"
 msgid "Create a dynamically linked position independent executable."
 msgstr "生成位置无关可执行文件"
 
-#: common.opt:3204
+#: common.opt:3208
 #, fuzzy
 #| msgid "Create a position independent executable"
 msgid "Create a static position independent executable."
 msgstr "生成位置无关可执行文件"
 
-#: common.opt:3211
+#: common.opt:3215
 msgid "Use caller save register across calls if possible."
 msgstr ""
 
-#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:598 cp/cvt.c:1308
+#: go/gofrontend/expressions.cc:95 c-family/c-warn.c:599 cp/cvt.c:1308
 #: cp/cvt.c:1561
 #, gcc-internal-format
 msgid "value computed is not used"
@@ -19244,7 +19246,7 @@
 msgstr "需要整数或布尔类型"
 
 #: go/gofrontend/expressions.cc:4331 c/c-parser.c:13477 c/c-parser.c:13484
-#: cp/parser.c:33264 cp/parser.c:33271
+#: cp/parser.c:33261 cp/parser.c:33268
 #, fuzzy, gcc-internal-format
 #| msgid "Expected integer"
 msgid "expected integer"
@@ -19718,14 +19720,14 @@
 msgid "ignoring attribute %qE because it conflicts with attribute %qs"
 msgstr "%qE属性与 %s 属性冲突"
 
-#: attribs.c:449 c-family/c-attribs.c:1894 cp/decl.c:13690 cp/friend.c:302
-#: cp/tree.c:4559
+#: attribs.c:449 c-family/c-attribs.c:1905 cp/decl.c:13714 cp/friend.c:302
+#: cp/tree.c:4607
 #, fuzzy, gcc-internal-format
 msgid "previous declaration here"
 msgstr "%q+T先前在此处有过声明"
 
 #. Warn about and ignore all others for now, but store them.
-#: attribs.c:564 c-family/c-attribs.c:2717 objc/objc-act.c:4963
+#: attribs.c:564 c-family/c-attribs.c:2728 objc/objc-act.c:4963
 #: objc/objc-act.c:6932 objc/objc-act.c:8119 objc/objc-act.c:8170
 #, gcc-internal-format
 msgid "%qE attribute directive ignored"
@@ -19744,17 +19746,17 @@
 #. This is a c++11 attribute that appertains to a
 #. type-specifier, outside of the definition of, a class
 #. type.  Ignore it.
-#: attribs.c:590 cp/decl.c:10999
+#: attribs.c:590 cp/decl.c:11023
 #, fuzzy, gcc-internal-format
 msgid "attribute ignored"
 msgstr "忽略%qs属性"
 
-#: attribs.c:592 cp/decl.c:11000
+#: attribs.c:592 cp/decl.c:11024
 #, fuzzy, gcc-internal-format
 msgid "an attribute that appertains to a type-specifier is ignored"
 msgstr "类型在非前向声明的详尽类型限定符中被忽略"
 
-#: attribs.c:610 c-family/c-attribs.c:3219
+#: attribs.c:610 c-family/c-attribs.c:3230
 #, gcc-internal-format
 msgid "%qE attribute does not apply to types"
 msgstr "不能向类型添加属性%qE"
@@ -19770,40 +19772,40 @@
 msgstr "类型属性在定义后被忽略"
 
 #: attribs.c:691 attribs.c:1622 attribs.c:1632 attribs.c:1642
-#: c-family/c-attribs.c:540 c-family/c-attribs.c:559 c-family/c-attribs.c:577
-#: c-family/c-attribs.c:607 c-family/c-attribs.c:628 c-family/c-attribs.c:649
-#: c-family/c-attribs.c:690 c-family/c-attribs.c:717 c-family/c-attribs.c:733
-#: c-family/c-attribs.c:750 c-family/c-attribs.c:766 c-family/c-attribs.c:792
-#: c-family/c-attribs.c:807 c-family/c-attribs.c:835 c-family/c-attribs.c:852
-#: c-family/c-attribs.c:870 c-family/c-attribs.c:893 c-family/c-attribs.c:931
-#: c-family/c-attribs.c:954 c-family/c-attribs.c:971 c-family/c-attribs.c:1000
-#: c-family/c-attribs.c:1021 c-family/c-attribs.c:1042
-#: c-family/c-attribs.c:1069 c-family/c-attribs.c:1099
-#: c-family/c-attribs.c:1136 c-family/c-attribs.c:1189
-#: c-family/c-attribs.c:1255 c-family/c-attribs.c:1313
-#: c-family/c-attribs.c:1402 c-family/c-attribs.c:1432
-#: c-family/c-attribs.c:1483 c-family/c-attribs.c:1998
-#: c-family/c-attribs.c:2035 c-family/c-attribs.c:2096
-#: c-family/c-attribs.c:2152 c-family/c-attribs.c:2230
-#: c-family/c-attribs.c:2312 c-family/c-attribs.c:2371
-#: c-family/c-attribs.c:2390 c-family/c-attribs.c:2498
-#: c-family/c-attribs.c:2514 c-family/c-attribs.c:2530
-#: c-family/c-attribs.c:2551 c-family/c-attribs.c:2608
-#: c-family/c-attribs.c:2635 c-family/c-attribs.c:2690
-#: c-family/c-attribs.c:2870 c-family/c-attribs.c:2891
-#: c-family/c-attribs.c:3004 c-family/c-attribs.c:3031
-#: c-family/c-attribs.c:3221 c-family/c-attribs.c:3239
-#: c-family/c-attribs.c:3262 c-family/c-attribs.c:3301
-#: c-family/c-attribs.c:3383 c-family/c-attribs.c:3439
-#: c-family/c-attribs.c:3455 c-family/c-attribs.c:3549
-#: c-family/c-common.c:5600 config/darwin.c:2072 config/arm/arm.c:6868
+#: c-family/c-attribs.c:547 c-family/c-attribs.c:566 c-family/c-attribs.c:584
+#: c-family/c-attribs.c:614 c-family/c-attribs.c:635 c-family/c-attribs.c:656
+#: c-family/c-attribs.c:697 c-family/c-attribs.c:728 c-family/c-attribs.c:744
+#: c-family/c-attribs.c:761 c-family/c-attribs.c:777 c-family/c-attribs.c:803
+#: c-family/c-attribs.c:818 c-family/c-attribs.c:846 c-family/c-attribs.c:863
+#: c-family/c-attribs.c:881 c-family/c-attribs.c:904 c-family/c-attribs.c:942
+#: c-family/c-attribs.c:965 c-family/c-attribs.c:982 c-family/c-attribs.c:1011
+#: c-family/c-attribs.c:1032 c-family/c-attribs.c:1053
+#: c-family/c-attribs.c:1080 c-family/c-attribs.c:1110
+#: c-family/c-attribs.c:1147 c-family/c-attribs.c:1200
+#: c-family/c-attribs.c:1266 c-family/c-attribs.c:1324
+#: c-family/c-attribs.c:1413 c-family/c-attribs.c:1443
+#: c-family/c-attribs.c:1494 c-family/c-attribs.c:2009
+#: c-family/c-attribs.c:2046 c-family/c-attribs.c:2107
+#: c-family/c-attribs.c:2163 c-family/c-attribs.c:2241
+#: c-family/c-attribs.c:2323 c-family/c-attribs.c:2382
+#: c-family/c-attribs.c:2401 c-family/c-attribs.c:2509
+#: c-family/c-attribs.c:2525 c-family/c-attribs.c:2541
+#: c-family/c-attribs.c:2562 c-family/c-attribs.c:2619
+#: c-family/c-attribs.c:2646 c-family/c-attribs.c:2701
+#: c-family/c-attribs.c:2881 c-family/c-attribs.c:2902
+#: c-family/c-attribs.c:3015 c-family/c-attribs.c:3042
+#: c-family/c-attribs.c:3232 c-family/c-attribs.c:3250
+#: c-family/c-attribs.c:3273 c-family/c-attribs.c:3312
+#: c-family/c-attribs.c:3394 c-family/c-attribs.c:3450
+#: c-family/c-attribs.c:3466 c-family/c-attribs.c:3560
+#: c-family/c-common.c:5598 config/darwin.c:2072 config/arm/arm.c:6868
 #: config/arm/arm.c:6896 config/arm/arm.c:6913 config/avr/avr.c:9698
-#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6497
-#: config/i386/i386.c:41520 config/ia64/ia64.c:788
-#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33056
-#: config/spu/spu.c:3743 ada/gcc-interface/utils.c:6244
-#: ada/gcc-interface/utils.c:6261 ada/gcc-interface/utils.c:6277
-#: ada/gcc-interface/utils.c:6303 brig/brig-lang.c:476 lto/lto-lang.c:283
+#: config/h8300/h8300.c:5483 config/h8300/h8300.c:5507 config/i386/i386.c:6500
+#: config/i386/i386.c:41514 config/ia64/ia64.c:788
+#: config/powerpcspe/powerpcspe.c:35859 config/rs6000/rs6000.c:33112
+#: config/spu/spu.c:3743 ada/gcc-interface/utils.c:6249
+#: ada/gcc-interface/utils.c:6266 ada/gcc-interface/utils.c:6282
+#: ada/gcc-interface/utils.c:6308 brig/brig-lang.c:476 lto/lto-lang.c:283
 #, gcc-internal-format
 msgid "%qE attribute ignored"
 msgstr "%qE属性被忽略"
@@ -20174,93 +20176,108 @@
 msgid "%Kattempt to free a non-heap object"
 msgstr "%K试图 free 一个不在堆上的对象"
 
-#: calls.c:1434
+#: calls.c:1291 file-prefix-map.c:50
 #, fuzzy, gcc-internal-format
+msgid "invalid argument %qs to %qs"
+msgstr "%<...%>作为实参。)"
+
+#: calls.c:1452
+#, fuzzy, gcc-internal-format
 #| msgid "Argument of %s function at %L is negative"
 msgid "%Kargument %i value %qE is negative"
 msgstr "%2$L处 %1$s 函数的参数是负的"
 
-#: calls.c:1452
+#: calls.c:1470
 #, fuzzy, gcc-internal-format
 #| msgid "Second argument MOD at %L is zero"
 msgid "%Kargument %i value is zero"
 msgstr "%L处 MOD 的第二个参数为 0"
 
-#: calls.c:1469
+#: calls.c:1487
 #, gcc-internal-format
 msgid "%Kargument %i value %qE exceeds maximum object size %E"
 msgstr ""
 
-#: calls.c:1483
+#: calls.c:1501
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of %s function at %L is negative"
 msgid "%Kargument %i range [%E, %E] is negative"
 msgstr "%2$L处 %1$s 函数的参数是负的"
 
-#: calls.c:1490
+#: calls.c:1508
 #, gcc-internal-format
 msgid "%Kargument %i range [%E, %E] exceeds maximum object size %E"
 msgstr ""
 
-#: calls.c:1520
+#: calls.c:1538
 #, gcc-internal-format
 msgid "%Kproduct %<%E * %E%> of arguments %i and %i exceeds %<SIZE_MAX%>"
 msgstr ""
 
-#: calls.c:1526
+#: calls.c:1544
 #, gcc-internal-format
 msgid "%Kproduct %<%E * %E%> of arguments %i and %i exceeds maximum object size %E"
 msgstr ""
 
-#: calls.c:1537 calls.c:1540
+#: calls.c:1555 calls.c:1558
 #, fuzzy, gcc-internal-format
 msgid "argument %i in the range [%E, %E]"
 msgstr "%2$qE的第 %1$d 个参数必须是在 %3$d 和 %4$d 之间"
 
-#: calls.c:1551
+#: calls.c:1569
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "in a call to built-in allocation function %qD"
 msgstr "调用非函数的%qD"
 
-#: calls.c:1554
+#: calls.c:1572
 #, fuzzy, gcc-internal-format
 msgid "in a call to allocation function %qD declared here"
 msgstr "内联函数%q+D声明过但从未定义"
 
-#: calls.c:1711
+#: calls.c:1835
 #, gcc-internal-format
-msgid "%qD argument %i declared attribute %<nonstring%> is smaller than the specified bound %E"
+msgid "%qD argument %i declared attribute %<nonstring%> is smaller than the specified bound %wu"
 msgstr ""
 
-#: calls.c:1716
+#: calls.c:1841
+#, gcc-internal-format
+msgid "%qD argument %i declared attribute %<nonstring%> is smaller than the specified bound [%E, %E]"
+msgstr ""
+
+#: calls.c:1847
+#, gcc-internal-format
+msgid "%qD argument %i declared attribute %<nonstring%> may be smaller than the specified bound [%E, %E]"
+msgstr ""
+
+#: calls.c:1857
 #, fuzzy, gcc-internal-format
 msgid "%qD argument %i declared attribute %<nonstring%>"
 msgstr "%qD在其类外被声明为%<constexpr%>"
 
-#: calls.c:1721
+#: calls.c:1862
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared here"
 msgid "argument %qD declared here"
 msgstr "%qD在此声明"
 
-#: calls.c:1735
+#: calls.c:1876
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "[cannot find %s]"
 msgid "cannot tail-call: %s"
 msgstr "[找不到 %s]"
 
-#: calls.c:3365
+#: calls.c:3506
 #, gcc-internal-format
 msgid "function call has aggregate value"
 msgstr "函数调用有聚合类型"
 
-#: calls.c:4059
+#: calls.c:4200
 #, fuzzy, gcc-internal-format
 msgid "passing too large argument on stack"
 msgstr "栈帧太大"
 
-#: cfgexpand.c:1665 function.c:1002 varasm.c:2231
+#: cfgexpand.c:1665 function.c:1002 varasm.c:2242
 #, gcc-internal-format
 msgid "size of variable %q+D is too large"
 msgstr "变量%q+D的大小太大"
@@ -20837,238 +20854,238 @@
 msgid "number of bb notes in insn chain (%d) != n_basic_blocks (%d)"
 msgstr "指令链中记录的基本块数 (%d) != n_basic_blocks (%d)"
 
-#: cgraph.c:3051
+#: cgraph.c:3056
 #, fuzzy, gcc-internal-format
 #| msgid "caller edge count is negative"
 msgid "caller edge count invalid"
 msgstr "调用边计数为负"
 
-#: cgraph.c:3135
+#: cgraph.c:3140
 #, gcc-internal-format, gfc-internal-format
 msgid "aux field set for edge %s->%s"
 msgstr "为边 %s->%s 设定辅助域"
 
-#: cgraph.c:3142
+#: cgraph.c:3147
 #, gcc-internal-format
 msgid "cgraph count invalid"
 msgstr ""
 
-#: cgraph.c:3147
+#: cgraph.c:3152
 #, fuzzy, gcc-internal-format
 msgid "inline clone in same comdat group list"
 msgstr "节点是单独在中 comdat 群组"
 
-#: cgraph.c:3152
+#: cgraph.c:3157
 #, fuzzy, gcc-internal-format
 msgid "local symbols must be defined"
 msgstr "强制公共符号必须定义"
 
-#: cgraph.c:3157
+#: cgraph.c:3162
 #, fuzzy, gcc-internal-format
 msgid "externally visible inline clone"
 msgstr "为外部可见的名字添加下划线"
 
-#: cgraph.c:3162
+#: cgraph.c:3167
 #, fuzzy, gcc-internal-format
 msgid "inline clone with address taken"
 msgstr "已取地址，但是 ADDRESSABLE 位未被设置"
 
-#: cgraph.c:3167
+#: cgraph.c:3172
 #, fuzzy, gcc-internal-format
 msgid "inline clone is forced to output"
 msgstr "需要内联克隆"
 
-#: cgraph.c:3174
+#: cgraph.c:3179
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "aux field set for indirect edge from %s"
 msgstr "为边 %s->%s 设定辅助域"
 
-#: cgraph.c:3181
+#: cgraph.c:3186
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "An indirect edge from %s is not marked as indirect or has associated indirect_info, the corresponding statement is: "
 msgstr "间接边缘从 %s 未被标记为间接或已关联的 indirectinfo(_I)，相应叙述是："
 
-#: cgraph.c:3196
+#: cgraph.c:3201
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local function called by %s outside its comdat"
 msgstr ""
 
-#: cgraph.c:3206
+#: cgraph.c:3211
 #, gcc-internal-format
 msgid "inlined_to pointer is wrong"
 msgstr "inlined_to pointer 错误"
 
-#: cgraph.c:3211
+#: cgraph.c:3216
 #, gcc-internal-format
 msgid "multiple inline callers"
 msgstr "多个内联调用者"
 
-#: cgraph.c:3218
+#: cgraph.c:3223
 #, gcc-internal-format
 msgid "inlined_to pointer set for noninline callers"
 msgstr "为非内联的调用者设定了 inlined_to pointer"
 
-#: cgraph.c:3239
+#: cgraph.c:3244
 #, fuzzy, gcc-internal-format
 msgid "caller edge count does not match BB count"
 msgstr "调用边频率 %i 与基本块频率 %i 不匹配"
 
-#: cgraph.c:3261
+#: cgraph.c:3266
 #, fuzzy, gcc-internal-format
 msgid "indirect call count does not match BB count"
 msgstr "调用边频率 %i 与基本块频率 %i 不匹配"
 
-#: cgraph.c:3272
+#: cgraph.c:3277
 #, gcc-internal-format
 msgid "inlined_to pointer is set but no predecessors found"
 msgstr "设定了 inlined_to 指针却找不到前驱"
 
-#: cgraph.c:3277
+#: cgraph.c:3282
 #, gcc-internal-format
 msgid "inlined_to pointer refers to itself"
 msgstr "inlined_to pointer 指向自身"
 
-#: cgraph.c:3289
+#: cgraph.c:3294
 #, fuzzy, gcc-internal-format
 msgid "cgraph_node has wrong clone_of"
 msgstr "节点有错误的 clone_of"
 
-#: cgraph.c:3301
+#: cgraph.c:3306
 #, fuzzy, gcc-internal-format
 msgid "cgraph_node has wrong clone list"
 msgstr "节点的克隆列表不正确"
 
-#: cgraph.c:3307
+#: cgraph.c:3312
 #, fuzzy, gcc-internal-format
 msgid "cgraph_node is in clone list but it is not clone"
 msgstr "节点在克隆列表中，但并不是克隆"
 
-#: cgraph.c:3312
+#: cgraph.c:3317
 #, fuzzy, gcc-internal-format
 msgid "cgraph_node has wrong prev_clone pointer"
 msgstr "节点的 prev_clone 指针错误"
 
-#: cgraph.c:3317
+#: cgraph.c:3322
 #, gcc-internal-format
 msgid "double linked list of clones corrupted"
 msgstr "双向克隆链接列表已损坏"
 
-#: cgraph.c:3329
+#: cgraph.c:3334
 #, fuzzy, gcc-internal-format
 msgid "Alias has call edges"
 msgstr "基本块 %i 有多个 EH 边"
 
-#: cgraph.c:3337
+#: cgraph.c:3342
 #, fuzzy, gcc-internal-format
 msgid "Alias has non-alias reference"
 msgstr "别名有 non-alias 参考"
 
-#: cgraph.c:3342
+#: cgraph.c:3347
 #, fuzzy, gcc-internal-format
 msgid "Alias has more than one alias reference"
 msgstr "别名有超过一个别名参考"
 
-#: cgraph.c:3349
+#: cgraph.c:3354
 #, fuzzy, gcc-internal-format
 msgid "Analyzed alias has no reference"
 msgstr "%qE有%qs的引用类型"
 
-#: cgraph.c:3358
+#: cgraph.c:3363
 #, gcc-internal-format
 msgid "Instrumentation clone does not reference original node"
 msgstr ""
 
-#: cgraph.c:3365
+#: cgraph.c:3370
 #, fuzzy, gcc-internal-format
 msgid "Not instrumented node has non-NULL original declaration"
 msgstr "%qD的对齐"
 
-#: cgraph.c:3375
+#: cgraph.c:3380
 #, fuzzy, gcc-internal-format
 msgid "Instrumented node has wrong original declaration"
 msgstr "%qD的对齐"
 
-#: cgraph.c:3393
+#: cgraph.c:3398
 #, fuzzy, gcc-internal-format
 msgid "Node has more than one chkp reference"
 msgstr "别名有超过一个别名参考"
 
-#: cgraph.c:3398
+#: cgraph.c:3403
 #, fuzzy, gcc-internal-format
 msgid "Wrong node is referenced with chkp reference"
 msgstr "生成指向引用类型%qT的引用"
 
-#: cgraph.c:3406
+#: cgraph.c:3411
 #, fuzzy, gcc-internal-format
 msgid "Analyzed node has no reference to instrumented version"
 msgstr "分析的别名没有任何参考"
 
-#: cgraph.c:3420
+#: cgraph.c:3425
 #, gcc-internal-format
 msgid "Alias chain for instrumented node is broken"
 msgstr ""
 
-#: cgraph.c:3429
+#: cgraph.c:3434
 #, fuzzy, gcc-internal-format
 msgid "No edge out of thunk node"
 msgstr "没有边缘超出 thunk 节点"
 
-#: cgraph.c:3434
+#: cgraph.c:3439
 #, fuzzy, gcc-internal-format
 msgid "More than one edge out of thunk node"
 msgstr "超过一个边缘超出 thunk 节点"
 
-#: cgraph.c:3439
+#: cgraph.c:3444
 #, fuzzy, gcc-internal-format
 msgid "Thunk is not supposed to have body"
 msgstr "广义常表达式构造函数体不为空"
 
-#: cgraph.c:3445
+#: cgraph.c:3450
 #, gcc-internal-format
 msgid "Instrumentation thunk has wrong edge callee"
 msgstr ""
 
-#: cgraph.c:3481
+#: cgraph.c:3486
 #, gcc-internal-format
 msgid "shared call_stmt:"
 msgstr "共享的 call_stmt："
 
-#: cgraph.c:3489
+#: cgraph.c:3494
 #, gcc-internal-format
 msgid "edge points to wrong declaration:"
 msgstr "边指向错误的声明："
 
-#: cgraph.c:3498
+#: cgraph.c:3503
 #, fuzzy, gcc-internal-format
 msgid "an indirect edge with unknown callee corresponding to a call_stmt with a known declaration:"
 msgstr "间接边缘与未知被调用端相应到 callstmt 与已知声明(_S)："
 
-#: cgraph.c:3508
+#: cgraph.c:3513
 #, gcc-internal-format
 msgid "missing callgraph edge for call stmt:"
 msgstr "调用语句缺少 callgraph 边："
 
-#: cgraph.c:3518
+#: cgraph.c:3523
 #, fuzzy, gcc-internal-format
 msgid "reference to dead statement"
 msgstr "删除死存储"
 
-#: cgraph.c:3531
+#: cgraph.c:3536
 #, gcc-internal-format, gfc-internal-format
 msgid "edge %s->%s has no corresponding call_stmt"
 msgstr "边 %s->%s 没有对应的 call_stmt"
 
-#: cgraph.c:3543
+#: cgraph.c:3548
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "an indirect edge from %s has no corresponding call_stmt"
 msgstr "边 %s->%s 没有对应的 call_stmt"
 
-#: cgraph.c:3554
+#: cgraph.c:3559
 #, gcc-internal-format
 msgid "verify_cgraph_node failed"
 msgstr "verify_cgraph_node 失败"
 
-#: cgraph.c:3661 varpool.c:306
+#: cgraph.c:3666 varpool.c:306
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s: section %s is missing"
 msgstr "在 %s %s 中有缺失的“%s”\n"
@@ -21099,12 +21116,12 @@
 msgstr "%qE属性被忽略，因为%qT已被定义"
 
 #. include_self=
-#: cgraphunit.c:981 c/c-decl.c:11282
+#: cgraphunit.c:981 c/c-decl.c:11302
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F使用过但从未定义"
 
-#: cgraphunit.c:983 c/c-decl.c:11291
+#: cgraphunit.c:983 c/c-decl.c:11311
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "%q+F声明为%<static%>却从未定义过"
@@ -21224,12 +21241,12 @@
 msgid "cannot find '%s'"
 msgstr "找不到‘%s’"
 
-#: collect-utils.c:183 collect2.c:2361 collect2.c:2560 gcc.c:3080 gcc.c:6856
+#: collect-utils.c:183 collect2.c:2387 collect2.c:2586 gcc.c:3080 gcc.c:6856
 #, fuzzy, gcc-internal-format
 msgid "pex_init failed: %m"
 msgstr "cap_init 失败"
 
-#: collect-utils.c:192 collect2.c:2370 collect2.c:2568 gcc.c:8498
+#: collect-utils.c:192 collect2.c:2396 collect2.c:2594 gcc.c:8498
 #, gcc-internal-format
 msgid "%s: %m"
 msgstr "%s：%m"
@@ -21239,93 +21256,93 @@
 msgid "COLLECT_LTO_WRAPPER must be set"
 msgstr "环境变量 COLLECT_GCC 必须被设置"
 
-#: collect2.c:966 gcc.c:7382 lto-wrapper.c:1666
+#: collect2.c:969 gcc.c:7382 lto-wrapper.c:1692
 #: config/i386/intelmic-mkoffload.c:556 config/nvptx/mkoffload.c:405
 #, gcc-internal-format
 msgid "atexit failed"
 msgstr "atexit 失败"
 
-#: collect2.c:1064
+#: collect2.c:1067
 #, gcc-internal-format
 msgid "no arguments"
 msgstr "没有参数"
 
-#: collect2.c:1303 opts.c:904
+#: collect2.c:1311 opts.c:904
 #, gcc-internal-format
 msgid "LTO support has not been enabled in this configuration"
 msgstr "LTO 支持在此配置下未被启用"
 
-#: collect2.c:1344
+#: collect2.c:1352
 #, gcc-internal-format
 msgid "can't open %s: %m"
 msgstr "无法打开 %s：%m"
 
-#: collect2.c:1450
+#: collect2.c:1472
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown demangling style '%s'"
 msgstr "未知的解修饰风格‘%s’"
 
-#: collect2.c:1546 collect2.c:1729 collect2.c:1769
+#: collect2.c:1574 collect2.c:1757 collect2.c:1797
 #, fuzzy, gcc-internal-format
 msgid "fopen %s: %m"
 msgstr "无法查看 %s 的状态：%m\n"
 
-#: collect2.c:1549 collect2.c:1734 collect2.c:1772
+#: collect2.c:1577 collect2.c:1762 collect2.c:1800
 #, fuzzy, gcc-internal-format
 msgid "fclose %s: %m"
 msgstr "无法查看 %s 的状态：%m\n"
 
-#: collect2.c:2335
+#: collect2.c:2361
 #, gcc-internal-format
 msgid "cannot find 'nm'"
 msgstr "找不到 ‘nm’"
 
-#: collect2.c:2383
+#: collect2.c:2409
 #, fuzzy, gcc-internal-format
 msgid "can't open nm output: %m"
 msgstr "无法打开 %s：%m"
 
-#: collect2.c:2467
+#: collect2.c:2493
 #, gcc-internal-format, gfc-internal-format
 msgid "init function found in object %s"
 msgstr "在对象 %s 中发现 init 函数"
 
-#: collect2.c:2478
+#: collect2.c:2504
 #, gcc-internal-format, gfc-internal-format
 msgid "fini function found in object %s"
 msgstr "在对象 %s 中发现 fini 函数"
 
-#: collect2.c:2535
+#: collect2.c:2561
 #, gcc-internal-format
 msgid "cannot find 'ldd'"
 msgstr "找不到‘ldd’"
 
-#: collect2.c:2581
+#: collect2.c:2607
 #, fuzzy, gcc-internal-format
 msgid "can't open ldd output: %m"
 msgstr "无法为输出打开“%s”：%s"
 
-#: collect2.c:2599
+#: collect2.c:2625
 #, gcc-internal-format, gfc-internal-format
 msgid "dynamic dependency %s not found"
 msgstr "找不到动态依赖项 %s"
 
-#: collect2.c:2611
+#: collect2.c:2637
 #, gcc-internal-format, gfc-internal-format
 msgid "unable to open dynamic dependency '%s'"
 msgstr "无法打开动态依赖项‘%s’"
 
-#: collect2.c:2765
+#: collect2.c:2791
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: not a COFF file"
 msgstr "%s：不是一个 COFF 文件"
 
-#: collect2.c:2930
+#: collect2.c:2961
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: cannot open as COFF file"
 msgstr "%s：不能打开 COFF 文件"
 
-#: collect2.c:2989
+#: collect2.c:3020
 #, gcc-internal-format, gfc-internal-format
 msgid "library lib%s not found"
 msgstr "找不到库 lib%s"
@@ -21536,12 +21553,12 @@
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr "多个 EH 个性需要汇编器支持 .cfi.personality 指示。"
 
-#: dwarf2out.c:10901
+#: dwarf2out.c:10909
 #, gcc-internal-format
 msgid "-gdwarf-6 is output as version 5 with incompatibilities"
 msgstr ""
 
-#: dwarf2out.c:14415
+#: dwarf2out.c:14423
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr "变量位置处发现未被非法化的 UNSPEC %d"
@@ -21662,11 +21679,6 @@
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr "%K调用%qs，声明有警告属性：%s"
 
-#: file-prefix-map.c:50
-#, fuzzy, gcc-internal-format
-msgid "invalid argument %qs to %qs"
-msgstr "%<...%>作为实参。)"
-
 #: final.c:1868
 #, gcc-internal-format
 msgid "the frame size of %wd bytes is larger than %wd bytes"
@@ -21687,42 +21699,42 @@
 msgid "large fixed-point constant implicitly truncated to fixed-point type"
 msgstr "大定点常量隐式截断为定点类型"
 
-#: fold-const.c:4151 fold-const.c:4161
+#: fold-const.c:4157 fold-const.c:4167
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d due to width of bit-field"
 msgstr "由于位段宽度所限，比较结果永远为 %d"
 
-#: fold-const.c:5478 tree-ssa-reassoc.c:2374 tree-ssa-reassoc.c:3214
+#: fold-const.c:5484 tree-ssa-reassoc.c:2379 tree-ssa-reassoc.c:3219
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr "简化范围检查时假定有符号数从不溢出"
 
-#: fold-const.c:5928 fold-const.c:5942
+#: fold-const.c:5934 fold-const.c:5948
 #, gcc-internal-format, gfc-internal-format
 msgid "comparison is always %d"
 msgstr "比较结果始终为 %d"
 
-#: fold-const.c:6085
+#: fold-const.c:6091
 #, gcc-internal-format
 msgid "%<or%> of unmatched not-equal tests is always 1"
 msgstr "对两个不匹配的不等比较取%<or%>的结果总为 1"
 
-#: fold-const.c:6090
+#: fold-const.c:6096
 #, gcc-internal-format
 msgid "%<and%> of mutually exclusive equal-tests is always 0"
 msgstr "对两个互斥的相等比较取%<and%>的结果永远是 0"
 
-#: fold-const.c:8310
+#: fold-const.c:8316
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when reducing constant in comparison"
 msgstr "在比较中归约常量时假定有符号数从不溢出"
 
-#: fold-const.c:8710
+#: fold-const.c:8716
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr "在比较周围组合变量时假定有符号数从不溢出"
 
-#: fold-const.c:12063
+#: fold-const.c:12069
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr "折叠检查: 原始树因折叠而改变 "
@@ -21732,7 +21744,7 @@
 msgid "total size of local objects too large"
 msgstr "局部对象的总大小太大"
 
-#: function.c:1776 gimplify.c:6270
+#: function.c:1776 gimplify.c:6273
 #, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr "%<asm%>中不可能的约束"
@@ -22038,7 +22050,7 @@
 msgid "%s: linker input file unused because linking not done"
 msgstr "%s：未使用链接器输入文件，因为链接尚未完成"
 
-#: gcc.c:8420 c-family/c-opts.c:770
+#: gcc.c:8420 c-family/c-opts.c:768
 #, gcc-internal-format
 msgid "cannot use %<-%> as input filename for a precompiled header"
 msgstr ""
@@ -22275,7 +22287,7 @@
 msgid "%G%qD destination unchanged after copying no bytes"
 msgstr ""
 
-#: gimple-fold.c:2052 tree-ssa-strlen.c:2050
+#: gimple-fold.c:2052 tree-ssa-strlen.c:2074
 msgid "%G%qD specified bound %E equals destination size"
 msgstr ""
 
@@ -22299,12 +22311,12 @@
 msgid "null pointer dereference"
 msgstr "空指针"
 
-#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12451
-#: tree.c:12488 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10147
-#: c/c-typeck.c:10164 c/gimple-parser.c:1616 c/gimple-parser.c:1624
+#: gimple-ssa-isolate-paths.c:429 gimple-ssa-isolate-paths.c:549 tree.c:12455
+#: tree.c:12492 c/c-typeck.c:2908 c/c-typeck.c:2994 c/c-typeck.c:10152
+#: c/c-typeck.c:10169 c/gimple-parser.c:1616 c/gimple-parser.c:1624
 #: cp/call.c:6493 cp/call.c:8098 cp/constexpr.c:820 cp/constexpr.c:2309
-#: cp/cvt.c:1015 cp/cvt.c:1042 cp/decl.c:7334 cp/decl2.c:5256 cp/pt.c:8334
-#: cp/semantics.c:1836 cp/semantics.c:4053 cp/typeck.c:1700 cp/typeck.c:1895
+#: cp/cvt.c:1015 cp/cvt.c:1042 cp/decl.c:7355 cp/decl2.c:5246 cp/pt.c:8348
+#: cp/semantics.c:1836 cp/semantics.c:4056 cp/typeck.c:1700 cp/typeck.c:1895
 #: cp/typeck.c:3837
 #, gcc-internal-format
 msgid "declared here"
@@ -22315,295 +22327,295 @@
 msgid "nonnull argument %qD compared to NULL"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2517 gimple-ssa-sprintf.c:2637
+#: gimple-ssa-sprintf.c:2555 gimple-ssa-sprintf.c:2675
 #, gcc-internal-format
 msgid "%qE output may be truncated before the last format character"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2519 gimple-ssa-sprintf.c:2639
+#: gimple-ssa-sprintf.c:2557 gimple-ssa-sprintf.c:2677
 #, gcc-internal-format
 msgid "%qE output truncated before the last format character"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2522 gimple-ssa-sprintf.c:2642
+#: gimple-ssa-sprintf.c:2560 gimple-ssa-sprintf.c:2680
 #, gcc-internal-format
 msgid "%qE may write a terminating nul past the end of the destination"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2524 gimple-ssa-sprintf.c:2644
+#: gimple-ssa-sprintf.c:2562 gimple-ssa-sprintf.c:2682
 #, gcc-internal-format
 msgid "%qE writing a terminating nul past the end of the destination"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2534
+#: gimple-ssa-sprintf.c:2572
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size %wu"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.c:2541
+#: gimple-ssa-sprintf.c:2579
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size %wu"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.c:2548
+#: gimple-ssa-sprintf.c:2586
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size %wu"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.c:2559
+#: gimple-ssa-sprintf.c:2597
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2562
+#: gimple-ssa-sprintf.c:2600
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2564
+#: gimple-ssa-sprintf.c:2602
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2576
+#: gimple-ssa-sprintf.c:2614
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2579
+#: gimple-ssa-sprintf.c:2617
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2582
+#: gimple-ssa-sprintf.c:2620
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2591
+#: gimple-ssa-sprintf.c:2629
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2594
+#: gimple-ssa-sprintf.c:2632
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2597
+#: gimple-ssa-sprintf.c:2635
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2606
+#: gimple-ssa-sprintf.c:2644
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2609
+#: gimple-ssa-sprintf.c:2647
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2611
+#: gimple-ssa-sprintf.c:2649
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2653
+#: gimple-ssa-sprintf.c:2691
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive writing %wu bytes into a region of size between %wu and %wu"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.c:2660
+#: gimple-ssa-sprintf.c:2698
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output may be truncated writing %wu bytes into a region of size between %wu and %wu"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.c:2668
+#: gimple-ssa-sprintf.c:2706
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu byte into a region of size between %wu and %wu"
 msgid_plural "%<%.*s%> directive output truncated writing %wu bytes into a region of size between %wu and %wu"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.c:2680
+#: gimple-ssa-sprintf.c:2718
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2683
+#: gimple-ssa-sprintf.c:2721
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2686
+#: gimple-ssa-sprintf.c:2724
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing up to %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2699
+#: gimple-ssa-sprintf.c:2737
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2702
+#: gimple-ssa-sprintf.c:2740
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2705
+#: gimple-ssa-sprintf.c:2743
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing likely %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2715
+#: gimple-ssa-sprintf.c:2753
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2718
+#: gimple-ssa-sprintf.c:2756
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2721
+#: gimple-ssa-sprintf.c:2759
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing between %wu and %wu bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2730
+#: gimple-ssa-sprintf.c:2768
 #, gcc-internal-format
 msgid "%<%.*s%> directive output may be truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2733
+#: gimple-ssa-sprintf.c:2771
 #, gcc-internal-format
 msgid "%<%.*s%> directive output truncated writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2736
+#: gimple-ssa-sprintf.c:2774
 #, gcc-internal-format
 msgid "%<%.*s%> directive writing %wu or more bytes into a region of size between %wu and %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2825
+#: gimple-ssa-sprintf.c:2863
 #, gcc-internal-format
 msgid "%<%.*s%> directive argument is null"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2890
+#: gimple-ssa-sprintf.c:2928
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes exceeds minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2897
+#: gimple-ssa-sprintf.c:2935
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may exceed minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2900
+#: gimple-ssa-sprintf.c:2938
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes exceeds minimum required size of 4095"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2929
+#: gimple-ssa-sprintf.c:2967
 #, gcc-internal-format
 msgid "%<%.*s%> directive output of %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2936
+#: gimple-ssa-sprintf.c:2974
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes causes result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2939
+#: gimple-ssa-sprintf.c:2977
 #, gcc-internal-format
 msgid "%<%.*s%> directive output between %wu and %wu bytes may cause result to exceed %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2949
+#: gimple-ssa-sprintf.c:2987
 #, gcc-internal-format
 msgid "assuming directive output of %wu byte"
 msgid_plural "assuming directive output of %wu bytes"
 msgstr[0] ""
 
-#: gimple-ssa-sprintf.c:2956
+#: gimple-ssa-sprintf.c:2994
 #, fuzzy, gcc-internal-format
 msgid "directive argument %qE"
 msgstr "%L处内建 REPEAT 的 NCOPIES 实参是负的"
 
-#: gimple-ssa-sprintf.c:2958
+#: gimple-ssa-sprintf.c:2996
 #, fuzzy, gcc-internal-format
 msgid "directive argument in the range [%E, %E]"
 msgstr "停用回合 %s 用于函数在中范围的 [%u，%u]"
 
-#: gimple-ssa-sprintf.c:2962
+#: gimple-ssa-sprintf.c:3000
 #, gcc-internal-format
 msgid "using the range [%E, %E] for directive argument"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2982
+#: gimple-ssa-sprintf.c:3020
 #, gcc-internal-format
 msgid "%qE output %wu byte into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2983
+#: gimple-ssa-sprintf.c:3021
 #, gcc-internal-format
 msgid "%qE output %wu bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2987
+#: gimple-ssa-sprintf.c:3025
 #, gcc-internal-format
 msgid "%qE output between %wu and %wu bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2992
+#: gimple-ssa-sprintf.c:3030
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes (assuming %wu) into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:2997
+#: gimple-ssa-sprintf.c:3035
 #, gcc-internal-format
 msgid "%qE output %wu or more bytes into a destination of size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3368
+#: gimple-ssa-sprintf.c:3406
 #, gcc-internal-format
 msgid "%<%.*s%> directive width out of range"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3402
+#: gimple-ssa-sprintf.c:3440
 #, gcc-internal-format
 msgid "%<%.*s%> directive precision out of range"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3893
+#: gimple-ssa-sprintf.c:3931
 #, gcc-internal-format
 msgid "specified bound %wu exceeds maximum object size %wu"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3899
+#: gimple-ssa-sprintf.c:3937
 #, gcc-internal-format
 msgid "specified bound %wu exceeds %<INT_MAX%>"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3949
+#: gimple-ssa-sprintf.c:3987
 #, fuzzy, gcc-internal-format
 #| msgid "null pointer"
 msgid "null destination pointer"
 msgstr "空指针"
 
-#: gimple-ssa-sprintf.c:3966
+#: gimple-ssa-sprintf.c:4004
 #, gcc-internal-format
 msgid "specified bound %wu exceeds the size %wu of the destination object"
 msgstr ""
 
-#: gimple-ssa-sprintf.c:3978
+#: gimple-ssa-sprintf.c:4016
 #, fuzzy, gcc-internal-format
 #| msgid "%s in format string at %L"
 msgid "null format string"
@@ -22816,10 +22828,10 @@
 msgstr "枚举值 %E 对其类型%<%T%>而言太大了"
 
 #: gimple-ssa-warn-restrict.c:1678 c/c-decl.c:3603 c/c-decl.c:3874
-#: c/c-typeck.c:8345 cp/class.c:1346 cp/class.c:3098 cp/decl.c:3979
-#: cp/decl.c:10753 cp/decl.c:11151 cp/decl.c:11160 cp/friend.c:384
+#: c/c-typeck.c:8350 cp/class.c:1346 cp/class.c:3102 cp/decl.c:3979
+#: cp/decl.c:10777 cp/decl.c:11175 cp/decl.c:11184 cp/friend.c:384
 #: cp/friend.c:393 cp/parser.c:3275 cp/parser.c:3372 cp/parser.c:3422
-#: cp/parser.c:6327 cp/parser.c:21027
+#: cp/parser.c:6330 cp/parser.c:21024
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD在此声明"
@@ -22893,222 +22905,222 @@
 msgid "using result of function returning %<void%>"
 msgstr "使用返回%<void%>的函数的结果"
 
-#: gimplify.c:6128
+#: gimplify.c:6131
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid lvalue in asm output %d"
 msgstr "汇编输出 %d 中左值无效"
 
-#: gimplify.c:6271
+#: gimplify.c:6274
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr "非内存输入 %d 必须在内存中"
 
-#: gimplify.c:6311 gimplify.c:6320
+#: gimplify.c:6314 gimplify.c:6323
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr "内存输入 %d 不可直接寻址"
 
-#: gimplify.c:6928
+#: gimplify.c:6931
 #, fuzzy, gcc-internal-format
 msgid "threadprivate variable %qE used in target region"
 msgstr "嵌套函数中使用了寄存器变量%qD"
 
-#: gimplify.c:6930
+#: gimplify.c:6933
 #, fuzzy, gcc-internal-format
 msgid "enclosing target region"
 msgstr "括入并行"
 
-#: gimplify.c:6942
+#: gimplify.c:6945
 #, fuzzy, gcc-internal-format
 msgid "threadprivate variable %qE used in untied task"
 msgstr "嵌套函数中使用了寄存器变量%qD"
 
-#: gimplify.c:6944
+#: gimplify.c:6947
 #, fuzzy, gcc-internal-format
 msgid "enclosing task"
 msgstr "括入并行"
 
-#: gimplify.c:7016
+#: gimplify.c:7019
 #, fuzzy, gcc-internal-format
 msgid "%qE not specified in enclosing %qs"
 msgstr "%qE未为在括入的并行中指定"
 
-#: gimplify.c:7018
+#: gimplify.c:7021
 #, fuzzy, gcc-internal-format
 msgid "enclosing %qs"
 msgstr "括入并行"
 
-#: gimplify.c:7143
+#: gimplify.c:7146
 #, fuzzy, gcc-internal-format
 msgid "%qE not specified in enclosing OpenACC %qs construct"
 msgstr "%qE未为在括入的并行中指定"
 
-#: gimplify.c:7145
+#: gimplify.c:7148
 #, fuzzy, gcc-internal-format
 msgid "enclosing OpenACC %qs construct"
 msgstr "括入并行"
 
-#: gimplify.c:7198
+#: gimplify.c:7201
 #, gcc-internal-format
 msgid "%qE with %<link%> clause used in %<routine%> function"
 msgstr ""
 
-#: gimplify.c:7206
+#: gimplify.c:7209
 #, fuzzy, gcc-internal-format
 #| msgid "%qE undeclared (first use in this function)"
 msgid "%qE requires a %<declare%> directive for use in a %<routine%> function"
 msgstr "%qE未声明(在此函数内第一次使用)"
 
-#: gimplify.c:7272 gimplify.c:7872
+#: gimplify.c:7275 gimplify.c:7875
 #, fuzzy, gcc-internal-format
 #| msgid "variable %q+D declared %<inline%>"
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr "变量%q+D声明为%<inline%>"
 
-#: gimplify.c:7293
+#: gimplify.c:7296
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr ""
 
-#: gimplify.c:7411 gimplify.c:7443
+#: gimplify.c:7414 gimplify.c:7446
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE is predetermined linear"
 msgstr "迭代变量%qE不应当是 reduction"
 
-#: gimplify.c:7414
+#: gimplify.c:7417
 #, gcc-internal-format
 msgid "iteration variable %qE should be private"
 msgstr "迭代变量%qE应当是私有的"
 
-#: gimplify.c:7428
+#: gimplify.c:7431
 #, gcc-internal-format
 msgid "iteration variable %qE should not be firstprivate"
 msgstr "迭代变量%qE不应当是 firstprivate"
 
-#: gimplify.c:7431
+#: gimplify.c:7434
 #, gcc-internal-format
 msgid "iteration variable %qE should not be reduction"
 msgstr "迭代变量%qE不应当是 reduction"
 
-#: gimplify.c:7434
+#: gimplify.c:7437
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be linear"
 msgstr "迭代变量%qE应当是私有的"
 
-#: gimplify.c:7437
+#: gimplify.c:7440
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be lastprivate"
 msgstr "迭代变量%qE不应当是 firstprivate"
 
-#: gimplify.c:7440
+#: gimplify.c:7443
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be private"
 msgstr "迭代变量%qE应当是私有的"
 
-#: gimplify.c:7742
+#: gimplify.c:7745
 #, gcc-internal-format
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr ""
 
-#: gimplify.c:7949
+#: gimplify.c:7952
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr ""
 
-#: gimplify.c:8160
+#: gimplify.c:8163
 #, fuzzy, gcc-internal-format
 msgid "%qE appears more than once in map clauses"
 msgstr "%qD在数据子句中多次出现"
 
-#: gimplify.c:8464
+#: gimplify.c:8467
 #, fuzzy, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr "%s 变量%qE在外层上下文中是私有的"
 
-#: gimplify.c:8484
+#: gimplify.c:8487
 #, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr "%s 变量%qE在外层上下文中是私有的"
 
-#: gimplify.c:8510
+#: gimplify.c:8513
 #, fuzzy, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr "{ 预期于运算式中 ? 之后"
 
-#: gimplify.c:8775
+#: gimplify.c:8778
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr ""
 
-#: gimplify.c:8808
+#: gimplify.c:8811
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:9000
+#: gimplify.c:9003
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:9051
+#: gimplify.c:9054
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr ""
 
-#: gimplify.c:9133
+#: gimplify.c:9136
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to present_or_copy"
 msgstr ""
 
-#: gimplify.c:9278
+#: gimplify.c:9281
 #, fuzzy, gcc-internal-format
 #| msgid "invalid template declaration of %qD"
 msgid "invalid private reduction on %qE"
 msgstr "%qD模板声明无效"
 
-#: gimplify.c:11103 omp-low.c:2791
+#: gimplify.c:11106 omp-low.c:2791
 #, fuzzy, gcc-internal-format
 #| msgid "ordered region must be closely nested inside a loop region with an ordered clause"
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr "有序区域必须紧密嵌套在一个有次序分句的循环内"
 
-#: gimplify.c:11121
+#: gimplify.c:11124
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr ""
 
-#: gimplify.c:11134
+#: gimplify.c:11137
 #, fuzzy, gcc-internal-format
 #| msgid "number of results does not match number of values"
 msgid "number of variables in %<depend(sink)%> clause does not match number of iteration variables"
 msgstr "返回值的数量不匹配值的数量"
 
-#: gimplify.c:11147
+#: gimplify.c:11150
 #, gcc-internal-format
 msgid "more than one %<depend(source)%> clause on an %<ordered%> construct"
 msgstr ""
 
-#: gimplify.c:11158
+#: gimplify.c:11161
 #, gcc-internal-format
 msgid "%<depend(source)%> clause specified together with %<depend(sink:)%> clauses on the same construct"
 msgstr ""
 
-#: gimplify.c:12393
+#: gimplify.c:12396
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr "gimplification 失败"
 
-#: gimplify.c:12936
+#: gimplify.c:12939
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr "通过%<...%>传递时%qT被提升为%qT"
 
-#: gimplify.c:12941
+#: gimplify.c:12944
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr "(因此您应该向%<va_arg%>传递%qT而不是%qT)"
 
-#: gimplify.c:12948
+#: gimplify.c:12951
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr "如果执行到这段代码，程序将中止"
@@ -23579,47 +23591,47 @@
 msgid "Max. number of generated reload insns per insn is achieved (%d)\n"
 msgstr ""
 
-#: lto-cgraph.c:1294
+#: lto-cgraph.c:1296
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "bytecode stream: found multiple instances of cgraph node with uid %d"
 msgstr "字节码流：找到 cgraph 节点 %d 的多个实例"
 
-#: lto-cgraph.c:1472
+#: lto-cgraph.c:1474
 #, gcc-internal-format
 msgid "bytecode stream: no caller found while reading edge"
 msgstr "字节码流：读取边时找不到调用者"
 
-#: lto-cgraph.c:1478
+#: lto-cgraph.c:1480
 #, gcc-internal-format
 msgid "bytecode stream: no callee found while reading edge"
 msgstr "字节码流：读取边时找不到被调用者"
 
-#: lto-cgraph.c:1552
+#: lto-cgraph.c:1554
 #, gcc-internal-format
 msgid "bytecode stream: found empty cgraph node"
 msgstr "字节码流：找到空的 cgraph 节点"
 
-#: lto-cgraph.c:1730
+#: lto-cgraph.c:1732
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "At most %i profile runs is supported. Perhaps corrupted profile?"
 msgstr "最多 %i 侧写档运行被支持。也许已损坏侧写档？"
 
-#: lto-cgraph.c:1817
+#: lto-cgraph.c:1819
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Profile information in %s corrupted"
 msgstr "%s：已损坏\n"
 
-#: lto-cgraph.c:1855
+#: lto-cgraph.c:1857
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO cgraph in %s"
 msgstr "无法从 “%s” 中读取 LTO decls"
 
-#: lto-cgraph.c:1865
+#: lto-cgraph.c:1867
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot find LTO section refs in %s"
 msgstr "%s：无法找到区段：%s"
 
-#: lto-cgraph.c:1946
+#: lto-cgraph.c:1948
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid offload table in %s"
 msgstr "表格类型   ：%s\n"
@@ -23691,85 +23703,91 @@
 msgid "bytecode stream in file %qs generated with LTO version %d.%d instead of the expected %d.%d"
 msgstr "字节码流是由 LTO 版本 %d.%d 生成，而非预期的 %d.%d"
 
-#: lto-wrapper.c:117
+#: lto-wrapper.c:118
 #, fuzzy, gcc-internal-format
 msgid "deleting LTRANS file %s: %m"
 msgstr "打开 LTRANS 输出列表 %s：%m"
 
-#: lto-wrapper.c:154
+#: lto-wrapper.c:155
 #, gcc-internal-format
 msgid "malformed COLLECT_GCC_OPTIONS"
 msgstr "COLLECT_GCC_OPTIONS 格式错误"
 
-#: lto-wrapper.c:308
+#: lto-wrapper.c:309
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "created and used with different endianness"
 msgid "Option %s with different values"
 msgstr "创建和使用时使用了不同的大小端设定"
 
-#: lto-wrapper.c:392
+#: lto-wrapper.c:393
 #, gcc-internal-format, gfc-internal-format
 msgid "Option %s not used consistently in all LTO input files"
 msgstr ""
 
-#: lto-wrapper.c:832
+#: lto-wrapper.c:833
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "problem with building target image for %s\n"
 msgstr "组建目标平台：%s\n"
 
-#: lto-wrapper.c:852
+#: lto-wrapper.c:853
 #, fuzzy, gcc-internal-format
 msgid "reading input file"
 msgstr "读取输入历史文件…\n"
 
-#: lto-wrapper.c:857
+#: lto-wrapper.c:858
 #, fuzzy, gcc-internal-format
 msgid "writing output file"
 msgstr "写入到输出文件 '%s' 时出错\n"
 
-#: lto-wrapper.c:889
+#: lto-wrapper.c:890
 #, gcc-internal-format
 msgid "installation error, can't find crtoffloadtable.o"
 msgstr ""
 
-#: lto-wrapper.c:1000 lto-wrapper.c:1012
+#: lto-wrapper.c:1001 lto-wrapper.c:1013
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s: %s"
 msgid "%s: %s\n"
 msgstr "%s：%s"
 
-#: lto-wrapper.c:1056
+#: lto-wrapper.c:1064
 #, gcc-internal-format
 msgid "environment variable COLLECT_GCC must be set"
 msgstr "环境变量 COLLECT_GCC 必须被设置"
 
-#: lto-wrapper.c:1060 config/nvptx/mkoffload.c:363
+#: lto-wrapper.c:1068 config/nvptx/mkoffload.c:363
 #, gcc-internal-format
 msgid "environment variable COLLECT_GCC_OPTIONS must be set"
 msgstr "环境变量 COLLECT_GCC_OPTIONS 必须被设置"
 
-#: lto-wrapper.c:1229 lto-wrapper.c:1285
+#: lto-wrapper.c:1237 lto-wrapper.c:1293
 #, fuzzy, gcc-internal-format
 #| msgid "can't open %s: %m"
 msgid "cannot open %s: %m"
 msgstr "无法打开 %s：%m"
 
-#: lto-wrapper.c:1232 lto-wrapper.c:1291
+#: lto-wrapper.c:1240 lto-wrapper.c:1299
 #, fuzzy, gcc-internal-format
 #| msgid "can%'t read %s: %m"
 msgid "cannot read %s: %m"
 msgstr "无法读取 %s：%m"
 
-#: lto-wrapper.c:1259
+#: lto-wrapper.c:1267
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid format of %s"
 msgstr "操作无效的对象"
 
-#: lto-wrapper.c:1482
+#: lto-wrapper.c:1491
 #, fuzzy, gcc-internal-format
 msgid "fopen: %s: %m"
 msgstr "无法查看 %s 的状态：%m\n"
 
+#: lto-wrapper.c:1508
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "Could not open output file '%s'\n"
+msgid "Corrupted ltrans output file %s"
+msgstr "无法打开输出文件 '%s'\n"
+
 #: multiple_target.c:76
 #, fuzzy, gcc-internal-format
 msgid "the call requires ifunc, which is not supported by this target"
@@ -24138,12 +24156,12 @@
 msgid "unrecognized argument in option %qs"
 msgstr "memusage：无法识别的选项“$1”"
 
-#: opts-common.c:1198 config/i386/i386.c:3206
+#: opts-common.c:1198 config/i386/i386.c:3209
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %qs are: %s; did you mean %qs?"
 msgstr "%qs对%qs而言无效"
 
-#: opts-common.c:1201 config/i386/i386.c:3209
+#: opts-common.c:1201 config/i386/i386.c:3212
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %qs are: %s"
 msgstr "%qs对%qs而言无效"
@@ -24759,22 +24777,22 @@
 msgid "output operand %d must use %<&%> constraint"
 msgstr "输出操作数 %d 必须使用%<&%>约束"
 
-#: regcprop.c:1187
+#: regcprop.c:1193
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad next_regno for empty chain (%u)"
 msgstr "validate_value_data：[%u]  空链(%u) 的 next_regno 错误"
 
-#: regcprop.c:1199
+#: regcprop.c:1205
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: Loop in regno chain (%u)"
 msgstr "validate_value_data：在 regno 链(%u)中的循环"
 
-#: regcprop.c:1202
+#: regcprop.c:1208
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Bad oldest_regno (%u)"
 msgstr "validate_value_data：[%u] 错误的 oldest_regno (%u)"
 
-#: regcprop.c:1214
+#: regcprop.c:1220
 #, gcc-internal-format, gfc-internal-format
 msgid "validate_value_data: [%u] Non-empty reg in chain (%s %u %i)"
 msgstr "validate_value_data：[%u] 链(%s %u %i)中的非空 reg"
@@ -24818,7 +24836,7 @@
 msgstr "嵌套函数中使用了全局寄存器变量%qD"
 
 #: reginfo.c:789 config/powerpcspe/powerpcspe.c:32259
-#: config/rs6000/rs6000.c:29453
+#: config/rs6000/rs6000.c:29530
 #, fuzzy, gcc-internal-format
 msgid "conflicts with %qD"
 msgstr "%qD与已用的函数冲突"
@@ -25065,152 +25083,157 @@
 msgid "function symbol is not function"
 msgstr "函数返回了一个函数"
 
-#: symtab.c:1006
+#: symtab.c:1005
+#, gcc-internal-format
+msgid "inconsistent `ifunc' attribute"
+msgstr ""
+
+#: symtab.c:1013
 #, fuzzy, gcc-internal-format
 msgid "variable symbol is not variable"
 msgstr "%L处的符号不是一个 DUMMY 变量"
 
-#: symtab.c:1012
+#: symtab.c:1019
 #, fuzzy, gcc-internal-format
 msgid "node has unknown type"
 msgstr "未知类型的输入行"
 
-#: symtab.c:1021
+#: symtab.c:1028
 #, gcc-internal-format
 msgid "node not found node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.c:1029
+#: symtab.c:1036
 #, gcc-internal-format
 msgid "node differs from node->decl->decl_with_vis.symtab_node"
 msgstr ""
 
-#: symtab.c:1038
+#: symtab.c:1045
 #, gcc-internal-format
 msgid "assembler name hash list corrupted"
 msgstr ""
 
-#: symtab.c:1051
+#: symtab.c:1058
 #, fuzzy, gcc-internal-format
 msgid "node not found in symtab assembler name hash"
 msgstr "cgraph_hash 中找不到节点"
 
-#: symtab.c:1058
+#: symtab.c:1065
 #, fuzzy, gcc-internal-format
 msgid "double linked list of assembler names corrupted"
 msgstr "双向克隆链接列表已损坏"
 
-#: symtab.c:1063
+#: symtab.c:1070
 #, fuzzy, gcc-internal-format
 msgid "node has body_removed but is definition"
 msgstr "节点在克隆列表中，但并不是克隆"
 
-#: symtab.c:1068
+#: symtab.c:1075
 #, fuzzy, gcc-internal-format
 msgid "node is analyzed but it is not a definition"
 msgstr "节点在克隆列表中，但并不是克隆"
 
-#: symtab.c:1073
+#: symtab.c:1080
 #, fuzzy, gcc-internal-format
 msgid "node is alias but not implicit alias"
 msgstr "找不到区域别名文件“%s”"
 
-#: symtab.c:1078
+#: symtab.c:1085
 #, fuzzy, gcc-internal-format
 msgid "node is alias but not definition"
 msgstr "-fmit-class-file 的别名"
 
-#: symtab.c:1083
+#: symtab.c:1090
 #, fuzzy, gcc-internal-format
 msgid "node is weakref but not an transparent_alias"
 msgstr "找不到区域别名文件“%s”"
 
-#: symtab.c:1088
+#: symtab.c:1095
 #, fuzzy, gcc-internal-format
 msgid "node is transparent_alias but not an alias"
 msgstr "找不到区域别名文件“%s”"
 
-#: symtab.c:1097
+#: symtab.c:1104
 #, fuzzy, gcc-internal-format
 msgid "node is in same_comdat_group list but has no comdat_group"
 msgstr "节点在克隆列表中，但并不是克隆"
 
-#: symtab.c:1102
+#: symtab.c:1109
 #, fuzzy, gcc-internal-format
 msgid "same_comdat_group list across different groups"
 msgstr "same_comdat_group 并非环状清单"
 
-#: symtab.c:1107
+#: symtab.c:1114
 #, fuzzy, gcc-internal-format
 msgid "mixing different types of symbol in same comdat groups is not supported"
 msgstr "不支持组合有不同取样信息的单元。"
 
-#: symtab.c:1112
+#: symtab.c:1119
 #, fuzzy, gcc-internal-format
 msgid "node is alone in a comdat group"
 msgstr "节点是单独在中 comdat 群组"
 
-#: symtab.c:1119
+#: symtab.c:1126
 #, fuzzy, gcc-internal-format
 msgid "same_comdat_group is not a circular list"
 msgstr "same_comdat_group 并非环状清单"
 
-#: symtab.c:1134
+#: symtab.c:1141
 #, gcc-internal-format, gfc-internal-format
 msgid "comdat-local symbol referred to by %s outside its comdat"
 msgstr ""
 
-#: symtab.c:1144
+#: symtab.c:1151
 #, gcc-internal-format
 msgid "implicit_section flag is set but section isn't"
 msgstr ""
 
-#: symtab.c:1151
+#: symtab.c:1158
 #, fuzzy, gcc-internal-format
 msgid "Both section and comdat group is set"
 msgstr "节点是单独在中 comdat 群组"
 
-#: symtab.c:1163
+#: symtab.c:1170
 #, fuzzy, gcc-internal-format
 msgid "Alias and target's section differs"
 msgstr "--help=target 的别名"
 
-#: symtab.c:1170
+#: symtab.c:1177
 #, gcc-internal-format
 msgid "Alias and target's comdat groups differs"
 msgstr ""
 
-#: symtab.c:1185
+#: symtab.c:1192
 #, fuzzy, gcc-internal-format
 msgid "Transparent alias and target's assembler names differs"
 msgstr "--help=target 的别名"
 
-#: symtab.c:1193
+#: symtab.c:1200
 #, gcc-internal-format
 msgid "Chained transparent aliases"
 msgstr ""
 
-#: symtab.c:1216 symtab.c:1253
+#: symtab.c:1223 symtab.c:1260
 #, gcc-internal-format
 msgid "symtab_node::verify failed"
 msgstr "symtab_node::verify 失败"
 
-#: symtab.c:1249
+#: symtab.c:1256
 #, gcc-internal-format
 msgid "Two symbols with same comdat_group are not linked by the same_comdat_group list."
 msgstr ""
 
-#: symtab.c:1658
+#: symtab.c:1665
 #, fuzzy, gcc-internal-format
 msgid "function %q+D part of alias cycle"
 msgstr "函数%q+D重声明为内联的"
 
-#: symtab.c:1660
+#: symtab.c:1667
 #, fuzzy, gcc-internal-format
 msgid "variable %q+D part of alias cycle"
 msgstr "变量%qD被设定但未被使用"
 
-#: symtab.c:1688
+#: symtab.c:1695
 #, gcc-internal-format
 msgid "section of alias %q+D must match section of its target"
 msgstr ""
@@ -26020,7 +26043,7 @@
 msgid "the first argument of a VEC_COND_EXPR must be of a boolean vector type of the same number of elements as the result"
 msgstr ""
 
-#: tree-cfg.c:4395 c/c-typeck.c:5212
+#: tree-cfg.c:4395 c/c-typeck.c:5217
 #, gcc-internal-format
 msgid "type mismatch in conditional expression"
 msgstr "条件表达式中类型不匹配"
@@ -26371,22 +26394,22 @@
 msgid "missing edge %i->%i"
 msgstr "缺少边 %i->%i"
 
-#: tree-cfg.c:9379
+#: tree-cfg.c:9388
 #, gcc-internal-format
 msgid "%<noreturn%> function does return"
 msgstr "%<noreturn%>函数返回了"
 
-#: tree-cfg.c:9400 tree-cfg.c:9432
+#: tree-cfg.c:9409 tree-cfg.c:9441
 #, gcc-internal-format
 msgid "control reaches end of non-void function"
 msgstr "在有返回值的函数中，控制流程到达函数尾"
 
-#: tree-cfg.c:9498 cp/cvt.c:1039
+#: tree-cfg.c:9507 cp/cvt.c:1039
 #, gcc-internal-format
 msgid "ignoring return value of %qD, declared with attribute warn_unused_result"
 msgstr "忽略声明有 warn_unused_result 属性的%qD的返回值"
 
-#: tree-cfg.c:9503 cp/cvt.c:1046
+#: tree-cfg.c:9512 cp/cvt.c:1046
 #, gcc-internal-format
 msgid "ignoring return value of function declared with attribute warn_unused_result"
 msgstr "忽略声明有 warn_unused_result 属性的函数的返回值"
@@ -26652,44 +26675,44 @@
 msgid "stmt volatile flag not up-to-date"
 msgstr "stmt 易变的旗标无法 up-to-date"
 
-#: tree-ssa-strlen.c:1975
+#: tree-ssa-strlen.c:1999
 msgid "%G%qD output truncated before terminating nul copying %E byte from a string of the same length"
 msgid_plural "%G%qD output truncated before terminating nul copying %E bytes from a string of the same length"
 msgstr[0] ""
 
-#: tree-ssa-strlen.c:1989
+#: tree-ssa-strlen.c:2013
 msgid "%G%qD output truncated copying %E byte from a string of length %wu"
 msgid_plural "%G%qD output truncated copying %E bytes from a string of length %wu"
 msgstr[0] ""
 
-#: tree-ssa-strlen.c:1996
+#: tree-ssa-strlen.c:2020
 msgid "%G%qD output truncated copying between %wu and %wu bytes from a string of length %wu"
 msgstr ""
 
-#: tree-ssa-strlen.c:2008
+#: tree-ssa-strlen.c:2032
 msgid "%G%qD output may be truncated copying %E byte from a string of length %wu"
 msgid_plural "%G%qD output may be truncated copying %E bytes from a string of length %wu"
 msgstr[0] ""
 
-#: tree-ssa-strlen.c:2015 tree-ssa-strlen.c:2029
+#: tree-ssa-strlen.c:2039 tree-ssa-strlen.c:2053
 msgid "%G%qD output may be truncated copying between %wu and %wu bytes from a string of length %wu"
 msgstr ""
 
-#: tree-ssa-strlen.c:2150
+#: tree-ssa-strlen.c:2174
 msgid "%G%qD output truncated before terminating nul copying as many bytes from a string as its length"
 msgstr ""
 
-#: tree-ssa-strlen.c:2156
+#: tree-ssa-strlen.c:2180
 msgid "%G%qD specified bound depends on the length of the source argument"
 msgstr ""
 
-#: tree-ssa-strlen.c:2163
+#: tree-ssa-strlen.c:2187
 #, fuzzy, gcc-internal-format
 #| msgid "length modifier"
 msgid "length computed here"
 msgstr "长度修饰符"
 
-#: tree-ssa-uninit.c:191 varasm.c:331
+#: tree-ssa-uninit.c:191 varasm.c:342
 #, gcc-internal-format
 msgid "%qD was declared here"
 msgstr "%qD在此声明"
@@ -26864,27 +26887,27 @@
 msgid "target specific builtin not available"
 msgstr "目标相关的内建函数不可用"
 
-#: tree-vect-generic.c:287
+#: tree-vect-generic.c:283
 #, fuzzy, gcc-internal-format
 msgid "vector operation will be expanded piecewise"
 msgstr "矢量作业将被展开 piecewise"
 
-#: tree-vect-generic.c:290
+#: tree-vect-generic.c:286
 #, fuzzy, gcc-internal-format
 msgid "vector operation will be expanded in parallel"
 msgstr "矢量作业将被展开在中平行"
 
-#: tree-vect-generic.c:341
+#: tree-vect-generic.c:337
 #, fuzzy, gcc-internal-format
 msgid "vector operation will be expanded with a single scalar operation"
 msgstr "矢量作业将被展开与单一纯量作业"
 
-#: tree-vect-generic.c:941
+#: tree-vect-generic.c:937
 #, fuzzy, gcc-internal-format
 msgid "vector condition will be expanded piecewise"
 msgstr "矢量作业将被展开 piecewise"
 
-#: tree-vect-generic.c:1373
+#: tree-vect-generic.c:1369
 #, fuzzy, gcc-internal-format
 msgid "vector shuffling operation will be expanded piecewise"
 msgstr "矢量随机播放作业将被展开 piecewise"
@@ -26894,31 +26917,31 @@
 msgid "vectorization did not happen for a simd loop"
 msgstr ""
 
-#: tree-vrp.c:4930 tree-vrp.c:4974
+#: tree-vrp.c:4931 tree-vrp.c:4975
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is above array bounds"
 msgid "array subscript %E is above array bounds of %qT"
 msgstr "数组下标大于数组边界"
 
-#: tree-vrp.c:4956
+#: tree-vrp.c:4957
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is outside array bounds"
 msgid "array subscript [%E, %E] is outside array bounds of %qT"
 msgstr "数组下标越过了数组边界"
 
-#: tree-vrp.c:4988
+#: tree-vrp.c:4989
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is below array bounds"
 msgid "array subscript %E is below array bounds of %qT"
 msgstr "数组下标小于数组边界"
 
-#: tree-vrp.c:5046
+#: tree-vrp.c:5047
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is below array bounds"
 msgid "array subscript %wi is below array bounds of %qT"
 msgstr "数组下标小于数组边界"
 
-#: tree-vrp.c:5060
+#: tree-vrp.c:5061
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is above array bounds"
 msgid "array subscript %wu is above array bounds of %qT"
@@ -26934,92 +26957,92 @@
 msgid "side-effects element in no-side-effects CONSTRUCTOR"
 msgstr ""
 
-#: tree.c:7852
+#: tree.c:7856
 #, gcc-internal-format
 msgid "arrays of functions are not meaningful"
 msgstr "函数数组是没有意义的"
 
-#: tree.c:8019
+#: tree.c:8023
 #, gcc-internal-format
 msgid "function return type cannot be function"
 msgstr "函数不能返回函数"
 
-#: tree.c:9327 tree.c:9412 tree.c:9473
+#: tree.c:9331 tree.c:9416 tree.c:9477
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: %s, have %s in %s, at %s:%d"
 msgstr "树检查：%s，得到 %s 在 %s，于 %s:%d"
 
-#: tree.c:9364
+#: tree.c:9368
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected none of %s, have %s in %s, at %s:%d"
 msgstr "树检查：不需要 %s，得到 %s 在 %s，于 %s:%d"
 
-#: tree.c:9377
+#: tree.c:9381
 #, gcc-internal-format
 msgid "tree check: expected class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "树检查：需要类%qs，得到%qs(%s) 在 %s，于 %s:%d"
 
-#: tree.c:9426
+#: tree.c:9430
 #, gcc-internal-format
 msgid "tree check: did not expect class %qs, have %qs (%s) in %s, at %s:%d"
 msgstr "树检查：不需要类%qs，得到%qs(%s) 在 %s，于 %s:%d"
 
-#: tree.c:9439
+#: tree.c:9443
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: expected omp_clause %s, have %s in %s, at %s:%d"
 msgstr "树检查：需要 omp_clause %s，得到 %s 在 %s，于 %s:%d"
 
-#: tree.c:9499
+#: tree.c:9503
 #, gcc-internal-format
 msgid "tree check: expected tree that contains %qs structure, have %qs in %s, at %s:%d"
 msgstr "树检查：需要包含%qs结构的树，得到%qs在 %s，于 %s:%d"
 
-#: tree.c:9513
+#: tree.c:9517
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_int_cst with %d elts in %s, at %s:%d"
 msgstr "树检查：访问了 %3$s 中有 %2$d 个 elt  的 tree_vec 的 elt %1$d，于 %4$s:%5$d"
 
-#: tree.c:9525
+#: tree.c:9529
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed elt %d of tree_vec with %d elts in %s, at %s:%d"
 msgstr "树检查：访问了 %3$s 中有 %2$d 个 elt  的 tree_vec 的 elt %1$d，于 %4$s:%5$d"
 
-#: tree.c:9538
+#: tree.c:9542
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of %s with %d operands in %s, at %s:%d"
 msgstr "树检查：在 %4$s 中访问有 %3$d 个操作数的 %2$s 的第 %1$d 个操作数，于 %5$s:%6$d"
 
-#: tree.c:9551
+#: tree.c:9555
 #, gcc-internal-format, gfc-internal-format
 msgid "tree check: accessed operand %d of omp_clause %s with %d operands in %s, at %s:%d"
 msgstr "树检查：在 %4$s 中访问有 %3$d 个操作数的 omp_clause %2$s 的第 %1$d 个操作数，于 %5$s:%6$d"
 
-#: tree.c:12446
+#: tree.c:12450
 #, fuzzy, gcc-internal-format
 msgid "%qD is deprecated: %s"
 msgstr "已弃用%qE：%s"
 
-#: tree.c:12449
+#: tree.c:12453
 #, fuzzy, gcc-internal-format
 msgid "%qD is deprecated"
 msgstr "已弃用%qE"
 
-#: tree.c:12473 tree.c:12495
+#: tree.c:12477 tree.c:12499
 #, gcc-internal-format
 msgid "%qE is deprecated: %s"
 msgstr "已弃用%qE：%s"
 
-#: tree.c:12476 tree.c:12498
+#: tree.c:12480 tree.c:12502
 #, gcc-internal-format
 msgid "%qE is deprecated"
 msgstr "已弃用%qE"
 
-#: tree.c:12482 tree.c:12503
+#: tree.c:12486 tree.c:12507
 #, gcc-internal-format, gfc-internal-format
 msgid "type is deprecated: %s"
 msgstr "已弃用类型：%s"
 
-#: tree.c:12485 tree.c:12506
+#: tree.c:12489 tree.c:12510
 #, gcc-internal-format
 msgid "type is deprecated"
 msgstr "已弃用此类型"
@@ -27044,247 +27067,247 @@
 #. - vector types may differ by TYPE_VECTOR_OPAQUE
 #.
 #. Convenience macro for matching individual fields.
-#: tree.c:13043
+#: tree.c:13047
 #, gcc-internal-format, gfc-internal-format
 msgid "type variant differs by %s"
 msgstr ""
 
-#: tree.c:13084
+#: tree.c:13088
 #, gcc-internal-format
 msgid "type variant has different TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13086
+#: tree.c:13090
 #, gcc-internal-format
 msgid "type variant's TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13088
+#: tree.c:13092
 #, gcc-internal-format
 msgid "type's TYPE_SIZE_UNIT"
 msgstr ""
 
-#: tree.c:13108
+#: tree.c:13112
 #, gcc-internal-format
 msgid "type variant with TYPE_ALIAS_SET_KNOWN_P"
 msgstr ""
 
-#: tree.c:13121
+#: tree.c:13125
 #, gcc-internal-format
 msgid "type variant has different TYPE_VFIELD"
 msgstr ""
 
-#: tree.c:13157
+#: tree.c:13161
 #, gcc-internal-format
 msgid "type variant has different TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13159
+#: tree.c:13163
 #, gcc-internal-format
 msgid "type variant's TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13161
+#: tree.c:13165
 #, gcc-internal-format
 msgid "type's TYPE_BINFO"
 msgstr ""
 
-#: tree.c:13199
+#: tree.c:13203
 #, gcc-internal-format
 msgid "type variant has different TYPE_FIELDS"
 msgstr ""
 
-#: tree.c:13201
+#: tree.c:13205
 #, fuzzy, gcc-internal-format
 #| msgid "%s:stamp mismatch with notes file\n"
 msgid "first mismatch is field"
 msgstr "%s:时间戳与说明文件不匹配\n"
 
-#: tree.c:13203
+#: tree.c:13207
 #, gcc-internal-format
 msgid "and field"
 msgstr ""
 
-#: tree.c:13220
+#: tree.c:13224
 #, gcc-internal-format
 msgid "type variant has different TREE_TYPE"
 msgstr ""
 
-#: tree.c:13222 tree.c:13233
+#: tree.c:13226 tree.c:13237
 #, gcc-internal-format
 msgid "type variant's TREE_TYPE"
 msgstr ""
 
-#: tree.c:13224 tree.c:13235
+#: tree.c:13228 tree.c:13239
 #, gcc-internal-format
 msgid "type's TREE_TYPE"
 msgstr ""
 
-#: tree.c:13231
+#: tree.c:13235
 #, fuzzy, gcc-internal-format
 #| msgid "-mnop-mcount is not compatible with this target"
 msgid "type is not compatible with its variant"
 msgstr "-mnop-mcount 与此目标不兼容"
 
-#: tree.c:13534
+#: tree.c:13538
 #, fuzzy, gcc-internal-format
 #| msgid "environment variable %qs not defined"
 msgid "Main variant is not defined"
 msgstr "环境变量%qs未定义"
 
-#: tree.c:13539
+#: tree.c:13543
 #, gcc-internal-format
 msgid "TYPE_MAIN_VARIANT has different TYPE_MAIN_VARIANT"
 msgstr ""
 
-#: tree.c:13551
+#: tree.c:13555
 #, gcc-internal-format
 msgid "TYPE_CANONICAL has different TYPE_CANONICAL"
 msgstr ""
 
-#: tree.c:13569
+#: tree.c:13573
 #, gcc-internal-format
 msgid "TYPE_CANONICAL is not compatible"
 msgstr ""
 
-#: tree.c:13577
+#: tree.c:13581
 #, gcc-internal-format
 msgid "TYPE_MODE of TYPE_CANONICAL is not compatible"
 msgstr ""
 
-#: tree.c:13583
+#: tree.c:13587
 #, gcc-internal-format
 msgid "TYPE_CANONICAL of main variant is not main variant"
 msgstr ""
 
-#: tree.c:13599
+#: tree.c:13603
 #, gcc-internal-format
 msgid "TYPE_VFIELD is not FIELD_DECL nor TREE_LIST"
 msgstr ""
 
-#: tree.c:13609
+#: tree.c:13613
 #, gcc-internal-format
 msgid "TYPE_NEXT_PTR_TO is not POINTER_TYPE"
 msgstr ""
 
-#: tree.c:13619
+#: tree.c:13623
 #, gcc-internal-format
 msgid "TYPE_NEXT_REF_TO is not REFERENCE_TYPE"
 msgstr ""
 
-#: tree.c:13640
+#: tree.c:13644
 #, gcc-internal-format
 msgid "TYPE_BINFO is not TREE_BINFO"
 msgstr ""
 
-#: tree.c:13646
+#: tree.c:13650
 #, gcc-internal-format
 msgid "TYPE_BINFO type is not TYPE_MAIN_VARIANT"
 msgstr ""
 
-#: tree.c:13657
+#: tree.c:13661
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not record nor union"
 msgstr ""
 
-#: tree.c:13668
+#: tree.c:13672
 #, gcc-internal-format
 msgid "TYPE_OFFSET_BASETYPE is not record nor union"
 msgstr ""
 
-#: tree.c:13686
+#: tree.c:13690
 #, gcc-internal-format
 msgid "TYPE_ARRAY_MAX_SIZE not INTEGER_CST"
 msgstr ""
 
-#: tree.c:13693
+#: tree.c:13697
 #, gcc-internal-format
 msgid "TYPE_MAX_VALUE_RAW non-NULL"
 msgstr ""
 
-#: tree.c:13700
+#: tree.c:13704
 #, gcc-internal-format
 msgid "TYPE_LANG_SLOT_1 (binfo) field is non-NULL"
 msgstr ""
 
-#: tree.c:13716
+#: tree.c:13720
 #, gcc-internal-format
 msgid "Enum value is not CONST_DECL or INTEGER_CST"
 msgstr ""
 
-#: tree.c:13724
+#: tree.c:13728
 #, gcc-internal-format
 msgid "Enum value type is not INTEGER_TYPE nor convertible to the enum"
 msgstr ""
 
-#: tree.c:13731
+#: tree.c:13735
 #, gcc-internal-format
 msgid "Enum value name is not IDENTIFIER_NODE"
 msgstr ""
 
-#: tree.c:13741
+#: tree.c:13745
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qE has non-integer type"
 msgid "Array TYPE_DOMAIN is not integer type"
 msgstr "数组%qE的大小的类型不是整数"
 
-#: tree.c:13750
+#: tree.c:13754
 #, fuzzy, gcc-internal-format
 #| msgid "field %qE has incomplete type"
 msgid "TYPE_FIELDS defined in incomplete type"
 msgstr "字段%qE的类型不完全"
 
-#: tree.c:13772
+#: tree.c:13776
 #, gcc-internal-format
 msgid "Wrong tree in TYPE_FIELDS list"
 msgstr ""
 
-#: tree.c:13787
+#: tree.c:13791
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is %i while TYPE_CACHED_VALUES is %p"
 msgstr ""
 
-#: tree.c:13793
+#: tree.c:13797
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES is not TREE_VEC"
 msgstr ""
 
-#: tree.c:13806
+#: tree.c:13810
 #, gcc-internal-format
 msgid "wrong TYPE_CACHED_VALUES entry"
 msgstr ""
 
-#: tree.c:13819
+#: tree.c:13823
 #, gcc-internal-format
 msgid "TREE_PURPOSE is non-NULL in TYPE_ARG_TYPES list"
 msgstr ""
 
-#: tree.c:13825
+#: tree.c:13829
 #, gcc-internal-format
 msgid "Wrong entry in TYPE_ARG_TYPES list"
 msgstr ""
 
-#: tree.c:13832
+#: tree.c:13836
 #, gcc-internal-format
 msgid "TYPE_VALUES_RAW field is non-NULL"
 msgstr ""
 
-#: tree.c:13844
+#: tree.c:13848
 #, gcc-internal-format
 msgid "TYPE_CACHED_VALUES_P is set while it should not"
 msgstr ""
 
-#: tree.c:13850
+#: tree.c:13854
 #, gcc-internal-format
 msgid "TYPE_STRING_FLAG is set on wrong type code"
 msgstr ""
 
-#: tree.c:13860
+#: tree.c:13864
 #, gcc-internal-format
 msgid "TYPE_METHOD_BASETYPE is not main variant"
 msgstr ""
 
-#: tree.c:13867
+#: tree.c:13871
 #, fuzzy, gcc-internal-format
 #| msgid "verify_gimple failed"
 msgid "verify_type failed"
@@ -27310,185 +27333,185 @@
 msgid "corrupted value profile: %s profile counter (%d out of %d) inconsistent with basic-block count (%d)"
 msgstr "损坏的值取样：%s 取样总数(%d)与基本块数(%d)不匹配"
 
-#: var-tracking.c:7166
+#: var-tracking.c:7184
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded with -fvar-tracking-assignments, retrying without"
 msgstr "变量跟踪大小越限，请不带 -fvar-tracking-assignments 重试"
 
-#: var-tracking.c:7170
+#: var-tracking.c:7188
 #, gcc-internal-format
 msgid "variable tracking size limit exceeded"
 msgstr "变量跟踪大小越限"
 
-#: varasm.c:326
+#: varasm.c:337
 #, fuzzy, gcc-internal-format
 msgid "%+qD causes a section type conflict with %qD"
 msgstr "%+D 导致一个节类型冲突"
 
-#: varasm.c:329
+#: varasm.c:340
 #, fuzzy, gcc-internal-format
 msgid "section type conflict with %qD"
 msgstr "%+D 导致一个节类型冲突"
 
-#: varasm.c:334
+#: varasm.c:345
 #, fuzzy, gcc-internal-format
 #| msgid "%+D causes a section type conflict"
 msgid "%+qD causes a section type conflict"
 msgstr "%+D 导致一个节类型冲突"
 
-#: varasm.c:336
+#: varasm.c:347
 #, fuzzy, gcc-internal-format
 msgid "section type conflict"
 msgstr "%+D 导致一个节类型冲突"
 
-#: varasm.c:1019
+#: varasm.c:1030
 #, fuzzy, gcc-internal-format
 msgid "alignment of %q+D is greater than maximum object file alignment %d"
 msgstr "%q+D的对齐要求大于目标文件的最大对齐边界。使用 %d"
 
-#: varasm.c:1172
+#: varasm.c:1183
 #, fuzzy, gcc-internal-format
 #| msgid "only uninitialized variables can be placed in a .bss section"
 msgid "only zero initializers are allowed in section %qs"
 msgstr "只有未初始化的变量才能放在 .bss 节中"
 
-#: varasm.c:1378 varasm.c:1387
+#: varasm.c:1389 varasm.c:1398
 #, gcc-internal-format
 msgid "register name not specified for %q+D"
 msgstr "%q+D的寄存器名无效"
 
-#: varasm.c:1389
+#: varasm.c:1400
 #, gcc-internal-format
 msgid "invalid register name for %q+D"
 msgstr "%q+D的寄存器名无效"
 
-#: varasm.c:1391
+#: varasm.c:1402
 #, gcc-internal-format
 msgid "data type of %q+D isn%'t suitable for a register"
 msgstr "为%q+D指定的寄存器不适合此数据类型"
 
-#: varasm.c:1394
+#: varasm.c:1405
 #, fuzzy, gcc-internal-format
 msgid "the register specified for %q+D cannot be accessed by the current target"
 msgstr "为%q+D指定的寄存器不适合此数据类型"
 
-#: varasm.c:1397
+#: varasm.c:1408
 #, fuzzy, gcc-internal-format
 msgid "the register specified for %q+D is not general enough to be used as a register variable"
 msgstr "寄存器用作两个全局寄存器变量"
 
-#: varasm.c:1400
+#: varasm.c:1411
 #, gcc-internal-format
 msgid "register specified for %q+D isn%'t suitable for data type"
 msgstr "为%q+D指定的寄存器不适合此数据类型"
 
-#: varasm.c:1410
+#: varasm.c:1421
 #, gcc-internal-format
 msgid "global register variable has initial value"
 msgstr "全局寄存器变量有初始值"
 
-#: varasm.c:1414
+#: varasm.c:1425
 #, gcc-internal-format
 msgid "optimization may eliminate reads and/or writes to register variables"
 msgstr "优化可能会去除对寄存器变量的读写"
 
-#: varasm.c:1460
+#: varasm.c:1471
 #, gcc-internal-format
 msgid "register name given for non-register variable %q+D"
 msgstr "为非寄存器变量%q+D给定了寄存器名"
 
-#: varasm.c:1870
+#: varasm.c:1881
 #, gcc-internal-format
 msgid "Patchable function entry > size"
 msgstr ""
 
-#: varasm.c:2069
+#: varasm.c:2080
 #, gcc-internal-format
 msgid "thread-local COMMON data not implemented"
 msgstr "线程局部的 COMMON 数据没有实现"
 
-#: varasm.c:2102
+#: varasm.c:2113
 #, gcc-internal-format
 msgid "requested alignment for %q+D is greater than implemented alignment of %wu"
 msgstr "%q+D需要的对齐边界大于实现的对齐边界 %wu"
 
-#: varasm.c:2205 c/c-decl.c:5027 c/c-parser.c:1534
+#: varasm.c:2216 c/c-decl.c:5027 c/c-parser.c:1534
 #, gcc-internal-format
 msgid "storage size of %q+D isn%'t known"
 msgstr "%q+D的存储大小未知"
 
-#: varasm.c:4910
+#: varasm.c:4921
 #, gcc-internal-format
 msgid "initializer for integer/fixed-point value is too complicated"
 msgstr "整数/定点值的初始值设定太复杂"
 
-#: varasm.c:4915
+#: varasm.c:4926
 #, gcc-internal-format
 msgid "initializer for floating value is not a floating constant"
 msgstr "浮点值的初始值设定不是一个浮点常量"
 
-#: varasm.c:5227
+#: varasm.c:5238
 #, gcc-internal-format
 msgid "invalid initial value for member %qE"
 msgstr "成员%qE的初始值无效"
 
-#: varasm.c:5487
+#: varasm.c:5498
 #, fuzzy, gcc-internal-format
 msgid "%+qD declared weak after being used"
 msgstr "%q+D声明为友元"
 
-#: varasm.c:5539
+#: varasm.c:5550
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q#D outside of class is not definition"
 msgid "weak declaration of %q+D being applied to a already existing, static definition"
 msgstr "出现在类外的%q#D的声明不是定义"
 
-#: varasm.c:5575
+#: varasm.c:5586
 #, gcc-internal-format
 msgid "weak declaration of %q+D must be public"
 msgstr "%q+D的弱声明必须是公共的"
 
-#: varasm.c:5579
+#: varasm.c:5590
 #, gcc-internal-format
 msgid "weak declaration of %q+D not supported"
 msgstr "不支持%q+D的弱声明"
 
-#: varasm.c:5608 varasm.c:5912
+#: varasm.c:5619 varasm.c:5926
 #, gcc-internal-format
 msgid "only weak aliases are supported in this configuration"
 msgstr "此配置下只支持弱别名"
 
-#: varasm.c:5802
+#: varasm.c:5813
 #, gcc-internal-format
 msgid "weakref is not supported in this configuration"
 msgstr "弱引用在此配置下不受支持"
 
-#: varasm.c:5834
+#: varasm.c:5846
 #, fuzzy, gcc-internal-format
 msgid "ifunc is not supported on this target"
 msgstr "堆栈限制在此目标机上不受支持"
 
-#: varasm.c:5892
+#: varasm.c:5904
 #, gcc-internal-format
 msgid "weakref %q+D ultimately targets itself"
 msgstr "weakref%q+D最终指向其自身"
 
-#: varasm.c:5894
+#: varasm.c:5906
 #, gcc-internal-format
 msgid "weakref %q+D must have static linkage"
 msgstr "弱引用%q+D必须有静态链接"
 
-#: varasm.c:5901
+#: varasm.c:5913
 #, gcc-internal-format
 msgid "alias definitions not supported in this configuration"
 msgstr "别名定义在此配置下不受支持"
 
-#: varasm.c:5909
+#: varasm.c:5923
 #, fuzzy, gcc-internal-format
 msgid "ifunc is not supported in this configuration"
 msgstr "弱引用在此配置下不受支持"
 
-#: varasm.c:6127 config/sol2.c:159 config/i386/winnt.c:265
+#: varasm.c:6141 config/sol2.c:159 config/i386/winnt.c:265
 #, gcc-internal-format
 msgid "visibility attribute not supported in this configuration; ignored"
 msgstr "可见性属性在此配置下不受支持；已忽略"
@@ -27565,473 +27588,479 @@
 msgid "bytecode stream: tag %s is not in the expected range [%s, %s]"
 msgstr "字节码流：标记 %s 不在预期的范围[%s，%s]内"
 
-#: c-family/c-attribs.c:529
+#: c-family/c-attribs.c:524
+#, fuzzy, gcc-internal-format
+#| msgid "%qE attribute ignored for %qE"
+msgid "%qE attribute ignored for type %qT"
+msgstr "%qE属性为%qE所忽略"
+
+#: c-family/c-attribs.c:536
 #, gcc-internal-format
 msgid "%qE attribute ignored for field of type %qT"
 msgstr "%qE属性为类型为%qT的字段所忽略"
 
-#: c-family/c-attribs.c:696
+#: c-family/c-attribs.c:706
 #, fuzzy, gcc-internal-format
 #| msgid "visibility argument not a string"
 msgid "no_sanitize argument not a string"
 msgstr "visibility 的实参不是一个字符串"
 
-#: c-family/c-attribs.c:826 ada/gcc-interface/utils.c:6235
+#: c-family/c-attribs.c:837 ada/gcc-interface/utils.c:6240
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute ignored due to conflict with attribute %qs"
 msgstr "%qE属性与 %s 属性冲突"
 
-#: c-family/c-attribs.c:875
+#: c-family/c-attribs.c:886
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute ignored. Use -fcf-protection option to enable it"
 msgstr "%qE属性与 %s 属性冲突"
 
-#: c-family/c-attribs.c:914 c-family/c-attribs.c:920 c-family/c-attribs.c:3388
-#: c-family/c-attribs.c:3423 c-family/c-attribs.c:3429
+#: c-family/c-attribs.c:925 c-family/c-attribs.c:931 c-family/c-attribs.c:3399
+#: c-family/c-attribs.c:3434 c-family/c-attribs.c:3440
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute ignored due to conflict with %qs attribute"
 msgstr "%qE属性与 %s 属性冲突"
 
-#: c-family/c-attribs.c:976 brig/brig-lang.c:482 lto/lto-lang.c:288
+#: c-family/c-attribs.c:987 brig/brig-lang.c:482 lto/lto-lang.c:288
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute has no effect on unit local functions"
 msgstr "%qE属性只能用于函数"
 
-#: c-family/c-attribs.c:1130
+#: c-family/c-attribs.c:1141
 #, gcc-internal-format
 msgid "%qE attribute have effect only on public objects"
 msgstr "%qE属性只能应用到公共对象上"
 
-#: c-family/c-attribs.c:1159
+#: c-family/c-attribs.c:1170
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only affects top level objects"
 msgstr "属性%qE只能用于变量"
 
-#: c-family/c-attribs.c:1198 c-family/c-attribs.c:2682
+#: c-family/c-attribs.c:1209 c-family/c-attribs.c:2693
 #, fuzzy, gcc-internal-format
 #| msgid "using result of function returning %<void%>"
 msgid "%qE attribute on function returning %<void%>"
 msgstr "使用返回%<void%>的函数的结果"
 
-#: c-family/c-attribs.c:1221 c-family/c-pragma.c:419
+#: c-family/c-attribs.c:1232 c-family/c-pragma.c:419
 #, gcc-internal-format
 msgid "scalar_storage_order is not supported because endianness is not uniform"
 msgstr ""
 
-#: c-family/c-attribs.c:1238
+#: c-family/c-attribs.c:1249
 #, gcc-internal-format
 msgid "scalar_storage_order argument must be one of \"big-endian\" or \"little-endian\""
 msgstr ""
 
-#: c-family/c-attribs.c:1334
+#: c-family/c-attribs.c:1345
 #, gcc-internal-format
 msgid "destructor priorities are not supported"
 msgstr "不支持析构函数优先级"
 
-#: c-family/c-attribs.c:1336
+#: c-family/c-attribs.c:1347
 #, gcc-internal-format
 msgid "constructor priorities are not supported"
 msgstr "不支持构造函数优先级"
 
-#: c-family/c-attribs.c:1358
+#: c-family/c-attribs.c:1369
 #, gcc-internal-format, gfc-internal-format
 msgid "destructor priorities from 0 to %d are reserved for the implementation"
 msgstr "析构函数优先级 0 到 %d 为实现所保留"
 
-#: c-family/c-attribs.c:1363
+#: c-family/c-attribs.c:1374
 #, gcc-internal-format, gfc-internal-format
 msgid "constructor priorities from 0 to %d are reserved for the implementation"
 msgstr "构造函数优先级 0 到 %d 为实现所保留"
 
-#: c-family/c-attribs.c:1371
+#: c-family/c-attribs.c:1382
 #, gcc-internal-format, gfc-internal-format
 msgid "destructor priorities must be integers from 0 to %d inclusive"
 msgstr "析构函数优先级必须为 0 到 %d 间的整数"
 
-#: c-family/c-attribs.c:1374
+#: c-family/c-attribs.c:1385
 #, gcc-internal-format, gfc-internal-format
 msgid "constructor priorities must be integers from 0 to %d inclusive"
 msgstr "构造函数优先级必须为 0 到 %d 间的整数"
 
-#: c-family/c-attribs.c:1527
+#: c-family/c-attribs.c:1538
 #, gcc-internal-format
 msgid "unknown machine mode %qE"
 msgstr "未知的机器模式%qE"
 
-#: c-family/c-attribs.c:1557
+#: c-family/c-attribs.c:1568
 #, gcc-internal-format
 msgid "specifying vector types with __attribute__ ((mode)) is deprecated"
 msgstr "已弃用在指定向量类型时使用 __attribute__ ((mode))"
 
-#: c-family/c-attribs.c:1560
+#: c-family/c-attribs.c:1571
 #, gcc-internal-format
 msgid "use __attribute__ ((vector_size)) instead"
 msgstr "改用 __attribute__ ((vector_size))"
 
-#: c-family/c-attribs.c:1569
+#: c-family/c-attribs.c:1580
 #, gcc-internal-format
 msgid "unable to emulate %qs"
 msgstr "无法枚举%qs"
 
-#: c-family/c-attribs.c:1582
+#: c-family/c-attribs.c:1593
 #, gcc-internal-format
 msgid "invalid pointer mode %qs"
 msgstr "无效的指针模式%qs"
 
-#: c-family/c-attribs.c:1599
+#: c-family/c-attribs.c:1610
 #, gcc-internal-format
 msgid "signedness of type and machine mode %qs don%'t match"
 msgstr "类型的符号与机器模式%qs不匹配"
 
-#: c-family/c-attribs.c:1610
+#: c-family/c-attribs.c:1621
 #, gcc-internal-format
 msgid "no data type for mode %qs"
 msgstr "没有模式为%qs的数据类型"
 
-#: c-family/c-attribs.c:1620
+#: c-family/c-attribs.c:1631
 #, gcc-internal-format
 msgid "cannot use mode %qs for enumeral types"
 msgstr "无法为枚举类型使用模式%qs"
 
-#: c-family/c-attribs.c:1647
+#: c-family/c-attribs.c:1658
 #, gcc-internal-format
 msgid "mode %qs applied to inappropriate type"
 msgstr "对不合适的类型应用模式%qs"
 
-#: c-family/c-attribs.c:1669
+#: c-family/c-attribs.c:1680
 #, gcc-internal-format
 msgid "section attributes are not supported for this target"
 msgstr "此目标机不支持节属性"
 
-#: c-family/c-attribs.c:1675
+#: c-family/c-attribs.c:1686
 #, gcc-internal-format
 msgid "section attribute not allowed for %q+D"
 msgstr "%q+D不能有 section 属性"
 
-#: c-family/c-attribs.c:1681
+#: c-family/c-attribs.c:1692
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute argument not a string constant"
 msgid "section attribute argument not a string constant"
 msgstr "%qE属性需要一个字符串常量作为实参"
 
-#: c-family/c-attribs.c:1690
+#: c-family/c-attribs.c:1701
 #, gcc-internal-format
 msgid "section attribute cannot be specified for local variables"
 msgstr "不能为局部变量指定节属性"
 
-#: c-family/c-attribs.c:1700 config/bfin/bfin.c:4806 config/bfin/bfin.c:4857
+#: c-family/c-attribs.c:1711 config/bfin/bfin.c:4806 config/bfin/bfin.c:4857
 #: config/bfin/bfin.c:4883 config/bfin/bfin.c:4896
 #, gcc-internal-format
 msgid "section of %q+D conflicts with previous declaration"
 msgstr "%q+D的节与早先的声明冲突"
 
-#: c-family/c-attribs.c:1708
+#: c-family/c-attribs.c:1719
 #, gcc-internal-format
 msgid "section of %q+D cannot be overridden"
 msgstr "节%q+D无法被重载"
 
-#: c-family/c-attribs.c:1773
+#: c-family/c-attribs.c:1784
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "requested alignment %d is larger than %d"
 msgstr "%q+D的大小超过 %wd 字节"
 
-#: c-family/c-attribs.c:1866
+#: c-family/c-attribs.c:1877
 #, gcc-internal-format
 msgid "alignment may not be specified for %q+D"
 msgstr "不能为%q+D指定对齐"
 
-#: c-family/c-attribs.c:1886
+#: c-family/c-attribs.c:1897
 #, fuzzy, gcc-internal-format
 msgid "ignoring attribute %<%E (%u)%> because it conflicts with attribute %<%E (%u)%>"
 msgstr "%s 属性与 %s 属性在%L处冲突"
 
 #. Do not error out for attribute warn_if_not_aligned.
-#: c-family/c-attribs.c:1891 c-family/c-attribs.c:1920
+#: c-family/c-attribs.c:1902 c-family/c-attribs.c:1931
 #, gcc-internal-format
 msgid "alignment for %q+D must be at least %d"
 msgstr "%q+D的对齐边界必须至少为 %d"
 
-#: c-family/c-attribs.c:1916
+#: c-family/c-attribs.c:1927
 #, gcc-internal-format
 msgid "alignment for %q+D was previously specified as %d and may not be decreased"
 msgstr "%q+D的对齐边界先前被指定为 %d 而不能被减小"
 
-#: c-family/c-attribs.c:1943
+#: c-family/c-attribs.c:1954
 #, fuzzy, gcc-internal-format
 #| msgid "alignment may not be specified for %q+D"
 msgid "%<warn_if_not_aligned%> may not be specified for %q+D"
 msgstr "不能为%q+D指定对齐"
 
-#: c-family/c-attribs.c:1986
+#: c-family/c-attribs.c:1997
 #, fuzzy, gcc-internal-format
 msgid "inline function %q+D declared weak"
 msgstr "内联函数%q+D声明过但从未定义"
 
-#: c-family/c-attribs.c:1991
+#: c-family/c-attribs.c:2002
 #, fuzzy, gcc-internal-format
 msgid "indirect function %q+D cannot be declared weak"
 msgstr "内联函数%q+D不能声明为有弱链接"
 
-#: c-family/c-attribs.c:2015
+#: c-family/c-attribs.c:2026
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to functions"
 msgid "%qE attribute is only applicable on functions"
 msgstr "%qE属性只能用于函数"
 
-#: c-family/c-attribs.c:2046
+#: c-family/c-attribs.c:2057
 #, fuzzy, gcc-internal-format
 msgid "%q+D defined both normally and as %qE attribute"
 msgstr "%q+D既有正常定义又有别名定义"
 
-#: c-family/c-attribs.c:2054
+#: c-family/c-attribs.c:2065
 #, fuzzy, gcc-internal-format
 msgid "weak %q+D cannot be defined %qE"
 msgstr "聚合%q#D类型不完全，无法被定义"
 
-#: c-family/c-attribs.c:2071 c-family/c-attribs.c:2582
+#: c-family/c-attribs.c:2082 c-family/c-attribs.c:2593
 #, fuzzy, gcc-internal-format
 msgid "attribute %qE argument not a string"
 msgstr "%qE属性需要一个字符串常量作为实参"
 
-#: c-family/c-attribs.c:2106
+#: c-family/c-attribs.c:2117
 #, fuzzy, gcc-internal-format
 msgid "%+qD declared alias after being used"
 msgstr "%q+D声明为友元"
 
-#: c-family/c-attribs.c:2108
+#: c-family/c-attribs.c:2119
 #, fuzzy, gcc-internal-format
 msgid "%+qD declared ifunc after being used"
 msgstr "%q+D声明为友元"
 
-#: c-family/c-attribs.c:2159
+#: c-family/c-attribs.c:2170
 #, gcc-internal-format
 msgid "indirect function %q+D cannot be declared weakref"
 msgstr "内联函数%q+D不能声明为有弱链接"
 
-#: c-family/c-attribs.c:2181
+#: c-family/c-attribs.c:2192
 #, gcc-internal-format
 msgid "weakref attribute must appear before alias attribute"
 msgstr "weakref 属性必须出现在 alias 属性前"
 
-#: c-family/c-attribs.c:2193
+#: c-family/c-attribs.c:2204
 #, fuzzy, gcc-internal-format
 msgid "%+qD declared weakref after being used"
 msgstr "%q+D声明为友元"
 
-#: c-family/c-attribs.c:2217
+#: c-family/c-attribs.c:2228
 #, gcc-internal-format
 msgid "%qE attribute ignored on non-class types"
 msgstr "%qE属性在不是类的类型上被忽略"
 
-#: c-family/c-attribs.c:2223
+#: c-family/c-attribs.c:2234
 #, gcc-internal-format
 msgid "%qE attribute ignored because %qT is already defined"
 msgstr "%qE属性被忽略，因为%qT已被定义"
 
-#: c-family/c-attribs.c:2236
+#: c-family/c-attribs.c:2247
 #, gcc-internal-format
 msgid "visibility argument not a string"
 msgstr "visibility 的实参不是一个字符串"
 
-#: c-family/c-attribs.c:2248
+#: c-family/c-attribs.c:2259
 #, gcc-internal-format
 msgid "%qE attribute ignored on types"
 msgstr "%qE属性在类型上被忽略"
 
-#: c-family/c-attribs.c:2264
+#: c-family/c-attribs.c:2275
 #, gcc-internal-format
 msgid "visibility argument must be one of \"default\", \"hidden\", \"protected\" or \"internal\""
 msgstr "visibility  的实参必须是“default”、“hidden”、“protected”或“internal”其中之一"
 
-#: c-family/c-attribs.c:2275
+#: c-family/c-attribs.c:2286
 #, gcc-internal-format
 msgid "%qD redeclared with different visibility"
 msgstr "%qD重声明时有不同的可见性"
 
-#: c-family/c-attribs.c:2278 c-family/c-attribs.c:2282
+#: c-family/c-attribs.c:2289 c-family/c-attribs.c:2293
 #, gcc-internal-format
 msgid "%qD was declared %qs which implies default visibility"
 msgstr "%qD声明为有默认可见性的%qs"
 
-#: c-family/c-attribs.c:2320
+#: c-family/c-attribs.c:2331
 #, gcc-internal-format
 msgid "tls_model argument not a string"
 msgstr "tls_model 的实参不是一个字符串"
 
-#: c-family/c-attribs.c:2333
+#: c-family/c-attribs.c:2344
 #, gcc-internal-format
 msgid "tls_model argument must be one of \"local-exec\", \"initial-exec\", \"local-dynamic\" or \"global-dynamic\""
 msgstr "tls_model 的实参必须是“local-exec”、“initial-exec”、“local-dynamic”或“global-dynamic”其中之一"
 
-#: c-family/c-attribs.c:2353 c-family/c-attribs.c:2656
-#: c-family/c-attribs.c:3497 config/m32c/m32c.c:2944
+#: c-family/c-attribs.c:2364 c-family/c-attribs.c:2667
+#: c-family/c-attribs.c:3508 config/m32c/m32c.c:2944
 #, gcc-internal-format
 msgid "%qE attribute applies only to functions"
 msgstr "%qE属性只能用于函数"
 
-#: c-family/c-attribs.c:2417
+#: c-family/c-attribs.c:2428
 #, gcc-internal-format
 msgid "alloc_size parameter outside range"
 msgstr "alloc_size 参数越界"
 
-#: c-family/c-attribs.c:2443
+#: c-family/c-attribs.c:2454
 #, fuzzy, gcc-internal-format
 msgid "alloc_align parameter outside range"
 msgstr "alloc_size 参数越界"
 
-#: c-family/c-attribs.c:2467
+#: c-family/c-attribs.c:2478
 #, fuzzy, gcc-internal-format
 msgid "assume_aligned parameter not integer constant"
 msgstr "要求的对齐边界不是常量"
 
-#: c-family/c-attribs.c:2595
+#: c-family/c-attribs.c:2606
 #, gcc-internal-format
 msgid "only %<inbranch%> and %<notinbranch%> flags are allowed for %<__simd__%> attribute"
 msgstr ""
 
-#: c-family/c-attribs.c:2662 c-family/c-attribs.c:3503
+#: c-family/c-attribs.c:2673 c-family/c-attribs.c:3514
 #, gcc-internal-format
 msgid "can%'t set %qE attribute after definition"
 msgstr "定义之后不能设定%qE属性"
 
-#: c-family/c-attribs.c:2727
+#: c-family/c-attribs.c:2738
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute duplicated"
 msgstr "%qE属性为%qE所忽略"
 
-#: c-family/c-attribs.c:2729
+#: c-family/c-attribs.c:2740
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute follows %qE"
 msgstr "%qE属性为%qE所忽略"
 
-#: c-family/c-attribs.c:2828
+#: c-family/c-attribs.c:2839
 #, fuzzy, gcc-internal-format
 msgid "type was previously declared %qE"
 msgstr "以前在此声明过"
 
-#: c-family/c-attribs.c:2841 cp/class.c:4397
+#: c-family/c-attribs.c:2852 cp/class.c:4401
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
 msgstr "只能为函数指定%qs"
 
-#: c-family/c-attribs.c:2899
+#: c-family/c-attribs.c:2910
 #, fuzzy, gcc-internal-format
 msgid "%qE argument not an identifier"
 msgstr "cleanup 实参不是一个标识符"
 
-#: c-family/c-attribs.c:2910
+#: c-family/c-attribs.c:2921
 #, fuzzy, gcc-internal-format
 msgid "%qD is not compatible with %qD"
 msgstr "选择%qD而不是%qD"
 
-#: c-family/c-attribs.c:2913
+#: c-family/c-attribs.c:2924
 #, fuzzy, gcc-internal-format
 msgid "%qE argument is not a function"
 msgstr "属性%qE的参数无效"
 
-#: c-family/c-attribs.c:2961
+#: c-family/c-attribs.c:2972
 #, gcc-internal-format
 msgid "deprecated message is not a string"
 msgstr "过时消息不是一个字符串"
 
-#: c-family/c-attribs.c:3002
+#: c-family/c-attribs.c:3013
 #, gcc-internal-format
 msgid "%qE attribute ignored for %qE"
 msgstr "%qE属性为%qE所忽略"
 
-#: c-family/c-attribs.c:3065
+#: c-family/c-attribs.c:3076
 #, gcc-internal-format
 msgid "invalid vector type for attribute %qE"
 msgstr "属性%qE的向量类型无效"
 
-#: c-family/c-attribs.c:3071 ada/gcc-interface/utils.c:3896
+#: c-family/c-attribs.c:3082 ada/gcc-interface/utils.c:3899
 #, gcc-internal-format
 msgid "vector size not an integral multiple of component size"
 msgstr "向量大小不是组件大小的整数倍"
 
-#: c-family/c-attribs.c:3077 ada/gcc-interface/utils.c:3903
+#: c-family/c-attribs.c:3088 ada/gcc-interface/utils.c:3906
 #, gcc-internal-format
 msgid "zero vector size"
 msgstr "向量大小为 0"
 
-#: c-family/c-attribs.c:3085
+#: c-family/c-attribs.c:3096
 #, gcc-internal-format
 msgid "number of components of the vector not a power of two"
 msgstr "向量中分量数不是 2 的某次方"
 
-#: c-family/c-attribs.c:3118 ada/gcc-interface/utils.c:6092
+#: c-family/c-attribs.c:3129 ada/gcc-interface/utils.c:6098
 #, gcc-internal-format
 msgid "nonnull attribute without arguments on a non-prototype"
 msgstr "非空的属性在非原型中没有实参"
 
-#: c-family/c-attribs.c:3137 ada/gcc-interface/utils.c:6106
+#: c-family/c-attribs.c:3148 ada/gcc-interface/utils.c:6112
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument has invalid operand number (argument %lu)"
 msgstr "非空的实参 %lu 操作数号不对"
 
-#: c-family/c-attribs.c:3159 ada/gcc-interface/utils.c:6128
+#: c-family/c-attribs.c:3170 ada/gcc-interface/utils.c:6134
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument with out-of-range operand number (argument %lu, operand %lu)"
 msgstr "非空的实参操作数号越界(实参 %lu，操作数 %lu)"
 
-#: c-family/c-attribs.c:3168 ada/gcc-interface/utils.c:6137
+#: c-family/c-attribs.c:3179 ada/gcc-interface/utils.c:6143
 #, gcc-internal-format, gfc-internal-format
 msgid "nonnull argument references non-pointer operand (argument %lu, operand %lu)"
 msgstr "非空的实参 %lu 引用了非指针操作数 %lu"
 
-#: c-family/c-attribs.c:3208
+#: c-family/c-attribs.c:3219
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored for field of type %qT"
 msgid "%qE attribute ignored on objects of type %qT"
 msgstr "%qE属性为类型为%qT的字段所忽略"
 
-#: c-family/c-attribs.c:3216
+#: c-family/c-attribs.c:3227
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute does not apply to functions"
 msgstr "不能向类型添加属性%qE"
 
-#: c-family/c-attribs.c:3273
+#: c-family/c-attribs.c:3284
 #, gcc-internal-format
 msgid "cleanup argument not an identifier"
 msgstr "cleanup 实参不是一个标识符"
 
-#: c-family/c-attribs.c:3280
+#: c-family/c-attribs.c:3291
 #, gcc-internal-format
 msgid "cleanup argument not a function"
 msgstr "cleanup 实参不是一个函数"
 
-#: c-family/c-attribs.c:3317
+#: c-family/c-attribs.c:3328
 #, gcc-internal-format
 msgid "%qE attribute requires prototypes with named arguments"
 msgstr "%qE属性需要带有名实参的原型"
 
-#: c-family/c-attribs.c:3325
+#: c-family/c-attribs.c:3336
 #, gcc-internal-format
 msgid "%qE attribute only applies to variadic functions"
 msgstr "%qE属性只能用于带可变参数函数"
 
-#: c-family/c-attribs.c:3341 ada/gcc-interface/utils.c:6179
+#: c-family/c-attribs.c:3352 ada/gcc-interface/utils.c:6185
 #, gcc-internal-format
 msgid "requested position is not an integer constant"
 msgstr "要求的位置不是一个整数常量"
 
-#: c-family/c-attribs.c:3349 ada/gcc-interface/utils.c:6186
+#: c-family/c-attribs.c:3360 ada/gcc-interface/utils.c:6192
 #, gcc-internal-format
 msgid "requested position is less than zero"
 msgstr "要求的位置小于 0"
 
-#: c-family/c-attribs.c:3404
+#: c-family/c-attribs.c:3415
 #, fuzzy, gcc-internal-format
 msgid "empty string in attribute %<target%>"
 msgstr "嵌套函数在此目标机上不受支持"
 
-#: c-family/c-attribs.c:3520
+#: c-family/c-attribs.c:3531
 #, fuzzy, gcc-internal-format
 msgid "returns_nonnull attribute on a function not returning a pointer"
 msgstr "在有返回值的的函数中，%<return%>不带返回值"
 
-#: c-family/c-attribs.c:3535
+#: c-family/c-attribs.c:3546
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is only valid on %<struct%> type"
 msgstr "%qE属性只能用于函数类型"
@@ -28076,13 +28105,13 @@
 msgid "__builtin_shuffle argument vector(s) inner type must have the same size as inner type of the mask"
 msgstr "__builtin_shuffle 参数矢量内类型必须有相同大小作为内类型的遮罩"
 
-#: c-family/c-common.c:1262 c-family/c-warn.c:1194
+#: c-family/c-common.c:1262 c-family/c-warn.c:1202
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT discards qualifiers"
 msgid "unsigned conversion from %qT to %qT changes value from %qE to %qE"
 msgstr "从%qT到%qT的转换丢失了限定信息"
 
-#: c-family/c-common.c:1267 c-family/c-warn.c:1202
+#: c-family/c-common.c:1267 c-family/c-warn.c:1210
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "unsigned conversion from %qT to %qT changes the value of %qE"
@@ -28218,7 +28247,7 @@
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "建议在用作真值的赋值语句前后加上括号"
 
-#: c-family/c-common.c:3518 c/c-decl.c:4325 c/c-decl.c:6430 c/c-typeck.c:14177
+#: c-family/c-common.c:3518 c/c-decl.c:4325 c/c-decl.c:6450 c/c-typeck.c:14182
 #, gcc-internal-format
 msgid "invalid use of %<restrict%>"
 msgstr "错误地使用了%<restrict%>"
@@ -28298,7 +28327,7 @@
 msgid "duplicate case value"
 msgstr "重复的 case 常量"
 
-#: c-family/c-common.c:4867 c-family/c-warn.c:2216
+#: c-family/c-common.c:4867 c-family/c-warn.c:2225
 #, gcc-internal-format
 msgid "previously used here"
 msgstr "已在这里使用过"
@@ -28343,198 +28372,198 @@
 msgid "missing sentinel in function call"
 msgstr "函数调用中缺少哨兵"
 
-#: c-family/c-common.c:5411
+#: c-family/c-common.c:5409
 #, gcc-internal-format, gfc-internal-format
 msgid "null argument where non-null required (argument %lu)"
 msgstr "实参为 NULL，需要非 NULL 值(实参 %lu)"
 
-#: c-family/c-common.c:5506 c-family/c-common.c:5553
+#: c-family/c-common.c:5504 c-family/c-common.c:5551
 #, fuzzy, gcc-internal-format
 #| msgid "bad option %s to pragma attribute"
 msgid "bad option %qs to attribute %<optimize%>"
 msgstr "pragma 属性选项 %s 无效"
 
-#: c-family/c-common.c:5509 c-family/c-common.c:5557
+#: c-family/c-common.c:5507 c-family/c-common.c:5555
 #, fuzzy, gcc-internal-format
 #| msgid "bad option %s to pragma attribute"
 msgid "bad option %qs to pragma %<optimize%>"
 msgstr "pragma 属性选项 %s 无效"
 
-#: c-family/c-common.c:5589
+#: c-family/c-common.c:5587
 #, gcc-internal-format
 msgid "%<fallthrough%> attribute specified multiple times"
 msgstr ""
 
-#: c-family/c-common.c:5593
+#: c-family/c-common.c:5591
 #, fuzzy, gcc-internal-format
 #| msgid "default argument specified for lambda parameter"
 msgid "%<fallthrough%> attribute specified with a parameter"
 msgstr "为 lambda 形参指定了默认参数"
 
-#: c-family/c-common.c:5733 c-family/c-common.c:6485 c-family/c-common.c:6558
+#: c-family/c-common.c:5731 c-family/c-common.c:6477 c-family/c-common.c:6550
 #: c/c-typeck.c:3555
 #, gcc-internal-format
 msgid "too few arguments to function %qE"
 msgstr "提供给函数%qE的实参太少"
 
-#: c-family/c-common.c:5738 c-family/c-common.c:6584 c/c-typeck.c:3284
+#: c-family/c-common.c:5736 c-family/c-common.c:6576 c/c-typeck.c:3284
 #, gcc-internal-format
 msgid "too many arguments to function %qE"
 msgstr "提供给函数%qE的实参太多"
 
-#: c-family/c-common.c:5769
+#: c-family/c-common.c:5767
 #, fuzzy, gcc-internal-format
 #| msgid "third argument to %<__builtin_prefetch%> must be a constant"
 msgid "third argument to function %qE must be a constant integer"
 msgstr "%<__builtin_prefetch%>的第三个实参必须是一个常量"
 
-#: c-family/c-common.c:5794
+#: c-family/c-common.c:5792
 #, gcc-internal-format
 msgid "second argument to function %qE must be a constant integer power of 2 between %qi and %qu bits"
 msgstr ""
 
-#: c-family/c-common.c:5815 c-family/c-common.c:5859
+#: c-family/c-common.c:5813 c-family/c-common.c:5857
 #, gcc-internal-format
 msgid "non-floating-point argument in call to function %qE"
 msgstr "给予函数%qE的参数不是浮点数"
 
-#: c-family/c-common.c:5838
+#: c-family/c-common.c:5836
 #, gcc-internal-format
 msgid "non-floating-point arguments in call to function %qE"
 msgstr "给予函数%qE的参数不是浮点数"
 
-#: c-family/c-common.c:5852
+#: c-family/c-common.c:5850
 #, gcc-internal-format
 msgid "non-const integer argument %u in call to function %qE"
 msgstr "给予函数%2$qE的参数%1$u不是整型常量"
 
-#: c-family/c-common.c:5872
+#: c-family/c-common.c:5870
 #, fuzzy, gcc-internal-format
 msgid "non-integer argument 3 in call to function %qE"
 msgstr "给予函数%2$qE的参数%1$u不是整型常量"
 
-#: c-family/c-common.c:5889 c-family/c-common.c:5925
+#: c-family/c-common.c:5887 c-family/c-common.c:5923
 #, fuzzy, gcc-internal-format
 msgid "argument %u in call to function %qE does not have integral type"
 msgstr "数组 new 的大小必须有整数类型"
 
-#: c-family/c-common.c:5896
+#: c-family/c-common.c:5894
 #, fuzzy, gcc-internal-format
 msgid "argument 3 in call to function %qE does not have pointer to integral type"
 msgstr "%K%D 的第一个实参必须是一个指针，第二个必须是整常量"
 
-#: c-family/c-common.c:5902
+#: c-family/c-common.c:5900
 #, fuzzy, gcc-internal-format
 msgid "argument 3 in call to function %qE has pointer to enumerated type"
 msgstr "%K%D 的第一个实参必须是一个指针，第二个必须是整常量"
 
-#: c-family/c-common.c:5908
+#: c-family/c-common.c:5906
 #, fuzzy, gcc-internal-format
 msgid "argument 3 in call to function %qE has pointer to boolean type"
 msgstr "%K%D 的第一个实参必须是一个指针，第二个必须是整常量"
 
-#: c-family/c-common.c:5931
+#: c-family/c-common.c:5929
 #, fuzzy, gcc-internal-format
 msgid "argument 3 in call to function %qE has enumerated type"
 msgstr "数组 new 的大小必须有整数类型"
 
-#: c-family/c-common.c:5937
+#: c-family/c-common.c:5935
 #, fuzzy, gcc-internal-format
 msgid "argument 3 in call to function %qE has boolean type"
 msgstr "数组 new 的大小必须有整数类型"
 
-#: c-family/c-common.c:6184
+#: c-family/c-common.c:6183
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to static data member %qD"
 msgstr "不能对静态数据成员%qD取%<offsetof%>"
 
-#: c-family/c-common.c:6189
+#: c-family/c-common.c:6188
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> when %<operator[]%> is overloaded"
 msgstr "%<operator[]%>重载后便不能使用%<offsetof%>"
 
-#: c-family/c-common.c:6196
+#: c-family/c-common.c:6195
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to a non constant address"
 msgstr "不能为非常量地址应用%<offsetof%>"
 
-#: c-family/c-common.c:6209
+#: c-family/c-common.c:6208
 #, gcc-internal-format
 msgid "attempt to take address of bit-field structure member %qD"
 msgstr "试图取位段结构成员%qD的地址"
 
-#: c-family/c-common.c:6261
+#: c-family/c-common.c:6260
 #, gcc-internal-format
 msgid "index %E denotes an offset greater than size of %qT"
 msgstr "索引 %E 指定了一个大于%qT大小的偏移量"
 
-#: c-family/c-common.c:6427 cp/init.c:3004 cp/init.c:3023
+#: c-family/c-common.c:6419 cp/init.c:3020 cp/init.c:3039
 #, gcc-internal-format
 msgid "size of array is too large"
 msgstr "数组太大"
 
-#: c-family/c-common.c:6517
+#: c-family/c-common.c:6509
 #, fuzzy, gcc-internal-format
 #| msgid "incompatible type for argument %d of %qE"
 msgid "operand type %qT is incompatible with argument %d of %qE"
 msgstr "%2$qE的第 %1$d 个实参类型不兼容"
 
-#: c-family/c-common.c:6651
+#: c-family/c-common.c:6643
 #, fuzzy, gcc-internal-format
 msgid "incorrect number of arguments to function %qE"
 msgstr "提供给函数%qE的实参太多"
 
-#: c-family/c-common.c:6665
+#: c-family/c-common.c:6657
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qE must be a non-void pointer type"
 msgstr "%2$qE的实参 %1$d 必须是地址"
 
-#: c-family/c-common.c:6674
+#: c-family/c-common.c:6666
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a constant size type"
 msgstr "%K%D 的第一个实参必须是一个指针，第二个必须是整常量"
 
-#: c-family/c-common.c:6685
+#: c-family/c-common.c:6677
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qE must be a pointer to a nonzero size object"
 msgstr "%K%D 的第一个实参必须是一个指针，第二个必须是整常量"
 
-#: c-family/c-common.c:6706
+#: c-family/c-common.c:6698
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must be a pointer type"
 msgstr "%2$qE的实参 %1$d 必须是地址"
 
-#: c-family/c-common.c:6714
+#: c-family/c-common.c:6706
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must be a pointer to a constant size type"
 msgstr "%K%D 的第一个实参必须是一个指针，第二个必须是整常量"
 
-#: c-family/c-common.c:6720
+#: c-family/c-common.c:6712
 #, fuzzy, gcc-internal-format
 msgid "argument %d of %qE must not be a pointer to a function"
 msgstr "%2$qE的实参 %1$d 必须是地址"
 
-#: c-family/c-common.c:6728
+#: c-family/c-common.c:6720
 #, fuzzy, gcc-internal-format
 msgid "size mismatch in argument %d of %qE"
 msgstr "%2$qE的第 %1$d 个参数必须是在 %3$d 和 %4$d 之间"
 
-#: c-family/c-common.c:6740
+#: c-family/c-common.c:6732
 #, fuzzy, gcc-internal-format
 msgid "non-integer memory model argument %d of %qE"
 msgstr "%2$qE的第 %1$d 个实参类型不兼容"
 
-#: c-family/c-common.c:6753
+#: c-family/c-common.c:6745
 #, fuzzy, gcc-internal-format
 msgid "invalid memory model argument %d of %qE"
 msgstr "%2$qE的第 %1$d 个实参类型不兼容"
 
-#: c-family/c-common.c:7672
+#: c-family/c-common.c:7664
 #, gcc-internal-format
 msgid "index value is out of bound"
 msgstr "索引值越界"
 
-#: c-family/c-common.c:7714 c-family/c-common.c:7763 c-family/c-common.c:7779
+#: c-family/c-common.c:7706 c-family/c-common.c:7755 c-family/c-common.c:7771
 #, fuzzy, gcc-internal-format
 msgid "conversion of scalar %qT to vector %qT involves truncation"
 msgstr "从%qT到%qT的转换有歧义"
@@ -28541,23 +28570,23 @@
 
 #. Reject arguments that are built-in functions with
 #. no library fallback.
-#: c-family/c-common.c:7867
+#: c-family/c-common.c:7859
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %qD takes one argument only"
 msgid "built-in function %qE must be directly called"
 msgstr "内建函数%qD只需要一个实参"
 
-#: c-family/c-common.c:7889 c/c-decl.c:6177
+#: c-family/c-common.c:7881 c/c-decl.c:6197
 #, gcc-internal-format
 msgid "size of array %qE is too large"
 msgstr "数组%qE太大"
 
-#: c-family/c-common.c:7891 c/c-decl.c:6180
+#: c-family/c-common.c:7883 c/c-decl.c:6200
 #, gcc-internal-format
 msgid "size of unnamed array is too large"
 msgstr "无名数组太大"
 
-#: c-family/c-common.c:7921
+#: c-family/c-common.c:7913
 #, gcc-internal-format
 msgid "environment variable SOURCE_DATE_EPOCH must expand to a non-negative integer less than or equal to %wd"
 msgstr ""
@@ -29085,7 +29114,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr "%<# pragma omp 基元的 capture%>使用两不同的变量用于内存"
 
-#: c-family/c-omp.c:557 cp/semantics.c:8186
+#: c-family/c-omp.c:557 cp/semantics.c:8189
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "迭代变量%qE类型无效"
@@ -29101,22 +29130,22 @@
 msgid "%qE is not initialized"
 msgstr "%qE未经初始化"
 
-#: c-family/c-omp.c:599 cp/semantics.c:8076
+#: c-family/c-omp.c:599 cp/semantics.c:8079
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "缺少控制谓词"
 
-#: c-family/c-omp.c:704 cp/semantics.c:7732
+#: c-family/c-omp.c:704 cp/semantics.c:7735
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "无效的控制谓词"
 
-#: c-family/c-omp.c:711 cp/semantics.c:8082
+#: c-family/c-omp.c:711 cp/semantics.c:8085
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "缺少自增语句"
 
-#: c-family/c-omp.c:775 cp/semantics.c:7847
+#: c-family/c-omp.c:775 cp/semantics.c:7850
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "无效的自增语句"
@@ -29174,112 +29203,127 @@
 msgid "%<-Wabi=1%> is not supported, using =2"
 msgstr "%<-Wabi=1%> 不受支持，将使用 =2"
 
-#: c-family/c-opts.c:612 fortran/cpp.c:350
+#: c-family/c-opts.c:610 fortran/cpp.c:350
 #, gcc-internal-format
 msgid "output filename specified twice"
 msgstr "输出文件名指定了两次"
 
-#: c-family/c-opts.c:799
+#: c-family/c-opts.c:797
 #, gcc-internal-format
 msgid "-fexcess-precision=standard for C++"
 msgstr "对 C++ 而言 -fexcess-precision=standard"
 
-#: c-family/c-opts.c:834
+#: c-family/c-opts.c:832
 #, gcc-internal-format
 msgid "-fno-gnu89-inline is only supported in GNU99 or C99 mode"
 msgstr "-fno-gnu89-inline 仅在 GNU99 或 C99 模式下支持"
 
-#: c-family/c-opts.c:880
+#: c-family/c-opts.c:878
 #, gcc-internal-format
 msgid "-Wformat-y2k ignored without -Wformat"
 msgstr "-Wformat-y2k 未与 -Wformat 一起使用，已忽略"
 
-#: c-family/c-opts.c:882
+#: c-family/c-opts.c:880
 #, gcc-internal-format
 msgid "-Wformat-extra-args ignored without -Wformat"
 msgstr "-Wformat-extra-args 未与 -Wformat 一起使用，已忽略"
 
-#: c-family/c-opts.c:884
+#: c-family/c-opts.c:882
 #, gcc-internal-format
 msgid "-Wformat-zero-length ignored without -Wformat"
 msgstr "-Wformat-zero-length 未与 -Wformat 一起使用，已忽略"
 
-#: c-family/c-opts.c:886
+#: c-family/c-opts.c:884
 #, gcc-internal-format
 msgid "-Wformat-nonliteral ignored without -Wformat"
 msgstr "-Wformat-nonliteral 未与 -Wformat 一起使用，已忽略"
 
-#: c-family/c-opts.c:888
+#: c-family/c-opts.c:886
 #, gcc-internal-format
 msgid "-Wformat-contains-nul ignored without -Wformat"
 msgstr "-Wformat-contains-nul 未与 -Wformat 一起使用，已忽略"
 
-#: c-family/c-opts.c:890
+#: c-family/c-opts.c:888
 #, gcc-internal-format
 msgid "-Wformat-security ignored without -Wformat"
 msgstr "-Wformat-security 未与 -Wformat 一起使用，已忽略"
 
-#: c-family/c-opts.c:928
+#: c-family/c-opts.c:918
 #, fuzzy, gcc-internal-format
 msgid "%<-fabi-compat-version=1%> is not supported, using =2"
 msgstr "不支持 -falign-loops=%d"
 
-#: c-family/c-opts.c:988
+#: c-family/c-opts.c:944
+#, gcc-internal-format
+msgid "-Wabi won't warn about anything"
+msgstr ""
+
+#: c-family/c-opts.c:946
+#, gcc-internal-format
+msgid "-Wabi warns about differences from the most up-to-date ABI, which is also used by default"
+msgstr ""
+
+#: c-family/c-opts.c:949
+#, gcc-internal-format
+msgid "use e.g. -Wabi=11 to warn about changes from GCC 7"
+msgstr ""
+
+#: c-family/c-opts.c:1003
 #, fuzzy, gcc-internal-format
 msgid "external TLS initialization functions not supported on this target"
 msgstr "嵌套函数在此目标机上不受支持"
 
-#: c-family/c-opts.c:1001
+#: c-family/c-opts.c:1016
 #, gcc-internal-format, gfc-internal-format
 msgid "too many filenames given.  Type %s --help for usage"
 msgstr "给定了太多文件名。试用 %s --help 以了解用法"
 
-#: c-family/c-opts.c:1016
+#: c-family/c-opts.c:1031
 #, gcc-internal-format
 msgid "opening output file %s: %m"
 msgstr "打开输出文件 %s：%m"
 
-#: c-family/c-opts.c:1036
+#: c-family/c-opts.c:1051
 #, gcc-internal-format, gfc-internal-format
 msgid "the \"%s\" debug format cannot be used with pre-compiled headers"
 msgstr ""
 
-#: c-family/c-opts.c:1190
+#: c-family/c-opts.c:1205
 #, gcc-internal-format
 msgid "opening dependency file %s: %m"
 msgstr "打开依赖文件 %s：%m"
 
-#: c-family/c-opts.c:1201
+#: c-family/c-opts.c:1216
 #, gcc-internal-format
 msgid "closing dependency file %s: %m"
 msgstr "关闭依赖文件 %s：%m"
 
-#: c-family/c-opts.c:1204
+#: c-family/c-opts.c:1219
 #, gcc-internal-format
 msgid "when writing output to %s: %m"
 msgstr "当写入输出到 %s 时：%m"
 
-#: c-family/c-opts.c:1284
+#: c-family/c-opts.c:1299
 #, gcc-internal-format
 msgid "to generate dependencies you must specify either -M or -MM"
 msgstr "要生成依赖项，您必须指定 -M 或 -MM"
 
-#: c-family/c-opts.c:1307
+#: c-family/c-opts.c:1322
 #, gcc-internal-format
 msgid "-MG may only be used with -M or -MM"
 msgstr "-MG 只能与 -M 或 -MM 一起使用"
 
-#: c-family/c-opts.c:1340
+#: c-family/c-opts.c:1355
 #, gcc-internal-format
 msgid "-fdirectives-only is incompatible with -Wunused_macros"
 msgstr "-fdirectives-only 与 -Wunused_macros 不兼容"
 
-#: c-family/c-opts.c:1342
+#: c-family/c-opts.c:1357
 #, gcc-internal-format
 msgid "-fdirectives-only is incompatible with -traditional"
 msgstr "-fdirectives-only 与 -traditional 不兼容"
 
-#: c-family/c-opts.c:1534
+#: c-family/c-opts.c:1549
 #, gcc-internal-format
 msgid "too late for # directive to set debug directory"
 msgstr "使用 # 指示设定调试目录太迟"
@@ -29665,752 +29709,752 @@
 msgid "wrong type argument to %s"
 msgstr "不能对该类型的参数求绝对值"
 
-#: c-family/c-warn.c:53 c-family/c-warn.c:66 cp/constexpr.c:1847
+#: c-family/c-warn.c:54 c-family/c-warn.c:67 cp/constexpr.c:1847
 #: cp/constexpr.c:4099
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "常量表达式溢出"
 
-#: c-family/c-warn.c:93
+#: c-family/c-warn.c:94
 #, fuzzy, gcc-internal-format
 #| msgid "integer overflow in expression"
 msgid "integer overflow in expression %qE of type %qT results in %qE"
 msgstr "整数溢出"
 
-#: c-family/c-warn.c:95
+#: c-family/c-warn.c:96
 #, fuzzy, gcc-internal-format
 #| msgid "integer overflow in expression"
 msgid "integer overflow in expression of type %qT results in %qE"
 msgstr "整数溢出"
 
-#: c-family/c-warn.c:101
+#: c-family/c-warn.c:102
 #, fuzzy, gcc-internal-format
 #| msgid "floating point overflow in expression"
 msgid "floating point overflow in expression %qE of type %qT results in %qE"
 msgstr "表达式中浮点溢出"
 
-#: c-family/c-warn.c:103
+#: c-family/c-warn.c:104
 #, fuzzy, gcc-internal-format
 #| msgid "floating point overflow in expression"
 msgid "floating point overflow in expression of type %qT results in %qE"
 msgstr "表达式中浮点溢出"
 
-#: c-family/c-warn.c:109
+#: c-family/c-warn.c:110
 #, fuzzy, gcc-internal-format
 #| msgid "fixed-point overflow in expression"
 msgid "fixed-point overflow in expression %qE of type %qT results in %qE"
 msgstr "表达式中定点溢出"
 
-#: c-family/c-warn.c:111
+#: c-family/c-warn.c:112
 #, fuzzy, gcc-internal-format
 #| msgid "fixed-point overflow in expression"
 msgid "fixed-point overflow in expression of type %qT results in %qE"
 msgstr "表达式中定点溢出"
 
-#: c-family/c-warn.c:117
+#: c-family/c-warn.c:118
 #, fuzzy, gcc-internal-format
 #| msgid "vector overflow in expression"
 msgid "vector overflow in expression %qE of type %qT results in %qE"
 msgstr "向量浮点溢出"
 
-#: c-family/c-warn.c:119
+#: c-family/c-warn.c:120
 #, fuzzy, gcc-internal-format
 #| msgid "vector overflow in expression"
 msgid "vector overflow in expression of type %qT results in %qE"
 msgstr "向量浮点溢出"
 
-#: c-family/c-warn.c:126
+#: c-family/c-warn.c:127
 #, fuzzy, gcc-internal-format
 #| msgid "complex integer overflow in expression"
 msgid "complex integer overflow in expression %qE of type %qT results in %qE"
 msgstr "表达式中整复数溢出"
 
-#: c-family/c-warn.c:128
+#: c-family/c-warn.c:129
 #, fuzzy, gcc-internal-format
 #| msgid "complex integer overflow in expression"
 msgid "complex integer overflow in expression of type %qT results in %qE"
 msgstr "表达式中整复数溢出"
 
-#: c-family/c-warn.c:132
+#: c-family/c-warn.c:133
 #, fuzzy, gcc-internal-format
 #| msgid "complex floating point overflow in expression"
 msgid "complex floating point overflow in expression %qE of type %qT results in %qE"
 msgstr "表达式中浮点复数溢出"
 
-#: c-family/c-warn.c:134
+#: c-family/c-warn.c:135
 #, fuzzy, gcc-internal-format
 #| msgid "complex floating point overflow in expression"
 msgid "complex floating point overflow in expression of type %qT results in %qE"
 msgstr "表达式中浮点复数溢出"
 
-#: c-family/c-warn.c:216
+#: c-family/c-warn.c:217
 #, gcc-internal-format
 msgid "logical %<or%> applied to non-boolean constant"
 msgstr "逻辑%<or%>被用在非布尔型常量上"
 
-#: c-family/c-warn.c:219
+#: c-family/c-warn.c:220
 #, gcc-internal-format
 msgid "logical %<and%> applied to non-boolean constant"
 msgstr "逻辑%<and%>被用在非布尔型常量上"
 
-#: c-family/c-warn.c:289
+#: c-family/c-warn.c:290
 #, gcc-internal-format
 msgid "logical %<or%> of collectively exhaustive tests is always true"
 msgstr "对两个互补的测试取逻辑%<or%>的结果永远为真"
 
-#: c-family/c-warn.c:293
+#: c-family/c-warn.c:294
 #, gcc-internal-format
 msgid "logical %<and%> of mutually exclusive tests is always false"
 msgstr "对两个互斥的测试取逻辑%<and%>的结果永远为假"
 
-#: c-family/c-warn.c:303
+#: c-family/c-warn.c:304
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand in unary expression"
 msgid "logical %<or%> of equal expressions"
 msgstr "单目表达式中操作数无效"
 
-#: c-family/c-warn.c:306
+#: c-family/c-warn.c:307
 #, fuzzy, gcc-internal-format
 #| msgid "logical %<and%> of mutually exclusive tests is always false"
 msgid "logical %<and%> of equal expressions"
 msgstr "对两个互斥的测试取逻辑%<and%>的结果永远为假"
 
-#: c-family/c-warn.c:384
+#: c-family/c-warn.c:385
 #, fuzzy, gcc-internal-format
 #| msgid "user-defined %qD always evaluates both arguments"
 msgid "bitwise comparison always evaluates to false"
 msgstr "用户定义的%qD总是计算所有两个参数"
 
-#: c-family/c-warn.c:387
+#: c-family/c-warn.c:388
 #, fuzzy, gcc-internal-format
 #| msgid "user-defined %qD always evaluates both arguments"
 msgid "bitwise comparison always evaluates to true"
 msgstr "用户定义的%qD总是计算所有两个参数"
 
-#: c-family/c-warn.c:441
+#: c-family/c-warn.c:442
 #, fuzzy, gcc-internal-format
 #| msgid "user-defined %qD always evaluates both arguments"
 msgid "self-comparison always evaluates to true"
 msgstr "用户定义的%qD总是计算所有两个参数"
 
-#: c-family/c-warn.c:444
+#: c-family/c-warn.c:445
 #, fuzzy, gcc-internal-format
 #| msgid "user-defined %qD always evaluates both arguments"
 msgid "self-comparison always evaluates to false"
 msgstr "用户定义的%qD总是计算所有两个参数"
 
-#: c-family/c-warn.c:494
+#: c-family/c-warn.c:495
 #, gcc-internal-format
 msgid "logical not is only applied to the left hand side of comparison"
 msgstr ""
 
-#: c-family/c-warn.c:502
+#: c-family/c-warn.c:503
 #, gcc-internal-format
 msgid "add parentheses around left hand side expression to silence this warning"
 msgstr ""
 
-#: c-family/c-warn.c:636
+#: c-family/c-warn.c:637
 #, gcc-internal-format
 msgid "type-punning to incomplete type might break strict-aliasing rules"
 msgstr "类型双关作用在不完全类型上可能破坏强重叠规则"
 
-#: c-family/c-warn.c:654
+#: c-family/c-warn.c:655
 #, gcc-internal-format
 msgid "dereferencing type-punned pointer will break strict-aliasing rules"
 msgstr "提领类型双关的指针将破坏强重叠规则"
 
-#: c-family/c-warn.c:662 c-family/c-warn.c:680
+#: c-family/c-warn.c:663 c-family/c-warn.c:681
 #, gcc-internal-format
 msgid "dereferencing type-punned pointer might break strict-aliasing rules"
 msgstr "提领类型双关的指针可能破坏强重叠规则"
 
-#: c-family/c-warn.c:803
+#: c-family/c-warn.c:811
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to use the size of the destination?"
 msgstr ""
 
-#: c-family/c-warn.c:834
+#: c-family/c-warn.c:842
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the destination; did you mean to remove the addressof?"
 msgstr ""
 
-#: c-family/c-warn.c:841
+#: c-family/c-warn.c:849
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the destination; did you mean to provide an explicit length?"
 msgstr ""
 
-#: c-family/c-warn.c:846
+#: c-family/c-warn.c:854
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the destination; did you mean to dereference it?"
 msgstr ""
 
-#: c-family/c-warn.c:858
+#: c-family/c-warn.c:866
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the destination; expected %qT or an explicit length"
 msgstr ""
 
-#: c-family/c-warn.c:874
+#: c-family/c-warn.c:882
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to remove the addressof?"
 msgstr ""
 
-#: c-family/c-warn.c:881
+#: c-family/c-warn.c:889
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to provide an explicit length?"
 msgstr ""
 
-#: c-family/c-warn.c:886
+#: c-family/c-warn.c:894
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the source; did you mean to dereference it?"
 msgstr ""
 
-#: c-family/c-warn.c:898
+#: c-family/c-warn.c:906
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the source; expected %qT or an explicit length"
 msgstr ""
 
-#: c-family/c-warn.c:914
+#: c-family/c-warn.c:922
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the first source; did you mean to remove the addressof?"
 msgstr ""
 
-#: c-family/c-warn.c:921
+#: c-family/c-warn.c:929
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the first source; did you mean to provide an explicit length?"
 msgstr ""
 
-#: c-family/c-warn.c:926
+#: c-family/c-warn.c:934
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the first source; did you mean to dereference it?"
 msgstr ""
 
-#: c-family/c-warn.c:938
+#: c-family/c-warn.c:946
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the first source; expected %qT or an explicit length"
 msgstr ""
 
-#: c-family/c-warn.c:954
+#: c-family/c-warn.c:962
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the second source; did you mean to remove the addressof?"
 msgstr ""
 
-#: c-family/c-warn.c:961
+#: c-family/c-warn.c:969
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the second source; did you mean to provide an explicit length?"
 msgstr ""
 
-#: c-family/c-warn.c:966
+#: c-family/c-warn.c:974
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same expression as the second source; did you mean to dereference it?"
 msgstr ""
 
-#: c-family/c-warn.c:978
+#: c-family/c-warn.c:986
 #, gcc-internal-format
 msgid "argument to %<sizeof%> in %qD call is the same pointer type %qT as the second source; expected %qT or an explicit length"
 msgstr ""
 
-#: c-family/c-warn.c:1007 c-family/c-warn.c:1014
+#: c-family/c-warn.c:1015 c-family/c-warn.c:1022
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%>-qualified parameter type %qT of %q+D"
 msgstr "不能将形参%q+D声明为具有抽象类型%qT"
 
-#: c-family/c-warn.c:1024
+#: c-family/c-warn.c:1032
 #, gcc-internal-format
 msgid "first argument of %q+D should be %<int%>"
 msgstr "%q+D的第一个参数的类型应该是%<int%>"
 
-#: c-family/c-warn.c:1033
+#: c-family/c-warn.c:1041
 #, gcc-internal-format
 msgid "second argument of %q+D should be %<char **%>"
 msgstr "%q+D的第二个参数类型应该是%<char **%>"
 
-#: c-family/c-warn.c:1042
+#: c-family/c-warn.c:1050
 #, gcc-internal-format
 msgid "third argument of %q+D should probably be %<char **%>"
 msgstr "%q+D如果有第三个参数，类型应该是%<char **%>"
 
-#: c-family/c-warn.c:1053
+#: c-family/c-warn.c:1061
 #, gcc-internal-format
 msgid "%q+D takes only zero or two arguments"
 msgstr "%q+D只带零或两个参数"
 
-#: c-family/c-warn.c:1057
+#: c-family/c-warn.c:1065
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared as variadic function"
 msgstr "嵌套函数%q+D声明过但从未定义"
 
-#: c-family/c-warn.c:1099
+#: c-family/c-warn.c:1107
 #, gcc-internal-format
 msgid "conversion to %qT from boolean expression"
 msgstr "将布尔表达式转化为%qT"
 
-#: c-family/c-warn.c:1117 c-family/c-warn.c:1192
+#: c-family/c-warn.c:1125 c-family/c-warn.c:1200
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT discards qualifiers"
 msgid "conversion from %qT to %qT changes value from %qE to %qE"
 msgstr "从%qT到%qT的转换丢失了限定信息"
 
-#: c-family/c-warn.c:1121 c-family/c-warn.c:1200
+#: c-family/c-warn.c:1129 c-family/c-warn.c:1208
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT is ambiguous"
 msgid "conversion from %qT to %qT changes the value of %qE"
 msgstr "从%qT到%qT的转换有歧义"
 
-#: c-family/c-warn.c:1141
+#: c-family/c-warn.c:1149
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT discards qualifiers"
 msgid "conversion from %qT to %qT discards imaginary component"
 msgstr "从%qT到%qT的转换丢失了限定信息"
 
-#: c-family/c-warn.c:1153
+#: c-family/c-warn.c:1161
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %qT from %qT may alter its value"
 msgid "conversion from %qT to %qT may change value"
 msgstr "%qT转换自%qT时可能改变值"
 
-#: c-family/c-warn.c:1213 c-family/c-warn.c:1230 c-family/c-warn.c:1247
+#: c-family/c-warn.c:1221 c-family/c-warn.c:1238 c-family/c-warn.c:1255
 #, fuzzy, gcc-internal-format
 msgid "overflow in conversion from %qT to %qT changes value from %qE to %qE"
 msgstr "C++ 中不允许从%qT到%qT的隐式转换"
 
-#: c-family/c-warn.c:1218 c-family/c-warn.c:1235 c-family/c-warn.c:1252
+#: c-family/c-warn.c:1226 c-family/c-warn.c:1243 c-family/c-warn.c:1260
 #, fuzzy, gcc-internal-format
 #| msgid "narrowing conversion of %qE from %qT to %qT inside { }"
 msgid "overflow in conversion from %qT to %qT changes the value of %qE"
 msgstr "在 {} 内将%qE从%qT转换为较窄的类型%qT"
 
-#: c-family/c-warn.c:1282
+#: c-family/c-warn.c:1290
 #, gcc-internal-format
 msgid "case value %qs not in enumerated type"
 msgstr "case 值%qs不在枚举类型内"
 
-#: c-family/c-warn.c:1287
+#: c-family/c-warn.c:1295
 #, gcc-internal-format
 msgid "case value %qs not in enumerated type %qT"
 msgstr "case 值%qs不在枚举类型%qT内"
 
-#: c-family/c-warn.c:1348
+#: c-family/c-warn.c:1356
 #, gcc-internal-format
 msgid "switch missing default case"
 msgstr "switch 没有默认 case"
 
-#: c-family/c-warn.c:1393
+#: c-family/c-warn.c:1401
 #, gcc-internal-format
 msgid "switch condition has boolean value"
 msgstr ""
 
-#: c-family/c-warn.c:1466
+#: c-family/c-warn.c:1474
 #, gcc-internal-format
 msgid "enumeration value %qE not handled in switch"
 msgstr "switch 没有处理枚举值%qE"
 
-#: c-family/c-warn.c:1494
+#: c-family/c-warn.c:1502
 #, fuzzy, gcc-internal-format
 msgid "the omitted middle operand in ?: will always be %<true%>, suggest explicit middle operand"
 msgstr "省略的中间算符在中 ?:将一律是 %<true%>，建议明确的中间算符"
 
-#: c-family/c-warn.c:1515
+#: c-family/c-warn.c:1523
 #, fuzzy, gcc-internal-format
 msgid "assignment of member %qD in read-only object"
 msgstr "向只读成员%qD赋值"
 
-#: c-family/c-warn.c:1517
+#: c-family/c-warn.c:1525
 #, fuzzy, gcc-internal-format
 msgid "increment of member %qD in read-only object"
 msgstr "令只读成员%qD自增"
 
-#: c-family/c-warn.c:1519
+#: c-family/c-warn.c:1527
 #, fuzzy, gcc-internal-format
 msgid "decrement of member %qD in read-only object"
 msgstr "令只读成员%qD自减"
 
-#: c-family/c-warn.c:1521
+#: c-family/c-warn.c:1529
 #, fuzzy, gcc-internal-format
 msgid "member %qD in read-only object used as %<asm%> output"
 msgstr "只读成员%qD用作%<asm%>的输出"
 
-#: c-family/c-warn.c:1525
+#: c-family/c-warn.c:1533
 #, gcc-internal-format
 msgid "assignment of read-only member %qD"
 msgstr "向只读成员%qD赋值"
 
-#: c-family/c-warn.c:1526
+#: c-family/c-warn.c:1534
 #, gcc-internal-format
 msgid "increment of read-only member %qD"
 msgstr "令只读成员%qD自增"
 
-#: c-family/c-warn.c:1527
+#: c-family/c-warn.c:1535
 #, gcc-internal-format
 msgid "decrement of read-only member %qD"
 msgstr "令只读成员%qD自减"
 
-#: c-family/c-warn.c:1528
+#: c-family/c-warn.c:1536
 #, gcc-internal-format
 msgid "read-only member %qD used as %<asm%> output"
 msgstr "只读成员%qD用作%<asm%>的输出"
 
-#: c-family/c-warn.c:1532
+#: c-family/c-warn.c:1540
 #, gcc-internal-format
 msgid "assignment of read-only variable %qD"
 msgstr "向只读变量%qD赋值"
 
-#: c-family/c-warn.c:1533
+#: c-family/c-warn.c:1541
 #, gcc-internal-format
 msgid "increment of read-only variable %qD"
 msgstr "令只读变量%qD自增"
 
-#: c-family/c-warn.c:1534
+#: c-family/c-warn.c:1542
 #, gcc-internal-format
 msgid "decrement of read-only variable %qD"
 msgstr "令只读成员%qD自增"
 
-#: c-family/c-warn.c:1535
+#: c-family/c-warn.c:1543
 #, gcc-internal-format
 msgid "read-only variable %qD used as %<asm%> output"
 msgstr "只读变量%qD被用作%<asm%>的输出"
 
-#: c-family/c-warn.c:1538
+#: c-family/c-warn.c:1546
 #, gcc-internal-format
 msgid "assignment of read-only parameter %qD"
 msgstr "向只读形参%qD赋值"
 
-#: c-family/c-warn.c:1539
+#: c-family/c-warn.c:1547
 #, gcc-internal-format
 msgid "increment of read-only parameter %qD"
 msgstr "令只读形参%qD自增"
 
-#: c-family/c-warn.c:1540
+#: c-family/c-warn.c:1548
 #, gcc-internal-format
 msgid "decrement of read-only parameter %qD"
 msgstr "令只读形参%qD自减"
 
-#: c-family/c-warn.c:1541
+#: c-family/c-warn.c:1549
 #, fuzzy, gcc-internal-format
 msgid "read-only parameter %qD use as %<asm%> output"
 msgstr "只读变量%qD被用作%<asm%>的输出"
 
-#: c-family/c-warn.c:1546
+#: c-family/c-warn.c:1554
 #, gcc-internal-format
 msgid "assignment of read-only named return value %qD"
 msgstr "向有名只读返回值%qD赋值"
 
-#: c-family/c-warn.c:1548
+#: c-family/c-warn.c:1556
 #, gcc-internal-format
 msgid "increment of read-only named return value %qD"
 msgstr "令只读有名返回值%qD自增"
 
-#: c-family/c-warn.c:1550
+#: c-family/c-warn.c:1558
 #, gcc-internal-format
 msgid "decrement of read-only named return value %qD"
 msgstr "令有名只读返回值%qD自减"
 
-#: c-family/c-warn.c:1552
+#: c-family/c-warn.c:1560
 #, fuzzy, gcc-internal-format
 msgid "read-only named return value %qD used as %<asm%>output"
 msgstr "通过‘asm’输出向只读有名返回值%qD赋值"
 
-#: c-family/c-warn.c:1557
+#: c-family/c-warn.c:1565
 #, gcc-internal-format
 msgid "assignment of function %qD"
 msgstr "向函数%qD赋值"
 
-#: c-family/c-warn.c:1558
+#: c-family/c-warn.c:1566
 #, gcc-internal-format
 msgid "increment of function %qD"
 msgstr "令函数%qD自增"
 
-#: c-family/c-warn.c:1559
+#: c-family/c-warn.c:1567
 #, gcc-internal-format
 msgid "decrement of function %qD"
 msgstr "令函数%qD自减"
 
-#: c-family/c-warn.c:1560
+#: c-family/c-warn.c:1568
 #, gcc-internal-format
 msgid "function %qD used as %<asm%> output"
 msgstr "函数%qD用作%<asm%>的输出"
 
-#: c-family/c-warn.c:1563 c/c-typeck.c:4762
+#: c-family/c-warn.c:1571 c/c-typeck.c:4767
 #, gcc-internal-format
 msgid "assignment of read-only location %qE"
 msgstr "向只读位置%qE赋值"
 
-#: c-family/c-warn.c:1564 c/c-typeck.c:4765
+#: c-family/c-warn.c:1572 c/c-typeck.c:4770
 #, gcc-internal-format
 msgid "increment of read-only location %qE"
 msgstr "令只读位置%qE自增"
 
-#: c-family/c-warn.c:1565 c/c-typeck.c:4768
+#: c-family/c-warn.c:1573 c/c-typeck.c:4773
 #, gcc-internal-format
 msgid "decrement of read-only location %qE"
 msgstr "令只读位置%qE自减"
 
-#: c-family/c-warn.c:1566
+#: c-family/c-warn.c:1574
 #, gcc-internal-format
 msgid "read-only location %qE used as %<asm%> output"
 msgstr "只读位置%qE用作%<asm%>的输出"
 
-#: c-family/c-warn.c:1580
+#: c-family/c-warn.c:1588
 #, gcc-internal-format
 msgid "lvalue required as left operand of assignment"
 msgstr "赋值运算的左操作数必须是左值"
 
-#: c-family/c-warn.c:1583
+#: c-family/c-warn.c:1591
 #, gcc-internal-format
 msgid "lvalue required as increment operand"
 msgstr "自增操作数必须是左值"
 
-#: c-family/c-warn.c:1586
+#: c-family/c-warn.c:1594
 #, gcc-internal-format
 msgid "lvalue required as decrement operand"
 msgstr "自减操作数必须是左值"
 
-#: c-family/c-warn.c:1589
+#: c-family/c-warn.c:1597
 #, gcc-internal-format
 msgid "lvalue required as unary %<&%> operand"
 msgstr "单目%<&%>的操作数必须是左值"
 
-#: c-family/c-warn.c:1592
+#: c-family/c-warn.c:1600
 #, gcc-internal-format
 msgid "lvalue required in asm statement"
 msgstr "asm 语句中需要左值"
 
-#: c-family/c-warn.c:1609
+#: c-family/c-warn.c:1617
 #, fuzzy, gcc-internal-format
 msgid "invalid type argument (have %qT)"
 msgstr "%<->%>参数类型无效(有%qT)"
 
-#: c-family/c-warn.c:1613
+#: c-family/c-warn.c:1621
 #, gcc-internal-format
 msgid "invalid type argument of array indexing (have %qT)"
 msgstr "数组索引参数类型无效(有%qT)"
 
-#: c-family/c-warn.c:1618
+#: c-family/c-warn.c:1626
 #, gcc-internal-format
 msgid "invalid type argument of unary %<*%> (have %qT)"
 msgstr "一元 %<*%>参数类型无效(有%qT) "
 
-#: c-family/c-warn.c:1623
+#: c-family/c-warn.c:1631
 #, gcc-internal-format
 msgid "invalid type argument of %<->%> (have %qT)"
 msgstr "%<->%>参数类型无效(有%qT)"
 
-#: c-family/c-warn.c:1628
+#: c-family/c-warn.c:1636
 #, fuzzy, gcc-internal-format
 msgid "invalid type argument of %<->*%> (have %qT)"
 msgstr "%<->%>参数类型无效(有%qT)"
 
-#: c-family/c-warn.c:1633
+#: c-family/c-warn.c:1641
 #, fuzzy, gcc-internal-format
 msgid "invalid type argument of implicit conversion (have %qT)"
 msgstr "数组索引参数类型无效(有%qT)"
 
-#: c-family/c-warn.c:1654
+#: c-family/c-warn.c:1662
 #, gcc-internal-format
 msgid "array subscript has type %<char%>"
 msgstr "数组下标类型为%<char%>"
 
-#: c-family/c-warn.c:1689 c-family/c-warn.c:1692
+#: c-family/c-warn.c:1697 c-family/c-warn.c:1700
 #, gcc-internal-format
 msgid "suggest parentheses around %<+%> inside %<<<%>"
 msgstr "建议在%<<<%>的操作数中出现的%<+%>前后加上括号"
 
-#: c-family/c-warn.c:1695 c-family/c-warn.c:1698
+#: c-family/c-warn.c:1703 c-family/c-warn.c:1706
 #, gcc-internal-format
 msgid "suggest parentheses around %<-%> inside %<<<%>"
 msgstr "建议在%<<<%>的操作数中出现的%<-%>前后加上括号"
 
-#: c-family/c-warn.c:1704 c-family/c-warn.c:1707
+#: c-family/c-warn.c:1712 c-family/c-warn.c:1715
 #, gcc-internal-format
 msgid "suggest parentheses around %<+%> inside %<>>%>"
 msgstr "建议在%<>>%>的操作数中出现的%<+%>前后加上括号"
 
-#: c-family/c-warn.c:1710 c-family/c-warn.c:1713
+#: c-family/c-warn.c:1718 c-family/c-warn.c:1721
 #, gcc-internal-format
 msgid "suggest parentheses around %<-%> inside %<>>%>"
 msgstr "建议在%<>>%>的操作数中出现的%<-%>前后加上括号"
 
-#: c-family/c-warn.c:1719 c-family/c-warn.c:1722
+#: c-family/c-warn.c:1727 c-family/c-warn.c:1730
 #, gcc-internal-format
 msgid "suggest parentheses around %<&&%> within %<||%>"
 msgstr "建议在%<||%>的操作数中出现的%<&&%>前后加上括号"
 
-#: c-family/c-warn.c:1729 c-family/c-warn.c:1733
+#: c-family/c-warn.c:1737 c-family/c-warn.c:1741
 #, gcc-internal-format
 msgid "suggest parentheses around arithmetic in operand of %<|%>"
 msgstr "建议在%<|%>的操作数中的算术表达式前后加上括号"
 
-#: c-family/c-warn.c:1737 c-family/c-warn.c:1740
+#: c-family/c-warn.c:1745 c-family/c-warn.c:1748
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<|%>"
 msgstr "建议在%<|%>的操作数中的比较表达式前后加上括号"
 
-#: c-family/c-warn.c:1745
+#: c-family/c-warn.c:1753
 #, gcc-internal-format
 msgid "suggest parentheses around operand of %<!%> or change %<|%> to %<||%> or %<!%> to %<~%>"
 msgstr "建议在%<!%>的操作数周围加上括号，或将%<|%>改为%<||%>，或将%<!%>改为%<~%>"
 
-#: c-family/c-warn.c:1753 c-family/c-warn.c:1757
+#: c-family/c-warn.c:1761 c-family/c-warn.c:1765
 #, gcc-internal-format
 msgid "suggest parentheses around arithmetic in operand of %<^%>"
 msgstr "建议在%<^%>的操作数中的算术表达式前后加上括号"
 
-#: c-family/c-warn.c:1761 c-family/c-warn.c:1764
+#: c-family/c-warn.c:1769 c-family/c-warn.c:1772
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<^%>"
 msgstr "建议在%<^%>的操作数中的比较表达式前后加上括号"
 
-#: c-family/c-warn.c:1770 c-family/c-warn.c:1773
+#: c-family/c-warn.c:1778 c-family/c-warn.c:1781
 #, gcc-internal-format
 msgid "suggest parentheses around %<+%> in operand of %<&%>"
 msgstr "建议在%<&%>的操作数中出现的%<+%>前后加上括号"
 
-#: c-family/c-warn.c:1776 c-family/c-warn.c:1779
+#: c-family/c-warn.c:1784 c-family/c-warn.c:1787
 #, gcc-internal-format
 msgid "suggest parentheses around %<-%> in operand of %<&%>"
 msgstr "建议在%<&%>的操作数中出现的%<-%>前后加上括号"
 
-#: c-family/c-warn.c:1783 c-family/c-warn.c:1786
+#: c-family/c-warn.c:1791 c-family/c-warn.c:1794
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<&%>"
 msgstr "建议在%<&%>的操作数中的比较表达式前后加上括号"
 
-#: c-family/c-warn.c:1791
+#: c-family/c-warn.c:1799
 #, gcc-internal-format
 msgid "suggest parentheses around operand of %<!%> or change %<&%> to %<&&%> or %<!%> to %<~%>"
 msgstr "建议在%<!%>的操作数周围加上括号，或将%<&%>改为%<&&%>，或将%<!%>改为%<~%>"
 
-#: c-family/c-warn.c:1798 c-family/c-warn.c:1801
+#: c-family/c-warn.c:1806 c-family/c-warn.c:1809
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<==%>"
 msgstr "建议在%<==%>的操作数的比较表达式前后加上括号"
 
-#: c-family/c-warn.c:1806 c-family/c-warn.c:1809
+#: c-family/c-warn.c:1814 c-family/c-warn.c:1817
 #, gcc-internal-format
 msgid "suggest parentheses around comparison in operand of %<!=%>"
 msgstr "建议在%<!=%>的操作数的比较前后加上括号"
 
-#: c-family/c-warn.c:1819 c-family/c-warn.c:1825
+#: c-family/c-warn.c:1827 c-family/c-warn.c:1833
 #, gcc-internal-format
 msgid "comparisons like %<X<=Y<=Z%> do not have their mathematical meaning"
 msgstr "形如%<X<=Y<=Z%>的比较并不具备其在数学上的意义"
 
-#: c-family/c-warn.c:1841
+#: c-family/c-warn.c:1849
 #, gcc-internal-format
 msgid "label %q+D defined but not used"
 msgstr "标号%q+D定义后未使用"
 
-#: c-family/c-warn.c:1843
+#: c-family/c-warn.c:1851
 #, gcc-internal-format
 msgid "label %q+D declared but not defined"
 msgstr "标号%q+D声明后未定义"
 
-#: c-family/c-warn.c:1866
+#: c-family/c-warn.c:1874
 #, gcc-internal-format
 msgid "division by zero"
 msgstr "被零除"
 
-#: c-family/c-warn.c:1886
+#: c-family/c-warn.c:1894
 #, gcc-internal-format
 msgid "%<memset%> used with constant zero length parameter; this could be due to transposed parameters"
 msgstr ""
 
-#: c-family/c-warn.c:1909
+#: c-family/c-warn.c:1918
 #, gcc-internal-format
 msgid "%<memset%> used with length equal to number of elements without multiplication by element size"
 msgstr ""
 
-#: c-family/c-warn.c:1948 c/c-typeck.c:11499 c/c-typeck.c:11667
+#: c-family/c-warn.c:1957 c/c-typeck.c:11504 c/c-typeck.c:11672
 #: cp/typeck.c:5048
 #, gcc-internal-format
 msgid "comparison between types %qT and %qT"
 msgstr "在类型%qT和%qT间比较"
 
-#: c-family/c-warn.c:1998
+#: c-family/c-warn.c:2007
 #, gcc-internal-format
 msgid "comparison of integer expressions of different signedness: %qT and %qT"
 msgstr ""
 
-#: c-family/c-warn.c:2051
+#: c-family/c-warn.c:2060
 #, gcc-internal-format
 msgid "promoted ~unsigned is always non-zero"
 msgstr "提升后的 ~unsigned 总是非零值"
 
-#: c-family/c-warn.c:2054
+#: c-family/c-warn.c:2063
 #, gcc-internal-format
 msgid "comparison of promoted ~unsigned with constant"
 msgstr "比较常量和取反后又经提升的无符号数"
 
-#: c-family/c-warn.c:2064
+#: c-family/c-warn.c:2073
 #, gcc-internal-format
 msgid "comparison of promoted ~unsigned with unsigned"
 msgstr "比较无符号数和取反后又经提升的无符号数"
 
-#: c-family/c-warn.c:2118
+#: c-family/c-warn.c:2127
 #, fuzzy, gcc-internal-format
 #| msgid "unused parameter %q+D"
 msgid "unused parameter %qD"
 msgstr "未使用的参数%q+D"
 
-#: c-family/c-warn.c:2180
+#: c-family/c-warn.c:2189
 #, fuzzy, gcc-internal-format
 msgid "typedef %qD locally defined but not used"
 msgstr "typedef 名%qD用于析构函数声明"
 
-#: c-family/c-warn.c:2215
+#: c-family/c-warn.c:2224
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<const%>"
 msgid "duplicated %<if%> condition"
 msgstr "重复的%<const%>"
 
-#: c-family/c-warn.c:2244
+#: c-family/c-warn.c:2253
 #, fuzzy, gcc-internal-format
 msgid "optimization attribute on %qD follows definition but the attribute doesn%'t match"
 msgstr "%q+D带有 noinline 属性的声明出现在其内联声明之后"
 
-#: c-family/c-warn.c:2254
+#: c-family/c-warn.c:2261
 #, fuzzy, gcc-internal-format
 #| msgid "inline declaration of %qD follows declaration with attribute noinline"
 msgid "inline declaration of %qD follows declaration with attribute %qs"
 msgstr "%q+D带有 noinline 属性的声明出现在其内联声明之后"
 
-#: c-family/c-warn.c:2259
+#: c-family/c-warn.c:2266
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D with attribute noinline follows inline declaration "
 msgid "declaration of %q+D with attribute %qs follows inline declaration"
 msgstr "%q+D带有 noinline 属性的声明出现在其内联声明之后"
 
-#: c-family/c-warn.c:2306
+#: c-family/c-warn.c:2313
 #, gcc-internal-format
 msgid "result of %qE requires %u bits to represent, but %qT only has %u bits"
 msgstr ""
 
-#: c-family/c-warn.c:2344 c-family/c-warn.c:2368
+#: c-family/c-warn.c:2351 c-family/c-warn.c:2375
 #, fuzzy, gcc-internal-format
 msgid "comparison of constant %qE with boolean expression is always false"
 msgstr "无符号表达式永远不小于 0"
 
-#: c-family/c-warn.c:2347 c-family/c-warn.c:2365
+#: c-family/c-warn.c:2354 c-family/c-warn.c:2372
 #, fuzzy, gcc-internal-format
 msgid "comparison of constant %qE with boolean expression is always true"
 msgstr "无符号表达式永远大于或等于 0"
 
-#: c-family/c-warn.c:2415
+#: c-family/c-warn.c:2422
 #, fuzzy
 msgid "passing argument %i to restrict-qualified parameter aliases with argument %Z"
 msgid_plural "passing argument %i to restrict-qualified parameter aliases with arguments %Z"
 msgstr[0] "传递%2$qE的第 %1$d 个实参时丢弃了指针目标类型的限定"
 
-#: c-family/c-warn.c:2480 c/c-typeck.c:5288 cp/call.c:5365
+#: c-family/c-warn.c:2487 c/c-typeck.c:5293 cp/call.c:5365
 #, gcc-internal-format
 msgid "this condition has identical branches"
 msgstr ""
 
-#: c-family/c-warn.c:2586
+#: c-family/c-warn.c:2593
 #, gcc-internal-format
 msgid "macro expands to multiple statements"
 msgstr ""
 
-#: c-family/c-warn.c:2587
+#: c-family/c-warn.c:2594
 #, gcc-internal-format
 msgid "some parts of macro expansion are not guarded by this %qs clause"
 msgstr ""
@@ -30425,7 +30469,7 @@
 msgid "too many input files"
 msgstr "输入文件太多"
 
-#: common/config/aarch64/aarch64-common.c:319 config/aarch64/aarch64.c:10686
+#: common/config/aarch64/aarch64-common.c:319 config/aarch64/aarch64.c:10702
 #, gcc-internal-format
 msgid "unknown value %qs for -mcpu"
 msgstr "-mcpu 的值%qs未知"
@@ -30457,13 +30501,13 @@
 msgstr ""
 
 #: common/config/arm/arm-common.c:322 common/config/arm/arm-common.c:376
-#: common/config/arm/arm-common.c:423 config/aarch64/aarch64.c:10639
+#: common/config/arm/arm-common.c:423 config/aarch64/aarch64.c:10655
 #, fuzzy, gcc-internal-format
 msgid "valid arguments are: %s; did you mean %qs?"
 msgstr "%qs对%qs而言无效"
 
 #: common/config/arm/arm-common.c:325 common/config/arm/arm-common.c:379
-#: common/config/arm/arm-common.c:426 config/aarch64/aarch64.c:10642
+#: common/config/arm/arm-common.c:426 config/aarch64/aarch64.c:10658
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "valid arguments are: %s"
 msgstr "%qs对%qs而言无效"
@@ -30945,12 +30989,12 @@
 msgid "profiler support for VxWorks"
 msgstr "对 VxWorks 的取样支持"
 
-#: config/aarch64/aarch64-builtins.c:1109 config/arm/arm-builtins.c:2262
+#: config/aarch64/aarch64-builtins.c:1109 config/arm/arm-builtins.c:2272
 #, fuzzy, gcc-internal-format
 msgid "%Kargument %d must be a constant immediate"
 msgstr "实参必须是常数"
 
-#: config/aarch64/aarch64-builtins.c:1180 config/arm/arm-builtins.c:2492
+#: config/aarch64/aarch64-builtins.c:1180 config/arm/arm-builtins.c:2502
 #, fuzzy, gcc-internal-format
 msgid "%Klane index must be a constant immediate"
 msgstr "掩码必须是一个立即数"
@@ -30960,178 +31004,178 @@
 msgid "%Ktotal size and element size must be a non-zero constant immediate"
 msgstr ""
 
-#: config/aarch64/aarch64.c:1053
+#: config/aarch64/aarch64.c:1069
 #, fuzzy, gcc-internal-format
 msgid "%qs is incompatible with %s %s"
 msgstr "%qs必须与%qs一起使用"
 
-#: config/aarch64/aarch64.c:1055
+#: config/aarch64/aarch64.c:1071
 #, fuzzy, gcc-internal-format
 msgid "%qs feature modifier is incompatible with %s %s"
 msgstr "%qs必须与%qs一起使用"
 
-#: config/aarch64/aarch64.c:3772
+#: config/aarch64/aarch64.c:3788
 #, gcc-internal-format
 msgid "stack probes for SVE frames"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10287
+#: config/aarch64/aarch64.c:10303
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown flag passed in -moverride=%s (%s)"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10331
+#: config/aarch64/aarch64.c:10347
 #, gcc-internal-format, gfc-internal-format
 msgid "%s string ill-formed\n"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10388
+#: config/aarch64/aarch64.c:10404
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "tuning string missing in option (%s)"
 msgstr "%s: 不适用的选项 -- %c\n"
 
-#: config/aarch64/aarch64.c:10406
+#: config/aarch64/aarch64.c:10422
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown tuning option (%s)"
 msgstr "spec 函数名格式错误"
 
-#: config/aarch64/aarch64.c:10683
+#: config/aarch64/aarch64.c:10699
 #, fuzzy, gcc-internal-format
 msgid "missing cpu name in %<-mcpu=%s%>"
 msgstr "%qs后缺少宏名"
 
-#: config/aarch64/aarch64.c:10690
+#: config/aarch64/aarch64.c:10706
 #, fuzzy, gcc-internal-format
 msgid "invalid feature modifier in %<-mcpu=%s%>"
 msgstr "%X%P: 未知特征 %s\n"
 
-#: config/aarch64/aarch64.c:10717
+#: config/aarch64/aarch64.c:10733
 #, fuzzy, gcc-internal-format
 msgid "missing arch name in %<-march=%s%>"
 msgstr "%qs后缺少宏名"
 
-#: config/aarch64/aarch64.c:10720
+#: config/aarch64/aarch64.c:10736
 #, fuzzy, gcc-internal-format
 msgid "unknown value %qs for -march"
 msgstr "未知的 TLS 模型%qs"
 
-#: config/aarch64/aarch64.c:10724
+#: config/aarch64/aarch64.c:10740
 #, fuzzy, gcc-internal-format
 msgid "invalid feature modifier in %<-march=%s%>"
 msgstr "%qs后缺少宏名"
 
-#: config/aarch64/aarch64.c:10750
+#: config/aarch64/aarch64.c:10766
 #, fuzzy, gcc-internal-format
 msgid "missing cpu name in %<-mtune=%s%>"
 msgstr "%qs后缺少宏名"
 
-#: config/aarch64/aarch64.c:10753
+#: config/aarch64/aarch64.c:10769
 #, gcc-internal-format
 msgid "unknown value %qs for -mtune"
 msgstr "-mtune 参数的值 %qs 未知"
 
-#: config/aarch64/aarch64.c:10871 config/arm/arm.c:3173
+#: config/aarch64/aarch64.c:10887 config/arm/arm.c:3173
 #, gcc-internal-format, gfc-internal-format
 msgid "switch -mcpu=%s conflicts with -march=%s switch"
 msgstr "开关 -mcpu=%s 与 -march=%s 冲突"
 
-#: config/aarch64/aarch64.c:10906
+#: config/aarch64/aarch64.c:10922
 #, fuzzy, gcc-internal-format
 #| msgid "Assembler does not support -mabi=ilp32"
 msgid "assembler does not support -mabi=ilp32"
 msgstr "汇编器不支持 -mabi=ilp32"
 
-#: config/aarch64/aarch64.c:10913
+#: config/aarch64/aarch64.c:10929
 #, gcc-internal-format
 msgid "return address signing is only supported for -mabi=lp64"
 msgstr ""
 
-#: config/aarch64/aarch64.c:10975
+#: config/aarch64/aarch64.c:10991
 #, fuzzy, gcc-internal-format
 msgid "code model %qs with -f%s"
 msgstr "代码模式%qs在 %s 位模式下不受支持"
 
-#: config/aarch64/aarch64.c:11138
+#: config/aarch64/aarch64.c:11154
 #, gcc-internal-format
 msgid "missing name in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11141
+#: config/aarch64/aarch64.c:11157
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"arch=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11145 config/aarch64/aarch64.c:11184
-#: config/aarch64/aarch64.c:11257
+#: config/aarch64/aarch64.c:11161 config/aarch64/aarch64.c:11200
+#: config/aarch64/aarch64.c:11273
 #, fuzzy, gcc-internal-format
 msgid "invalid value (\"%s\") in %<target()%> pragma or attribute"
 msgstr "重置属性为默认值"
 
-#: config/aarch64/aarch64.c:11177
+#: config/aarch64/aarch64.c:11193
 #, gcc-internal-format
 msgid "missing name in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11180
+#: config/aarch64/aarch64.c:11196
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"cpu=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11213
+#: config/aarch64/aarch64.c:11229
 #, gcc-internal-format
 msgid "invalid name (\"%s\") in %<target(\"tune=\")%> pragma or attribute"
 msgstr ""
 
-#: config/aarch64/aarch64.c:11253
+#: config/aarch64/aarch64.c:11269
 #, fuzzy, gcc-internal-format
 msgid "missing value in %<target()%> pragma or attribute"
 msgstr "%qs后断言"
 
-#: config/aarch64/aarch64.c:11306 config/aarch64/aarch64.c:11483
+#: config/aarch64/aarch64.c:11322 config/aarch64/aarch64.c:11499
 #, fuzzy, gcc-internal-format
 msgid "malformed %<target()%> pragma or attribute"
 msgstr "异常的 URL"
 
-#: config/aarch64/aarch64.c:11354
+#: config/aarch64/aarch64.c:11370
 #, fuzzy, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not accept an argument"
 msgstr "%s 只接受 2 个参数"
 
-#: config/aarch64/aarch64.c:11362
+#: config/aarch64/aarch64.c:11378
 #, fuzzy, gcc-internal-format
 msgid "pragma or attribute %<target(\"%s\")%> does not allow a negated form"
 msgstr "目标系统不支持调试输出"
 
-#: config/aarch64/aarch64.c:11416
+#: config/aarch64/aarch64.c:11432
 #, fuzzy, gcc-internal-format
 #| msgid "attribute(target(\"%s\")) is unknown"
 msgid "pragma or attribute %<target(\"%s=%s\")%> is not valid"
 msgstr "attribute(target(\"%s\"))未知"
 
-#: config/aarch64/aarch64.c:11473 config/arm/arm.c:30742
-#: config/i386/i386.c:5440 config/powerpcspe/powerpcspe.c:39760
-#: config/rs6000/rs6000.c:36904 config/s390/s390.c:15746
+#: config/aarch64/aarch64.c:11489 config/arm/arm.c:30742
+#: config/i386/i386.c:5443 config/powerpcspe/powerpcspe.c:39760
+#: config/rs6000/rs6000.c:36960 config/s390/s390.c:15746
 #, fuzzy, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "%qE属性需要一个字符串常量作为实参"
 
-#: config/aarch64/aarch64.c:11500
+#: config/aarch64/aarch64.c:11516
 #, fuzzy, gcc-internal-format
 #| msgid "attribute(target(\"%s\")) is unknown"
 msgid "pragma or attribute %<target(\"%s\")%> is not valid"
 msgstr "attribute(target(\"%s\"))未知"
 
-#: config/aarch64/aarch64.c:11509
+#: config/aarch64/aarch64.c:11525
 #, fuzzy, gcc-internal-format
 msgid "malformed %<target(\"%s\")%> pragma or attribute"
 msgstr "异常的 URL"
 
-#: config/aarch64/aarch64.c:13571
+#: config/aarch64/aarch64.c:13587
 #, fuzzy, gcc-internal-format
 msgid "%Klane %wd out of range %wd - %wd"
 msgstr "操作数号超出范围"
 
-#: config/aarch64/aarch64.c:13573
+#: config/aarch64/aarch64.c:13589
 #, fuzzy, gcc-internal-format
 msgid "lane %wd out of range %wd - %wd"
 msgstr "操作数号超出范围"
@@ -31191,8 +31235,8 @@
 msgid "bad value %qs for -mmemory-latency"
 msgstr "-mmemory-latency 开关的值%qs错误"
 
-#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6526
-#: config/arc/arc.c:6800 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
+#: config/alpha/alpha.c:6683 config/alpha/alpha.c:6686 config/arc/arc.c:6517
+#: config/arc/arc.c:6791 config/s390/s390.c:847 config/tilegx/tilegx.c:3544
 #: config/tilepro/tilepro.c:3108
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -31304,11 +31348,11 @@
 #: config/arm/arm.c:7029 config/avr/avr.c:9718 config/avr/avr.c:9734
 #: config/bfin/bfin.c:4705 config/bfin/bfin.c:4766 config/bfin/bfin.c:4795
 #: config/epiphany/epiphany.c:491 config/h8300/h8300.c:5459
-#: config/i386/i386.c:6452 config/i386/i386.c:12479 config/i386/i386.c:41424
-#: config/i386/i386.c:41474 config/i386/i386.c:41544 config/m68k/m68k.c:780
+#: config/i386/i386.c:6455 config/i386/i386.c:12482 config/i386/i386.c:41418
+#: config/i386/i386.c:41468 config/i386/i386.c:41538 config/m68k/m68k.c:780
 #: config/mcore/mcore.c:3070 config/nvptx/nvptx.c:4611
 #: config/powerpcspe/powerpcspe.c:35785 config/riscv/riscv.c:2698
-#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:32982
+#: config/rl78/rl78.c:815 config/rl78/rl78.c:884 config/rs6000/rs6000.c:33038
 #: config/rx/rx.c:2719 config/rx/rx.c:2745 config/s390/s390.c:1056
 #: config/s390/s390.c:1143 config/sh/sh.c:8428 config/sh/sh.c:8446
 #: config/sh/sh.c:8470 config/sh/sh.c:8541 config/sh/sh.c:8564
@@ -31318,141 +31362,141 @@
 msgid "%qE attribute only applies to functions"
 msgstr "%qE属性只能用于函数"
 
-#: config/arc/arc.c:6425
+#: config/arc/arc.c:6416
 #, fuzzy, gcc-internal-format
 msgid "__builtin_arc_aligned with non-constant alignment"
 msgstr "调用%<__builtin_next_arg%>时没有给定实参"
 
-#: config/arc/arc.c:6433
+#: config/arc/arc.c:6424
 #, fuzzy, gcc-internal-format
 msgid "invalid alignment value for __builtin_arc_aligned"
 msgstr "%<__builtin_frame_address%>的实参无效"
 
-#: config/arc/arc.c:6596
+#: config/arc/arc.c:6587
 #, fuzzy, gcc-internal-format
 #| msgid "-mcorea should be used with -mmulticore"
 msgid "operand 1 should be an unsigned 3-bit immediate"
 msgstr "-mcorea 必须与 -mmulticore 一起使用"
 
-#: config/arc/arc.c:6637 config/arc/arc.c:6734
+#: config/arc/arc.c:6628 config/arc/arc.c:6725
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6670 config/arc/arc.c:6702
+#: config/arc/arc.c:6661 config/arc/arc.c:6693
 #, gcc-internal-format
 msgid "operand 1 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6674 config/arc/arc.c:6706
+#: config/arc/arc.c:6665 config/arc/arc.c:6697
 #, fuzzy, gcc-internal-format
 msgid "operand 2 should be an unsigned 8-bit value"
 msgstr "实参 2 必须是一个 5 位无符号字面量"
 
-#: config/arc/arc.c:6738
+#: config/arc/arc.c:6729
 #, fuzzy, gcc-internal-format
 msgid "operand 3 should be an unsigned 8-bit value"
 msgstr "实参 2 必须是一个 5 位无符号字面量"
 
-#: config/arc/arc.c:6771
+#: config/arc/arc.c:6762
 #, gcc-internal-format
 msgid "operand 4 should be an unsigned 8-bit value (0-255)"
 msgstr ""
 
-#: config/arc/arc.c:6775
+#: config/arc/arc.c:6766
 #, gcc-internal-format
 msgid "operand 3 should be an unsigned 3-bit value (I0-I7)"
 msgstr ""
 
-#: config/arc/arc.c:6782
+#: config/arc/arc.c:6773
 #, gcc-internal-format
 msgid "operand 2 should be an unsigned 3-bit value (subreg 0-7)"
 msgstr ""
 
-#: config/arc/arc.c:6785
+#: config/arc/arc.c:6776
 #, gcc-internal-format
 msgid "operand 2 should be an even 3-bit value (subreg 0,2,4,6)"
 msgstr ""
 
-#: config/arc/arc.c:6832
+#: config/arc/arc.c:6823
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "symbol used as immediate operand"
 msgid "builtin requires an immediate for operand %d"
 msgstr "符号被用作立即操作数"
 
-#: config/arc/arc.c:6837
+#: config/arc/arc.c:6828
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "operand %d should be a 6 bit unsigned immediate"
 msgstr "实参 2 必须是一个 5 位无符号字面量"
 
-#: config/arc/arc.c:6841
+#: config/arc/arc.c:6832
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "operand %d should be a 8 bit unsigned immediate"
 msgstr "实参 2 必须是一个 5 位无符号字面量"
 
-#: config/arc/arc.c:6845
+#: config/arc/arc.c:6836
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "operand %d should be a 3 bit unsigned immediate"
 msgstr "实参 2 必须是一个 5 位无符号字面量"
 
-#: config/arc/arc.c:6848
+#: config/arc/arc.c:6839
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown builtin immediate operand type for operand %d"
 msgstr ""
 
-#: config/arc/arc.c:6899
+#: config/arc/arc.c:6890
 #, gcc-internal-format
 msgid "register number must be a compile-time constant. Try giving higher optimization levels"
 msgstr ""
 
-#: config/arc/arc.c:7685
+#: config/arc/arc.c:7747
 #, gcc-internal-format
 msgid "Insn addresses not set after shorten_branches"
 msgstr ""
 
-#: config/arc/arc.c:7894
+#: config/arc/arc.c:7956
 #, fuzzy, gcc-internal-format
 msgid "insn addresses not freed"
 msgstr "在 %2$s 缓存中 %1$zu 字节可用"
 
-#: config/arc/arc.c:10682
+#: config/arc/arc.c:10670
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only available for 32-bit"
 msgid "%qE attribute only valid for ARCv2 architecture"
 msgstr "%qE属性只能在 32 位下使用"
 
-#: config/arc/arc.c:10690 config/arc/arc.c:10729
+#: config/arc/arc.c:10678 config/arc/arc.c:10717
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qE attribute is not \"ilink1\" or \"ilink2\""
 msgid "argument of %qE attribute is missing"
 msgstr "%qE属性的实参不是“ilink1”或“ilink2”"
 
-#: config/arc/arc.c:10701 config/arc/arc.c:10740 config/arc/arc.c:10842
+#: config/arc/arc.c:10689 config/arc/arc.c:10728 config/arc/arc.c:10830
 #: config/avr/avr.c:9790
 #, gcc-internal-format
 msgid "%qE attribute allows only an integer constant argument"
 msgstr "%qE属性需要一个整常量作为实参"
 
-#: config/arc/arc.c:10721
+#: config/arc/arc.c:10709
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only valid for ARC EM architecture"
 msgstr "%qE属性只能用于函数类型"
 
-#: config/arc/arc.c:10776
+#: config/arc/arc.c:10764
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to function types"
 msgid "%qE attribute only applies to types"
 msgstr "%qE属性只能用于函数类型"
 
-#: config/arc/arc.c:10782
+#: config/arc/arc.c:10770
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qE attribute is not \"ilink1\" or \"ilink2\""
 msgid "argument of %qE attribute ignored"
 msgstr "%qE属性的实参不是“ilink1”或“ilink2”"
 
-#: config/arc/arc.c:10832 config/avr/avr.c:9777 config/bfin/bfin.c:4827
+#: config/arc/arc.c:10820 config/avr/avr.c:9777 config/bfin/bfin.c:4827
 #: config/i386/winnt.c:63 config/msp430/msp430.c:2018
 #: config/nvptx/nvptx.c:4634
 #, gcc-internal-format
@@ -31459,174 +31503,174 @@
 msgid "%qE attribute only applies to variables"
 msgstr "属性%qE只能用于变量"
 
-#: config/arm/arm-builtins.c:2370
+#: config/arm/arm-builtins.c:2380
 #, fuzzy, gcc-internal-format
 msgid "this builtin is not supported for this target"
 msgstr "堆栈限制在此目标机上不受支持"
 
-#: config/arm/arm-builtins.c:2475
+#: config/arm/arm-builtins.c:2485
 #, gcc-internal-format
 msgid "You must enable NEON instructions (e.g. -mfloat-abi=softfp -mfpu=neon) to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2513
+#: config/arm/arm-builtins.c:2523
 #, gcc-internal-format
 msgid "You must enable VFP instructions to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2573
+#: config/arm/arm-builtins.c:2583
 #, gcc-internal-format
 msgid "You must enable crypto instructions (e.g. include -mfloat-abi=softfp -mfpu=crypto-neon...) to use these intrinsics."
 msgstr ""
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:2633 config/arm/arm-builtins.c:2737
+#: config/arm/arm-builtins.c:2643 config/arm/arm-builtins.c:2747
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr "选择子必须是立即数"
 
-#: config/arm/arm-builtins.c:2641 config/arm/arm-builtins.c:2686
-#: config/arm/arm-builtins.c:2744 config/arm/arm-builtins.c:2753
+#: config/arm/arm-builtins.c:2651 config/arm/arm-builtins.c:2696
+#: config/arm/arm-builtins.c:2754 config/arm/arm-builtins.c:2763
 #, fuzzy, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr "选择子必须是 0 到 %wi 间的整常量"
 
-#: config/arm/arm-builtins.c:2646 config/arm/arm-builtins.c:2755
+#: config/arm/arm-builtins.c:2656 config/arm/arm-builtins.c:2765
 #, fuzzy, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr "选择子必须是 0 到 %wi 间的整常量"
 
-#: config/arm/arm-builtins.c:2651 config/arm/arm-builtins.c:2757
+#: config/arm/arm-builtins.c:2661 config/arm/arm-builtins.c:2767
 #, fuzzy, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr "选择子必须是 0 到 %wi 间的整常量"
 
-#: config/arm/arm-builtins.c:2823
+#: config/arm/arm-builtins.c:2833
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr "掩码必须是一个立即数"
 
-#: config/arm/arm-builtins.c:2828
+#: config/arm/arm-builtins.c:2838
 #, fuzzy, gcc-internal-format
 msgid "the range of mask should be in 0 to 255"
 msgstr "%qE属性的参数应当在 0 和 255 之间"
 
-#: config/arm/arm-builtins.c:3016
+#: config/arm/arm-builtins.c:3026
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3018
+#: config/arm/arm-builtins.c:3028
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3020
+#: config/arm/arm-builtins.c:3030
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3022
+#: config/arm/arm-builtins.c:3032
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3028
+#: config/arm/arm-builtins.c:3038
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3030
+#: config/arm/arm-builtins.c:3040
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3035
+#: config/arm/arm-builtins.c:3045
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3037
+#: config/arm/arm-builtins.c:3047
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3039
+#: config/arm/arm-builtins.c:3049
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3041
+#: config/arm/arm-builtins.c:3051
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3043
+#: config/arm/arm-builtins.c:3053
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3045
+#: config/arm/arm-builtins.c:3055
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3047
+#: config/arm/arm-builtins.c:3057
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3049
+#: config/arm/arm-builtins.c:3059
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3051
+#: config/arm/arm-builtins.c:3061
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3053
+#: config/arm/arm-builtins.c:3063
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3055
+#: config/arm/arm-builtins.c:3065
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3057
+#: config/arm/arm-builtins.c:3067
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3059
+#: config/arm/arm-builtins.c:3069
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3061
+#: config/arm/arm-builtins.c:3071
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3063
+#: config/arm/arm-builtins.c:3073
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3065
+#: config/arm/arm-builtins.c:3075
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3067
+#: config/arm/arm-builtins.c:3077
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3069
+#: config/arm/arm-builtins.c:3079
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr ""
@@ -32549,60 +32593,60 @@
 msgid "can%'t set position in PCH file: %m"
 msgstr "不能在 PCH 文件中找到位置：%m"
 
-#: config/i386/i386.c:3177
+#: config/i386/i386.c:3180
 #, fuzzy, gcc-internal-format
 msgid "wrong argument %qs to option %qs"
 msgstr "错误的选项于环境变量 MINICOM=“%s”\n"
 
-#: config/i386/i386.c:3183
+#: config/i386/i386.c:3186
 #, gcc-internal-format
 msgid "size ranges of option %qs should be increasing"
 msgstr ""
 
-#: config/i386/i386.c:3193
+#: config/i386/i386.c:3196
 #, fuzzy, gcc-internal-format
 msgid "wrong strategy name %qs specified for option %qs"
 msgstr "%q+D的寄存器名无效"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3219
+#: config/i386/i386.c:3222
 #, fuzzy, gcc-internal-format
 msgid "strategy name %qs specified for option %qs not supported for 32-bit code"
 msgstr "%q+D的寄存器名无效"
 
-#: config/i386/i386.c:3232
+#: config/i386/i386.c:3235
 #, fuzzy, gcc-internal-format
 msgid "unknown alignment %qs specified for option %qs"
 msgstr "%s：未知选项 -%c\n"
 
-#: config/i386/i386.c:3242
+#: config/i386/i386.c:3245
 #, gcc-internal-format
 msgid "the max value for the last size range should be -1 for option %qs"
 msgstr ""
 
-#: config/i386/i386.c:3249
+#: config/i386/i386.c:3252
 #, fuzzy, gcc-internal-format
 msgid "too many size ranges specified in option %qs"
 msgstr "%qs没有指定类名"
 
-#: config/i386/i386.c:3302
+#: config/i386/i386.c:3305
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown parameter to option -mtune-ctrl: %s"
 msgstr "%L处参数列表函数未知"
 
-#: config/i386/i386.c:3726
+#: config/i386/i386.c:3729
 #, fuzzy, gcc-internal-format
 #| msgid "64-bit ABI not supported in ESA/390 mode"
 msgid "Intel MCU psABI isn%'t supported in %s mode"
 msgstr "64-bit ABI 在 ESA/390 模式下不受支持"
 
-#: config/i386/i386.c:3775
+#: config/i386/i386.c:3778
 #, fuzzy, gcc-internal-format
 #| msgid "%stune=x86-64%s is deprecated; use %stune=k8%s or %stune=generic%s instead as appropriate"
 msgid "%<-mtune=x86-64%> is deprecated; use %<-mtune=k8%> or %<-mtune=generic%> instead as appropriate"
 msgstr "已弃用%stune=x86-64%s；请视情况改用%stune=k8%s或%stune=generic%s"
 
-#: config/i386/i386.c:3777
+#: config/i386/i386.c:3780
 #, fuzzy, gcc-internal-format
 #| msgid "%stune=x86-64%s is deprecated; use %stune=k8%s or %stune=generic%s instead as appropriate"
 msgid "%<target(\"tune=x86-64\")%> is deprecated; use %<target(\"tune=k8\")%> or %<target(\"tune=generic\")%> instead as appropriate"
@@ -32609,514 +32653,514 @@
 msgstr "已弃用%stune=x86-64%s；请视情况改用%stune=k8%s或%stune=generic%s"
 
 #. rep; movq isn't available in 32-bit code.
-#: config/i386/i386.c:3804
+#: config/i386/i386.c:3807
 #, gcc-internal-format
 msgid "-mstringop-strategy=rep_8byte not supported for 32-bit code"
 msgstr "-mstringop-strategy=rep_8byte 不支持用于 32 位代码"
 
-#: config/i386/i386.c:3821
+#: config/i386/i386.c:3824
 #, fuzzy, gcc-internal-format
 msgid "address mode %qs not supported in the %s bit mode"
 msgstr "代码模式%qs在 %s 位模式下不受支持"
 
-#: config/i386/i386.c:3833
+#: config/i386/i386.c:3836
 #, fuzzy, gcc-internal-format
 #| msgid "%<-Wabi=1%> is not supported, using =2"
 msgid "-mabi=ms not supported with X32 ABI"
 msgstr "%<-Wabi=1%> 不受支持，将使用 =2"
 
-#: config/i386/i386.c:3851 config/i386/i386.c:3860 config/i386/i386.c:3872
-#: config/i386/i386.c:3883 config/i386/i386.c:3894
+#: config/i386/i386.c:3854 config/i386/i386.c:3863 config/i386/i386.c:3875
+#: config/i386/i386.c:3886 config/i386/i386.c:3897
 #, gcc-internal-format
 msgid "code model %qs not supported in the %s bit mode"
 msgstr "代码模式%qs在 %s 位模式下不受支持"
 
-#: config/i386/i386.c:3863 config/i386/i386.c:3875
+#: config/i386/i386.c:3866 config/i386/i386.c:3878
 #, fuzzy, gcc-internal-format
 msgid "code model %qs not supported in x32 mode"
 msgstr "代码模式%qs在 %s 位模式下不受支持"
 
-#: config/i386/i386.c:3881 config/i386/i386.c:3890 config/i386/i386.c:5213
+#: config/i386/i386.c:3884 config/i386/i386.c:3893 config/i386/i386.c:5216
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "代码模式 %s 在 PIC 模式下不受支持"
 
-#: config/i386/i386.c:3918
+#: config/i386/i386.c:3921
 #, gcc-internal-format
 msgid "-masm=intel not supported in this configuration"
 msgstr "-masm=intel 在此配置下不受支持"
 
-#: config/i386/i386.c:3923
+#: config/i386/i386.c:3926
 #, gcc-internal-format, gfc-internal-format
 msgid "%i-bit mode not compiled in"
 msgstr "未编译入对 %i 位模式的支持"
 
-#: config/i386/i386.c:3932
+#: config/i386/i386.c:3935
 #, fuzzy, gcc-internal-format
 #| msgid "generic CPU can be used only for %stune=%s %s"
 msgid "%<generic%> CPU can be used only for %<-mtune=%> switch"
 msgstr "generic 只能用在%stune%s %s中"
 
-#: config/i386/i386.c:3934
+#: config/i386/i386.c:3937
 #, fuzzy, gcc-internal-format
 #| msgid "generic CPU can be used only for %stune=%s %s"
 msgid "%<generic%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "generic 只能用在%stune%s %s中"
 
-#: config/i386/i386.c:3941
+#: config/i386/i386.c:3944
 #, fuzzy, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<-mtune=%> switch"
 msgstr "generic 只能用在%stune%s %s中"
 
-#: config/i386/i386.c:3943
+#: config/i386/i386.c:3946
 #, fuzzy, gcc-internal-format
 msgid "%<intel%> CPU can be used only for %<target(\"tune=\")%> attribute"
 msgstr "generic 只能用在%stune%s %s中"
 
-#: config/i386/i386.c:3951 config/i386/i386.c:4265
+#: config/i386/i386.c:3954 config/i386/i386.c:4268
 #, gcc-internal-format
 msgid "CPU you selected does not support x86-64 instruction set"
 msgstr "您选择的 CPU 不支持 x86-64 指令集"
 
-#: config/i386/i386.c:4197 config/i386/i386.c:4200
+#: config/i386/i386.c:4200 config/i386/i386.c:4203
 #, gcc-internal-format
 msgid "Intel MPX does not support x32"
 msgstr "Intel MPX 不支持 x32"
 
-#: config/i386/i386.c:4205
+#: config/i386/i386.c:4208
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -march= switch"
 msgid "bad value (%qs) for %<-march=%> switch"
 msgstr "-march= 的值(%s)不正确"
 
-#: config/i386/i386.c:4206
+#: config/i386/i386.c:4209
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for %sarch=%s %s"
 msgid "bad value (%qs) for %<target(\"arch=\")%> attribute"
 msgstr "%2$sarch=%3$s %4$s所带参数(%1$s)不正确"
 
-#: config/i386/i386.c:4228
+#: config/i386/i386.c:4231
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s; did you mean %qs?"
 msgstr "%qs对%qs而言无效"
 
-#: config/i386/i386.c:4230
+#: config/i386/i386.c:4233
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4235
+#: config/i386/i386.c:4238
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-march=%> switch are: %s"
 msgstr "%qs对%qs而言无效"
 
-#: config/i386/i386.c:4236
+#: config/i386/i386.c:4239
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"arch=\")%> attribute are: %s"
 msgstr "%qs对%qs而言无效"
 
-#: config/i386/i386.c:4284
+#: config/i386/i386.c:4287
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for -mtune= switch"
 msgid "bad value (%qs) for %<-mtune=%> switch"
 msgstr "-mtune= 开关的值 (%s) 错误"
 
-#: config/i386/i386.c:4285
+#: config/i386/i386.c:4288
 #, fuzzy, gcc-internal-format
 #| msgid "bad value (%s) for %stune=%s %s"
 msgid "bad value (%qs) for %<target(\"tune=\")%> attribute"
 msgstr "%2$stune=%3$s%4$s所带参数(%1$s)不正确"
 
-#: config/i386/i386.c:4305
+#: config/i386/i386.c:4308
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s; did you mean %qs?"
 msgstr "%qs对%qs而言无效"
 
-#: config/i386/i386.c:4307
+#: config/i386/i386.c:4310
 #, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s; did you mean %qs?"
 msgstr ""
 
-#: config/i386/i386.c:4312
+#: config/i386/i386.c:4315
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<-mtune=%> switch are: %s"
 msgstr "%qs对%qs而言无效"
 
-#: config/i386/i386.c:4313
+#: config/i386/i386.c:4316
 #, fuzzy, gcc-internal-format
 msgid "valid arguments to %<target(\"tune=\")%> attribute are: %s"
 msgstr "%qs对%qs而言无效"
 
-#: config/i386/i386.c:4379
+#: config/i386/i386.c:4382
 #, fuzzy, gcc-internal-format
 msgid "-mregparm is ignored in 64-bit mode"
 msgstr "64-bit ABI 在 ESA/390 模式下不受支持"
 
-#: config/i386/i386.c:4381
+#: config/i386/i386.c:4384
 #, fuzzy, gcc-internal-format
 msgid "-mregparm is ignored for Intel MCU psABI"
 msgstr "64-bit ABI 在 ESA/390 模式下不受支持"
 
-#: config/i386/i386.c:4384
+#: config/i386/i386.c:4387
 #, gcc-internal-format, gfc-internal-format
 msgid "-mregparm=%d is not between 0 and %d"
 msgstr "-mregparm=%d 不在 0 和 %d 之间"
 
-#: config/i386/i386.c:4417
+#: config/i386/i386.c:4420
 #, fuzzy, gcc-internal-format
 #| msgid "%srtd%s is ignored in 64bit mode"
 msgid "%<-mrtd%> is ignored in 64bit mode"
 msgstr "%srtd%s 在 64 位模式下被忽略"
 
-#: config/i386/i386.c:4418
+#: config/i386/i386.c:4421
 #, fuzzy, gcc-internal-format
 #| msgid "%srtd%s is ignored in 64bit mode"
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "%srtd%s 在 64 位模式下被忽略"
 
-#: config/i386/i386.c:4497
+#: config/i386/i386.c:4500
 #, fuzzy, gcc-internal-format
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "堆栈限制在此目标机上不受支持"
 
-#: config/i386/i386.c:4500
+#: config/i386/i386.c:4503
 #, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d 的值不在 %d 和 %d 之间"
 
-#: config/i386/i386.c:4523
+#: config/i386/i386.c:4526
 #, gcc-internal-format, gfc-internal-format
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr "-mincoming-stack-boundary=%d 不在 %d 和 12 之间"
 
-#: config/i386/i386.c:4536
+#: config/i386/i386.c:4539
 #, gcc-internal-format
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "-mnop-mcount 与此目标不兼容"
 
-#: config/i386/i386.c:4539
+#: config/i386/i386.c:4542
 #, fuzzy, gcc-internal-format
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr "模块间优化未为 C++ 实现"
 
-#: config/i386/i386.c:4545
+#: config/i386/i386.c:4548
 #, fuzzy, gcc-internal-format
 #| msgid "%ssseregparm%s used without SSE enabled"
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "使用了 %ssseregparm%s 却没有启用 SEE"
 
-#: config/i386/i386.c:4546
+#: config/i386/i386.c:4549
 #, fuzzy, gcc-internal-format
 #| msgid "%ssseregparm%s used without SSE enabled"
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "使用了 %ssseregparm%s 却没有启用 SEE"
 
-#: config/i386/i386.c:4556
+#: config/i386/i386.c:4559
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "SSE 指令集已禁用，使用 387 指令"
 
-#: config/i386/i386.c:4563
+#: config/i386/i386.c:4566
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "387 指令集已禁用，使用 SSE 指令"
 
-#: config/i386/i386.c:4613
+#: config/i386/i386.c:4616
 #, fuzzy, gcc-internal-format
 #| msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr "堆栈探针目前需要框架指针或 %saccumulate-outgoing-args%s 来保证正确性"
 
-#: config/i386/i386.c:4615
+#: config/i386/i386.c:4618
 #, fuzzy, gcc-internal-format
 #| msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr "堆栈探针目前需要框架指针或 %saccumulate-outgoing-args%s 来保证正确性"
 
-#: config/i386/i386.c:4629
+#: config/i386/i386.c:4632
 #, fuzzy, gcc-internal-format
 #| msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr "堆栈探针目前需要框架指针或 %saccumulate-outgoing-args%s 来保证正确性"
 
-#: config/i386/i386.c:4631
+#: config/i386/i386.c:4634
 #, fuzzy, gcc-internal-format
 #| msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr "堆栈探针目前需要框架指针或 %saccumulate-outgoing-args%s 来保证正确性"
 
-#: config/i386/i386.c:4741
+#: config/i386/i386.c:4744
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr "-mfentry 在 32 位下不能和 -fpic 同时使用"
 
-#: config/i386/i386.c:4744
+#: config/i386/i386.c:4747
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr "-mno-fentry 与 SEH 不兼容"
 
-#: config/i386/i386.c:4748
+#: config/i386/i386.c:4751
 #, gcc-internal-format
 msgid "-mcall-ms2sysv-xlogues isn%'t currently supported with SEH"
 msgstr ""
 
-#: config/i386/i386.c:4813 config/powerpcspe/powerpcspe.c:5663
+#: config/i386/i386.c:4816 config/powerpcspe/powerpcspe.c:5663
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown option for -mrecip=%s"
 msgstr "未知的选项：%s %s %s"
 
-#: config/i386/i386.c:4870 config/powerpcspe/powerpcspe.c:5339
+#: config/i386/i386.c:4873 config/powerpcspe/powerpcspe.c:5339
 #, gcc-internal-format
 msgid "%qs is not a valid number in -mstack-protector-guard-offset="
 msgstr ""
 
-#: config/i386/i386.c:4875 config/powerpcspe/powerpcspe.c:5344
+#: config/i386/i386.c:4878 config/powerpcspe/powerpcspe.c:5344
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid offset in -mstack-protector-guard-offset="
 msgstr "%qs对%qs而言无效"
 
-#: config/i386/i386.c:4907 config/powerpcspe/powerpcspe.c:5356
+#: config/i386/i386.c:4910 config/powerpcspe/powerpcspe.c:5356
 #, gcc-internal-format
 msgid "%qs is not a valid base register in -mstack-protector-guard-reg="
 msgstr ""
 
-#: config/i386/i386.c:5506 config/i386/i386.c:5553 config/s390/s390.c:15812
+#: config/i386/i386.c:5509 config/i386/i386.c:5556 config/s390/s390.c:15812
 #: config/s390/s390.c:15862 config/s390/s390.c:15879
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr "attribute(target(\"%s\"))未知"
 
-#: config/i386/i386.c:5534
+#: config/i386/i386.c:5537
 #, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr "option(\"%s\")已经被指定"
 
-#: config/i386/i386.c:5837
+#: config/i386/i386.c:5840
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and cdecl attributes are not compatible"
 msgid "interrupt and naked attributes are not compatible"
 msgstr "stdcall 和 cdecl 属性互不兼容"
 
-#: config/i386/i386.c:5852
+#: config/i386/i386.c:5855
 #, gcc-internal-format
 msgid "Only DWARF debug format is supported for interrupt service routine."
 msgstr ""
 
-#: config/i386/i386.c:5901
+#: config/i386/i386.c:5904
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mindirect-branch=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s 与 -mcall-%s 互不兼容"
 
-#: config/i386/i386.c:5913
+#: config/i386/i386.c:5916
 #, gcc-internal-format
 msgid "%<-mindirect-branch=thunk-extern%>, %<-fcf-protection=branch%> and %<-fcheck-pointer-bounds%> are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:5949
+#: config/i386/i386.c:5952
 #, fuzzy, gcc-internal-format
 #| msgid "-msdata=%s and -mcall-%s are incompatible"
 msgid "%<-mfunction-return=%s%> and %<-mcmodel=large%> are not compatible"
 msgstr "-msdata=%s 与 -mcall-%s 互不兼容"
 
-#: config/i386/i386.c:6047
+#: config/i386/i386.c:6050
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "2 byte cop instructions are not allowed in 64-bit VLIW mode"
 msgid "%s instructions aren't allowed in %s service routine"
 msgstr "2 字节 cop 指针不允许被用在 VLIW 模式中"
 
-#: config/i386/i386.c:6051
+#: config/i386/i386.c:6054
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in function with no_caller_saved_registers attribute"
 msgstr "为每个函数使用堆栈保护机制"
 
-#: config/i386/i386.c:6465 config/i386/i386.c:6516
+#: config/i386/i386.c:6468 config/i386/i386.c:6519
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "fastcall 和 regparm 属性互不兼容"
 
-#: config/i386/i386.c:6470
+#: config/i386/i386.c:6473
 #, fuzzy, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "fastcall 和 thiscall 属性互不兼容"
 
-#: config/i386/i386.c:6477 config/i386/i386.c:41444
+#: config/i386/i386.c:6480 config/i386/i386.c:41438
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "%qE属性需要一个整常量作为实参"
 
-#: config/i386/i386.c:6483
+#: config/i386/i386.c:6486
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "%qE属性的实参大于 %d"
 
-#: config/i386/i386.c:6508 config/i386/i386.c:6551
+#: config/i386/i386.c:6511 config/i386/i386.c:6554
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "fastcall 和 cdecl 属性互不兼容"
 
-#: config/i386/i386.c:6512
+#: config/i386/i386.c:6515
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "fastcall 和 stdcall 属性互不兼容"
 
-#: config/i386/i386.c:6520 config/i386/i386.c:6569
+#: config/i386/i386.c:6523 config/i386/i386.c:6572
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "fastcall 和 thiscall 属性互不兼容"
 
-#: config/i386/i386.c:6530 config/i386/i386.c:6547
+#: config/i386/i386.c:6533 config/i386/i386.c:6550
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "stdcall 和 cdecl 属性互不兼容"
 
-#: config/i386/i386.c:6534
+#: config/i386/i386.c:6537
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "stdcall 和 fastcall 属性互不兼容"
 
-#: config/i386/i386.c:6538 config/i386/i386.c:6565
+#: config/i386/i386.c:6541 config/i386/i386.c:6568
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "stdcall 和 thiscall 属性互不兼容"
 
-#: config/i386/i386.c:6555 config/i386/i386.c:6573
+#: config/i386/i386.c:6558 config/i386/i386.c:6576
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "cdecl 和 thiscall 属性互不兼容"
 
-#: config/i386/i386.c:6561
+#: config/i386/i386.c:6564
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "%qE属性在不是类的类型上被忽略"
 
-#: config/i386/i386.c:6805
+#: config/i386/i386.c:6808
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "带属性 sseregparm 调用%qD却没有启用 SSE/SSE2"
 
-#: config/i386/i386.c:6808
+#: config/i386/i386.c:6811
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "带属性 sseregparm 调用%qT却没有启用 SSE/SSE2"
 
-#: config/i386/i386.c:7126
+#: config/i386/i386.c:7129
 #, gcc-internal-format
 msgid "X32 does not support ms_abi attribute"
 msgstr "X32 不支持 ms_abi 属性"
 
-#: config/i386/i386.c:7160
+#: config/i386/i386.c:7163
 #, gcc-internal-format
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr "ms_hook_prologue 与嵌套函数不兼容"
 
-#: config/i386/i386.c:7502
+#: config/i386/i386.c:7505
 #, fuzzy, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr "没有启用 MMX，却出现了 MMX 向量实参，这改变了 ABI"
 
-#: config/i386/i386.c:7508
+#: config/i386/i386.c:7511
 #, fuzzy, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr "没有启用 SSE，却有 SSE 向量返回值，这改变了 ABI"
 
-#: config/i386/i386.c:7522
+#: config/i386/i386.c:7525
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr "没有启用 AVX，却出现了 AVX 向量实参，这改变了 ABI"
 
-#: config/i386/i386.c:7528
+#: config/i386/i386.c:7531
 #, fuzzy, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr "没有启用 AVX，却出现了 AVX 向量实参，这改变了 ABI"
 
-#: config/i386/i386.c:7544
+#: config/i386/i386.c:7547
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr "没有启用 SSE，却出现了 SSE 向量实参，这改变了 ABI"
 
-#: config/i386/i386.c:7550
+#: config/i386/i386.c:7553
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr "没有启用 SSE，却有 SSE 向量返回值，这改变了 ABI"
 
-#: config/i386/i386.c:7566
+#: config/i386/i386.c:7569
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr "没有启用 MMX，却出现了 MMX 向量实参，这改变了 ABI"
 
-#: config/i386/i386.c:7572
+#: config/i386/i386.c:7575
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr "没有启用 MMX却返回 MMX 向量，这改变了 ABI"
 
-#: config/i386/i386.c:7754
+#: config/i386/i386.c:7757
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr "在 GCC 4.4 中传递带有一个可变数组成员的结构的 ABI 有了改变"
 
-#: config/i386/i386.c:7871
+#: config/i386/i386.c:7874
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr "在 GCC 4.4 中传递有 long double 的联合的 ABI 有改变"
 
-#: config/i386/i386.c:7989
+#: config/i386/i386.c:7992
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr "在 GCC 4.4 中传递带有复数浮点成员结构的 ABI 有了改变"
 
-#: config/i386/i386.c:8152
+#: config/i386/i386.c:8155
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr "已禁用 SSE 却在 SSE 寄存器中返回"
 
-#: config/i386/i386.c:8158
+#: config/i386/i386.c:8161
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr "已禁用 SSE 却在 SSE 寄存器中传递参数"
 
-#: config/i386/i386.c:8174
+#: config/i386/i386.c:8177
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr "已禁用 x87 却在 x87 寄存器中返回"
 
-#: config/i386/i386.c:8471 config/i386/i386.c:8750 config/i386/i386.c:9276
+#: config/i386/i386.c:8474 config/i386/i386.c:8753 config/i386/i386.c:9279
 #, fuzzy, gcc-internal-format
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr "带属性 sseregparm 调用%qD却没有启用 SSE/SSE2"
 
-#: config/i386/i386.c:8473 config/i386/i386.c:8752 config/i386/i386.c:9278
+#: config/i386/i386.c:8476 config/i386/i386.c:8755 config/i386/i386.c:9281
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr ""
 
-#: config/i386/i386.c:9178
+#: config/i386/i386.c:9181
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr "在 GCC 4.4 中传递有 long double 的联合的 ABI 有改变"
 
-#: config/i386/i386.c:11601
+#: config/i386/i386.c:11604
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "assert: %s is assign compatible with %s"
 msgid "-mcall-ms2sysv-xlogues is not compatible with %s"
 msgstr "assert：%s 与 %s 赋值兼容"
 
-#: config/i386/i386.c:13593
+#: config/i386/i386.c:13596
 #, fuzzy, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr "ms_hook_prologue 与嵌套函数不兼容"
 
-#: config/i386/i386.c:13683
+#: config/i386/i386.c:13686
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr ""
 
-#: config/i386/i386.c:14970
+#: config/i386/i386.c:14973
 #, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr "-fsplit-stack 不支持对嵌套函数使用 fastcall"
 
-#: config/i386/i386.c:14990
+#: config/i386/i386.c:14993
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
 msgstr "-fsplit-stack 不支持在嵌套函数中使用 2 个寄存器参数"
@@ -33123,85 +33167,85 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:15001
+#: config/i386/i386.c:15004
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr "-fsplit-stack 不支持 3 个寄存器参数"
 
-#: config/i386/i386.c:17939
+#: config/i386/i386.c:17942
 #, gcc-internal-format
 msgid "'V' modifier on non-integer register"
 msgstr ""
 
-#: config/i386/i386.c:17950 config/i386/i386.c:17964
+#: config/i386/i386.c:17953 config/i386/i386.c:17967
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported operand size for extended register"
 msgid "unsupported size for integer register"
 msgstr "扩展的寄存器不支持的操作数大小"
 
-#: config/i386/i386.c:17996
+#: config/i386/i386.c:17999
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr "扩展的寄存器没有高半部分"
 
-#: config/i386/i386.c:18011
+#: config/i386/i386.c:18014
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr "扩展的寄存器不支持的操作数大小"
 
-#: config/i386/i386.c:18202
+#: config/i386/i386.c:18205
 #, fuzzy, gcc-internal-format
 msgid "non-integer operand used with operand code 'z'"
 msgstr "非整数操作数使用了操作数代码‘%c’"
 
-#: config/i386/i386.c:28467
+#: config/i386/i386.c:28470
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine can't be called directly"
 msgstr "Thumb 模式中不能编码中断服务进程"
 
-#: config/i386/i386.c:29995
+#: config/i386/i386.c:29998
 #, gcc-internal-format
 msgid "empty class %qT parameter passing ABI changes in -fabi-version=12 (GCC 8)"
 msgstr ""
 
-#: config/i386/i386.c:32435
+#: config/i386/i386.c:32438
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr ""
 
-#: config/i386/i386.c:32485
+#: config/i386/i386.c:32488
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for %s"
 msgstr "找不到任何查看器用于 %s/%s\n"
 
-#: config/i386/i386.c:32495
+#: config/i386/i386.c:32498
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr ""
 
-#: config/i386/i386.c:32657
+#: config/i386/i386.c:32660
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386.c:32662 config/i386/i386.c:32938
-#: config/rs6000/rs6000.c:37850
+#: config/i386/i386.c:32665 config/i386/i386.c:32941
+#: config/rs6000/rs6000.c:37906
 #, fuzzy, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "联合成员函数%qD被声明为虚函数"
 
-#: config/i386/i386.c:32795 config/rs6000/rs6000.c:37607
+#: config/i386/i386.c:32798 config/rs6000/rs6000.c:37663
 #, fuzzy, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "嵌套函数在此目标机上不受支持"
 
-#: config/i386/i386.c:33207
+#: config/i386/i386.c:33210
 #, fuzzy, gcc-internal-format
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr "%qs的实参必须是一个 2 位无符号字面常量"
 
-#: config/i386/i386.c:33232 config/i386/i386.c:33282
+#: config/i386/i386.c:33235 config/i386/i386.c:33285
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Parameter to builtin not valid: %s"
 msgstr ""
@@ -33208,233 +33252,233 @@
 "\n"
 "错误：“%s”并非有效新闻群组！\n"
 
-#: config/i386/i386.c:33975 config/i386/i386.c:35415
+#: config/i386/i386.c:33978 config/i386/i386.c:35418
 #, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "最后一个实参必须是一个 2 位立即数"
 
-#: config/i386/i386.c:34370
+#: config/i386/i386.c:34373
 #, fuzzy, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "最后一个实参必须是一个 8 位立即数"
 
-#: config/i386/i386.c:34465
+#: config/i386/i386.c:34468
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "最后一个实参必须是一个 8 位立即数"
 
-#: config/i386/i386.c:35346
+#: config/i386/i386.c:35349
 #, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "最后一个实参必须是一个 1 位立即数"
 
-#: config/i386/i386.c:35361
+#: config/i386/i386.c:35364
 #, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "最后一个实参必须是一个 3 位立即数"
 
-#: config/i386/i386.c:35394
+#: config/i386/i386.c:35397
 #, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "最后一个实参必须是一个 4 位立即数"
 
-#: config/i386/i386.c:35434
+#: config/i386/i386.c:35437
 #, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "最后一个实参必须是一个 1 位立即数"
 
-#: config/i386/i386.c:35447
+#: config/i386/i386.c:35450
 #, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "最后一个实参必须是一个 5 位立即数"
 
-#: config/i386/i386.c:35457
+#: config/i386/i386.c:35460
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "倒数第二个实参必须是一个 8 位立即数"
 
-#: config/i386/i386.c:35462 config/i386/i386.c:36249
+#: config/i386/i386.c:35465 config/i386/i386.c:36252
 #, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "最后一个实参必须是一个 8 位立即数"
 
-#: config/i386/i386.c:35596
+#: config/i386/i386.c:35599
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr "%<__builtin_prefetch%>的第三个实参必须是一个常量"
 
-#: config/i386/i386.c:35601
+#: config/i386/i386.c:35604
 #, fuzzy, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr "不正确的格式：%s\n"
 
-#: config/i386/i386.c:35607 config/i386/i386.c:35814
+#: config/i386/i386.c:35610 config/i386/i386.c:35817
 #, fuzzy, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr "控制生成的浮点舍入模式"
 
-#: config/i386/i386.c:35796
+#: config/i386/i386.c:35799
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "最后一个实参必须是一个 4 位立即数"
 
-#: config/i386/i386.c:35802
+#: config/i386/i386.c:35805
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "最后一个实参必须是一个 5 位立即数"
 
-#: config/i386/i386.c:35805
+#: config/i386/i386.c:35808
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "最后一个实参必须是一个 8 位立即数"
 
-#: config/i386/i386.c:36247
+#: config/i386/i386.c:36250
 #, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "最后一个参数必须是一个 32 位立即数"
 
-#: config/i386/i386.c:36329 config/powerpcspe/powerpcspe.c:16219
-#: config/rs6000/rs6000.c:15304
+#: config/i386/i386.c:36332 config/powerpcspe/powerpcspe.c:16219
+#: config/rs6000/rs6000.c:15348
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr "选择子必须是 0 到 %wi 间的整常量"
 
-#: config/i386/i386.c:36539
+#: config/i386/i386.c:36542
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr "%qE需要未知的 ISA 选项"
 
-#: config/i386/i386.c:36543
+#: config/i386/i386.c:36546
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "%qE需要 ISA 选项 %s"
 
-#: config/i386/i386.c:37381
+#: config/i386/i386.c:37375
 #, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "最后一个实参必须是一个立即数"
 
-#: config/i386/i386.c:38108 config/i386/i386.c:38290
+#: config/i386/i386.c:38102 config/i386/i386.c:38284
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "最后一个实参必须是一个 4 位立即数"
 
-#: config/i386/i386.c:38343
+#: config/i386/i386.c:38337
 #, fuzzy, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "左实参必须是一个切片"
 
-#: config/i386/i386.c:38349
+#: config/i386/i386.c:38343
 #, fuzzy, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr "(提示略过)"
 
-#: config/i386/i386.c:38368
+#: config/i386/i386.c:38362
 #, fuzzy, gcc-internal-format
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr "最后一个实参必须是一个 8 位立即数"
 
-#: config/i386/i386.c:41431
+#: config/i386/i386.c:41425
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "%qE属性只能在 32 位下使用"
 
-#: config/i386/i386.c:41452
+#: config/i386/i386.c:41446
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "%qE属性的实参不是一个字符串常量"
 
-#: config/i386/i386.c:41485 config/i386/i386.c:41494
+#: config/i386/i386.c:41479 config/i386/i386.c:41488
 #, gcc-internal-format
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr "ms_abi 和 sysv_abi 属性互不兼容"
 
-#: config/i386/i386.c:41530 config/powerpcspe/powerpcspe.c:35868
-#: config/rs6000/rs6000.c:33065
+#: config/i386/i386.c:41524 config/powerpcspe/powerpcspe.c:35868
+#: config/rs6000/rs6000.c:33121
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "%qE不兼容的属性已被忽略"
 
-#: config/i386/i386.c:41555 config/i386/i386.c:41577 config/ia64/ia64.c:815
+#: config/i386/i386.c:41549 config/i386/i386.c:41571 config/ia64/ia64.c:815
 #: config/s390/s390.c:1153
 #, gcc-internal-format
 msgid "%qE attribute requires a string constant argument"
 msgstr "%qE属性需要一个字符串常量作为实参"
 
-#: config/i386/i386.c:41565 config/i386/i386.c:41587 config/s390/s390.c:1182
+#: config/i386/i386.c:41559 config/i386/i386.c:41581 config/s390/s390.c:1182
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qE attribute is not \"ilink1\" or \"ilink2\""
 msgid "argument to %qE attribute is not (keep|thunk|thunk-inline|thunk-extern)"
 msgstr "%qE属性的实参不是“ilink1”或“ilink2”"
 
-#: config/i386/i386.c:41619
+#: config/i386/i386.c:41613
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386.c:41626
+#: config/i386/i386.c:41620
 #, gcc-internal-format, gfc-internal-format
 msgid "interrupt service routine should have unsigned %sint as the second argument"
 msgstr ""
 
-#: config/i386/i386.c:41636
+#: config/i386/i386.c:41630
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386.c:41639
+#: config/i386/i386.c:41633
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine can't have non-void return value"
 msgstr "Thumb 模式中不能编码中断服务进程"
 
-#: config/i386/i386.c:44676
+#: config/i386/i386.c:44670
 #, fuzzy, gcc-internal-format
 #| msgid "By-value argument at %L is not allowed in this context"
 msgid "alternatives not allowed in asm flag output"
 msgstr "%L处上下文中不允许使用按值传递的实参"
 
-#: config/i386/i386.c:44740
+#: config/i386/i386.c:44734
 #, fuzzy, gcc-internal-format
 msgid "unknown asm flag output %qs"
 msgstr "未知的 TLS 模型%qs"
 
-#: config/i386/i386.c:44769
+#: config/i386/i386.c:44763
 #, fuzzy, gcc-internal-format
 msgid "invalid type for asm flag output"
 msgstr "向函数类型%qT的转换无效"
 
-#: config/i386/i386.c:50634
+#: config/i386/i386.c:50628
 #, fuzzy, gcc-internal-format
 msgid "unknown architecture specific memory model"
 msgstr "未知的架构‘%s’"
 
-#: config/i386/i386.c:50641
+#: config/i386/i386.c:50635
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50647
+#: config/i386/i386.c:50641
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50671 config/i386/i386.c:50787
+#: config/i386/i386.c:50665 config/i386/i386.c:50781
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unsupported simdlen %d"
 msgstr "不支持的真理哈希类型 %d。\n"
 
-#: config/i386/i386.c:50690
+#: config/i386/i386.c:50684
 #, fuzzy, gcc-internal-format
 msgid "unsupported return type %qT for simd"
 msgstr "%<operator new%>必须返回%qT"
 
-#: config/i386/i386.c:50712
+#: config/i386/i386.c:50706
 #, fuzzy, gcc-internal-format
 msgid "unsupported argument type %qT for simd"
 msgstr "需要类型%qT，但实参的类型为%qT"
 
-#: config/i386/i386.c:51033
+#: config/i386/i386.c:51027
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr ""
@@ -33658,7 +33702,7 @@
 msgstr "interrupt_thread 只在 fido 中可用"
 
 #: config/m68k/m68k.c:1128 config/powerpcspe/powerpcspe.c:28512
-#: config/rs6000/rs6000.c:25791
+#: config/rs6000/rs6000.c:25868
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "不支持堆栈限制表达式"
@@ -34244,58 +34288,58 @@
 
 #. Trampoline is not supported on reduced-set registers yet.
 #: config/nds32/nds32.c:2327 config/nds32/nds32.c:2381
-#: config/nds32/nds32.c:3127 config/nds32/nds32.c:3201
-#: config/nds32/nds32.c:3216 config/nds32/nds32.c:3222
-#: config/nds32/nds32.c:3284 config/nds32/nds32.c:3290
-#: config/nds32/nds32.c:3322
+#: config/nds32/nds32.c:3128 config/nds32/nds32.c:3202
+#: config/nds32/nds32.c:3217 config/nds32/nds32.c:3223
+#: config/nds32/nds32.c:3285 config/nds32/nds32.c:3291
+#: config/nds32/nds32.c:3323
 #, fuzzy, gcc-internal-format
 msgid "a nested function is not supported for reduced registers"
 msgstr "嵌套函数蹦床在此目标机上不受支持"
 
 #. The enum index value for array size is out of range.
-#: config/nds32/nds32.c:3025
+#: config/nds32/nds32.c:3026
 #, fuzzy, gcc-internal-format
 msgid "intrinsic register index is out of range"
 msgstr "类型索引编号 %d 超出范围\n"
 
-#: config/nds32/nds32.c:3041 config/nds32/nds32.c:3048
-#: config/nds32/nds32.c:3055 config/nds32/nds32.c:3062
-#: config/nds32/nds32.c:3069
+#: config/nds32/nds32.c:3042 config/nds32/nds32.c:3049
+#: config/nds32/nds32.c:3056 config/nds32/nds32.c:3063
+#: config/nds32/nds32.c:3070
 #, fuzzy, gcc-internal-format
 msgid "CCTL intrinsic function subtype out of range!"
 msgstr "类型索引编号 %d 超出范围\n"
 
-#: config/nds32/nds32.c:3508
+#: config/nds32/nds32.c:3509
 #, fuzzy, gcc-internal-format
 msgid "invalid id value for interrupt/exception attribute"
 msgstr "迭代变量%qE类型无效"
 
-#: config/nds32/nds32.c:3536
+#: config/nds32/nds32.c:3537
 #, fuzzy, gcc-internal-format
 msgid "invalid id value for reset attribute"
 msgstr "重置属性为默认值"
 
-#: config/nds32/nds32.c:3552
+#: config/nds32/nds32.c:3553
 #, fuzzy, gcc-internal-format
 msgid "invalid nmi function for reset attribute"
 msgstr "属性%qs的参数无效"
 
-#: config/nds32/nds32.c:3565
+#: config/nds32/nds32.c:3566
 #, fuzzy, gcc-internal-format
 msgid "invalid warm function for reset attribute"
 msgstr "属性%qs的参数无效"
 
-#: config/nds32/nds32.c:3638
+#: config/nds32/nds32.c:3639
 #, gcc-internal-format
 msgid "Disable FPU ISA, the ABI option must be enable '-mfloat-abi=soft'"
 msgstr ""
 
-#: config/nds32/nds32.c:3641
+#: config/nds32/nds32.c:3642
 #, gcc-internal-format
 msgid "'-mabi=2fp+' option only support when FPU available, must be enable '-mext-fpu-sp' or '-mext-fpu-dp'"
 msgstr ""
 
-#: config/nds32/nds32.c:3647
+#: config/nds32/nds32.c:3648
 #, fuzzy, gcc-internal-format
 msgid "position-independent code not supported"
 msgstr "尽可能生成与位置无关的代码(大模式)"
@@ -34637,12 +34681,12 @@
 msgid "junk at end of #pragma longcall"
 msgstr "#pragma longcall 末尾有垃圾字符"
 
-#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6154
+#: config/powerpcspe/powerpcspe-c.c:5661 config/rs6000/rs6000-c.c:6152
 #, gcc-internal-format
 msgid "vec_lvsl is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6158
+#: config/powerpcspe/powerpcspe-c.c:5665 config/rs6000/rs6000-c.c:6156
 #, gcc-internal-format
 msgid "vec_lvsr is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
@@ -34696,7 +34740,7 @@
 msgid "vec_insert only accepts 3 arguments"
 msgstr "vec_insert 只接受三个参数"
 
-#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6868
+#: config/powerpcspe/powerpcspe-c.c:6468 config/rs6000/rs6000-c.c:6866
 #, fuzzy, gcc-internal-format
 #| msgid "passing arg %d of %qE discards qualifiers frompointer target type"
 msgid "passing arg %d of %qE discards qualifiers from pointer target type"
@@ -34784,7 +34828,7 @@
 msgid "target attribute or pragma changes SPE ABI"
 msgstr "目标属性或 pragma 改变了 SPE ABI"
 
-#: config/powerpcspe/powerpcspe.c:4351 config/rs6000/rs6000.c:4223
+#: config/powerpcspe/powerpcspe.c:4351 config/rs6000/rs6000.c:4243
 #, gcc-internal-format
 msgid "AltiVec not supported in this target"
 msgstr "AltiVec 在此目标机上不受支持"
@@ -34939,7 +34983,7 @@
 msgid "-mvsx-small-integer requires -mpower8-vector, -mupper-regs-di, and -mdirect-move"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:4959 config/rs6000/rs6000.c:4601
+#: config/powerpcspe/powerpcspe.c:4959 config/rs6000/rs6000.c:4628
 #, gcc-internal-format
 msgid "target attribute or pragma changes long double size"
 msgstr "目标属性或 pragma 改变了 long double 的大小"
@@ -34980,22 +35024,22 @@
 msgstr "%2$sveclibabi=%3$s %4$s向量库 ABI 类型(%1$s)未知"
 
 #: config/powerpcspe/powerpcspe.c:5140 config/powerpcspe/powerpcspe.c:5155
-#: config/rs6000/rs6000.c:4766 config/rs6000/rs6000.c:4781
+#: config/rs6000/rs6000.c:4791 config/rs6000/rs6000.c:4806
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr "目标属性或 pragma 改变了 AltiVec ABI"
 
-#: config/powerpcspe/powerpcspe.c:5168 config/rs6000/rs6000.c:4794
+#: config/powerpcspe/powerpcspe.c:5168 config/rs6000/rs6000.c:4819
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr "目标属性或 pragma 改变了 darwin64 ABI"
 
-#: config/powerpcspe/powerpcspe.c:5234 config/rs6000/rs6000.c:4828
+#: config/powerpcspe/powerpcspe.c:5234 config/rs6000/rs6000.c:4853
 #, gcc-internal-format
 msgid "target attribute or pragma changes single precision floating point"
 msgstr "目标属性或 pragma 改变了单精度浮点数"
 
-#: config/powerpcspe/powerpcspe.c:5237 config/rs6000/rs6000.c:4831
+#: config/powerpcspe/powerpcspe.c:5237 config/rs6000/rs6000.c:4856
 #, gcc-internal-format
 msgid "target attribute or pragma changes double precision floating point"
 msgstr "目标属性或 pragma 改变了双精度浮点数"
@@ -35005,12 +35049,12 @@
 msgid "-mstack-protector-guard=tls needs a valid base register"
 msgstr ""
 
-#: config/powerpcspe/powerpcspe.c:8415 config/rs6000/rs6000.c:7925
+#: config/powerpcspe/powerpcspe.c:8415 config/rs6000/rs6000.c:7950
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr "在 GCC 4.4 中传递有 long double 的联合的 ABI 有改变"
 
-#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11237
+#: config/powerpcspe/powerpcspe.c:11834 config/rs6000/rs6000.c:11269
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC 返回向量引用：非标准的 ABI 扩展，不保证兼容性"
@@ -35020,7 +35064,7 @@
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "不能在向量寄存器中返回值，因为 altivec 指令集已被禁用，使用 -maltivec 启用"
 
-#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11595
+#: config/powerpcspe/powerpcspe.c:12193 config/rs6000/rs6000.c:11633
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr "在 GCC 4.4 中传递有 long double 的联合的 ABI 有改变"
@@ -35030,12 +35074,12 @@
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "不能在向量寄存器中传递参数，因为 altivec 指令集已被禁用，使用 -maltivec 启用"
 
-#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12604
+#: config/powerpcspe/powerpcspe.c:13311 config/rs6000/rs6000.c:12648
 #, fuzzy, gcc-internal-format
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr "在 GCC 4.4 中传递带有复数浮点成员结构的 ABI 有了改变"
 
-#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12779
+#: config/powerpcspe/powerpcspe.c:13486 config/rs6000/rs6000.c:12823
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC 传递向量引用：非标准的 ABI 扩展，不保证兼容性"
@@ -35045,28 +35089,28 @@
 msgid "internal error: builtin function %s already processed"
 msgstr "内部错误：内建函数 %s 没有类型"
 
-#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:13971
+#: config/powerpcspe/powerpcspe.c:14785 config/rs6000/rs6000.c:14015
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be an 8-bit field value"
 msgstr "实参 1 必须是一个 5 位有符号字面量"
 
-#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14015
+#: config/powerpcspe/powerpcspe.c:14831 config/rs6000/rs6000.c:14059
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "实参 1 必须是一个 5 位有符号字面量"
 
 #: config/powerpcspe/powerpcspe.c:14934 config/powerpcspe/powerpcspe.c:16803
-#: config/rs6000/rs6000.c:14101
+#: config/rs6000/rs6000.c:14145
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "实参 2 必须是一个 5 位无符号字面量"
 
-#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14119
+#: config/powerpcspe/powerpcspe.c:14952 config/rs6000/rs6000.c:14163
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "实参 2 必须是一个 1 位无符号字面量"
 
-#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14135
+#: config/powerpcspe/powerpcspe.c:14966 config/rs6000/rs6000.c:14179
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 7-bit unsigned literal"
@@ -35087,12 +35131,12 @@
 msgid "builtin %s is only valid in 64-bit mode"
 msgstr "%srtd%s 在 64 位模式下被忽略"
 
-#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14791
+#: config/powerpcspe/powerpcspe.c:15599 config/rs6000/rs6000.c:14835
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %d must be an unsigned literal"
 msgstr "实参 2 必须是一个 5 位无符号字面量"
 
-#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14793
+#: config/powerpcspe/powerpcspe.c:15601 config/rs6000/rs6000.c:14837
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "__builtin_spe_predicate 的第 1 个实参越界"
@@ -35115,53 +35159,53 @@
 msgid "hwcap %s is an invalid argument to builtin %s"
 msgstr "属性%qs的参数无效"
 
-#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15065
+#: config/powerpcspe/powerpcspe.c:15860 config/rs6000/rs6000.c:15109
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "实参 3 必须是一个 4 位无符号字面量"
 
-#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15090
+#: config/powerpcspe/powerpcspe.c:15885 config/rs6000/rs6000.c:15134
 #, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "实参 2 必须是一个 2 位无符号字面量"
 
-#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15110
+#: config/powerpcspe/powerpcspe.c:15905 config/rs6000/rs6000.c:15154
 #, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "实参 2 必须是一个 1 位无符号字面量"
 
-#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15122
+#: config/powerpcspe/powerpcspe.c:15917 config/rs6000/rs6000.c:15166
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be 0 or 2"
 msgstr "数字必须是 0 或 1"
 
-#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15134
+#: config/powerpcspe/powerpcspe.c:15929 config/rs6000/rs6000.c:15178
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "实参 2 必须是一个 1 位无符号字面量"
 
-#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15148
+#: config/powerpcspe/powerpcspe.c:15943 config/rs6000/rs6000.c:15192
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "实参 2 必须是一个 5 位无符号字面量"
 
-#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15160
+#: config/powerpcspe/powerpcspe.c:15955 config/rs6000/rs6000.c:15204
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be 0 or 1"
 msgstr "数字必须是 0 或 1"
 
-#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15168
+#: config/powerpcspe/powerpcspe.c:15963 config/rs6000/rs6000.c:15212
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be in the range 0..15"
 msgstr "%2$qE的第 %1$d 个参数必须是在 %3$d 和 %4$d 之间"
 
-#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15237
-#: config/rs6000/rs6000.c:15569
+#: config/powerpcspe/powerpcspe.c:16152 config/rs6000/rs6000.c:15281
+#: config/rs6000/rs6000.c:15613
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "%qs的实参必须是一个 2 位无符号字面常量"
 
-#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15394
+#: config/powerpcspe/powerpcspe.c:16309 config/rs6000/rs6000.c:15438
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr "无法解析的重载 Altivec 内建函数%qF"
@@ -35287,7 +35331,7 @@
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr "内部错误：内建函数 %s 的第 %d 个参数有非预期的参数类型 %s"
 
-#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25758
+#: config/powerpcspe/powerpcspe.c:28481 config/rs6000/rs6000.c:25835
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr "栈帧太大"
@@ -35297,13 +35341,13 @@
 msgid "-fsplit-stack uses register r29"
 msgstr "ISO C90 不允许可变数组成员"
 
-#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29459
+#: config/powerpcspe/powerpcspe.c:32265 config/rs6000/rs6000.c:29536
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC target is not supported for this machine"
 msgid "Stack frame larger than 2G is not supported for -fsplit-stack"
 msgstr "#pragma GCC target 在此目标机上不受支持"
 
-#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30447
+#: config/powerpcspe/powerpcspe.c:33252 config/rs6000/rs6000.c:30524
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "此 ABI 不支持取样 64 位代码"
@@ -35313,22 +35357,22 @@
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr "您无法需地址的嵌套的函数如果您使用 -mno-pointers-to-nested-functions 选项。"
 
-#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32830
+#: config/powerpcspe/powerpcspe.c:35637 config/rs6000/rs6000.c:32907
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "在 AltiVec 类型中使用%<long double%>无效"
 
-#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32832
+#: config/powerpcspe/powerpcspe.c:35639 config/rs6000/rs6000.c:32909
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "在 AltiVec 类型中使用布尔类型无效"
 
-#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32834
+#: config/powerpcspe/powerpcspe.c:35641 config/rs6000/rs6000.c:32911
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "在 AltiVec 类型中使用%<complex%>无效"
 
-#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32836
+#: config/powerpcspe/powerpcspe.c:35643 config/rs6000/rs6000.c:32913
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr "在 AltiVec 类型中使用十进制浮点类型无效"
@@ -35338,7 +35382,7 @@
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr "不使用 -mvsx 时，在 AltiVec 类型中使用%<long%>对 64 位代码无效"
 
-#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32845
+#: config/powerpcspe/powerpcspe.c:35652 config/rs6000/rs6000.c:32922
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "已弃用在 AltiVec 类型中使用%<long%>；请改用%<int%>"
@@ -35886,79 +35930,79 @@
 "Please use an explicit cpu name.  Valid cpu names are: %s"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6168 config/rs6000/rs6000-c.c:6219
-#: config/rs6000/rs6000-c.c:6489 config/rs6000/rs6000-c.c:6555
-#: config/rs6000/rs6000-c.c:6916 config/rs6000/rs6000-c.c:6963
+#: config/rs6000/rs6000-c.c:6166 config/rs6000/rs6000-c.c:6217
+#: config/rs6000/rs6000-c.c:6487 config/rs6000/rs6000-c.c:6553
+#: config/rs6000/rs6000-c.c:6914 config/rs6000/rs6000-c.c:6961
 #, fuzzy, gcc-internal-format
 #| msgid "%s only accepts 1 argument"
 msgid "builtin %qs only accepts 2 arguments"
 msgstr "%s 只接受 1 个参数"
 
-#: config/rs6000/rs6000-c.c:6292 config/rs6000/rs6000-c.c:6375
-#: config/rs6000/rs6000-c.c:6736
+#: config/rs6000/rs6000-c.c:6290 config/rs6000/rs6000-c.c:6373
+#: config/rs6000/rs6000-c.c:6734
 #, fuzzy, gcc-internal-format
 #| msgid "%s only accepts 1 argument"
 msgid "builtin %qs only accepts 3 arguments"
 msgstr "%s 只接受 1 个参数"
 
-#: config/rs6000/rs6000-c.c:6484
+#: config/rs6000/rs6000-c.c:6482
 #, fuzzy, gcc-internal-format
 #| msgid "%s only accepts 1 argument"
 msgid "builtin %qs only accepts 1 argument"
 msgstr "%s 只接受 1 个参数"
 
-#: config/rs6000/rs6000-c.c:7054
+#: config/rs6000/rs6000-c.c:7052
 #, fuzzy, gcc-internal-format
 msgid "builtin %qs requires builtin %qs"
 msgstr "内建函数%q+D未被声明为函数"
 
-#: config/rs6000/rs6000-c.c:7058
+#: config/rs6000/rs6000-c.c:7056
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs not supported in this compiler configuration"
 msgstr "弱引用在此配置下不受支持"
 
-#: config/rs6000/rs6000-c.c:7068
+#: config/rs6000/rs6000-c.c:7066
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter combination for AltiVec intrinsic"
 msgid "invalid parameter combination for AltiVec intrinsic %qs"
 msgstr "对 AltiVec 内建函数来说无效的参数组合"
 
-#: config/rs6000/rs6000.c:3754 config/rs6000/rs6000.c:3757
-#: config/rs6000/rs6000.c:3760
+#: config/rs6000/rs6000.c:3772 config/rs6000/rs6000.c:3775
+#: config/rs6000/rs6000.c:3778
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is predetermined %qs for %qs"
 msgid "%qs requires %qs or %qs"
 msgstr "%qE可被预先确定为%qs，为%qs"
 
-#: config/rs6000/rs6000.c:3861
+#: config/rs6000/rs6000.c:3879
 #, fuzzy, gcc-internal-format
 #| msgid "-m64 requires PowerPC64 architecture, enabling"
 msgid "%qs requires PowerPC64 architecture, enabling"
 msgstr "-m64 需要 PowerPC64 架构，正在启用"
 
-#: config/rs6000/rs6000.c:4037
+#: config/rs6000/rs6000.c:4057
 #, gcc-internal-format
 msgid "%qs command-line option is deprecated"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4048
+#: config/rs6000/rs6000.c:4068
 #, fuzzy, gcc-internal-format
 #| msgid "-malign-power is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgid "%qs is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr "-malign-power 在 64 位 Darwin 下不受支持；它与已安装的 C 和 C++ 库不兼容"
 
-#: config/rs6000/rs6000.c:4147
+#: config/rs6000/rs6000.c:4167
 #, gcc-internal-format
 msgid "will not generate %qs instructions because assembler lacks %qs support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4240
+#: config/rs6000/rs6000.c:4260
 #, fuzzy, gcc-internal-format
 #| msgid "-mstring is not supported on little endian systems"
 msgid "%qs is not supported on little endian systems"
 msgstr "-mstring 在小端在前的系统上不受支持"
 
-#: config/rs6000/rs6000.c:4333
+#: config/rs6000/rs6000.c:4353
 #, gcc-internal-format
 msgid "power9 target option is incompatible with %<%s=<xxx>%> for <xxx> less than power9"
 msgstr ""
@@ -35965,7 +36009,7 @@
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:4341
+#: config/rs6000/rs6000.c:4361
 #, fuzzy, gcc-internal-format
 msgid "%qs incompatible with explicitly disabled options"
 msgstr "%qs必须与%qs一起使用"
@@ -35974,123 +36018,123 @@
 #. error messages.  However, if users have managed to select
 #. power9-fusion without selecting power8-fusion, they
 #. already know about undocumented flags.
-#: config/rs6000/rs6000.c:4366 config/rs6000/rs6000.c:4373
-#: config/rs6000/rs6000.c:4380 config/rs6000/rs6000.c:4388
-#: config/rs6000/rs6000.c:4407 config/rs6000/rs6000.c:4464
-#: config/rs6000/rs6000.c:4468 config/rs6000/rs6000.c:4485
-#: config/rs6000/rs6000.c:4538 config/rs6000/rs6000.c:4565
-#: config/rs6000/rs6000.c:4580 config/rs6000/rs6000.c:4588
-#: config/rs6000/rs6000.c:4684
+#: config/rs6000/rs6000.c:4386 config/rs6000/rs6000.c:4393
+#: config/rs6000/rs6000.c:4400 config/rs6000/rs6000.c:4408
+#: config/rs6000/rs6000.c:4427 config/rs6000/rs6000.c:4484
+#: config/rs6000/rs6000.c:4488 config/rs6000/rs6000.c:4505
+#: config/rs6000/rs6000.c:4558 config/rs6000/rs6000.c:4585
+#: config/rs6000/rs6000.c:4600 config/rs6000/rs6000.c:4608
+#: config/rs6000/rs6000.c:4709
 #, fuzzy, gcc-internal-format
 #| msgid "%qT referred to as %qs"
 msgid "%qs requires %qs"
 msgstr "%qT作为%qs被引用"
 
-#: config/rs6000/rs6000.c:4625
+#: config/rs6000/rs6000.c:4650
 #, fuzzy, gcc-internal-format
 #| msgid "using IEEE extended precision long double"
 msgid "Using IEEE extended precision long double"
 msgstr "使用 IEEE 扩展精度 long double"
 
-#: config/rs6000/rs6000.c:4627
+#: config/rs6000/rs6000.c:4652
 #, fuzzy, gcc-internal-format
 #| msgid "using IBM extended precision long double"
 msgid "Using IBM extended precision long double"
 msgstr "使用 IBM 扩展精度 long double"
 
-#: config/rs6000/rs6000.c:4644
+#: config/rs6000/rs6000.c:4669
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "%qs requires VSX support"
 msgstr "%s 不支持 %s"
 
-#: config/rs6000/rs6000.c:4653
+#: config/rs6000/rs6000.c:4678
 #, gcc-internal-format
 msgid "The -mfloat128 option may not be fully supported"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4676
+#: config/rs6000/rs6000.c:4701
 #, gcc-internal-format
 msgid "%qs requires full ISA 3.0 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4743
+#: config/rs6000/rs6000.c:4768
 #, fuzzy, gcc-internal-format
 msgid "unknown vectorization library ABI type (%qs) for %qs switch"
 msgstr "%2$sveclibabi=%3$s %4$s向量库 ABI 类型(%1$s)未知"
 
-#: config/rs6000/rs6000.c:4930
+#: config/rs6000/rs6000.c:4955
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "%qs is not a valid number in %qs"
 msgstr "%qs对%qs而言无效"
 
-#: config/rs6000/rs6000.c:4935
+#: config/rs6000/rs6000.c:4960
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not valid for %qs"
 msgid "%qs is not a valid offset in %qs"
 msgstr "%qs对%qs而言无效"
 
-#: config/rs6000/rs6000.c:4947
+#: config/rs6000/rs6000.c:4972
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid base register in %qs"
 msgstr "%qs没有指定类名"
 
-#: config/rs6000/rs6000.c:4955
+#: config/rs6000/rs6000.c:4980
 #, fuzzy, gcc-internal-format
 msgid "%qs needs a valid base register"
 msgstr "调用篡改寄存器用作全局寄存器变量"
 
-#: config/rs6000/rs6000.c:5253
+#: config/rs6000/rs6000.c:5278
 #, fuzzy, gcc-internal-format
 msgid "unknown option for %<%s=%s%>"
 msgstr "未知的选项：%s %s %s"
 
-#: config/rs6000/rs6000.c:5290
+#: config/rs6000/rs6000.c:5315
 #, fuzzy, gcc-internal-format
 msgid "%qs is deprecated and not recommended in any circumstances"
 msgstr "已弃用。此开关不起作用。"
 
-#: config/rs6000/rs6000.c:11401
+#: config/rs6000/rs6000.c:11439
 #, fuzzy, gcc-internal-format
 #| msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgid "cannot return value in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr "不能在向量寄存器中返回值，因为 altivec 指令集已被禁用，使用 -maltivec 启用"
 
-#: config/rs6000/rs6000.c:11862
+#: config/rs6000/rs6000.c:11906
 #, fuzzy, gcc-internal-format
 #| msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use %qs to enable them"
 msgstr "不能在向量寄存器中传递参数，因为 altivec 指令集已被禁用，使用 -maltivec 启用"
 
-#: config/rs6000/rs6000.c:13572
+#: config/rs6000/rs6000.c:13616
 #, fuzzy, gcc-internal-format
 msgid "internal error: builtin function %qs already processed"
 msgstr "内部错误：内建函数 %s 没有类型"
 
-#: config/rs6000/rs6000.c:14150
+#: config/rs6000/rs6000.c:14194
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 1-bit unsigned literal"
 msgstr "实参 2 必须是一个 5 位无符号字面量"
 
-#: config/rs6000/rs6000.c:14189
+#: config/rs6000/rs6000.c:14233
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of %qs must be a constant"
 msgstr "%2$qE的实参 %1$d 必须是地址"
 
-#: config/rs6000/rs6000.c:14247 config/rs6000/rs6000.c:15898
+#: config/rs6000/rs6000.c:14291 config/rs6000/rs6000.c:15942
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument 1 of %qs is out of range"
 msgstr "__builtin_spe_predicate 的第 1 个实参越界"
 
-#: config/rs6000/rs6000.c:14742
+#: config/rs6000/rs6000.c:14786
 #, fuzzy, gcc-internal-format
 msgid "builtin %qs is only valid in 64-bit mode"
 msgstr "%srtd%s 在 64 位模式下被忽略"
 
-#: config/rs6000/rs6000.c:14939
+#: config/rs6000/rs6000.c:14983
 #, fuzzy, gcc-internal-format
 #| msgid "%s only accepts 1 argument"
 msgid "builtin %qs only accepts a string argument"
@@ -36097,133 +36141,134 @@
 msgstr "%s 只接受 1 个参数"
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000.c:14958
+#: config/rs6000/rs6000.c:15002
 #, fuzzy, gcc-internal-format
 msgid "cpu %qs is an invalid argument to builtin %qs"
 msgstr "属性%qs的参数无效"
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000.c:14986
+#: config/rs6000/rs6000.c:15030
 #, fuzzy, gcc-internal-format
 msgid "%s %qs is an invalid argument to builtin %qs"
 msgstr "属性%qs的参数无效"
 
-#: config/rs6000/rs6000.c:15012
+#: config/rs6000/rs6000.c:15056
 #, gcc-internal-format
 msgid "builtin %qs needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15616
+#: config/rs6000/rs6000.c:15660
 #, fuzzy, gcc-internal-format
 msgid "second argument to %qs must be 0..12"
 msgstr "数字必须是 0 或 1"
 
-#: config/rs6000/rs6000.c:15631
+#: config/rs6000/rs6000.c:15675
 #, fuzzy, gcc-internal-format
 msgid "third argument to %qs must be 0..12"
 msgstr "数字必须是 0 或 1"
 
-#: config/rs6000/rs6000.c:15850
+#: config/rs6000/rs6000.c:15894
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument 1 of %s must be a constant"
 msgstr "%2$qE的实参 %1$d 必须是地址"
 
-#: config/rs6000/rs6000.c:15932
+#: config/rs6000/rs6000.c:15976
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs is only valid for the cell processor"
 msgstr "此内建函数只在 fr450 上可用"
 
-#: config/rs6000/rs6000.c:15934 config/rs6000/rs6000.c:15936
-#: config/rs6000/rs6000.c:15938 config/rs6000/rs6000.c:15940
-#: config/rs6000/rs6000.c:15946 config/rs6000/rs6000.c:15948
-#: config/rs6000/rs6000.c:15955 config/rs6000/rs6000.c:15962
-#: config/rs6000/rs6000.c:15969 config/rs6000/rs6000.c:15975
+#: config/rs6000/rs6000.c:15978 config/rs6000/rs6000.c:15980
+#: config/rs6000/rs6000.c:15982 config/rs6000/rs6000.c:15984
+#: config/rs6000/rs6000.c:15990 config/rs6000/rs6000.c:15992
+#: config/rs6000/rs6000.c:15999 config/rs6000/rs6000.c:16006
+#: config/rs6000/rs6000.c:16011 config/rs6000/rs6000.c:16014
+#: config/rs6000/rs6000.c:16018 config/rs6000/rs6000.c:16024
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs requires the %qs option"
 msgstr "内建函数%q+D未被声明为函数"
 
-#: config/rs6000/rs6000.c:15943 config/rs6000/rs6000.c:15952
-#: config/rs6000/rs6000.c:15959 config/rs6000/rs6000.c:15966
+#: config/rs6000/rs6000.c:15987 config/rs6000/rs6000.c:15996
+#: config/rs6000/rs6000.c:16003
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs requires the %qs and %qs options"
 msgstr "内建函数%q+D未被声明为函数"
 
-#: config/rs6000/rs6000.c:15972
+#: config/rs6000/rs6000.c:16021
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs requires ISA 3.0 IEEE 128-bit floating point"
 msgstr "内建函数%q+D未被声明为函数"
 
-#: config/rs6000/rs6000.c:15978
+#: config/rs6000/rs6000.c:16027
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs requires the %qs (or newer), and %qs or %qs options"
 msgstr "内建函数%q+D未被声明为函数"
 
-#: config/rs6000/rs6000.c:15982
+#: config/rs6000/rs6000.c:16031
 #, fuzzy, gcc-internal-format
 msgid "builtin function %qs is not supported with the current options"
 msgstr "弱引用在此配置下不受支持"
 
-#: config/rs6000/rs6000.c:18218
+#: config/rs6000/rs6000.c:18290
 #, fuzzy, gcc-internal-format
 #| msgid "internal error: builtin function %s had an unexpected return type %s"
 msgid "internal error: builtin function %qs had an unexpected return type %qs"
 msgstr "内部错误：内建函数 %s 有非预期的返回类型 %s"
 
-#: config/rs6000/rs6000.c:18235
+#: config/rs6000/rs6000.c:18307
 #, fuzzy, gcc-internal-format
 #| msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgid "internal error: builtin function %qs, argument %d had unexpected argument type %qs"
 msgstr "内部错误：内建函数 %s 的第 %d 个参数有非预期的参数类型 %s"
 
-#: config/rs6000/rs6000.c:29451
+#: config/rs6000/rs6000.c:29528
 #, fuzzy, gcc-internal-format
 msgid "%qs uses register r29"
 msgstr "ISO C90 不允许可变数组成员"
 
-#: config/rs6000/rs6000.c:32748
+#: config/rs6000/rs6000.c:32825
 #, fuzzy, gcc-internal-format
 msgid "you cannot take the address of a nested function if you use the %qs option"
 msgstr "您无法需地址的嵌套的函数如果您使用 -mno-pointers-to-nested-functions 选项。"
 
-#: config/rs6000/rs6000.c:32842
+#: config/rs6000/rs6000.c:32919
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without %qs"
 msgstr "不使用 -mvsx 时，在 AltiVec 类型中使用%<long%>对 64 位代码无效"
 
-#: config/rs6000/rs6000.c:32850
+#: config/rs6000/rs6000.c:32927
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long long%> in AltiVec types is invalid without -mvsx"
 msgid "use of %<long long%> in AltiVec types is invalid without %qs"
 msgstr "不使用 -mvsx 时，在 AltiVec 类型中使用%<long long%>无效"
 
-#: config/rs6000/rs6000.c:32853
+#: config/rs6000/rs6000.c:32930
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<double%> in AltiVec types is invalid without -mvsx"
 msgid "use of %<double%> in AltiVec types is invalid without %qs"
 msgstr "不使用 -mvsx 时，在 AltiVec 类型中使用%<double%>无效"
 
-#: config/rs6000/rs6000.c:36876
+#: config/rs6000/rs6000.c:36932
 #, fuzzy, gcc-internal-format
 msgid "invalid cpu %qs for %s%qs%s"
 msgstr "%s：无效的目的：%s\n"
 
-#: config/rs6000/rs6000.c:36879
+#: config/rs6000/rs6000.c:36935
 #, fuzzy, gcc-internal-format
 msgid "%s%qs%s is not allowed"
 msgstr "%s：不允许空权字符串"
 
-#: config/rs6000/rs6000.c:36881
+#: config/rs6000/rs6000.c:36937
 #, fuzzy, gcc-internal-format
 msgid "%s%qs%s is invalid"
 msgstr "无效的 %s 字组：%s\n"
 
-#: config/rs6000/rs6000.c:37416
+#: config/rs6000/rs6000.c:37472
 #, fuzzy, gcc-internal-format
 msgid "%<-mno-%s%> turns off %<-m%s%>"
 msgstr "%<-march=%s%>与所选 ABI 不兼容"
 
-#: config/rs6000/rs6000.c:37575
+#: config/rs6000/rs6000.c:37631
 #, gcc-internal-format
 msgid "target_clones attribute needs GLIBC (2.23 and newer) that exports hardware capability bits"
 msgstr ""
@@ -36979,48 +37024,48 @@
 msgid "subprogram %q+F not marked Inline"
 msgstr ""
 
-#: ada/gcc-interface/trans.c:6404
+#: ada/gcc-interface/trans.c:6401
 #, gcc-internal-format
 msgid "out-of-bounds access may be optimized away"
 msgstr ""
 
-#: ada/gcc-interface/trans.c:6406
+#: ada/gcc-interface/trans.c:6403
 #, fuzzy, gcc-internal-format
 msgid "containing loop"
 msgstr "循环变量"
 
-#: ada/gcc-interface/utils.c:3887
+#: ada/gcc-interface/utils.c:3890
 #, gcc-internal-format
 msgid "invalid element type for attribute %qs"
 msgstr "属性%qs的元素类型无效"
 
-#: ada/gcc-interface/utils.c:3911
+#: ada/gcc-interface/utils.c:3914
 #, fuzzy, gcc-internal-format
 msgid "number of components of vector not a power of two"
 msgstr "向量中分量数不是 2 的某次方"
 
-#: ada/gcc-interface/utils.c:6037 ada/gcc-interface/utils.c:6215
-#: ada/gcc-interface/utils.c:6322
+#: ada/gcc-interface/utils.c:6043 ada/gcc-interface/utils.c:6220
+#: ada/gcc-interface/utils.c:6327
 #, gcc-internal-format
 msgid "%qs attribute ignored"
 msgstr "忽略%qs属性"
 
-#: ada/gcc-interface/utils.c:6158
+#: ada/gcc-interface/utils.c:6164
 #, gcc-internal-format
 msgid "%qs attribute requires prototypes with named arguments"
 msgstr "%qs属性需要带有名参数的原型"
 
-#: ada/gcc-interface/utils.c:6167
+#: ada/gcc-interface/utils.c:6173
 #, gcc-internal-format
 msgid "%qs attribute only applies to variadic functions"
 msgstr "%qs属性只能用于带可变参数函数"
 
-#: ada/gcc-interface/utils.c:6282
+#: ada/gcc-interface/utils.c:6287
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute has no effect"
 msgstr "语句不起作用"
 
-#: ada/gcc-interface/utils.c:6406
+#: ada/gcc-interface/utils.c:6411
 #, gcc-internal-format
 msgid "attribute %qs applies to array types only"
 msgstr "%qs属性只能为数组类型使用"
@@ -37036,7 +37081,7 @@
 #. an unprototyped function, it is compile-time undefined;
 #. making it a constraint in that case was rejected in
 #. DR#252.
-#: c/c-convert.c:101 c/c-typeck.c:2175 c/c-typeck.c:6507 c/c-typeck.c:12138
+#: c/c-convert.c:101 c/c-typeck.c:2175 c/c-typeck.c:6512 c/c-typeck.c:12143
 #: cp/typeck.c:2027 cp/typeck.c:7977 cp/typeck.c:8742
 #, gcc-internal-format
 msgid "void value not ignored as it ought to be"
@@ -37097,7 +37142,7 @@
 msgid "type of array %q+D completed incompatibly with implicit initialization"
 msgstr "数组%q+D类型与隐式初始化不兼容"
 
-#: c/c-decl.c:1567 c/c-decl.c:6701 c/c-decl.c:7574 c/c-decl.c:8381
+#: c/c-decl.c:1567 c/c-decl.c:6721 c/c-decl.c:7594 c/c-decl.c:8401
 #, gcc-internal-format
 msgid "originally defined here"
 msgstr "原先在这里定义"
@@ -37506,16 +37551,11 @@
 #. C99 6.7.5.2p4
 #. A function definition isn't function prototype scope C99 6.2.1p4.
 #. C99 6.7.5.2p4
-#: c/c-decl.c:4548 c/c-decl.c:7147
+#: c/c-decl.c:4548 c/c-decl.c:7167
 #, gcc-internal-format
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr "%<[*]%>不能用于函数原型以外"
 
-#: c/c-decl.c:4635 cp/decl2.c:1520
-#, gcc-internal-format
-msgid "%q+D in declare target directive does not have mappable type"
-msgstr ""
-
 #: c/c-decl.c:4693
 #, gcc-internal-format
 msgid "%q+D is usually a function"
@@ -37541,7 +37581,7 @@
 #. of VLAs themselves count as VLAs, it does not make
 #. sense to permit them to be initialized given that
 #. ordinary VLAs may not be initialized.
-#: c/c-decl.c:4732 c/c-decl.c:4747 c/c-typeck.c:7630
+#: c/c-decl.c:4732 c/c-decl.c:4747 c/c-typeck.c:7635
 #, gcc-internal-format
 msgid "variable-sized object may not be initialized"
 msgstr "可变大小的对象不能被初始化"
@@ -37601,203 +37641,208 @@
 msgid "uninitialized const %qD is invalid in C++"
 msgstr "未初始化的常量%qD在C++中是无效的"
 
-#: c/c-decl.c:5268
+#: c/c-decl.c:5224 cp/decl.c:7318
 #, gcc-internal-format
+msgid "%q+D in declare target directive does not have mappable type"
+msgstr ""
+
+#: c/c-decl.c:5288
+#, gcc-internal-format
 msgid "ISO C forbids forward parameter declarations"
 msgstr "ISO C 不允许前向参数声明"
 
-#: c/c-decl.c:5371
+#: c/c-decl.c:5391
 #, gcc-internal-format
 msgid "defining a type in a compound literal is invalid in C++"
 msgstr "C++ 不允许在组合字面常量中定义类型"
 
-#: c/c-decl.c:5425 c/c-decl.c:5440
+#: c/c-decl.c:5445 c/c-decl.c:5460
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant"
 msgstr "位段%qs的宽度不是一个整数常量"
 
-#: c/c-decl.c:5435
+#: c/c-decl.c:5455
 #, gcc-internal-format
 msgid "bit-field %qs width not an integer constant expression"
 msgstr "位段%qs的宽度不是一个整数常量表达式"
 
-#: c/c-decl.c:5446
+#: c/c-decl.c:5466
 #, gcc-internal-format
 msgid "negative width in bit-field %qs"
 msgstr "位段%qs宽度为负"
 
-#: c/c-decl.c:5451
+#: c/c-decl.c:5471
 #, gcc-internal-format
 msgid "zero width for bit-field %qs"
 msgstr "位段%qs宽度为 0"
 
-#: c/c-decl.c:5461
+#: c/c-decl.c:5481
 #, gcc-internal-format
 msgid "bit-field %qs has invalid type"
 msgstr "位段%qs类型无效"
 
-#: c/c-decl.c:5467
+#: c/c-decl.c:5487
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare bit-field %qD with function type"
 msgid "cannot declare bit-field %qs with %<warn_if_not_aligned%> type"
 msgstr "不能将位段%qD声明为函数类型"
 
-#: c/c-decl.c:5478
+#: c/c-decl.c:5498
 #, gcc-internal-format
 msgid "type of bit-field %qs is a GCC extension"
 msgstr "位段类型%qs是一个 GCC 扩展"
 
-#: c/c-decl.c:5484
+#: c/c-decl.c:5504
 #, gcc-internal-format
 msgid "width of %qs exceeds its type"
 msgstr "%qs的宽度超过它自身的类型"
 
-#: c/c-decl.c:5497
+#: c/c-decl.c:5517
 #, gcc-internal-format
 msgid "%qs is narrower than values of its type"
 msgstr "%qs比其类型的值要窄"
 
-#: c/c-decl.c:5512
+#: c/c-decl.c:5532
 #, gcc-internal-format
 msgid "ISO C90 forbids array %qE whose size can%'t be evaluated"
 msgstr "ISO C90 不允许数组%qE，因为不能计算其大小"
 
-#: c/c-decl.c:5515
+#: c/c-decl.c:5535
 #, gcc-internal-format
 msgid "ISO C90 forbids array whose size can%'t be evaluated"
 msgstr "ISO C90 不允许任何不能确定大小的数组"
 
-#: c/c-decl.c:5522
+#: c/c-decl.c:5542
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array %qE"
 msgstr "ISO C90 不允许变长数组%qE"
 
-#: c/c-decl.c:5524
+#: c/c-decl.c:5544
 #, gcc-internal-format
 msgid "ISO C90 forbids variable length array"
 msgstr "ISO C90 不允许变长数组"
 
-#: c/c-decl.c:5733 c/c-decl.c:6107 c/c-decl.c:6117
+#: c/c-decl.c:5753 c/c-decl.c:6127 c/c-decl.c:6137
 #, gcc-internal-format
 msgid "variably modified %qE at file scope"
 msgstr "文件域中的动态可变的%qE"
 
-#: c/c-decl.c:5735
+#: c/c-decl.c:5755
 #, gcc-internal-format
 msgid "variably modified field at file scope"
 msgstr "文件域中的动态可变字段"
 
-#: c/c-decl.c:5755
+#: c/c-decl.c:5775
 #, gcc-internal-format
 msgid "type defaults to %<int%> in declaration of %qE"
 msgstr "在%qE的声明中，类型默认为%<int%>"
 
-#: c/c-decl.c:5759
+#: c/c-decl.c:5779
 #, gcc-internal-format
 msgid "type defaults to %<int%> in type name"
 msgstr "类型名中类型默认为%<int%>"
 
-#: c/c-decl.c:5791
+#: c/c-decl.c:5811
 #, gcc-internal-format
 msgid "duplicate %<const%>"
 msgstr "重复的%<const%>"
 
-#: c/c-decl.c:5793
+#: c/c-decl.c:5813
 #, gcc-internal-format
 msgid "duplicate %<restrict%>"
 msgstr "重复的%<restrict%>"
 
-#: c/c-decl.c:5795
+#: c/c-decl.c:5815
 #, gcc-internal-format
 msgid "duplicate %<volatile%>"
 msgstr "重复的%<volatile%>"
 
-#: c/c-decl.c:5797
+#: c/c-decl.c:5817
 #, fuzzy, gcc-internal-format
 msgid "duplicate %<_Atomic%>"
 msgstr "重复键值"
 
-#: c/c-decl.c:5800
+#: c/c-decl.c:5820
 #, gcc-internal-format, gfc-internal-format
 msgid "conflicting named address spaces (%s vs %s)"
 msgstr "冲突的有名地址空间(%s和%s)"
 
-#: c/c-decl.c:5823 c/c-parser.c:2821
+#: c/c-decl.c:5843 c/c-parser.c:2821
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%>-qualified array type"
 msgstr "%<#pragma omp atomic%>表达式类型无效"
 
-#: c/c-decl.c:5837
+#: c/c-decl.c:5857
 #, gcc-internal-format
 msgid "function definition declared %<auto%>"
 msgstr "函数声明定义为%<auto%>"
 
-#: c/c-decl.c:5839
+#: c/c-decl.c:5859
 #, gcc-internal-format
 msgid "function definition declared %<register%>"
 msgstr "函数声明定义为%<register%>"
 
-#: c/c-decl.c:5841
+#: c/c-decl.c:5861
 #, gcc-internal-format
 msgid "function definition declared %<typedef%>"
 msgstr "函数声明定义为%<typedef%>"
 
-#: c/c-decl.c:5843
+#: c/c-decl.c:5863
 #, fuzzy, gcc-internal-format
 msgid "function definition declared %qs"
 msgstr "函数声明定义为%<auto%>"
 
-#: c/c-decl.c:5861
+#: c/c-decl.c:5881
 #, gcc-internal-format
 msgid "storage class specified for structure field %qE"
 msgstr "为结构字段%qE指定了存储类"
 
-#: c/c-decl.c:5864
+#: c/c-decl.c:5884
 #, gcc-internal-format
 msgid "storage class specified for structure field"
 msgstr "为结构字段指定了存储类"
 
-#: c/c-decl.c:5868
+#: c/c-decl.c:5888
 #, gcc-internal-format
 msgid "storage class specified for parameter %qE"
 msgstr "为形参%qE指定了存储类"
 
-#: c/c-decl.c:5871
+#: c/c-decl.c:5891
 #, gcc-internal-format
 msgid "storage class specified for unnamed parameter"
 msgstr "为无名形参指定了存储类"
 
-#: c/c-decl.c:5874 cp/decl.c:10935
+#: c/c-decl.c:5894 cp/decl.c:10959
 #, gcc-internal-format
 msgid "storage class specified for typename"
 msgstr "为类型名指定了存储类"
 
-#: c/c-decl.c:5891
+#: c/c-decl.c:5911
 #, gcc-internal-format
 msgid "%qE initialized and declared %<extern%>"
 msgstr "%qE已初始化，却又被声明为%<extern%>"
 
-#: c/c-decl.c:5895
+#: c/c-decl.c:5915
 #, gcc-internal-format
 msgid "%qE has both %<extern%> and initializer"
 msgstr "%qE既有%<extern%>又有初始值设定"
 
-#: c/c-decl.c:5900
+#: c/c-decl.c:5920
 #, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<auto%>"
 msgstr "文件作用域声明%qE指定了%<auto%>"
 
-#: c/c-decl.c:5904
+#: c/c-decl.c:5924
 #, gcc-internal-format
 msgid "file-scope declaration of %qE specifies %<register%>"
 msgstr "文件作用域声明%qE指定了%<register%>"
 
-#: c/c-decl.c:5909
+#: c/c-decl.c:5929
 #, gcc-internal-format
 msgid "nested function %qE declared %<extern%>"
 msgstr "嵌套函数%qE被声明为%<extern%>"
 
-#: c/c-decl.c:5912
+#: c/c-decl.c:5932
 #, fuzzy, gcc-internal-format
 msgid "function-scope %qE implicitly auto and declared %qs"
 msgstr "函数作用域的%qs隐式为 auto，却被声明为%<__thread%>"
@@ -37805,706 +37850,706 @@
 #. Only the innermost declarator (making a parameter be of
 #. array type which is converted to pointer type)
 #. may have static or type qualifiers.
-#: c/c-decl.c:5959 c/c-decl.c:6328
+#: c/c-decl.c:5979 c/c-decl.c:6348
 #, gcc-internal-format
 msgid "static or type qualifiers in non-parameter array declarator"
 msgstr "static 或类型限定符出现在非形参数组声明中"
 
-#: c/c-decl.c:6007
+#: c/c-decl.c:6027
 #, gcc-internal-format
 msgid "declaration of %qE as array of voids"
 msgstr "%qE声明为 void 的数组"
 
-#: c/c-decl.c:6009
+#: c/c-decl.c:6029
 #, gcc-internal-format
 msgid "declaration of type name as array of voids"
 msgstr "类型名声明为 void 的数组"
 
-#: c/c-decl.c:6016
+#: c/c-decl.c:6036
 #, gcc-internal-format
 msgid "declaration of %qE as array of functions"
 msgstr "%qE声明为函数的数组"
 
-#: c/c-decl.c:6019
+#: c/c-decl.c:6039
 #, gcc-internal-format
 msgid "declaration of type name as array of functions"
 msgstr "类型名声明为函数的数组"
 
-#: c/c-decl.c:6027 c/c-decl.c:8085
+#: c/c-decl.c:6047 c/c-decl.c:8105
 #, gcc-internal-format
 msgid "invalid use of structure with flexible array member"
 msgstr "对包含可变数组成员的结构的无效使用"
 
-#: c/c-decl.c:6053
+#: c/c-decl.c:6073
 #, gcc-internal-format
 msgid "size of array %qE has non-integer type"
 msgstr "数组%qE的大小的类型不是整数"
 
-#: c/c-decl.c:6057
+#: c/c-decl.c:6077
 #, gcc-internal-format
 msgid "size of unnamed array has non-integer type"
 msgstr "无名数组的大小的类型不是整数"
 
-#: c/c-decl.c:6064
+#: c/c-decl.c:6084
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qE has non-integer type"
 msgid "size of array %qE has incomplete type"
 msgstr "数组%qE的大小的类型不是整数"
 
-#: c/c-decl.c:6067
+#: c/c-decl.c:6087
 #, fuzzy, gcc-internal-format
 #| msgid "size of unnamed array has non-integer type"
 msgid "size of unnamed array has incomplete type"
 msgstr "无名数组的大小的类型不是整数"
 
-#: c/c-decl.c:6078
+#: c/c-decl.c:6098
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array %qE"
 msgstr "ISO C 不允许大小为 0 的数组%qE"
 
-#: c/c-decl.c:6081
+#: c/c-decl.c:6101
 #, gcc-internal-format
 msgid "ISO C forbids zero-size array"
 msgstr "ISO C 不允许大小为 0 的数组"
 
-#: c/c-decl.c:6090
+#: c/c-decl.c:6110
 #, gcc-internal-format
 msgid "size of array %qE is negative"
 msgstr "数组%qE的大小为负"
 
-#: c/c-decl.c:6092
+#: c/c-decl.c:6112
 #, gcc-internal-format
 msgid "size of unnamed array is negative"
 msgstr "无名数组的大小为负"
 
-#: c/c-decl.c:6216 c/c-decl.c:6871
+#: c/c-decl.c:6236 c/c-decl.c:6891
 #, gcc-internal-format
 msgid "ISO C90 does not support flexible array members"
 msgstr "ISO C90 不允许可变数组成员"
 
 #. C99 6.7.5.2p4
-#: c/c-decl.c:6238
+#: c/c-decl.c:6258
 #, gcc-internal-format
 msgid "%<[*]%> not in a declaration"
 msgstr "%<[*]%>不在声明中"
 
-#: c/c-decl.c:6251
+#: c/c-decl.c:6271
 #, fuzzy, gcc-internal-format
 msgid "array type has incomplete element type %qT"
 msgstr "%2$qD的第 %1$P 个形参的类型%3$qT不完全"
 
-#: c/c-decl.c:6257
+#: c/c-decl.c:6277
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgid "declaration of %qE as multidimensional array must have bounds for all dimensions except the first"
 msgstr "多维数组%qD的声明必须至少指定除第一维以外所有维的大小"
 
-#: c/c-decl.c:6261
+#: c/c-decl.c:6281
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgid "declaration of multidimensional array must have bounds for all dimensions except the first"
 msgstr "多维数组%qD的声明必须至少指定除第一维以外所有维的大小"
 
-#: c/c-decl.c:6364
+#: c/c-decl.c:6384
 #, gcc-internal-format
 msgid "%qE declared as function returning a function"
 msgstr "%qE声明为返回一个函数的函数"
 
-#: c/c-decl.c:6367
+#: c/c-decl.c:6387
 #, gcc-internal-format
 msgid "type name declared as function returning a function"
 msgstr "类型名声明为返回一个数组的函数"
 
-#: c/c-decl.c:6374
+#: c/c-decl.c:6394
 #, gcc-internal-format
 msgid "%qE declared as function returning an array"
 msgstr "%qE声明为返回一个数组的函数"
 
-#: c/c-decl.c:6377
+#: c/c-decl.c:6397
 #, gcc-internal-format
 msgid "type name declared as function returning an array"
 msgstr "类型名声明为返回一个数组的函数"
 
-#: c/c-decl.c:6418
+#: c/c-decl.c:6438
 #, gcc-internal-format
 msgid "function definition has qualified void return type"
 msgstr "函数定义有限定的 void 返回类型"
 
-#: c/c-decl.c:6421 cp/decl.c:11201
+#: c/c-decl.c:6441 cp/decl.c:11225
 #, gcc-internal-format
 msgid "type qualifiers ignored on function return type"
 msgstr "忽略函数返回类型的类型限定"
 
-#: c/c-decl.c:6459 c/c-decl.c:6668 c/c-decl.c:6721 c/c-decl.c:6805
-#: c/c-decl.c:6926 c/c-parser.c:2823
+#: c/c-decl.c:6479 c/c-decl.c:6688 c/c-decl.c:6741 c/c-decl.c:6825
+#: c/c-decl.c:6946 c/c-parser.c:2823
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%>-qualified function type"
 msgstr "调用了有限定 void 返回类型的函数"
 
-#: c/c-decl.c:6465 c/c-decl.c:6674 c/c-decl.c:6810 c/c-decl.c:6931
+#: c/c-decl.c:6485 c/c-decl.c:6694 c/c-decl.c:6830 c/c-decl.c:6951
 #, gcc-internal-format
 msgid "ISO C forbids qualified function types"
 msgstr "ISO C 不允许使用 const 或 volatile 限定函数类型"
 
-#: c/c-decl.c:6559
+#: c/c-decl.c:6579
 #, gcc-internal-format
 msgid "%qs combined with %<auto%> qualifier for %qE"
 msgstr "%qs和%<auto%>限定符同时用于%qE"
 
-#: c/c-decl.c:6563
+#: c/c-decl.c:6583
 #, gcc-internal-format
 msgid "%qs combined with %<register%> qualifier for %qE"
 msgstr "%qs和%<register%>限定符同时用于%qE"
 
-#: c/c-decl.c:6569
+#: c/c-decl.c:6589
 #, gcc-internal-format
 msgid "%qs specified for auto variable %qE"
 msgstr "为 auto 变量%2$qE指定了%1$qs"
 
-#: c/c-decl.c:6585
+#: c/c-decl.c:6605
 #, gcc-internal-format
 msgid "%qs specified for parameter %qE"
 msgstr "为形参%2$qE指定了%1$qs"
 
-#: c/c-decl.c:6588
+#: c/c-decl.c:6608
 #, gcc-internal-format
 msgid "%qs specified for unnamed parameter"
 msgstr "为无名形参指定了%qs"
 
-#: c/c-decl.c:6594
+#: c/c-decl.c:6614
 #, gcc-internal-format
 msgid "%qs specified for structure field %qE"
 msgstr "为结构字段%2$qE指定了%1$qs"
 
-#: c/c-decl.c:6597
+#: c/c-decl.c:6617
 #, gcc-internal-format
 msgid "%qs specified for structure field"
 msgstr "为结构字段指定了%qs"
 
-#: c/c-decl.c:6612
+#: c/c-decl.c:6632
 #, fuzzy, gcc-internal-format
 msgid "bit-field %qE has atomic type"
 msgstr "字段%qE的类型不完全"
 
-#: c/c-decl.c:6614
+#: c/c-decl.c:6634
 #, fuzzy, gcc-internal-format
 msgid "bit-field has atomic type"
 msgstr "位段%qs类型无效"
 
-#: c/c-decl.c:6623
+#: c/c-decl.c:6643
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for typedef %qE"
 msgstr "不能为%q+D指定对齐"
 
-#: c/c-decl.c:6625
+#: c/c-decl.c:6645
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for %<register%> object %qE"
 msgstr "为形参%2$qE指定了%1$qs"
 
-#: c/c-decl.c:6630
+#: c/c-decl.c:6650
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for parameter %qE"
 msgstr "为形参%2$qE指定了%1$qs"
 
-#: c/c-decl.c:6632
+#: c/c-decl.c:6652
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for unnamed parameter"
 msgstr "为无名形参指定了%qs"
 
-#: c/c-decl.c:6637
+#: c/c-decl.c:6657
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for bit-field %qE"
 msgstr "为结构字段%2$qE指定了%1$qs"
 
-#: c/c-decl.c:6639
+#: c/c-decl.c:6659
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for unnamed bit-field"
 msgstr "为无名形参指定了%qs"
 
-#: c/c-decl.c:6642
+#: c/c-decl.c:6662
 #, fuzzy, gcc-internal-format
 msgid "alignment specified for function %qE"
 msgstr "不能为%q+D指定对齐"
 
-#: c/c-decl.c:6649
+#: c/c-decl.c:6669
 #, fuzzy, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of %qE"
 msgstr "%<Alignas%(_A)>说明符无法缩小对齐的 %qE"
 
-#: c/c-decl.c:6652
+#: c/c-decl.c:6672
 #, fuzzy, gcc-internal-format
 msgid "%<_Alignas%> specifiers cannot reduce alignment of unnamed field"
 msgstr "%<Alignas%(_A)>说明符无法缩小对齐的未命名字段"
 
-#: c/c-decl.c:6683
+#: c/c-decl.c:6703
 #, gcc-internal-format
 msgid "typedef %q+D declared %<inline%>"
 msgstr "typedef%q+D声明为%<inline%>"
 
-#: c/c-decl.c:6685
+#: c/c-decl.c:6705
 #, fuzzy, gcc-internal-format
 msgid "typedef %q+D declared %<_Noreturn%>"
 msgstr "typedef%q+D声明为%<inline%>"
 
-#: c/c-decl.c:6727
+#: c/c-decl.c:6747
 #, gcc-internal-format
 msgid "ISO C forbids const or volatile function types"
 msgstr "ISO C 不允许使用 const 或 volatile 限定函数类型"
 
 #. C99 6.7.2.1p8
-#: c/c-decl.c:6738
+#: c/c-decl.c:6758
 #, gcc-internal-format
 msgid "a member of a structure or union cannot have a variably modified type"
 msgstr "结构或联合成员不能具有可变类型"
 
-#: c/c-decl.c:6755 cp/decl.c:9989
+#: c/c-decl.c:6775 cp/decl.c:10010
 #, gcc-internal-format
 msgid "variable or field %qE declared void"
 msgstr "变量或字段%qE声明为 void"
 
-#: c/c-decl.c:6795
+#: c/c-decl.c:6815
 #, gcc-internal-format
 msgid "attributes in parameter array declarator ignored"
 msgstr "出现在形参数组声明中的属性被忽略"
 
-#: c/c-decl.c:6837
+#: c/c-decl.c:6857
 #, gcc-internal-format
 msgid "parameter %q+D declared %<inline%>"
 msgstr "形参%q+D声明为%<inline%>"
 
-#: c/c-decl.c:6839
+#: c/c-decl.c:6859
 #, fuzzy, gcc-internal-format
 msgid "parameter %q+D declared %<_Noreturn%>"
 msgstr "形参%q+D声明为%<inline%>"
 
-#: c/c-decl.c:6852
+#: c/c-decl.c:6872
 #, gcc-internal-format
 msgid "field %qE declared as a function"
 msgstr "字段%qE声明为一个函数"
 
-#: c/c-decl.c:6859
+#: c/c-decl.c:6879
 #, gcc-internal-format
 msgid "field %qE has incomplete type"
 msgstr "字段%qE的类型不完全"
 
-#: c/c-decl.c:6861
+#: c/c-decl.c:6881
 #, gcc-internal-format
 msgid "unnamed field has incomplete type"
 msgstr "无名字段类型不完全"
 
-#: c/c-decl.c:6897 c/c-decl.c:6908 c/c-decl.c:6911
+#: c/c-decl.c:6917 c/c-decl.c:6928 c/c-decl.c:6931
 #, gcc-internal-format
 msgid "invalid storage class for function %qE"
 msgstr "函数%qE存储类无效"
 
-#: c/c-decl.c:6968
+#: c/c-decl.c:6988
 #, gcc-internal-format
 msgid "cannot inline function %<main%>"
 msgstr "不能内联%<main%>函数"
 
-#: c/c-decl.c:6970
+#: c/c-decl.c:6990
 #, fuzzy, gcc-internal-format
 msgid "%<main%> declared %<_Noreturn%>"
 msgstr "%qE已初始化，却又被声明为%<extern%>"
 
-#: c/c-decl.c:6981
+#: c/c-decl.c:7001
 #, gcc-internal-format
 msgid "ISO C99 does not support %<_Noreturn%>"
 msgstr "ISO C99 不支持 %<_Noreturn%>"
 
-#: c/c-decl.c:6984
+#: c/c-decl.c:7004
 #, gcc-internal-format
 msgid "ISO C90 does not support %<_Noreturn%>"
 msgstr "ISO C90 不支持 %<_Noreturn%>"
 
-#: c/c-decl.c:7013
+#: c/c-decl.c:7033
 #, gcc-internal-format
 msgid "variable previously declared %<static%> redeclared %<extern%>"
 msgstr "先前被声明为%<static%>的变量重声明为%<extern%>"
 
-#: c/c-decl.c:7023
+#: c/c-decl.c:7043
 #, gcc-internal-format
 msgid "variable %q+D declared %<inline%>"
 msgstr "变量%q+D声明为%<inline%>"
 
-#: c/c-decl.c:7025
+#: c/c-decl.c:7045
 #, fuzzy, gcc-internal-format
 msgid "variable %q+D declared %<_Noreturn%>"
 msgstr "变量%q+D声明为%<inline%>"
 
-#: c/c-decl.c:7060
+#: c/c-decl.c:7080
 #, gcc-internal-format
 msgid "non-nested function with variably modified type"
 msgstr "非嵌套函数有动态可变类型"
 
-#: c/c-decl.c:7062
+#: c/c-decl.c:7082
 #, gcc-internal-format
 msgid "object with variably modified type must have no linkage"
 msgstr "可变类型对象不能有外部链接"
 
-#: c/c-decl.c:7153 c/c-decl.c:8821
+#: c/c-decl.c:7173 c/c-decl.c:8841
 #, gcc-internal-format
 msgid "function declaration isn%'t a prototype"
 msgstr "函数声明不是一个原型"
 
-#: c/c-decl.c:7163
+#: c/c-decl.c:7183
 #, gcc-internal-format
 msgid "parameter names (without types) in function declaration"
 msgstr "函数声明中出现形参名却未指定类型"
 
-#: c/c-decl.c:7201
+#: c/c-decl.c:7221
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has incomplete type"
 msgstr "形参 %u (%q+D) 的类型不完全"
 
-#: c/c-decl.c:7205
+#: c/c-decl.c:7225
 #, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has incomplete type"
 msgstr "形参 %u 的类型不完全"
 
-#: c/c-decl.c:7216
+#: c/c-decl.c:7236
 #, gcc-internal-format
 msgid "parameter %u (%q+D) has void type"
 msgstr "形参 %u (%q+D)类型为 void"
 
-#: c/c-decl.c:7220
+#: c/c-decl.c:7240
 #, gcc-internal-format, gfc-internal-format
 msgid "parameter %u has void type"
 msgstr "第 %u 个参数类型为 void"
 
-#: c/c-decl.c:7294
+#: c/c-decl.c:7314
 #, gcc-internal-format
 msgid "%<void%> as only parameter may not be qualified"
 msgstr "%<void%>作为仅有的参数时不能被限定"
 
-#: c/c-decl.c:7298 c/c-decl.c:7334
+#: c/c-decl.c:7318 c/c-decl.c:7354
 #, gcc-internal-format
 msgid "%<void%> must be the only parameter"
 msgstr "%<void%>必须是仅有的形参"
 
-#: c/c-decl.c:7328
+#: c/c-decl.c:7348
 #, gcc-internal-format
 msgid "parameter %q+D has just a forward declaration"
 msgstr "形参%q+D有一个前向声明"
 
-#: c/c-decl.c:7374
+#: c/c-decl.c:7394
 #, gcc-internal-format
 msgid "%<%s %E%> declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr ""
 
-#: c/c-decl.c:7380
+#: c/c-decl.c:7400
 #, gcc-internal-format, gfc-internal-format
 msgid "anonymous %s declared inside parameter list will not be visible outside of this definition or declaration"
 msgstr ""
 
-#: c/c-decl.c:7482
+#: c/c-decl.c:7502
 #, gcc-internal-format
 msgid "enum type defined here"
 msgstr "枚举类型在此定义"
 
-#: c/c-decl.c:7488
+#: c/c-decl.c:7508
 #, gcc-internal-format
 msgid "struct defined here"
 msgstr "结构在此定义"
 
-#: c/c-decl.c:7494
+#: c/c-decl.c:7514
 #, gcc-internal-format
 msgid "union defined here"
 msgstr "联合在此定义"
 
-#: c/c-decl.c:7570
+#: c/c-decl.c:7590
 #, gcc-internal-format
 msgid "redefinition of %<union %E%>"
 msgstr "%<union %E%>重定义"
 
-#: c/c-decl.c:7572
+#: c/c-decl.c:7592
 #, gcc-internal-format
 msgid "redefinition of %<struct %E%>"
 msgstr "%<struct %E%>重定义"
 
-#: c/c-decl.c:7581
+#: c/c-decl.c:7601
 #, gcc-internal-format
 msgid "nested redefinition of %<union %E%>"
 msgstr "嵌套的%<union %E%>重定义"
 
-#: c/c-decl.c:7583
+#: c/c-decl.c:7603
 #, gcc-internal-format
 msgid "nested redefinition of %<struct %E%>"
 msgstr "嵌套的%<struct %E%>重定义"
 
-#: c/c-decl.c:7613 c/c-decl.c:8400
+#: c/c-decl.c:7633 c/c-decl.c:8420
 #, gcc-internal-format
 msgid "defining type in %qs expression is invalid in C++"
 msgstr "C++ 不允许在%qs表达式中定义类型"
 
-#: c/c-decl.c:7680 cp/decl.c:4802
+#: c/c-decl.c:7700 cp/decl.c:4802
 #, gcc-internal-format
 msgid "declaration does not declare anything"
 msgstr "没有声明任何东西"
 
-#: c/c-decl.c:7685
+#: c/c-decl.c:7705
 #, gcc-internal-format
 msgid "ISO C99 doesn%'t support unnamed structs/unions"
 msgstr "ISO C99 不支持无名结构/联合"
 
-#: c/c-decl.c:7688
+#: c/c-decl.c:7708
 #, gcc-internal-format
 msgid "ISO C90 doesn%'t support unnamed structs/unions"
 msgstr "ISO C90 不支持无名结构/联合"
 
-#: c/c-decl.c:7781 c/c-decl.c:7799 c/c-decl.c:7860
+#: c/c-decl.c:7801 c/c-decl.c:7819 c/c-decl.c:7880
 #, gcc-internal-format
 msgid "duplicate member %q+D"
 msgstr "重复的成员%q+D"
 
-#: c/c-decl.c:7886
+#: c/c-decl.c:7906
 #, gcc-internal-format
 msgid "empty struct has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.c:7889
+#: c/c-decl.c:7909
 #, gcc-internal-format
 msgid "empty union has size 0 in C, size 1 in C++"
 msgstr ""
 
-#: c/c-decl.c:7994
+#: c/c-decl.c:8014
 #, gcc-internal-format
 msgid "union has no named members"
 msgstr "联合包含无名成员"
 
-#: c/c-decl.c:7996
+#: c/c-decl.c:8016
 #, gcc-internal-format
 msgid "union has no members"
 msgstr "联合体没有成员"
 
-#: c/c-decl.c:8001
+#: c/c-decl.c:8021
 #, gcc-internal-format
 msgid "struct has no named members"
 msgstr "结构不包含任何有名成员"
 
-#: c/c-decl.c:8003
+#: c/c-decl.c:8023
 #, gcc-internal-format
 msgid "struct has no members"
 msgstr "结构体没有成员"
 
-#: c/c-decl.c:8064 cp/decl.c:12069
+#: c/c-decl.c:8084 cp/decl.c:12093
 #, gcc-internal-format
 msgid "flexible array member in union"
 msgstr "联合和可变数组成员"
 
-#: c/c-decl.c:8070
+#: c/c-decl.c:8090
 #, gcc-internal-format
 msgid "flexible array member not at end of struct"
 msgstr "可变数组成员没有出现在结构的末尾"
 
-#: c/c-decl.c:8076
+#: c/c-decl.c:8096
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member in union"
 msgid "flexible array member in a struct with no named members"
 msgstr "联合和可变数组成员"
 
-#: c/c-decl.c:8107
+#: c/c-decl.c:8127
 #, fuzzy, gcc-internal-format
 msgid "type %qT is too large"
 msgstr "对已定义的数据类型来说值过大"
 
-#: c/c-decl.c:8230
+#: c/c-decl.c:8250
 #, gcc-internal-format
 msgid "union cannot be made transparent"
 msgstr "联合不能成为透明的"
 
-#: c/c-decl.c:8372
+#: c/c-decl.c:8392
 #, gcc-internal-format
 msgid "nested redefinition of %<enum %E%>"
 msgstr "嵌套的%<enum %E%>重定义"
 
 #. This enum is a named one that has been declared already.
-#: c/c-decl.c:8379
+#: c/c-decl.c:8399
 #, gcc-internal-format
 msgid "redeclaration of %<enum %E%>"
 msgstr "%<enum %E%>重声明"
 
-#: c/c-decl.c:8458 cp/decl.c:14423
+#: c/c-decl.c:8478 cp/decl.c:14447
 #, gcc-internal-format
 msgid "specified mode too small for enumeral values"
 msgstr "指定的模式对枚举值来说太小"
 
-#: c/c-decl.c:8473
+#: c/c-decl.c:8493
 #, gcc-internal-format
 msgid "enumeration values exceed range of largest integer"
 msgstr "枚举值超过了最大整数类型可表示的范围"
 
-#: c/c-decl.c:8587 c/c-decl.c:8603
+#: c/c-decl.c:8607 c/c-decl.c:8623
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant"
 msgstr "%qE的枚举值不是一个整数常量"
 
-#: c/c-decl.c:8598
+#: c/c-decl.c:8618
 #, gcc-internal-format
 msgid "enumerator value for %qE is not an integer constant expression"
 msgstr "%qE的枚举值不是一个整数常量"
 
-#: c/c-decl.c:8622
+#: c/c-decl.c:8642
 #, gcc-internal-format
 msgid "overflow in enumeration values"
 msgstr "枚举值溢出"
 
-#: c/c-decl.c:8630
+#: c/c-decl.c:8650
 #, gcc-internal-format
 msgid "ISO C restricts enumerator values to range of %<int%>"
 msgstr "ISO C 将枚举值限制在%<int%>范围内"
 
-#: c/c-decl.c:8715 cp/decl.c:5104 cp/decl.c:14955
+#: c/c-decl.c:8735 cp/decl.c:5104 cp/decl.c:14979
 #, gcc-internal-format
 msgid "inline function %qD given attribute noinline"
 msgstr "内联函数%qD给定了非内联属性"
 
-#: c/c-decl.c:8733
+#: c/c-decl.c:8753
 #, gcc-internal-format
 msgid "return type is an incomplete type"
 msgstr "返回不完全的类型"
 
-#: c/c-decl.c:8744
+#: c/c-decl.c:8764
 #, gcc-internal-format
 msgid "return type defaults to %<int%>"
 msgstr "返回类型默认为%<int%>"
 
-#: c/c-decl.c:8771
+#: c/c-decl.c:8791
 #, fuzzy, gcc-internal-format
 msgid "%q+D defined as variadic function without prototype"
 msgstr "嵌套函数%q+D声明过但从未定义"
 
-#: c/c-decl.c:8830
+#: c/c-decl.c:8850
 #, gcc-internal-format
 msgid "no previous prototype for %qD"
 msgstr "%qD先前没有原型"
 
-#: c/c-decl.c:8839
+#: c/c-decl.c:8859
 #, gcc-internal-format
 msgid "%qD was used with no prototype before its definition"
 msgstr "使用%qD时先前既没有原型也没有定义"
 
-#: c/c-decl.c:8847 cp/decl.c:15090
+#: c/c-decl.c:8867 cp/decl.c:15114
 #, gcc-internal-format
 msgid "no previous declaration for %qD"
 msgstr "%qD先前没有声明"
 
-#: c/c-decl.c:8857
+#: c/c-decl.c:8877
 #, gcc-internal-format
 msgid "%qD was used with no declaration before its definition"
 msgstr "使用%qD时先前既没有声明也没有定义"
 
-#: c/c-decl.c:8876
+#: c/c-decl.c:8896
 #, gcc-internal-format
 msgid "return type of %qD is not %<int%>"
 msgstr "%qD的返回类型不是%<int%>"
 
-#: c/c-decl.c:8878
+#: c/c-decl.c:8898
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%>-qualified return type of %qD"
 msgstr "调用了有限定 void 返回类型的函数"
 
-#: c/c-decl.c:8885
+#: c/c-decl.c:8905
 #, gcc-internal-format
 msgid "%qD is normally a non-static function"
 msgstr "%qD通常不是一个静态函数"
 
-#: c/c-decl.c:8922
+#: c/c-decl.c:8942
 #, gcc-internal-format
 msgid "old-style parameter declarations in prototyped function definition"
 msgstr "原型函数定义中使用了旧式参数声明"
 
-#: c/c-decl.c:8937
+#: c/c-decl.c:8957
 #, gcc-internal-format
 msgid "traditional C rejects ISO C style function definitions"
 msgstr "传统 C 不接受 ISO C 风格的函数定义"
 
-#: c/c-decl.c:8953
+#: c/c-decl.c:8973
 #, gcc-internal-format
 msgid "parameter name omitted"
 msgstr "省略的形参名"
 
-#: c/c-decl.c:8990
+#: c/c-decl.c:9010
 #, gcc-internal-format
 msgid "old-style function definition"
 msgstr "旧式的函数定义"
 
-#: c/c-decl.c:8999
+#: c/c-decl.c:9019
 #, gcc-internal-format
 msgid "parameter name missing from parameter list"
 msgstr "形参列表中缺少形参名"
 
-#: c/c-decl.c:9015
+#: c/c-decl.c:9035
 #, gcc-internal-format
 msgid "%qD declared as a non-parameter"
 msgstr "%qD没有声明为一个参数"
 
-#: c/c-decl.c:9023
+#: c/c-decl.c:9043
 #, gcc-internal-format
 msgid "multiple parameters named %qD"
 msgstr "多个名为%qD的形参"
 
-#: c/c-decl.c:9032
+#: c/c-decl.c:9052
 #, gcc-internal-format
 msgid "parameter %qD declared with void type"
 msgstr "形参%qD被声明为有 void 类型"
 
-#: c/c-decl.c:9061 c/c-decl.c:9066
+#: c/c-decl.c:9081 c/c-decl.c:9086
 #, gcc-internal-format
 msgid "type of %qD defaults to %<int%>"
 msgstr "%qD的类型默认为%<int%>"
 
-#: c/c-decl.c:9086
+#: c/c-decl.c:9106
 #, gcc-internal-format
 msgid "parameter %qD has incomplete type"
 msgstr "形参%qD类型不完全"
 
-#: c/c-decl.c:9093
+#: c/c-decl.c:9113
 #, gcc-internal-format
 msgid "declaration for parameter %qD but no such parameter"
 msgstr "声明的形参%qD不存在"
 
-#: c/c-decl.c:9146
+#: c/c-decl.c:9166
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match built-in prototype"
 msgstr "实参个数与内建原型不符"
 
-#: c/c-decl.c:9157
+#: c/c-decl.c:9177
 #, gcc-internal-format
 msgid "number of arguments doesn%'t match prototype"
 msgstr "实参数目与原型不符"
 
-#: c/c-decl.c:9160 c/c-decl.c:9207 c/c-decl.c:9221
+#: c/c-decl.c:9180 c/c-decl.c:9227 c/c-decl.c:9241
 #, gcc-internal-format
 msgid "prototype declaration"
 msgstr "原型声明"
 
-#: c/c-decl.c:9199
+#: c/c-decl.c:9219
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match built-in prototype"
 msgstr "提升后的实参%qD与内建原型不符"
 
-#: c/c-decl.c:9204
+#: c/c-decl.c:9224
 #, gcc-internal-format
 msgid "promoted argument %qD doesn%'t match prototype"
 msgstr "提升后的实参%qD与原型不符"
 
-#: c/c-decl.c:9214
+#: c/c-decl.c:9234
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match built-in prototype"
 msgstr "实参%qD与内建原型不符"
 
-#: c/c-decl.c:9219
+#: c/c-decl.c:9239
 #, gcc-internal-format
 msgid "argument %qD doesn%'t match prototype"
 msgstr "实参%qD与原型不符"
 
-#: c/c-decl.c:9470 cp/decl.c:15873
+#: c/c-decl.c:9490 cp/decl.c:15897
 #, gcc-internal-format
 msgid "no return statement in function returning non-void"
 msgstr "在有返回值的函数中未发现 return 语句"
 
-#: c/c-decl.c:9490 cp/decl.c:15905
+#: c/c-decl.c:9510 cp/decl.c:15929
 #, gcc-internal-format
 msgid "parameter %qD set but not used"
 msgstr "形参%qD被设定但未被使用"
@@ -38512,251 +38557,251 @@
 #. If we get here, declarations have been used in a for loop without
 #. the C99 for loop scope.  This doesn't make much sense, so don't
 #. allow it.
-#: c/c-decl.c:9586
+#: c/c-decl.c:9606
 #, fuzzy, gcc-internal-format
 msgid "%<for%> loop initial declarations are only allowed in C99 or C11 mode"
 msgstr "只允许在 C99 模式下使用%<for%>循环初始化声明"
 
-#: c/c-decl.c:9591
+#: c/c-decl.c:9611
 #, fuzzy, gcc-internal-format
 msgid "use option -std=c99, -std=gnu99, -std=c11 or -std=gnu11 to compile your code"
 msgstr "使用 -std=c99 或 -std=gnu99 来编译您的代码"
 
-#: c/c-decl.c:9626
+#: c/c-decl.c:9646
 #, gcc-internal-format
 msgid "declaration of static variable %qD in %<for%> loop initial declaration"
 msgstr "在%<for%>循环初始声明中声明了静态变量%qD"
 
-#: c/c-decl.c:9630
+#: c/c-decl.c:9650
 #, gcc-internal-format
 msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgstr "在%<for%>循环初始声明中声明了%<extern%>变量%qD"
 
-#: c/c-decl.c:9637
+#: c/c-decl.c:9657
 #, gcc-internal-format
 msgid "%<struct %E%> declared in %<for%> loop initial declaration"
 msgstr "%<struct %E%>声明于%<for%>循环初始声明中"
 
-#: c/c-decl.c:9642
+#: c/c-decl.c:9662
 #, gcc-internal-format
 msgid "%<union %E%> declared in %<for%> loop initial declaration"
 msgstr "%<union %E%>声明于%<for%>循环初始声明中"
 
-#: c/c-decl.c:9646
+#: c/c-decl.c:9666
 #, gcc-internal-format
 msgid "%<enum %E%> declared in %<for%> loop initial declaration"
 msgstr "%<enum %E%>声明于%<for%>循环初始声明中"
 
-#: c/c-decl.c:9650
+#: c/c-decl.c:9670
 #, gcc-internal-format
 msgid "declaration of non-variable %qD in %<for%> loop initial declaration"
 msgstr "在%<for%>循环初始声明中声明了非变量%qD"
 
-#: c/c-decl.c:9900
+#: c/c-decl.c:9920
 #, gcc-internal-format
 msgid "incompatible address space qualifiers %qs and %qs"
 msgstr "不兼容的地址空间限定符%qs和%qs"
 
-#: c/c-decl.c:9958 c/c-decl.c:9965
+#: c/c-decl.c:9978 c/c-decl.c:9985
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "duplicate %qE declaration specifier"
 msgstr "需要指定声明"
 
-#: c/c-decl.c:9992 c/c-decl.c:10376 c/c-decl.c:10766
+#: c/c-decl.c:10012 c/c-decl.c:10396 c/c-decl.c:10786
 #, gcc-internal-format
 msgid "two or more data types in declaration specifiers"
 msgstr "声明指定了两个以上的数据类型"
 
-#: c/c-decl.c:10004 cp/parser.c:28261
+#: c/c-decl.c:10024 cp/parser.c:28258
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%>对 GCC 来说太长了"
 
-#: c/c-decl.c:10017
+#: c/c-decl.c:10037
 #, gcc-internal-format
 msgid "ISO C90 does not support %<long long%>"
 msgstr "ISO C90 不支持%<long long%>"
 
-#: c/c-decl.c:10246 c/c-parser.c:8848
+#: c/c-decl.c:10266 c/c-parser.c:8848
 #, gcc-internal-format
 msgid "ISO C90 does not support complex types"
 msgstr "ISO C90 不支持复数类型"
 
-#: c/c-decl.c:10292
+#: c/c-decl.c:10312
 #, gcc-internal-format
 msgid "ISO C does not support saturating types"
 msgstr "ISO C 不支持饱和类型"
 
-#: c/c-decl.c:10363 c/c-decl.c:10923
+#: c/c-decl.c:10383 c/c-decl.c:10943
 #, gcc-internal-format
 msgid "duplicate %qE"
 msgstr "重复的%qE"
 
-#: c/c-decl.c:10419
+#: c/c-decl.c:10439
 #, gcc-internal-format
 msgid "ISO C does not support %<__int%d%> types"
 msgstr "ISO C 不支持 %<__int%d%> 类型"
 
-#: c/c-decl.c:10441
+#: c/c-decl.c:10461
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported on this target"
 msgstr "嵌套函数在此目标机上不受支持"
 
-#: c/c-decl.c:10484
+#: c/c-decl.c:10504
 #, gcc-internal-format
 msgid "ISO C90 does not support boolean types"
 msgstr "ISO C90 不支持布尔类型"
 
-#: c/c-decl.c:10603
+#: c/c-decl.c:10623
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support %<__int%d%> types"
 msgid "ISO C does not support the %<_Float%d%s%> type"
 msgstr "ISO C 不支持 %<__int%d%> 类型"
 
-#: c/c-decl.c:10653
+#: c/c-decl.c:10673
 #, fuzzy, gcc-internal-format
 msgid "%<_Float%d%s%> is not supported on this target"
 msgstr "嵌套函数在此目标机上不受支持"
 
-#: c/c-decl.c:10724
+#: c/c-decl.c:10744
 #, gcc-internal-format
 msgid "ISO C does not support decimal floating point"
 msgstr "ISO C 不支持十进制浮点数"
 
-#: c/c-decl.c:10747 c/c-decl.c:11013 c/c-parser.c:7842
+#: c/c-decl.c:10767 c/c-decl.c:11033 c/c-parser.c:7842
 #, gcc-internal-format
 msgid "fixed-point types not supported for this target"
 msgstr "定点类型在此目标机上不受支持"
 
-#: c/c-decl.c:10749
+#: c/c-decl.c:10769
 #, gcc-internal-format
 msgid "ISO C does not support fixed-point types"
 msgstr "ISO C 不支持定点类型"
 
-#: c/c-decl.c:10784
+#: c/c-decl.c:10804
 #, gcc-internal-format
 msgid "C++ lookup of %qD would return a field, not a type"
 msgstr "%qD的 C++ 查询会返回一个字段而非类型"
 
-#: c/c-decl.c:10797
+#: c/c-decl.c:10817
 #, gcc-internal-format
 msgid "%qE fails to be a typedef or built in type"
 msgstr "%qE不是一个 typedef 类型，也不是一个内建类型"
 
-#: c/c-decl.c:10845
+#: c/c-decl.c:10865
 #, gcc-internal-format
 msgid "%qE is not at beginning of declaration"
 msgstr "%qE没有出现在声明的开头"
 
-#: c/c-decl.c:10866
+#: c/c-decl.c:10886
 #, fuzzy, gcc-internal-format
 msgid "%qE used with %<auto%>"
 msgstr "%qE不能用作函数"
 
-#: c/c-decl.c:10868
+#: c/c-decl.c:10888
 #, fuzzy, gcc-internal-format
 msgid "%qE used with %<register%>"
 msgstr "无效的协寄存器%qE"
 
-#: c/c-decl.c:10870
+#: c/c-decl.c:10890
 #, fuzzy, gcc-internal-format
 msgid "%qE used with %<typedef%>"
 msgstr "%qE不是一个 typedef 类型，也不是一个内建类型"
 
-#: c/c-decl.c:10884 c/c-parser.c:7360
+#: c/c-decl.c:10904 c/c-parser.c:7360
 #, gcc-internal-format
 msgid "ISO C99 does not support %qE"
 msgstr "ISO C99 不支持 %qE"
 
-#: c/c-decl.c:10887 c/c-parser.c:7363
+#: c/c-decl.c:10907 c/c-parser.c:7363
 #, gcc-internal-format
 msgid "ISO C90 does not support %qE"
 msgstr "ISO C90 不支持 %qE"
 
-#: c/c-decl.c:10899
+#: c/c-decl.c:10919
 #, gcc-internal-format
 msgid "%<__thread%> before %<extern%>"
 msgstr "%<__thread%>出现在%<extern%>之前"
 
-#: c/c-decl.c:10908
+#: c/c-decl.c:10928
 #, gcc-internal-format
 msgid "%<__thread%> before %<static%>"
 msgstr "%<__thread%>出现在%<static%>之前"
 
-#: c/c-decl.c:10921
+#: c/c-decl.c:10941
 #, fuzzy, gcc-internal-format
 msgid "duplicate %<_Thread_local%> or %<__thread%>"
 msgstr "线程局部的 COMMON 数据没有实现"
 
-#: c/c-decl.c:10929
+#: c/c-decl.c:10949
 #, gcc-internal-format
 msgid "multiple storage classes in declaration specifiers"
 msgstr "声明指定了多个存储类"
 
-#: c/c-decl.c:10937
+#: c/c-decl.c:10957
 #, fuzzy, gcc-internal-format
 msgid "%qs used with %qE"
 msgstr "%qE可被预先确定为%qs，为%qs"
 
-#: c/c-decl.c:11010
+#: c/c-decl.c:11030
 #, gcc-internal-format
 msgid "%<_Sat%> is used without %<_Fract%> or %<_Accum%>"
 msgstr "%<_Sat%>使用时缺少%<_Fract%>或%<_Accum%>"
 
-#: c/c-decl.c:11025
+#: c/c-decl.c:11045
 #, gcc-internal-format
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C 不支持单独用%<complex%>表示%<double complex%>"
 
-#: c/c-decl.c:11076 c/c-decl.c:11092 c/c-decl.c:11118
+#: c/c-decl.c:11096 c/c-decl.c:11112 c/c-decl.c:11138
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C 不支持复整数"
 
-#: c/c-decl.c:11514 cp/semantics.c:5348
+#: c/c-decl.c:11534 cp/semantics.c:5351
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:11518 cp/semantics.c:5352
+#: c/c-decl.c:11538 cp/semantics.c:5355
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
 
-#: c/c-fold.c:385 c/c-typeck.c:11426 cp/typeck.c:4680
+#: c/c-fold.c:385 c/c-typeck.c:11431 cp/typeck.c:4680
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count is negative"
 msgid "left shift of negative value"
 msgstr "左移次数为负"
 
-#: c/c-fold.c:395 c/c-typeck.c:11435 cp/typeck.c:4688
+#: c/c-fold.c:395 c/c-typeck.c:11440 cp/typeck.c:4688
 #, gcc-internal-format
 msgid "left shift count is negative"
 msgstr "左移次数为负"
 
-#: c/c-fold.c:396 c/c-typeck.c:11365 cp/typeck.c:4633
+#: c/c-fold.c:396 c/c-typeck.c:11370 cp/typeck.c:4633
 #, gcc-internal-format
 msgid "right shift count is negative"
 msgstr "右移次数为负"
 
-#: c/c-fold.c:404 c/c-typeck.c:11454 cp/typeck.c:4696
+#: c/c-fold.c:404 c/c-typeck.c:11459 cp/typeck.c:4696
 #, gcc-internal-format
 msgid "left shift count >= width of type"
 msgstr "左移次数大于或等于类型宽度"
 
-#: c/c-fold.c:405 c/c-typeck.c:11389 cp/typeck.c:4641
+#: c/c-fold.c:405 c/c-typeck.c:11394 cp/typeck.c:4641
 #, gcc-internal-format
 msgid "right shift count >= width of type"
 msgstr "右移次数大于或等于类型宽度"
 
-#: c/c-fold.c:412 c/c-typeck.c:11446
+#: c/c-fold.c:412 c/c-typeck.c:11451
 #, fuzzy, gcc-internal-format
 #| msgid "left shift count >= width of type"
 msgid "left shift count >= width of vector element"
 msgstr "左移次数大于或等于类型宽度"
 
-#: c/c-fold.c:413 c/c-typeck.c:11376
+#: c/c-fold.c:413 c/c-typeck.c:11381
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count >= width of type"
 msgid "right shift count >= width of vector element"
@@ -38777,7 +38822,7 @@
 msgid "to match this %qs"
 msgstr "没有匹配"
 
-#: c/c-parser.c:1216 cp/parser.c:28484
+#: c/c-parser.c:1216 cp/parser.c:28481
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr "需要行尾"
@@ -38819,7 +38864,7 @@
 msgstr "未知的类型名%qE"
 
 #: c/c-parser.c:1848 c/c-parser.c:11129 c/c-parser.c:16147 c/c-parser.c:16585
-#: c/c-parser.c:17061 cp/parser.c:36007 cp/parser.c:38993
+#: c/c-parser.c:17061 cp/parser.c:36004 cp/parser.c:38990
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "需要指定声明"
@@ -38834,7 +38879,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "需要标识符或%<(%>"
 
-#: c/c-parser.c:1906 cp/parser.c:30161 cp/parser.c:30235
+#: c/c-parser.c:1906 cp/parser.c:30158 cp/parser.c:30232
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "属性在未初始化类型上被忽略"
@@ -38889,7 +38934,7 @@
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr "%<auto%> 只能被指定的用于变量或函数声明"
 
-#: c/c-parser.c:2220 cp/parser.c:13002 cp/parser.c:13159
+#: c/c-parser.c:2220 cp/parser.c:12999 cp/parser.c:13156
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "需要%<,%>或%<;%>"
@@ -38917,7 +38962,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C90 不支持%<_Static_assert%>"
 
-#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38634
+#: c/c-parser.c:2448 c/c-parser.c:4160 c/c-parser.c:11187 cp/parser.c:38631
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr "需要字面字符串"
@@ -38982,13 +39027,13 @@
 #: c/c-parser.c:10745 c/c-parser.c:10798 c/c-parser.c:10814 c/c-parser.c:10860
 #: c/c-parser.c:11496 c/c-parser.c:11537 c/c-parser.c:13445 c/c-parser.c:13681
 #: c/c-parser.c:15544 c/c-parser.c:18218 c/gimple-parser.c:1058
-#: c/gimple-parser.c:1096 cp/parser.c:28487 cp/parser.c:31013
-#: cp/parser.c:31043 cp/parser.c:31113 cp/parser.c:33230 cp/parser.c:38350
+#: c/gimple-parser.c:1096 cp/parser.c:28484 cp/parser.c:31010
+#: cp/parser.c:31040 cp/parser.c:31110 cp/parser.c:33227 cp/parser.c:38347
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "需要标识符"
 
-#: c/c-parser.c:2995 cp/parser.c:18384
+#: c/c-parser.c:2995 cp/parser.c:18381
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "枚举表以逗号结尾"
@@ -39157,12 +39202,12 @@
 msgid "expected statement"
 msgstr "需要语句"
 
-#: c/c-parser.c:5639 cp/parser.c:12516
+#: c/c-parser.c:5639 cp/parser.c:12513
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "建议在空的%<if%>语句体周围加上花括号"
 
-#: c/c-parser.c:5681 cp/parser.c:12519
+#: c/c-parser.c:5681 cp/parser.c:12516
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "建议在空的%<else%>语句体周围加上花括号"
@@ -39515,7 +39560,7 @@
 msgid "%<__builtin_complex%> operands of different types"
 msgstr "?: 的操作数类型不一致，分别为%qT和%qT"
 
-#: c/c-parser.c:8891 cp/parser.c:6918
+#: c/c-parser.c:8891 cp/parser.c:6921
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_shuffle%>"
 msgstr "给函数%<__builtin_next_arg%>的参数数目不对"
@@ -39575,77 +39620,77 @@
 msgid "no type or storage class may be specified here,"
 msgstr "为%qs指定了存储类"
 
-#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31073
+#: c/c-parser.c:10661 c/c-parser.c:10718 cp/parser.c:31070
 #, fuzzy, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "不能设置只读属性"
 
-#: c/c-parser.c:10682 cp/parser.c:31033
+#: c/c-parser.c:10682 cp/parser.c:31030
 #, fuzzy, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "%qs后断言"
 
-#: c/c-parser.c:10685 cp/parser.c:31036
+#: c/c-parser.c:10685 cp/parser.c:31033
 #, fuzzy, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "%<readonly%>属性与%<setter%>属性冲突"
 
-#: c/c-parser.c:10699 cp/parser.c:31051
+#: c/c-parser.c:10699 cp/parser.c:31048
 #, fuzzy, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "不能为函数指定地址区域属性"
 
-#: c/c-parser.c:10704 cp/parser.c:31057
+#: c/c-parser.c:10704 cp/parser.c:31054
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr "setter 的名字必须以%<:%>结尾"
 
-#: c/c-parser.c:10711 cp/parser.c:31065
+#: c/c-parser.c:10711 cp/parser.c:31062
 #, fuzzy, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "不能为函数指定地址区域属性"
 
-#: c/c-parser.c:10905 cp/parser.c:38674
+#: c/c-parser.c:10905 cp/parser.c:38671
 #, gcc-internal-format
 msgid "%<#pragma GCC unroll%> requires an assignment-expression that evaluates to a non-negative integral constant less than %u"
 msgstr ""
 
 #: c/c-parser.c:10949 c/c-parser.c:16582 c/c-parser.c:16840 c/c-parser.c:16899
-#: c/c-parser.c:16983 cp/parser.c:36004 cp/parser.c:36298 cp/parser.c:36386
-#: cp/parser.c:36457 cp/parser.c:38721 cp/parser.c:38736 cp/parser.c:38752
-#: cp/parser.c:38768 cp/parser.c:38784 cp/parser.c:38811 cp/parser.c:38824
-#: cp/parser.c:38847 cp/parser.c:38860
+#: c/c-parser.c:16983 cp/parser.c:36001 cp/parser.c:36295 cp/parser.c:36383
+#: cp/parser.c:36454 cp/parser.c:38718 cp/parser.c:38733 cp/parser.c:38749
+#: cp/parser.c:38765 cp/parser.c:38781 cp/parser.c:38808 cp/parser.c:38821
+#: cp/parser.c:38844 cp/parser.c:38857
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp flush%> may only be used in compound statements"
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<#pragma omp flush%>只能用在复合语句中"
 
-#: c/c-parser.c:10972 cp/parser.c:38837
+#: c/c-parser.c:10972 cp/parser.c:38834
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "Objective-C 声明只能出现在全局作用域中"
 
-#: c/c-parser.c:11050 cp/parser.c:38918
+#: c/c-parser.c:11050 cp/parser.c:38915
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<#pragma omp section%>只能用在%<#pragma omp sections%>结构中"
 
-#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38947 cp/parser.c:38980
+#: c/c-parser.c:11074 c/c-parser.c:11098 cp/parser.c:38944 cp/parser.c:38977
 #, fuzzy, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "需要语句"
 
-#: c/c-parser.c:11111 cp/parser.c:38711
+#: c/c-parser.c:11111 cp/parser.c:38708
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%>必须是第一个"
 
-#: c/c-parser.c:11421 cp/parser.c:31457
+#: c/c-parser.c:11421 cp/parser.c:31454
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "太多的%qs子句"
 
-#: c/c-parser.c:11443 cp/parser.c:31994
+#: c/c-parser.c:11443 cp/parser.c:31991
 #, fuzzy, gcc-internal-format
 msgid "expected integer expression before ')'"
 msgstr "需要整数表达式"
@@ -39660,58 +39705,58 @@
 msgid "%qD is not a variable"
 msgstr "%qD不是一个变量"
 
-#: c/c-parser.c:11746 cp/semantics.c:6808
+#: c/c-parser.c:11746 cp/semantics.c:6811
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "%qD不是一个变量"
 
-#: c/c-parser.c:11788 cp/parser.c:32073
+#: c/c-parser.c:11788 cp/parser.c:32070
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr "折叠参数需要正整常量表达式"
 
-#: c/c-parser.c:11865 cp/parser.c:32137
+#: c/c-parser.c:11865 cp/parser.c:32134
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<none%> or %<present%>"
 msgstr "需要%<none%>或%<shared%>"
 
-#: c/c-parser.c:11867 cp/parser.c:32139
+#: c/c-parser.c:11867 cp/parser.c:32136
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "需要%<none%>或%<shared%>"
 
-#: c/c-parser.c:11968 cp/parser.c:32242
+#: c/c-parser.c:11968 cp/parser.c:32239
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "需要 %<;%>、%<,%> 或 %<)%>"
 
-#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32260
-#: cp/parser.c:36290 cp/parser.c:36378
+#: c/c-parser.c:11988 c/c-parser.c:16892 c/c-parser.c:16976 cp/parser.c:32257
+#: cp/parser.c:36287 cp/parser.c:36375
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<catch%>"
 msgid "expected %<data%>"
 msgstr "需要%<catch%>"
 
-#: c/c-parser.c:12035 cp/parser.c:32313
+#: c/c-parser.c:12035 cp/parser.c:32310
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:12042 cp/parser.c:32320
+#: c/c-parser.c:12042 cp/parser.c:32317
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<if%> clauses"
 msgstr "太多的%qs子句"
 
-#: c/c-parser.c:12044 cp/parser.c:32322
+#: c/c-parser.c:12044 cp/parser.c:32319
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<if%> clauses without modifier"
 msgstr "太多的%qs子句"
 
-#: c/c-parser.c:12050 cp/parser.c:32328
+#: c/c-parser.c:12050 cp/parser.c:32325
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -39733,85 +39778,85 @@
 msgid "%<num_tasks%> value must be positive"
 msgstr "%<num_threads%>值必须为正"
 
-#: c/c-parser.c:12229 cp/semantics.c:6992
+#: c/c-parser.c:12229 cp/semantics.c:6995
 #, fuzzy, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr "%<num_threads%>值必须为正"
 
-#: c/c-parser.c:12276 cp/semantics.c:7021
+#: c/c-parser.c:12276 cp/semantics.c:7024
 #, fuzzy, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr "%<num_threads%>值必须为正"
 
-#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32545 cp/parser.c:32552
+#: c/c-parser.c:12341 c/c-parser.c:12347 cp/parser.c:32542 cp/parser.c:32549
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<throw%>"
 msgid "expected %<tofrom%>"
 msgstr "需要%<throw%>"
 
-#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32561 cp/parser.c:32568
+#: c/c-parser.c:12355 c/c-parser.c:12361 cp/parser.c:32558 cp/parser.c:32565
 #, fuzzy, gcc-internal-format
 msgid "expected %<scalar%>"
 msgstr "需要%<;%>"
 
-#: c/c-parser.c:12425 cp/semantics.c:6299
+#: c/c-parser.c:12425 cp/semantics.c:6302
 #, fuzzy, gcc-internal-format
 msgid "%qs expression must be integral"
 msgstr "调度块大小表达式必须为整型"
 
-#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6331
+#: c/c-parser.c:12437 c/c-parser.c:12560 cp/semantics.c:6334
 #, fuzzy, gcc-internal-format
 msgid "%qs value must be positive"
 msgstr "%<num_threads%>值必须为正"
 
-#: c/c-parser.c:12499 cp/parser.c:31853
+#: c/c-parser.c:12499 cp/parser.c:31850
 #, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "太多 %<static%> 参数"
 
-#: c/c-parser.c:12533 cp/parser.c:31886
+#: c/c-parser.c:12533 cp/parser.c:31883
 #, gcc-internal-format
 msgid "unexpected argument"
 msgstr "非预期的参数"
 
-#: c/c-parser.c:12699 cp/semantics.c:7120
+#: c/c-parser.c:12699 cp/semantics.c:7123
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute argument not an integer constant"
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "%qE属性需要一个整常量作为实参"
 
-#: c/c-parser.c:12765 cp/parser.c:32626
+#: c/c-parser.c:12765 cp/parser.c:32623
 #, fuzzy, gcc-internal-format
 #| msgid "collapse argument needs positive constant integer expression"
 msgid "ordered argument needs positive constant integer expression"
 msgstr "折叠参数需要正整常量表达式"
 
-#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37643
+#: c/c-parser.c:12857 c/c-parser.c:17625 cp/parser.c:37640
 #, fuzzy, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "需要标识符或%<(%>"
 
-#: c/c-parser.c:12967 cp/parser.c:32840
+#: c/c-parser.c:12967 cp/parser.c:32837
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr ""
 
-#: c/c-parser.c:13021 cp/parser.c:32856
+#: c/c-parser.c:13021 cp/parser.c:32853
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "调度%<runtime%>不接受一个%<chunk_size%>参数"
 
-#: c/c-parser.c:13025 cp/parser.c:32859
+#: c/c-parser.c:13025 cp/parser.c:32856
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "调度%<auto%>不接受一个%<chunk_size%>参数"
 
-#: c/c-parser.c:13037 cp/semantics.c:6389
+#: c/c-parser.c:13037 cp/semantics.c:6392
 #, fuzzy, gcc-internal-format
 msgid "chunk size value must be positive"
 msgstr "%<num_threads%>值必须为正"
 
-#: c/c-parser.c:13060 cp/parser.c:32879
+#: c/c-parser.c:13060 cp/parser.c:32876
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "无效的调度类型"
@@ -39821,12 +39866,12 @@
 msgid "%<num_teams%> value must be positive"
 msgstr "%<num_threads%>值必须为正"
 
-#: c/c-parser.c:13226 cp/semantics.c:6479
+#: c/c-parser.c:13226 cp/semantics.c:6482
 #, fuzzy, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr "%<num_threads%>值必须为正"
 
-#: c/c-parser.c:13271 cp/semantics.c:6589
+#: c/c-parser.c:13271 cp/semantics.c:6592
 #, fuzzy, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr "%H折叠变量需要正整常数表达式"
@@ -39846,17 +39891,17 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr "%H折叠变量需要正整常数表达式"
 
-#: c/c-parser.c:13584 cp/parser.c:33374 cp/parser.c:33599
+#: c/c-parser.c:13584 cp/parser.c:33371 cp/parser.c:33596
 #, fuzzy, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "无效的调度类型"
 
-#: c/c-parser.c:13669 cp/parser.c:33447
+#: c/c-parser.c:13669 cp/parser.c:33444
 #, fuzzy, gcc-internal-format
 msgid "invalid map kind"
 msgstr "无效的实型种别 %d，在%C处"
 
-#: c/c-parser.c:13767 cp/parser.c:33546
+#: c/c-parser.c:13767 cp/parser.c:33543
 #, fuzzy, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "无效的调度类型"
@@ -39866,69 +39911,69 @@
 msgid "invalid proc_bind kind"
 msgstr "无效的调度类型"
 
-#: c/c-parser.c:14059 cp/parser.c:33825
+#: c/c-parser.c:14059 cp/parser.c:33822
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr "需要%<#pragma omp%>子句"
 
-#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33836 cp/parser.c:34143
+#: c/c-parser.c:14070 c/c-parser.c:14345 cp/parser.c:33833 cp/parser.c:34140
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs对%qs而言无效"
 
-#: c/c-parser.c:14214 cp/parser.c:34010
+#: c/c-parser.c:14214 cp/parser.c:34007
 #, fuzzy, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "%qE在子句%qs中不是一个变量"
 
-#: c/c-parser.c:14334 cp/parser.c:34132
+#: c/c-parser.c:14334 cp/parser.c:34129
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "需要%<#pragma omp%>子句"
 
-#: c/c-parser.c:14472 cp/parser.c:36803
+#: c/c-parser.c:14472 cp/parser.c:36800
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14482 cp/parser.c:36813
+#: c/c-parser.c:14482 cp/parser.c:36810
 #, fuzzy, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr "%qD的声明隐藏了一个全局声明"
 
-#: c/c-parser.c:14502 cp/parser.c:36833
+#: c/c-parser.c:14502 cp/parser.c:36830
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr "指定链接时使用%qD无效"
 
-#: c/c-parser.c:14513 cp/parser.c:36844
+#: c/c-parser.c:14513 cp/parser.c:36841
 #, fuzzy, gcc-internal-format
 #| msgid "variably modified field at file scope"
 msgid "invalid OpenACC clause at file scope"
 msgstr "文件域中的动态可变字段"
 
-#: c/c-parser.c:14520 cp/parser.c:36851
+#: c/c-parser.c:14520 cp/parser.c:36848
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "在%<for%>循环初始声明中声明了%<extern%>变量%qD"
 
-#: c/c-parser.c:14528 cp/parser.c:36859
+#: c/c-parser.c:14528 cp/parser.c:36856
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "指定链接时使用%qD无效"
 
-#: c/c-parser.c:14540 cp/parser.c:36871
+#: c/c-parser.c:14540 cp/parser.c:36868
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:14632 cp/parser.c:36957
+#: c/c-parser.c:14632 cp/parser.c:36954
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "%<#pragma message%>后需要一个字符串"
 
-#: c/c-parser.c:14648 cp/parser.c:36974
+#: c/c-parser.c:14648 cp/parser.c:36971
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
@@ -39944,7 +39989,7 @@
 msgid "expected function name"
 msgstr "需要函数"
 
-#: c/c-parser.c:14893 cp/parser.c:38064
+#: c/c-parser.c:14893 cp/parser.c:38061
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qD does not refer to a function"
@@ -39955,42 +40000,42 @@
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr "%<#pragma align%>必须出现在 %D 的声明之前，忽略"
 
-#: c/c-parser.c:14953 cp/parser.c:38118 cp/parser.c:38160
+#: c/c-parser.c:14953 cp/parser.c:38115 cp/parser.c:38157
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr "%<#pragma align%>必须出现在 %D 的声明之前，忽略"
 
-#: c/c-parser.c:14970 cp/parser.c:38174
+#: c/c-parser.c:14970 cp/parser.c:38171
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> already applied to %qD"
 msgstr "#pragma GCC optimize 不允许用在函数中"
 
-#: c/c-parser.c:14979 cp/parser.c:38183
+#: c/c-parser.c:14979 cp/parser.c:38180
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr "#pragma GCC optimize 不允许用在函数中"
 
-#: c/c-parser.c:14980 cp/parser.c:38184
+#: c/c-parser.c:14980 cp/parser.c:38181
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "#pragma GCC optimize 不允许用在函数中"
 
-#: c/c-parser.c:15023 cp/parser.c:37152
+#: c/c-parser.c:15023 cp/parser.c:37149
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.c:15435 cp/parser.c:34511 cp/parser.c:34537
+#: c/c-parser.c:15435 cp/parser.c:34508 cp/parser.c:34534
 #, fuzzy, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "%<#pragma omp atomic%>运算符无效"
 
-#: c/c-parser.c:15439 cp/parser.c:34568 cp/parser.c:34584
+#: c/c-parser.c:15439 cp/parser.c:34565 cp/parser.c:34581
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "%<#pragma omp atomic%>运算符无效"
 
-#: c/c-parser.c:15488 cp/semantics.c:8401 cp/semantics.c:8411
+#: c/c-parser.c:15488 cp/semantics.c:8404 cp/semantics.c:8414
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr "%<# pragma omp 基元的 capture%>使用两不同的变量用于内存"
@@ -40000,22 +40045,22 @@
 msgid "expected %<(%> or end of line"
 msgstr "需要%<(%>或行尾"
 
-#: c/c-parser.c:15619 cp/parser.c:35103
+#: c/c-parser.c:15619 cp/parser.c:35100
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:15630 cp/parser.c:35114
+#: c/c-parser.c:15630 cp/parser.c:35111
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:15648 cp/parser.c:35141
+#: c/c-parser.c:15648 cp/parser.c:35138
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "需要 for 语句"
 
-#: c/c-parser.c:15718 cp/semantics.c:8066 cp/semantics.c:8153
+#: c/c-parser.c:15718 cp/semantics.c:8069 cp/semantics.c:8156
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "需要迭代声明或初始化"
@@ -40025,74 +40070,74 @@
 msgid "not enough perfectly nested loops"
 msgstr "不够完美的嵌套循环"
 
-#: c/c-parser.c:15862 cp/parser.c:35364
+#: c/c-parser.c:15862 cp/parser.c:35361
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr "折叠的循环没有完美的嵌套"
 
-#: c/c-parser.c:15909 cp/parser.c:35184 cp/parser.c:35226 cp/pt.c:16385
+#: c/c-parser.c:15909 cp/parser.c:35181 cp/parser.c:35223 cp/pt.c:16407
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "迭代变量%qD不应当是 firstprivate"
 
-#: c/c-parser.c:16000 cp/parser.c:35437
+#: c/c-parser.c:16000 cp/parser.c:35434
 #, fuzzy, gcc-internal-format
 #| msgid "%<void%> as only parameter may not be qualified"
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "%<void%>作为仅有的参数时不能被限定"
 
-#: c/c-parser.c:16166 cp/parser.c:35600
+#: c/c-parser.c:16166 cp/parser.c:35597
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr "%<#pragma omp barrier%>只能用在复合语句中"
 
-#: c/c-parser.c:16374 cp/parser.c:35799
+#: c/c-parser.c:16374 cp/parser.c:35796
 #, fuzzy, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "{ 预期于运算式中 ? 之后"
 
-#: c/c-parser.c:16573 cp/parser.c:35995
+#: c/c-parser.c:16573 cp/parser.c:35992
 #, fuzzy, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "需要%<;%>"
 
-#: c/c-parser.c:16793 cp/parser.c:36232
+#: c/c-parser.c:16793 cp/parser.c:36229
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.c:16806 cp/parser.c:36245
+#: c/c-parser.c:16806 cp/parser.c:36242
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.c:16853 cp/parser.c:36470
+#: c/c-parser.c:16853 cp/parser.c:36467
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.c:16925 cp/parser.c:36325
+#: c/c-parser.c:16925 cp/parser.c:36322
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.c:16937 cp/parser.c:36337
+#: c/c-parser.c:16937 cp/parser.c:36334
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.c:17011 cp/parser.c:36414
+#: c/c-parser.c:17011 cp/parser.c:36411
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.c:17024 cp/parser.c:36427
+#: c/c-parser.c:17024 cp/parser.c:36424
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.c:17238 cp/parser.c:36680
+#: c/c-parser.c:17238 cp/parser.c:36677
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
@@ -40112,32 +40157,32 @@
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17395 cp/parser.c:37273
+#: c/c-parser.c:17395 cp/parser.c:37270
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:17474 cp/parser.c:37343
+#: c/c-parser.c:17474 cp/parser.c:37340
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare target%> with clauses in between %<#pragma omp declare target%> without clauses and %<#pragma omp end declare target%>"
 msgstr "%<#pragma GCC pop_options%>缺少相应的%<#pragma GCC push_options%>"
 
-#: c/c-parser.c:17493 cp/parser.c:37362
+#: c/c-parser.c:17493 cp/parser.c:37359
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:17534 cp/parser.c:37409
+#: c/c-parser.c:17534 cp/parser.c:37406
 #, fuzzy, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "需要%<;%>"
 
-#: c/c-parser.c:17541 cp/parser.c:37416
+#: c/c-parser.c:17541 cp/parser.c:37413
 #, fuzzy, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "需要%<;%>"
 
-#: c/c-parser.c:17547 cp/parser.c:37423
+#: c/c-parser.c:17547 cp/parser.c:37420
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr "%<#pragma GCC pop_options%>缺少相应的%<#pragma GCC push_options%>"
@@ -40192,47 +40237,47 @@
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:17947 cp/parser.c:37868
+#: c/c-parser.c:17947 cp/parser.c:37865
 #, fuzzy, gcc-internal-format
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr "需要%<#pragma omp section%>或%<}%>"
 
-#: c/c-parser.c:18162 cp/semantics.c:7531
+#: c/c-parser.c:18162 cp/semantics.c:7534
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE在其首次使用后被声明为%<threadprivate%>"
 
-#: c/c-parser.c:18164 cp/semantics.c:7533
+#: c/c-parser.c:18164 cp/semantics.c:7536
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "自动变量%qE不能是%<threadprivate%>"
 
-#: c/c-parser.c:18168 cp/semantics.c:7535
+#: c/c-parser.c:18168 cp/semantics.c:7538
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%<threadprivate%>%qE的类型不完全"
 
-#: c/c-parser.c:18368 cp/parser.c:38565
+#: c/c-parser.c:18368 cp/parser.c:38562
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr "%<__transaction_cancel%>而无需 transactional 内存支持已启用"
 
-#: c/c-parser.c:18374 cp/parser.c:38571
+#: c/c-parser.c:18374 cp/parser.c:38568
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr "%<__transaction_cancel%>在之内 %<__transaction_relaxed%>"
 
-#: c/c-parser.c:18383 cp/parser.c:38580
+#: c/c-parser.c:18383 cp/parser.c:38577
 #, fuzzy, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr "外 %<__transaction_cancel%>无法在之内外 %<__transaction_atomic%>"
 
-#: c/c-parser.c:18385 cp/parser.c:38583
+#: c/c-parser.c:18385 cp/parser.c:38580
 #, fuzzy, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr "  或 %<transaction_may_cancel_outer%> 函数"
 
-#: c/c-parser.c:18391 cp/parser.c:38589
+#: c/c-parser.c:18391 cp/parser.c:38586
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr "%<__transaction_cancel%>无法在之内 %<__transaction_atomic%>"
@@ -40248,7 +40293,7 @@
 msgid "%qD has an incomplete type %qT"
 msgstr "%qD类型不完全"
 
-#: c/c-typeck.c:237 c/c-typeck.c:9994 c/c-typeck.c:10036 cp/call.c:4147
+#: c/c-typeck.c:237 c/c-typeck.c:9999 c/c-typeck.c:10041 cp/call.c:4147
 #, gcc-internal-format
 msgid "invalid use of void expression"
 msgstr "对 void 表达式的使用无效"
@@ -40326,13 +40371,13 @@
 msgid "converting an array compound literal to a pointer is ill-formed in C++"
 msgstr "C++ 不允许在组合字面常量中定义类型"
 
-#: c/c-typeck.c:2417 c/c-typeck.c:8641
+#: c/c-typeck.c:2417 c/c-typeck.c:8646
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no member named %qE"
 msgid "%qT has no member named %qE; did you mean %qE?"
 msgstr "%qT没有名为%qE的成员"
 
-#: c/c-typeck.c:2421 c/c-typeck.c:8645
+#: c/c-typeck.c:2421 c/c-typeck.c:8650
 #, gcc-internal-format
 msgid "%qT has no member named %qE"
 msgstr "%qT没有名为%qE的成员"
@@ -40532,481 +40577,481 @@
 msgid "pointer to a function used in subtraction"
 msgstr "函数指针不能相减"
 
-#: c/c-typeck.c:3847
+#: c/c-typeck.c:3852
 #, gcc-internal-format
 msgid "arithmetic on pointer to an incomplete type"
 msgstr "在指向不完全类型的指针上执行算术运算"
 
-#: c/c-typeck.c:3852 cp/typeck.c:5562
+#: c/c-typeck.c:3857 cp/typeck.c:5562
 #, fuzzy, gcc-internal-format
 msgid "arithmetic on pointer to an empty aggregate"
 msgstr "在指向不完全类型的指针上执行算术运算"
 
-#: c/c-typeck.c:4283
+#: c/c-typeck.c:4288
 #, fuzzy, gcc-internal-format
 #| msgid "expected boolean expression"
 msgid "%<~%> on a boolean expression"
 msgstr "需要布尔表达式"
 
-#: c/c-typeck.c:4287
+#: c/c-typeck.c:4292
 #, gcc-internal-format
 msgid "did you mean to use logical not?"
 msgstr ""
 
-#: c/c-typeck.c:4296
+#: c/c-typeck.c:4301
 #, gcc-internal-format
 msgid "ISO C does not support %<~%> for complex conjugation"
 msgstr "ISO C 不支持用%<~%>求共轭复数"
 
-#: c/c-typeck.c:4335
+#: c/c-typeck.c:4340
 #, gcc-internal-format
 msgid "wrong type argument to unary exclamation mark"
 msgstr "单目 ! 的实参类型无效"
 
-#: c/c-typeck.c:4393
+#: c/c-typeck.c:4398
 #, gcc-internal-format
 msgid "increment of enumeration value is invalid in C++"
 msgstr "C++ 中枚举自增操作无效"
 
-#: c/c-typeck.c:4396
+#: c/c-typeck.c:4401
 #, gcc-internal-format
 msgid "decrement of enumeration value is invalid in C++"
 msgstr "C++ 中枚举自减操作无效"
 
-#: c/c-typeck.c:4403
+#: c/c-typeck.c:4408
 #, fuzzy, gcc-internal-format
 #| msgid "expected boolean expression"
 msgid "increment of a boolean expression"
 msgstr "需要布尔表达式"
 
-#: c/c-typeck.c:4406
+#: c/c-typeck.c:4411
 #, fuzzy, gcc-internal-format
 #| msgid "expected boolean expression"
 msgid "decrement of a boolean expression"
 msgstr "需要布尔表达式"
 
-#: c/c-typeck.c:4422
+#: c/c-typeck.c:4427
 #, gcc-internal-format
 msgid "ISO C does not support %<++%> and %<--%> on complex types"
 msgstr "ISO C 不支持对复数类型进行%<++%>或%<--%>操作"
 
-#: c/c-typeck.c:4447 c/c-typeck.c:4481
+#: c/c-typeck.c:4452 c/c-typeck.c:4486
 #, gcc-internal-format
 msgid "wrong type argument to increment"
 msgstr "该类型不支持自增"
 
-#: c/c-typeck.c:4449 c/c-typeck.c:4484
+#: c/c-typeck.c:4454 c/c-typeck.c:4489
 #, gcc-internal-format
 msgid "wrong type argument to decrement"
 msgstr "该类型不支持自减"
 
-#: c/c-typeck.c:4469
+#: c/c-typeck.c:4474
 #, fuzzy, gcc-internal-format
 msgid "increment of pointer to an incomplete type %qT"
 msgstr "指向不完全类型%qT的指针不能自增"
 
-#: c/c-typeck.c:4473
+#: c/c-typeck.c:4478
 #, fuzzy, gcc-internal-format
 msgid "decrement of pointer to an incomplete type %qT"
 msgstr "指向不完全类型%qT的指针不能自减"
 
-#: c/c-typeck.c:4577
+#: c/c-typeck.c:4582
 #, gcc-internal-format
 msgid "taking address of expression of type %<void%>"
 msgstr "取一个类型为%<void%>的表达式的地址"
 
-#: c/c-typeck.c:4636
+#: c/c-typeck.c:4641
 #, gcc-internal-format
 msgid "cannot take address of bit-field %qD"
 msgstr "无法取得位段%qD的地址"
 
-#: c/c-typeck.c:4649
+#: c/c-typeck.c:4654
 #, fuzzy, gcc-internal-format
 #| msgid "cannot take the address of %<this%>, which is an rvalue expression"
 msgid "cannot take address of scalar with reverse storage order"
 msgstr "无法取右值表达式%<this%>的地址"
 
-#: c/c-typeck.c:4657
+#: c/c-typeck.c:4662
 #, fuzzy, gcc-internal-format
 #| msgid "address of register variable %qD requested"
 msgid "address of array with reverse scalar storage order requested"
 msgstr "要求寄存器变量%qD的地址。"
 
-#: c/c-typeck.c:4838
+#: c/c-typeck.c:4843
 #, gcc-internal-format
 msgid "global register variable %qD used in nested function"
 msgstr "嵌套函数中使用了全局寄存器变量%qD"
 
-#: c/c-typeck.c:4841
+#: c/c-typeck.c:4846
 #, gcc-internal-format
 msgid "register variable %qD used in nested function"
 msgstr "嵌套函数中使用了寄存器变量%qD"
 
-#: c/c-typeck.c:4846
+#: c/c-typeck.c:4851
 #, gcc-internal-format
 msgid "address of global register variable %qD requested"
 msgstr "要求全局寄存器变量%qD的地址"
 
-#: c/c-typeck.c:4848
+#: c/c-typeck.c:4853
 #, gcc-internal-format
 msgid "address of register variable %qD requested"
 msgstr "要求寄存器变量%qD的地址。"
 
-#: c/c-typeck.c:4951
+#: c/c-typeck.c:4956
 #, gcc-internal-format
 msgid "non-lvalue array in conditional expression"
 msgstr "非左值数组出现在条件表达式中"
 
-#: c/c-typeck.c:5033
+#: c/c-typeck.c:5038
 #, fuzzy, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other result of conditional"
 msgstr "C++ 中不允许从%qT到%qT的隐式转换"
 
-#: c/c-typeck.c:5092 c/c-typeck.c:5098
+#: c/c-typeck.c:5097 c/c-typeck.c:5103
 #, gcc-internal-format
 msgid "operand of ?: changes signedness from %qT to %qT due to unsignedness of other operand"
 msgstr ""
 
-#: c/c-typeck.c:5115
+#: c/c-typeck.c:5120
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr with only one void side"
 msgstr "ISO C 不允许条件表达式仅有一边为空"
 
-#: c/c-typeck.c:5132
+#: c/c-typeck.c:5137
 #, gcc-internal-format
 msgid "pointers to disjoint address spaces used in conditional expression"
 msgstr "条件表达式中使用了指向不相交地址空间的指针"
 
-#: c/c-typeck.c:5143 c/c-typeck.c:5160
+#: c/c-typeck.c:5148 c/c-typeck.c:5165
 #, fuzzy, gcc-internal-format
 msgid "pointer to array loses qualifier in conditional expression"
 msgstr "条件表达式指针类型不匹配"
 
-#: c/c-typeck.c:5148 c/c-typeck.c:5165
+#: c/c-typeck.c:5153 c/c-typeck.c:5170
 #, gcc-internal-format
 msgid "ISO C forbids conditional expr between %<void *%> and function pointer"
 msgstr "ISO C 不允许在条件表达式中同时使用%<void *%>和函数指针"
 
-#: c/c-typeck.c:5178
+#: c/c-typeck.c:5183
 #, gcc-internal-format
 msgid "pointer type mismatch in conditional expression"
 msgstr "条件表达式指针类型不匹配"
 
-#: c/c-typeck.c:5187 c/c-typeck.c:5198
+#: c/c-typeck.c:5192 c/c-typeck.c:5203
 #, gcc-internal-format
 msgid "pointer/integer type mismatch in conditional expression"
 msgstr "条件表达式中指针/整数类型不匹配"
 
-#: c/c-typeck.c:5336
+#: c/c-typeck.c:5341
 #, gcc-internal-format
 msgid "left-hand operand of comma expression has no effect"
 msgstr "逗号表达式的左操作数不起作用"
 
-#: c/c-typeck.c:5354 c/c-typeck.c:10636
+#: c/c-typeck.c:5359 c/c-typeck.c:10641
 #, fuzzy, gcc-internal-format
 msgid "right-hand operand of comma expression has no effect"
 msgstr "逗号表达式的左操作数不起作用"
 
-#: c/c-typeck.c:5423
+#: c/c-typeck.c:5428
 #, fuzzy
 msgid "cast adds %q#v qualifier to function type"
 msgstr "类型转换为函数类型添加了新的限定"
 
-#: c/c-typeck.c:5429
+#: c/c-typeck.c:5434
 #, fuzzy
 msgid "cast discards %qv qualifier from pointer target type"
 msgstr "类型转换丢弃了指针目标类型的限定"
 
-#: c/c-typeck.c:5464
+#: c/c-typeck.c:5469
 #, fuzzy, gcc-internal-format
 msgid "to be safe all intermediate pointers in cast from %qT to %qT must be %<const%> qualified"
 msgstr "要是安全所有中介指标在中演员阵容从 %qT 到 %qT 必须是 %<const%> 经资格修饰"
 
-#: c/c-typeck.c:5554
+#: c/c-typeck.c:5559
 #, gcc-internal-format
 msgid "cast specifies array type"
 msgstr "类型转换指定了数组类型"
 
-#: c/c-typeck.c:5560
+#: c/c-typeck.c:5565
 #, gcc-internal-format
 msgid "cast specifies function type"
 msgstr "类型转换指定了函数类型"
 
-#: c/c-typeck.c:5575
+#: c/c-typeck.c:5580
 #, gcc-internal-format
 msgid "ISO C forbids casting nonscalar to the same type"
 msgstr "ISO C 不允许将非标量转换为其自身类型"
 
-#: c/c-typeck.c:5595
+#: c/c-typeck.c:5600
 #, gcc-internal-format
 msgid "ISO C forbids casts to union type"
 msgstr "ISO C 不允许转换为联合类型"
 
-#: c/c-typeck.c:5605
+#: c/c-typeck.c:5610
 #, gcc-internal-format
 msgid "cast to union type from type not present in union"
 msgstr "类型转换的源类型未出现在联合中"
 
-#: c/c-typeck.c:5640
+#: c/c-typeck.c:5645
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint generic address space pointer"
 msgstr "将不相交的普通地址空间指针转换为 %s 地址空间指针"
 
-#: c/c-typeck.c:5645
+#: c/c-typeck.c:5650
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to generic address space pointer from disjoint %s address space pointer"
 msgstr "将不相交的 %s 地址空间指针转换为普通地址空间指针"
 
-#: c/c-typeck.c:5650
+#: c/c-typeck.c:5655
 #, gcc-internal-format, gfc-internal-format
 msgid "cast to %s address space pointer from disjoint %s address space pointer"
 msgstr "将不相交的 %2$s 地址空间指针转换为 %1$s 地址空间指针"
 
-#: c/c-typeck.c:5670
+#: c/c-typeck.c:5675
 #, gcc-internal-format
 msgid "cast increases required alignment of target type"
 msgstr "类型转换增大了目标类型的对齐需求"
 
-#: c/c-typeck.c:5681
+#: c/c-typeck.c:5686
 #, gcc-internal-format
 msgid "cast from pointer to integer of different size"
 msgstr "将一个指针转换为大小不同的整数"
 
-#: c/c-typeck.c:5686
+#: c/c-typeck.c:5691
 #, gcc-internal-format
 msgid "cast from function call of type %qT to non-matching type %qT"
 msgstr "从类型为%qT的函数调用转换到不匹配的类型%qT"
 
-#: c/c-typeck.c:5695 cp/typeck.c:7811
+#: c/c-typeck.c:5700 cp/typeck.c:7811
 #, gcc-internal-format
 msgid "cast to pointer from integer of different size"
 msgstr "将一个整数转换为大小不同的指针"
 
-#: c/c-typeck.c:5709
+#: c/c-typeck.c:5714
 #, gcc-internal-format
 msgid "ISO C forbids conversion of function pointer to object pointer type"
 msgstr "ISO C 不允许将一个函数指针转换为一个对象指针"
 
-#: c/c-typeck.c:5718
+#: c/c-typeck.c:5723
 #, gcc-internal-format
 msgid "ISO C forbids conversion of object pointer to function pointer type"
 msgstr "ISO C 不允许将一个对象指针转换为一个函数指针"
 
-#: c/c-typeck.c:5728
+#: c/c-typeck.c:5733
 #, fuzzy, gcc-internal-format
 #| msgid "can%'t convert from incomplete type %qT to %qT"
 msgid "cast between incompatible function types from %qT to %qT"
 msgstr "无法从不完全类型%qT转换到%qT"
 
-#: c/c-typeck.c:5815
+#: c/c-typeck.c:5820
 #, gcc-internal-format
 msgid "defining a type in a cast is invalid in C++"
 msgstr "C++ 禁止在类型转换中定义类型"
 
-#: c/c-typeck.c:5856
+#: c/c-typeck.c:5861
 #, fuzzy, gcc-internal-format
 msgid "assignment to expression with array type"
 msgstr "无效的数组赋值"
 
-#: c/c-typeck.c:5982
+#: c/c-typeck.c:5987
 #, gcc-internal-format
 msgid "enum conversion in assignment is invalid in C++"
 msgstr "C++ 禁止在赋值时进行枚举转换"
 
-#: c/c-typeck.c:6180 c/c-typeck.c:6202 c/c-typeck.c:6226
+#: c/c-typeck.c:6185 c/c-typeck.c:6207 c/c-typeck.c:6231
 #, gcc-internal-format
 msgid "(near initialization for %qs)"
 msgstr "(在%qs的初始化附近)"
 
-#: c/c-typeck.c:6241
+#: c/c-typeck.c:6246
 #, gcc-internal-format
 msgid "array initialized from parenthesized string constant"
 msgstr "用括号中的字符串常量初始化数组"
 
-#: c/c-typeck.c:6284 c/c-typeck.c:6476 c/c-typeck.c:6908
+#: c/c-typeck.c:6289 c/c-typeck.c:6481 c/c-typeck.c:6913
 #, gcc-internal-format
 msgid "expected %qT but argument is of type %qT"
 msgstr "需要类型%qT，但实参的类型为%qT"
 
-#: c/c-typeck.c:6471
+#: c/c-typeck.c:6476
 #, gcc-internal-format
 msgid "enum conversion when passing argument %d of %qE is invalid in C++"
 msgstr "C++ 禁止在传递%2$qE的第 %1$d 个参数时进行枚举转换"
 
-#: c/c-typeck.c:6480
+#: c/c-typeck.c:6485
 #, fuzzy, gcc-internal-format
 #| msgid "enum conversion in assignment is invalid in C++"
 msgid "enum conversion from %qT to %qT in assignment is invalid in C++"
 msgstr "C++ 禁止在赋值时进行枚举转换"
 
-#: c/c-typeck.c:6484
+#: c/c-typeck.c:6489
 #, fuzzy, gcc-internal-format
 #| msgid "enum conversion in initialization is invalid in C++"
 msgid "enum conversion from %qT to %qT in initialization is invalid in C++"
 msgstr "C++ 禁止在初始化时进行枚举转换"
 
-#: c/c-typeck.c:6489
+#: c/c-typeck.c:6494
 #, fuzzy, gcc-internal-format
 #| msgid "enum conversion in return is invalid in C++"
 msgid "enum conversion from %qT to %qT in return is invalid in C++"
 msgstr "C++ 禁止在返回时进行枚举转换"
 
-#: c/c-typeck.c:6523
+#: c/c-typeck.c:6528
 #, gcc-internal-format
 msgid "cannot pass rvalue to reference parameter"
 msgstr "不能将右值传递给引用参数"
 
-#: c/c-typeck.c:6656 c/c-typeck.c:6942
+#: c/c-typeck.c:6661 c/c-typeck.c:6947
 #, fuzzy
 msgid "passing argument %d of %qE makes %q#v qualified function pointer from unqualified"
 msgstr "传递%2$qE的第 %1$d 个实参时从未限定的函数指针构造了限定的函数指针"
 
-#: c/c-typeck.c:6659 c/c-typeck.c:6945
+#: c/c-typeck.c:6664 c/c-typeck.c:6950
 #, fuzzy
 msgid "assignment makes %q#v qualified function pointer from unqualified"
 msgstr "将未限定的函数指针赋予限定的函数指针"
 
-#: c/c-typeck.c:6662 c/c-typeck.c:6947
+#: c/c-typeck.c:6667 c/c-typeck.c:6952
 #, fuzzy
 msgid "initialization makes %q#v qualified function pointer from unqualified"
 msgstr "返回时将未限定的函数指针赋给限定的函数指针"
 
-#: c/c-typeck.c:6665 c/c-typeck.c:6949
+#: c/c-typeck.c:6670 c/c-typeck.c:6954
 #, fuzzy
 msgid "return makes %q#v qualified function pointer from unqualified"
 msgstr "返回时将未限定的函数指针赋给限定的函数指针"
 
-#: c/c-typeck.c:6673 c/c-typeck.c:6840 c/c-typeck.c:6883
+#: c/c-typeck.c:6678 c/c-typeck.c:6845 c/c-typeck.c:6888
 #, fuzzy
 msgid "passing argument %d of %qE discards %qv qualifier from pointer target type"
 msgstr "传递%2$qE的第 %1$d 个实参时丢弃了指针目标类型的限定"
 
-#: c/c-typeck.c:6675 c/c-typeck.c:6842 c/c-typeck.c:6885
+#: c/c-typeck.c:6680 c/c-typeck.c:6847 c/c-typeck.c:6890
 #, fuzzy
 msgid "assignment discards %qv qualifier from pointer target type"
 msgstr "赋值丢弃了指针目标类型的限定"
 
-#: c/c-typeck.c:6677 c/c-typeck.c:6844 c/c-typeck.c:6887
+#: c/c-typeck.c:6682 c/c-typeck.c:6849 c/c-typeck.c:6892
 #, fuzzy
 msgid "initialization discards %qv qualifier from pointer target type"
 msgstr "初始化丢弃了指针目标类型的限定"
 
-#: c/c-typeck.c:6679 c/c-typeck.c:6846 c/c-typeck.c:6889
+#: c/c-typeck.c:6684 c/c-typeck.c:6851 c/c-typeck.c:6894
 #, fuzzy
 msgid "return discards %qv qualifier from pointer target type"
 msgstr "返回时丢弃了指针目标类型的限定"
 
-#: c/c-typeck.c:6688
+#: c/c-typeck.c:6693
 #, gcc-internal-format
 msgid "ISO C prohibits argument conversion to union type"
 msgstr "ISO C 不允许将实参转换为联合"
 
-#: c/c-typeck.c:6750
+#: c/c-typeck.c:6755
 #, gcc-internal-format
 msgid "request for implicit conversion from %qT to %qT not permitted in C++"
 msgstr "C++ 中不允许从%qT到%qT的隐式转换"
 
-#: c/c-typeck.c:6762
+#: c/c-typeck.c:6767
 #, gcc-internal-format
 msgid "passing argument %d of %qE from pointer to non-enclosed address space"
 msgstr "传递%2$qE的第 %1$d 个参数时从指针转换为未被包围的地址空间"
 
-#: c/c-typeck.c:6766
+#: c/c-typeck.c:6771
 #, gcc-internal-format
 msgid "assignment from pointer to non-enclosed address space"
 msgstr "将指针赋值给未被包围的地址空间"
 
-#: c/c-typeck.c:6770
+#: c/c-typeck.c:6775
 #, gcc-internal-format
 msgid "initialization from pointer to non-enclosed address space"
 msgstr "从指针向未被包围的地址空间初始化"
 
-#: c/c-typeck.c:6774
+#: c/c-typeck.c:6779
 #, gcc-internal-format
 msgid "return from pointer to non-enclosed address space"
 msgstr "返回时将指针赋值给未被包围的地址空间"
 
-#: c/c-typeck.c:6792
+#: c/c-typeck.c:6797
 #, gcc-internal-format
 msgid "argument %d of %qE might be a candidate for a format attribute"
 msgstr "%2$qE的第 %1$d 个实参可能是 format 属性的备选"
 
-#: c/c-typeck.c:6798
+#: c/c-typeck.c:6803
 #, gcc-internal-format
 msgid "assignment left-hand side might be a candidate for a format attribute"
 msgstr "赋值的左手边可能是 format 属性的备选时"
 
-#: c/c-typeck.c:6803
+#: c/c-typeck.c:6808
 #, gcc-internal-format
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "初始化的左手边可能是 format 属性的备选时"
 
-#: c/c-typeck.c:6808 cp/typeck.c:8891
+#: c/c-typeck.c:6813 cp/typeck.c:8891
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "返回类型可能是 format 属性的备选"
 
-#: c/c-typeck.c:6857
+#: c/c-typeck.c:6862
 #, gcc-internal-format
 msgid "ISO C forbids passing argument %d of %qE between function pointer and %<void *%>"
 msgstr "ISO C 不允许将%2$qE的第 %1$d 个实参在函数指针和%<void *%>间传递"
 
-#: c/c-typeck.c:6860
+#: c/c-typeck.c:6865
 #, gcc-internal-format
 msgid "ISO C forbids assignment between function pointer and %<void *%>"
 msgstr "ISO C 不允许在函数指针和%<void *%>间赋值"
 
-#: c/c-typeck.c:6862
+#: c/c-typeck.c:6867
 #, gcc-internal-format
 msgid "ISO C forbids initialization between function pointer and %<void *%>"
 msgstr "ISO C 不允许在函数指针和%<void *%>间初始化"
 
-#: c/c-typeck.c:6864
+#: c/c-typeck.c:6869
 #, gcc-internal-format
 msgid "ISO C forbids return between function pointer and %<void *%>"
 msgstr "ISO C 不允许在函数指针和%<void *%>间返回"
 
-#: c/c-typeck.c:6904
+#: c/c-typeck.c:6909
 #, gcc-internal-format
 msgid "pointer targets in passing argument %d of %qE differ in signedness"
 msgstr "传递%2$qE的第 %1$d 个参数给指针时，目标与指针符号不一致"
 
-#: c/c-typeck.c:6913
+#: c/c-typeck.c:6918
 #, fuzzy, gcc-internal-format
 #| msgid "pointer targets in assignment differ in signedness"
 msgid "pointer targets in assignment from %qT to %qT differ in signedness"
 msgstr "对指针赋值时目标与指针符号不一致"
 
-#: c/c-typeck.c:6918
+#: c/c-typeck.c:6923
 #, fuzzy, gcc-internal-format
 #| msgid "pointer targets in initialization differ in signedness"
 msgid "pointer targets in initialization of %qT from %qT differ in signedness"
 msgstr "初始化指针时目标与指针符号不一致"
 
-#: c/c-typeck.c:6923
+#: c/c-typeck.c:6928
 #, fuzzy, gcc-internal-format
 #| msgid "pointer targets in passing argument %d of %qE differ in signedness"
 msgid "pointer targets in returning %qT from a function with return type %qT differ in signedness"
 msgstr "传递%2$qE的第 %1$d 个参数给指针时，目标与指针符号不一致"
 
-#: c/c-typeck.c:6961
+#: c/c-typeck.c:6966
 #, gcc-internal-format
 msgid "passing argument %d of %qE from incompatible pointer type"
 msgstr "传递%2$qE的第 %1$d 个参数时在不兼容的指针类型间转换"
 
-#: c/c-typeck.c:6967
+#: c/c-typeck.c:6972
 #, fuzzy, gcc-internal-format
 #| msgid "assignment from incompatible pointer type"
 msgid "assignment to %qT from incompatible pointer type %qT"
 msgstr "从不兼容的指针类型赋值"
 
-#: c/c-typeck.c:6972
+#: c/c-typeck.c:6977
 #, fuzzy, gcc-internal-format
 #| msgid "initialization from incompatible pointer type"
 msgid "initialization of %qT from incompatible pointer type %qT"
 msgstr "从不兼容的指针类型初始化"
 
-#: c/c-typeck.c:6977
+#: c/c-typeck.c:6982
 #, fuzzy, gcc-internal-format
 msgid "returning %qT from a function with incompatible return type %qT"
 msgstr "在无返回值的函数中，%<return%>带返回值"
@@ -41013,791 +41058,791 @@
 
 #. ??? This should not be an error when inlining calls to
 #. unprototyped functions.
-#: c/c-typeck.c:6991 c/c-typeck.c:7514 cp/typeck.c:2063
+#: c/c-typeck.c:6996 c/c-typeck.c:7519 cp/typeck.c:2063
 #, gcc-internal-format
 msgid "invalid use of non-lvalue array"
 msgstr "对非左值数组的使用无效"
 
-#: c/c-typeck.c:7004
+#: c/c-typeck.c:7009
 #, gcc-internal-format
 msgid "passing argument %d of %qE makes pointer from integer without a cast"
 msgstr "传递%2$qE的第 %1$d 个参数时将整数赋给指针，未作类型转换"
 
-#: c/c-typeck.c:7010
+#: c/c-typeck.c:7015
 #, fuzzy, gcc-internal-format
 #| msgid "assignment makes pointer from integer without a cast"
 msgid "assignment to %qT from %qT makes pointer from integer without a cast"
 msgstr "赋值时将整数赋给指针，未作类型转换"
 
-#: c/c-typeck.c:7015
+#: c/c-typeck.c:7020
 #, fuzzy, gcc-internal-format
 #| msgid "initialization makes pointer from integer without a cast"
 msgid "initialization of %qT from %qT makes pointer from integer without a cast"
 msgstr "初始化时将整数赋给指针，未作类型转换"
 
-#: c/c-typeck.c:7019
+#: c/c-typeck.c:7024
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE makes pointer from integer without a cast"
 msgid "returning %qT from a function with return type %qT makes pointer from integer without a cast"
 msgstr "传递%2$qE的第 %1$d 个参数时将整数赋给指针，未作类型转换"
 
-#: c/c-typeck.c:7035
+#: c/c-typeck.c:7040
 #, gcc-internal-format
 msgid "passing argument %d of %qE makes integer from pointer without a cast"
 msgstr "传递%2$qE的第 %1$d 个参数时将指针赋给整数，未作类型转换"
 
-#: c/c-typeck.c:7041
+#: c/c-typeck.c:7046
 #, fuzzy, gcc-internal-format
 #| msgid "assignment makes integer from pointer without a cast"
 msgid "assignment to %qT from %qT makes integer from pointer without a cast"
 msgstr "赋值时将指针赋给整数，未作类型转换"
 
-#: c/c-typeck.c:7046
+#: c/c-typeck.c:7051
 #, fuzzy, gcc-internal-format
 #| msgid "initialization makes integer from pointer without a cast"
 msgid "initialization of %qT from %qT makes integer from pointer without a cast"
 msgstr "初始化将指针赋给整数，未作类型转换"
 
-#: c/c-typeck.c:7050
+#: c/c-typeck.c:7055
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE makes integer from pointer without a cast"
 msgid "returning %qT from a function with return type %qT makes integer from pointer without a cast"
 msgstr "传递%2$qE的第 %1$d 个参数时将指针赋给整数，未作类型转换"
 
-#: c/c-typeck.c:7073
+#: c/c-typeck.c:7078
 #, gcc-internal-format
 msgid "incompatible type for argument %d of %qE"
 msgstr "%2$qE的第 %1$d 个实参类型不兼容"
 
-#: c/c-typeck.c:7078
+#: c/c-typeck.c:7083
 #, gcc-internal-format
 msgid "incompatible types when assigning to type %qT from type %qT"
 msgstr "将%2$qT赋值给%1$qT时类型不兼容"
 
-#: c/c-typeck.c:7083
+#: c/c-typeck.c:7088
 #, gcc-internal-format
 msgid "incompatible types when initializing type %qT using type %qT"
 msgstr "用%2$qT初始化%1$qT时类型不兼容"
 
-#: c/c-typeck.c:7088
+#: c/c-typeck.c:7093
 #, gcc-internal-format
 msgid "incompatible types when returning type %qT but %qT was expected"
 msgstr "将%qT返回为%qT时类型不兼容"
 
-#: c/c-typeck.c:7152
+#: c/c-typeck.c:7157
 #, gcc-internal-format
 msgid "traditional C rejects automatic aggregate initialization"
 msgstr "传统 C 不接受自动的聚合初始化"
 
-#: c/c-typeck.c:7388 c/c-typeck.c:8284 cp/typeck2.c:1045
+#: c/c-typeck.c:7393 c/c-typeck.c:8289 cp/typeck2.c:1045
 #, gcc-internal-format
 msgid "initialization of a flexible array member"
 msgstr "对可变数组成员的初始化"
 
-#: c/c-typeck.c:7398 cp/typeck2.c:1059
+#: c/c-typeck.c:7403 cp/typeck2.c:1059
 #, gcc-internal-format
 msgid "char-array initialized from wide string"
 msgstr "用宽字符串初始化 char 数组"
 
-#: c/c-typeck.c:7407
+#: c/c-typeck.c:7412
 #, gcc-internal-format
 msgid "wide character array initialized from non-wide string"
 msgstr "用窄字符串初始化宽字符数组"
 
-#: c/c-typeck.c:7413
+#: c/c-typeck.c:7418
 #, gcc-internal-format
 msgid "wide character array initialized from incompatible wide string"
 msgstr "用不兼容的宽字符串初始化宽字符数组"
 
-#: c/c-typeck.c:7446
+#: c/c-typeck.c:7451
 #, gcc-internal-format
 msgid "array of inappropriate type initialized from string constant"
 msgstr "用字符串常量初始化的数组类型不合适"
 
-#: c/c-typeck.c:7533 c/c-typeck.c:7557 c/c-typeck.c:7560 c/c-typeck.c:7568
-#: c/c-typeck.c:7608 c/c-typeck.c:9131 c/c-typeck.c:9181
+#: c/c-typeck.c:7538 c/c-typeck.c:7562 c/c-typeck.c:7565 c/c-typeck.c:7573
+#: c/c-typeck.c:7613 c/c-typeck.c:9136 c/c-typeck.c:9186
 #, gcc-internal-format
 msgid "initializer element is not constant"
 msgstr "初始值设定元素不是常量"
 
-#: c/c-typeck.c:7542
+#: c/c-typeck.c:7547
 #, gcc-internal-format
 msgid "array initialized from non-constant array expression"
 msgstr "用非常量的数组表达式初始化数组"
 
-#: c/c-typeck.c:7573 c/c-typeck.c:7621 c/c-typeck.c:9191
+#: c/c-typeck.c:7578 c/c-typeck.c:7626 c/c-typeck.c:9196
 #, gcc-internal-format
 msgid "initializer element is not a constant expression"
 msgstr "初始值设定中元素不是常量表达式"
 
-#: c/c-typeck.c:7615 c/c-typeck.c:9186
+#: c/c-typeck.c:7620 c/c-typeck.c:9191
 #, gcc-internal-format
 msgid "initializer element is not computable at load time"
 msgstr "初始值设定中的元素在载入时无法被计算出"
 
-#: c/c-typeck.c:7634
+#: c/c-typeck.c:7639
 #, gcc-internal-format
 msgid "invalid initializer"
 msgstr "无效的初始值设定"
 
-#: c/c-typeck.c:7912 cp/decl.c:6396
+#: c/c-typeck.c:7917 cp/decl.c:6396
 #, gcc-internal-format
 msgid "opaque vector types cannot be initialized"
 msgstr "不透明的向量类型不能被初始化"
 
-#: c/c-typeck.c:8132
+#: c/c-typeck.c:8137
 #, gcc-internal-format
 msgid "extra brace group at end of initializer"
 msgstr "初始值设定项末尾有多余的花括号组"
 
-#: c/c-typeck.c:8215
+#: c/c-typeck.c:8220
 #, gcc-internal-format
 msgid "braces around scalar initializer"
 msgstr "标量初始化带花括号"
 
-#: c/c-typeck.c:8281 c/c-typeck.c:9615 cp/typeck2.c:1084 cp/typeck2.c:1297
+#: c/c-typeck.c:8286 c/c-typeck.c:9620 cp/typeck2.c:1084 cp/typeck2.c:1297
 #, gcc-internal-format
 msgid "initialization of flexible array member in a nested context"
 msgstr "在嵌套的上下文中初始化可变数组成员"
 
-#: c/c-typeck.c:8318
+#: c/c-typeck.c:8323
 #, gcc-internal-format
 msgid "missing braces around initializer"
 msgstr "初始值设定周围缺少花括号"
 
-#: c/c-typeck.c:8341
+#: c/c-typeck.c:8346
 #, fuzzy, gcc-internal-format
 msgid "missing initializer for field %qD of %qT"
 msgstr "成员%qD缺少初始值设定"
 
-#: c/c-typeck.c:8365
+#: c/c-typeck.c:8370
 #, gcc-internal-format
 msgid "empty scalar initializer"
 msgstr "空的标量初始值设定项"
 
-#: c/c-typeck.c:8370
+#: c/c-typeck.c:8375
 #, gcc-internal-format
 msgid "extra elements in scalar initializer"
 msgstr "标量初始值设定中有多余元素"
 
-#: c/c-typeck.c:8483 c/c-typeck.c:8565
+#: c/c-typeck.c:8488 c/c-typeck.c:8570
 #, gcc-internal-format
 msgid "array index in non-array initializer"
 msgstr "在非数组初始值设定项中出现数组索引"
 
-#: c/c-typeck.c:8488 c/c-typeck.c:8627
+#: c/c-typeck.c:8493 c/c-typeck.c:8632
 #, gcc-internal-format
 msgid "field name not in record or union initializer"
 msgstr "字段名不在记录或联合初始值设定中"
 
-#: c/c-typeck.c:8538
+#: c/c-typeck.c:8543
 #, gcc-internal-format
 msgid "array index in initializer not of integer type"
 msgstr "初始值设定中数组索引不是整型"
 
-#: c/c-typeck.c:8547 c/c-typeck.c:8556
+#: c/c-typeck.c:8552 c/c-typeck.c:8561
 #, gcc-internal-format
 msgid "array index in initializer is not an integer constant expression"
 msgstr "初始值设定中数组索引不是整型常量表达式"
 
-#: c/c-typeck.c:8561 c/c-typeck.c:8563
+#: c/c-typeck.c:8566 c/c-typeck.c:8568
 #, gcc-internal-format
 msgid "nonconstant array index in initializer"
 msgstr "初始值设定中数组索引不是常数"
 
-#: c/c-typeck.c:8567 c/c-typeck.c:8570
+#: c/c-typeck.c:8572 c/c-typeck.c:8575
 #, gcc-internal-format
 msgid "array index in initializer exceeds array bounds"
 msgstr "初始化时数组索引越界"
 
-#: c/c-typeck.c:8589
+#: c/c-typeck.c:8594
 #, gcc-internal-format
 msgid "empty index range in initializer"
 msgstr "初始值设定项中索引范围为空"
 
-#: c/c-typeck.c:8598
+#: c/c-typeck.c:8603
 #, gcc-internal-format
 msgid "array index range in initializer exceeds array bounds"
 msgstr "初始值设定中数据索引范围超出数组边界"
 
-#: c/c-typeck.c:8700 c/c-typeck.c:8730 c/c-typeck.c:9274
+#: c/c-typeck.c:8705 c/c-typeck.c:8735 c/c-typeck.c:9279
 #, gcc-internal-format
 msgid "initialized field with side-effects overwritten"
 msgstr "带副作用的字段初始值设定被覆盖"
 
-#: c/c-typeck.c:8704 c/c-typeck.c:8734 c/c-typeck.c:9277
+#: c/c-typeck.c:8709 c/c-typeck.c:8739 c/c-typeck.c:9282
 #, gcc-internal-format
 msgid "initialized field overwritten"
 msgstr "已初始化的字段被覆盖"
 
-#: c/c-typeck.c:9208
+#: c/c-typeck.c:9213
 #, gcc-internal-format
 msgid "enum conversion in initialization is invalid in C++"
 msgstr "C++ 禁止在初始化时进行枚举转换"
 
-#: c/c-typeck.c:9496
+#: c/c-typeck.c:9501
 #, gcc-internal-format
 msgid "excess elements in char array initializer"
 msgstr "字符数组初始值设定项中有多余元素"
 
-#: c/c-typeck.c:9503 c/c-typeck.c:9574
+#: c/c-typeck.c:9508 c/c-typeck.c:9579
 #, gcc-internal-format
 msgid "excess elements in struct initializer"
 msgstr "结构初始值设定项中有多余元素"
 
-#: c/c-typeck.c:9518
+#: c/c-typeck.c:9523
 #, gcc-internal-format
 msgid "positional initialization of field in %<struct%> declared with %<designated_init%> attribute"
 msgstr ""
 
-#: c/c-typeck.c:9589
+#: c/c-typeck.c:9594
 #, gcc-internal-format
 msgid "non-static initialization of a flexible array member"
 msgstr "对可变数组成员非静态地初始化"
 
-#: c/c-typeck.c:9687
+#: c/c-typeck.c:9692
 #, gcc-internal-format
 msgid "excess elements in union initializer"
 msgstr "联合初始值设定项中有多余元素"
 
-#: c/c-typeck.c:9709
+#: c/c-typeck.c:9714
 #, gcc-internal-format
 msgid "traditional C rejects initialization of unions"
 msgstr "传统 C 不接受对联合的初始化"
 
-#: c/c-typeck.c:9777
+#: c/c-typeck.c:9782
 #, gcc-internal-format
 msgid "excess elements in array initializer"
 msgstr "数组初始值设定项中有多余的元素"
 
-#: c/c-typeck.c:9811
+#: c/c-typeck.c:9816
 #, gcc-internal-format
 msgid "excess elements in vector initializer"
 msgstr "向量初始值设定项中有多余元素"
 
-#: c/c-typeck.c:9843
+#: c/c-typeck.c:9848
 #, gcc-internal-format
 msgid "excess elements in scalar initializer"
 msgstr "标量初始值设定项中有多余元素"
 
-#: c/c-typeck.c:10086
+#: c/c-typeck.c:10091
 #, gcc-internal-format
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C++ 不允许%<goto *expr;%>"
 
-#: c/c-typeck.c:10113 c/gimple-parser.c:1604 cp/typeck.c:9113
+#: c/c-typeck.c:10118 c/gimple-parser.c:1604 cp/typeck.c:9113
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "被声明为%<noreturn%>的函数却有%<return%>语句"
 
-#: c/c-typeck.c:10139 c/c-typeck.c:10143
+#: c/c-typeck.c:10144 c/c-typeck.c:10148
 #, gcc-internal-format
 msgid "%<return%> with no value, in function returning non-void"
 msgstr "在有返回值的的函数中，%<return%>不带返回值"
 
-#: c/c-typeck.c:10157 c/gimple-parser.c:1614
+#: c/c-typeck.c:10162 c/gimple-parser.c:1614
 #, gcc-internal-format
 msgid "%<return%> with a value, in function returning void"
 msgstr "在无返回值的函数中，%<return%>带返回值"
 
-#: c/c-typeck.c:10160
+#: c/c-typeck.c:10165
 #, gcc-internal-format
 msgid "ISO C forbids %<return%> with expression, in function returning void"
 msgstr "ISO C 不允许在无返回值的函数中%<return%>带返回值"
 
-#: c/c-typeck.c:10236
+#: c/c-typeck.c:10241
 #, fuzzy, gcc-internal-format
 msgid "function returns address of label"
 msgstr "函数返回局部变量的地址"
 
-#: c/c-typeck.c:10327 cp/semantics.c:1171
+#: c/c-typeck.c:10332 cp/semantics.c:1171
 #, gcc-internal-format
 msgid "switch quantity not an integer"
 msgstr "switch 语句中的值不是一个整数"
 
-#: c/c-typeck.c:10352
+#: c/c-typeck.c:10357
 #, gcc-internal-format
 msgid "%<long%> switch expression not converted to %<int%> in ISO C"
 msgstr "在 ISO C 中，%<long%>开关表达式不被转换为%<int%>"
 
-#: c/c-typeck.c:10390 c/c-typeck.c:10398
+#: c/c-typeck.c:10395 c/c-typeck.c:10403
 #, gcc-internal-format
 msgid "case label is not an integer constant expression"
 msgstr "case 标号不是一个整数常量表达式"
 
-#: c/c-typeck.c:10404 cp/parser.c:11067
+#: c/c-typeck.c:10409 cp/parser.c:11067
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "case 标号出现在开关语句外"
 
-#: c/c-typeck.c:10406
+#: c/c-typeck.c:10411
 #, gcc-internal-format
 msgid "%<default%> label not within a switch statement"
 msgstr "%<default%>标号未出现在 switch 语句内"
 
-#: c/c-typeck.c:10578 cp/parser.c:12356
+#: c/c-typeck.c:10583 cp/parser.c:12353
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "break 语句不在循环或开关语句内"
 
-#: c/c-typeck.c:10580 cp/parser.c:12379
+#: c/c-typeck.c:10585 cp/parser.c:12376
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "continue 语句出现在循环以外"
 
-#: c/c-typeck.c:10585 cp/parser.c:12369
+#: c/c-typeck.c:10590 cp/parser.c:12366
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr "OpenMP for 循环中使用了 break 语句"
 
-#: c/c-typeck.c:10590
+#: c/c-typeck.c:10595
 #, fuzzy, gcc-internal-format
 msgid "break statement within %<#pragma simd%> loop body"
 msgstr "break 语句不在循环或开关语句内"
 
-#: c/c-typeck.c:10592
+#: c/c-typeck.c:10597
 #, fuzzy, gcc-internal-format
 msgid "continue statement within %<#pragma simd%> loop body"
 msgstr "continue 语句出现在循环以外"
 
-#: c/c-typeck.c:10618 cp/cp-gimplify.c:432
+#: c/c-typeck.c:10623 cp/cp-gimplify.c:432
 #, gcc-internal-format
 msgid "statement with no effect"
 msgstr "语句不起作用"
 
-#: c/c-typeck.c:10662
+#: c/c-typeck.c:10667
 #, gcc-internal-format
 msgid "expression statement has incomplete type"
 msgstr "表达式语句类型不完全"
 
-#: c/c-typeck.c:11476 c/c-typeck.c:11644 cp/typeck.c:5017
+#: c/c-typeck.c:11481 c/c-typeck.c:11649 cp/typeck.c:5017
 #, fuzzy, gcc-internal-format
 msgid "comparing vectors with different element types"
 msgstr "对不同枚举类型之间的比较给出警告"
 
-#: c/c-typeck.c:11484 c/c-typeck.c:11652 cp/typeck.c:5030
+#: c/c-typeck.c:11489 c/c-typeck.c:11657 cp/typeck.c:5030
 #, fuzzy, gcc-internal-format
 msgid "comparing vectors with different number of elements"
 msgstr "形参数量不同"
 
-#: c/c-typeck.c:11509 c/c-typeck.c:11677 cp/typeck.c:5058
+#: c/c-typeck.c:11514 c/c-typeck.c:11682 cp/typeck.c:5058
 #, fuzzy, gcc-internal-format
 msgid "could not find an integer type of the same size as %qT"
 msgstr "找不到类%qE的接口"
 
-#: c/c-typeck.c:11523 cp/typeck.c:4743
+#: c/c-typeck.c:11528 cp/typeck.c:4743
 #, gcc-internal-format
 msgid "comparing floating point with == or != is unsafe"
 msgstr "使用 == 或 != 比较浮点数是不安全的"
 
-#: c/c-typeck.c:11541 c/c-typeck.c:11562
+#: c/c-typeck.c:11546 c/c-typeck.c:11567
 #, fuzzy, gcc-internal-format
 msgid "the comparison will always evaluate as %<false%> for the address of %qD will never be NULL"
 msgstr "比较将一律评估作为 %<false%> 用于地址的 %qD 将永不是空值"
 
-#: c/c-typeck.c:11547 c/c-typeck.c:11568
+#: c/c-typeck.c:11552 c/c-typeck.c:11573
 #, fuzzy, gcc-internal-format
 msgid "the comparison will always evaluate as %<true%> for the address of %qD will never be NULL"
 msgstr "比较将一律评估作为 %<true%> 用于地址的 %qD 将永不是空值"
 
-#: c/c-typeck.c:11589 c/c-typeck.c:11718
+#: c/c-typeck.c:11594 c/c-typeck.c:11723
 #, gcc-internal-format
 msgid "comparison of pointers to disjoint address spaces"
 msgstr "比较指向不相交的地址空间的指针"
 
-#: c/c-typeck.c:11596 c/c-typeck.c:11602
+#: c/c-typeck.c:11601 c/c-typeck.c:11607
 #, gcc-internal-format
 msgid "ISO C forbids comparison of %<void *%> with function pointer"
 msgstr "ISO C 不允许在%<void *%>和函数指针间比较"
 
-#: c/c-typeck.c:11609 c/c-typeck.c:11728
+#: c/c-typeck.c:11614 c/c-typeck.c:11733
 #, gcc-internal-format
 msgid "comparison of distinct pointer types lacks a cast"
 msgstr "比较不相关的指针时缺少类型转换"
 
-#: c/c-typeck.c:11621 c/c-typeck.c:11626 c/c-typeck.c:11754 c/c-typeck.c:11759
+#: c/c-typeck.c:11626 c/c-typeck.c:11631 c/c-typeck.c:11759 c/c-typeck.c:11764
 #, gcc-internal-format
 msgid "comparison between pointer and integer"
 msgstr "比较指针和整数"
 
-#: c/c-typeck.c:11706
+#: c/c-typeck.c:11711
 #, gcc-internal-format
 msgid "comparison of complete and incomplete pointers"
 msgstr "在完全和不完全指针间比较"
 
-#: c/c-typeck.c:11708
+#: c/c-typeck.c:11713
 #, gcc-internal-format
 msgid "ISO C forbids ordered comparisons of pointers to functions"
 msgstr "ISO C 不允许函数指针间比较大小"
 
-#: c/c-typeck.c:11713
+#: c/c-typeck.c:11718
 #, fuzzy, gcc-internal-format
 msgid "ordered comparison of pointer with null pointer"
 msgstr "指针与整数 0 比较大小"
 
-#: c/c-typeck.c:11736 c/c-typeck.c:11739 c/c-typeck.c:11746 c/c-typeck.c:11749
+#: c/c-typeck.c:11741 c/c-typeck.c:11744 c/c-typeck.c:11751 c/c-typeck.c:11754
 #: cp/typeck.c:5081 cp/typeck.c:5088
 #, gcc-internal-format
 msgid "ordered comparison of pointer with integer zero"
 msgstr "指针与整数 0 比较大小"
 
-#: c/c-typeck.c:11811
+#: c/c-typeck.c:11816
 #, fuzzy, gcc-internal-format
 msgid "implicit conversion from %qT to %qT to match other operand of binary expression"
 msgstr "C++ 中不允许从%qT到%qT的隐式转换"
 
-#: c/c-typeck.c:12126
+#: c/c-typeck.c:12131
 #, gcc-internal-format
 msgid "used array that cannot be converted to pointer where scalar is required"
 msgstr "需要标量时使用了不能被转换为指针的数组"
 
-#: c/c-typeck.c:12130
+#: c/c-typeck.c:12135
 #, gcc-internal-format
 msgid "used struct type value where scalar is required"
 msgstr "需要标量时使用了结构类型"
 
-#: c/c-typeck.c:12134
+#: c/c-typeck.c:12139
 #, gcc-internal-format
 msgid "used union type value where scalar is required"
 msgstr "需要标量时使用了联合类型"
 
-#: c/c-typeck.c:12150
+#: c/c-typeck.c:12155
 #, fuzzy, gcc-internal-format
 msgid "used vector type where scalar is required"
 msgstr "需要标量时使用了联合类型"
 
-#: c/c-typeck.c:12340 cp/semantics.c:8508
+#: c/c-typeck.c:12345 cp/semantics.c:8511
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-typeck.c:12379 cp/semantics.c:8545
+#: c/c-typeck.c:12384 cp/semantics.c:8548
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-typeck.c:12423 c/c-typeck.c:13581 c/c-typeck.c:13642 c/c-typeck.c:13704
+#: c/c-typeck.c:12428 c/c-typeck.c:13586 c/c-typeck.c:13647 c/c-typeck.c:13709
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "字段%qE的类型不完全"
 
-#: c/c-typeck.c:12436 c/c-typeck.c:13628 cp/semantics.c:4546
-#: cp/semantics.c:6717
+#: c/c-typeck.c:12441 c/c-typeck.c:13633 cp/semantics.c:4549
+#: cp/semantics.c:6720
 #, fuzzy, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr "字段%qE的类型不完全"
 
-#: c/c-typeck.c:12445 c/c-typeck.c:13652 cp/semantics.c:4556
-#: cp/semantics.c:6735
+#: c/c-typeck.c:12450 c/c-typeck.c:13657 cp/semantics.c:4559
+#: cp/semantics.c:6738
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qE is a member of a union"
 msgstr "%qD不是一个成员模板函数"
 
-#: c/c-typeck.c:12455 cp/semantics.c:4570 cp/semantics.c:6760
+#: c/c-typeck.c:12460 cp/semantics.c:4573 cp/semantics.c:6763
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD在子句%qs中不是一个变量"
 
-#: c/c-typeck.c:12459 c/c-typeck.c:13669 cp/semantics.c:4574
-#: cp/semantics.c:6763
+#: c/c-typeck.c:12464 c/c-typeck.c:13674 cp/semantics.c:4577
+#: cp/semantics.c:6766
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qE在子句%qs中不是一个变量"
 
-#: c/c-typeck.c:12466
+#: c/c-typeck.c:12471
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%> %qD in %qs clause"
 msgstr "字段%qE的类型不完全"
 
-#: c/c-typeck.c:12475 c/c-typeck.c:13676 c/c-typeck.c:13778
-#: cp/semantics.c:4591 cp/semantics.c:6769 cp/semantics.c:6931
+#: c/c-typeck.c:12480 c/c-typeck.c:13681 c/c-typeck.c:13783
+#: cp/semantics.c:4594 cp/semantics.c:6772 cp/semantics.c:6934
 #, fuzzy, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD在子句%qs中不是一个变量"
 
-#: c/c-typeck.c:12511 cp/semantics.c:4623
+#: c/c-typeck.c:12516 cp/semantics.c:4626
 #, fuzzy, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr "数组 new 的大小必须有整数类型"
 
-#: c/c-typeck.c:12518 cp/semantics.c:4630
+#: c/c-typeck.c:12523 cp/semantics.c:4633
 #, fuzzy, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr "数组 new 的大小必须有整数类型"
 
-#: c/c-typeck.c:12545 c/c-typeck.c:12609 c/c-typeck.c:12867
-#: cp/semantics.c:4666 cp/semantics.c:4730
+#: c/c-typeck.c:12550 c/c-typeck.c:12614 c/c-typeck.c:12872
+#: cp/semantics.c:4669 cp/semantics.c:4733
 #, fuzzy, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr "使用了变长数组"
 
-#: c/c-typeck.c:12564 cp/semantics.c:4685
+#: c/c-typeck.c:12569 cp/semantics.c:4688
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12572 cp/semantics.c:4693
+#: c/c-typeck.c:12577 cp/semantics.c:4696
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12581 c/c-typeck.c:12691 cp/semantics.c:4702
-#: cp/semantics.c:4812
+#: c/c-typeck.c:12586 c/c-typeck.c:12696 cp/semantics.c:4705
+#: cp/semantics.c:4815
 #, fuzzy, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr "使用了变长数组"
 
-#: c/c-typeck.c:12598 cp/semantics.c:4719
+#: c/c-typeck.c:12603 cp/semantics.c:4722
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12635 cp/semantics.c:4756
+#: c/c-typeck.c:12640 cp/semantics.c:4759
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12650 cp/semantics.c:4771
+#: c/c-typeck.c:12655 cp/semantics.c:4774
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12683 cp/semantics.c:4804
+#: c/c-typeck.c:12688 cp/semantics.c:4807
 #, fuzzy, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr "for 循环増量表达式不起作用"
 
-#: c/c-typeck.c:12701 c/c-typeck.c:12810 cp/semantics.c:4822
-#: cp/semantics.c:4934
+#: c/c-typeck.c:12706 c/c-typeck.c:12815 cp/semantics.c:4825
+#: cp/semantics.c:4937
 #, fuzzy, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr "在过程入口处将数组段复制到一个连续的块中"
 
-#: c/c-typeck.c:12709 cp/semantics.c:4830
+#: c/c-typeck.c:12714 cp/semantics.c:4833
 #, fuzzy, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr "%qE不是一个类"
 
-#: c/c-typeck.c:13103 c/c-typeck.c:13113
+#: c/c-typeck.c:13108 c/c-typeck.c:13118
 #, fuzzy, gcc-internal-format
 msgid "%qD in %<reduction%> clause is a zero size array"
 msgstr "向量 delete 的实参类型既非指针也非数组"
 
-#: c/c-typeck.c:13130
+#: c/c-typeck.c:13135
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%> %qE in %<reduction%> clause"
 msgstr "调用了有限定 void 返回类型的函数"
 
-#: c/c-typeck.c:13178
+#: c/c-typeck.c:13183
 #, gcc-internal-format
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "%qE的类型对%<reduction(%s)%>无效"
 
-#: c/c-typeck.c:13187 cp/semantics.c:5755
+#: c/c-typeck.c:13192 cp/semantics.c:5758
 #, fuzzy, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr "用户定义的%qD总是计算所有两个参数"
 
-#: c/c-typeck.c:13275
+#: c/c-typeck.c:13280
 #, fuzzy, gcc-internal-format
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "使用了变长数组"
 
-#: c/c-typeck.c:13293 c/c-typeck.c:13836 cp/semantics.c:7249
+#: c/c-typeck.c:13298 c/c-typeck.c:13841 cp/semantics.c:7252
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13305 cp/semantics.c:7289
+#: c/c-typeck.c:13310 cp/semantics.c:7292
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE必须是%<threadprivate%>方可%<copyin%>"
 
-#: c/c-typeck.c:13319 cp/semantics.c:5929
+#: c/c-typeck.c:13324 cp/semantics.c:5932
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr ""
 
-#: c/c-typeck.c:13327
+#: c/c-typeck.c:13332
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with type %qT"
 msgstr ""
 
-#: c/c-typeck.c:13335
+#: c/c-typeck.c:13340
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13354 cp/semantics.c:5999
+#: c/c-typeck.c:13359 cp/semantics.c:6002
 #, fuzzy, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr "向量 delete 的实参类型既非指针也非数组"
 
-#: c/c-typeck.c:13384 c/c-typeck.c:13771 cp/semantics.c:6083
-#: cp/semantics.c:6924
+#: c/c-typeck.c:13389 c/c-typeck.c:13776 cp/semantics.c:6086
+#: cp/semantics.c:6927
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE在子句%qs中不是一个变量"
 
-#: c/c-typeck.c:13393 cp/semantics.c:6092
+#: c/c-typeck.c:13398 cp/semantics.c:6095
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr "%qD在数据子句中多次出现"
 
-#: c/c-typeck.c:13404 c/c-typeck.c:13434 c/c-typeck.c:13463
+#: c/c-typeck.c:13409 c/c-typeck.c:13439 c/c-typeck.c:13468
 #, gcc-internal-format
 msgid "%qE appears more than once in data clauses"
 msgstr "%qE在数据子句中多次出现"
 
-#: c/c-typeck.c:13411 c/c-typeck.c:13440 c/c-typeck.c:13600 c/c-typeck.c:13714
-#: c/c-typeck.c:13720 c/c-typeck.c:13733 c/c-typeck.c:13742
-#: cp/semantics.c:6102 cp/semantics.c:6109 cp/semantics.c:6160
-#: cp/semantics.c:6166 cp/semantics.c:6203 cp/semantics.c:6680
-#: cp/semantics.c:6817 cp/semantics.c:6823 cp/semantics.c:6836
-#: cp/semantics.c:6845
+#: c/c-typeck.c:13416 c/c-typeck.c:13445 c/c-typeck.c:13605 c/c-typeck.c:13719
+#: c/c-typeck.c:13725 c/c-typeck.c:13738 c/c-typeck.c:13747
+#: cp/semantics.c:6105 cp/semantics.c:6112 cp/semantics.c:6163
+#: cp/semantics.c:6169 cp/semantics.c:6206 cp/semantics.c:6683
+#: cp/semantics.c:6820 cp/semantics.c:6826 cp/semantics.c:6839
+#: cp/semantics.c:6848
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr "%qD在数据子句中多次出现"
 
-#: c/c-typeck.c:13413 c/c-typeck.c:13442 c/c-typeck.c:13722 c/c-typeck.c:13744
-#: cp/semantics.c:6111 cp/semantics.c:6168 cp/semantics.c:6825
-#: cp/semantics.c:6847
+#: c/c-typeck.c:13418 c/c-typeck.c:13447 c/c-typeck.c:13727 c/c-typeck.c:13749
+#: cp/semantics.c:6114 cp/semantics.c:6171 cp/semantics.c:6828
+#: cp/semantics.c:6850
 #, fuzzy, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr "%qD在数据子句中多次出现"
 
-#: c/c-typeck.c:13427 cp/semantics.c:6154
+#: c/c-typeck.c:13432 cp/semantics.c:6157
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "%qE在子句%<firstprivate%>中不是一个变量"
 
-#: c/c-typeck.c:13456 cp/semantics.c:6197
+#: c/c-typeck.c:13461 cp/semantics.c:6200
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "%qE在子句%<lastprivate%>中不是一个变量"
 
-#: c/c-typeck.c:13475 cp/semantics.c:6545
+#: c/c-typeck.c:13480 cp/semantics.c:6548
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "%qE在子句%<firstprivate%>中不是一个变量"
 
-#: c/c-typeck.c:13482
+#: c/c-typeck.c:13487
 #, fuzzy, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array"
 msgstr "向量 delete 的实参类型既非指针也非数组"
 
-#: c/c-typeck.c:13489
+#: c/c-typeck.c:13494
 #, fuzzy, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<aligned%> clause"
 msgstr "%qD在%<lastprivate%>子句中不是一个变量"
 
-#: c/c-typeck.c:13496
+#: c/c-typeck.c:13501
 #, fuzzy, gcc-internal-format
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr "%qE在数据子句中多次出现"
 
-#: c/c-typeck.c:13551 cp/semantics.c:6627
+#: c/c-typeck.c:13556 cp/semantics.c:6630
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr "%qE在子句%<lastprivate%>中不是一个变量"
 
-#: c/c-typeck.c:13573 cp/semantics.c:6658
+#: c/c-typeck.c:13578 cp/semantics.c:6661
 #, fuzzy, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr "在 %L 处的推迟数组“%1$s”在初始化表达式中不被允许"
 
-#: c/c-typeck.c:13597 c/c-typeck.c:13731 cp/semantics.c:6677
-#: cp/semantics.c:6834
+#: c/c-typeck.c:13602 c/c-typeck.c:13736 cp/semantics.c:6680
+#: cp/semantics.c:6837
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD在数据子句中多次出现"
 
-#: c/c-typeck.c:13603 c/c-typeck.c:13735 cp/semantics.c:6683
-#: cp/semantics.c:6838
+#: c/c-typeck.c:13608 c/c-typeck.c:13740 cp/semantics.c:6686
+#: cp/semantics.c:6841
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD在数据子句中多次出现"
 
-#: c/c-typeck.c:13635 cp/semantics.c:6724
+#: c/c-typeck.c:13640 cp/semantics.c:6727
 #, fuzzy, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qD在子句%qs中不是一个变量"
 
-#: c/c-typeck.c:13695 c/c-typeck.c:13785 cp/semantics.c:6799
-#: cp/semantics.c:6938
+#: c/c-typeck.c:13700 c/c-typeck.c:13790 cp/semantics.c:6802
+#: cp/semantics.c:6941
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD在子句%qs中不是一个变量"
 
-#: c/c-typeck.c:13766 cp/semantics.c:6918
+#: c/c-typeck.c:13771 cp/semantics.c:6921
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE在子句%qs中不是一个变量"
 
-#: c/c-typeck.c:13794 cp/semantics.c:6947
+#: c/c-typeck.c:13799 cp/semantics.c:6950
 #, fuzzy, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qE在数据子句中多次出现"
 
-#: c/c-typeck.c:13808 cp/semantics.c:6962
+#: c/c-typeck.c:13813 cp/semantics.c:6965
 #, fuzzy, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD在%<lastprivate%>子句中不是一个变量"
 
-#: c/c-typeck.c:13811 cp/semantics.c:6964
+#: c/c-typeck.c:13816 cp/semantics.c:6967
 #, fuzzy, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qE在子句%<lastprivate%>中不是一个变量"
 
-#: c/c-typeck.c:13826
+#: c/c-typeck.c:13831
 #, fuzzy, gcc-internal-format
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "向量 delete 的实参类型既非指针也非数组"
 
-#: c/c-typeck.c:13900 cp/semantics.c:6359
+#: c/c-typeck.c:13905 cp/semantics.c:6362
 #, gcc-internal-format
 msgid "%<nonmonotonic%> modifier specified for %qs schedule kind"
 msgstr ""
 
-#: c/c-typeck.c:13931 cp/semantics.c:7141
+#: c/c-typeck.c:13936 cp/semantics.c:7144
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:13981 cp/semantics.c:7332
+#: c/c-typeck.c:13986 cp/semantics.c:7335
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE可被预先确定为%qs，为%qs"
 
-#: c/c-typeck.c:14001 cp/semantics.c:7223
+#: c/c-typeck.c:14006 cp/semantics.c:7226
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:14013 cp/semantics.c:7236
+#: c/c-typeck.c:14018 cp/semantics.c:7239
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14031 cp/semantics.c:7203
+#: c/c-typeck.c:14036 cp/semantics.c:7206
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:14204
+#: c/c-typeck.c:14209
 #, gcc-internal-format
 msgid "cannot use %<va_arg%> with reverse storage order"
 msgstr ""
 
-#: c/c-typeck.c:14209
+#: c/c-typeck.c:14214
 #, fuzzy, gcc-internal-format
 #| msgid "first argument to %<va_arg%> not of type %<va_list%>"
 msgid "second argument to %<va_arg%> is of incomplete type %qT"
 msgstr "给%<va_arg%>的第一个参数的类型不是%<va_list%>"
 
-#: c/c-typeck.c:14215
+#: c/c-typeck.c:14220
 #, gcc-internal-format
 msgid "C++ requires promoted type, not enum type, in %<va_arg%>"
 msgstr "C++ 在%<va_arg%>中需要提升后的类型而不是枚举"
@@ -41924,7 +41969,7 @@
 msgid "  no known conversion for argument %d from %qH to %qI"
 msgstr "以从%qT转换为%qT"
 
-#: cp/call.c:3441 cp/pt.c:6495
+#: cp/call.c:3441 cp/pt.c:6509
 #, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects %d argument, %d provided"
 msgid_plural "  candidate expects %d arguments, %d provided"
@@ -42229,7 +42274,7 @@
 msgid "%q#D is private within this context"
 msgstr "在此上下文中"
 
-#: cp/call.c:6478 cp/decl.c:7343
+#: cp/call.c:6478 cp/decl.c:7364
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "declared private here"
@@ -42241,7 +42286,7 @@
 msgid "%q#D is protected within this context"
 msgstr "在此上下文中"
 
-#: cp/call.c:6486 cp/decl.c:7344
+#: cp/call.c:6486 cp/decl.c:7365
 #, fuzzy, gcc-internal-format
 #| msgid "declared here"
 msgid "declared protected here"
@@ -42559,7 +42604,7 @@
 msgid "call to non-function %qD"
 msgstr "调用非函数的%qD"
 
-#: cp/call.c:9119 cp/pt.c:15053 cp/typeck.c:2901
+#: cp/call.c:9119 cp/pt.c:15075 cp/typeck.c:2901
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "不能直接调用构造函数%<%T::%D%>"
@@ -42781,270 +42826,270 @@
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr "无法从基类%qT转换到派生类%qT，通过虚基类%qT"
 
-#: cp/class.c:2098
+#: cp/class.c:2103
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr "类%qT中所有成员函数都是私有的"
 
-#: cp/class.c:2110
+#: cp/class.c:2115
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr "%q#T仅定义了一个私有析构函数且没有友元"
 
-#: cp/class.c:2152
+#: cp/class.c:2156
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr "%q#T仅定义了一个私有构造函数且没有友元"
 
-#: cp/class.c:2156
+#: cp/class.c:2160
 #, gcc-internal-format
 msgid "%q#D is public, but requires an existing %q#T object"
 msgstr ""
 
-#: cp/class.c:2430
+#: cp/class.c:2434
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr "%qD的最终重载在%qT中不唯一"
 
-#: cp/class.c:2785
+#: cp/class.c:2789
 #, fuzzy, gcc-internal-format
 msgid "%qD can be marked override"
 msgstr "函数%q+D的定义被标记为 dllimport"
 
-#: cp/class.c:2797
+#: cp/class.c:2801
 #, fuzzy, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr "%q#D的定义被标记为 %<dllimport%>"
 
-#: cp/class.c:2799
+#: cp/class.c:2803
 #, fuzzy, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr "%q+D定义后未使用"
 
-#: cp/class.c:2861
+#: cp/class.c:2865
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was hidden"
 msgid "%qD was hidden"
 msgstr "%q+D为"
 
-#: cp/class.c:2863
+#: cp/class.c:2867
 #, fuzzy, gcc-internal-format
 #| msgid "  by %q+D"
 msgid "  by %qD"
 msgstr "%q+D所隐藏"
 
-#: cp/class.c:2896
+#: cp/class.c:2900
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D invalid; an anonymous union can only have non-static data members"
 msgid "%q#D invalid; an anonymous union may only have public non-static data members"
 msgstr "%q+#D无效；匿名联合只能有非静态的数据成员"
 
-#: cp/class.c:2906 cp/name-lookup.c:3293 cp/parser.c:19720
+#: cp/class.c:2910 cp/name-lookup.c:3293 cp/parser.c:19717
 #, gcc-internal-format
 msgid "this flexibility is deprecated and will be removed"
 msgstr ""
 
-#: cp/class.c:3097
+#: cp/class.c:3101
 #, fuzzy, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr "当继承来的方法未被实现时给出警告"
 
-#: cp/class.c:3213
+#: cp/class.c:3217
 #, gcc-internal-format
 msgid "bit-field %q+#D with non-integral type"
 msgstr "位段%q+#D有非整数的类型"
 
-#: cp/class.c:3229
+#: cp/class.c:3233
 #, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr "位段%q+D的宽度不是一个整数常量"
 
-#: cp/class.c:3234
+#: cp/class.c:3238
 #, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr "位段%q+D宽度为负"
 
-#: cp/class.c:3239
+#: cp/class.c:3243
 #, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr "位段%q+D宽度为 0"
 
-#: cp/class.c:3249
+#: cp/class.c:3253
 #, fuzzy, gcc-internal-format
 #| msgid "width of %q+D exceeds its type"
 msgid "width of %qD exceeds its type"
 msgstr "%q+D的宽度超过了它的类型"
 
-#: cp/class.c:3255
+#: cp/class.c:3259
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is too small to hold all values of %q#T"
 msgid "%qD is too small to hold all values of %q#T"
 msgstr "%q+D太小而不能存放%q#T的所有可能值"
 
-#: cp/class.c:3316
+#: cp/class.c:3320
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr "有构造函数的成员%q+#D不能用在联合中"
 
-#: cp/class.c:3319
+#: cp/class.c:3323
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr "有析构函数的成员%q+#D不能用在联合中"
 
-#: cp/class.c:3321
+#: cp/class.c:3325
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr "有拷贝赋值运算符的成员%q+#D不能用在联合中"
 
-#: cp/class.c:3325
+#: cp/class.c:3329
 #, fuzzy, gcc-internal-format
 msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/class.c:3453
+#: cp/class.c:3457
 #, fuzzy, gcc-internal-format
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr "%q+D不能是静态的，因为它是联合的成员"
 
-#: cp/class.c:3460
+#: cp/class.c:3464
 #, fuzzy, gcc-internal-format
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr "非静态数据成员%qD具有 Java 类类型"
 
-#: cp/class.c:3470
+#: cp/class.c:3474
 #, gcc-internal-format
 msgid "field %q+D invalidly declared function type"
 msgstr "字段%q+D无效地声明为函数类型"
 
-#: cp/class.c:3476
+#: cp/class.c:3480
 #, gcc-internal-format
 msgid "field %q+D invalidly declared method type"
 msgstr "字段%q+D无效地声明为方法类型"
 
-#: cp/class.c:3536
+#: cp/class.c:3540
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring packed attribute because of unpacked non-POD field %q+#D"
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr "为非紧实的非简单旧数据字段%q+#D忽略 packed 属性"
 
-#: cp/class.c:3585
+#: cp/class.c:3589
 #, fuzzy, gcc-internal-format
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr "非成员%qs不能被声明为%<mutable%>"
 
-#: cp/class.c:3591
+#: cp/class.c:3595
 #, fuzzy, gcc-internal-format
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr "非成员%qs不能被声明为%<mutable%>"
 
-#: cp/class.c:3617
+#: cp/class.c:3621
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr "初始化了联合%qT中的多个字段"
 
-#: cp/class.c:3658
+#: cp/class.c:3662
 #, fuzzy, gcc-internal-format
 #| msgid "field %q+#D with same name as class"
 msgid "field %q#D with same name as class"
 msgstr "字段%q+#D与类重名"
 
-#: cp/class.c:3681
+#: cp/class.c:3685
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr "%q#T有指针数据成员"
 
-#: cp/class.c:3686
+#: cp/class.c:3690
 #, gcc-internal-format
 msgid "  but does not override %<%T(const %T&)%>"
 msgstr "但没有重载%<%T(const %T&)%>"
 
-#: cp/class.c:3688
+#: cp/class.c:3692
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr "或者%<operator=(const %T&)%>"
 
-#: cp/class.c:3692
+#: cp/class.c:3696
 #, gcc-internal-format
 msgid "  but does not override %<operator=(const %T&)%>"
 msgstr "但没有重载%<operator=(const %T&)%>"
 
-#: cp/class.c:4097
+#: cp/class.c:4101
 #, gcc-internal-format
 msgid "alignment of %qD increased in -fabi-version=9 (GCC 5.2)"
 msgstr ""
 
-#: cp/class.c:4100
+#: cp/class.c:4104
 #, fuzzy, gcc-internal-format
 msgid "alignment of %qD will increase in -fabi-version=9"
 msgstr "%qD的对齐"
 
-#: cp/class.c:4378
+#: cp/class.c:4382
 #, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "为非虚方法%q+D指定了初始值设定项"
 
-#: cp/class.c:4813
+#: cp/class.c:4817
 #, fuzzy, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr "方法强制变更两者 %<transaction_pure%> 和 %qE 方法"
 
-#: cp/class.c:4834
+#: cp/class.c:4838
 #, fuzzy, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr "为不存在的方法%qE创建选择子"
 
-#: cp/class.c:5350 cp/constexpr.c:237
+#: cp/class.c:5367 cp/constexpr.c:237
 #, fuzzy, gcc-internal-format
 msgid "enclosing class of %<constexpr%> non-static member function %q+#D is not a literal type"
 msgstr "%3$L处 CLASS 变量‘%2$s’的类型‘%1$s’不能被扩展"
 
-#: cp/class.c:5374
+#: cp/class.c:5391
 #, fuzzy, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr "在%q#T和%q#T间比较"
 
-#: cp/class.c:5377
+#: cp/class.c:5394
 #, gcc-internal-format
 msgid "  %qT is a closure type, which is only literal in C++17 and later"
 msgstr ""
 
-#: cp/class.c:5380
+#: cp/class.c:5397
 #, fuzzy, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr "基类%q#T有一个非虚析构函数"
 
-#: cp/class.c:5387
+#: cp/class.c:5404
 #, fuzzy, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no %<constexpr%> constructor that is not a copy or move constructor"
 msgstr "  %q+T 不是汇总，没有 trivial 缺省构造函数，而没有任何 constexpr 建构子该并非复制或移动建构子"
 
-#: cp/class.c:5420
+#: cp/class.c:5437
 #, fuzzy, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "%3$L处 CLASS 变量‘%2$s’的类型‘%1$s’不能被扩展"
 
-#: cp/class.c:5435
+#: cp/class.c:5452
 #, fuzzy, gcc-internal-format
 msgid "  non-static data member %qD has non-literal type"
 msgstr "非静态数据成员%qD具有 Java 类类型"
 
-#: cp/class.c:5442
+#: cp/class.c:5459
 #, fuzzy, gcc-internal-format
 msgid "  non-static data member %qD has volatile type"
 msgstr "非静态数据成员%qD具有 Java 类类型"
 
-#: cp/class.c:5561
+#: cp/class.c:5578
 #, fuzzy, gcc-internal-format
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "%q#T有虚函数和可访问的非虚拟析构函数"
 
-#: cp/class.c:5590
+#: cp/class.c:5607
 #, fuzzy, gcc-internal-format
 #| msgid "non-static reference %q+#D in class without a constructor"
 msgid "non-static reference %q#D in class without a constructor"
 msgstr "类中有非静态引用%q+#D，却没有提供构造函数"
 
-#: cp/class.c:5596
+#: cp/class.c:5613
 #, fuzzy, gcc-internal-format
 #| msgid "non-static const member %q+#D in class without a constructor"
 msgid "non-static const member %q#D in class without a constructor"
@@ -43052,160 +43097,160 @@
 
 #. If the function is defaulted outside the class, we just
 #. give the synthesis error.
-#: cp/class.c:5624
+#: cp/class.c:5641
 #, gcc-internal-format
 msgid "%q+D declared to take const reference, but implicit declaration would take non-const"
 msgstr "%q+D被声明为取常量引用，但是隐式声明取非常量引用"
 
-#: cp/class.c:5898
+#: cp/class.c:5915
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr "由于存在歧义，直接基类%qT在%qT中无法访问"
 
-#: cp/class.c:5910
+#: cp/class.c:5927
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr "由于存在歧义，虚基类%qT在%qT中无法访问"
 
-#: cp/class.c:6133
+#: cp/class.c:6150
 #, fuzzy, gcc-internal-format
 #| msgid "offset of %q+D is not ABI-compliant and may change in a future version of GCC"
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr "%q+D的偏移量与 ABI 不兼容，并且在 GCC 的未来版本中可能会有变化"
 
-#: cp/class.c:6291
+#: cp/class.c:6308
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qE is too large"
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr "数组%qE太大"
 
-#: cp/class.c:6576
+#: cp/class.c:6593
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr "对非左值数组的使用无效"
 
-#: cp/class.c:6578
+#: cp/class.c:6595
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of structure with flexible array member"
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr "对包含可变数组成员的结构的无效使用"
 
-#: cp/class.c:6583
+#: cp/class.c:6600
 #, fuzzy, gcc-internal-format
 msgid "array member %q#D declared here"
 msgstr "%q+D已在此声明过"
 
-#: cp/class.c:6610
+#: cp/class.c:6627
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member not at end of struct"
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr "可变数组成员没有出现在结构的末尾"
 
-#: cp/class.c:6612
+#: cp/class.c:6629
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member in otherwise empty struct"
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr "可变数组是结构中的唯一成员"
 
-#: cp/class.c:6620 cp/class.c:6650
+#: cp/class.c:6637 cp/class.c:6667
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %q#T"
 msgid "in the definition of %q#T"
 msgstr "%q#T重定义"
 
-#: cp/class.c:6628
+#: cp/class.c:6645
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member not at end of struct"
 msgid "flexible array member %qD not at end of %q#T"
 msgstr "可变数组成员没有出现在结构的末尾"
 
-#: cp/class.c:6630
+#: cp/class.c:6647
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member in otherwise empty struct"
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr "可变数组是结构中的唯一成员"
 
-#: cp/class.c:6648
+#: cp/class.c:6665
 #, fuzzy, gcc-internal-format
 msgid "next member %q#D declared here"
 msgstr "%q+D已在此声明过"
 
-#: cp/class.c:6760 cp/parser.c:23239
+#: cp/class.c:6777 cp/parser.c:23236
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "%q#T重定义"
 
-#: cp/class.c:6897
+#: cp/class.c:6914
 #, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "%q#T有虚函数和可访问的非虚拟析构函数"
 
-#: cp/class.c:6925
+#: cp/class.c:6942
 #, fuzzy, gcc-internal-format
 msgid "type transparent %q#T does not have any fields"
 msgstr "类型%qT大小未知"
 
-#: cp/class.c:6931
+#: cp/class.c:6948
 #, fuzzy, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr "类型透明类别 %qT 有基础类别"
 
-#: cp/class.c:6935
+#: cp/class.c:6952
 #, fuzzy, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr "类型%qE有虚成员函数"
 
-#: cp/class.c:6941
+#: cp/class.c:6958
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:7071
+#: cp/class.c:7088
 #, fuzzy, gcc-internal-format
 msgid "definition of %qD does not match %<#include <initializer_list>%>"
 msgstr "从花括号中的初始化列表演绎需要 #include <initializer_list>"
 
-#: cp/class.c:7082
+#: cp/class.c:7099
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr "试图完成结构，但为先前的解析错误所中断"
 
-#: cp/class.c:7582
+#: cp/class.c:7599
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "语言字符串%<\"%E\"%>不可识别"
 
-#: cp/class.c:7672
+#: cp/class.c:7689
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr "无法解析重载函数%qD，基于向类型%qT的转换"
 
-#: cp/class.c:7817
+#: cp/class.c:7834
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr "没有可将函数%qD转换到类型%q#T的匹配项"
 
-#: cp/class.c:7844
+#: cp/class.c:7861
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "将重载函数%qD转换为类型%q#T有歧义"
 
-#: cp/class.c:7870
+#: cp/class.c:7887
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "假定是成员指针%qD"
 
-#: cp/class.c:7873
+#: cp/class.c:7890
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(成员指针只能用%<&%E%>构成)"
 
-#: cp/class.c:7948 cp/class.c:7990
+#: cp/class.c:7965 cp/class.c:8007
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "类型信息不充分"
 
-#: cp/class.c:7968
+#: cp/class.c:7985
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "无法将%qE从类型%qT转换到类型%qT"
@@ -43215,12 +43260,12 @@
 #. A name N used in a class S shall refer to the same declaration
 #. in its context and when re-evaluated in the completed scope of
 #. S.
-#: cp/class.c:8235
+#: cp/class.c:8252
 #, gcc-internal-format
 msgid "declaration of %q#D"
 msgstr "%q#D的声明"
 
-#: cp/class.c:8237
+#: cp/class.c:8254
 #, fuzzy, gcc-internal-format
 #| msgid "changes meaning of %qD from %q+#D"
 msgid "changes meaning of %qD from %q#D"
@@ -43620,17 +43665,17 @@
 msgid "unexpected AST of kind %s"
 msgstr "%2$L处 %1$s 种别无效"
 
-#: cp/cp-gimplify.c:1415
+#: cp/cp-gimplify.c:1416
 #, gcc-internal-format
 msgid "throw will always call terminate()"
 msgstr ""
 
-#: cp/cp-gimplify.c:1418
+#: cp/cp-gimplify.c:1419
 #, gcc-internal-format
 msgid "in C++11 destructors default to noexcept"
 msgstr ""
 
-#: cp/cp-gimplify.c:1429
+#: cp/cp-gimplify.c:1430
 #, gcc-internal-format
 msgid "in C++11 this throw will terminate because destructors default to noexcept"
 msgstr ""
@@ -44056,7 +44101,7 @@
 msgid "redeclaration %qD differs in %<constexpr%> from previous declaration"
 msgstr "对%qD的重声明在%<constexpr%>方面"
 
-#: cp/decl.c:1304 cp/decl.c:13843
+#: cp/decl.c:1304 cp/decl.c:13867
 #, fuzzy, gcc-internal-format
 msgid "previous declaration %qD"
 msgstr "先前的声明%q+D"
@@ -44394,7 +44439,7 @@
 msgid "  enters OpenMP structured block"
 msgstr "进入了 OpenMP 结构块"
 
-#: cp/decl.c:3434 cp/parser.c:12366 cp/parser.c:12387
+#: cp/decl.c:3434 cp/parser.c:12363 cp/parser.c:12384
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr "OpenMP 结构块出口无效"
@@ -44404,7 +44449,7 @@
 msgid "%qD is not a type"
 msgstr "%qD不是一个类型"
 
-#: cp/decl.c:3838 cp/parser.c:6366
+#: cp/decl.c:3838 cp/parser.c:6369
 #, gcc-internal-format
 msgid "%qD used without template parameters"
 msgstr "%qD使用时未带模板参数"
@@ -44788,8 +44833,8 @@
 msgid "C99 designator %qE outside aggregate initializer"
 msgstr "C99 指示项 %qE 外侧汇总初始设置式"
 
-#: cp/decl.c:6011 cp/decl.c:6234 cp/typeck2.c:1310 cp/typeck2.c:1590
-#: cp/typeck2.c:1638 cp/typeck2.c:1685
+#: cp/decl.c:6011 cp/decl.c:6234 cp/typeck2.c:1310 cp/typeck2.c:1593
+#: cp/typeck2.c:1641 cp/typeck2.c:1688
 #, gcc-internal-format
 msgid "too many initializers for %qT"
 msgstr "%qT的初始值设定项太多"
@@ -44864,13 +44909,13 @@
 msgid "assignment (not initialization) in declaration"
 msgstr "赋值(不是初始化)出现在声明中"
 
-#: cp/decl.c:6873 cp/decl.c:12605
+#: cp/decl.c:6873 cp/decl.c:12629
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++17 does not allow %<register%> storage class specifier"
 msgstr "ISO C++ 不允许指定元素初始值设定"
 
-#: cp/decl.c:6877 cp/decl.c:12609
+#: cp/decl.c:6877 cp/decl.c:12633
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for %qs"
 msgid "%<register%> storage class specifier used"
@@ -44897,45 +44942,45 @@
 msgid "function %q#D is initialized like a variable"
 msgstr "函数%q#D像变量一样被初始化"
 
-#: cp/decl.c:7329
+#: cp/decl.c:7350
 #, fuzzy, gcc-internal-format
 #| msgid "  cannot use obsolete binding at %q+D because it has a destructor"
 msgid "cannot decompose class type %qT because it has an anonymous struct member"
 msgstr "不能在%q+D使用过时的绑定，因为它有析构函数"
 
-#: cp/decl.c:7332
+#: cp/decl.c:7353
 #, gcc-internal-format
 msgid "cannot decompose class type %qT because it has an anonymous union member"
 msgstr ""
 
-#: cp/decl.c:7339
+#: cp/decl.c:7360
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is an inaccessible base of %qT"
 msgid "cannot decompose inaccessible member %qD of %qT"
 msgstr "%qT是%qT不可访问的基类"
 
-#: cp/decl.c:7365
+#: cp/decl.c:7386
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: both it and its base class %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:7374
+#: cp/decl.c:7395
 #, gcc-internal-format
 msgid "cannot decompose class type %qT: its base classes %qT and %qT have non-static data members"
 msgstr ""
 
-#: cp/decl.c:7592
+#: cp/decl.c:7613
 #, fuzzy, gcc-internal-format
 msgid "structured binding refers to incomplete type %qT"
 msgstr "指向不完全类型%qT的指针不能自减"
 
-#: cp/decl.c:7608
+#: cp/decl.c:7629
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 forbids variable length array %qE"
 msgid "cannot decompose variable length array %qT"
 msgstr "ISO C90 不允许变长数组%qE"
 
-#: cp/decl.c:7617 cp/decl.c:7702
+#: cp/decl.c:7638 cp/decl.c:7723
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qs specified for structure field"
 msgid "%u name provided for structured binding"
@@ -44942,925 +44987,925 @@
 msgid_plural "%u names provided for structured binding"
 msgstr[0] "为结构字段指定了%qs"
 
-#: cp/decl.c:7621
+#: cp/decl.c:7642
 #, gcc-internal-format, gfc-internal-format
 msgid "only %u name provided for structured binding"
 msgid_plural "only %u names provided for structured binding"
 msgstr[0] ""
 
-#: cp/decl.c:7624
+#: cp/decl.c:7645
 #, gcc-internal-format
 msgid "while %qT decomposes into %wu element"
 msgid_plural "while %qT decomposes into %wu elements"
 msgstr[0] ""
 
-#: cp/decl.c:7669
+#: cp/decl.c:7690
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to %q#T"
 msgid "cannot decompose variable length vector %qT"
 msgstr "无法声明指向%q#T的指针"
 
-#: cp/decl.c:7695
+#: cp/decl.c:7716
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "%<std::tuple_size<%T>::value%> is not an integral constant expression"
 msgstr "数组大小不是一个整数常表达式"
 
-#: cp/decl.c:7704
+#: cp/decl.c:7725
 #, gcc-internal-format
 msgid "while %qT decomposes into %E elements"
 msgstr ""
 
-#: cp/decl.c:7725
+#: cp/decl.c:7746
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type for iteration variable %qE"
 msgid "in initialization of structured binding variable %qD"
 msgstr "迭代变量%qE类型无效"
 
-#: cp/decl.c:7751
+#: cp/decl.c:7772
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to qualified function type %qT"
 msgid "cannot decompose union type %qT"
 msgstr "不能声明指向限定函数类型%qT的指针"
 
-#: cp/decl.c:7756
+#: cp/decl.c:7777
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "cannot decompose non-array non-class type %qT"
 msgstr "生成非类类型%qT的成员指针"
 
-#: cp/decl.c:7761
+#: cp/decl.c:7782
 #, fuzzy, gcc-internal-format
 #| msgid "cannot decompose address"
 msgid "cannot decompose lambda closure type %qT"
 msgstr "无法分解地址"
 
-#: cp/decl.c:7765
+#: cp/decl.c:7786
 #, fuzzy, gcc-internal-format
 #| msgid "source is of incomplete class type"
 msgid "structured binding refers to incomplete class type %qT"
 msgstr "源有不完全的类类型"
 
-#: cp/decl.c:7774
+#: cp/decl.c:7795
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply %<offsetof%> to static data member %qD"
 msgid "cannot decompose class type %qT without non-static data members"
 msgstr "不能对静态数据成员%qD取%<offsetof%>"
 
-#: cp/decl.c:8213
+#: cp/decl.c:8234
 #, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> needs dynamic initialization"
 msgstr ""
 
-#: cp/decl.c:8216
+#: cp/decl.c:8237
 #, fuzzy, gcc-internal-format
 msgid "non-local variable %qD declared %<__thread%> has a non-trivial destructor"
 msgstr "  %q+T 有 non-trivial 解构式"
 
-#: cp/decl.c:8222
+#: cp/decl.c:8243
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> allows dynamic initialization and destruction"
 msgstr ""
 
-#: cp/decl.c:8450
+#: cp/decl.c:8471
 #, fuzzy, gcc-internal-format
 msgid "initializer fails to determine size of %qT"
 msgstr "初始值设定无法决定%qD的大小"
 
-#: cp/decl.c:8454
+#: cp/decl.c:8475
 #, fuzzy, gcc-internal-format
 msgid "array size missing in %qT"
 msgstr "%qD缺少数组大小"
 
-#: cp/decl.c:8457
+#: cp/decl.c:8478
 #, fuzzy, gcc-internal-format
 msgid "zero-size array %qT"
 msgstr "大小为 0 的数组%qD"
 
-#: cp/decl.c:8473
+#: cp/decl.c:8494
 #, gcc-internal-format
 msgid "destructor for alien class %qT cannot be a member"
 msgstr "其他类%qT的析构函数不能用作成员"
 
-#: cp/decl.c:8475
+#: cp/decl.c:8496
 #, gcc-internal-format
 msgid "constructor for alien class %qT cannot be a member"
 msgstr "其他类%qT的构造函数不能用作成员"
 
-#: cp/decl.c:8499
+#: cp/decl.c:8520
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> variable"
 msgstr "%qD声明为%<virtual%>变量"
 
-#: cp/decl.c:8501
+#: cp/decl.c:8522
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in variable declaration"
 msgstr "为%qD指定的%<const%>和%<volatile%>在 %s 声明中无效"
 
-#: cp/decl.c:8506
+#: cp/decl.c:8527
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> parameter"
 msgstr "%qD声明为%<virtual%>参数"
 
-#: cp/decl.c:8508
+#: cp/decl.c:8529
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> parameter"
 msgstr "%qD声明为%<inline%>参数"
 
-#: cp/decl.c:8510
+#: cp/decl.c:8531
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in parameter declaration"
 msgstr "为%qD指定的%<const%>和%<volatile%>在 %s 声明中无效"
 
-#: cp/decl.c:8515
+#: cp/decl.c:8536
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> type"
 msgstr "%qD声明为%<virtual%>类型"
 
-#: cp/decl.c:8517
+#: cp/decl.c:8538
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> type"
 msgstr "%qD声明为%<inline%>类型"
 
-#: cp/decl.c:8519
+#: cp/decl.c:8540
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in type declaration"
 msgstr "为%qD指定的%<const%>和%<volatile%>在 %s 声明中无效"
 
-#: cp/decl.c:8524
+#: cp/decl.c:8545
 #, gcc-internal-format
 msgid "%qD declared as a %<virtual%> field"
 msgstr "%qD声明为%<virtual%>字段"
 
-#: cp/decl.c:8526
+#: cp/decl.c:8547
 #, gcc-internal-format
 msgid "%qD declared as an %<inline%> field"
 msgstr "%qD声明为%<inline%>字段"
 
-#: cp/decl.c:8528
+#: cp/decl.c:8549
 #, fuzzy, gcc-internal-format
 msgid "%<const%> and %<volatile%> function specifiers on %qD invalid in field declaration"
 msgstr "为%qD指定的%<const%>和%<volatile%>在 %s 声明中无效"
 
-#: cp/decl.c:8535
+#: cp/decl.c:8556
 #, gcc-internal-format
 msgid "%q+D declared as a friend"
 msgstr "%q+D声明为友元"
 
-#: cp/decl.c:8542
+#: cp/decl.c:8563
 #, gcc-internal-format
 msgid "%q+D declared with an exception specification"
 msgstr "%q+D声明时带有异常规范"
 
-#: cp/decl.c:8574
+#: cp/decl.c:8595
 #, gcc-internal-format
 msgid "definition of %qD is not in namespace enclosing %qT"
 msgstr "%qD的定义不在包含%qT的命名空间中"
 
-#: cp/decl.c:8614
+#: cp/decl.c:8635
 #, gcc-internal-format
 msgid "static member function %q#D declared with type qualifiers"
 msgstr "静态成员函数%q#D的声明带有类型限定符"
 
-#: cp/decl.c:8624
+#: cp/decl.c:8645
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared as a non-parameter"
 msgid "concept %q#D declared with function parameters"
 msgstr "%qD没有声明为一个参数"
 
-#: cp/decl.c:8630
+#: cp/decl.c:8651
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD declared with void type"
 msgid "concept %q#D declared with a deduced return type"
 msgstr "形参%qD被声明为有 void 类型"
 
-#: cp/decl.c:8632
+#: cp/decl.c:8653
 #, fuzzy, gcc-internal-format
 #| msgid "Java method %qD has non-Java return type %qT"
 msgid "concept %q#D with non-%<bool%> return type %qT"
 msgstr "Java 方法%qD返回非 Java 类型%qT"
 
-#: cp/decl.c:8703
+#: cp/decl.c:8724
 #, fuzzy, gcc-internal-format
 msgid "concept %qD has no definition"
 msgstr "-fmit-class-file 的别名"
 
-#: cp/decl.c:8772
+#: cp/decl.c:8793
 #, gcc-internal-format
 msgid "defining explicit specialization %qD in friend declaration"
 msgstr "在友元声明中定义显式特例化%qD"
 
 #. Something like `template <class T> friend void f<T>()'.
-#: cp/decl.c:8782
+#: cp/decl.c:8803
 #, gcc-internal-format
 msgid "invalid use of template-id %qD in declaration of primary template"
 msgstr "在基本模板的声明中对模板标识符%qD的使用无效"
 
-#: cp/decl.c:8800
+#: cp/decl.c:8821
 #, gcc-internal-format
 msgid "default arguments are not allowed in declaration of friend template specialization %qD"
 msgstr "友元模板特例化%qD中不允许出现默认参数"
 
-#: cp/decl.c:8808
+#: cp/decl.c:8829
 #, gcc-internal-format
 msgid "%<inline%> is not allowed in declaration of friend template specialization %qD"
 msgstr "%<inline%>不允许用于友元模板特例化%qD的声明"
 
-#: cp/decl.c:8857
+#: cp/decl.c:8878
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be a template"
 msgstr "不能将%<::main%>声明为一个模板"
 
-#: cp/decl.c:8859
+#: cp/decl.c:8880
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be inline"
 msgstr "不能将%<::main%>声明为 inline"
 
-#: cp/decl.c:8861
+#: cp/decl.c:8882
 #, fuzzy, gcc-internal-format
 msgid "cannot declare %<::main%> to be %<constexpr%>"
 msgstr "不能将%<::main%>声明为一个模板"
 
-#: cp/decl.c:8863
+#: cp/decl.c:8884
 #, gcc-internal-format
 msgid "cannot declare %<::main%> to be static"
 msgstr "不能将%<::main%>声明为 static"
 
-#: cp/decl.c:8920
+#: cp/decl.c:8941
 #, gcc-internal-format
 msgid "static member function %qD cannot have cv-qualifier"
 msgstr "成员函数%qD不能拥有 cv 限定符"
 
-#: cp/decl.c:8921
+#: cp/decl.c:8942
 #, gcc-internal-format
 msgid "non-member function %qD cannot have cv-qualifier"
 msgstr "非成员函数%qD不能拥有 cv 限定符"
 
-#: cp/decl.c:8929
+#: cp/decl.c:8950
 #, fuzzy, gcc-internal-format
 msgid "static member function %qD cannot have ref-qualifier"
 msgstr "成员函数%qD不能拥有 cv 限定符"
 
-#: cp/decl.c:8930
+#: cp/decl.c:8951
 #, fuzzy, gcc-internal-format
 msgid "non-member function %qD cannot have ref-qualifier"
 msgstr "非成员函数%qD不能拥有 cv 限定符"
 
-#: cp/decl.c:8940
+#: cp/decl.c:8961
 #, fuzzy, gcc-internal-format
 #| msgid "specialization of %qD must appear at namespace scope"
 msgid "deduction guide %qD must be declared at namespace scope"
 msgstr "%qD的特例化必须出现在命名空间内"
 
-#: cp/decl.c:8946
+#: cp/decl.c:8967
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as non-function"
 msgid "deduction guide %qD must not have a function body"
 msgstr "%qD没有声明为一个函数"
 
-#: cp/decl.c:8959
+#: cp/decl.c:8980
 #, fuzzy, gcc-internal-format
 msgid "literal operator with C linkage"
 msgstr "特例化模板有 C 链接"
 
-#: cp/decl.c:8969
+#: cp/decl.c:8990
 #, gcc-internal-format
 msgid "%qD has invalid argument list"
 msgstr "%qD 带有无效参数列表"
 
-#: cp/decl.c:8977
+#: cp/decl.c:8998
 #, fuzzy, gcc-internal-format
 msgid "integer suffix %qs shadowed by implementation"
 msgstr "整数字尾 %<%s%>带阴影由实现"
 
-#: cp/decl.c:8983
+#: cp/decl.c:9004
 #, fuzzy, gcc-internal-format
 msgid "floating point suffix %qs shadowed by implementation"
 msgstr "浮点数字尾 %<%s%>带阴影由实现"
 
-#: cp/decl.c:8991
+#: cp/decl.c:9012
 #, fuzzy, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr "实字运算符后缀无法前继的由 %<_%>被保留的用于未来标准化"
 
-#: cp/decl.c:8996
+#: cp/decl.c:9017
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a non-member function"
 msgstr "%qD必须是一个非静态的成员函数"
 
-#: cp/decl.c:9076
+#: cp/decl.c:9097
 #, gcc-internal-format
 msgid "%<::main%> must return %<int%>"
 msgstr "%<::main%>必须返回%<int%>"
 
-#: cp/decl.c:9116
+#: cp/decl.c:9137
 #, gcc-internal-format
 msgid "definition of implicitly-declared %qD"
 msgstr "隐式声明的%qD的定义"
 
-#: cp/decl.c:9121
+#: cp/decl.c:9142
 #, fuzzy, gcc-internal-format
 msgid "definition of explicitly-defaulted %q+D"
 msgstr "默认化声明%q+D"
 
-#: cp/decl.c:9123
+#: cp/decl.c:9144
 #, fuzzy, gcc-internal-format
 msgid "%q#D explicitly defaulted here"
 msgstr "默认化声明%q+D"
 
-#: cp/decl.c:9140
+#: cp/decl.c:9161
 #, gcc-internal-format
 msgid "no %q#D member function declared in class %qT"
 msgstr "成员函数%q#D未在类%qT中声明"
 
-#: cp/decl.c:9329
+#: cp/decl.c:9350
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %<::main%> to be a template"
 msgid "cannot declare %<::main%> to be a global variable"
 msgstr "不能将%<::main%>声明为一个模板"
 
-#: cp/decl.c:9337
+#: cp/decl.c:9358
 #, fuzzy, gcc-internal-format
 #| msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgid "a non-template variable cannot be %<concept%>"
 msgstr "自动变量%qE不能是%<threadprivate%>"
 
-#: cp/decl.c:9344
+#: cp/decl.c:9365
 #, gcc-internal-format
 msgid "concept must have type %<bool%>"
 msgstr ""
 
-#: cp/decl.c:9464
+#: cp/decl.c:9485
 #, fuzzy, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of incomplete type"
 msgstr "类中对具有非整数类型%qT的静态数据成员的初始化无效"
 
-#: cp/decl.c:9468
+#: cp/decl.c:9489
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> needed for in-class initialization of static data member %q#D of non-integral type"
 msgstr "类中对具有非整数类型%qT的静态数据成员的初始化无效"
 
-#: cp/decl.c:9472
+#: cp/decl.c:9493
 #, fuzzy, gcc-internal-format
 msgid "in-class initialization of static data member %q#D of non-literal type"
 msgstr "类中对具有非整数类型%qT的静态数据成员的初始化无效"
 
-#: cp/decl.c:9486
+#: cp/decl.c:9507
 #, gcc-internal-format
 msgid "invalid in-class initialization of static data member of non-integral type %qT"
 msgstr "类中对具有非整数类型%qT的静态数据成员的初始化无效"
 
-#: cp/decl.c:9493
+#: cp/decl.c:9514
 #, gcc-internal-format
 msgid "ISO C++ forbids in-class initialization of non-const static member %qD"
 msgstr "ISO C++ 不允许在类内初始化非常量静态成员%qD"
 
-#: cp/decl.c:9498
+#: cp/decl.c:9519
 #, gcc-internal-format
 msgid "ISO C++ forbids initialization of member constant %qD of non-integral type %qT"
 msgstr "ISO C++ 不允许初始化成员常量%qD，因为它有非整数的类型%qT"
 
-#: cp/decl.c:9598
+#: cp/decl.c:9619
 #, gcc-internal-format
 msgid "size of array %qD has non-integral type %qT"
 msgstr "数组%qD的大小具有非整数类型%qT"
 
-#: cp/decl.c:9600
+#: cp/decl.c:9621
 #, gcc-internal-format
 msgid "size of array has non-integral type %qT"
 msgstr "数组%qT的大小的类型不是整数"
 
-#: cp/decl.c:9630 cp/decl.c:9680
+#: cp/decl.c:9651 cp/decl.c:9701
 #, gcc-internal-format
 msgid "size of array is not an integral constant-expression"
 msgstr "数组大小不是一个整数常表达式"
 
-#: cp/decl.c:9646
+#: cp/decl.c:9667
 #, gcc-internal-format
 msgid "size of array %qD is negative"
 msgstr "数组%qD的大小为负"
 
-#: cp/decl.c:9648 cp/init.c:3651
+#: cp/decl.c:9669 cp/init.c:3667
 #, gcc-internal-format
 msgid "size of array is negative"
 msgstr "数组大小为负数"
 
-#: cp/decl.c:9662
+#: cp/decl.c:9683
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array %qD"
 msgstr "ISO C 不允许大小为 0 的数组%qD"
 
-#: cp/decl.c:9664
+#: cp/decl.c:9685
 #, gcc-internal-format
 msgid "ISO C++ forbids zero-size array"
 msgstr "ISO C++ 不允许大小为 0 的数组"
 
-#: cp/decl.c:9677
+#: cp/decl.c:9698
 #, gcc-internal-format
 msgid "size of array %qD is not an integral constant-expression"
 msgstr "数组%qD的大小不是一个整数常表达式"
 
-#: cp/decl.c:9686
+#: cp/decl.c:9707
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array %qD"
 msgstr "ISO C++ 不允许变长数组%qD"
 
-#: cp/decl.c:9688
+#: cp/decl.c:9709
 #, gcc-internal-format
 msgid "ISO C++ forbids variable length array"
 msgstr "ISO C++ 不允许变长数组"
 
-#: cp/decl.c:9694
+#: cp/decl.c:9715
 #, gcc-internal-format
 msgid "variable length array %qD is used"
 msgstr "使用了变长数组%qD"
 
-#: cp/decl.c:9697
+#: cp/decl.c:9718
 #, gcc-internal-format
 msgid "variable length array is used"
 msgstr "使用了变长数组"
 
-#: cp/decl.c:9746
+#: cp/decl.c:9767
 #, gcc-internal-format
 msgid "overflow in array dimension"
 msgstr "数组维数溢出"
 
-#: cp/decl.c:9799
+#: cp/decl.c:9820
 #, fuzzy, gcc-internal-format
 msgid "%qD declared as array of %qT"
 msgstr "成员函数%qD未在%qT中声明"
 
-#: cp/decl.c:9809
+#: cp/decl.c:9830
 #, gcc-internal-format
 msgid "declaration of %qD as array of void"
 msgstr "%qD声明为 void 的数组"
 
-#: cp/decl.c:9811
+#: cp/decl.c:9832
 #, gcc-internal-format
 msgid "creating array of void"
 msgstr "创建 void 数组"
 
-#: cp/decl.c:9816
+#: cp/decl.c:9837
 #, gcc-internal-format
 msgid "declaration of %qD as array of functions"
 msgstr "%qD声明为函数的数组"
 
-#: cp/decl.c:9818
+#: cp/decl.c:9839
 #, gcc-internal-format
 msgid "creating array of functions"
 msgstr "创建函数的数组"
 
-#: cp/decl.c:9823
+#: cp/decl.c:9844
 #, gcc-internal-format
 msgid "declaration of %qD as array of references"
 msgstr "%qD声明为引用的数组"
 
-#: cp/decl.c:9825
+#: cp/decl.c:9846
 #, gcc-internal-format
 msgid "creating array of references"
 msgstr "创建引用的数组"
 
-#: cp/decl.c:9830
+#: cp/decl.c:9851
 #, gcc-internal-format
 msgid "declaration of %qD as array of function members"
 msgstr "%qD声明为函数成员的数组"
 
-#: cp/decl.c:9832
+#: cp/decl.c:9853
 #, gcc-internal-format
 msgid "creating array of function members"
 msgstr "创建函数成员的组织"
 
-#: cp/decl.c:9846
+#: cp/decl.c:9867
 #, gcc-internal-format
 msgid "declaration of %qD as multidimensional array must have bounds for all dimensions except the first"
 msgstr "多维数组%qD的声明必须至少指定除第一维以外所有维的大小"
 
-#: cp/decl.c:9850
+#: cp/decl.c:9871
 #, gcc-internal-format
 msgid "multidimensional array must have bounds for all dimensions except the first"
 msgstr "声明多维数组必须至少指定除第一维以外所有维的大小"
 
-#: cp/decl.c:9909
+#: cp/decl.c:9930
 #, gcc-internal-format
 msgid "return type specification for constructor invalid"
 msgstr "为构造函数指定返回值无效"
 
-#: cp/decl.c:9912
+#: cp/decl.c:9933
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on constructor declaration"
 msgstr "%<operator %T%>的声明中不能使用限定符"
 
-#: cp/decl.c:9922
+#: cp/decl.c:9943
 #, gcc-internal-format
 msgid "return type specification for destructor invalid"
 msgstr "指定析构函数的返回类型无效"
 
-#: cp/decl.c:9925
+#: cp/decl.c:9946
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on destructor declaration"
 msgstr "%<operator %T%>的声明中不能使用限定符"
 
-#: cp/decl.c:9937
+#: cp/decl.c:9958
 #, gcc-internal-format
 msgid "return type specified for %<operator %T%>"
 msgstr "为%<operator %T%>指定了返回值"
 
-#: cp/decl.c:9940
+#: cp/decl.c:9961
 #, gcc-internal-format
 msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgstr "%<operator %T%>的声明中不能使用限定符"
 
-#: cp/decl.c:9948
+#: cp/decl.c:9969
 #, fuzzy, gcc-internal-format
 #| msgid "return type specification for destructor invalid"
 msgid "return type specified for deduction guide"
 msgstr "指定析构函数的返回类型无效"
 
-#: cp/decl.c:9951
+#: cp/decl.c:9972
 #, fuzzy, gcc-internal-format
 #| msgid "qualifiers are not allowed on declaration of %<operator %T%>"
 msgid "qualifiers are not allowed on declaration of deduction guide"
 msgstr "%<operator %T%>的声明中不能使用限定符"
 
-#: cp/decl.c:9955
+#: cp/decl.c:9976
 #, fuzzy, gcc-internal-format
 #| msgid "too many template parameter lists in declaration of %qD"
 msgid "template template parameter %qT in declaration of deduction guide"
 msgstr "%qD声明时模板参数表太多"
 
-#: cp/decl.c:9964
+#: cp/decl.c:9985
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting specifiers in declaration of %qs"
 msgid "decl-specifier in declaration of deduction guide"
 msgstr "%qs的声明中有相互冲突的限定符"
 
-#: cp/decl.c:9985
+#: cp/decl.c:10006
 #, gcc-internal-format
 msgid "unnamed variable or field declared void"
 msgstr "无名变量或字段声明为 void"
 
-#: cp/decl.c:9992
+#: cp/decl.c:10013
 #, gcc-internal-format
 msgid "variable or field declared void"
 msgstr "变量或字段声明为 void"
 
-#: cp/decl.c:10007
+#: cp/decl.c:10028
 #, fuzzy, gcc-internal-format
 #| msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgid "%<inline%> specifier invalid for variable %qD declared at block scope"
 msgstr "在全局作用域外为函数%qs指定%<inline%>无效"
 
-#: cp/decl.c:10013
+#: cp/decl.c:10034
 #, fuzzy, gcc-internal-format
 msgid "inline variables are only available with -std=c++17 or -std=gnu++17"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/decl.c:10268
+#: cp/decl.c:10292
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<::%D%>"
 msgstr "对限定名%<::%D%>的使用无效"
 
-#: cp/decl.c:10271 cp/decl.c:10291
+#: cp/decl.c:10295 cp/decl.c:10315
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%T::%D%>"
 msgstr "对限定名%<%T::%D%>的使用无效"
 
-#: cp/decl.c:10274
+#: cp/decl.c:10298
 #, gcc-internal-format
 msgid "invalid use of qualified-name %<%D::%D%>"
 msgstr "对限定名%<%D::%D%>的使用无效"
 
-#: cp/decl.c:10283
+#: cp/decl.c:10307
 #, gcc-internal-format
 msgid "%q#T is not a class or a namespace"
 msgstr "%q#T 不是一个类或命名空间"
 
-#: cp/decl.c:10305 cp/decl.c:10398 cp/decl.c:10407 cp/decl.c:11970
+#: cp/decl.c:10329 cp/decl.c:10422 cp/decl.c:10431 cp/decl.c:11994
 #, gcc-internal-format
 msgid "declaration of %qD as non-function"
 msgstr "%qD没有声明为一个函数"
 
-#: cp/decl.c:10311
+#: cp/decl.c:10335
 #, gcc-internal-format
 msgid "declaration of %qD as non-member"
 msgstr "%qD未声明为成员"
 
-#: cp/decl.c:10339
+#: cp/decl.c:10363
 #, gcc-internal-format
 msgid "declarator-id missing; using reserved word %qD"
 msgstr "缺少声明标识符：使用了保留字%qD"
 
-#: cp/decl.c:10390
+#: cp/decl.c:10414
 #, gcc-internal-format
 msgid "function definition does not declare parameters"
 msgstr "函数定义未声明形参"
 
-#: cp/decl.c:10415
+#: cp/decl.c:10439
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as %<typedef%>"
 msgstr "形参声明中出现的 typedef 声明无效"
 
-#: cp/decl.c:10420
+#: cp/decl.c:10444
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD as parameter"
 msgstr "声明的形参%qD不存在"
 
-#: cp/decl.c:10454
+#: cp/decl.c:10478
 #, fuzzy, gcc-internal-format
 #| msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgid "%<concept%> cannot appear in a typedef declaration"
 msgstr "%<constexpr%>不能被用于 typedef 声明"
 
-#: cp/decl.c:10460
+#: cp/decl.c:10484
 #, gcc-internal-format
 msgid "%<constexpr%> cannot appear in a typedef declaration"
 msgstr "%<constexpr%>不能被用于 typedef 声明"
 
-#: cp/decl.c:10468
+#: cp/decl.c:10492
 #, gcc-internal-format
 msgid "two or more data types in declaration of %qs"
 msgstr "%qs的声明指定了两个以上的数据类型"
 
-#: cp/decl.c:10474
+#: cp/decl.c:10498
 #, gcc-internal-format
 msgid "conflicting specifiers in declaration of %qs"
 msgstr "%qs的声明中有相互冲突的限定符"
 
-#: cp/decl.c:10515
+#: cp/decl.c:10539
 #, gcc-internal-format
 msgid "ISO C++ does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C++ 不支持单独以 %<complex%> 表示 %<double complex%>"
 
-#: cp/decl.c:10564 cp/decl.c:10567 cp/decl.c:10570
+#: cp/decl.c:10588 cp/decl.c:10591 cp/decl.c:10594
 #, gcc-internal-format
 msgid "ISO C++ forbids declaration of %qs with no type"
 msgstr "ISO C++ 不允许声明无类型的%qs"
 
-#: cp/decl.c:10586
+#: cp/decl.c:10610
 #, fuzzy, gcc-internal-format
 msgid "%<__int%d%> is not supported by this target"
 msgstr "嵌套函数在此目标机上不受支持"
 
-#: cp/decl.c:10592
+#: cp/decl.c:10616
 #, gcc-internal-format
 msgid "ISO C++ does not support %<__int%d%> for %qs"
 msgstr "ISO C++ 对 %2$qs 不支持 %<__int%1$d%>"
 
-#: cp/decl.c:10614 cp/decl.c:10634
+#: cp/decl.c:10638 cp/decl.c:10658
 #, gcc-internal-format
 msgid "%<signed%> or %<unsigned%> invalid for %qs"
 msgstr "为%qs使用%<signed%>或%<unsigned%>无效"
 
-#: cp/decl.c:10616
+#: cp/decl.c:10640
 #, gcc-internal-format
 msgid "%<signed%> and %<unsigned%> specified together for %qs"
 msgstr "为%qs同时给定了%<signed%>和%<unsigned%>"
 
-#: cp/decl.c:10618
+#: cp/decl.c:10642
 #, gcc-internal-format
 msgid "%<long long%> invalid for %qs"
 msgstr "%<long long%>对%qs无效"
 
-#: cp/decl.c:10620
+#: cp/decl.c:10644
 #, gcc-internal-format
 msgid "%<long%> invalid for %qs"
 msgstr "%<long%>对%qs无效"
 
-#: cp/decl.c:10622
+#: cp/decl.c:10646
 #, gcc-internal-format
 msgid "%<short%> invalid for %qs"
 msgstr "%<short%>对%qs无效"
 
-#: cp/decl.c:10624
+#: cp/decl.c:10648
 #, gcc-internal-format
 msgid "%<long%> or %<short%> invalid for %qs"
 msgstr "%<long%>或%<short%>对%qs无效"
 
-#: cp/decl.c:10626
+#: cp/decl.c:10650
 #, gcc-internal-format
 msgid "%<long%>, %<int%>, %<short%>, or %<char%> invalid for %qs"
 msgstr "%<long%>、%<int%>、%<short%>或%<char%>对%qs无效"
 
-#: cp/decl.c:10628
+#: cp/decl.c:10652
 #, gcc-internal-format
 msgid "%<long%> or %<short%> specified with char for %qs"
 msgstr "为 char%qs给定了%<long%>或%<short%>"
 
-#: cp/decl.c:10630
+#: cp/decl.c:10654
 #, gcc-internal-format
 msgid "%<long%> and %<short%> specified together for %qs"
 msgstr "为%qs同时给定了%<long%>和%<short%>"
 
-#: cp/decl.c:10636
+#: cp/decl.c:10660
 #, gcc-internal-format
 msgid "%<short%> or %<long%> invalid for %qs"
 msgstr "%<long%>或%<short%>对%qs无效"
 
-#: cp/decl.c:10644
+#: cp/decl.c:10668
 #, gcc-internal-format
 msgid "long, short, signed or unsigned used invalidly for %qs"
 msgstr "为%qs使用 long、short、signed 或 unsigned 无效"
 
-#: cp/decl.c:10712
+#: cp/decl.c:10736
 #, gcc-internal-format
 msgid "complex invalid for %qs"
 msgstr "对%qs而言无效的复数"
 
-#: cp/decl.c:10751
+#: cp/decl.c:10775
 #, gcc-internal-format
 msgid "template placeholder type %qT must be followed by a simple declarator-id"
 msgstr ""
 
-#: cp/decl.c:10769
+#: cp/decl.c:10793
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD cannot be declared both %<virtual%> and %<static%>"
 msgstr "成员%qD不能既被声明为虚函数，又被声明为静态函数"
 
-#: cp/decl.c:10775
+#: cp/decl.c:10799
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %qD cannot be declared both %<virtual%> and %<constexpr%>"
 msgstr "成员%qD不能既被声明为虚函数，又被声明为静态函数"
 
-#: cp/decl.c:10785
+#: cp/decl.c:10809
 #, gcc-internal-format
 msgid "typedef declaration invalid in parameter declaration"
 msgstr "形参声明中出现的 typedef 声明无效"
 
-#: cp/decl.c:10790
+#: cp/decl.c:10814
 #, gcc-internal-format
 msgid "storage class specified for template parameter %qs"
 msgstr "为模板参数%qs指定了存储类"
 
-#: cp/decl.c:10796
+#: cp/decl.c:10820
 #, gcc-internal-format
 msgid "storage class specifiers invalid in parameter declarations"
 msgstr "为形参声明指定了无效的存储类"
 
-#: cp/decl.c:10800
+#: cp/decl.c:10824
 #, fuzzy, gcc-internal-format
 #| msgid "a parameter cannot be declared %<constexpr%>"
 msgid "a parameter cannot be declared %<concept%>"
 msgstr "形参不能被声明为%<constexpr%>"
 
-#: cp/decl.c:10805
+#: cp/decl.c:10829
 #, gcc-internal-format
 msgid "a parameter cannot be declared %<constexpr%>"
 msgstr "形参不能被声明为%<constexpr%>"
 
-#: cp/decl.c:10815
+#: cp/decl.c:10839
 #, gcc-internal-format
 msgid "%<virtual%> outside class declaration"
 msgstr "%<virtual%>用在类声明以外"
 
-#: cp/decl.c:10825
+#: cp/decl.c:10849
 #, fuzzy, gcc-internal-format
 #| msgid "Warn when an inlined function cannot be inlined"
 msgid "structured binding declaration cannot be %<inline%>"
 msgstr "当内联函数无法被内联时给出警告"
 
-#: cp/decl.c:10828
+#: cp/decl.c:10852
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %<typedef%>"
 msgid "structured binding declaration cannot be %<typedef%>"
 msgstr "%<typedef%>的模板声明"
 
-#: cp/decl.c:10830
+#: cp/decl.c:10854
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "structured binding declaration cannot be %<constexpr%>"
 msgstr "析构函数不能是%<constexpr%>"
 
-#: cp/decl.c:10834
+#: cp/decl.c:10858
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot be %qs"
 msgstr "%q+T先前在此处有过声明"
 
-#: cp/decl.c:10839
+#: cp/decl.c:10863
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "structured binding declaration cannot be %<concept%>"
 msgstr "析构函数不能是%<constexpr%>"
 
-#: cp/decl.c:10845
+#: cp/decl.c:10869
 #, fuzzy, gcc-internal-format
 #| msgid "subscripting array declared %<register%>"
 msgid "structured binding declaration cannot be %<register%>"
 msgstr "按下标访问声明为%<register%>的数组"
 
-#: cp/decl.c:10849
+#: cp/decl.c:10873
 #, gcc-internal-format
 msgid "structured binding declaration cannot be %<static%>"
 msgstr ""
 
-#: cp/decl.c:10853
+#: cp/decl.c:10877
 #, fuzzy, gcc-internal-format
 #| msgid "nested function %qE declared %<extern%>"
 msgid "structured binding declaration cannot be %<extern%>"
 msgstr "嵌套函数%qE被声明为%<extern%>"
 
-#: cp/decl.c:10857
+#: cp/decl.c:10881
 #, fuzzy, gcc-internal-format
 #| msgid "function %qs cannot be declared %<mutable%>"
 msgid "structured binding declaration cannot be %<mutable%>"
 msgstr "函数%qs不能被声明为%<mutable%>"
 
-#: cp/decl.c:10861
+#: cp/decl.c:10885
 #, gcc-internal-format
 msgid "structured binding declaration cannot be C++98 %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10872
+#: cp/decl.c:10896
 #, fuzzy, gcc-internal-format
 msgid "structured binding declaration cannot have type %qT"
 msgstr "%q+T先前在此处有过声明"
 
-#: cp/decl.c:10875
+#: cp/decl.c:10899
 #, gcc-internal-format
 msgid "type must be cv-qualified %<auto%> or reference to cv-qualified %<auto%>"
 msgstr ""
 
-#: cp/decl.c:10906
+#: cp/decl.c:10930
 #, gcc-internal-format
 msgid "multiple storage classes in declaration of %qs"
 msgstr "%qs的声明指定了多个存储类"
 
-#: cp/decl.c:10929
+#: cp/decl.c:10953
 #, gcc-internal-format
 msgid "storage class specified for %qs"
 msgstr "为%qs指定了存储类"
 
-#: cp/decl.c:10933
+#: cp/decl.c:10957
 #, gcc-internal-format
 msgid "storage class specified for parameter %qs"
 msgstr "为形参%qs指定了存储类"
 
-#: cp/decl.c:10946
+#: cp/decl.c:10970
 #, gcc-internal-format
 msgid "nested function %qs declared %<extern%>"
 msgstr "嵌套函数%qs被声明为%<extern%>"
 
-#: cp/decl.c:10950
+#: cp/decl.c:10974
 #, gcc-internal-format
 msgid "top-level declaration of %qs specifies %<auto%>"
 msgstr "在文件层将%qs声明为%<auto%>"
 
-#: cp/decl.c:10957
+#: cp/decl.c:10981
 #, gcc-internal-format
 msgid "function-scope %qs implicitly auto and declared %<__thread%>"
 msgstr "函数作用域的%qs隐式为 auto，却被声明为%<__thread%>"
 
-#: cp/decl.c:10969
+#: cp/decl.c:10993
 #, gcc-internal-format
 msgid "storage class specifiers invalid in friend function declarations"
 msgstr "为友元函数声明指定了无效的存储类"
 
-#: cp/decl.c:11050
+#: cp/decl.c:11074
 #, fuzzy, gcc-internal-format
 #| msgid "multiple storage classes in declaration of %qs"
 msgid "unnecessary parentheses in declaration of %qs"
 msgstr "%qs的声明指定了多个存储类"
 
-#: cp/decl.c:11098
+#: cp/decl.c:11122
 #, fuzzy, gcc-internal-format
 msgid "requires-clause on return type"
 msgstr "%qE属性在类型上被忽略"
 
-#: cp/decl.c:11118
+#: cp/decl.c:11142
 #, fuzzy, gcc-internal-format
 msgid "%qs function uses %<auto%> type specifier without trailing return type"
 msgstr "%qs函数使用了%<auto%>类型限定却没有迟返回类型"
 
-#: cp/decl.c:11121
+#: cp/decl.c:11145
 #, fuzzy, gcc-internal-format
 msgid "deduced return type only available with -std=c++14 or -std=gnu++14"
 msgstr "带作用域的枚举只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/decl.c:11127
+#: cp/decl.c:11151
 #, fuzzy, gcc-internal-format
 msgid "virtual function cannot have deduced return type"
 msgstr "虚函数不能是友元"
 
-#: cp/decl.c:11134
+#: cp/decl.c:11158
 #, fuzzy, gcc-internal-format
 msgid "%qs function with trailing return type has %qT as its type rather than plain %<auto%>"
 msgstr "%qs函数使用迟返回类型%qT作为它的类型，而不是%<auto%>"
 
-#: cp/decl.c:11147
+#: cp/decl.c:11171
 #, fuzzy, gcc-internal-format
 #| msgid "type qualifiers ignored on function return type"
 msgid "deduced class type %qD in function return type"
 msgstr "忽略函数返回类型的类型限定"
 
-#: cp/decl.c:11156
+#: cp/decl.c:11180
 #, fuzzy, gcc-internal-format
 msgid "deduction guide for %qT must have trailing return type"
 msgstr "虚函数不能是友元"
 
-#: cp/decl.c:11169
+#: cp/decl.c:11193
 #, gcc-internal-format
 msgid "trailing return type %qT of deduction guide is not a specialization of %qT"
 msgstr ""
@@ -45867,57 +45912,57 @@
 
 #. Not using maybe_warn_cpp0x because this should
 #. always be an error.
-#: cp/decl.c:11180
+#: cp/decl.c:11204
 #, fuzzy, gcc-internal-format
 msgid "trailing return type only available with -std=c++11 or -std=gnu++11"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/decl.c:11183
+#: cp/decl.c:11207
 #, fuzzy, gcc-internal-format
 msgid "%qs function with trailing return type not declared with %<auto%> type specifier"
 msgstr "%qs函数使用了迟返回类型却未用%<auto%>类型限定声明"
 
-#: cp/decl.c:11212
+#: cp/decl.c:11236
 #, gcc-internal-format
 msgid "%qs declared as function returning a function"
 msgstr "%qs声明为返回一个函数的函数"
 
-#: cp/decl.c:11218
+#: cp/decl.c:11242
 #, gcc-internal-format
 msgid "%qs declared as function returning an array"
 msgstr "%qs声明为返回一个数组的函数"
 
-#: cp/decl.c:11247
+#: cp/decl.c:11271
 #, gcc-internal-format
 msgid "destructor cannot be static member function"
 msgstr "析构函数不能是静态成员函数"
 
-#: cp/decl.c:11248
+#: cp/decl.c:11272
 #, fuzzy, gcc-internal-format
 msgid "constructor cannot be static member function"
 msgstr "析构函数不能是静态成员函数"
 
-#: cp/decl.c:11252
+#: cp/decl.c:11276
 #, gcc-internal-format
 msgid "destructors may not be cv-qualified"
 msgstr "析构函数不能被 cv 限定"
 
-#: cp/decl.c:11253
+#: cp/decl.c:11277
 #, fuzzy, gcc-internal-format
 msgid "constructors may not be cv-qualified"
 msgstr "析构函数不能被 cv 限定"
 
-#: cp/decl.c:11261
+#: cp/decl.c:11285
 #, fuzzy, gcc-internal-format
 msgid "destructors may not be ref-qualified"
 msgstr "析构函数不能被 cv 限定"
 
-#: cp/decl.c:11262
+#: cp/decl.c:11286
 #, fuzzy, gcc-internal-format
 msgid "constructors may not be ref-qualified"
 msgstr "析构函数不能被 cv 限定"
 
-#: cp/decl.c:11280
+#: cp/decl.c:11304
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructors cannot be declared %<virtual%>"
@@ -45924,249 +45969,249 @@
 msgstr "构造函数不能被声明为虚函数"
 
 #. Cannot be both friend and virtual.
-#: cp/decl.c:11295
+#: cp/decl.c:11319
 #, gcc-internal-format
 msgid "virtual functions cannot be friends"
 msgstr "虚函数不能是友元"
 
-#: cp/decl.c:11299
+#: cp/decl.c:11323
 #, gcc-internal-format
 msgid "friend declaration not in class definition"
 msgstr "友元声明不在类定义内"
 
-#: cp/decl.c:11301
+#: cp/decl.c:11325
 #, fuzzy, gcc-internal-format
 msgid "can%'t define friend function %qs in a local class definition"
 msgstr "局部类定义中不能定义友元函数%qs"
 
-#: cp/decl.c:11313
+#: cp/decl.c:11337
 #, fuzzy, gcc-internal-format
 msgid "a conversion function cannot have a trailing return type"
 msgstr "虚函数不能是友元"
 
-#: cp/decl.c:11339
+#: cp/decl.c:11363
 #, gcc-internal-format
 msgid "destructors may not have parameters"
 msgstr "析构函数不能有参数"
 
-#: cp/decl.c:11379
+#: cp/decl.c:11403
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T"
 msgstr "无法声明指向%q#T的指针"
 
-#: cp/decl.c:11392 cp/decl.c:11399
+#: cp/decl.c:11416 cp/decl.c:11423
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T"
 msgstr "无法声明对%q#T的引用"
 
-#: cp/decl.c:11401
+#: cp/decl.c:11425
 #, gcc-internal-format
 msgid "cannot declare pointer to %q#T member"
 msgstr "无法声明指向%q#T成员的指针"
 
-#: cp/decl.c:11430
+#: cp/decl.c:11454
 #, gcc-internal-format
 msgid "cannot declare reference to qualified function type %qT"
 msgstr "不能声明指向限定函数类型%qT的引用"
 
-#: cp/decl.c:11431
+#: cp/decl.c:11455
 #, gcc-internal-format
 msgid "cannot declare pointer to qualified function type %qT"
 msgstr "不能声明指向限定函数类型%qT的指针"
 
-#: cp/decl.c:11504
+#: cp/decl.c:11528
 #, gcc-internal-format
 msgid "cannot declare reference to %q#T, which is not a typedef or a template type argument"
 msgstr "无法声明对%q#T的引用，因为它不是 typedef 或者模板类型实参"
 
-#: cp/decl.c:11574
+#: cp/decl.c:11598
 #, gcc-internal-format
 msgid "template-id %qD used as a declarator"
 msgstr "模板标识符%qD用作声明"
 
-#: cp/decl.c:11599
+#: cp/decl.c:11623
 #, gcc-internal-format
 msgid "member functions are implicitly friends of their class"
 msgstr "成员函数隐式地成为所属类的友元"
 
-#: cp/decl.c:11605
+#: cp/decl.c:11629
 #, gcc-internal-format
 msgid "extra qualification %<%T::%> on member %qs"
 msgstr "有多余的限定%<%T::%>在成员%qs上"
 
-#: cp/decl.c:11635
+#: cp/decl.c:11659
 #, fuzzy, gcc-internal-format
 #| msgid "cannot define member function %<%T::%s%> within %<%T%>"
 msgid "cannot define member function %<%T::%s%> within %qT"
 msgstr "无法定义成员函数%<%T::%s%>，在%<%T%>中"
 
-#: cp/decl.c:11637
+#: cp/decl.c:11661
 #, fuzzy, gcc-internal-format
 msgid "cannot declare member function %<%T::%s%> within %qT"
 msgstr "无法声明成员%<%T::%s%>，在%qT中"
 
-#: cp/decl.c:11645
+#: cp/decl.c:11669
 #, gcc-internal-format
 msgid "cannot declare member %<%T::%s%> within %qT"
 msgstr "无法声明成员%<%T::%s%>，在%qT中"
 
-#: cp/decl.c:11685
+#: cp/decl.c:11709
 #, gcc-internal-format
 msgid "non-parameter %qs cannot be a parameter pack"
 msgstr "非形参%qs不能是一个参数包"
 
-#: cp/decl.c:11693
+#: cp/decl.c:11717
 #, gcc-internal-format
 msgid "data member may not have variably modified type %qT"
 msgstr "数据成员不能具有可变类型%qT"
 
-#: cp/decl.c:11695
+#: cp/decl.c:11719
 #, gcc-internal-format
 msgid "parameter may not have variably modified type %qT"
 msgstr "参数不能具有可变类型%qT"
 
-#: cp/decl.c:11706
+#: cp/decl.c:11730
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> outside class declaration"
 msgstr "%<virtual%>用在类声明以外"
 
-#: cp/decl.c:11709
+#: cp/decl.c:11733
 #, fuzzy, gcc-internal-format
 msgid "%<explicit%> in friend declaration"
 msgstr "%<inline%>用于空声明中"
 
-#: cp/decl.c:11712
+#: cp/decl.c:11736
 #, fuzzy, gcc-internal-format
 msgid "only declarations of constructors and conversion operators can be %<explicit%>"
 msgstr "只有构造函数才能被声明为%<explicit%>"
 
-#: cp/decl.c:11721
+#: cp/decl.c:11745
 #, gcc-internal-format
 msgid "non-member %qs cannot be declared %<mutable%>"
 msgstr "非成员%qs不能被声明为%<mutable%>"
 
-#: cp/decl.c:11726
+#: cp/decl.c:11750
 #, gcc-internal-format
 msgid "non-object member %qs cannot be declared %<mutable%>"
 msgstr "非对象成员%qs不能被声明为%<mutable%>"
 
-#: cp/decl.c:11732
+#: cp/decl.c:11756
 #, gcc-internal-format
 msgid "function %qs cannot be declared %<mutable%>"
 msgstr "函数%qs不能被声明为%<mutable%>"
 
-#: cp/decl.c:11737
+#: cp/decl.c:11761
 #, gcc-internal-format
 msgid "static %qs cannot be declared %<mutable%>"
 msgstr "静态%qs不能被声明为%<mutable%>"
 
-#: cp/decl.c:11742
+#: cp/decl.c:11766
 #, gcc-internal-format
 msgid "const %qs cannot be declared %<mutable%>"
 msgstr "常量%qs不能被声明为%<mutable%>"
 
-#: cp/decl.c:11747
+#: cp/decl.c:11771
 #, fuzzy, gcc-internal-format
 msgid "reference %qs cannot be declared %<mutable%>"
 msgstr "常量%qs不能被声明为%<mutable%>"
 
-#: cp/decl.c:11778
+#: cp/decl.c:11802
 #, fuzzy, gcc-internal-format
 msgid "typedef declared %<auto%>"
 msgstr "typedef%q+D声明为%<inline%>"
 
-#: cp/decl.c:11783
+#: cp/decl.c:11807
 #, gcc-internal-format
 msgid "requires-clause on typedef"
 msgstr ""
 
-#: cp/decl.c:11787
+#: cp/decl.c:11811
 #, gcc-internal-format
 msgid "typedef name may not be a nested-name-specifier"
 msgstr "typedef 名不能是嵌套名指定"
 
-#: cp/decl.c:11813
+#: cp/decl.c:11837
 #, gcc-internal-format
 msgid "ISO C++ forbids nested type %qD with same name as enclosing class"
 msgstr "ISO C++ 不允许嵌类的类型%qD与其所属的类重名"
 
-#: cp/decl.c:11900
+#: cp/decl.c:11924
 #, gcc-internal-format
 msgid "%<inline%> specified for friend class declaration"
 msgstr "友元函数声明中出现了%<inline%>"
 
-#: cp/decl.c:11908
+#: cp/decl.c:11932
 #, gcc-internal-format
 msgid "template parameters cannot be friends"
 msgstr "模板参数不能是友元"
 
-#: cp/decl.c:11910
+#: cp/decl.c:11934
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend class %T::%D%>"
 msgstr "友元声明需要 class，即%<friend class %T::%D%>"
 
-#: cp/decl.c:11914
+#: cp/decl.c:11938
 #, gcc-internal-format
 msgid "friend declaration requires class-key, i.e. %<friend %#T%>"
 msgstr "友元声明需要 class，即%<friend %#T%>"
 
-#: cp/decl.c:11927
+#: cp/decl.c:11951
 #, gcc-internal-format
 msgid "trying to make class %qT a friend of global scope"
 msgstr "试图让%qT成为全局域的友元"
 
-#: cp/decl.c:11947
+#: cp/decl.c:11971
 #, gcc-internal-format
 msgid "invalid qualifiers on non-member function type"
 msgstr "非成员函数类型上的限定符无效"
 
-#: cp/decl.c:11951
+#: cp/decl.c:11975
 #, gcc-internal-format
 msgid "requires-clause on type-id"
 msgstr ""
 
-#: cp/decl.c:11961
+#: cp/decl.c:11985
 #, gcc-internal-format
 msgid "abstract declarator %qT used as declaration"
 msgstr "抽象声明%qT被用作声明"
 
-#: cp/decl.c:11976
+#: cp/decl.c:12000
 #, fuzzy, gcc-internal-format
 msgid "requires-clause on declaration of non-function type %qT"
 msgstr "在返回%qT的函数中，返回语句不带返回值"
 
-#: cp/decl.c:11995
+#: cp/decl.c:12019
 #, gcc-internal-format
 msgid "cannot use %<::%> in parameter declaration"
 msgstr "不能在参数声明中使用%<::%>"
 
-#: cp/decl.c:12001
+#: cp/decl.c:12025
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> parameter not permitted in this context"
 msgstr "形参声明为%<auto%>"
 
-#: cp/decl.c:12003
+#: cp/decl.c:12027
 #, gcc-internal-format
 msgid "parameter declared %<auto%>"
 msgstr "形参声明为%<auto%>"
 
-#: cp/decl.c:12052 cp/parser.c:3270
+#: cp/decl.c:12076 cp/parser.c:3270
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "使用模板名%qE时不带实参表无效"
 
-#: cp/decl.c:12056
+#: cp/decl.c:12080
 #, fuzzy, gcc-internal-format
 msgid "non-static data member declared with placeholder %qT"
 msgstr "非静态数据成员%qE被声明为%<constexpr%>"
 
-#: cp/decl.c:12080
+#: cp/decl.c:12104
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids zero-size array %qD"
 msgid "ISO C++ forbids flexible array member %qs"
 msgstr "ISO C 不允许大小为 0 的数组%qD"
 
-#: cp/decl.c:12083
+#: cp/decl.c:12107
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "ISO C++ forbids flexible array members"
@@ -46173,164 +46218,164 @@
 msgstr "ISO C90 不允许可变数组成员"
 
 #. Something like struct S { int N::j; };
-#: cp/decl.c:12099
+#: cp/decl.c:12123
 #, gcc-internal-format
 msgid "invalid use of %<::%>"
 msgstr "错误地使用了%<::%>"
 
-#: cp/decl.c:12121
+#: cp/decl.c:12145
 #, fuzzy, gcc-internal-format
 msgid "declaration of function %qD in invalid context"
 msgstr "%qD模板声明无效"
 
-#: cp/decl.c:12130
+#: cp/decl.c:12154
 #, fuzzy, gcc-internal-format
 #| msgid "function %qD declared virtual inside a union"
 msgid "function %qD declared %<virtual%> inside a union"
 msgstr "联合成员函数%qD被声明为虚函数"
 
-#: cp/decl.c:12139
+#: cp/decl.c:12163
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be declared virtual, since it is always static"
 msgid "%qD cannot be declared %<virtual%>, since it is always static"
 msgstr "%qD不能声明为虚函数，因为它总是静态的"
 
-#: cp/decl.c:12153
+#: cp/decl.c:12177
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for destructor %qD"
 msgstr "在析构函数%qD中的友元声明需要限定名"
 
-#: cp/decl.c:12160
+#: cp/decl.c:12184
 #, gcc-internal-format
 msgid "declaration of %qD as member of %qT"
 msgstr "%qD声明为%qT的一个成员"
 
-#: cp/decl.c:12166
+#: cp/decl.c:12190
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "a destructor cannot be %<concept%>"
 msgstr "析构函数不能是%<constexpr%>"
 
-#: cp/decl.c:12171
+#: cp/decl.c:12195
 #, gcc-internal-format
 msgid "a destructor cannot be %<constexpr%>"
 msgstr "析构函数不能是%<constexpr%>"
 
-#: cp/decl.c:12177
+#: cp/decl.c:12201
 #, gcc-internal-format
 msgid "expected qualified name in friend declaration for constructor %qD"
 msgstr "在构造函数%qD中的友元声明需要限定名"
 
-#: cp/decl.c:12185
+#: cp/decl.c:12209
 #, fuzzy, gcc-internal-format
 #| msgid "a destructor cannot be %<constexpr%>"
 msgid "a constructor cannot be %<concept%>"
 msgstr "析构函数不能是%<constexpr%>"
 
-#: cp/decl.c:12190
+#: cp/decl.c:12214
 #, fuzzy, gcc-internal-format
 msgid "a concept cannot be a member function"
 msgstr "析构函数不能是静态成员函数"
 
-#: cp/decl.c:12199
+#: cp/decl.c:12223
 #, fuzzy, gcc-internal-format
 msgid "specialization of variable template %qD declared as function"
 msgstr "模板声明%q#D"
 
-#: cp/decl.c:12202
+#: cp/decl.c:12226
 #, fuzzy, gcc-internal-format
 msgid "variable template declared here"
 msgstr "%q+D已在此声明过"
 
-#: cp/decl.c:12257
+#: cp/decl.c:12281
 #, fuzzy, gcc-internal-format
 msgid "field %qD has incomplete type %qT"
 msgstr "%qD类型不完全"
 
-#: cp/decl.c:12262
+#: cp/decl.c:12286
 #, gcc-internal-format
 msgid "name %qT has incomplete type"
 msgstr "名字%qT类型不完全"
 
-#: cp/decl.c:12272
+#: cp/decl.c:12296
 #, gcc-internal-format
 msgid "%qE is neither function nor member function; cannot be declared friend"
 msgstr "%qE既不是函数也不是成员函数；不能声明为友元"
 
-#: cp/decl.c:12318
+#: cp/decl.c:12342
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qE declared %<constexpr%>"
 msgid "static data member %qE declared %<concept%>"
 msgstr "非静态数据成员%qE被声明为%<constexpr%>"
 
-#: cp/decl.c:12322
+#: cp/decl.c:12346
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> static data member %qD must have an initializer"
 msgstr "非静态数据成员%qD具有 Java 类类型"
 
-#: cp/decl.c:12350
+#: cp/decl.c:12374
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qE declared %<constexpr%>"
 msgid "non-static data member %qE declared %<concept%>"
 msgstr "非静态数据成员%qE被声明为%<constexpr%>"
 
-#: cp/decl.c:12354
+#: cp/decl.c:12378
 #, gcc-internal-format
 msgid "non-static data member %qE declared %<constexpr%>"
 msgstr "非静态数据成员%qE被声明为%<constexpr%>"
 
-#: cp/decl.c:12409
+#: cp/decl.c:12433
 #, gcc-internal-format
 msgid "storage class %<auto%> invalid for function %qs"
 msgstr "函数%qs的存储类%<auto%>无效"
 
-#: cp/decl.c:12411
+#: cp/decl.c:12435
 #, gcc-internal-format
 msgid "storage class %<register%> invalid for function %qs"
 msgstr "函数%qs的存储类%<register%>无效"
 
-#: cp/decl.c:12415
+#: cp/decl.c:12439
 #, gcc-internal-format
 msgid "storage class %<__thread%> invalid for function %qs"
 msgstr "函数%qs的存储类%<__thread%>无效"
 
-#: cp/decl.c:12418
+#: cp/decl.c:12442
 #, fuzzy, gcc-internal-format
 msgid "storage class %<thread_local%> invalid for function %qs"
 msgstr "函数%qs的存储类%<__thread%>无效"
 
-#: cp/decl.c:12423
+#: cp/decl.c:12447
 #, fuzzy, gcc-internal-format
 msgid "virt-specifiers in %qs not allowed outside a class definition"
 msgstr "函数定义中不允许出现 asm 指定"
 
-#: cp/decl.c:12434
+#: cp/decl.c:12458
 #, fuzzy, gcc-internal-format
 #| msgid "%<static%> specified invalid for function %qs declared out of global scope"
 msgid "%<static%> specifier invalid for function %qs declared out of global scope"
 msgstr "在全局作用域外为函数%qs指定%<static%>无效"
 
-#: cp/decl.c:12438
+#: cp/decl.c:12462
 #, gcc-internal-format
 msgid "%<inline%> specifier invalid for function %qs declared out of global scope"
 msgstr "在全局作用域外为函数%qs指定%<inline%>无效"
 
-#: cp/decl.c:12446
+#: cp/decl.c:12470
 #, gcc-internal-format
 msgid "virtual non-class function %qs"
 msgstr "虚函数%qs不是类成员"
 
-#: cp/decl.c:12453
+#: cp/decl.c:12477
 #, gcc-internal-format
 msgid "%qs defined in a non-class scope"
 msgstr "%qs定义在在非类作用域中"
 
-#: cp/decl.c:12454
+#: cp/decl.c:12478
 #, fuzzy, gcc-internal-format
 msgid "%qs declared in a non-class scope"
 msgstr "%qs定义在在非类作用域中"
 
-#: cp/decl.c:12489
+#: cp/decl.c:12513
 #, gcc-internal-format
 msgid "cannot declare member function %qD to have static linkage"
 msgstr "不能将成员函数%qD声明为有静态链接"
@@ -46337,78 +46382,78 @@
 
 #. 7.1.1: There can be no static function declarations within a
 #. block.
-#: cp/decl.c:12497
+#: cp/decl.c:12521
 #, gcc-internal-format
 msgid "cannot declare static function inside another function"
 msgstr "不能在另一个函数中声明一个静态函数"
 
-#: cp/decl.c:12533
+#: cp/decl.c:12557
 #, gcc-internal-format
 msgid "%<static%> may not be used when defining (as opposed to declaring) a static data member"
 msgstr "与声明不同，定义静态数据成员时不能使用%<static%>"
 
-#: cp/decl.c:12540
+#: cp/decl.c:12564
 #, gcc-internal-format
 msgid "static member %qD declared %<register%>"
 msgstr "静态成员%qD声明为%<register%>"
 
-#: cp/decl.c:12546
+#: cp/decl.c:12570
 #, gcc-internal-format
 msgid "cannot explicitly declare member %q#D to have extern linkage"
 msgstr "不能显式地将成员%q#D声明为有外部链接"
 
-#: cp/decl.c:12553
+#: cp/decl.c:12577
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of constexpr variable %qD is not a definition"
 msgid "declaration of %<constexpr%> variable %qD is not a definition"
 msgstr "对广义常变量%qD的声明不同时是定义"
 
-#: cp/decl.c:12574
+#: cp/decl.c:12598
 #, gcc-internal-format
 msgid "declaration of %q#D has no initializer"
 msgstr "%q#D声明有缺少初始值设定"
 
-#: cp/decl.c:12585
+#: cp/decl.c:12609
 #, gcc-internal-format
 msgid "%qs initialized and declared %<extern%>"
 msgstr "%qs已初始化，却又被声明为%<extern%>"
 
-#: cp/decl.c:12589
+#: cp/decl.c:12613
 #, gcc-internal-format
 msgid "%qs has both %<extern%> and initializer"
 msgstr "%qs既有%<extern%>又有初始值设定"
 
-#: cp/decl.c:12754
+#: cp/decl.c:12778
 #, fuzzy, gcc-internal-format
 msgid "default argument %qE uses %qD"
 msgstr "默认实参%qE使用了局部变量%qD"
 
-#: cp/decl.c:12757
+#: cp/decl.c:12781
 #, gcc-internal-format
 msgid "default argument %qE uses local variable %qD"
 msgstr "默认实参%qE使用了局部变量%qD"
 
-#: cp/decl.c:12841
+#: cp/decl.c:12865
 #, fuzzy, gcc-internal-format
 msgid "invalid use of cv-qualified type %qT in parameter declaration"
 msgstr "ISO C 不允许前向参数声明"
 
-#: cp/decl.c:12845
+#: cp/decl.c:12869
 #, fuzzy, gcc-internal-format
 msgid "invalid use of type %<void%> in parameter declaration"
 msgstr "对模板类型参数%qT的使用无效"
 
-#: cp/decl.c:12868
+#: cp/decl.c:12892
 #, gcc-internal-format
 msgid "parameter %qD invalidly declared method type"
 msgstr "形参%qD被无效地被声明为具有方法类型"
 
-#: cp/decl.c:12895
+#: cp/decl.c:12919
 #, gcc-internal-format
 msgid "parameter %qD includes pointer to array of unknown bound %qT"
 msgstr "形参%qD包含了指向具有未知边界数组%qT的指针"
 
-#: cp/decl.c:12897
+#: cp/decl.c:12921
 #, gcc-internal-format
 msgid "parameter %qD includes reference to array of unknown bound %qT"
 msgstr "形参%qD包含了指向具有未知边界数组%qT的引用"
@@ -46428,177 +46473,177 @@
 #. or implicitly defined), there's no need to worry about their
 #. existence.  Theoretically, they should never even be
 #. instantiated, but that's hard to forestall.
-#: cp/decl.c:13150
+#: cp/decl.c:13174
 #, gcc-internal-format
 msgid "invalid constructor; you probably meant %<%T (const %T&)%>"
 msgstr "无效的构造函数：您要的可能是%<%T (const %T&)%>"
 
-#: cp/decl.c:13228
+#: cp/decl.c:13252
 #, gcc-internal-format
 msgid "%qD may not be declared within a namespace"
 msgstr "%qD不能在命名空间声明"
 
-#: cp/decl.c:13234
+#: cp/decl.c:13258
 #, gcc-internal-format
 msgid "%qD may not be declared as static"
 msgstr "%qD不能被声明为静态的"
 
-#: cp/decl.c:13261
+#: cp/decl.c:13285
 #, gcc-internal-format
 msgid "%qD must be a nonstatic member function"
 msgstr "%qD必须是一个非静态的成员函数"
 
-#: cp/decl.c:13267
+#: cp/decl.c:13291
 #, gcc-internal-format
 msgid "%qD must be either a non-static member function or a non-member function"
 msgstr "%qD必须是一个非静态成员函数或非成员函数"
 
-#: cp/decl.c:13277
+#: cp/decl.c:13301
 #, gcc-internal-format
 msgid "%qD must have an argument of class or enumerated type"
 msgstr "%qD的实参必须有类或枚举类型"
 
 #. 13.4.0.3
-#: cp/decl.c:13303
+#: cp/decl.c:13327
 #, gcc-internal-format
 msgid "ISO C++ prohibits overloading operator ?:"
 msgstr "ISO C++ 不允许重载 ?: 运算符"
 
 #. Variadic.
-#: cp/decl.c:13314
+#: cp/decl.c:13338
 #, gcc-internal-format
 msgid "%qD must not have variable number of arguments"
 msgstr "%qD不能带可变数量的实参"
 
-#: cp/decl.c:13338
+#: cp/decl.c:13362
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either zero or one argument"
 msgid "%qD must have either zero or one argument"
 msgstr "%qD必须带 0 或 1 个实参"
 
-#: cp/decl.c:13339
+#: cp/decl.c:13363
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take either one or two arguments"
 msgid "%qD must have either one or two arguments"
 msgstr "%qD必须带 1 或 2 个实参"
 
-#: cp/decl.c:13350
+#: cp/decl.c:13374
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its argument"
 msgid "postfix %qD must have %<int%> as its argument"
 msgstr "后缀%qD必须使用%<int%>作为它的参数"
 
-#: cp/decl.c:13351
+#: cp/decl.c:13375
 #, fuzzy, gcc-internal-format
 #| msgid "postfix %qD must take %<int%> as its second argument"
 msgid "postfix %qD must have %<int%> as its second argument"
 msgstr "后缀%qD必须使用%<int%>作为它的第二个参数"
 
-#: cp/decl.c:13361
+#: cp/decl.c:13385
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have no arguments"
 msgstr "%qD带且仅带 2 个实参"
 
-#: cp/decl.c:13362 cp/decl.c:13371
+#: cp/decl.c:13386 cp/decl.c:13395
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly one argument"
 msgid "%qD must have exactly one argument"
 msgstr "%qD带且仅带 1 个实参"
 
-#: cp/decl.c:13372
+#: cp/decl.c:13396
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must take exactly two arguments"
 msgid "%qD must have exactly two arguments"
 msgstr "%qD带且仅带 2 个实参"
 
-#: cp/decl.c:13389 cp/decl.c:13392
+#: cp/decl.c:13413 cp/decl.c:13416
 #, gcc-internal-format
 msgid "%qD cannot have default arguments"
 msgstr "%qD不能有默认参数"
 
-#: cp/decl.c:13419
+#: cp/decl.c:13443
 #, gcc-internal-format
 msgid "conversion to a reference to void will never use a type conversion operator"
 msgstr "向指向 void 的引用的转换永远不会用到类型转换运算符"
 
-#: cp/decl.c:13421
+#: cp/decl.c:13445
 #, gcc-internal-format
 msgid "conversion to void will never use a type conversion operator"
 msgstr "向 void 的转换永远不会用到类型转换运算符"
 
-#: cp/decl.c:13428
+#: cp/decl.c:13452
 #, gcc-internal-format
 msgid "conversion to a reference to the same type will never use a type conversion operator"
 msgstr "向具有相同类型的引用的转换永远不会用到类型转换运算符"
 
-#: cp/decl.c:13430
+#: cp/decl.c:13454
 #, gcc-internal-format
 msgid "conversion to the same type will never use a type conversion operator"
 msgstr "向相同类型的转换永远不会用到类型转换运算符"
 
-#: cp/decl.c:13438
+#: cp/decl.c:13462
 #, gcc-internal-format
 msgid "conversion to a reference to a base class will never use a type conversion operator"
 msgstr "向指向基类的引用的转换永远不会用到类型转换运算符"
 
-#: cp/decl.c:13440
+#: cp/decl.c:13464
 #, gcc-internal-format
 msgid "conversion to a base class will never use a type conversion operator"
 msgstr "向基类的转换永远不会用到类型转换运算符"
 
-#: cp/decl.c:13455
+#: cp/decl.c:13479
 #, gcc-internal-format
 msgid "user-defined %qD always evaluates both arguments"
 msgstr "用户定义的%qD总是计算所有两个参数"
 
-#: cp/decl.c:13474
+#: cp/decl.c:13498
 #, gcc-internal-format
 msgid "prefix %qD should return %qT"
 msgstr "前缀%qD应当返回%qT"
 
-#: cp/decl.c:13480
+#: cp/decl.c:13504
 #, gcc-internal-format
 msgid "postfix %qD should return %qT"
 msgstr "后缀%qD应当返回%qT"
 
-#: cp/decl.c:13492
+#: cp/decl.c:13516
 #, gcc-internal-format
 msgid "%qD should return by value"
 msgstr "%qD应当返回值而非引用"
 
-#: cp/decl.c:13547
+#: cp/decl.c:13571
 #, gcc-internal-format
 msgid "using template type parameter %qT after %qs"
 msgstr "使用模板类型形参%qT，在%qs后"
 
-#: cp/decl.c:13570
+#: cp/decl.c:13594
 #, fuzzy, gcc-internal-format
 msgid "using alias template specialization %qT after %qs"
 msgstr "使用模板类型形参%qT，在%qs后"
 
-#: cp/decl.c:13573
+#: cp/decl.c:13597
 #, gcc-internal-format
 msgid "using typedef-name %qD after %qs"
 msgstr "使用 typedef 名%qD，在%qs后"
 
-#: cp/decl.c:13575
+#: cp/decl.c:13599
 #, fuzzy, gcc-internal-format
 msgid "%qD has a previous declaration here"
 msgstr "%q+T先前在此处有过声明"
 
-#: cp/decl.c:13583
+#: cp/decl.c:13607
 #, gcc-internal-format
 msgid "%qT referred to as %qs"
 msgstr "%qT作为%qs被引用"
 
-#: cp/decl.c:13584 cp/decl.c:13591
+#: cp/decl.c:13608 cp/decl.c:13615
 #, fuzzy, gcc-internal-format
 #| msgid "%q+T has a previous declaration here"
 msgid "%qT has a previous declaration here"
 msgstr "%q+T先前在此处有过声明"
 
-#: cp/decl.c:13590
+#: cp/decl.c:13614
 #, gcc-internal-format
 msgid "%qT referred to as enum"
 msgstr "%qT作为枚举被引用"
@@ -46610,95 +46655,95 @@
 #. void f(class C);		// No template header here
 #.
 #. then the required template argument is missing.
-#: cp/decl.c:13605
+#: cp/decl.c:13629
 #, gcc-internal-format
 msgid "template argument required for %<%s %T%>"
 msgstr "%<%s %T%>需要模板参数"
 
-#: cp/decl.c:13659 cp/name-lookup.c:4652
+#: cp/decl.c:13683 cp/name-lookup.c:4652
 #, gcc-internal-format
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD与其声明所在的类重名"
 
-#: cp/decl.c:13689 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6425
-#: cp/pt.c:9209
+#: cp/decl.c:13713 cp/friend.c:301 cp/parser.c:3096 cp/parser.c:6428
+#: cp/pt.c:9223
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT不是一个模板"
 
-#: cp/decl.c:13694
+#: cp/decl.c:13718
 #, gcc-internal-format
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:13703 cp/name-lookup.c:4079 cp/name-lookup.c:4086
-#: cp/name-lookup.c:4939 cp/parser.c:6376 cp/parser.c:26300
+#: cp/decl.c:13727 cp/name-lookup.c:4079 cp/name-lookup.c:4086
+#: cp/name-lookup.c:4939 cp/parser.c:6379 cp/parser.c:26297
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "对%qD的引用有歧义"
 
-#: cp/decl.c:13806
+#: cp/decl.c:13830
 #, gcc-internal-format
 msgid "use of enum %q#D without previous declaration"
 msgstr "使用枚举%q#D前没有给出声明"
 
-#: cp/decl.c:13842
+#: cp/decl.c:13866
 #, gcc-internal-format
 msgid "redeclaration of %qT as a non-template"
 msgstr "%qT重声明为非模板"
 
-#: cp/decl.c:13982
+#: cp/decl.c:14006
 #, gcc-internal-format
 msgid "derived union %qT invalid"
 msgstr "派生联合%qT无效"
 
-#: cp/decl.c:13989
+#: cp/decl.c:14013
 #, fuzzy, gcc-internal-format
 msgid "%qT defined with multiple direct bases"
 msgstr "此函数中的%qD在使用前未初始化"
 
-#: cp/decl.c:14000
+#: cp/decl.c:14024
 #, fuzzy, gcc-internal-format
 #| msgid "type %qT is not a direct or virtual base of %qT"
 msgid "%qT defined with direct virtual base"
 msgstr "类型%qT不是%qT的直接或虚基类"
 
-#: cp/decl.c:14025
+#: cp/decl.c:14049
 #, gcc-internal-format
 msgid "base type %qT fails to be a struct or class type"
 msgstr "基类型%qT不是结构或类"
 
-#: cp/decl.c:14055
+#: cp/decl.c:14079
 #, gcc-internal-format
 msgid "recursive type %qT undefined"
 msgstr "递归的类型%qT未定义"
 
-#: cp/decl.c:14057
+#: cp/decl.c:14081
 #, gcc-internal-format
 msgid "duplicate base type %qT invalid"
 msgstr "重复的基类型%qT无效"
 
-#: cp/decl.c:14202
+#: cp/decl.c:14226
 #, fuzzy, gcc-internal-format
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr "范围/unscoped 不匹配在中 enum %q#T"
 
-#: cp/decl.c:14205 cp/decl.c:14213 cp/decl.c:14225 cp/parser.c:18284
+#: cp/decl.c:14229 cp/decl.c:14237 cp/decl.c:14249 cp/parser.c:18281
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "先前的定义在这里"
 
-#: cp/decl.c:14210
+#: cp/decl.c:14234
 #, fuzzy, gcc-internal-format
 msgid "underlying type mismatch in enum %q#T"
 msgstr "条件表达式中类型不匹配"
 
-#: cp/decl.c:14222
+#: cp/decl.c:14246
 #, fuzzy, gcc-internal-format
 msgid "different underlying type in enum %q#T"
 msgstr "不同的下层的输入 enum %q#T"
 
-#: cp/decl.c:14300
+#: cp/decl.c:14324
 #, fuzzy, gcc-internal-format
 #| msgid "underlying type %<%T%> of %<%T%> must be an integral type"
 msgid "underlying type %qT of %qT must be an integral type"
@@ -46708,78 +46753,78 @@
 #.
 #. IF no integral type can represent all the enumerator values, the
 #. enumeration is ill-formed.
-#: cp/decl.c:14447
+#: cp/decl.c:14471
 #, gcc-internal-format
 msgid "no integral type can represent all of the enumerator values for %qT"
 msgstr "没有一个整数类型可以表示%qT的所有枚举值"
 
-#: cp/decl.c:14619
+#: cp/decl.c:14643
 #, fuzzy, gcc-internal-format
 #| msgid "enumerator value for %qD is not an integer constant"
 msgid "enumerator value for %qD must have integral or unscoped enumeration type"
 msgstr "%qD的枚举值不是一个整数常量"
 
-#: cp/decl.c:14629
+#: cp/decl.c:14653
 #, gcc-internal-format
 msgid "enumerator value for %qD is not an integer constant"
 msgstr "%qD的枚举值不是一个整数常量"
 
-#: cp/decl.c:14678
+#: cp/decl.c:14702
 #, fuzzy, gcc-internal-format
 msgid "incremented enumerator value is too large for %<unsigned long%>"
 msgstr "对%<unsigned long%>类型而言整数常量太大"
 
-#: cp/decl.c:14679
+#: cp/decl.c:14703
 #, fuzzy, gcc-internal-format
 msgid "incremented enumerator value is too large for %<long%>"
 msgstr "对%<unsigned long%>类型而言整数常量太大"
 
-#: cp/decl.c:14690
+#: cp/decl.c:14714
 #, gcc-internal-format
 msgid "overflow in enumeration values at %qD"
 msgstr "%qD处枚举值溢出"
 
-#: cp/decl.c:14710
+#: cp/decl.c:14734
 #, fuzzy, gcc-internal-format
 msgid "enumerator value %qE is outside the range of underlying type %qT"
 msgstr "枚举值 %E 对其类型%<%T%>而言太大了"
 
-#: cp/decl.c:14821
+#: cp/decl.c:14845
 #, gcc-internal-format
 msgid "return type %q#T is incomplete"
 msgstr "返回值类型%q#T不完全"
 
-#: cp/decl.c:14999 cp/typeck.c:9286
+#: cp/decl.c:15023 cp/typeck.c:9286
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%>应当返回一个对%<*this%>的引用"
 
-#: cp/decl.c:15344
+#: cp/decl.c:15368
 #, gcc-internal-format
 msgid "invalid function declaration"
 msgstr "无效的函数声明"
 
-#: cp/decl.c:15786
+#: cp/decl.c:15810
 #, fuzzy, gcc-internal-format
 msgid "no return statements in function returning %qT"
 msgstr "在返回%qT的函数中，返回语句不带返回值"
 
-#: cp/decl.c:15788 cp/typeck.c:9166
+#: cp/decl.c:15812 cp/typeck.c:9166
 #, fuzzy, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "由于%<volatile%>，函数返回类型不兼容"
 
-#: cp/decl.c:15996
+#: cp/decl.c:16020
 #, gcc-internal-format
 msgid "invalid member function declaration"
 msgstr "无效的成员函数声明"
 
-#: cp/decl.c:16010
+#: cp/decl.c:16034
 #, gcc-internal-format
 msgid "%qD is already defined in class %qT"
 msgstr "%qD已在类%qT中定义过"
 
-#: cp/decl.c:16386
+#: cp/decl.c:16410
 #, fuzzy, gcc-internal-format
 msgid "use of %qD before deduction of %<auto%>"
 msgstr "%qD的类型默认为%<int%>"
@@ -46819,7 +46864,7 @@
 msgid "deleting %qT is undefined"
 msgstr "删除%qT未定义"
 
-#: cp/decl2.c:585 cp/pt.c:5552
+#: cp/decl2.c:585 cp/pt.c:5566
 #, gcc-internal-format
 msgid "template declaration of %q#D"
 msgstr "%q#D声明为模板"
@@ -46832,7 +46877,7 @@
 #. [temp.mem]
 #.
 #. A destructor shall not be a member template.
-#: cp/decl2.c:640 cp/pt.c:5511
+#: cp/decl2.c:640 cp/pt.c:5525
 #, gcc-internal-format
 msgid "destructor %qD declared as member template"
 msgstr "析构函数%qD被声明为一个成员模板"
@@ -47012,51 +47057,51 @@
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "%<operator delete%>的第一个形参类型为%qT"
 
-#: cp/decl2.c:2660
+#: cp/decl2.c:2650
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgid "%qT has a field %qD whose type has no linkage"
 msgstr "%qT有一个字段%qD使用匿名命名空间"
 
-#: cp/decl2.c:2664
+#: cp/decl2.c:2654
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr "%qT有一个字段%qD使用匿名命名空间"
 
-#: cp/decl2.c:2669
+#: cp/decl2.c:2659
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr "%qT有一个字段%qD使用匿名命名空间"
 
-#: cp/decl2.c:2677
+#: cp/decl2.c:2667
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr "%qT被声明为比其字段%qD的类型有更高的可见性"
 
-#: cp/decl2.c:2695
+#: cp/decl2.c:2685
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgid "%qT has a base %qT whose type has no linkage"
 msgstr "%qT有一个基类%qT使用匿名命名空间"
 
-#: cp/decl2.c:2699
+#: cp/decl2.c:2689
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgid "%qT has a base %qT whose type depends on the type %qT which has no linkage"
 msgstr "%qT有一个基类%qT使用匿名命名空间"
 
-#: cp/decl2.c:2704
+#: cp/decl2.c:2694
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr "%qT有一个基类%qT使用匿名命名空间"
 
-#: cp/decl2.c:2711
+#: cp/decl2.c:2701
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr "%qT被声明为比其基类%qT有更高的可见性"
 
-#: cp/decl2.c:4309
+#: cp/decl2.c:4299
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using unnamed type, is used but never defined"
 msgstr "%q+#D声明为具有匿名类型，在使用前未被定义"
@@ -47065,63 +47110,63 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4318
+#: cp/decl2.c:4308
 #, fuzzy, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr "匿名类型不具任何链结用来声明变量 %q#D 与链结"
 
-#: cp/decl2.c:4322
+#: cp/decl2.c:4312
 #, fuzzy, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr "匿名类型不具任何链结用来声明函数 %q#D 与链结"
 
-#: cp/decl2.c:4326
+#: cp/decl2.c:4316
 #, fuzzy, gcc-internal-format
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr "%q+#D未指明非限定类型，所以它不被用作外部链接"
 
-#: cp/decl2.c:4334
+#: cp/decl2.c:4324
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "%q+#D声明为具有局部类型%qT，在使用前未被定义"
 
-#: cp/decl2.c:4338
+#: cp/decl2.c:4328
 #, fuzzy, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr "constexpr 变量%2$qD的类型%1$qT不是字面常量"
 
-#: cp/decl2.c:4341
+#: cp/decl2.c:4331
 #, fuzzy, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "%q+#D的早先声明有%qL链接"
 
-#: cp/decl2.c:4529
+#: cp/decl2.c:4519
 #, fuzzy, gcc-internal-format
 msgid "mangling of %q#D as %qE conflicts with a previous mangle"
 msgstr "%q+D的节与早先的声明冲突"
 
-#: cp/decl2.c:4532
+#: cp/decl2.c:4522
 #, fuzzy, gcc-internal-format
 msgid "previous mangling %q#D"
 msgstr "先前的声明%q+D"
 
-#: cp/decl2.c:4534
+#: cp/decl2.c:4524
 #, fuzzy, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr "-fabi-version=4 (or =0) 可以改变向量修饰来避免这个错误"
 
-#: cp/decl2.c:4606 cp/decl2.c:4609
+#: cp/decl2.c:4596 cp/decl2.c:4599
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.c:4956
+#: cp/decl2.c:4946
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D used but never defined"
 msgid "inline function %qD used but never defined"
 msgstr "使用了内联函数%q+D但从未定义过"
 
-#: cp/decl2.c:5143
+#: cp/decl2.c:5133
 #, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr "%2$q+#D的第 %1$P 个形参缺少默认实参"
@@ -47128,18 +47173,18 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5251
+#: cp/decl2.c:5241
 #, fuzzy, gcc-internal-format
 #| msgid "converting lambda which uses %<...%> to function pointer"
 msgid "converting lambda that uses %<...%> to function pointer"
 msgstr "将使用了%<...%>的 Lambda 转换为函数指针"
 
-#: cp/decl2.c:5254
+#: cp/decl2.c:5244
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "使用了被删除的函数%qD"
 
-#: cp/decl2.c:5307
+#: cp/decl2.c:5297
 #, gcc-internal-format
 msgid "use of built-in parameter pack %qD outside of a template"
 msgstr ""
@@ -47426,338 +47471,338 @@
 msgid "recursive instantiation of default member initializer for %qD"
 msgstr "对非静态数据成员%q+D的无效使用"
 
-#: cp/init.c:613
+#: cp/init.c:629
 #, gcc-internal-format
 msgid "default member initializer for %qD required before the end of its enclosing class"
 msgstr ""
 
-#: cp/init.c:615
+#: cp/init.c:631
 #, fuzzy, gcc-internal-format
 #| msgid "union defined here"
 msgid "defined here"
 msgstr "联合在此定义"
 
-#: cp/init.c:673
+#: cp/init.c:689
 #, fuzzy, gcc-internal-format
 msgid "initializer for flexible array member %q#D"
 msgstr "成员函数%q+#D的抽象返回类型无效"
 
-#: cp/init.c:699
+#: cp/init.c:715
 #, gcc-internal-format
 msgid "%qD should be initialized in the member initialization list"
 msgstr "%qD应该在成员初始化列表中被初始化"
 
-#: cp/init.c:720
+#: cp/init.c:736
 #, fuzzy, gcc-internal-format
 msgid "%qD is initialized with itself"
 msgstr "形参%qD已初始化"
 
-#: cp/init.c:831
+#: cp/init.c:847
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer for array member %q#D"
 msgstr "成员函数%q+#D的抽象返回类型无效"
 
-#: cp/init.c:845 cp/init.c:869 cp/init.c:2410 cp/method.c:1368
+#: cp/init.c:861 cp/init.c:885 cp/init.c:2427 cp/method.c:1368
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr "%<new%>%q#T时常量未初始化"
 
-#: cp/init.c:847 cp/init.c:864 cp/init.c:871 cp/init.c:2395 cp/init.c:2423
+#: cp/init.c:863 cp/init.c:880 cp/init.c:887 cp/init.c:2412 cp/init.c:2440
 #: cp/method.c:1371 cp/method.c:1382
 #, fuzzy, gcc-internal-format
 msgid "%q#D should be initialized"
 msgstr "%q+D将在"
 
-#: cp/init.c:862 cp/init.c:2382 cp/method.c:1379
+#: cp/init.c:878 cp/init.c:2399 cp/method.c:1379
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr "%q#T中有未初始化的引用成员"
 
-#: cp/init.c:1041
+#: cp/init.c:1057
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D will be initialized after"
 msgid "%qD will be initialized after"
 msgstr "%q+D将在"
 
-#: cp/init.c:1044
+#: cp/init.c:1060
 #, gcc-internal-format
 msgid "base %qT will be initialized after"
 msgstr "基类%qT将在"
 
-#: cp/init.c:1048
+#: cp/init.c:1064
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D"
 msgid "  %q#D"
 msgstr "%q+#D"
 
-#: cp/init.c:1050
+#: cp/init.c:1066
 #, gcc-internal-format
 msgid "  base %qT"
 msgstr "基类%qT"
 
-#: cp/init.c:1052
+#: cp/init.c:1068
 #, gcc-internal-format
 msgid "  when initialized here"
 msgstr "在此处初始化后被初始化"
 
-#: cp/init.c:1069
+#: cp/init.c:1085
 #, gcc-internal-format
 msgid "multiple initializations given for %qD"
 msgstr "为%qD给定了多个初始值设定"
 
-#: cp/init.c:1073
+#: cp/init.c:1089
 #, gcc-internal-format
 msgid "multiple initializations given for base %qT"
 msgstr "为基类%qT给定了多个初始值设定"
 
-#: cp/init.c:1158
+#: cp/init.c:1174
 #, gcc-internal-format
 msgid "initializations for multiple members of %qT"
 msgstr "初始化%qT的多个成员"
 
-#: cp/init.c:1255
+#: cp/init.c:1271
 #, gcc-internal-format
 msgid "base class %q#T should be explicitly initialized in the copy constructor"
 msgstr "基类%q#T应该在复制构造函数中显式地初始化"
 
-#: cp/init.c:1482 cp/init.c:1501
+#: cp/init.c:1498 cp/init.c:1517
 #, gcc-internal-format
 msgid "class %qT does not have any field named %qD"
 msgstr "类%qT没有名为%qD的字段"
 
-#: cp/init.c:1488
+#: cp/init.c:1504
 #, gcc-internal-format
 msgid "%q#D is a static data member; it can only be initialized at its definition"
 msgstr "%q#D是一个静态数据成员；它只能在定义时被初始化"
 
-#: cp/init.c:1495
+#: cp/init.c:1511
 #, gcc-internal-format
 msgid "%q#D is not a non-static data member of %qT"
 msgstr "%q#D不是%qT的非静态数据成员"
 
-#: cp/init.c:1534
+#: cp/init.c:1550
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which has no base classes"
 msgstr "对没有基类的%qT的无名初始化"
 
-#: cp/init.c:1542
+#: cp/init.c:1558
 #, gcc-internal-format
 msgid "unnamed initializer for %qT, which uses multiple inheritance"
 msgstr "对使用了多继承的%qT的无名初始化"
 
-#: cp/init.c:1589
+#: cp/init.c:1605
 #, gcc-internal-format
 msgid "%qD is both a direct base and an indirect virtual base"
 msgstr "%qD既是一个直接基类又是一个间接虚基类"
 
-#: cp/init.c:1597
+#: cp/init.c:1613
 #, gcc-internal-format
 msgid "type %qT is not a direct or virtual base of %qT"
 msgstr "类型%qT不是%qT的直接或虚基类"
 
-#: cp/init.c:1600
+#: cp/init.c:1616
 #, gcc-internal-format
 msgid "type %qT is not a direct base of %qT"
 msgstr "类型%qT不是%qT的直接基类"
 
-#: cp/init.c:1710 cp/init.c:4386 cp/typeck2.c:1175
+#: cp/init.c:1727 cp/init.c:4402 cp/typeck2.c:1175
 #, gcc-internal-format
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "数组必须为一个由花括号包围的初始值设定所初始化"
 
-#: cp/init.c:2019 cp/semantics.c:3268
+#: cp/init.c:2036 cp/semantics.c:3271
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qT不是一个类"
 
-#: cp/init.c:2075
+#: cp/init.c:2092
 #, gcc-internal-format
 msgid "incomplete type %qT does not have member %qD"
 msgstr "不完全类型%qT没有成员%qD"
 
-#: cp/init.c:2089
+#: cp/init.c:2106
 #, gcc-internal-format
 msgid "invalid pointer to bit-field %qD"
 msgstr "指向位段%qD指针无效"
 
-#: cp/init.c:2175 cp/typeck.c:1893
+#: cp/init.c:2192 cp/typeck.c:1893
 #, gcc-internal-format
 msgid "invalid use of non-static member function %qD"
 msgstr "对非静态成员函数%qD的使用无效"
 
-#: cp/init.c:2182 cp/semantics.c:1835
+#: cp/init.c:2199 cp/semantics.c:1835
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "对非静态数据成员%qD的无效使用"
 
-#: cp/init.c:2379
+#: cp/init.c:2396
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in %q#T using %<new%> without new-initializer"
 msgstr "未初始化的引用成员%qD"
 
-#: cp/init.c:2387
+#: cp/init.c:2404
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "未初始化的引用成员%qD"
 
-#: cp/init.c:2391
+#: cp/init.c:2408
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in base %q#T of %q#T"
 msgstr "%q#T中有未初始化的引用成员"
 
-#: cp/init.c:2407
+#: cp/init.c:2424
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in %q#T using %<new%> without new-initializer"
 msgstr "%<new%>%q#T时常量未初始化"
 
-#: cp/init.c:2415
+#: cp/init.c:2432
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T using %<new%> without new-initializer"
 msgstr "%<new%>%q#T时常量未初始化"
 
-#: cp/init.c:2419
+#: cp/init.c:2436
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in base %q#T of %q#T"
 msgstr "%q#T中有未初始化的引用成员"
 
-#: cp/init.c:2710
+#: cp/init.c:2727
 #, gcc-internal-format
 msgid "placement new constructing an object of type %<%T [%wu]%> and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2721
+#: cp/init.c:2738
 #, gcc-internal-format
 msgid "placement new constructing an array of objects of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2732
+#: cp/init.c:2749
 #, gcc-internal-format
 msgid "placement new constructing an object of type %qT and size %qwu in a region of type %qT and size %qwi"
 msgstr ""
 
-#: cp/init.c:2880
+#: cp/init.c:2896
 #, fuzzy, gcc-internal-format
 msgid "integer overflow in array size"
 msgstr "表达式中整复数溢出"
 
-#: cp/init.c:2890
+#: cp/init.c:2906
 #, fuzzy, gcc-internal-format
 msgid "array size in new-expression must be constant"
 msgstr "数组 new 的大小必须有整数类型"
 
-#: cp/init.c:2904
+#: cp/init.c:2920
 #, fuzzy, gcc-internal-format
 msgid "variably modified type not allowed in new-expression"
 msgstr "文件域中的动态可变字段"
 
-#: cp/init.c:2920
+#: cp/init.c:2936
 #, gcc-internal-format
 msgid "non-constant array new length must be specified directly, not by typedef"
 msgstr ""
 
-#: cp/init.c:2922
+#: cp/init.c:2938
 #, fuzzy, gcc-internal-format
 #| msgid "try removing the parentheses around the type-id"
 msgid "non-constant array new length must be specified without parentheses around the type-id"
 msgstr "请尝试删除类型标识符两边的括号"
 
-#: cp/init.c:2932
+#: cp/init.c:2948
 #, gcc-internal-format
 msgid "invalid type %<void%> for new"
 msgstr "对 new 而言类型%<void%>无效"
 
-#: cp/init.c:2975
+#: cp/init.c:2991
 #, gcc-internal-format
 msgid "uninitialized const in %<new%> of %q#T"
 msgstr "%<new%>%q#T时常量未初始化"
 
-#: cp/init.c:3101
+#: cp/init.c:3117
 #, gcc-internal-format
 msgid "no suitable %qD found in class %qT"
 msgstr "找不到合适的%qD，在类%qT中"
 
-#: cp/init.c:3108 cp/search.c:1023
+#: cp/init.c:3124 cp/search.c:1026
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous"
 msgstr "对成员%qD的请求有歧义"
 
-#: cp/init.c:3181
+#: cp/init.c:3197
 #, gcc-internal-format
 msgid "%<new%> of type %qT with extended alignment %d"
 msgstr ""
 
-#: cp/init.c:3184
+#: cp/init.c:3200
 #, fuzzy, gcc-internal-format
 #| msgid "class %qT does not have any field named %qD"
 msgid "uses %qD, which does not have an alignment parameter"
 msgstr "类%qT没有名为%qD的字段"
 
-#: cp/init.c:3187
+#: cp/init.c:3203
 #, gcc-internal-format
 msgid "use %<-faligned-new%> to enable C++17 over-aligned new support"
 msgstr ""
 
-#: cp/init.c:3370
+#: cp/init.c:3386
 #, fuzzy, gcc-internal-format
 msgid "parenthesized initializer in array new"
 msgstr "括起的初始值设定后出现的属性被忽略"
 
-#: cp/init.c:3633
+#: cp/init.c:3649
 #, gcc-internal-format
 msgid "size in array new must have integral type"
 msgstr "数组 new 的大小必须有整数类型"
 
-#: cp/init.c:3665
+#: cp/init.c:3681
 #, gcc-internal-format
 msgid "new cannot be applied to a reference type"
 msgstr "new 不能用于引用类型"
 
-#: cp/init.c:3674
+#: cp/init.c:3690
 #, gcc-internal-format
 msgid "new cannot be applied to a function type"
 msgstr "new 不能用于函数类型"
 
-#: cp/init.c:3743
+#: cp/init.c:3759
 #, fuzzy, gcc-internal-format
 msgid "possible problem detected in invocation of delete [] operator:"
 msgstr "检测到调用 delete 运算符时可能出现的问题："
 
-#: cp/init.c:3747
+#: cp/init.c:3763
 #, fuzzy, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete [] will be called, even if they are declared when the class is defined"
 msgstr "析构函数和类特定的 delete 运算符均不会被调用，即使它们在类定义时已经声明。"
 
-#: cp/init.c:4295
+#: cp/init.c:4311
 #, gcc-internal-format
 msgid "initializer ends prematurely"
 msgstr "初始值设定在完成之前结束"
 
-#: cp/init.c:4599
+#: cp/init.c:4615
 #, gcc-internal-format
 msgid "unknown array size in delete"
 msgstr "delete 时数组大小未知"
 
-#: cp/init.c:4623
+#: cp/init.c:4639
 #, gcc-internal-format
 msgid "possible problem detected in invocation of delete operator:"
 msgstr "检测到调用 delete 运算符时可能出现的问题："
 
-#: cp/init.c:4628
+#: cp/init.c:4644
 #, fuzzy, gcc-internal-format
 msgid "neither the destructor nor the class-specific operator delete will be called, even if they are declared when the class is defined"
 msgstr "析构函数和类特定的 delete 运算符均不会被调用，即使它们在类定义时已经声明。"
 
-#: cp/init.c:4642
+#: cp/init.c:4658
 #, fuzzy, gcc-internal-format
 msgid "deleting object of abstract class type %qT which has non-virtual destructor will cause undefined behavior"
 msgstr "删除对象的抽象类别类型 %qT 该项有 non-virtual 解构式将造成未定义的行为"
 
-#: cp/init.c:4647
+#: cp/init.c:4663
 #, fuzzy, gcc-internal-format
 msgid "deleting object of polymorphic class type %qT which has non-virtual destructor might cause undefined behavior"
 msgstr "删除对象的 polymorphic 类别类型 %qT 该项有 non-virtual 解构式也许造成未定义的行为"
 
-#: cp/init.c:4954
+#: cp/init.c:4970
 #, gcc-internal-format
 msgid "type to vector delete is neither pointer or array type"
 msgstr "向量 delete 的实参类型既非指针也非数组"
@@ -48245,7 +48290,7 @@
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "%qs(有%qT)的实参类型无效"
 
-#: cp/name-lookup.c:5111 cp/name-lookup.c:7065
+#: cp/name-lookup.c:5111 cp/name-lookup.c:7073
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "指定%qD属性被忽略"
@@ -48295,57 +48340,57 @@
 msgid "it was later defined here"
 msgstr "结构在此定义"
 
-#: cp/name-lookup.c:6687
+#: cp/name-lookup.c:6695
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<std::initializer_list%> does not match %<#include <initializer_list>%>, isn't a template"
 msgstr "从花括号中的初始化列表演绎需要 #include <initializer_list>"
 
-#: cp/name-lookup.c:7059
+#: cp/name-lookup.c:7067
 #, fuzzy, gcc-internal-format
 #| msgid "switch %qs is no longer supported"
 msgid "strong using directive no longer supported"
 msgstr "开关%qs不再被支持"
 
-#: cp/name-lookup.c:7062
+#: cp/name-lookup.c:7070
 #, gcc-internal-format
 msgid "you may use an inline namespace instead"
 msgstr ""
 
-#: cp/name-lookup.c:7079
+#: cp/name-lookup.c:7087
 #, fuzzy, gcc-internal-format
 #| msgid "attributes ignored on uninstantiated type"
 msgid "attributes ignored on local using directive"
 msgstr "属性在未初始化类型上被忽略"
 
-#: cp/name-lookup.c:7163
+#: cp/name-lookup.c:7171
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "这里不允许命名空间别名%qD，假定为%qD"
 
 #. We only allow depth 255.
-#: cp/name-lookup.c:7183
+#: cp/name-lookup.c:7191
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qD may not be declared within a namespace"
 msgid "cannot nest more than %d namespaces"
 msgstr "%qD不能在命名空间声明"
 
-#: cp/name-lookup.c:7218
+#: cp/name-lookup.c:7226
 #, fuzzy, gcc-internal-format
 msgid "inline namespace must be specified at initial definition"
 msgstr "方法属性必须被指定的于结束只有"
 
-#: cp/name-lookup.c:7219
+#: cp/name-lookup.c:7227
 #, fuzzy, gcc-internal-format
 #| msgid "label %qD defined here"
 msgid "%qD defined here"
 msgstr "标号%qD在此定义"
 
-#: cp/name-lookup.c:7292
+#: cp/name-lookup.c:7300
 #, gcc-internal-format
 msgid "XXX entering pop_everything ()\n"
 msgstr "XXX 进入 pop_everything ()\n"
 
-#: cp/name-lookup.c:7301
+#: cp/name-lookup.c:7309
 #, gcc-internal-format
 msgid "XXX leaving pop_everything ()\n"
 msgstr "XXX 离开 pop_everything ()\n"
@@ -48365,7 +48410,7 @@
 msgid "LEXER_DEBUGGING_ENABLED_P is not set to true"
 msgstr ""
 
-#: cp/parser.c:1352 cp/parser.c:37254
+#: cp/parser.c:1352 cp/parser.c:37251
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -48390,7 +48435,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr "在非类类型%2$qT中请求成员%1$qE"
 
-#: cp/parser.c:2949 cp/parser.c:18221
+#: cp/parser.c:2949 cp/parser.c:18218
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "%<%T::%E%>尚未声明"
@@ -48471,7 +48516,7 @@
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "浮点字面量不能出现在常量表达式中"
 
-#: cp/parser.c:3143 cp/pt.c:17853
+#: cp/parser.c:3143 cp/pt.c:17890
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr "常量表达式中不能出现目标不是整型或枚举型的类型转换"
@@ -48695,7 +48740,7 @@
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr "无法找到字串实字运算符 %qD 与 %qT，%qT 参数"
 
-#: cp/parser.c:4587 cp/parser.c:12940
+#: cp/parser.c:4587 cp/parser.c:12937
 #, gcc-internal-format
 msgid "expected declaration"
 msgstr "需要声明"
@@ -48748,7 +48793,7 @@
 msgid "fold-expressions only available with -std=c++17 or -std=gnu++17"
 msgstr "Lambda 表达式只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:5275 cp/parser.c:5452 cp/parser.c:5630 cp/semantics.c:3612
+#: cp/parser.c:5275 cp/parser.c:5452 cp/parser.c:5633 cp/semantics.c:3615
 #, gcc-internal-format
 msgid "expected primary-expression"
 msgstr "需要元表达式"
@@ -48768,92 +48813,92 @@
 msgid "local variable %qD may not appear in this context"
 msgstr "局部变量%qD不应出现在此上下文中"
 
-#: cp/parser.c:5787
+#: cp/parser.c:5790
 #, fuzzy, gcc-internal-format
 msgid "expected id-expression"
 msgstr "? 预期于运算式中"
 
-#: cp/parser.c:5919
+#: cp/parser.c:5922
 #, gcc-internal-format
 msgid "scope %qT before %<~%> is not a class-name"
 msgstr "%<~%>前的作用域%qT不是一个类名"
 
-#: cp/parser.c:5948 cp/parser.c:7860
+#: cp/parser.c:5951 cp/parser.c:7860
 #, fuzzy, gcc-internal-format
 msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgstr "C++0x auto 只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:6059
+#: cp/parser.c:6062
 #, gcc-internal-format
 msgid "declaration of %<~%T%> as member of %qT"
 msgstr "%<~%T%>声明为%qT的一个成员"
 
-#: cp/parser.c:6074
+#: cp/parser.c:6077
 #, gcc-internal-format
 msgid "typedef-name %qD used as destructor declarator"
 msgstr "typedef 名%qD用于析构函数声明"
 
-#: cp/parser.c:6111 cp/parser.c:20249
+#: cp/parser.c:6114 cp/parser.c:20246
 #, fuzzy, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr "需要模板 ID"
 
-#: cp/parser.c:6220
+#: cp/parser.c:6223
 #, fuzzy, gcc-internal-format
 msgid "found %<:%> in nested-name-specifier, expected %<::%>"
 msgstr "嵌套名指定中使用了不完全的类型%qT"
 
-#: cp/parser.c:6288
+#: cp/parser.c:6291
 #, fuzzy, gcc-internal-format
 msgid "decltype evaluates to %qT, which is not a class or enumeration type"
 msgstr "%qT被解析到非枚举类型%qT"
 
-#: cp/parser.c:6314
+#: cp/parser.c:6317
 #, fuzzy, gcc-internal-format
 msgid "function template-id %qD in nested-name-specifier"
 msgstr "嵌套名指定中使用了不完全的类型%qT"
 
-#: cp/parser.c:6322
+#: cp/parser.c:6325
 #, fuzzy, gcc-internal-format
 msgid "variable template-id %qD in nested-name-specifier"
 msgstr "%C 期待访问指定符"
 
-#: cp/parser.c:6426 cp/typeck.c:2684 cp/typeck.c:2687 cp/typeck.c:2704
+#: cp/parser.c:6429 cp/typeck.c:2684 cp/typeck.c:2687 cp/typeck.c:2704
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD不是一个模板"
 
-#: cp/parser.c:6504
+#: cp/parser.c:6507
 #, fuzzy, gcc-internal-format
 msgid "expected nested-name-specifier"
 msgstr "typedef 名不能是嵌套名指定"
 
-#: cp/parser.c:6711 cp/parser.c:8950
+#: cp/parser.c:6714 cp/parser.c:8950
 #, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr "类型不能定义在类型转换中"
 
-#: cp/parser.c:6797
+#: cp/parser.c:6800
 #, gcc-internal-format
 msgid "types may not be defined in a %<typeid%> expression"
 msgstr "类型不能定义在%<typeid%>表达式中"
 
-#: cp/parser.c:6889
+#: cp/parser.c:6892
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "给函数%<__builtin_next_arg%>的参数数目不对"
 
-#: cp/parser.c:6901 cp/pt.c:18416
+#: cp/parser.c:6904 cp/pt.c:18453
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "给函数%<__builtin_next_arg%>的参数数目不对"
 
-#: cp/parser.c:6995
+#: cp/parser.c:6998
 #, gcc-internal-format
 msgid "ISO C++ forbids compound-literals"
 msgstr "ISO C++ 不允许复合字面量"
 
-#: cp/parser.c:7054
+#: cp/parser.c:7057
 #, gcc-internal-format
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
@@ -48986,7 +49031,7 @@
 msgid "capture of non-variable %qE"
 msgstr "%qD不是一个变量"
 
-#: cp/parser.c:10391 cp/parser.c:10401 cp/semantics.c:3453 cp/semantics.c:3465
+#: cp/parser.c:10391 cp/parser.c:10401 cp/semantics.c:3456 cp/semantics.c:3468
 #, fuzzy, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "%q+D已在此声明过"
@@ -49072,7 +49117,7 @@
 msgid "init-statement in selection statements only available with -std=c++17 or -std=gnu++17"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:11546 cp/parser.c:28490
+#: cp/parser.c:11546 cp/parser.c:28487
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "需要选择语句"
@@ -49092,569 +49137,569 @@
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr "对%qT不一致的演绎：先是%qT然后是%qT"
 
-#: cp/parser.c:12250 cp/parser.c:28493
+#: cp/parser.c:12250 cp/parser.c:28490
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "需要循环语句"
 
-#: cp/parser.c:12298
+#: cp/parser.c:12297
 #, fuzzy, gcc-internal-format
 msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
 msgstr "带作用域的枚举只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:12426
+#: cp/parser.c:12423
 #, fuzzy, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr "前往目录:"
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:12434
+#: cp/parser.c:12431
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ 不允许计算转移"
 
-#: cp/parser.c:12447 cp/parser.c:28496
+#: cp/parser.c:12444 cp/parser.c:28493
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "需要跳转语句"
 
-#: cp/parser.c:12620 cp/parser.c:23584
+#: cp/parser.c:12617 cp/parser.c:23581
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "多余的%<;%>"
 
-#: cp/parser.c:12863
+#: cp/parser.c:12860
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr "%<__label__%>未出现在块起始"
 
-#: cp/parser.c:13083
+#: cp/parser.c:13080
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:13103
+#: cp/parser.c:13100
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr "对%qT不一致的演绎：先是%qT然后是%qT"
 
-#: cp/parser.c:13124
+#: cp/parser.c:13121
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr "不能混合声明和函数定义"
 
-#: cp/parser.c:13148
+#: cp/parser.c:13145
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in exception-declarations"
 msgid "types may not be defined in a for-range-declaration"
 msgstr "类型不能定义在异常声明中"
 
-#: cp/parser.c:13203
+#: cp/parser.c:13200
 #, fuzzy, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr "初始值设定项中索引范围为空"
 
-#: cp/parser.c:13206
+#: cp/parser.c:13203
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:13257
+#: cp/parser.c:13254
 #, fuzzy, gcc-internal-format
 msgid "structured bindings only available with -std=c++17 or -std=gnu++17"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:13306
+#: cp/parser.c:13303
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration"
 msgid "empty structured binding declaration"
 msgstr "需要声明"
 
-#: cp/parser.c:13324
+#: cp/parser.c:13321
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer for member function %qD"
 msgid "invalid initializer for structured binding declaration"
 msgstr "成员函数%qD的初始值设定无效"
 
-#: cp/parser.c:13491
+#: cp/parser.c:13488
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr "%<friend%>用在类外"
 
-#: cp/parser.c:13558
+#: cp/parser.c:13555
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr "%<auto%>的语义在 C++0x 中将被改变；请考虑删除它"
 
-#: cp/parser.c:13594
+#: cp/parser.c:13591
 #, fuzzy, gcc-internal-format
 msgid "decl-specifier invalid in condition"
 msgstr "%s：无效的新列指定符号“%s”\n"
 
-#: cp/parser.c:13600
+#: cp/parser.c:13597
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D invalid in %q#T"
 msgid "%qD invalid in lambda"
 msgstr "%q+D无效，在%q#T中"
 
-#: cp/parser.c:13693
+#: cp/parser.c:13690
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "类定义不能被声明为友元"
 
-#: cp/parser.c:13763 cp/parser.c:24064
+#: cp/parser.c:13760 cp/parser.c:24061
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr "模板不能是%<virtual%>的"
 
-#: cp/parser.c:13805
+#: cp/parser.c:13802
 #, fuzzy, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr "指定链接时使用%qD无效"
 
-#: cp/parser.c:13909
+#: cp/parser.c:13906
 #, fuzzy, gcc-internal-format
 msgid "static_assert without a message only available with -std=c++17 or -std=gnu++17"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:14111
+#: cp/parser.c:14108
 #, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr "类型不能定义在%<decltype%>中"
 
-#: cp/parser.c:14264
+#: cp/parser.c:14261
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr "类型不能定义在 new-type-id 中"
 
-#: cp/parser.c:14291
+#: cp/parser.c:14288
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "在转换运算符中使用%<auto%>无效"
 
-#: cp/parser.c:14295
+#: cp/parser.c:14292
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr "在转换运算符中使用%<auto%>无效"
 
-#: cp/parser.c:14379
+#: cp/parser.c:14376
 #, fuzzy, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr "只有构造函数才能有基类初始值设定"
 
-#: cp/parser.c:14406
+#: cp/parser.c:14403
 #, fuzzy, gcc-internal-format
 #| msgid "cannot expand initializer for member %<%D%>"
 msgid "cannot expand initializer for member %qD"
 msgstr "无法从成员%<%D%>中扩展初始值"
 
-#: cp/parser.c:14418 cp/pt.c:24255
+#: cp/parser.c:14415 cp/pt.c:24333
 #, fuzzy, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "对%qD的静态声明出现在非静态声明之后"
 
-#: cp/parser.c:14430 cp/pt.c:24267
+#: cp/parser.c:14427 cp/pt.c:24345
 #, fuzzy, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr "建构子 delegation 追随 mem-initializer 用于 %qD"
 
-#: cp/parser.c:14482
+#: cp/parser.c:14479
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr "年代错误的旧式基类初始值设定"
 
-#: cp/parser.c:14552
+#: cp/parser.c:14549
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr "关键字%<typename%>不允许用在此上下文中(限定的初始值设定隐式地是一个类型)"
 
-#: cp/parser.c:14927
+#: cp/parser.c:14924
 #, fuzzy, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr "缺少空格介于 %<“”%>和后缀识别码"
 
-#: cp/parser.c:14933
+#: cp/parser.c:14930
 #, fuzzy, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr "需要标识符或%<(%>"
 
-#: cp/parser.c:14942
+#: cp/parser.c:14939
 #, fuzzy, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr "%<#pragma message%>后需要一个字符串"
 
-#: cp/parser.c:14948
+#: cp/parser.c:14945
 #, fuzzy, gcc-internal-format
 msgid "invalid encoding prefix in literal operator"
 msgstr "二元操作中中操作数无效"
 
-#: cp/parser.c:14975
+#: cp/parser.c:14972
 #, gcc-internal-format
 msgid "expected operator"
 msgstr "需要操作符"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:15020
+#: cp/parser.c:15017
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "关键字%<export%>未实现，将被忽略"
 
-#: cp/parser.c:15190
+#: cp/parser.c:15187
 #, fuzzy, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr "对模板类型参数%qT的使用无效"
 
-#: cp/parser.c:15198
+#: cp/parser.c:15195
 #, fuzzy, gcc-internal-format
 msgid "cv-qualified type parameter"
 msgstr "对模板类型参数%qT的使用无效"
 
-#: cp/parser.c:15283
+#: cp/parser.c:15280
 #, gcc-internal-format
 msgid "variadic constraint introduced without %<...%>"
 msgstr ""
 
-#: cp/parser.c:15347
+#: cp/parser.c:15344
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "模板第 %d 个参数无效"
 
-#: cp/parser.c:15582 cp/parser.c:15668 cp/parser.c:21694
+#: cp/parser.c:15579 cp/parser.c:15665 cp/parser.c:21691
 #, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "模板参数包%qD不能有默认参数"
 
-#: cp/parser.c:15586 cp/parser.c:15672
+#: cp/parser.c:15583 cp/parser.c:15669
 #, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr "模板参数包不能有默认参数"
 
-#: cp/parser.c:15738
+#: cp/parser.c:15735
 #, gcc-internal-format
 msgid "expected template-id"
 msgstr "需要模板 ID"
 
-#: cp/parser.c:15798
+#: cp/parser.c:15795
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "不能以%<<::%>开始一个模板实参列表"
 
-#: cp/parser.c:15802
+#: cp/parser.c:15799
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr "%<<:%>是%<[%>的另一种拼法。请在%<<%>和%<::%>间加上空格"
 
-#: cp/parser.c:15806
+#: cp/parser.c:15803
 #, fuzzy, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr "(如果您使用%<-fpermissive%>G++ 会接受您的代码)"
 
-#: cp/parser.c:15924
+#: cp/parser.c:15921
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "模板实参表语法错误"
 
 #. The name does not name a template.
-#: cp/parser.c:15992 cp/parser.c:16122 cp/parser.c:16337
+#: cp/parser.c:15989 cp/parser.c:16119 cp/parser.c:16334
 #, gcc-internal-format
 msgid "expected template-name"
 msgstr "需要模板名"
 
 #. Explain what went wrong.
-#: cp/parser.c:16038
+#: cp/parser.c:16035
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr "非模板%qD用作模板"
 
-#: cp/parser.c:16040
+#: cp/parser.c:16037
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr "使用%<%T::template %D%>来表示这是一个模板"
 
-#: cp/parser.c:16189
+#: cp/parser.c:16186
 #, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr "%<...%>前需要形参包"
 
-#: cp/parser.c:16298 cp/parser.c:16316 cp/parser.c:16483
+#: cp/parser.c:16295 cp/parser.c:16313 cp/parser.c:16480
 #, gcc-internal-format
 msgid "expected template-argument"
 msgstr "需要模板实参"
 
-#: cp/parser.c:16458
+#: cp/parser.c:16455
 #, fuzzy, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr "模板第 %d 个参数无效"
 
-#: cp/parser.c:16585
+#: cp/parser.c:16582
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "显式实例化不应当使用%<inline%>限定符"
 
-#: cp/parser.c:16589
+#: cp/parser.c:16586
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "显式实例化不应当使用%<constexpr%>限定符"
 
-#: cp/parser.c:16648
+#: cp/parser.c:16645
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr "特例化模板有 C 链接"
 
-#: cp/parser.c:16869
+#: cp/parser.c:16866
 #, fuzzy, gcc-internal-format
 msgid "expected type specifier"
 msgstr "需要类型限定"
 
-#: cp/parser.c:17053
+#: cp/parser.c:17050
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "默认化和被删除的函数只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:17059
+#: cp/parser.c:17056
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "默认化和被删除的函数只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:17064
+#: cp/parser.c:17061
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -fconcepts"
 msgstr "默认化和被删除的函数只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:17209
+#: cp/parser.c:17206
 #, fuzzy, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "需要模板 ID"
 
-#: cp/parser.c:17278
+#: cp/parser.c:17275
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr "需要类型名"
 
-#: cp/parser.c:17631
+#: cp/parser.c:17628
 #, fuzzy, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %qD keyword"
 msgstr "elaborated-type-specifier 用于范围的 enum 必须不使用 %<%D%>关键字"
 
-#: cp/parser.c:17854
+#: cp/parser.c:17851
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "声明%qD没有声明任何东西"
 
-#: cp/parser.c:17942
+#: cp/parser.c:17939
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "属性在未初始化类型上被忽略"
 
-#: cp/parser.c:17946
+#: cp/parser.c:17943
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "属性在模板实例化上被忽略"
 
-#: cp/parser.c:17951
+#: cp/parser.c:17948
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr "类型在非前向声明的详尽类型限定符中被忽略"
 
-#: cp/parser.c:18085
+#: cp/parser.c:18082
 #, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "%qD不是一个枚举模板"
 
-#: cp/parser.c:18096
+#: cp/parser.c:18093
 #, fuzzy, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr "new 声明中的表达式必须具有整数或枚举类型"
 
-#: cp/parser.c:18111
+#: cp/parser.c:18108
 #, fuzzy, gcc-internal-format
 #| msgid "%<namespace%> definition is not allowed here"
 msgid "unnamed scoped enum is not allowed"
 msgstr "在这里不允许使用%<namespace%>定义"
 
-#: cp/parser.c:18166
+#: cp/parser.c:18163
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "需要 %<;%>、%<,%> 或 %<)%>"
 
-#: cp/parser.c:18215
+#: cp/parser.c:18212
 #, fuzzy, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "启用模板自动实例化"
 
-#: cp/parser.c:18229
+#: cp/parser.c:18226
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration does not name a class or function"
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "友元声明没有指定类或函数名"
 
-#: cp/parser.c:18241 cp/parser.c:23070
+#: cp/parser.c:18238 cp/parser.c:23067
 #, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "%qD声明出现在命名空间%qD中，而后者并不包含%qD"
 
-#: cp/parser.c:18246 cp/parser.c:23075
+#: cp/parser.c:18243 cp/parser.c:23072
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "%qD声明出现在%qD中，而后者并不包含%qD"
 
-#: cp/parser.c:18258 cp/parser.c:23089
+#: cp/parser.c:18255 cp/parser.c:23086
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr "不允许有多余的限定"
 
-#: cp/parser.c:18282
+#: cp/parser.c:18279
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "%q#T多次定义"
 
-#: cp/parser.c:18295
+#: cp/parser.c:18292
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO C++ 不允许枚举自减"
 
-#: cp/parser.c:18315
+#: cp/parser.c:18312
 #, fuzzy, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr "opaque-enum-specifier 而无需名称"
 
-#: cp/parser.c:18318
+#: cp/parser.c:18315
 #, fuzzy, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr "opaque-enum-specifier 必须使用简单的识别码"
 
-#: cp/parser.c:18497
+#: cp/parser.c:18494
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD不是一个命名空间名"
 
-#: cp/parser.c:18503
+#: cp/parser.c:18500
 #, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "需要命名空间名"
 
-#: cp/parser.c:18570
+#: cp/parser.c:18567
 #, fuzzy, gcc-internal-format
 msgid "nested namespace definitions only available with -std=c++17 or -std=gnu++17"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:18578
+#: cp/parser.c:18575
 #, fuzzy, gcc-internal-format
 #| msgid "expected namespace-name"
 msgid "nested namespace name required"
 msgstr "需要命名空间名"
 
-#: cp/parser.c:18583
+#: cp/parser.c:18580
 #, fuzzy, gcc-internal-format
 #| msgid "use of namespace %qD as expression"
 msgid "namespace name required"
 msgstr "命名空间%qD被用作表达式"
 
-#: cp/parser.c:18587
+#: cp/parser.c:18584
 #, fuzzy, gcc-internal-format
 #| msgid "%<namespace%> definition is not allowed here"
 msgid "a nested namespace definition cannot have attributes"
 msgstr "在这里不允许使用%<namespace%>定义"
 
-#: cp/parser.c:18590
+#: cp/parser.c:18587
 #, fuzzy, gcc-internal-format
 #| msgid "Warn when an inlined function cannot be inlined"
 msgid "a nested namespace definition cannot be inline"
 msgstr "当内联函数无法被内联时给出警告"
 
-#: cp/parser.c:18597
+#: cp/parser.c:18594
 #, fuzzy, gcc-internal-format
 #| msgid "use of namespace %qD as expression"
 msgid "namespace %qD entered"
 msgstr "命名空间%qD被用作表达式"
 
-#: cp/parser.c:18652
+#: cp/parser.c:18649
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "在这里不允许使用%<namespace%>定义"
 
-#: cp/parser.c:18803
+#: cp/parser.c:18800
 #, fuzzy, gcc-internal-format
 msgid "pack expansion in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr "Lambda 表达式只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:18818
+#: cp/parser.c:18815
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "模板标识符不允许出现在 using 声明中"
 
-#: cp/parser.c:18865
+#: cp/parser.c:18862
 #, fuzzy, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with -std=c++17 or -std=gnu++17"
 msgstr "默认化和被删除的函数只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:18875
+#: cp/parser.c:18872
 #, fuzzy, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr "访问声明被不宜用在中 favour 的 using-declarations；建议：加入 %<using%> 关键字"
 
-#: cp/parser.c:18940
+#: cp/parser.c:18937
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "类型不能定义在异常声明中"
 
-#: cp/parser.c:19106
+#: cp/parser.c:19103
 #, fuzzy, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr "函数%qD用作%<asm%>的输出"
 
-#: cp/parser.c:19493
+#: cp/parser.c:19490
 #, fuzzy, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "在这里不允许使用%<namespace%>定义"
 
-#: cp/parser.c:19504
+#: cp/parser.c:19501
 #, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr "函数定义中不允许出现 asm 指定"
 
-#: cp/parser.c:19508
+#: cp/parser.c:19505
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "函数定义中不允许有属性"
 
-#: cp/parser.c:19559
+#: cp/parser.c:19556
 #, fuzzy, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr "预期的建构子、解构式，或类型转换"
 
 #. Anything else is an error.
-#: cp/parser.c:19598 cp/parser.c:21906
+#: cp/parser.c:19595 cp/parser.c:21903
 #, gcc-internal-format
 msgid "expected initializer"
 msgstr "需要初始值设定"
 
-#: cp/parser.c:19679
+#: cp/parser.c:19676
 #, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "为函数提供了初始值设定"
 
-#: cp/parser.c:19713
+#: cp/parser.c:19710
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "括起的初始值设定后出现的属性被忽略"
 
-#: cp/parser.c:19727
+#: cp/parser.c:19724
 #, fuzzy, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr "函数%q+D重声明为内联的"
 
-#: cp/parser.c:20169
+#: cp/parser.c:20166
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "数组边界不是一个整数常量"
 
-#: cp/parser.c:20295
+#: cp/parser.c:20292
 #, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr "生成引用类型%qT的成员指针"
 
-#: cp/parser.c:20299
+#: cp/parser.c:20296
 #, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "%<%T::%E%>不是一个类型"
@@ -49663,17 +49708,17 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:20328
+#: cp/parser.c:20325
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr "无效的声明"
 
-#: cp/parser.c:20336
+#: cp/parser.c:20333
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "将构造函数用作模板无效"
 
-#: cp/parser.c:20338
+#: cp/parser.c:20335
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr "使用%<%T::%D%>而不是%<%T::%D%>来以限定名指定构造函数"
@@ -49680,392 +49725,392 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:20410
+#: cp/parser.c:20407
 #, fuzzy, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr "需要一个限定的标识符"
 
-#: cp/parser.c:20435
+#: cp/parser.c:20432
 #, gcc-internal-format
 msgid "expected declarator"
 msgstr "需要声明"
 
-#: cp/parser.c:20554
+#: cp/parser.c:20551
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD是一个命名空间"
 
-#: cp/parser.c:20556
+#: cp/parser.c:20553
 #, fuzzy, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "生成非类类型%qT的成员指针"
 
-#: cp/parser.c:20577
+#: cp/parser.c:20574
 #, fuzzy, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "需要%<operator%>"
 
-#: cp/parser.c:20638
+#: cp/parser.c:20635
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "重复的 cv 限定"
 
-#: cp/parser.c:20692
+#: cp/parser.c:20689
 #, fuzzy, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr "%q+D的类型限定冲突"
 
-#: cp/parser.c:20729
+#: cp/parser.c:20726
 #, fuzzy, gcc-internal-format
 #| msgid "%<-mfpxx%> requires %<-mlra%>"
 msgid "%qE requires %<-fgnu-tm%>"
 msgstr "%<-mfpxx%> 需要 %<-mlra%>"
 
-#: cp/parser.c:20787
+#: cp/parser.c:20784
 #, fuzzy, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "%C处重复访问限定符"
 
-#: cp/parser.c:21025
+#: cp/parser.c:21022
 #, fuzzy, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr "%qE不是类型%qT的有效模板实参，因为%qE不是一个变量"
 
-#: cp/parser.c:21031 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2090
+#: cp/parser.c:21028 cp/typeck2.c:494 cp/typeck2.c:534 cp/typeck2.c:2093
 #, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr "对%qT的使用非法"
 
-#: cp/parser.c:21052
+#: cp/parser.c:21049
 #, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "不能在模板实参中定义类型"
 
-#: cp/parser.c:21057
+#: cp/parser.c:21054
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "模板第 %d 个参数无效"
 
-#: cp/parser.c:21145
+#: cp/parser.c:21142
 #, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "需要类型限定"
 
-#: cp/parser.c:21429
+#: cp/parser.c:21426
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "需要%<,%>或%<...%>"
 
-#: cp/parser.c:21504
+#: cp/parser.c:21501
 #, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr "类型不能定义在参数类型中"
 
-#: cp/parser.c:21678
+#: cp/parser.c:21675
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "默认参数只允许出现在函数参数中"
 
-#: cp/parser.c:21696
+#: cp/parser.c:21693
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "模板参数包%qD不能有默认参数"
 
-#: cp/parser.c:21702
+#: cp/parser.c:21699
 #, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr "模板参数包不能有默认参数"
 
-#: cp/parser.c:21704
+#: cp/parser.c:21701
 #, fuzzy, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr "模板参数包不能有默认参数"
 
-#: cp/parser.c:22131
+#: cp/parser.c:22128
 #, fuzzy, gcc-internal-format
 msgid "C++ designated initializers only available with -std=c++2a or -std=gnu++2a"
 msgstr "扩展初始值设定列表只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:22151
+#: cp/parser.c:22148
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow GNU designated initializers"
 msgstr "ISO C++ 不允许指定元素初始值设定"
 
-#: cp/parser.c:22189
+#: cp/parser.c:22186
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C++ 不允许指定元素初始值设定"
 
-#: cp/parser.c:22203
+#: cp/parser.c:22200
 #, gcc-internal-format
 msgid "either all initializer clauses should be designated or none of them should be"
 msgstr ""
 
-#: cp/parser.c:22228
+#: cp/parser.c:22225
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "%<...%> not allowed in designated initializer list"
 msgstr "ISO C++ 不允许指定元素初始值设定"
 
-#: cp/parser.c:22266
+#: cp/parser.c:22263
 #, gcc-internal-format
 msgid "%<.%s%> designator used multiple times in the same initializer list"
 msgstr ""
 
-#: cp/parser.c:22322 cp/parser.c:22448
+#: cp/parser.c:22319 cp/parser.c:22445
 #, gcc-internal-format
 msgid "expected class-name"
 msgstr "需要类名"
 
-#: cp/parser.c:22650
+#: cp/parser.c:22647
 #, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "类定义后需要%<;%>"
 
-#: cp/parser.c:22653
+#: cp/parser.c:22650
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "结构定义后需要%<;%>"
 
-#: cp/parser.c:22656
+#: cp/parser.c:22653
 #, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "联合定义后需要%<;%>"
 
-#: cp/parser.c:23012
+#: cp/parser.c:23009
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "需要%<{%>或%<:%>"
 
-#: cp/parser.c:23023
+#: cp/parser.c:23020
 #, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "不能为类指定 %<override%>"
 
-#: cp/parser.c:23031
+#: cp/parser.c:23028
 #, fuzzy, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr "%qD的声明中类名无效"
 
-#: cp/parser.c:23038
+#: cp/parser.c:23035
 #, fuzzy, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "友元声明没有指定类或函数名"
 
-#: cp/parser.c:23050
+#: cp/parser.c:23047
 #, fuzzy, gcc-internal-format
 #| msgid "keyword %<typename%> not allowed outside of templates"
 msgid "keyword %<template%> not allowed in class-head-name"
 msgstr "关键字%<typename%>不能在模板以外使用"
 
-#: cp/parser.c:23056
+#: cp/parser.c:23053
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "%qD的声明中类名无效"
 
-#: cp/parser.c:23114
+#: cp/parser.c:23111
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "显式特例化前必须有%<template <>%>"
 
-#: cp/parser.c:23146
+#: cp/parser.c:23143
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "函数模板%qD重声明为类模板"
 
-#: cp/parser.c:23182
+#: cp/parser.c:23179
 #, fuzzy, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr "缺少用以解析%qE类型的上下文"
 
-#: cp/parser.c:23241
+#: cp/parser.c:23238
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+#T"
 msgid "previous definition of %q#T"
 msgstr "%q+#T的前一个定义"
 
-#: cp/parser.c:23331 cp/parser.c:28499
+#: cp/parser.c:23328 cp/parser.c:28496
 #, fuzzy, gcc-internal-format
 msgid "expected class-key"
 msgstr "需要%<class%>"
 
-#: cp/parser.c:23355
+#: cp/parser.c:23352
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++17 or -std=gnu++17"
 msgstr ""
 
-#: cp/parser.c:23359
+#: cp/parser.c:23356
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "需要%<class%>、%<typename%>或%<template%>"
 
-#: cp/parser.c:23605
+#: cp/parser.c:23602
 #, fuzzy, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr "声明友元时必须使用 class 关键字"
 
-#: cp/parser.c:23623
+#: cp/parser.c:23620
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "友元声明没有指定类或函数名"
 
-#: cp/parser.c:23641
+#: cp/parser.c:23638
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:23738
+#: cp/parser.c:23735
 #, fuzzy, gcc-internal-format
 msgid "default member initializers for bit-fields only available with -std=c++2a or -std=gnu++2a"
 msgstr "扩展初始值设定列表只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:23745
+#: cp/parser.c:23742
 #, fuzzy, gcc-internal-format
 msgid "default member initializer for unnamed bit-field"
 msgstr "为无名形参指定了%qs"
 
-#: cp/parser.c:23758
+#: cp/parser.c:23755
 #, gcc-internal-format
 msgid "ISO C++ allows bit-field attributes only before the %<:%> token"
 msgstr ""
 
-#: cp/parser.c:23903
+#: cp/parser.c:23900
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr "函数定义上有 pure 指定"
 
-#: cp/parser.c:23923
+#: cp/parser.c:23920
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%> after class definition"
 msgid "extra %<;%> after in-class function definition"
 msgstr "类定义后需要%<;%>"
 
-#: cp/parser.c:23970
+#: cp/parser.c:23967
 #, fuzzy, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr "可变数组成员没有出现在结构的末尾"
 
-#: cp/parser.c:23984
+#: cp/parser.c:23981
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "需要声明"
 
-#: cp/parser.c:24058
+#: cp/parser.c:24055
 #, fuzzy, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr "指定了无效的 AE 类型(%s)\n"
 
-#: cp/parser.c:24093
+#: cp/parser.c:24090
 #, fuzzy, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "%qT的初始值设定必须在花括号内"
 
-#: cp/parser.c:24223
+#: cp/parser.c:24220
 #, fuzzy, gcc-internal-format
 #| msgid "%<virtual%> specified more than once in base-specified"
 msgid "%<virtual%> specified more than once in base-specifier"
 msgstr "在基类限定中指定了多于一次的%<virtual%>"
 
-#: cp/parser.c:24243
+#: cp/parser.c:24240
 #, fuzzy, gcc-internal-format
 msgid "more than one access specifier in base-specifier"
 msgstr "超过一个访问说明符在中 base-specified"
 
-#: cp/parser.c:24267
+#: cp/parser.c:24264
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "关键字%<typename%>不能在模板以外使用"
 
-#: cp/parser.c:24270
+#: cp/parser.c:24267
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "关键字%<typename%>不允许用在此上下文中(基类隐式地是一个类型)"
 
-#: cp/parser.c:24364 cp/parser.c:24442
+#: cp/parser.c:24361 cp/parser.c:24439
 #, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "类型不能定义在异常规范中"
 
-#: cp/parser.c:24450
+#: cp/parser.c:24447
 #, fuzzy, gcc-internal-format
 #| msgid "due to different exception specifications"
 msgid "ISO C++17 does not allow dynamic exception specifications"
 msgstr "因为异常规范不一致"
 
-#: cp/parser.c:24456
+#: cp/parser.c:24453
 #, fuzzy, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr "动态异常规格被不宜用在中 C++0x; 使用 %<noexcept%> 作为替代"
 
-#: cp/parser.c:24500
+#: cp/parser.c:24497
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%> in conversion operator"
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "在转换运算符中使用%<auto%>无效"
 
-#: cp/parser.c:24539
+#: cp/parser.c:24536
 #, fuzzy, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr "对%qD的重声明在%<constexpr%>方面"
 
-#: cp/parser.c:24650
+#: cp/parser.c:24647
 #, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr "类型不能定义在异常声明中"
 
-#: cp/parser.c:25203
+#: cp/parser.c:25200
 #, fuzzy, gcc-internal-format
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr "%qE属性与 %s 属性冲突"
 
-#: cp/parser.c:25217
+#: cp/parser.c:25214
 #, fuzzy, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr "需要标识符"
 
-#: cp/parser.c:25301
+#: cp/parser.c:25298
 #, fuzzy, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr "%qE属性与 %s 属性冲突"
 
-#: cp/parser.c:25305
+#: cp/parser.c:25302
 #, fuzzy, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr "%qE属性与 %s 属性冲突"
 
-#: cp/parser.c:25342
+#: cp/parser.c:25339
 #, fuzzy, gcc-internal-format
 #| msgid "expected parameter pack before %<...%>"
 msgid "expected attribute before %<...%>"
 msgstr "%<...%>前需要形参包"
 
-#: cp/parser.c:25403
+#: cp/parser.c:25400
 #, fuzzy, gcc-internal-format
 msgid "attribute using prefix only available with -std=c++17 or -std=gnu++17"
 msgstr "C++0x auto 只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:25721
+#: cp/parser.c:25718
 #, fuzzy, gcc-internal-format
 msgid "%<requires%> only available with -fconcepts"
 msgstr "带作用域的枚举只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:25753
+#: cp/parser.c:25750
 #, fuzzy, gcc-internal-format
 msgid "a requires expression cannot appear outside a template"
 msgstr "自增不能出现在常量表达式中"
 
-#: cp/parser.c:26467
+#: cp/parser.c:26464
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr "特例化成员%<%T::%E%>需要%<template<>%>语法"
 
-#: cp/parser.c:26472
+#: cp/parser.c:26469
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "%<%T::%E%>声明无效"
 
-#: cp/parser.c:26476
+#: cp/parser.c:26473
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "模板参数表太少"
@@ -50074,456 +50119,456 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:26483
+#: cp/parser.c:26480
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "模板参数表太多"
 
-#: cp/parser.c:26832
+#: cp/parser.c:26829
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "有名返回值不再被支持"
 
-#: cp/parser.c:26991
+#: cp/parser.c:26988
 #, fuzzy, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr "实字运算符模板 %qD 有无效的参数清单。 预期 non-type 模板参数包装 <char...>"
 
-#: cp/parser.c:26996
+#: cp/parser.c:26993
 #, fuzzy, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr "实字运算符模板 %qD 有无效的参数清单。 预期 non-type 模板参数包装 <char...>"
 
-#: cp/parser.c:27066
+#: cp/parser.c:27063
 #, fuzzy, gcc-internal-format
 #| msgid "Enable multiply instructions"
 msgid "empty introduction-list"
 msgstr "启用乘法指令"
 
-#: cp/parser.c:27090
+#: cp/parser.c:27087
 #, fuzzy, gcc-internal-format
 #| msgid "no matching template for %qD found"
 msgid "no matching concept for template-introduction"
 msgstr "没有找到与%qD匹配的模板"
 
-#: cp/parser.c:27112
+#: cp/parser.c:27109
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "局部类中对成员模板的声明无效"
 
-#: cp/parser.c:27121
+#: cp/parser.c:27118
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "模板有 C 链接"
 
-#: cp/parser.c:27141
+#: cp/parser.c:27138
 #, fuzzy, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "显式特例化前必须有%<template <>%>"
 
-#: cp/parser.c:27245
+#: cp/parser.c:27242
 #, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "%<typedef%>的模板声明"
 
-#: cp/parser.c:27296
+#: cp/parser.c:27293
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "a class template declaration must not declare anything else"
 msgstr "没有声明任何东西"
 
-#: cp/parser.c:27342
+#: cp/parser.c:27339
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "显式特例化不能有存储类型"
 
-#: cp/parser.c:27650
+#: cp/parser.c:27647
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "在嵌套模板实参列表中应当使用%<> >%>而非%<>>%>"
 
-#: cp/parser.c:27663
+#: cp/parser.c:27660
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "可疑的%<>>%>，使用%<>%>来结束模板实参列表"
 
-#: cp/parser.c:27958
+#: cp/parser.c:27955
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:28118
+#: cp/parser.c:28115
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "指定链接时使用%qD无效"
 
-#: cp/parser.c:28133
+#: cp/parser.c:28130
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%>出现在%qD之前"
 
-#: cp/parser.c:28267
+#: cp/parser.c:28264
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ 1998 不支持%<long long%>"
 
-#: cp/parser.c:28275
+#: cp/parser.c:28272
 #, fuzzy, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "线程局部的 COMMON 数据没有实现"
 
-#: cp/parser.c:28280
+#: cp/parser.c:28277
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "重复的标号%qD"
 
-#: cp/parser.c:28304
+#: cp/parser.c:28301
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "重复的%qs"
 
-#: cp/parser.c:28356
+#: cp/parser.c:28353
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "需要%<new%>"
 
-#: cp/parser.c:28359
+#: cp/parser.c:28356
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "需要%<delete%>"
 
-#: cp/parser.c:28362
+#: cp/parser.c:28359
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "需要%<return%>"
 
-#: cp/parser.c:28368
+#: cp/parser.c:28365
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "需要%<extern%>"
 
-#: cp/parser.c:28371
+#: cp/parser.c:28368
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "需要%<static_assert%>"
 
-#: cp/parser.c:28374
+#: cp/parser.c:28371
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "需要%<decltype%>"
 
-#: cp/parser.c:28377
+#: cp/parser.c:28374
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "需要%<operator%>"
 
-#: cp/parser.c:28380
+#: cp/parser.c:28377
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "需要%<class%>"
 
-#: cp/parser.c:28383
+#: cp/parser.c:28380
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "需要%<template%>"
 
-#: cp/parser.c:28386
+#: cp/parser.c:28383
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "需要%<namespace%>"
 
-#: cp/parser.c:28389
+#: cp/parser.c:28386
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "需要%<using%>"
 
-#: cp/parser.c:28392
+#: cp/parser.c:28389
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "需要%<asm%>"
 
-#: cp/parser.c:28395
+#: cp/parser.c:28392
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "需要%<try%>"
 
-#: cp/parser.c:28398
+#: cp/parser.c:28395
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "需要%<catch%>"
 
-#: cp/parser.c:28401
+#: cp/parser.c:28398
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "需要%<throw%>"
 
-#: cp/parser.c:28404
+#: cp/parser.c:28401
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "需要%<__label__%>"
 
-#: cp/parser.c:28407
+#: cp/parser.c:28404
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "需要%<@try%>"
 
-#: cp/parser.c:28410
+#: cp/parser.c:28407
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "需要%<@synchronized%>"
 
-#: cp/parser.c:28413
+#: cp/parser.c:28410
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "需要%<@throw%>"
 
-#: cp/parser.c:28416
+#: cp/parser.c:28413
 #, fuzzy, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "对 rpmtxn 数据库异动作业进行除错"
 
-#: cp/parser.c:28419
+#: cp/parser.c:28416
 #, fuzzy, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "于 %s 等待异动作业锁定\n"
 
-#: cp/parser.c:28451
+#: cp/parser.c:28448
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "需要%<::%>"
 
-#: cp/parser.c:28463
+#: cp/parser.c:28460
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "需要%<...%>"
 
-#: cp/parser.c:28466
+#: cp/parser.c:28463
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "需要%<*%>"
 
-#: cp/parser.c:28469
+#: cp/parser.c:28466
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "需要%<~%>"
 
-#: cp/parser.c:28475
+#: cp/parser.c:28472
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "需要%<:%>或%<::%>"
 
-#: cp/parser.c:28502
+#: cp/parser.c:28499
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "需要%<class%>、%<typename%>或%<template%>"
 
-#: cp/parser.c:28772
+#: cp/parser.c:28769
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "使用了%qs标记，在命名%q#T时"
 
-#: cp/parser.c:28777
+#: cp/parser.c:28774
 #, fuzzy, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "以前在此声明过"
 
-#: cp/parser.c:28798
+#: cp/parser.c:28795
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD重声明时有不同的可访问性"
 
-#: cp/parser.c:28819
+#: cp/parser.c:28816
 #, fuzzy, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "用作消歧义的%<template%>只能用于模板内"
 
-#: cp/parser.c:29062
+#: cp/parser.c:29059
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "文件在默认参数处结束"
 
-#: cp/parser.c:29303 cp/parser.c:30620 cp/parser.c:30808
+#: cp/parser.c:29300 cp/parser.c:30617 cp/parser.c:30805
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "位置错误的%<@%D%>Objective-C++ 构造"
 
-#: cp/parser.c:29372
+#: cp/parser.c:29369
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr "需要指定声明"
 
-#: cp/parser.c:29442
+#: cp/parser.c:29439
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr "objective-c++ 消息参数被预期"
 
-#: cp/parser.c:29473
+#: cp/parser.c:29470
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "%<@encode%>必须指定一个类型作为实参"
 
-#: cp/parser.c:29883
+#: cp/parser.c:29880
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "无效的 Objective-C++ 选择子名"
 
-#: cp/parser.c:29958 cp/parser.c:29976
+#: cp/parser.c:29955 cp/parser.c:29973
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr "%C处数组声明需要另外一维"
 
-#: cp/parser.c:29970 cp/parser.c:30035
+#: cp/parser.c:29967 cp/parser.c:30032
 #, fuzzy, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "不能为局部变量指定节属性"
 
-#: cp/parser.c:30078
+#: cp/parser.c:30075
 #, fuzzy, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr "零星的 %qs 介于 Objective-C++ 方法"
 
-#: cp/parser.c:30284 cp/parser.c:30291 cp/parser.c:30298
+#: cp/parser.c:30281 cp/parser.c:30288 cp/parser.c:30295
 #, fuzzy, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "不一致的实例变量指定"
 
-#: cp/parser.c:30413
+#: cp/parser.c:30410
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "%<@protocol%>需要标识符"
 
-#: cp/parser.c:30585
+#: cp/parser.c:30582
 #, fuzzy, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr "属性可能无法被指定的之前 %<@%D%>Objective-C++ 关键字"
 
-#: cp/parser.c:30592
+#: cp/parser.c:30589
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "%qE属性为%qE所忽略"
 
-#: cp/parser.c:30867 cp/parser.c:30874 cp/parser.c:30881
+#: cp/parser.c:30864 cp/parser.c:30871 cp/parser.c:30878
 #, fuzzy, gcc-internal-format
 msgid "invalid type for property"
 msgstr "不能设置只读属性"
 
-#: cp/parser.c:32011
+#: cp/parser.c:32008
 #, fuzzy, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/parser.c:32724
+#: cp/parser.c:32721
 #, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr "无效还原标识符"
 
-#: cp/parser.c:34911
+#: cp/parser.c:34908
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr "括起的初始化不允许使用在 OpenMP %<for%>循环中"
 
-#: cp/parser.c:35231 cp/pt.c:16392
+#: cp/parser.c:35228 cp/pt.c:16414
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "迭代变量%qD不应当是 reduction"
 
-#: cp/parser.c:35316
+#: cp/parser.c:35313
 #, fuzzy, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr "%L处折叠的 !$OMP DO 没有足够的 DO 循环"
 
-#: cp/parser.c:37521
+#: cp/parser.c:37518
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr "无效的初始值设定"
 
-#: cp/parser.c:37549
+#: cp/parser.c:37546
 #, fuzzy, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "? 预期于运算式中"
 
-#: cp/parser.c:37561
+#: cp/parser.c:37558
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:37662
+#: cp/parser.c:37659
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr "不能在返回类型中定义新类型"
 
-#: cp/parser.c:37682 cp/semantics.c:5405
+#: cp/parser.c:37679 cp/semantics.c:5408
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37687 cp/semantics.c:5414
+#: cp/parser.c:37684 cp/semantics.c:5417
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37690 cp/pt.c:12944 cp/semantics.c:5420
+#: cp/parser.c:37687 cp/pt.c:12966 cp/semantics.c:5423
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37693 cp/semantics.c:5426
+#: cp/parser.c:37690 cp/semantics.c:5429
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:38047
+#: cp/parser.c:38044
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:38057
+#: cp/parser.c:38054
 #, fuzzy, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr "#pragma GCC optimize 不允许用在函数中"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:38392
+#: cp/parser.c:38389
 #, gcc-internal-format
 msgid "atomic_cancel"
 msgstr ""
 
-#: cp/parser.c:38435 cp/semantics.c:8575
+#: cp/parser.c:38432 cp/semantics.c:8578
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr "%<__transaction_relaxed%>而无需 transactional 内存支持已启用"
 
-#: cp/parser.c:38437 cp/semantics.c:8577
+#: cp/parser.c:38434 cp/semantics.c:8580
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr "%<__transaction_atomic%>而无需 transactional 内存支持已启用"
 
-#: cp/parser.c:38631
+#: cp/parser.c:38628
 #, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "%<#pragma GCC pch_preprocess%>末尾有垃圾字符"
 
-#: cp/parser.c:38927
+#: cp/parser.c:38924
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "#pragma GCC memregs 必须出现在所有函数声明之前"
 
-#: cp/parser.c:38959
+#: cp/parser.c:38956
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC unroll%> must be inside a function"
 msgstr "#pragma GCC memregs 必须出现在所有函数声明之前"
 
-#: cp/parser.c:39039
+#: cp/parser.c:39036
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "模块间优化未为 C++ 实现"
 
-#: cp/parser.c:39295
+#: cp/parser.c:39292
 #, fuzzy, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr "模板不能是%<virtual%>的"
 
-#: cp/parser.c:39351
+#: cp/parser.c:39348
 #, gcc-internal-format
 msgid "%<extern \"C\"%> linkage started here"
 msgstr ""
@@ -50611,7 +50656,7 @@
 msgid "specialization of %qD after instantiation"
 msgstr "%qD的特例化在实例化之后"
 
-#: cp/pt.c:1954 cp/semantics.c:5274
+#: cp/pt.c:1954 cp/semantics.c:5277
 #, fuzzy, gcc-internal-format
 msgid "%s %#qD"
 msgstr "%s%#D"
@@ -50783,129 +50828,129 @@
 msgid "argument to __integer_pack must be between 0 and %d"
 msgstr "%L处 ACOS 的参数必须在 -1 和 1 之间"
 
-#: cp/pt.c:3942
+#: cp/pt.c:3955
 #, fuzzy, gcc-internal-format
 #| msgid "base initializer expansion %<%T%> contains no parameter packs"
 msgid "base initializer expansion %qT contains no parameter packs"
 msgstr "基类初始值设定展开%<%T%>不包括参数包"
 
-#: cp/pt.c:4010
+#: cp/pt.c:4023
 #, fuzzy, gcc-internal-format
 #| msgid "expansion pattern %<%T%> contains no argument packs"
 msgid "expansion pattern %qT contains no argument packs"
 msgstr "展开样式%<%T%>不包括参数包"
 
-#: cp/pt.c:4012
+#: cp/pt.c:4025
 #, fuzzy, gcc-internal-format
 #| msgid "expansion pattern %<%E%> contains no argument packs"
 msgid "expansion pattern %qE contains no argument packs"
 msgstr "展开样式%<%E%>不包括参数包"
 
-#: cp/pt.c:4063
+#: cp/pt.c:4077
 #, gcc-internal-format
 msgid "parameter packs not expanded with %<...%>:"
 msgstr "参数包未能在%<...%>中被展开："
 
-#: cp/pt.c:4080 cp/pt.c:4835
+#: cp/pt.c:4094 cp/pt.c:4849
 #, gcc-internal-format
 msgid "        %qD"
 msgstr "       %qD"
 
-#: cp/pt.c:4082
+#: cp/pt.c:4096
 #, gcc-internal-format
 msgid "        <anonymous>"
 msgstr "        <匿名>"
 
-#: cp/pt.c:4208
+#: cp/pt.c:4222
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of template parameter %q+D shadows template parameter"
 msgstr "%q+D的声明隐藏了一个形参"
 
-#: cp/pt.c:4211
+#: cp/pt.c:4225
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "declaration of %q+#D shadows template parameter"
 msgstr "%q+D的声明隐藏了一个形参"
 
-#: cp/pt.c:4213
+#: cp/pt.c:4227
 #, fuzzy, gcc-internal-format
 #| msgid "template parameter type %qT declared %<friend%>"
 msgid "template parameter %qD declared here"
 msgstr "模板形参类型%qT声明为%<friend%>"
 
-#: cp/pt.c:4771
+#: cp/pt.c:4785
 #, fuzzy, gcc-internal-format
 msgid "specialization of variable concept %q#D"
 msgstr "有歧义的模板特例化%qD(为%q+D)"
 
-#: cp/pt.c:4830
+#: cp/pt.c:4844
 #, fuzzy, gcc-internal-format
 msgid "template parameters not deducible in partial specialization:"
 msgstr "部分特例化中未用到模板参数："
 
-#: cp/pt.c:4854
+#: cp/pt.c:4868
 #, fuzzy, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments; to define the primary template, remove the template argument list"
 msgstr "部分特例化%qT并未特例化任何模板参数"
 
-#: cp/pt.c:4858
+#: cp/pt.c:4872
 #, fuzzy, gcc-internal-format
 msgid "partial specialization %q+D does not specialize any template arguments and is not more constrained than the primary template; to define the primary template, remove the template argument list"
 msgstr "部分特例化%qT并未特例化任何模板参数"
 
-#: cp/pt.c:4862 cp/pt.c:4873
+#: cp/pt.c:4876 cp/pt.c:4887
 #, fuzzy, gcc-internal-format
 msgid "primary template here"
 msgstr "以前在此声明过"
 
-#: cp/pt.c:4870
+#: cp/pt.c:4884
 #, gcc-internal-format
 msgid "partial specialization is not more specialized than the primary template because it replaces multiple parameters with a pack expansion"
 msgstr ""
 
-#: cp/pt.c:4885
+#: cp/pt.c:4899
 #, fuzzy, gcc-internal-format
 msgid "partial specialization %qD is not more specialized than"
 msgstr "部分特例化%qT并未特例化任何模板参数"
 
-#: cp/pt.c:4887
+#: cp/pt.c:4901
 #, fuzzy, gcc-internal-format
 msgid "primary template %qD"
 msgstr "以前在此声明过"
 
-#: cp/pt.c:4934
+#: cp/pt.c:4948
 #, gcc-internal-format
 msgid "parameter pack argument %qE must be at the end of the template argument list"
 msgstr "参数包实参%qE必须出现在模板实参表末尾"
 
-#: cp/pt.c:4937
+#: cp/pt.c:4951
 #, gcc-internal-format
 msgid "parameter pack argument %qT must be at the end of the template argument list"
 msgstr "参数包实参%qT必须出现在模板实参表末尾"
 
-#: cp/pt.c:4958
+#: cp/pt.c:4972
 #, gcc-internal-format
 msgid "template argument %qE involves template parameter(s)"
 msgstr "模板实参%qE混杂了模板形参"
 
-#: cp/pt.c:5004
+#: cp/pt.c:5018
 #, gcc-internal-format
 msgid "type %qT of template argument %qE depends on a template parameter"
 msgid_plural "type %qT of template argument %qE depends on template parameters"
 msgstr[0] "模板实参%2$qE的类型%1$qT取决于模板参数"
 
-#: cp/pt.c:5066
+#: cp/pt.c:5080
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD ambiguates earlier template instantiation for %qD"
 msgstr "有歧义的模板特例化%qD(为%q+D)"
 
-#: cp/pt.c:5070
+#: cp/pt.c:5084
 #, fuzzy, gcc-internal-format
 msgid "partial specialization of %qD after instantiation of %qD"
 msgstr "%qD的特例化在实例化之后"
 
-#: cp/pt.c:5247
+#: cp/pt.c:5261
 #, gcc-internal-format
 msgid "no default argument for %qD"
 msgstr "%qD没有默认参数"
@@ -50913,49 +50958,49 @@
 #. A primary class template can only have one
 #. parameter pack, at the end of the template
 #. parameter list.
-#: cp/pt.c:5269
+#: cp/pt.c:5283
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %q+D must be at the end of the template parameter list"
 msgstr "参数包实参%qE必须出现在模板实参表末尾"
 
-#: cp/pt.c:5305
+#: cp/pt.c:5319
 #, gcc-internal-format
 msgid "default template arguments may not be used in function template friend re-declaration"
 msgstr "默认参数不能用在函数模板友元重声明中"
 
-#: cp/pt.c:5308
+#: cp/pt.c:5322
 #, fuzzy, gcc-internal-format
 #| msgid "default template arguments may not be used in function template friend declarations"
 msgid "default template arguments may not be used in template friend declarations"
 msgstr "默认参数不能用在函数模板友元重声明中"
 
-#: cp/pt.c:5311
+#: cp/pt.c:5325
 #, fuzzy, gcc-internal-format
 msgid "default template arguments may not be used in function templates without -std=c++11 or -std=gnu++11"
 msgstr "只有指定了 -std=c++0x 或 -std=gnu++0x 时才能在函数模板中使用默认参数"
 
-#: cp/pt.c:5314
+#: cp/pt.c:5328
 #, gcc-internal-format
 msgid "default template arguments may not be used in partial specializations"
 msgstr "默认参数不能用在部分特例化中"
 
-#: cp/pt.c:5317 cp/pt.c:5375
+#: cp/pt.c:5331 cp/pt.c:5389
 #, gcc-internal-format
 msgid "default argument for template parameter for class enclosing %qD"
 msgstr "包含%qD的类的模板参数有默认参数"
 
-#: cp/pt.c:5489
+#: cp/pt.c:5503
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD declared void"
 msgid "template %qD declared"
 msgstr "形参%qD被声明为 void"
 
-#: cp/pt.c:5496
+#: cp/pt.c:5510
 #, gcc-internal-format
 msgid "template class without a name"
 msgstr "模板类没有名字"
 
-#: cp/pt.c:5504
+#: cp/pt.c:5518
 #, fuzzy, gcc-internal-format
 msgid "member template %qD may not have virt-specifiers"
 msgstr "非成员函数%qD不能拥有 cv 限定符"
@@ -50965,64 +51010,64 @@
 #. An allocation function can be a function
 #. template. ... Template allocation functions shall
 #. have two or more parameters.
-#: cp/pt.c:5526
+#: cp/pt.c:5540
 #, gcc-internal-format
 msgid "invalid template declaration of %qD"
 msgstr "%qD模板声明无效"
 
-#: cp/pt.c:5669
+#: cp/pt.c:5683
 #, gcc-internal-format
 msgid "template definition of non-template %q#D"
 msgstr "对非模板%q#D的模板定义"
 
-#: cp/pt.c:5712
+#: cp/pt.c:5726
 #, gcc-internal-format
 msgid "expected %d levels of template parms for %q#D, got %d"
 msgstr "需要 %d 级的%q#D模板参数，却给出了 %d 级"
 
-#: cp/pt.c:5726
+#: cp/pt.c:5740
 #, gcc-internal-format
 msgid "got %d template parameters for %q#D"
 msgstr "得到 %d 个模板参数，为%q#D"
 
-#: cp/pt.c:5729
+#: cp/pt.c:5743
 #, gcc-internal-format
 msgid "got %d template parameters for %q#T"
 msgstr "%2$q#T得到了 %1$d 个模板参数"
 
-#: cp/pt.c:5731
+#: cp/pt.c:5745
 #, gcc-internal-format, gfc-internal-format
 msgid "  but %d required"
 msgstr "但实际需要 %d 个"
 
-#: cp/pt.c:5752
+#: cp/pt.c:5766
 #, gcc-internal-format
 msgid "template arguments to %qD do not match original template %qD"
 msgstr "给%qD的模板实参不匹配原先的模板%qD"
 
-#: cp/pt.c:5755
+#: cp/pt.c:5769
 #, fuzzy, gcc-internal-format
 #| msgid "use template<> for an explicit specialization"
 msgid "use %<template<>%> for an explicit specialization"
 msgstr "使用 template<> 来显式特例化"
 
-#: cp/pt.c:5882
+#: cp/pt.c:5896
 #, gcc-internal-format
 msgid "%qT is not a template type"
 msgstr "%qT不是一个模板类型"
 
-#: cp/pt.c:5895
+#: cp/pt.c:5909
 #, gcc-internal-format
 msgid "template specifiers not specified in declaration of %qD"
 msgstr "%qD的声明中没有 template 限定"
 
-#: cp/pt.c:5906
+#: cp/pt.c:5920
 #, gcc-internal-format, gfc-internal-format
 msgid "redeclared with %d template parameter"
 msgid_plural "redeclared with %d template parameters"
 msgstr[0] "重声明为具有 %d 个模板参数"
 
-#: cp/pt.c:5910
+#: cp/pt.c:5924
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+D used %d template parameter"
 #| msgid_plural "previous declaration %q+D used %d template parameters"
@@ -51030,12 +51075,12 @@
 msgid_plural "previous declaration %qD used %d template parameters"
 msgstr[0] "先前的声明%q+D使用了 %d 个模板参数"
 
-#: cp/pt.c:5947
+#: cp/pt.c:5961
 #, gcc-internal-format
 msgid "template parameter %q+#D"
 msgstr "模板形参%q+#D"
 
-#: cp/pt.c:5948
+#: cp/pt.c:5962
 #, gcc-internal-format
 msgid "redeclared here as %q#D"
 msgstr "在这里又被声明为%q#D"
@@ -51044,422 +51089,422 @@
 #.
 #. A template-parameter may not be given default arguments
 #. by two different declarations in the same scope.
-#: cp/pt.c:5958
+#: cp/pt.c:5972
 #, gcc-internal-format
 msgid "redefinition of default argument for %q#D"
 msgstr "重定义%q#D的默认参数"
 
-#: cp/pt.c:5960
+#: cp/pt.c:5974
 #, gcc-internal-format
 msgid "original definition appeared here"
 msgstr "原始定义在此"
 
-#: cp/pt.c:5988
+#: cp/pt.c:6002
 #, fuzzy, gcc-internal-format
 #| msgid "redeclaration %qD differs in %<constexpr%>"
 msgid "redeclaration %q#D with different constraints"
 msgstr "对%qD的重声明在%<constexpr%>方面"
 
-#: cp/pt.c:5991
+#: cp/pt.c:6005
 #, fuzzy, gcc-internal-format
 #| msgid "original definition appeared here"
 msgid "original declaration appeared here"
 msgstr "原始定义在此"
 
-#: cp/pt.c:6250 cp/pt.c:6318
+#: cp/pt.c:6264 cp/pt.c:6332
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT"
 msgstr "%qE不是类型%qT的有效模板参数"
 
-#: cp/pt.c:6253
+#: cp/pt.c:6267
 #, gcc-internal-format
 msgid "it must be the address of a function with external linkage"
 msgstr "它必须是一个具有外部链接函数的地址"
 
-#: cp/pt.c:6256
+#: cp/pt.c:6270
 #, fuzzy, gcc-internal-format
 msgid "it must be the name of a function with external linkage"
 msgstr "它必须是一个具有外部链接函数的地址"
 
-#: cp/pt.c:6268
+#: cp/pt.c:6282
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD has no linkage"
 msgstr "%qE不是类型%qT的有效模板实参，因为对象%qD没有外部链接"
 
-#: cp/pt.c:6272
+#: cp/pt.c:6286
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because %qD does not have external linkage"
 msgstr "%qE不是类型%qT的有效模板实参，因为函数%qD没有外部链接"
 
-#: cp/pt.c:6321
+#: cp/pt.c:6335
 #, fuzzy, gcc-internal-format
 msgid "it must be a pointer-to-member of the form %<&X::Y%>"
 msgstr "它必须是格式为‘&X::Y’的成员指针"
 
-#: cp/pt.c:6323
+#: cp/pt.c:6337
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qT"
 msgid "because it is a member of %qT"
 msgstr "%qD不是%qT的成员"
 
-#: cp/pt.c:6383
+#: cp/pt.c:6397
 #, fuzzy, gcc-internal-format
 msgid "  couldn't deduce template parameter %qD"
 msgstr "%qD声明时模板参数表太多"
 
-#: cp/pt.c:6392
+#: cp/pt.c:6406
 #, fuzzy, gcc-internal-format
 msgid "  types %qT and %qT have incompatible cv-qualifiers"
 msgstr "  类型 %qT 和 %qT 有不兼容的 cv-qualifiers"
 
-#: cp/pt.c:6401
+#: cp/pt.c:6415
 #, fuzzy, gcc-internal-format
 msgid "  mismatched types %qT and %qT"
 msgstr "在类型%qT和%qT间比较"
 
-#: cp/pt.c:6410
+#: cp/pt.c:6424
 #, fuzzy, gcc-internal-format
 msgid "  template parameter %qD is not a parameter pack, but argument %qD is"
 msgstr "模板参数包%qD不能有默认参数"
 
-#: cp/pt.c:6421
+#: cp/pt.c:6435
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match pointer-to-member constant %qE"
 msgstr "给%qD的模板实参不匹配原先的模板%qD"
 
-#: cp/pt.c:6431
+#: cp/pt.c:6445
 #, fuzzy, gcc-internal-format
 msgid "  %qE is not equivalent to %qE"
 msgstr "%qE属性为%qE所忽略"
 
-#: cp/pt.c:6440
+#: cp/pt.c:6454
 #, fuzzy, gcc-internal-format
 msgid "  inconsistent parameter pack deduction with %qT and %qT"
 msgstr "对%qT不一致的演绎：先是%qT然后是%qT"
 
-#: cp/pt.c:6452
+#: cp/pt.c:6466
 #, fuzzy, gcc-internal-format
 msgid "  deduced conflicting types for parameter %qT (%qT and %qT)"
 msgstr "Lambda 返回类型演绎得到不一致的类型%qT和%qT"
 
-#: cp/pt.c:6456
+#: cp/pt.c:6470
 #, fuzzy, gcc-internal-format
 msgid "  deduced conflicting values for non-type parameter %qE (%qE and %qE)"
 msgstr "  deduced 冲突值用于 non-type 参数 %qE (%qE 和 %qE)"
 
-#: cp/pt.c:6467
+#: cp/pt.c:6481
 #, fuzzy, gcc-internal-format
 msgid "  variable-sized array type %qT is not a valid template argument"
 msgstr "%qE不是类型%qT的有效模板实参，因为%qE不是一个变量"
 
-#: cp/pt.c:6478
+#: cp/pt.c:6492
 #, fuzzy, gcc-internal-format
 msgid "  member function type %qT is not a valid template argument"
 msgstr "%qE不是类型%qT的有效模板实参，因为它的类型是%qT"
 
-#: cp/pt.c:6490
+#: cp/pt.c:6504
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "  candidate expects at least %d argument, %d provided"
 msgid_plural "  candidate expects at least %d arguments, %d provided"
 msgstr[0] " 备选需要 %d 实参，但提供了 %d 个"
 
-#: cp/pt.c:6521
+#: cp/pt.c:6535
 #, fuzzy, gcc-internal-format
 msgid "  cannot convert %qE (type %qT) to type %qT"
 msgstr "无法将%qE从类型%qT转换到类型%qT"
 
-#: cp/pt.c:6534
+#: cp/pt.c:6548
 #, fuzzy, gcc-internal-format
 msgid "  %qT is an ambiguous base class of %qT"
 msgstr "%qT是%qT的有歧义的基类"
 
-#: cp/pt.c:6538
+#: cp/pt.c:6552
 #, fuzzy, gcc-internal-format
 msgid "  %qT is not derived from %qT"
 msgstr "派生联合%qT无效"
 
-#: cp/pt.c:6549
+#: cp/pt.c:6563
 #, fuzzy, gcc-internal-format
 msgid "  template parameters of a template template argument are inconsistent with other deduced template arguments"
 msgstr "  模板参数的模板模板参数是不一致与其他 deduced 模板参数"
 
-#: cp/pt.c:6559
+#: cp/pt.c:6573
 #, fuzzy, gcc-internal-format
 msgid "  can't deduce a template for %qT from non-template type %qT"
 msgstr "指向不完全类型%qT的指针不能自减"
 
-#: cp/pt.c:6569
+#: cp/pt.c:6583
 #, fuzzy, gcc-internal-format
 msgid "  template argument %qE does not match %qE"
 msgstr "给%qD的模板实参不匹配原先的模板%qD"
 
-#: cp/pt.c:6609
+#: cp/pt.c:6623
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because string literals can never be used in this context"
 msgstr "%qE不是类型%qT的有效模板实参，因为字面字符串不能用在此上下文中"
 
-#: cp/pt.c:6758
+#: cp/pt.c:6772
 #, fuzzy, gcc-internal-format
 msgid "in template argument for type %qT"
 msgstr "%qE不是类型%qT的有效模板实参，因为%qE不是一个变量"
 
-#: cp/pt.c:6772
+#: cp/pt.c:6786
 #, fuzzy, gcc-internal-format
 msgid "template argument %qE for type %qT not a constant integer"
 msgstr "%qE不是类型%qT的有效模板实参，因为%qE不是一个变量"
 
-#: cp/pt.c:6833
+#: cp/pt.c:6847
 #, gcc-internal-format
 msgid "%qD is not a valid template argument because %qD is a variable, not the address of a variable"
 msgstr "%qD不是一个有效模板实参，因为%qD是一个变量，而非变量的地址"
 
-#: cp/pt.c:6841
+#: cp/pt.c:6855
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for %qT because it is not the address of a variable"
 msgstr "%qE不是类型%qT的有效模板实参，因为%qE不是一个变量"
 
-#: cp/pt.c:6857
+#: cp/pt.c:6871
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgstr "%qE不是类型%qT的有效模板实参，因为%qE不是一个变量"
 
-#: cp/pt.c:6864
+#: cp/pt.c:6878
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr "%qE不是类型%qT的有效模板实参，因为函数%qD没有外部链接"
 
-#: cp/pt.c:6873
+#: cp/pt.c:6887
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE不是类型%qT的有效模板实参，因为对象%qD没有外部链接"
 
-#: cp/pt.c:6888
+#: cp/pt.c:6902
 #, fuzzy, gcc-internal-format
 msgid "the address of %qD is not a valid template argument"
 msgstr "%qE不是类型%qT的有效模板实参，因为%qE不是一个变量"
 
-#: cp/pt.c:6897
+#: cp/pt.c:6911
 #, fuzzy, gcc-internal-format
 msgid "the address of the %qT subobject of %qD is not a valid template argument"
 msgstr "%qE不是类型%qT的有效模板实参，因为%qE不是一个变量"
 
-#: cp/pt.c:6904
+#: cp/pt.c:6918
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
 msgstr "%qE不是类型%qT的有效模板实参，因为函数%qD没有外部链接"
 
-#: cp/pt.c:6933
+#: cp/pt.c:6947
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "%qE不是类型%qT的有效模板实参，因为 cv 限定冲突"
 
-#: cp/pt.c:6941
+#: cp/pt.c:6955
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE不是类型%qT的有效模板实参，因为它不是一个左值"
 
-#: cp/pt.c:6959
+#: cp/pt.c:6973
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%q#D不是类型%qT的有效模板参数，因为一个引用变量没有常量地址"
 
-#: cp/pt.c:6975
+#: cp/pt.c:6989
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is not an object with external linkage"
 msgid "%qE is not a valid template argument for type %qT because it is not an object with linkage"
 msgstr "%qE不是类型%qT的有效模板实参，因为它没有外部链接"
 
-#: cp/pt.c:6986
+#: cp/pt.c:7000
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "%qE is not a valid template argument for type %qT because object %qD does not have linkage"
 msgstr "%qE不是类型%qT的有效模板实参，因为对象%qD没有外部链接"
 
-#: cp/pt.c:7036
+#: cp/pt.c:7050
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE不是类型%qT的有效模板实参，因为它是一个指针"
 
-#: cp/pt.c:7038
+#: cp/pt.c:7052
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "尝试使用%qE代替"
 
-#: cp/pt.c:7092
+#: cp/pt.c:7106
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE不是类型%qT的有效模板实参，因为它的类型是%qT"
 
-#: cp/pt.c:7654
+#: cp/pt.c:7668
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "忽略在其定义之后为%qT应用的属性"
 
-#: cp/pt.c:7670
+#: cp/pt.c:7684
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr "忽略在其定义之后为%qT应用的属性"
 
-#: cp/pt.c:7805
+#: cp/pt.c:7819
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "注入的类名%qD被用作模板的模板参数"
 
-#: cp/pt.c:7834
+#: cp/pt.c:7848
 #, fuzzy, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "将析构函数%qD用作类型无效"
 
-#: cp/pt.c:7839
+#: cp/pt.c:7853
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "需要使用某个模板参数的类型成员时，请使用%<typename %E%>"
 
-#: cp/pt.c:7855 cp/pt.c:7877 cp/pt.c:7931
+#: cp/pt.c:7869 cp/pt.c:7891 cp/pt.c:7945
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "实参 %d 的类型/值不匹配，在%qD的模板参数列表中"
 
-#: cp/pt.c:7860
+#: cp/pt.c:7874
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "需要一个%qT类型的常量，却给出了%qT"
 
-#: cp/pt.c:7865
+#: cp/pt.c:7879
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "需要一个类模板，却给出了%qE"
 
-#: cp/pt.c:7868
+#: cp/pt.c:7882
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "需要一个类型，却给出了%qE"
 
-#: cp/pt.c:7882
+#: cp/pt.c:7896
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "需要一个类型，却给出了%qT"
 
-#: cp/pt.c:7885
+#: cp/pt.c:7899
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "需要一个类模板，却给出了%qT"
 
-#: cp/pt.c:7935
+#: cp/pt.c:7949
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "需要有%qD类型的模板，却得到了%qT"
 
-#: cp/pt.c:7949
+#: cp/pt.c:7963
 #, fuzzy, gcc-internal-format
 #| msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "实参 %d 的类型/值不匹配，在%qD的模板参数列表中"
 
-#: cp/pt.c:7952
+#: cp/pt.c:7966
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a type, got %qE"
 msgid "  expected %qD but got %qD"
 msgstr "需要一个类型，却给出了%qE"
 
-#: cp/pt.c:8012
+#: cp/pt.c:8026
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert template argument %qE to %qT"
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "不能将模板参数从%qE转换到%qT"
 
-#: cp/pt.c:8149 cp/pt.c:8465
+#: cp/pt.c:8163 cp/pt.c:8479
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "模板第 %d 个参数无效"
 
-#: cp/pt.c:8164 cp/pt.c:8298
+#: cp/pt.c:8178 cp/pt.c:8312
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "模板参数数目不对(不应是 %d 个而应是 %d 个)"
 
-#: cp/pt.c:8294
+#: cp/pt.c:8308
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "模板参数数目不对(不应是 %d 个而应是 %d 个)"
 
-#: cp/pt.c:8303
+#: cp/pt.c:8317
 #, fuzzy, gcc-internal-format
 #| msgid "provided for %q+D"
 msgid "provided for %qD"
 msgstr "提供给%q+D"
 
-#: cp/pt.c:8328
+#: cp/pt.c:8342
 #, fuzzy, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr "包含%qD的类的模板参数有默认参数"
 
-#: cp/pt.c:8332
+#: cp/pt.c:8346
 #, fuzzy, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "包含%qD的类的模板参数有默认参数"
 
-#: cp/pt.c:8431
+#: cp/pt.c:8445
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:9054
+#: cp/pt.c:9068
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%q#D声明为模板"
 
-#: cp/pt.c:9221
+#: cp/pt.c:9235
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "非模板类型%qT用作模板"
 
-#: cp/pt.c:9223
+#: cp/pt.c:9237
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "对于模板声明%q+D"
 
-#: cp/pt.c:9346
+#: cp/pt.c:9360
 #, fuzzy, gcc-internal-format
 #| msgid "internal consistency failure"
 msgid "template constraint failure"
 msgstr "内部一致性错误"
 
-#: cp/pt.c:9697
+#: cp/pt.c:9718
 #, fuzzy, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr "%qD不是一个模板"
 
-#: cp/pt.c:10125
+#: cp/pt.c:10148
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr "在实例化%2$qD时模板实例化深度超过最大值 %1$d(使用 use -ftemplate-depth= 来增大最大值)"
 
-#: cp/pt.c:11202
+#: cp/pt.c:11225
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member in union"
 msgid "flexible array member %qD in union"
 msgstr "联合和可变数组成员"
 
-#: cp/pt.c:11691
+#: cp/pt.c:11713
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:12160
+#: cp/pt.c:12182
 #, fuzzy, gcc-internal-format
 #| msgid "mismatched argument pack lengths while expanding %<%T%>"
 msgid "mismatched argument pack lengths while expanding %qT"
 msgstr "展开%<%T%>时参数包长度不匹配"
 
-#: cp/pt.c:12163
+#: cp/pt.c:12185
 #, fuzzy, gcc-internal-format
 #| msgid "mismatched argument pack lengths while expanding %<%E%>"
 msgid "mismatched argument pack lengths while expanding %qE"
 msgstr "展开%<%E%>时参数包长度不匹配"
 
-#: cp/pt.c:12747
+#: cp/pt.c:12769
 #, fuzzy, gcc-internal-format
 msgid "  when instantiating default argument for call to %qD"
 msgstr "重定义%q#D的默认参数"
@@ -51477,278 +51522,278 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:13708
+#: cp/pt.c:13730
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "变量%qD有函数类型"
 
-#: cp/pt.c:13881
+#: cp/pt.c:13903
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "无效的参数类型%qT"
 
-#: cp/pt.c:13883
+#: cp/pt.c:13905
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "在声明%q+D中"
 
-#: cp/pt.c:14001
+#: cp/pt.c:14023
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "函数返回了一个数组"
 
-#: cp/pt.c:14003
+#: cp/pt.c:14025
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "函数返回了一个函数"
 
-#: cp/pt.c:14043
+#: cp/pt.c:14065
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "生成非类类型%qT的成员函数指针"
 
-#: cp/pt.c:14637
+#: cp/pt.c:14659
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "形成对 void 的引用"
 
-#: cp/pt.c:14639
+#: cp/pt.c:14661
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "生成指向引用类型%qT的指针"
 
-#: cp/pt.c:14641
+#: cp/pt.c:14663
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "生成指向引用类型%qT的引用"
 
-#: cp/pt.c:14654
+#: cp/pt.c:14676
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "不能声明指向限定函数类型%qT的指针"
 
-#: cp/pt.c:14657
+#: cp/pt.c:14679
 #, fuzzy, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "不能声明指向限定函数类型%qT的引用"
 
-#: cp/pt.c:14705
+#: cp/pt.c:14727
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "生成非类类型%qT的成员指针"
 
-#: cp/pt.c:14711
+#: cp/pt.c:14733
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "生成引用类型%qT的成员指针"
 
-#: cp/pt.c:14717
+#: cp/pt.c:14739
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "创建指向 void 类型的成员指针"
 
-#: cp/pt.c:14783
+#: cp/pt.c:14805
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "生成%qT的数组"
 
-#: cp/pt.c:14816
+#: cp/pt.c:14838
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT不是类、结构或联合类型"
 
-#: cp/pt.c:14853
+#: cp/pt.c:14875
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT被解析到非枚举类型%qT"
 
-#: cp/pt.c:14861
+#: cp/pt.c:14883
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr "%qT被解析到非类类型%qT"
 
-#: cp/pt.c:14925
+#: cp/pt.c:14947
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.c:15000
+#: cp/pt.c:15022
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "在模板中使用%qs"
 
-#: cp/pt.c:15178
+#: cp/pt.c:15200
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "限定类型%qT不匹配析构函数名 ~%qT"
 
-#: cp/pt.c:15193
+#: cp/pt.c:15215
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "依赖名%qE被解析为非类型，但实例化却产生了一个类型"
 
-#: cp/pt.c:15195
+#: cp/pt.c:15217
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "如果您想指定类型，请使用%<typename %E%>"
 
-#: cp/pt.c:15394
+#: cp/pt.c:15416
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "使用无效字段%qD"
 
-#: cp/pt.c:15883 cp/pt.c:17386
+#: cp/pt.c:15905 cp/pt.c:17408
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "对集展开表达式的无效使用"
 
-#: cp/pt.c:15887 cp/pt.c:17390
+#: cp/pt.c:15909 cp/pt.c:17412
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "使用%<...%>来展开实参集"
 
-#: cp/pt.c:18334
+#: cp/pt.c:18371
 #, fuzzy, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr "%qD 未被声明在中这个范围，而找不到任何声明是由 argument-dependent 查找于点的实体化"
 
-#: cp/pt.c:18362
+#: cp/pt.c:18399
 #, fuzzy, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr "声明在中附属基底 %qT 找不到由资格不符的查找"
 
-#: cp/pt.c:18367
+#: cp/pt.c:18404
 #, fuzzy, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "使用%<%T::%D%>而不是%<%T::%D%>来以限定名指定构造函数"
 
-#: cp/pt.c:18370
+#: cp/pt.c:18407
 #, fuzzy, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "使用%<%T::%D%>而不是%<%T::%D%>来以限定名指定构造函数"
 
-#: cp/pt.c:18375
+#: cp/pt.c:18412
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "%qE未声明(不在函数内)"
 
-#: cp/pt.c:18712
+#: cp/pt.c:18752
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT既不是类也不是命名空间"
 
-#: cp/pt.c:18715
+#: cp/pt.c:18755
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD既不是类也不是命名空间"
 
-#: cp/pt.c:19026
+#: cp/pt.c:19066
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is/uses anonymous type"
 msgid "%qT is/uses unnamed type"
 msgstr "%qT是/使用了匿名类型"
 
-#: cp/pt.c:19028
+#: cp/pt.c:19068
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "%qD的模板实参使用了局部类型%qT"
 
-#: cp/pt.c:19038
+#: cp/pt.c:19078
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT是一个可变类型"
 
-#: cp/pt.c:19053
+#: cp/pt.c:19093
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "整型表达式%qE不是常量"
 
-#: cp/pt.c:19071
+#: cp/pt.c:19111
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  试图实例化%qD"
 
-#: cp/pt.c:22972
+#: cp/pt.c:23050
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "%q#T的显式实例化出现在模板定义之前"
 
-#: cp/pt.c:22974
+#: cp/pt.c:23052
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "有歧义的模板特例化%qD(为%q+D)"
 
-#: cp/pt.c:22980
+#: cp/pt.c:23058
 #, fuzzy
 msgid "%s %#qS"
 msgstr "张贴被搁置的文章 [%%s]？(%s/%s/%s/%s/%s)："
 
-#: cp/pt.c:23004 cp/pt.c:23091
+#: cp/pt.c:23082 cp/pt.c:23169
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "对非模板%q#D的显式实例化"
 
-#: cp/pt.c:23023
+#: cp/pt.c:23101
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD不是类模板的非静态数据成员"
 
-#: cp/pt.c:23029 cp/pt.c:23086
+#: cp/pt.c:23107 cp/pt.c:23164
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "没有找到与%qD匹配的模板"
 
-#: cp/pt.c:23034
+#: cp/pt.c:23112
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "类型%qT用于显式实例化%qD时不匹配声明的类型%qT"
 
-#: cp/pt.c:23042
+#: cp/pt.c:23120
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "对%q#D的显式实例化"
 
-#: cp/pt.c:23078
+#: cp/pt.c:23156
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "对%q#D重复的显式实例化"
 
-#: cp/pt.c:23101 cp/pt.c:23187
+#: cp/pt.c:23179 cp/pt.c:23265
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ 1998 不允许在显式实例化时使用%<extern%>"
 
-#: cp/pt.c:23106 cp/pt.c:23204
+#: cp/pt.c:23184 cp/pt.c:23282
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "为模板实例化化应用了存储类型%qD"
 
-#: cp/pt.c:23163
+#: cp/pt.c:23241
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "显式实例化非模板类型%qT"
 
-#: cp/pt.c:23165
+#: cp/pt.c:23243
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "显式实例化非模板类型%qT"
 
-#: cp/pt.c:23174
+#: cp/pt.c:23252
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "%q#T的显式实例化出现在模板定义之前"
 
-#: cp/pt.c:23192
+#: cp/pt.c:23270
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ 不允许在显式实例化时使用%qE"
 
-#: cp/pt.c:23238
+#: cp/pt.c:23316
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "对%q#T重复的显式实例化"
 
-#: cp/pt.c:23536
+#: cp/pt.c:23614
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization of %qD after first use"
 msgid "exception specification of %qD depends on itself"
@@ -51761,114 +51806,114 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:23842
+#: cp/pt.c:23920
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "显式实例化%qD时没有可用的定义"
 
-#: cp/pt.c:24043
+#: cp/pt.c:24121
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr "在实例化%2$q+D时模板实例化深度超过了最大值 %1$d，可能是由于生成虚函数表所致(使用 -ftemplate-depth= 来增大最大值)"
 
-#: cp/pt.c:24418
+#: cp/pt.c:24496
 #, fuzzy, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "对模板类型参数%qT的使用无效"
 
-#: cp/pt.c:24420
+#: cp/pt.c:24498
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T不是一个有效的模板常量参数类型"
 
-#: cp/pt.c:25723
+#: cp/pt.c:25802
 #, fuzzy, gcc-internal-format
 #| msgid "keyword %<typename%> not allowed outside of templates"
 msgid "keyword %<template%> not allowed in declarator-id"
 msgstr "关键字%<typename%>不能在模板以外使用"
 
-#: cp/pt.c:25961
+#: cp/pt.c:26040
 #, fuzzy, gcc-internal-format
 #| msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
 msgid "deducing from brace-enclosed initializer list requires %<#include <initializer_list>%>"
 msgstr "从花括号中的初始化列表演绎需要 #include <initializer_list>"
 
-#: cp/pt.c:26440
+#: cp/pt.c:26519
 #, fuzzy, gcc-internal-format
 #| msgid "non-template %qD used as template"
 msgid "non-class template %qT used without template arguments"
 msgstr "非模板%qD用作模板"
 
-#: cp/pt.c:26586
+#: cp/pt.c:26665
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:26593
+#: cp/pt.c:26672
 #, fuzzy, gcc-internal-format
 msgid "cannot deduce template arguments of %qT, as it has no viable deduction guides"
 msgstr "%qE不是类型%qT的有效模板实参，因为对象%qD没有外部链接"
 
-#: cp/pt.c:26607
+#: cp/pt.c:26686
 #, fuzzy, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "模板第 %d 个参数无效"
 
-#: cp/pt.c:26614
+#: cp/pt.c:26693
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "不考虑内联函数"
 
-#: cp/pt.c:26676
+#: cp/pt.c:26755
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:26679
+#: cp/pt.c:26758
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:26711
+#: cp/pt.c:26790
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/pt.c:26746
+#: cp/pt.c:26825
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "无法从%2$qE推导出%1$qT"
 
-#: cp/pt.c:26748
+#: cp/pt.c:26827
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "无法从%2$qE推导出%1$qT"
 
-#: cp/pt.c:26781
+#: cp/pt.c:26860
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:26785
+#: cp/pt.c:26864
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "指令不满足其约束："
 
-#: cp/pt.c:26789
+#: cp/pt.c:26868
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "指令不满足其约束："
 
-#: cp/pt.c:26793
+#: cp/pt.c:26872
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "指令不满足其约束："
 
-#: cp/pt.c:26912
+#: cp/pt.c:26991
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT in template argument"
 msgstr "模板第 %d 个参数无效"
@@ -51925,83 +51970,83 @@
 msgid "cannot dynamic_cast %qE (of type %q#T) to type %q#T (%s)"
 msgstr "无法将%qE从类型%qT动态转换到类型%q#T(%s)"
 
-#: cp/search.c:240
+#: cp/search.c:243
 #, gcc-internal-format
 msgid "%qT is an ambiguous base of %qT"
 msgstr "%qT是%qT的有歧义的基类"
 
-#: cp/search.c:256
+#: cp/search.c:259
 #, gcc-internal-format
 msgid "%qT is an inaccessible base of %qT"
 msgstr "%qT是%qT不可访问的基类"
 
-#: cp/search.c:1905
+#: cp/search.c:1908
 #, fuzzy, gcc-internal-format
 msgid "invalid covariant return type for %q#D"
 msgstr "%q+#D的协变返回类型无效"
 
-#: cp/search.c:1907 cp/search.c:1922 cp/search.c:1928 cp/search.c:1957
+#: cp/search.c:1910 cp/search.c:1925 cp/search.c:1931 cp/search.c:1960
 #, fuzzy, gcc-internal-format
 #| msgid "overriding deleted function %q+D"
 msgid "overridden function is %q#D"
 msgstr "隐藏了被删除的函数%q+D"
 
-#: cp/search.c:1920
+#: cp/search.c:1923
 #, gcc-internal-format
 msgid "invalid covariant return type for %q+#D"
 msgstr "%q+#D的协变返回类型无效"
 
-#: cp/search.c:1926
+#: cp/search.c:1929
 #, gcc-internal-format
 msgid "conflicting return type specified for %q+#D"
 msgstr "为%q+#D指定了冲突的返回类型"
 
-#: cp/search.c:1942
+#: cp/search.c:1945
 #, gcc-internal-format
 msgid "looser throw specifier for %q+#F"
 msgstr "对%q+#F放松的 throw 限定"
 
-#: cp/search.c:1944
+#: cp/search.c:1947
 #, fuzzy, gcc-internal-format
 #| msgid "overriding deleted function %q+D"
 msgid "overridden function is %q#F"
 msgstr "隐藏了被删除的函数%q+D"
 
-#: cp/search.c:1955
+#: cp/search.c:1958
 #, gcc-internal-format
 msgid "conflicting type attributes specified for %q+#D"
 msgstr "为%q+#D指定了冲突的属性"
 
-#: cp/search.c:1972
+#: cp/search.c:1975
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<transaction_safe_dynamic%>"
 msgstr "对 rpmtxn 数据库异动作业进行除错"
 
-#: cp/search.c:1974
+#: cp/search.c:1977
 #, fuzzy, gcc-internal-format
 #| msgid "variable %q+D declared %<inline%>"
 msgid "overriding %qD declared %<transaction_safe%>"
 msgstr "变量%q+D声明为%<inline%>"
 
-#: cp/search.c:1981
+#: cp/search.c:1984
 #, fuzzy, gcc-internal-format
 #| msgid "overriding non-deleted function %q+D"
 msgid "deleted function %q+D overriding non-deleted function"
 msgstr "覆盖了未被删除的函数%q+D"
 
-#: cp/search.c:1984 cp/search.c:1992 cp/search.c:2000
+#: cp/search.c:1987 cp/search.c:1995 cp/search.c:2003
 #, fuzzy, gcc-internal-format
 #| msgid "overriding deleted function %q+D"
 msgid "overridden function is %qD"
 msgstr "隐藏了被删除的函数%q+D"
 
-#: cp/search.c:1989
+#: cp/search.c:1992
 #, fuzzy, gcc-internal-format
 #| msgid "non-deleted function %q+D"
 msgid "non-deleted function %q+D overriding deleted function"
 msgstr "未被删除的函数%q+D"
 
-#: cp/search.c:1998
+#: cp/search.c:2001
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "virtual function %q+D overriding final function"
@@ -52009,12 +52054,12 @@
 
 #. A static member function cannot match an inherited
 #. virtual member function.
-#: cp/search.c:2082
+#: cp/search.c:2085
 #, gcc-internal-format
 msgid "%q+#D cannot be declared"
 msgstr "无法声明%q+#D"
 
-#: cp/search.c:2083
+#: cp/search.c:2086
 #, gcc-internal-format
 msgid "  since %q+#D declared in base class"
 msgstr "因为%q+#D已在基类中声明过"
@@ -52055,585 +52100,601 @@
 msgid "invalid use of member %qD in static member function"
 msgstr "对非静态成员函数%qD的使用无效"
 
-#: cp/semantics.c:2153
+#: cp/semantics.c:2156
 #, gcc-internal-format
 msgid "a statement expression is an insufficient context for overload resolution"
 msgstr ""
 
-#: cp/semantics.c:2540
+#: cp/semantics.c:2543
 #, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr "析构函数不能有参数"
 
-#: cp/semantics.c:2622
+#: cp/semantics.c:2625
 #, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr "静态成员函数中不能使用%<this%>"
 
-#: cp/semantics.c:2624
+#: cp/semantics.c:2627
 #, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr "在非成员函数中使用%<this%>无效"
 
-#: cp/semantics.c:2626
+#: cp/semantics.c:2629
 #, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr "在文件作用域使用%<this%>无效"
 
-#: cp/semantics.c:2648
+#: cp/semantics.c:2651
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "伪析构函数名的限定作用域无效"
 
-#: cp/semantics.c:2656 cp/typeck.c:2604
+#: cp/semantics.c:2659 cp/typeck.c:2604
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "限定的类型%qT不匹配析构函数名 ~%qT"
 
-#: cp/semantics.c:2678
+#: cp/semantics.c:2681
 #, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr "%qE的类型不是%qT"
 
-#: cp/semantics.c:2751
+#: cp/semantics.c:2754
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr "非对象类型%qT的复合字面常量"
 
-#: cp/semantics.c:2892
+#: cp/semantics.c:2895
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr "模板形参必须使用%<class%>或%<typename%>关键字"
 
-#: cp/semantics.c:2942
+#: cp/semantics.c:2945
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr "将类型%qT用作模板的模板参数的默认值无效"
 
-#: cp/semantics.c:2945
+#: cp/semantics.c:2948
 #, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr "模板的模板形参的默认实参无效"
 
-#: cp/semantics.c:2962
+#: cp/semantics.c:2965
 #, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr "在模板参数列表中定义了%q#T"
 
-#: cp/semantics.c:2993
+#: cp/semantics.c:2996
 #, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr "对限定类型%qT的定义无效"
 
-#: cp/semantics.c:3263
+#: cp/semantics.c:3266
 #, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "无效的基类"
 
-#: cp/semantics.c:3423
+#: cp/semantics.c:3426
 #, fuzzy, gcc-internal-format
 msgid "cannot capture member %qD of anonymous union"
 msgstr "匿名联合中出现保护成员%q+#D"
 
-#: cp/semantics.c:3443 cp/semantics.c:9269
+#: cp/semantics.c:3446 cp/semantics.c:9272
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qD未被捕获"
 
-#: cp/semantics.c:3448
+#: cp/semantics.c:3451
 #, fuzzy, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr "为 lambda 形参指定了默认参数"
 
-#: cp/semantics.c:3450
+#: cp/semantics.c:3453
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.c:3462
+#: cp/semantics.c:3465
 #, fuzzy, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr "在包含函数中使用%<auto%>变量"
 
-#: cp/semantics.c:3464
+#: cp/semantics.c:3467
 #, fuzzy, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr "已弃用为非函数指定默认参数"
 
-#: cp/semantics.c:3596
+#: cp/semantics.c:3599
 #, fuzzy, gcc-internal-format
 msgid "use of parameter outside function body"
 msgstr "已弃用为非函数指定默认参数"
 
-#: cp/semantics.c:3606
+#: cp/semantics.c:3609
 #, fuzzy, gcc-internal-format
 #| msgid "mismatched arguments"
 msgid "missing template arguments"
 msgstr "参数不匹配"
 
-#: cp/semantics.c:3633
+#: cp/semantics.c:3636
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr "模板参数%qD(类型为%qT)不允许出现在整数表达式中，因为它的类型不是整数或枚举"
 
-#: cp/semantics.c:3664
+#: cp/semantics.c:3667
 #, gcc-internal-format
 msgid "use of namespace %qD as expression"
 msgstr "命名空间%qD被用作表达式"
 
-#: cp/semantics.c:3669
+#: cp/semantics.c:3672
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr "将类模板%qT用作表达式"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:3675
+#: cp/semantics.c:3678
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "在多继承网格中对%qD的访问有歧义"
 
-#: cp/semantics.c:3702
+#: cp/semantics.c:3705
 #, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "%qD不能出现在常量表达式中"
 
-#: cp/semantics.c:3841
+#: cp/semantics.c:3844
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "%qE的类型未知"
 
-#: cp/semantics.c:3870
+#: cp/semantics.c:3873
 #, fuzzy, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr "%qD不是一个枚举名"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4009
+#: cp/semantics.c:4012
 #, fuzzy, gcc-internal-format
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr "为形参声明指定了无效的存储类"
 
-#: cp/semantics.c:4038
+#: cp/semantics.c:4041
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr "不能为析构函数%<~%T%>使用%<offsetof%>"
 
-#: cp/semantics.c:4052
+#: cp/semantics.c:4055
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "不能为成员函数%qD应用%<offsetof%>"
 
-#: cp/semantics.c:4056
+#: cp/semantics.c:4059
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply %<offsetof%> to member function %qD"
 msgid "cannot apply %<offsetof%> to member function"
 msgstr "不能为成员函数%qD应用%<offsetof%>"
 
-#: cp/semantics.c:4061
+#: cp/semantics.c:4064
 #, fuzzy, gcc-internal-format
 #| msgid "cannot apply %<offsetof%> to member function %qD"
 msgid "cannot apply %<offsetof%> to an enumerator %qD"
 msgstr "不能为成员函数%qD应用%<offsetof%>"
 
-#: cp/semantics.c:4072
+#: cp/semantics.c:4075
 #, fuzzy, gcc-internal-format
 msgid "offsetof within non-standard-layout type %qT is conditionally-supported"
 msgstr "不能通过%<...%>接受不能平凡复制的类型%q#T；"
 
-#: cp/semantics.c:4583 cp/semantics.c:6069 cp/semantics.c:6140
-#: cp/semantics.c:6183 cp/semantics.c:6533 cp/semantics.c:6632
-#: cp/semantics.c:6775
+#: cp/semantics.c:4586 cp/semantics.c:6072 cp/semantics.c:6143
+#: cp/semantics.c:6186 cp/semantics.c:6536 cp/semantics.c:6635
+#: cp/semantics.c:6778
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5271
+#: cp/semantics.c:5274
 #, fuzzy, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr "对%qD的引用有歧义"
 
-#: cp/semantics.c:5544
+#: cp/semantics.c:5547
 #, fuzzy, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr "向量 delete 的实参类型既非指针也非数组"
 
-#: cp/semantics.c:5592
+#: cp/semantics.c:5595
 #, fuzzy, gcc-internal-format
 #| msgid "%qE has invalid type for %<reduction%>"
 msgid "%qE has const type for %<reduction%>"
 msgstr "%qE的类型对%<reduction%>无效"
 
-#: cp/semantics.c:5707
+#: cp/semantics.c:5710
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:5941
+#: cp/semantics.c:5944
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5955
+#: cp/semantics.c:5958
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5977
+#: cp/semantics.c:5980
 #, fuzzy, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.c:6080
+#: cp/semantics.c:6083
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD在子句%qs中不是一个变量"
 
-#: cp/semantics.c:6152
+#: cp/semantics.c:6155
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "%qD在%<firstprivate%>子句中不是一个变量"
 
-#: cp/semantics.c:6195
+#: cp/semantics.c:6198
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "%qD在%<lastprivate%>子句中不是一个变量"
 
-#: cp/semantics.c:6240
+#: cp/semantics.c:6243
 #, fuzzy, gcc-internal-format
 msgid "%<gang%> static expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.c:6254
+#: cp/semantics.c:6257
 #, fuzzy, gcc-internal-format
 msgid "%<gang%> static value must be positive"
 msgstr "%<num_threads%>值必须为正"
 
-#: cp/semantics.c:6288
+#: cp/semantics.c:6291
 #, fuzzy, gcc-internal-format
 msgid "%<gang%> num expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.c:6291
+#: cp/semantics.c:6294
 #, fuzzy, gcc-internal-format
 msgid "%<vector%> length expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.c:6295
+#: cp/semantics.c:6298
 #, fuzzy, gcc-internal-format
 msgid "%<worker%> num expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.c:6317
+#: cp/semantics.c:6320
 #, fuzzy, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr "%<num_threads%>值必须为正"
 
-#: cp/semantics.c:6321
+#: cp/semantics.c:6324
 #, fuzzy, gcc-internal-format
 msgid "%<vector%> length value must be positive"
 msgstr "%<num_threads%>值必须为正"
 
-#: cp/semantics.c:6326
+#: cp/semantics.c:6329
 #, fuzzy, gcc-internal-format
 msgid "%<worker%> num value must be positive"
 msgstr "%<num_threads%>值必须为正"
 
-#: cp/semantics.c:6376
+#: cp/semantics.c:6379
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr "调度块大小表达式必须为整型"
 
-#: cp/semantics.c:6406
+#: cp/semantics.c:6409
 #, fuzzy, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.c:6419
+#: cp/semantics.c:6422
 #, fuzzy, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "%H折叠变量需要正整常数表达式"
 
-#: cp/semantics.c:6438
+#: cp/semantics.c:6441
 #, fuzzy, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.c:6466
+#: cp/semantics.c:6469
 #, fuzzy, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.c:6495
+#: cp/semantics.c:6498
 #, fuzzy, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr "调度块大小表达式必须为整型"
 
-#: cp/semantics.c:6516
+#: cp/semantics.c:6519
 #, fuzzy, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr "调度块大小表达式必须为整型"
 
-#: cp/semantics.c:6543
+#: cp/semantics.c:6546
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qD在%<lastprivate%>子句中不是一个变量"
 
-#: cp/semantics.c:6557
+#: cp/semantics.c:6560
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:6563
+#: cp/semantics.c:6566
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr "%qD在数据子句中多次出现"
 
-#: cp/semantics.c:6576
+#: cp/semantics.c:6579
 #, fuzzy, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr "调度块大小表达式必须为整型"
 
-#: cp/semantics.c:6625
+#: cp/semantics.c:6628
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr "%qD在子句%qs中不是一个变量"
 
-#: cp/semantics.c:6910
+#: cp/semantics.c:6913
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "template %qE in clause %qs"
 msgstr "太多的%qs子句"
 
-#: cp/semantics.c:6914
+#: cp/semantics.c:6917
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6979
+#: cp/semantics.c:6982
 #, fuzzy, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.c:7008
+#: cp/semantics.c:7011
 #, fuzzy, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.c:7037
+#: cp/semantics.c:7040
 #, fuzzy, gcc-internal-format
 msgid "%<num_tasks%> expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.c:7066
+#: cp/semantics.c:7069
 #, fuzzy, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr "向量 delete 的实参类型既非指针也非数组"
 
-#: cp/semantics.c:7105
+#: cp/semantics.c:7108
 #, fuzzy, gcc-internal-format
 msgid "%<tile%> argument needs integral type"
 msgstr "调度块大小表达式必须为整型"
 
-#: cp/semantics.c:7524
+#: cp/semantics.c:7527
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr "%<threadprivate%>%qD不是一个文件、命名空间或块作用域变量"
 
-#: cp/semantics.c:7538
+#: cp/semantics.c:7541
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "%<threadprivate%>%qE指示不在%qT定义中"
 
-#: cp/semantics.c:7743
+#: cp/semantics.c:7746
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr "%qE和%qD之间的差不具有整数类型"
 
-#: cp/semantics.c:8171
+#: cp/semantics.c:8174
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr "%<# pragma omp 基元的 update%>使用两不同的变量用于内存"
 
-#: cp/semantics.c:8398 cp/semantics.c:8408
+#: cp/semantics.c:8401 cp/semantics.c:8411
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr "%<# pragma omp 基元的 update%>使用两不同的变量用于内存"
 
-#: cp/semantics.c:8702
+#: cp/semantics.c:8705
 #, fuzzy, gcc-internal-format
 #| msgid "static assertion failed: %E"
 msgid "static assertion failed"
 msgstr "静态断言错误：%E"
 
-#: cp/semantics.c:8704
+#: cp/semantics.c:8707
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr "静态断言错误：%E"
 
-#: cp/semantics.c:8709
+#: cp/semantics.c:8712
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "静态断言中出现非常量条件"
 
-#: cp/semantics.c:8739
+#: cp/semantics.c:8742
 #, gcc-internal-format
 msgid "argument to decltype must be an expression"
 msgstr "decltype 的实参必须是一个表达式"
 
-#: cp/semantics.c:8767
+#: cp/semantics.c:8770
 #, fuzzy, gcc-internal-format
 msgid "decltype cannot resolve address of overloaded function"
 msgstr "%s 无法解析重载的函数地址"
 
-#: cp/semantics.c:9308
+#: cp/semantics.c:9311
 #, fuzzy, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "逗号表达式的左操作数不起作用"
 
-#: cp/semantics.c:9361
+#: cp/semantics.c:9364
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %qE involves template parameter(s)"
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "模板实参%qE混杂了模板形参"
 
-#: cp/semantics.c:9363
+#: cp/semantics.c:9366
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:9381
+#: cp/semantics.c:9384
 #, fuzzy, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "给函数%<__builtin_next_arg%>的参数数目不对"
 
-#: cp/tree.c:1276
+#: cp/tree.c:1295
 #, gcc-internal-format
 msgid "%qV qualifiers cannot be applied to %qT"
 msgstr "%qV限定符不能应用到%qT上"
 
-#: cp/tree.c:1788
+#: cp/tree.c:1807
 #, gcc-internal-format
 msgid "lambda-expression in a constant expression"
 msgstr "常量表达式中的 Lambda 表达式"
 
-#: cp/tree.c:1792
+#: cp/tree.c:1811
 #, fuzzy, gcc-internal-format
 #| msgid "lambda-expression in a constant expression"
 msgid "statement-expression in a constant expression"
 msgstr "常量表达式中的 Lambda 表达式"
 
-#: cp/tree.c:4050
+#: cp/tree.c:4083
+#, gcc-internal-format
+msgid "-fabi-version=13 (GCC 8.2) fixes the calling convention for %qT, which was accidentally changed in 8.1"
+msgstr ""
+
+#: cp/tree.c:4087
+#, gcc-internal-format
+msgid "-fabi-version=12 (GCC 8.1) accidentally changes the calling convention for %qT"
+msgstr ""
+
+#: cp/tree.c:4090
 #, fuzzy, gcc-internal-format
-msgid "the calling convention for %qT changes in -fabi-version=12 (GCC 8)"
-msgstr "%qD的对齐"
+#| msgid "declared here"
+msgid " declared here"
+msgstr "在此声明"
 
-#: cp/tree.c:4055
+#: cp/tree.c:4094
 #, gcc-internal-format
+msgid "the calling convention for %qT changes in -fabi-version=13 (GCC 8.2)"
+msgstr ""
+
+#: cp/tree.c:4096
+#, gcc-internal-format
 msgid " because all of its copy and move constructors are deleted"
 msgstr ""
 
-#: cp/tree.c:4416
+#: cp/tree.c:4464
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to %qD with void return type"
 msgstr "%qE属性在类型上被忽略"
 
-#: cp/tree.c:4423
+#: cp/tree.c:4471
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr "只能为类定义应用%qE属性"
 
-#: cp/tree.c:4475
+#: cp/tree.c:4523
 #, gcc-internal-format
 msgid "requested init_priority is not an integer constant"
 msgstr "请求的 init_priority 不是一个整数常数"
 
-#: cp/tree.c:4497
+#: cp/tree.c:4545
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr "只能将%qE属性用于某个类的对象的文件作用域定义"
 
-#: cp/tree.c:4505
+#: cp/tree.c:4553
 #, gcc-internal-format
 msgid "requested init_priority is out of range"
 msgstr "请求的 init_priority 越界"
 
-#: cp/tree.c:4515
+#: cp/tree.c:4563
 #, gcc-internal-format
 msgid "requested init_priority is reserved for internal use"
 msgstr "请求的 init_priority 保留为内部使用"
 
-#: cp/tree.c:4526
+#: cp/tree.c:4574
 #, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr "%qE属性在此平台上不受支持"
 
-#: cp/tree.c:4553
+#: cp/tree.c:4601
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %qE"
 msgstr "%qD声明为%qT的一个成员"
 
-#: cp/tree.c:4573
+#: cp/tree.c:4621
 #, fuzzy, gcc-internal-format
 msgid "the %qE attribute requires arguments"
 msgstr "%qE属性需要带有名实参的原型"
 
-#: cp/tree.c:4584
+#: cp/tree.c:4632
 #, fuzzy, gcc-internal-format
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "%qE属性的实参不是一个字符串常量"
 
-#: cp/tree.c:4597 cp/tree.c:4610
+#: cp/tree.c:4645 cp/tree.c:4658
 #, fuzzy, gcc-internal-format
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "%qE属性的实参不是一个字符串常量"
 
-#: cp/tree.c:4599
+#: cp/tree.c:4647
 #, fuzzy, gcc-internal-format
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "%<%T::%D%>不是一个有效的声明"
 
-#: cp/tree.c:4612
+#: cp/tree.c:4660
 #, fuzzy, gcc-internal-format
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "请输入有效字符"
 
-#: cp/tree.c:4636
+#: cp/tree.c:4684
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "%qE属性在不是类的类型上被忽略"
 
-#: cp/tree.c:4642
+#: cp/tree.c:4690
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "忽略在其定义之后为%qT应用的属性"
 
-#: cp/tree.c:4649
+#: cp/tree.c:4697
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "忽略在其定义之后为%qT应用的属性"
 
-#: cp/tree.c:4656
+#: cp/tree.c:4704
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "忽略在其定义之后为%qT应用的属性"
 
-#: cp/tree.c:4678
+#: cp/tree.c:4726
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "%qE属性只能用于函数"
 
-#: cp/tree.c:4684
+#: cp/tree.c:4732
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "%qE属性只能用于函数"
 
-#: cp/tree.c:5440
+#: cp/tree.c:5488
 #, fuzzy, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "PRINT_OPERAND 空指针"
 
-#: cp/tree.c:5453
+#: cp/tree.c:5501
 #, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr "lang_* check：在 %s 中失败，于 %s:%d"
@@ -53758,108 +53819,108 @@
 msgid "cannot initialize aggregate of type %qT with a compound literal"
 msgstr "无法用复合字面常量初始化类型为%qT的聚集"
 
-#: cp/typeck2.c:1496 cp/typeck2.c:1523
+#: cp/typeck2.c:1499 cp/typeck2.c:1526
 #, gcc-internal-format
 msgid "missing initializer for member %qD"
 msgstr "成员%qD缺少初始值设定"
 
-#: cp/typeck2.c:1504
+#: cp/typeck2.c:1507
 #, gcc-internal-format
 msgid "member %qD is uninitialized reference"
 msgstr "成员%qD是未初始化的引用"
 
-#: cp/typeck2.c:1511
+#: cp/typeck2.c:1514
 #, fuzzy, gcc-internal-format
 msgid "member %qD with uninitialized reference fields"
 msgstr "成员%qD是未初始化的引用"
 
-#: cp/typeck2.c:1587
+#: cp/typeck2.c:1590
 #, fuzzy, gcc-internal-format
 #| msgid "type of %qD does not match original declaration"
 msgid "designator order for field %qD does not match declaration order in %qT"
 msgstr "类型%qD不匹配原先的声明"
 
-#: cp/typeck2.c:1660
+#: cp/typeck2.c:1663
 #, gcc-internal-format
 msgid "no field %qD found in union being initialized"
 msgstr "在初始化的联合中找不到字段%qD"
 
-#: cp/typeck2.c:1671
+#: cp/typeck2.c:1674
 #, gcc-internal-format
 msgid "index value instead of field name in union initializer"
 msgstr "在联合初始值设定中出现了索引值而不是字段名"
 
-#: cp/typeck2.c:1858
+#: cp/typeck2.c:1861
 #, gcc-internal-format
 msgid "circular pointer delegation detected"
 msgstr "检测到循环指针代理"
 
-#: cp/typeck2.c:1872
+#: cp/typeck2.c:1875
 #, gcc-internal-format
 msgid "base operand of %<->%> has non-pointer type %qT"
 msgstr "%<->%>的基操作数具有非指针类型%qT"
 
-#: cp/typeck2.c:1898
+#: cp/typeck2.c:1901
 #, gcc-internal-format
 msgid "result of %<operator->()%> yields non-pointer result"
 msgstr "%<operator->()%>的结果给出了非指针的结果"
 
-#: cp/typeck2.c:1900
+#: cp/typeck2.c:1903
 #, gcc-internal-format
 msgid "base operand of %<->%> is not a pointer"
 msgstr "%<->%>的左操作数不是一个指针"
 
-#: cp/typeck2.c:1927
+#: cp/typeck2.c:1930
 #, gcc-internal-format
 msgid "%qE cannot be used as a member pointer, since it is of type %qT"
 msgstr "%qE不能用作成员指针，因为它的类型为%qT"
 
-#: cp/typeck2.c:1936
+#: cp/typeck2.c:1939
 #, gcc-internal-format
 msgid "cannot apply member pointer %qE to %qE, which is of non-class type %qT"
 msgstr "无法将成员指针%qE应用到%qE上，因为后者的类型%qT不是一个类"
 
-#: cp/typeck2.c:1958
+#: cp/typeck2.c:1961
 #, gcc-internal-format
 msgid "pointer to member type %qT incompatible with object type %qT"
 msgstr "成员指针类型%qT与对象类型%qT不兼容"
 
-#: cp/typeck2.c:2018
+#: cp/typeck2.c:2021
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an rvalue"
 msgstr "生成非类类型%qT的成员函数指针"
 
-#: cp/typeck2.c:2029
+#: cp/typeck2.c:2032
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue"
 msgstr "生成非类类型%qT的成员函数指针"
 
-#: cp/typeck2.c:2037
+#: cp/typeck2.c:2040
 #, fuzzy, gcc-internal-format
 msgid "pointer-to-member-function type %qT requires an lvalue before C++2a"
 msgstr "生成非类类型%qT的成员函数指针"
 
-#: cp/typeck2.c:2080
+#: cp/typeck2.c:2083
 #, fuzzy, gcc-internal-format
 msgid "functional cast to array type %qT"
 msgstr "从类型%qT到类型%qT的转换无效"
 
-#: cp/typeck2.c:2096
+#: cp/typeck2.c:2099
 #, fuzzy, gcc-internal-format
 msgid "cannot deduce template arguments for %qT from ()"
 msgstr "%qE不是类型%qT的有效模板实参，因为%qE不是一个变量"
 
-#: cp/typeck2.c:2114
+#: cp/typeck2.c:2117
 #, fuzzy, gcc-internal-format
 msgid "invalid value-initialization of reference type"
 msgstr "引用类型的非法值初始化"
 
-#: cp/typeck2.c:2341
+#: cp/typeck2.c:2344
 #, gcc-internal-format
 msgid "call to function %qD which throws incomplete type %q#T"
 msgstr "调用的函数%qD会抛出不完全的类型%q#T"
 
-#: cp/typeck2.c:2344
+#: cp/typeck2.c:2347
 #, gcc-internal-format
 msgid "call to function which throws incomplete type %q#T"
 msgstr "调用的函数会抛出不完全的类型%q#T"
@@ -54075,11 +54136,11 @@
 msgstr "%C处的任何引用都不能多于 %d 维"
 
 #: fortran/array.c:221 fortran/array.c:661 fortran/check.c:2849
-#: fortran/check.c:5222 fortran/check.c:5260 fortran/check.c:5302
-#: fortran/check.c:5329 fortran/check.c:5529 fortran/match.c:1821
+#: fortran/check.c:5225 fortran/check.c:5263 fortran/check.c:5305
+#: fortran/check.c:5332 fortran/check.c:5532 fortran/match.c:1821
 #: fortran/match.c:3174 fortran/match.c:3516 fortran/match.c:3712
-#: fortran/simplify.c:2909 fortran/simplify.c:2939 fortran/simplify.c:5764
-#: fortran/simplify.c:7658
+#: fortran/simplify.c:2909 fortran/simplify.c:2939 fortran/simplify.c:5769
+#: fortran/simplify.c:7663
 #, fuzzy, gcc-internal-format
 msgid "Coarrays disabled at %C, use %<-fcoarray=%> to enable"
 msgstr "集合数组在%C处被禁用，使用 -fcoarray= 来启用"
@@ -54215,122 +54276,128 @@
 msgid "DO-iterator %qs at %L is inside iterator of the same name"
 msgstr "DO 游标‘%s’在%L处出现在另一个同名游标作用域内"
 
-#: fortran/array.c:1073 fortran/array.c:1255
+#: fortran/array.c:1073 fortran/array.c:1264
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in array constructor at %C"
 msgstr "%C处数组构造语法错误"
 
-#: fortran/array.c:1129
+#: fortran/array.c:1105
 #, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "ENTRY statement at %C cannot appear in a contained procedure"
+msgid "NULL() at %C cannot appear in an array constructor"
+msgstr "%C处 ENTRY 语句不能出现在被包含的过程中"
+
+#: fortran/array.c:1138
+#, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "[...] style array constructors at %C"
 msgstr "程序使用 C 风格的类型转换时给出警告"
 
-#: fortran/array.c:1149
+#: fortran/array.c:1158
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array constructor including type specification at %C"
 msgstr "Fortran 2003：%C处包含类型规格的数组构造"
 
-#: fortran/array.c:1155 fortran/match.c:4148
+#: fortran/array.c:1164 fortran/match.c:4148
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type-spec at %L cannot contain a deferred type parameter"
 msgstr "数组‘%s’在%L处不能有延迟的外形"
 
-#: fortran/array.c:1163
+#: fortran/array.c:1172
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type-spec at %L cannot contain an asterisk for a type parameter"
 msgstr "数组‘%s’在%L处不能有延迟的外形"
 
-#: fortran/array.c:1181
+#: fortran/array.c:1190
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty array constructor at %C is not allowed"
 msgstr "%C处的空数组构造不被允许"
 
-#: fortran/array.c:1218 fortran/array.c:1228
+#: fortran/array.c:1227 fortran/array.c:1237
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "incompatible type for argument %d of %qE"
 msgid "Incompatible typespec for array element at %L"
 msgstr "%2$qE的第 %1$d 个实参类型不兼容"
 
-#: fortran/array.c:1302
+#: fortran/array.c:1311
 #, gcc-internal-format, gfc-internal-format
 msgid "Element in %s array constructor at %L is %s"
 msgstr "%s 数组构造中的元素在%L处是 %s"
 
-#: fortran/array.c:1633
+#: fortran/array.c:1642
 #, gcc-internal-format, gfc-internal-format
 msgid "Iterator step at %L cannot be zero"
 msgstr "%L处游标步进不能为零"
 
-#: fortran/array.c:1770
+#: fortran/array.c:1779
 #, fuzzy, gcc-internal-format
 msgid "The number of elements in the array constructor at %L requires an increase of the allowed %d upper limit.   See %<-fmax-array-constructor%> option"
 msgstr "%L处数组构造函数中的元素数超过容许的上限 %d。请参见 -fmax-array-constructor 选项"
 
-#: fortran/array.c:1940
+#: fortran/array.c:1949
 #, gcc-internal-format, gfc-internal-format
 msgid "AC-IMPLIED-DO initial expression references control variable at %L"
 msgstr ""
 
-#: fortran/array.c:1947
+#: fortran/array.c:1956
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "AC-IMPLIED-DO final expression references control variable at %L"
 msgstr "%L 处运算式参照类型错误"
 
-#: fortran/array.c:1954
+#: fortran/array.c:1963
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "AC-IMPLIED-DO step expression references control variable at %L"
 msgstr "%L 处运算式参照类型错误"
 
-#: fortran/array.c:1966
+#: fortran/array.c:1975
 #, gcc-internal-format, gfc-internal-format
 msgid "Array constructor value at %L shall not be unlimited polymorphic [F2008: C4106]"
 msgstr ""
 
-#: fortran/array.c:2055
+#: fortran/array.c:2067
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Different CHARACTER lengths (%d/%d) in array constructor at %L"
 msgid "Different CHARACTER lengths (%ld/%ld) in array constructor at %L"
 msgstr "%3$L处数组构造函数中不同 CHARACTER 长度(%1$d/%2$d)"
 
-#: fortran/array.c:2174
+#: fortran/array.c:2186
 #, gcc-internal-format
 msgid "spec_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2233
+#: fortran/array.c:2245
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2237
+#: fortran/array.c:2249
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad array reference at %L"
 msgid "Bad array dimension at %L"
 msgstr "%L处数组引用错误"
 
-#: fortran/array.c:2264 fortran/data.c:552 fortran/data.c:571
-#: fortran/data.c:585 fortran/data.c:714
+#: fortran/array.c:2276 fortran/data.c:563 fortran/data.c:582
+#: fortran/data.c:596 fortran/data.c:725
 #, fuzzy, gcc-internal-format
 #| msgid "gimplification failed"
 msgid "Simplification error"
 msgstr "gimplification 失败"
 
-#: fortran/array.c:2376
+#: fortran/array.c:2388
 #, gcc-internal-format
 msgid "gfc_ref_dimen_size(): Bad dimen_type"
 msgstr ""
 
-#: fortran/array.c:2427
+#: fortran/array.c:2439
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad dimension"
 msgstr ""
 
-#: fortran/array.c:2472
+#: fortran/array.c:2484
 #, gcc-internal-format
 msgid "gfc_array_dimen_size(): Bad EXPR_ARRAY expr"
 msgstr ""
 
-#: fortran/array.c:2620
+#: fortran/array.c:2632
 #, gcc-internal-format
 msgid "gfc_find_array_ref(): No ref found"
 msgstr ""
@@ -54381,7 +54448,7 @@
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or PROCEDURE"
 msgstr "实参‘%s’(属于内建函数‘%s’，位于 %L)必须为 INTEGER 或 PROCEDURE"
 
-#: fortran/check.c:205 fortran/check.c:6658
+#: fortran/check.c:205 fortran/check.c:6661
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be a constant"
 msgstr "%2$L 处初始化表达式中的函数 ‘%1$qs’ 必须是一个内建函数"
@@ -54496,7 +54563,7 @@
 msgid "Unequal character lengths (%ld/%ld) in %s at %L"
 msgstr "%4$L处 %3$s 中字符长度不相等 (%1$ld/%2$ld)"
 
-#: fortran/check.c:946 fortran/check.c:6602
+#: fortran/check.c:946 fortran/check.c:6605
 #, fuzzy, gcc-internal-format
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have the same type"
 msgstr "%4$L处‘%3$s’内建函数的‘%1$s’和‘%2$s’实参类型必须相同"
@@ -54731,9 +54798,9 @@
 msgstr "%3$L处内建函数‘%2$s’的实参‘%1$s’必须是一个标量"
 
 #: fortran/check.c:1939 fortran/check.c:2525 fortran/check.c:2628
-#: fortran/check.c:2835 fortran/check.c:2880 fortran/check.c:4256
-#: fortran/check.c:4390 fortran/check.c:4445 fortran/check.c:5515
-#: fortran/check.c:5644
+#: fortran/check.c:2835 fortran/check.c:2880 fortran/check.c:4259
+#: fortran/check.c:4393 fortran/check.c:4448 fortran/check.c:5518
+#: fortran/check.c:5647
 #, fuzzy, gcc-internal-format
 msgid "%qs intrinsic with KIND argument at %L"
 msgstr "%L处内建 REPEAT 的 NCOPIES 实参是负的"
@@ -54928,7 +54995,7 @@
 msgid "NULL intrinsic with allocatable MOLD at %L"
 msgstr "Fortran 2003:空值 intrinsic 与 allocatable 铸型于 %L"
 
-#: fortran/check.c:3768 fortran/check.c:5591
+#: fortran/check.c:3768 fortran/check.c:5594
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must provide at least as many elements as there are .TRUE. values in %qs (%ld/%d)"
 msgstr "%3$L处内建函数‘%2$s’的实参‘%1$s’必须至少具有与‘%4$s’(%5$ld/%6$d)中 .TRUE. 值一样多的元素"
@@ -54948,374 +55015,374 @@
 msgid "%qs argument of %qs intrinsic at %L must not be a subobject of %qs"
 msgstr "%2$L 处初始化表达式中的函数 ‘%1$qs’ 必须是一个内建函数"
 
-#: fortran/check.c:3901
+#: fortran/check.c:3904
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The argument of the RANK intrinsic at %L must be a data object"
 msgstr "%3$L处内建函数‘%2$s’的实参‘%1$s’必须是一个变量"
 
-#: fortran/check.c:4005
+#: fortran/check.c:4008
 #, fuzzy, gcc-internal-format
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L must be an array of constant size"
 msgstr "‘reshape’内建函数的‘shape’实参在%L处必须是大小为常量的数组"
 
-#: fortran/check.c:4015
+#: fortran/check.c:4018
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L is empty"
 msgstr "%2$L 处初始化表达式中的函数 ‘%1$qs’ 必须是一个内建函数"
 
-#: fortran/check.c:4022
+#: fortran/check.c:4025
 #, fuzzy, gcc-internal-format
 msgid "%<shape%> argument of %<reshape%> intrinsic at %L has more than %d elements"
 msgstr "‘reshape’内建函数的‘shape’实参在%L处有多于 %d 个的元素"
 
-#: fortran/check.c:4039
+#: fortran/check.c:4042
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has negative element (%d)"
 msgstr "%3$L处内建‘%2$s’内建函数的‘%1$s’实参有负的元素(%4$d)"
 
-#: fortran/check.c:4071
+#: fortran/check.c:4074
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Complex argument of LOG at %L cannot be zero"
 msgid "Element %d of actual argument of RESHAPE at %L cannot be negative"
 msgstr "%L处 LOG 的复数实参不可为零"
 
-#: fortran/check.c:4109
+#: fortran/check.c:4112
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has wrong number of elements (%d/%d)"
 msgstr "%3$L处‘%2$s’内建函数的‘%1$s’实参的元素数错误(%4$d/%5$d)"
 
-#: fortran/check.c:4127
+#: fortran/check.c:4130
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has out-of-range dimension (%d)"
 msgstr "%3$L处内建‘%2$s’内建函数的‘%1$s’实参维数越界(%4$d)"
 
-#: fortran/check.c:4136
+#: fortran/check.c:4139
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L has invalid permutation of dimensions (dimension %qd duplicated)"
 msgstr "%3$L处‘%2$s’内建函数的‘%1$s’实参维数置换无效(维数%4$d重复)"
 
-#: fortran/check.c:4172
+#: fortran/check.c:4175
 #, gcc-internal-format, gfc-internal-format
 msgid "Without padding, there are not enough elements in the intrinsic RESHAPE source at %L to match the shape"
 msgstr "若没有填充，%L处内建 ESHAPE 源中没有足够的元素去与外形匹配"
 
-#: fortran/check.c:4189 fortran/check.c:4208
+#: fortran/check.c:4192 fortran/check.c:4211
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L cannot be of type %s"
 msgstr "%3$L处内建函数‘%2$s’的实参‘%1$s’必须是 %4$s"
 
-#: fortran/check.c:4199 fortran/check.c:4218
+#: fortran/check.c:4202 fortran/check.c:4221
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of an extensible type"
 msgstr "%3$L处内建函数‘%2$s’的实参‘%1$s’必须具有可扩展类型"
 
-#: fortran/check.c:4317
+#: fortran/check.c:4320
 #, fuzzy, gcc-internal-format
 msgid "SELECTED_REAL_KIND with neither %<P%> nor %<R%> argument at %L"
 msgstr "Fortran 2008:SELECTED_REAL_KIND 与 neither‘P’nor‘R’参数于 %L"
 
-#: fortran/check.c:4348
+#: fortran/check.c:4351
 #, fuzzy, gcc-internal-format
 msgid "%qs intrinsic with RADIX argument at %L"
 msgstr "%L处内建 REPEAT 的 NCOPIES 实参是负的"
 
-#: fortran/check.c:4383
+#: fortran/check.c:4386
 #, fuzzy, gcc-internal-format
 msgid "%<source%> argument of %<shape%> intrinsic at %L must not be an assumed size array"
 msgstr "‘shape’内建函数的‘source’实参在%L处不能是假定大小的数组"
 
-#: fortran/check.c:4460 fortran/check.c:6641
+#: fortran/check.c:4463 fortran/check.c:6644
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be a procedure"
 msgstr "%3$L处内建函数‘%2$s’的实参‘%1$s’必须是一个标量"
 
-#: fortran/check.c:4473 fortran/check.c:4612 fortran/check.c:6633
+#: fortran/check.c:4476 fortran/check.c:4615 fortran/check.c:6636
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be TYPE(*)"
 msgstr "%3$L处内建函数‘%2$s’的实参‘%1$s’不能是 INTENT(IN)"
 
-#: fortran/check.c:4484 fortran/check.c:4624
+#: fortran/check.c:4487 fortran/check.c:4627
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L shall not be an assumed-size array"
 msgstr "‘shape’内建函数的‘source’实参在%L处不能是假定大小的数组"
 
-#: fortran/check.c:4554
+#: fortran/check.c:4557
 #, gcc-internal-format
 msgid "is_c_interoperable(): gfc_simplify_expr failed"
 msgstr ""
 
-#: fortran/check.c:4603
+#: fortran/check.c:4606
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be an interoperable data entity: %s"
 msgstr "%3$L处内建函数‘%2$s’的实参‘%1$s’必须是一个数组"
 
-#: fortran/check.c:4642
+#: fortran/check.c:4645
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_1 at %L to C_ASSOCIATED shall have the type TYPE(C_PTR) or TYPE(C_FUNPTR)"
 msgstr ""
 
-#: fortran/check.c:4656
+#: fortran/check.c:4659
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument C_PTR_2 at %L to C_ASSOCIATED shall have the same type as C_PTR_1: %s instead of %s"
 msgstr ""
 
-#: fortran/check.c:4680
+#: fortran/check.c:4683
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_POINTER shall have the type TYPE(C_PTR)"
 msgstr ""
 
-#: fortran/check.c:4692
+#: fortran/check.c:4695
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER must be a pointer"
 msgstr "%L 实参维数必须是标量"
 
-#: fortran/check.c:4699
+#: fortran/check.c:4702
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FPTR argument at %L to C_F_POINTER shall not be polymorphic"
 msgstr "‘%s’的实参在%L处必须是一个指针"
 
-#: fortran/check.c:4706
+#: fortran/check.c:4709
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_POINTER shall not be coindexed"
 msgstr "%L处数据传输元素不能有 POINTER 组件"
 
-#: fortran/check.c:4713
+#: fortran/check.c:4716
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected SHAPE argument at %L to C_F_POINTER with scalar FPTR"
 msgstr ""
 
-#: fortran/check.c:4719
+#: fortran/check.c:4722
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected SHAPE argument to C_F_POINTER with array FPTR at %L"
 msgstr ""
 
-#: fortran/check.c:4738
+#: fortran/check.c:4741
 #, gcc-internal-format, gfc-internal-format
 msgid "SHAPE argument at %L to C_F_POINTER must have the same size as the RANK of FPTR"
 msgstr ""
 
-#: fortran/check.c:4748
+#: fortran/check.c:4751
 #, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic FPTR at %L to C_F_POINTER"
 msgstr ""
 
-#: fortran/check.c:4753
+#: fortran/check.c:4756
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array FPTR at %L to C_F_POINTER: %s"
 msgstr ""
 
-#: fortran/check.c:4769
+#: fortran/check.c:4772
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument CPTR at %L to C_F_PROCPOINTER shall have the type TYPE(C_FUNPTR)"
 msgstr ""
 
-#: fortran/check.c:4781
+#: fortran/check.c:4784
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall be a procedure pointer"
 msgstr "实际参数到‘%s’于 %L 必须是 polymorphic"
 
-#: fortran/check.c:4788
+#: fortran/check.c:4791
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument FPTR at %L to C_F_PROCPOINTER shall not be coindexed"
 msgstr "实际参数到‘%s’于 %L 必须是 polymorphic"
 
-#: fortran/check.c:4794
+#: fortran/check.c:4797
 #, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure pointer at %L to C_F_PROCPOINTER"
 msgstr ""
 
-#: fortran/check.c:4808
+#: fortran/check.c:4811
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall not be coindexed"
 msgstr "%L处数据传输元素不能有 POINTER 组件"
 
-#: fortran/check.c:4823
+#: fortran/check.c:4826
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L is invalid as X argument to C_FUNLOC"
 msgstr "%2$L处的函数返回值‘%1$s’处没有隐式类型"
 
-#: fortran/check.c:4831
+#: fortran/check.c:4834
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_FUNLOC shall be a procedure or a procedure pointer"
 msgstr ""
 
-#: fortran/check.c:4837
+#: fortran/check.c:4840
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable procedure at %L to C_FUNLOC"
 msgstr "%2$C处的过程‘%1$s’已经在%3$L处被定义"
 
-#: fortran/check.c:4851
+#: fortran/check.c:4854
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall not be coindexed"
 msgstr "%L处数据传输元素不能有 POINTER 组件"
 
-#: fortran/check.c:4857
+#: fortran/check.c:4860
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "X argument at %L to C_LOC shall not be polymorphic"
 msgstr "‘%s’的实参在%L处必须是一个指针"
 
-#: fortran/check.c:4868
+#: fortran/check.c:4871
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall have either the POINTER or the TARGET attribute"
 msgstr "%C处的组件必须有 POINTER 属性"
 
-#: fortran/check.c:4876
+#: fortran/check.c:4879
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument X at %L to C_LOC shall be not be a zero-sized string"
 msgstr "参数‘S’的最近的于 %L 不应该是零"
 
-#: fortran/check.c:4885
+#: fortran/check.c:4888
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Argument at %L to C_LOC shall not be polymorphic"
 msgstr "‘%s’的实参在%L处必须是一个指针"
 
-#: fortran/check.c:4892
+#: fortran/check.c:4895
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Noninteroperable array at %L as argument to C_LOC: %s"
 msgstr "缺少参数“%s”，在调用“%s”时，位于 %L"
 
-#: fortran/check.c:4903
+#: fortran/check.c:4906
 #, gcc-internal-format, gfc-internal-format
 msgid "Array of interoperable type at %L to C_LOC which is nonallocatable and neither assumed size nor explicit size"
 msgstr ""
 
-#: fortran/check.c:4908
+#: fortran/check.c:4911
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array section at %L to C_LOC"
 msgstr "%C处 EQUIVALENCE 中的数组引用不能是个数组段"
 
-#: fortran/check.c:4936
+#: fortran/check.c:4939
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "non double precision REAL argument to %s intrinsic at %L"
 msgstr "%2$L处 %1$s 内建函数缺少实参"
 
-#: fortran/check.c:4949
+#: fortran/check.c:4952
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be less than rank %d"
 msgstr "%3$L处内建函数‘%2$s’的实参‘%1$s’秩必须小于 %4$d"
 
-#: fortran/check.c:4968
+#: fortran/check.c:4971
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L is not a valid dimension index"
 msgstr "%3$L处‘%2$s’内建函数的‘%1$s’实参不是一个有效的维数索引"
 
-#: fortran/check.c:5231
+#: fortran/check.c:5234
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s argument to IMAGE_INDEX must be a rank one array at %L"
 msgstr "‘%s’的实参在%L处必须是一个指针"
 
-#: fortran/check.c:5242
+#: fortran/check.c:5245
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The number of array elements of the SUB argument to IMAGE_INDEX at %L shall be %d (corank) not %d"
 msgstr "数组元素数量的子参数到 IMAGE_INDEX 于 %L 应该是 %d (corank) 无法 %d"
 
-#: fortran/check.c:5275
+#: fortran/check.c:5278
 #, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to NUM_IMAGES at %L"
 msgstr ""
 
-#: fortran/check.c:5288
+#: fortran/check.c:5291
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FAILED= argument to NUM_IMAGES at %L"
 msgstr "铸型参数到空值必要项于 %L"
 
-#: fortran/check.c:5312
+#: fortran/check.c:5315
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "TEAM argument at %L to the intrinsic TEAM_NUMBER shall be of type TEAM_TYPE"
 msgstr "%3$L处内建函数‘%2$s’的实参‘%1$s’必须具有种别 %4$d"
 
-#: fortran/check.c:5338
+#: fortran/check.c:5341
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DIM argument without COARRAY argument not allowed for THIS_IMAGE intrinsic at %L"
 msgstr "DIM 参数而无需数组参数不允许用于 THIS_IMAGE intrinsic 于 %L"
 
-#: fortran/check.c:5345
+#: fortran/check.c:5348
 #, gcc-internal-format, gfc-internal-format
 msgid "The DISTANCE argument may not be specified together with the COARRAY or DIM argument in intrinsic at %L"
 msgstr ""
 
-#: fortran/check.c:5356
+#: fortran/check.c:5359
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected DIM argument with noncoarray argument at %L"
 msgstr "%L处实参维数必须具有 INTEGER 类型"
 
-#: fortran/check.c:5374
+#: fortran/check.c:5377
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DISTANCE= argument to THIS_IMAGE at %L"
 msgstr "%L处按值传递的实参不具有数字类型"
 
-#: fortran/check.c:5454
+#: fortran/check.c:5457
 #, fuzzy, gcc-internal-format
 msgid "%<MOLD%> argument of %<TRANSFER%> intrinsic at %L must not be %s"
 msgstr "%L处‘TRANSER’内建函数的‘MOLD’参数不能是 %s"
 
-#: fortran/check.c:5483
+#: fortran/check.c:5486
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic TRANSFER at %L has partly undefined result: source size %ld < result size %ld"
 msgstr "%L处内建 TRANSFER 有部分未定义的结果：源尺寸 %ld < 结果尺寸 %ld"
 
-#: fortran/check.c:5605
+#: fortran/check.c:5608
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must have the same rank as %qs or be a scalar"
 msgstr "%3$L处内建函数‘%2$s’的实参‘%1$s’必须是标量或者具有与‘%4$s’一样的秩"
 
-#: fortran/check.c:5618
+#: fortran/check.c:5621
 #, fuzzy, gcc-internal-format
 msgid "%qs and %qs arguments of %qs intrinsic at %L must have identical shape."
 msgstr "%4$L处‘%3$s’内建函数的‘%1$s’和‘%2$s’实参必须有相同的外形。"
 
-#: fortran/check.c:5861 fortran/check.c:5893
+#: fortran/check.c:5864 fortran/check.c:5896
 #, fuzzy, gcc-internal-format
 msgid "Size of %qs argument of %qs intrinsic at %L too small (%i/%i)"
 msgstr "%3$L处内建函数‘%2$s’的实参‘%1$s’的大小太小(%4$i/%5$i)"
 
-#: fortran/check.c:5901
+#: fortran/check.c:5904
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many arguments to %s at %L"
 msgstr "给予函数 %s 的参数太多，于 %L"
 
-#: fortran/check.c:5919
+#: fortran/check.c:5922
 #, gcc-internal-format
 msgid "fe_runtime_error string must be null terminated"
 msgstr ""
 
-#: fortran/check.c:5931
+#: fortran/check.c:5934
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "fe_runtime_error: Wrong number of arguments (%d instead of %d)"
 msgstr "模板参数数目不对(不应是 %d 个而应是 %d 个)"
 
-#: fortran/check.c:5971
+#: fortran/check.c:5974
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "COUNT argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr "%L处 NEAREST 的第二个参数不能为 0"
 
-#: fortran/check.c:5990
+#: fortran/check.c:5993
 #, gcc-internal-format, gfc-internal-format
 msgid "Real COUNT_RATE argument to SYSTEM_CLOCK at %L"
 msgstr ""
 
-#: fortran/check.c:6000
+#: fortran/check.c:6003
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "COUNT_RATE argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr "%L处 NEAREST 的第二个参数不能为 0"
 
-#: fortran/check.c:6017
+#: fortran/check.c:6020
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "COUNT_MAX argument to SYSTEM_CLOCK at %L has non-default kind"
 msgstr "%L处 NEAREST 的第二个参数不能为 0"
 
-#: fortran/check.c:6234
+#: fortran/check.c:6237
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be of a kind not wider than the default kind (%d)"
 msgstr "%3$L处内建函数‘%2$s’的实参‘%1$s’的种别必须不能比默认种别(%4$d)宽"
 
-#: fortran/check.c:6586 fortran/check.c:6594
+#: fortran/check.c:6589 fortran/check.c:6597
 #, fuzzy, gcc-internal-format
 msgid "%qs argument of %qs intrinsic at %L must be INTEGER or LOGICAL"
 msgstr "实参‘%s’(属于内建函数‘%s’，位于 %L)必须为 INTEGER 或 LOGICAL"
 
-#: fortran/check.c:6625
+#: fortran/check.c:6628
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic function NULL at %L cannot be an actual argument to STORAGE_SIZE, because it returns a disassociated pointer"
 msgstr ""
@@ -55327,7 +55394,7 @@
 
 #. Since the extension field is 8 bit wide, we can only have
 #. up to 255 extension levels.
-#: fortran/class.c:727 fortran/decl.c:3636 fortran/decl.c:10066
+#: fortran/class.c:727 fortran/decl.c:3655 fortran/decl.c:10091
 #, fuzzy, gcc-internal-format
 msgid "Maximum extension level reached with type %qs at %L"
 msgstr "%2$L处类型‘%1$s’达到了最大的扩展级别"
@@ -55352,43 +55419,48 @@
 msgid "non-constant array in DATA statement %L"
 msgstr "%L处 DATA 语句中有非常量数组"
 
-#: fortran/data.c:137
+#: fortran/data.c:140
 #, gcc-internal-format, gfc-internal-format
 msgid "failure to simplify substring reference in DATA statement at %L"
 msgstr "%L处 DATA 语句简化子串引用时失败"
 
-#: fortran/data.c:170
+#: fortran/data.c:173
 #, gcc-internal-format, gfc-internal-format
 msgid "Unused initialization string at %L because variable has zero length"
 msgstr ""
 
-#: fortran/data.c:176
+#: fortran/data.c:179
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Initialization string at %L was truncated to fit the variable (%ld/%ld)"
 msgstr "初始化字符串被截断，以匹配%L处的变量"
 
-#: fortran/data.c:265
+#: fortran/data.c:268
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L already is initialized at %L"
 msgid "%qs at %L already is initialized at %L"
 msgstr "%2$L处的‘%1$s’已于 %3$L处被初始化"
 
-#: fortran/data.c:289
+#: fortran/data.c:292
 #, gcc-internal-format, gfc-internal-format
 msgid "Data element below array lower bound at %L"
 msgstr "%L处数据元素低于数组下限"
 
-#: fortran/data.c:306 fortran/data.c:395
+#: fortran/data.c:309 fortran/data.c:398
 #, gcc-internal-format, gfc-internal-format
 msgid "Data element above array upper bound at %L"
 msgstr "%L处数据元素高于数组上限"
 
-#: fortran/data.c:336 fortran/data.c:505
+#: fortran/data.c:339 fortran/data.c:496
 #, fuzzy, gcc-internal-format
 msgid "re-initialization of %qs at %L"
 msgstr "(在%qs的初始化附近)"
 
-#: fortran/data.c:727
+#: fortran/data.c:515
+#, fuzzy, gcc-internal-format
+msgid "Nonpointer object %qs with default initialization shall not appear in a DATA statement at %L"
+msgstr "%2$C处有初始值设定的变量‘%1$s’已经出现在一个 DATA 语句中"
+
+#: fortran/data.c:738
 #, gcc-internal-format
 msgid "TODO: Vector sections in data statements"
 msgstr ""
@@ -55413,808 +55485,808 @@
 msgid "Invalid initializer %s in Data statement at %C"
 msgstr "%2$C处 DATA 语句初始值设定 %1$s 无效"
 
-#: fortran/decl.c:536
+#: fortran/decl.c:537
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C is not allowed in a PURE procedure"
 msgstr "初始化不允许出现在%C处的 PURE 过程中"
 
-#: fortran/decl.c:573
+#: fortran/decl.c:574
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgid "DATA statement at %C cannot appear within an INTERFACE"
 msgstr "%C处的 ENTRY 语句不能出现在 INTERFACE 中"
 
-#: fortran/decl.c:597
+#: fortran/decl.c:598
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid initializer %s in Data statement at %C"
 msgid "Invalid substring in data-implied-do at %L in DATA statement"
 msgstr "%2$C处 DATA 语句初始值设定 %1$s 无效"
 
-#: fortran/decl.c:619
+#: fortran/decl.c:620
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %C is not allowed in a PURE procedure"
 msgstr "DATA 语句不允许出现在%C处的 PURE 过程中"
 
-#: fortran/decl.c:664
+#: fortran/decl.c:662
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Empty old style initializer list at %C"
 msgstr "创建旧风格表格"
 
-#: fortran/decl.c:684
+#: fortran/decl.c:671
 #, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "Array component of structure at %C must have an explicit shape"
+msgid "Array in initializer list at %L must have an explicit shape"
+msgstr "%C处结构的数组组件必须有显式的外形"
+
+#: fortran/decl.c:694
+#, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "extra elements in scalar initializer"
 msgid "Repeat spec invalid in scalar initializer at %C"
 msgstr "标量初始值设定中有多余元素"
 
-#: fortran/decl.c:689
+#: fortran/decl.c:699
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Repeat spec must be an integer at %C"
 msgstr "数组边界不是一个整数常量"
 
-#: fortran/decl.c:698
+#: fortran/decl.c:710
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected alternate return label at %C"
 msgid "Expected data constant after repeat spec at %C"
 msgstr "%C处需要替代的返回标号"
 
-#: fortran/decl.c:729
+#: fortran/decl.c:742
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected scalar initialization expression at %C"
 msgid "End of scalar initializer expected at %C"
 msgstr "%C处需要标量初始化表达式"
 
-#: fortran/decl.c:758
+#: fortran/decl.c:773
 #, fuzzy, gcc-internal-format, gfc-internal-format
-#| msgid "nonconstant array index in initializer"
-msgid "Expected constant array-spec in initializer list at %L"
-msgstr "初始值设定中数组索引不是常数"
-
-#: fortran/decl.c:767
-#, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "excess elements in array initializer"
 msgid "Not enough elements in array initializer at %C"
 msgstr "数组初始值设定项中有多余的元素"
 
-#: fortran/decl.c:769
+#: fortran/decl.c:775
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "excess elements in array initializer"
 msgid "Too many elements in array initializer at %C"
 msgstr "数组初始值设定项中有多余的元素"
 
-#: fortran/decl.c:790
+#: fortran/decl.c:795
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in OpenMP variable list at %C"
 msgid "Syntax error in old style initializer list at %C"
 msgstr "%C处的 OpenMP 变量列表语法错误"
 
-#: fortran/decl.c:812
+#: fortran/decl.c:821
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The assumed-rank array at %C shall not have a codimension"
 msgstr "%L处数据传输元素不能有 POINTER 组件"
 
-#: fortran/decl.c:876
+#: fortran/decl.c:885
 #, gcc-internal-format, gfc-internal-format
 msgid "Sum of array rank %d and corank %d at %C exceeds maximum allowed dimensions of %d"
 msgstr ""
 
-#: fortran/decl.c:900
+#: fortran/decl.c:909
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad INTENT specification at %C"
 msgstr "%C处错误的 INTENT 规格"
 
-#: fortran/decl.c:921
+#: fortran/decl.c:930
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "deferred type parameter at %C"
 msgstr "%C处重复的 DEFERRED 语句"
 
-#: fortran/decl.c:1004 fortran/resolve.c:11705
+#: fortran/decl.c:1013 fortran/resolve.c:11725
 #, gcc-internal-format, gfc-internal-format
 msgid "Scalar INTEGER expression expected at %L"
 msgstr ""
 
-#: fortran/decl.c:1030
+#: fortran/decl.c:1039
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Old-style character length at %C"
 msgstr "%C处字符长度规格语法错误"
 
-#: fortran/decl.c:1061
+#: fortran/decl.c:1070
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in character length specification at %C"
 msgstr "%C处字符长度规格语法错误"
 
-#: fortran/decl.c:1212 fortran/decl.c:1217 fortran/decl.c:1266
+#: fortran/decl.c:1221 fortran/decl.c:1226 fortran/decl.c:1275
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %C is already defined at %L"
 msgid "Procedure %qs at %C is already defined at %L"
 msgstr "%2$C处的过程‘%1$s’已经在%3$L处被定义"
 
-#: fortran/decl.c:1222
+#: fortran/decl.c:1231
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %C is already defined at %L"
 msgid "Contained procedure %qs at %C clashes with procedure defined at %L"
 msgstr "%2$C处的过程‘%1$s’已经在%3$L处被定义"
 
-#: fortran/decl.c:1231
+#: fortran/decl.c:1240
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is already defined as a generic interface at %L"
 msgid "Name %qs at %C is already defined as a generic interface at %L"
 msgstr "%2$C处的名字‘%1$s’已经在%3$L处被定义为泛型接口"
 
-#: fortran/decl.c:1244
+#: fortran/decl.c:1253
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure '%s' at %C has an explicit interface and must not have attributes declared at %L"
 msgid "Procedure %qs at %C has an explicit interface from a previous declaration"
 msgstr "过程‘%s’在%C处具有显式接口，因此不能有在%L处声明的属性"
 
-#: fortran/decl.c:1257
+#: fortran/decl.c:1266
 #, gcc-internal-format
 msgid "Procedure %qs defined in interface body at %L clashes with internal procedure defined at %C"
 msgstr ""
 
-#: fortran/decl.c:1335
+#: fortran/decl.c:1344
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L must have the BIND(C) attribute to be C interoperable"
 msgstr "%2$L处的过程‘%1$s’必须有属性才能与 C 互操作"
 
-#: fortran/decl.c:1362
+#: fortran/decl.c:1371
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because derived type %qs is not C interoperable"
 msgstr "%2$L 处类型“%1$s”是去到 BIND(C) 过程“%3$s”的参数，但不能与 C 互操作，因为派生类型“%4$s”不是与 C 可互操作的"
 
-#: fortran/decl.c:1369
+#: fortran/decl.c:1378
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument to the BIND(C) procedure %qs but is not C interoperable because it is polymorphic"
 msgstr "%2$L处变量‘%1$s’是 BIND(C) 过程‘%3$s’的参数，但它不能与 C 互操作"
 
-#: fortran/decl.c:1376
+#: fortran/decl.c:1385
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L is a dummy argument of the BIND(C) procedure %qs but may not be C interoperable"
 msgstr "%2$L处变量‘%1$s’是 BIND(C) 过程‘%3$s’的参数，但它不能与 C 互操作"
 
-#: fortran/decl.c:1391
+#: fortran/decl.c:1400
 #, fuzzy, gcc-internal-format
 msgid "Character argument %qs at %L must be length 1 because procedure %qs is BIND(C)"
 msgstr "%2$L处字符参数‘%1$s’长度必须为 1，因为过程‘%3$s’是 BIND(C)"
 
-#: fortran/decl.c:1404
+#: fortran/decl.c:1413
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L with ALLOCATABLE attribute in procedure %qs with BIND(C)"
 msgstr "%2$L处变量‘%1$s’不能有 ALLOCATABLE 属性，因为过程‘%3$s’是 BIND(C)"
 
-#: fortran/decl.c:1412
+#: fortran/decl.c:1421
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L with POINTER attribute in procedure %qs with BIND(C)"
 msgstr "%2$L处变量‘%1$s’不能有 POINTER 属性，因为过程‘%3$s’是 BIND(C)"
 
-#: fortran/decl.c:1421
+#: fortran/decl.c:1430
 #, fuzzy, gcc-internal-format
 msgid "Scalar variable %qs at %L with POINTER or ALLOCATABLE in procedure %qs with BIND(C) is not yet supported"
 msgstr "%2$L处变量‘%1$s’不能有 ALLOCATABLE 属性，因为过程‘%3$s’是 BIND(C)"
 
-#: fortran/decl.c:1430
+#: fortran/decl.c:1439
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the OPTIONAL and the VALUE attribute because procedure %qs is BIND(C)"
 msgstr "%2$L处变量‘%1$s’不能有 OPTIONAL 属性，因为过程‘%3$s’是 BIND(C)"
 
-#: fortran/decl.c:1437
+#: fortran/decl.c:1446
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L with OPTIONAL attribute in procedure %qs which is BIND(C)"
 msgstr "%2$L处变量‘%1$s’不能有 OPTIONAL 属性，因为过程‘%3$s’是 BIND(C)"
 
-#: fortran/decl.c:1448
+#: fortran/decl.c:1457
 #, fuzzy, gcc-internal-format
 msgid "Assumed-shape array %qs at %L as dummy argument to the BIND(C) procedure %qs at %L"
 msgstr "%2$L处假定外形数组‘%1$s’不能是%4$L处过程‘%3$s’的参数，因为该过程是 BIND(C)"
 
-#: fortran/decl.c:1516
+#: fortran/decl.c:1525
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C also declared as a type at %L"
 msgstr "符号‘%s’在%L处已经有了基本类型 %s"
 
-#: fortran/decl.c:1575
+#: fortran/decl.c:1584
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs in common block %qs at %C must be declared with a C interoperable kind since common block %qs is BIND(C)"
 msgstr "%3$C处公共块‘%2$s’中的变量‘%1$s’必须被声明为与 C 可互操作的种别，因为公共块‘%4$s’是 BIND(C)"
 
-#: fortran/decl.c:1615
+#: fortran/decl.c:1624
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Different CHARACTER lengths (%d/%d) in array constructor at %L"
 msgid "CHARACTER length must be a constant at %L"
 msgstr "%3$L处数组构造函数中不同 CHARACTER 长度(%1$d/%2$d)"
 
-#: fortran/decl.c:1630
+#: fortran/decl.c:1639
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CHARACTER expression at %L is being truncated (%d/%d)"
 msgid "CHARACTER expression at %L is being truncated (%ld/%ld)"
 msgstr "CHARACTER 表达式在%L处被截断(%d/%d)"
 
-#: fortran/decl.c:1638
+#: fortran/decl.c:1647
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The CHARACTER elements of the array constructor at %L must have the same length (%d/%d)"
 msgid "The CHARACTER elements of the array constructor at %L must have the same length (%ld/%ld)"
 msgstr "%L处的数组构造函数的 CHARACTER 元素必须有相同的长度(%d/%d)"
 
-#: fortran/decl.c:1729
+#: fortran/decl.c:1738
 #, fuzzy, gcc-internal-format
 msgid "Initializer not allowed for PARAMETER %qs at %C"
 msgstr "PARAMETER‘%s’在%C处不允许有初始值设定"
 
-#: fortran/decl.c:1739
+#: fortran/decl.c:1748
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER at %L is missing an initializer"
 msgstr "%L处 PARAMETER 缺少初始值设定"
 
-#: fortran/decl.c:1749
+#: fortran/decl.c:1758
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %C with an initializer already appears in a DATA statement"
 msgstr "%2$C处有初始值设定的变量‘%1$s’已经出现在一个 DATA 语句中"
 
-#: fortran/decl.c:1792
+#: fortran/decl.c:1801
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Cannot initialize parameter array at %L with variable length elements"
 msgstr "不能用初始值设定项来初始化多维数组"
 
-#: fortran/decl.c:1861
+#: fortran/decl.c:1870
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Can't initialize implied-shape array at %L with scalar"
 msgstr "不能用初始值设定项来初始化多维数组"
 
-#: fortran/decl.c:1896
+#: fortran/decl.c:1905
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-constant lower bound in implied-shape declaration at %L"
 msgstr "%C处数据声明语法错误"
 
-#: fortran/decl.c:1982 fortran/decl.c:1989
+#: fortran/decl.c:1991 fortran/decl.c:1998
 #, gcc-internal-format, gfc-internal-format
 msgid "Component at %C must have the POINTER attribute"
 msgstr "%C处的组件必须有 POINTER 属性"
 
-#: fortran/decl.c:1998
+#: fortran/decl.c:2007
 #, fuzzy, gcc-internal-format
 msgid "Component %qs with CLASS at %C must be allocatable or pointer"
 msgstr "%2$L处具有 CLASS 的组件‘%1$s’必须是可分配的或指针"
 
-#: fortran/decl.c:2007
+#: fortran/decl.c:2016
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have explicit or deferred shape"
 msgstr "%C处结构的数组组件必须有显式或延迟的外形"
 
-#: fortran/decl.c:2031 fortran/symbol.c:2230
+#: fortran/decl.c:2040 fortran/symbol.c:2244
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C already declared at %L"
 msgid "Component %qs at %C already declared at %L"
 msgstr "%2$C处的组件‘%1$s’已于 %3$L处被声明"
 
-#: fortran/decl.c:2079
+#: fortran/decl.c:2088
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer array component of structure at %C must have a deferred shape"
 msgstr "%C处结构的指针数组组件必须有延迟的外形"
 
-#: fortran/decl.c:2088
+#: fortran/decl.c:2097
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component of structure at %C must have a deferred shape"
 msgstr "%C处可分配的组件必须有延迟的外形"
 
-#: fortran/decl.c:2097
+#: fortran/decl.c:2106
 #, gcc-internal-format, gfc-internal-format
 msgid "Array component of structure at %C must have an explicit shape"
 msgstr "%C处结构的数组组件必须有显式的外形"
 
-#: fortran/decl.c:2114
+#: fortran/decl.c:2123
 #, fuzzy, gcc-internal-format
 #| msgid "a parameter list with an ellipsis can%'t match an empty parameter name list declaration"
 msgid "Type parameter %qs at %C has no corresponding entry in the type parameter name list at %L"
 msgstr "带有省略号的形参列表无法与空形参名列表声明匹配"
 
-#: fortran/decl.c:2171
+#: fortran/decl.c:2180
 #, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C is ambiguous"
 msgstr "%C处的 NULL() 初始化有歧义"
 
-#: fortran/decl.c:2188
+#: fortran/decl.c:2197
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "NULL() initialization at %C may not have MOLD"
 msgstr "%C处的 NULL() 初始化有歧义"
 
-#: fortran/decl.c:2205
+#: fortran/decl.c:2214
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of pointer at %C is not allowed in a PURE procedure"
 msgstr "%C处对指针的初始化不允许出现在 PURE 过程中"
 
-#: fortran/decl.c:2226
+#: fortran/decl.c:2235
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Error in pointer initialization at %C"
 msgstr "%C处对指针的初始化不允许出现在 PURE 过程中"
 
-#: fortran/decl.c:2233
+#: fortran/decl.c:2242
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "non-NULL pointer initialization at %C"
 msgstr "%C处的 NULL() 初始化有歧义"
 
-#: fortran/decl.c:2256
+#: fortran/decl.c:2265
 #, gcc-internal-format
 msgid "RESULT variable %qs at %L prohibits FUNCTION name %qs at %C from appearing in a specification statement"
 msgstr ""
 
-#: fortran/decl.c:2318
+#: fortran/decl.c:2327
 #, fuzzy, gcc-internal-format
 #| msgid "VALUE is not allowed inside of BLOCK at %C"
 msgid "%qs not allowed outside STRUCTURE at %C"
 msgstr "VALUE 不能用在%C处 BLOCK 内"
 
-#: fortran/decl.c:2320
+#: fortran/decl.c:2329
 #, fuzzy, gcc-internal-format
 msgid "%qs at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr "为结构字段%2$qE指定了%1$qs"
 
-#: fortran/decl.c:2327
+#: fortran/decl.c:2336
 #, fuzzy, gcc-internal-format
 msgid "%qs entity cannot have attributes at %C"
 msgstr "%qD不能有默认参数"
 
-#: fortran/decl.c:2367
+#: fortran/decl.c:2376
 #, fuzzy, gcc-internal-format
 msgid "Non-PARAMETER symbol %qs at %L can't be implied-shape"
 msgstr "指定CHARACTER(*) 函数‘%s’在%L处不能为指针值"
 
-#: fortran/decl.c:2377
+#: fortran/decl.c:2386
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Implied-shape array at %L"
 msgstr "Fortran 2008：%L处格式中的‘G0’"
 
-#: fortran/decl.c:2422
+#: fortran/decl.c:2431
 #, gcc-internal-format, gfc-internal-format
 msgid "Explicit shaped array with nonconstant bounds at %C"
 msgstr ""
 
-#: fortran/decl.c:2501
+#: fortran/decl.c:2510
 #, gcc-internal-format
 msgid "%qs at %C is a redefinition of the declaration in the corresponding interface for MODULE PROCEDURE %qs"
 msgstr ""
 
-#: fortran/decl.c:2512
+#: fortran/decl.c:2521
 #, fuzzy, gcc-internal-format
 msgid "%qs entity cannot have an initializer at %C"
 msgstr "哑元‘%s’在%L处不能有初始值设定"
 
-#: fortran/decl.c:2538 fortran/decl.c:8369
+#: fortran/decl.c:2547 fortran/decl.c:8388
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate array spec for Cray pointee at %C"
 msgstr "%C处 Cray 指针重复指定了数组"
 
-#: fortran/decl.c:2546
+#: fortran/decl.c:2555
 #, fuzzy, gcc-internal-format
 msgid "Couldn't set pointee array spec."
 msgstr "%C处 Cray 指针重复指定了数组"
 
-#: fortran/decl.c:2609
+#: fortran/decl.c:2618
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Old-style initialization at %C"
 msgstr "创建旧风格表格"
 
-#: fortran/decl.c:2617
+#: fortran/decl.c:2626
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid old style initialization for derived type component at %C"
 msgstr "引用类型的非法值初始化"
 
-#: fortran/decl.c:2630
+#: fortran/decl.c:2639
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in old style initialization of %s at %C"
 msgstr "%C处对指针的初始化不允许出现在 PURE 过程中"
 
-#: fortran/decl.c:2650 fortran/decl.c:6661
+#: fortran/decl.c:2659 fortran/decl.c:6680
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization at %C isn't for a pointer variable"
 msgstr "%C处的初始化不是为指针变量准备的"
 
-#: fortran/decl.c:2663
+#: fortran/decl.c:2672
 #, fuzzy, gcc-internal-format
 msgid "Pointer initialization at %C requires %<=>%>, not %<=%>"
 msgstr "%C处的初始化不是为指针变量准备的"
 
-#: fortran/decl.c:2672 fortran/decl.c:10240
+#: fortran/decl.c:2681 fortran/decl.c:10265
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected an initialization expression at %C"
 msgstr "%C处需要一个初始化表达式"
 
-#: fortran/decl.c:2679
+#: fortran/decl.c:2688
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgstr "%C处对变量的初始化不允许出现在 PURE 过程中"
 
-#: fortran/decl.c:2696
+#: fortran/decl.c:2705
 #, gcc-internal-format, gfc-internal-format
 msgid "Initialization of allocatable component at %C is not allowed"
 msgstr "不允许在%C处初始化可分配的组件"
 
-#: fortran/decl.c:2710
+#: fortran/decl.c:2719
 #, gcc-internal-format, gfc-internal-format
 msgid "The component with KIND or LEN attribute at %C does not not appear in the type parameter list at %L"
 msgstr ""
 
-#: fortran/decl.c:2718
+#: fortran/decl.c:2727
 #, gcc-internal-format, gfc-internal-format
 msgid "The component at %C that appears in the type parameter list at %L has neither the KIND nor LEN attribute"
 msgstr ""
 
-#: fortran/decl.c:2726
+#: fortran/decl.c:2735
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The component at %C which is a type parameter must be a scalar"
 msgstr "%3$L处‘%2$s’的指针组件‘%1$s’类型尚未声明"
 
-#: fortran/decl.c:2789 fortran/decl.c:2825
+#: fortran/decl.c:2798 fortran/decl.c:2834
 #, gcc-internal-format, gfc-internal-format
 msgid "Old-style type declaration %s*%d not supported at %C"
 msgstr "%3$C处旧式的类型声明 %1$s*%2$d 不受支持"
 
-#: fortran/decl.c:2831
+#: fortran/decl.c:2840
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonstandard type declaration %s*%d at %C"
 msgstr "%3$C处的 %1$s*%2$d 类型声明不符合标准"
 
-#: fortran/decl.c:2890 fortran/decl.c:2967
+#: fortran/decl.c:2899 fortran/decl.c:2976
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis at %C"
 msgstr "%C处缺少右括号"
 
-#: fortran/decl.c:2903 fortran/decl.c:3038
+#: fortran/decl.c:2912 fortran/decl.c:3047
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected initialization expression at %C"
 msgstr "%C处需要初始化表达式"
 
-#: fortran/decl.c:2911 fortran/decl.c:3044
+#: fortran/decl.c:2920 fortran/decl.c:3053
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected scalar initialization expression at %C"
 msgstr "%C处需要标量初始化表达式"
 
-#: fortran/decl.c:2941 fortran/decl.c:3657
+#: fortran/decl.c:2950 fortran/decl.c:3676
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d not supported for type %s at %C"
 msgstr "种别 %1$d 不为类型%3$C处 %2$s 所支持"
 
-#: fortran/decl.c:2954
+#: fortran/decl.c:2963
 #, gcc-internal-format, gfc-internal-format
 msgid "C kind type parameter is for type %s but type at %L is %s"
 msgstr "C 种别类型参数对应类型 %s 但%L处的类型却是 %s"
 
-#: fortran/decl.c:2965
+#: fortran/decl.c:2974
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing right parenthesis or comma at %C"
 msgstr "%C处缺少右括号或逗号"
 
-#: fortran/decl.c:3070
+#: fortran/decl.c:3079
 #, gcc-internal-format, gfc-internal-format
 msgid "Kind %d is not supported for CHARACTER at %C"
 msgstr "种别 %d 在%C处不为 CHARACTER 所支持"
 
-#: fortran/decl.c:3202
+#: fortran/decl.c:3211
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CHARACTER declaration at %C"
 msgstr "%C处 CHARACTER 声明语法错误"
 
-#: fortran/decl.c:3291
+#: fortran/decl.c:3310
 #, gcc-internal-format, gfc-internal-format
 msgid "RECORD at %C is an extension, enable it with -fdec-structure"
 msgstr ""
 
-#: fortran/decl.c:3304
+#: fortran/decl.c:3323
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Structure name expected after RECORD at %C"
 msgstr "%C 需要一个无名接口"
 
-#: fortran/decl.c:3417
+#: fortran/decl.c:3436
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C cannot contain both ASSUMED and DEFERRED parameters"
 msgstr ""
 
-#: fortran/decl.c:3441
+#: fortran/decl.c:3460
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Kind type parameter for entity at %L differs from the kind type parameter of the typespec"
 msgid "The type parameter spec list at %C does not contain enough parameter expressions"
 msgstr "%L实体的种别类型参数与类型限定中的种别类型参数不同"
 
-#: fortran/decl.c:3465
+#: fortran/decl.c:3484
 #, fuzzy, gcc-internal-format
 #| msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgid "The derived parameter %qs at %C does not have a default value"
 msgstr "%<operator new%>的第一个形参不能有默认参数"
 
-#: fortran/decl.c:3497
+#: fortran/decl.c:3516
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression at %L must be of INTEGER type, found %s"
 msgid "The parameter expression at %C must be of INTEGER type and not %s type"
 msgstr "%L处的表达式必须具有 INTEGER 类型而不是 %s"
 
-#: fortran/decl.c:3525
+#: fortran/decl.c:3544
 #, gcc-internal-format
 msgid "The KIND parameter %qs at %C cannot either be ASSUMED or DEFERRED"
 msgstr ""
 
-#: fortran/decl.c:3532
+#: fortran/decl.c:3551
 #, fuzzy, gcc-internal-format
 msgid "The value for the KIND parameter %qs at %C does not reduce to a constant expression"
 msgstr "%2$L处数组‘%1$s’是个变量，不能被归约为常量表达式"
 
-#: fortran/decl.c:3547
+#: fortran/decl.c:3566
 #, gcc-internal-format, gfc-internal-format
 msgid "The type parameter spec list at %C contains too many parameter expressions"
 msgstr ""
 
-#: fortran/decl.c:3556
+#: fortran/decl.c:3575
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Parameterized derived type at %C is ambiguous"
 msgstr "%L处 PARAMETER 中派生类型不兼容"
 
-#: fortran/decl.c:3819
+#: fortran/decl.c:3838
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BYTE type at %C"
 msgstr "扩展：%C处的 BYTE 类型"
 
-#: fortran/decl.c:3824
+#: fortran/decl.c:3843
 #, gcc-internal-format, gfc-internal-format
 msgid "BYTE type used at %C is not available on the target machine"
 msgstr "%C处使用到的 BYTE 类型在目标机上不可用"
 
-#: fortran/decl.c:3846
+#: fortran/decl.c:3865
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C is not allowed for components"
 msgstr "%C处 TYPE 中的组件必须先于 CONTAINS"
 
-#: fortran/decl.c:3849
+#: fortran/decl.c:3868
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed type at %C"
 msgstr "%C处非预期的 TYPE IS 语句"
 
-#: fortran/decl.c:3872 fortran/decl.c:3903 fortran/decl.c:3932
-#: fortran/decl.c:4216
+#: fortran/decl.c:3891 fortran/decl.c:3922 fortran/decl.c:3951
+#: fortran/decl.c:4235
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "TYPE with intrinsic-type-spec at %C"
 msgstr "%C处类型指定无效"
 
-#: fortran/decl.c:3928
+#: fortran/decl.c:3947
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DOUBLE COMPLEX at %C"
 msgstr "扩展：‘%s’重初始化于 %L"
 
-#: fortran/decl.c:3971 fortran/decl.c:4107 fortran/decl.c:4119
-#: fortran/decl.c:4133 fortran/decl.c:4611 fortran/decl.c:4619
+#: fortran/decl.c:3990 fortran/decl.c:4126 fortran/decl.c:4138
+#: fortran/decl.c:4152 fortran/decl.c:4630 fortran/decl.c:4638
 #, fuzzy, gcc-internal-format
 msgid "Type name %qs at %C is ambiguous"
 msgstr "%C处 TYPE 定义中的歧义符号"
 
-#: fortran/decl.c:4066
+#: fortran/decl.c:4085
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CLASS statement at %C"
 msgstr "未定义 C++ 基类"
 
-#: fortran/decl.c:4148
+#: fortran/decl.c:4167
 #, fuzzy, gcc-internal-format
 msgid "Type name %qs at %C conflicts with previously declared entity at %L, which has the same name"
 msgstr "类型名称‘%s’于 %C 冲突与在之前声明的实体于 %L, 该项有同名"
 
-#: fortran/decl.c:4287
+#: fortran/decl.c:4306
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate IMPLICIT NONE statement at %C"
 msgstr "%C处 IMPLICIT NONE 语句重复"
 
-#: fortran/decl.c:4296
+#: fortran/decl.c:4315
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT NONE with spec list at %C"
 msgstr ""
 
-#: fortran/decl.c:4355
+#: fortran/decl.c:4374
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing character range in IMPLICIT at %C"
 msgstr "%C处 IMPLICIT 缺少字符范围"
 
-#: fortran/decl.c:4401
+#: fortran/decl.c:4420
 #, gcc-internal-format, gfc-internal-format
 msgid "Letters must be in alphabetic order in IMPLICIT statement at %C"
 msgstr "%C处 IMPLICIT 语句中的字母必须按序排列"
 
-#: fortran/decl.c:4454
+#: fortran/decl.c:4473
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IMPLICIT statement at %C following an IMPLICIT NONE (type) statement"
 msgstr "%C处 SAVE 语句跟随空白 SAVE 语句"
 
-#: fortran/decl.c:4464
+#: fortran/decl.c:4483
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty IMPLICIT statement at %C"
 msgstr "%C处 IMPLICIT 语句为空"
 
-#: fortran/decl.c:4570
+#: fortran/decl.c:4589
 #, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgstr "%C处 IMPORT 语句只允许出现在接口体中"
 
-#: fortran/decl.c:4577
+#: fortran/decl.c:4596
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "IMPORT statement at %C only permitted in an INTERFACE body"
 msgid "F2008: C1210 IMPORT statement at %C is not permitted in a module procedure interface body"
 msgstr "%C处 IMPORT 语句只允许出现在接口体中"
 
-#: fortran/decl.c:4582
+#: fortran/decl.c:4601
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IMPORT statement at %C"
 msgstr "%C处 IMPORT 语句只允许出现在接口体中"
 
-#: fortran/decl.c:4596
+#: fortran/decl.c:4615
 #, gcc-internal-format, gfc-internal-format
 msgid "Expecting list of named entities at %C"
 msgstr "%C处需要有名实体列表"
 
-#: fortran/decl.c:4625
+#: fortran/decl.c:4644
 #, fuzzy, gcc-internal-format
 msgid "Cannot IMPORT %qs from host scoping unit at %C - does not exist."
 msgstr "不能从%2$C处主机作用域单元 IMPORT‘%1$s’- 不存在。"
 
-#: fortran/decl.c:4632
+#: fortran/decl.c:4651
 #, fuzzy, gcc-internal-format
 msgid "%qs is already IMPORTed from host scoping unit at %C"
 msgstr "‘%s’已经从%C处主机作用域单元导入。"
 
-#: fortran/decl.c:4673
+#: fortran/decl.c:4692
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in IMPORT statement at %C"
 msgstr "%C处的 IMPORT 语句语法错误"
 
-#: fortran/decl.c:5010
+#: fortran/decl.c:5029
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing codimension specification at %C"
 msgstr "%C处没有维数规格"
 
-#: fortran/decl.c:5012
+#: fortran/decl.c:5031
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing dimension specification at %C"
 msgstr "%C处没有维数规格"
 
-#: fortran/decl.c:5107
+#: fortran/decl.c:5126
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s attribute at %L"
 msgstr "重复的 %s 属性，位于 %L"
 
-#: fortran/decl.c:5124
+#: fortran/decl.c:5143
 #, gcc-internal-format
 msgid "%s at %L is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:5141
+#: fortran/decl.c:5160
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ALLOCATABLE attribute at %C in a TYPE definition"
 msgstr "%L处的属性不允许出现在 TYPE 定义中"
 
-#: fortran/decl.c:5150
+#: fortran/decl.c:5169
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "KIND attribute at %C in a TYPE definition"
 msgstr "%L处的属性不允许出现在 TYPE 定义中"
 
-#: fortran/decl.c:5158
+#: fortran/decl.c:5177
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be INTEGER"
 msgstr "%2$L 处初始化表达式中的函数 ‘%1$qs’ 必须是一个内建函数"
 
-#: fortran/decl.c:5165
+#: fortran/decl.c:5184
 #, gcc-internal-format, gfc-internal-format
 msgid "Component with KIND attribute at %C must be default integer kind (%d)"
 msgstr ""
 
-#: fortran/decl.c:5174
+#: fortran/decl.c:5193
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LEN attribute at %C in a TYPE definition"
 msgstr "%L处的属性不允许出现在 TYPE 定义中"
 
-#: fortran/decl.c:5182
+#: fortran/decl.c:5201
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be INTEGER"
 msgstr "%2$L 处初始化表达式中的函数 ‘%1$qs’ 必须是一个内建函数"
 
-#: fortran/decl.c:5189
+#: fortran/decl.c:5208
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component with LEN attribute at %C must be default integer kind (%d)"
 msgstr "%2$L处具有 CLASS 的组件‘%1$s’必须是可分配的或指针"
 
-#: fortran/decl.c:5198
+#: fortran/decl.c:5217
 #, gcc-internal-format, gfc-internal-format
 msgid "Attribute at %L is not allowed in a TYPE definition"
 msgstr "%L处的属性不允许出现在 TYPE 定义中"
 
-#: fortran/decl.c:5216
+#: fortran/decl.c:5235
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Attribute %s at %L in a TYPE definition"
 msgstr "%L处的属性不允许出现在 TYPE 定义中"
 
-#: fortran/decl.c:5226
+#: fortran/decl.c:5245
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute at %L is not allowed outside of the specification part of a module"
 msgstr "%2$L处的 %1$s 属性不允许出现在模块规格说明以外"
 
-#: fortran/decl.c:5236
+#: fortran/decl.c:5255
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Attribute at %L is not allowed in a TYPE definition"
 msgid "Attribute at %L is not allowed outside a TYPE definition"
 msgstr "%L处的属性不允许出现在 TYPE 定义中"
 
-#: fortran/decl.c:5249
+#: fortran/decl.c:5268
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS attribute at %C"
 msgstr "%C处 ASYNCHRONOUS 语句语法错误"
 
-#: fortran/decl.c:5260
+#: fortran/decl.c:5279
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS attribute at %C"
 msgstr "%C处需要绑定属性"
 
-#: fortran/decl.c:5315 fortran/decl.c:8673
+#: fortran/decl.c:5334 fortran/decl.c:8692
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED at %C only allowed in specification part of a module"
 msgstr "%C处的 PROTECTED 仅允许出现在模块规格说明部分内"
 
-#: fortran/decl.c:5321
+#: fortran/decl.c:5340
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute at %C"
 msgstr "%C处 PROTECTED 语句语法错误"
 
-#: fortran/decl.c:5355
+#: fortran/decl.c:5374
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VALUE attribute at %C"
 msgstr "%L处指定了重复的 VALUE 属性"
 
-#: fortran/decl.c:5362
+#: fortran/decl.c:5381
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE attribute at %C"
 msgstr "%C处的 VOLATILE 语句语法错误"
 
-#: fortran/decl.c:5369
+#: fortran/decl.c:5388
 #, gcc-internal-format
 msgid "match_attr_spec(): Bad attribute"
 msgstr ""
 
-#: fortran/decl.c:5410
+#: fortran/decl.c:5429
 #, gcc-internal-format, gfc-internal-format
 msgid "Multiple identifiers provided with single NAME= specifier at %C"
 msgstr "%C处为单个 NAME= 指定了多个标识符"
 
-#: fortran/decl.c:5508
+#: fortran/decl.c:5527
 #, fuzzy, gcc-internal-format
 msgid "Implicitly declared BIND(C) function %qs at %L may not be C interoperable"
 msgstr "%2$L处隐式声明的 BIND(C) 函数‘%1$s’不能与 C 互操作"
 
-#: fortran/decl.c:5530
+#: fortran/decl.c:5549
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L may not be a C interoperable kind though common block %qs is BIND(C)"
 msgstr "%3$L处的公共块‘%2$s’中的变量‘%1$s’可能不是 C 互操作种别，即使公共块‘%4$s’是 BIND(C)"
 
-#: fortran/decl.c:5539
+#: fortran/decl.c:5558
 #, fuzzy, gcc-internal-format
 msgid "Type declaration %qs at %L is not C interoperable but it is BIND(C)"
 msgstr "%2$L处的类型声明‘%1$s’不是与 C 可互操作的，但它是个 BIND(C)"
 
-#: fortran/decl.c:5543
+#: fortran/decl.c:5562
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L may not be a C interoperable kind but it is BIND(C)"
 msgstr "%2$L处的变量‘%1$s’无法与 C 互操作但被声明为 BIND(C)"
 
-#: fortran/decl.c:5555
+#: fortran/decl.c:5574
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs in common block %qs at %L cannot be declared with BIND(C) since it is not a global"
 msgstr "%3$L处的公共块‘%2$s’中的变量‘%1$s’不能被声明为 BIND(C)，因为它不是全局的"
 
-#: fortran/decl.c:5569
+#: fortran/decl.c:5588
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the POINTER and BIND(C) attributes"
 msgstr "%2$L处变量‘%1$s’不能既有 POINTER 又有 BIND(C) 属性"
 
-#: fortran/decl.c:5577
+#: fortran/decl.c:5596
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgstr "%2$L处变量‘%1$s’不能既有 ALLOCATABLE 又有 BIND(C) 属性"
 
-#: fortran/decl.c:5589
+#: fortran/decl.c:5608
 #, fuzzy, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be an array"
 msgstr "%2$L处的BIND(C) 函数‘%1$s’不能返回一个数组"
 
-#: fortran/decl.c:5597
+#: fortran/decl.c:5616
 #, fuzzy, gcc-internal-format
 msgid "Return type of BIND(C) function %qs at %L cannot be a character string"
 msgstr "%2$L处的BIND(C) 函数‘%1$s’不能返回一个字符串"
@@ -56221,962 +56293,967 @@
 
 #. Use gfc_warning_now because we won't say that the symbol fails
 #. just because of this.
-#: fortran/decl.c:5608
+#: fortran/decl.c:5627
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L is marked PRIVATE but has been given the binding label %qs"
 msgstr "%2$L处符号‘%1$s’被标记为 PRIVATE 但是已经给定绑定标号‘%3$s’"
 
-#: fortran/decl.c:5682
+#: fortran/decl.c:5701
 #, gcc-internal-format, gfc-internal-format
 msgid "Need either entity or common block name for attribute specification statement at %C"
 msgstr "%C处的属性规格说明语句需要实体或公共块名"
 
-#: fortran/decl.c:5727
+#: fortran/decl.c:5746
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing entity or common block name for attribute specification statement at %C"
 msgstr "%C处的属性规格说明语句缺少实体或公共块名"
 
-#: fortran/decl.c:5734
+#: fortran/decl.c:5753
 #, fuzzy, gcc-internal-format
 msgid "Missing symbol"
 msgstr "%s:%d: 缺少新的符号名称"
 
-#: fortran/decl.c:5763
+#: fortran/decl.c:5782
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) statement at %C"
 msgstr "%C处的 BIND(C) 中不允许有绑定名"
 
-#: fortran/decl.c:5850
+#: fortran/decl.c:5869
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C has not been previously defined and so cannot appear in a derived type definition"
 msgstr "%C处的派生类型以前尚未被定义，因此不能出现在派生类型定义中"
 
-#: fortran/decl.c:5892
+#: fortran/decl.c:5911
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in data declaration at %C"
 msgid "Syntax error in anonymous structure declaration at %C"
 msgstr "%C处数据声明语法错误"
 
-#: fortran/decl.c:5901
+#: fortran/decl.c:5920
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in data declaration at %C"
 msgstr "%C处数据声明语法错误"
 
-#: fortran/decl.c:5951
+#: fortran/decl.c:5970
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MODULE prefix at %C"
 msgstr "初始化不允许出现在%C处的 PURE 过程中"
 
-#: fortran/decl.c:5996
+#: fortran/decl.c:6015
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IMPURE procedure at %C"
 msgstr "初始化不允许出现在%C处的 PURE 过程中"
 
-#: fortran/decl.c:6008
+#: fortran/decl.c:6027
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PURE and IMPURE must not appear both at %C"
 msgstr "PURE 和 IMPURE 必须不出现两者于 %C"
 
-#: fortran/decl.c:6054
+#: fortran/decl.c:6073
 #, gcc-internal-format, gfc-internal-format
 msgid "ELEMENTAL prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6061
+#: fortran/decl.c:6080
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PURE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr "%C处 PROCEDURE 语句语法错误"
 
-#: fortran/decl.c:6068
+#: fortran/decl.c:6087
 #, gcc-internal-format, gfc-internal-format
 msgid "RECURSIVE prefix in MODULE PROCEDURE interface is missing at %L"
 msgstr ""
 
-#: fortran/decl.c:6134 fortran/primary.c:1820
+#: fortran/decl.c:6153 fortran/primary.c:1820
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Alternate-return argument at %C"
 msgstr "%L 不带 * 虚参的替代返回"
 
-#: fortran/decl.c:6140 fortran/decl.c:6148
+#: fortran/decl.c:6159 fortran/decl.c:6167
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "A parameter name is required at %C"
 msgstr "缺少前导左括号"
 
-#: fortran/decl.c:6188
+#: fortran/decl.c:6207
 #, fuzzy, gcc-internal-format
 msgid "Name %qs at %C is the name of the procedure"
 msgstr "%C处期待模块过程名"
 
-#: fortran/decl.c:6201
+#: fortran/decl.c:6220
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected another dimension in array declaration at %C"
 msgid "Expected parameter list in type declaration at %C"
 msgstr "%C处数组声明需要另外一维"
 
-#: fortran/decl.c:6204
+#: fortran/decl.c:6223
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk in formal argument list at %C"
 msgstr "%C处形参列表中有非预期的垃圾字符"
 
-#: fortran/decl.c:6222
+#: fortran/decl.c:6241
 #, fuzzy, gcc-internal-format
 msgid "Duplicate name %qs in parameter list at %C"
 msgstr "重复的汇编操作数名%qs"
 
-#: fortran/decl.c:6225
+#: fortran/decl.c:6244
 #, fuzzy, gcc-internal-format
 msgid "Duplicate symbol %qs in formal argument list at %C"
 msgstr "符号‘%s’在%C处的形参列表中重复出现"
 
-#: fortran/decl.c:6264
+#: fortran/decl.c:6283
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in MODULE PROCEDURE formal argument names (%s/%s) at %C"
 msgstr ""
 
-#: fortran/decl.c:6270
+#: fortran/decl.c:6289
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in number of MODULE PROCEDURE formal arguments at %C"
 msgstr "%C处 PROCEDURE 语句语法错误"
 
-#: fortran/decl.c:6309
+#: fortran/decl.c:6328
 #, gcc-internal-format, gfc-internal-format
 msgid "RESULT variable at %C must be different than function name"
 msgstr "%C处 RESULT 变量不能与函数重名"
 
-#: fortran/decl.c:6386
+#: fortran/decl.c:6405
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after function declaration at %C"
 msgstr "%C处的函数声明后有非预期的垃圾字符"
 
-#: fortran/decl.c:6396 fortran/decl.c:7494
+#: fortran/decl.c:6415 fortran/decl.c:7513
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L may not be specified for an internal procedure"
 msgstr "Fortran 2008：%L处的 BIND(C)属性对于内部过程不可以指定"
 
-#: fortran/decl.c:6600
+#: fortran/decl.c:6619
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %C requires an interface with BIND(C)"
 msgstr "%C处的 BIND(C) 属性要求一个具有 BIND(C)的接口"
 
-#: fortran/decl.c:6607
+#: fortran/decl.c:6626
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) procedure with NAME may not have POINTER attribute at %C"
 msgstr "%C处带有 NAME 的 BIND(C)过程不能有 POINTER 属性"
 
-#: fortran/decl.c:6613
+#: fortran/decl.c:6632
 #, gcc-internal-format, gfc-internal-format
 msgid "Dummy procedure at %C may not have BIND(C) attribute with NAME"
 msgstr "%C处的哑过程不能有带有 NAME 的 BIND(C) 属性"
 
-#: fortran/decl.c:6636
+#: fortran/decl.c:6655
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L already has basic type of %s"
 msgstr "符号‘%s’在%L处已经有了基本类型 %s"
 
-#: fortran/decl.c:6682 fortran/decl.c:6870 fortran/decl.c:10723
+#: fortran/decl.c:6701 fortran/decl.c:6889 fortran/decl.c:10748
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROCEDURE statement at %C"
 msgstr "%C处 PROCEDURE 语句语法错误"
 
-#: fortran/decl.c:6731 fortran/decl.c:10623
+#: fortran/decl.c:6750 fortran/decl.c:10648
 #, fuzzy, gcc-internal-format
 msgid "Expected %<::%> after binding-attributes at %C"
 msgstr "%C 处的泛型绑定后有垃圾字符"
 
-#: fortran/decl.c:6738
+#: fortran/decl.c:6757
 #, gcc-internal-format, gfc-internal-format
 msgid "NOPASS or explicit interface required at %C"
 msgstr "%C处需要 NOPASS 或显式接口"
 
-#: fortran/decl.c:6742
+#: fortran/decl.c:6761
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer component at %C"
 msgstr "%C处需要一个类型限定的过程或过程指针组件"
 
-#: fortran/decl.c:6814
+#: fortran/decl.c:6833
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in procedure pointer component at %C"
 msgstr "%C处过程指针组件语法错误"
 
-#: fortran/decl.c:6832
+#: fortran/decl.c:6851
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE at %C must be in a generic interface"
 msgstr "%C处的 PROCEDURE 必须在一个泛型接口内"
 
-#: fortran/decl.c:6841 fortran/decl.c:9392
+#: fortran/decl.c:6860 fortran/decl.c:9411
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "double colon in MODULE PROCEDURE statement at %L"
 msgstr "%C处 PROCEDURE 语句语法错误"
 
-#: fortran/decl.c:6911
+#: fortran/decl.c:6930
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE statement at %C"
 msgstr "%C处 PROCEDURE 语句语法错误"
 
-#: fortran/decl.c:6983
+#: fortran/decl.c:7002
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected formal argument list in function definition at %C"
 msgstr "函数定义在%C处需要形参列表"
 
-#: fortran/decl.c:7007 fortran/decl.c:7011 fortran/decl.c:7266
-#: fortran/decl.c:7270 fortran/decl.c:7462 fortran/decl.c:7466
-#: fortran/symbol.c:1875
+#: fortran/decl.c:7026 fortran/decl.c:7030 fortran/decl.c:7285
+#: fortran/decl.c:7289 fortran/decl.c:7481 fortran/decl.c:7485
+#: fortran/symbol.c:1889
 #, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) attribute at %L can only be used for variables or common blocks"
 msgstr "%L处的 BIND(C) 属性只能用于变量或公共块"
 
-#: fortran/decl.c:7164
+#: fortran/decl.c:7183
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C"
 msgstr "%C处的 ENTRY 语句不能出现在 BLOCK DATA 中"
 
-#: fortran/decl.c:7173
+#: fortran/decl.c:7192
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a PROGRAM"
 msgstr "%C处的 ENTRY 语句不能出现在 PROGRAM 中"
 
-#: fortran/decl.c:7176
+#: fortran/decl.c:7195
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgstr "%C处的 ENTRY 语句不能出现在 MODULE 中"
 
-#: fortran/decl.c:7179
+#: fortran/decl.c:7198
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within a MODULE"
 msgid "ENTRY statement at %C cannot appear within a SUBMODULE"
 msgstr "%C处的 ENTRY 语句不能出现在 MODULE 中"
 
-#: fortran/decl.c:7182
+#: fortran/decl.c:7201
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a BLOCK DATA"
 msgstr "%C处的 ENTRY 语句不能出现在 BLOCK DATA 中"
 
-#: fortran/decl.c:7186 fortran/decl.c:7231
+#: fortran/decl.c:7205 fortran/decl.c:7250
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgstr "%C处的 ENTRY 语句不能出现在 INTERFACE 中"
 
-#: fortran/decl.c:7190
+#: fortran/decl.c:7209
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgid "ENTRY statement at %C cannot appear within a STRUCTURE block"
 msgstr "%C处的 ENTRY 语句不能出现在 SELECT 块中"
 
-#: fortran/decl.c:7194
+#: fortran/decl.c:7213
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DERIVED TYPE block"
 msgstr "%C处的 ENTRY 语句不能出现在 DERIVED TYPE 块中"
 
-#: fortran/decl.c:7198
+#: fortran/decl.c:7217
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within an IF-THEN block"
 msgstr "%C处的 ENTRY 语句不能出现在 IF-THEN 块中"
 
-#: fortran/decl.c:7203
+#: fortran/decl.c:7222
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a DO block"
 msgstr "%C处的 ENTRY 语句不能出现在 DO 块中"
 
-#: fortran/decl.c:7207
+#: fortran/decl.c:7226
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a SELECT block"
 msgstr "%C处的 ENTRY 语句不能出现在 SELECT 块中"
 
-#: fortran/decl.c:7211
+#: fortran/decl.c:7230
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a FORALL block"
 msgstr "%C处的 ENTRY 语句不能出现在 FORALL 块中"
 
-#: fortran/decl.c:7215
+#: fortran/decl.c:7234
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a WHERE block"
 msgstr "%C处的 ENTRY 语句不能出现在 WHERE 块中"
 
-#: fortran/decl.c:7219
+#: fortran/decl.c:7238
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgstr "%C处的 ENTRY 语句不能出现在嵌套的子程序中"
 
-#: fortran/decl.c:7223
+#: fortran/decl.c:7242
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected ENTRY statement at %C"
 msgstr "%C处非预期的 CASE 语句"
 
-#: fortran/decl.c:7244
+#: fortran/decl.c:7263
 #, gcc-internal-format, gfc-internal-format
 msgid "ENTRY statement at %C cannot appear in a contained procedure"
 msgstr "%C处 ENTRY 语句不能出现在被包含的过程中"
 
-#: fortran/decl.c:7295 fortran/decl.c:7501
+#: fortran/decl.c:7314 fortran/decl.c:7520
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing required parentheses before BIND(C) at %C"
 msgstr "%C 处 BIND(C) 前缺少要求的括号"
 
-#: fortran/decl.c:7563 fortran/decl.c:7570
+#: fortran/decl.c:7582 fortran/decl.c:7589
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid C identifier in NAME= specifier at %C"
 msgstr "%C处的名字中有非法字符"
 
-#: fortran/decl.c:7610
+#: fortran/decl.c:7629
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in NAME= specifier for binding label at %C"
 msgstr "%C绑定标号的 NAME= 限定符语法错误"
 
-#: fortran/decl.c:7626
+#: fortran/decl.c:7645
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a constant expression"
 msgstr "必须为%L处的 ASYNCHRONOUS= 指定一个初始化表达式"
 
-#: fortran/decl.c:7634
+#: fortran/decl.c:7653
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME= specifier at %C should be a scalar of default character kind"
 msgstr ""
 
-#: fortran/decl.c:7653
+#: fortran/decl.c:7672
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing closing paren for binding label at %C"
 msgstr "%C处绑定标号缺少右括号"
 
-#: fortran/decl.c:7659
+#: fortran/decl.c:7678
 #, gcc-internal-format, gfc-internal-format
 msgid "No binding name is allowed in BIND(C) at %C"
 msgstr "%C处的 BIND(C) 中不允许有绑定名"
 
-#: fortran/decl.c:7665
+#: fortran/decl.c:7684
 #, gcc-internal-format, gfc-internal-format
 msgid "For dummy procedure %s, no binding name is allowed in BIND(C) at %C"
 msgstr "对于哑过程 %s，%C 处的 BIND(C) 中不允许有绑定名"
 
-#: fortran/decl.c:7694
+#: fortran/decl.c:7713
 #, gcc-internal-format, gfc-internal-format
 msgid "NAME not allowed on BIND(C) for ABSTRACT INTERFACE at %C"
 msgstr "%C 处的 ABSTRACT INTERFACE 的 BIND(C)上不允许有 NAME"
 
-#: fortran/decl.c:7939
+#: fortran/decl.c:7958
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected END statement at %C"
 msgstr "%C处非预期的 END 语句"
 
-#: fortran/decl.c:7948
+#: fortran/decl.c:7967
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "END statement instead of %s statement at %L"
 msgstr "%s 语句在%C处不能跟随 %s 语句在%L处"
 
 #. We would have required END [something].
-#: fortran/decl.c:7957
+#: fortran/decl.c:7976
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement expected at %L"
 msgstr "需要 %s 语句在%L处"
 
-#: fortran/decl.c:7968
+#: fortran/decl.c:7987
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s statement at %L"
 msgstr "需要 %s 语句在%L处"
 
-#: fortran/decl.c:7988
+#: fortran/decl.c:8007
 #, fuzzy, gcc-internal-format
 msgid "Expected block name of %qs in %s statement at %L"
 msgstr "需要块名‘%s’在‘%s’表达式中，于 %C"
 
-#: fortran/decl.c:8005
+#: fortran/decl.c:8024
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected terminating name at %C"
 msgstr "%C处需要结束名"
 
-#: fortran/decl.c:8019 fortran/decl.c:8027
+#: fortran/decl.c:8038 fortran/decl.c:8046
 #, fuzzy, gcc-internal-format
 msgid "Expected label %qs for %s statement at %C"
 msgstr "%2$C处需要 %1$s 语句"
 
-#: fortran/decl.c:8126
+#: fortran/decl.c:8145
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in DIMENSION statement"
 msgstr "%L处的 DIMENSION 语句缺少数组规格"
 
-#: fortran/decl.c:8134
+#: fortran/decl.c:8153
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Dimensions specified for %s at %L after its initialisation"
 msgid "Dimensions specified for %s at %L after its initialization"
 msgstr "%2$L处在初始化后为 %1$s 指定了维数"
 
-#: fortran/decl.c:8142
+#: fortran/decl.c:8161
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing array specification at %L in CODIMENSION statement"
 msgstr "%L处的 DIMENSION 语句缺少数组规格"
 
-#: fortran/decl.c:8151
+#: fortran/decl.c:8170
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification must be deferred at %L"
 msgstr "%L处数组规格必须延迟"
 
-#: fortran/decl.c:8249
+#: fortran/decl.c:8268
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected character in variable list at %C"
 msgstr "%C处变量列表中有非预期的垃圾字符"
 
-#: fortran/decl.c:8286
+#: fortran/decl.c:8305
 #, fuzzy, gcc-internal-format
 msgid "Expected %<(%> at %C"
 msgstr "在%C处需要“,”"
 
-#: fortran/decl.c:8300 fortran/decl.c:8340
+#: fortran/decl.c:8319 fortran/decl.c:8359
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C"
 msgstr "在%C处需要变量名"
 
-#: fortran/decl.c:8316
+#: fortran/decl.c:8335
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C must be an integer"
 msgstr "%C处 Cray 指针必须是一个整数"
 
-#: fortran/decl.c:8320
+#: fortran/decl.c:8339
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer at %C has %d bytes of precision; memory addresses require %d bytes"
 msgstr "%C处的 Cray 指针精度为 %d；内存地址需要 %d 字节"
 
-#: fortran/decl.c:8326
+#: fortran/decl.c:8345
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \",\" at %C"
 msgstr "在%C处需要“,”"
 
-#: fortran/decl.c:8365
+#: fortran/decl.c:8384
 #, fuzzy, gcc-internal-format
 msgid "Couldn't set Cray pointee array spec."
 msgstr "%C处 Cray 指针重复指定了数组"
 
-#: fortran/decl.c:8389
+#: fortran/decl.c:8408
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected \")\" at %C"
 msgstr "在%C处需要“)”"
 
-#: fortran/decl.c:8401
+#: fortran/decl.c:8420
 #, fuzzy, gcc-internal-format
 msgid "Expected %<,%> or end of statement at %C"
 msgstr "%C处非预期的 END 语句"
 
-#: fortran/decl.c:8427
+#: fortran/decl.c:8446
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT is not allowed inside of BLOCK at %C"
 msgstr "INTENT 不能用在%C处 BLOCK 内"
 
-#: fortran/decl.c:8459
+#: fortran/decl.c:8478
 #, gcc-internal-format, gfc-internal-format
 msgid "OPTIONAL is not allowed inside of BLOCK at %C"
 msgstr "OPTIONAL 不能用在%C处 BLOCK 内"
 
-#: fortran/decl.c:8478
+#: fortran/decl.c:8497
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray pointer declaration at %C requires -fcray-pointer flag"
 msgstr "%C处的 Cray 指针声明需要 -fcray-pointer 标记"
 
-#: fortran/decl.c:8517
+#: fortran/decl.c:8536
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CONTIGUOUS statement at %C"
 msgstr "%C处的语句标号为零"
 
-#: fortran/decl.c:8623
+#: fortran/decl.c:8642
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the %s operator at %C has already been specified"
 msgstr "%2$C处的 %1$s 运算符的访问规格说明已经被指定"
 
-#: fortran/decl.c:8640
+#: fortran/decl.c:8659
 #, gcc-internal-format, gfc-internal-format
 msgid "Access specification of the .%s. operator at %C has already been specified"
 msgstr "%2$C处的 .%1$s. 运算符的访问规格说明已经被指定"
 
-#: fortran/decl.c:8679
+#: fortran/decl.c:8698
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED statement at %C"
 msgstr "%C处 PROTECTED 语句语法错误"
 
-#: fortran/decl.c:8717
+#: fortran/decl.c:8736
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in PROTECTED statement at %C"
 msgstr "%C处 PROTECTED 语句语法错误"
 
-#: fortran/decl.c:8741
+#: fortran/decl.c:8760
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C is only allowed in the specification part of a module"
 msgstr "%C处的 PRIVATE 语句仅允许出现在模块规格说明部分内"
 
-#: fortran/decl.c:8778
+#: fortran/decl.c:8797
 #, gcc-internal-format, gfc-internal-format
 msgid "PUBLIC statement at %C is only allowed in the specification part of a module"
 msgstr "%C处的 PUBLIC 语句只不允许出现在模块规格说明部分内"
 
-#: fortran/decl.c:8806
+#: fortran/decl.c:8825
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable name at %C in PARAMETER statement"
 msgstr "%C处的 PARAMETER 语句需要变量名"
 
-#: fortran/decl.c:8813
+#: fortran/decl.c:8832
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected = sign in PARAMETER statement at %C"
 msgstr "%C 在 PARAMETER 语句中需要 = 符号"
 
-#: fortran/decl.c:8819
+#: fortran/decl.c:8838
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression at %C in PARAMETER statement"
 msgstr "%C 在 PARAMETER 语句中需要表达式"
 
-#: fortran/decl.c:8839
+#: fortran/decl.c:8858
 #, gcc-internal-format, gfc-internal-format
 msgid "Initializing already initialized variable at %C"
 msgstr "%C处初始化已经初始化的变量"
 
 #. With legacy PARAMETER statements, don't expect a terminating ')'.
-#: fortran/decl.c:8864
+#: fortran/decl.c:8883
 #, gcc-internal-format, gfc-internal-format
 msgid "PARAMETER without '()' at %C"
 msgstr ""
 
-#: fortran/decl.c:8880
+#: fortran/decl.c:8899
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected characters in PARAMETER statement at %C"
 msgstr "%C处 PARAMETER 语句中有非预期的字符"
 
-#: fortran/decl.c:8899 fortran/decl.c:8955
+#: fortran/decl.c:8918 fortran/decl.c:8974
 #, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-static%>"
 msgstr ""
 
-#: fortran/decl.c:8934
+#: fortran/decl.c:8953
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected variable in READ statement at %C"
 msgid "Expected entity-list in AUTOMATIC statement at %C"
 msgstr "%C READ 语句需要变量"
 
-#: fortran/decl.c:8941
+#: fortran/decl.c:8960
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in VOLATILE statement at %C"
 msgid "Syntax error in AUTOMATIC statement at %C"
 msgstr "%C处的 VOLATILE 语句语法错误"
 
-#: fortran/decl.c:8990
+#: fortran/decl.c:9009
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected variable in READ statement at %C"
 msgid "Expected entity-list in STATIC statement at %C"
 msgstr "%C READ 语句需要变量"
 
-#: fortran/decl.c:8997
+#: fortran/decl.c:9016
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in STATIC statement at %C"
 msgstr "%C SAVE 语句语法错误"
 
-#: fortran/decl.c:9016
+#: fortran/decl.c:9035
 #, gcc-internal-format, gfc-internal-format
 msgid "Blanket SAVE statement at %C follows previous SAVE statement"
 msgstr "%C处覆盖 SAVE 语句跟随以前的 SAVE 语句"
 
-#: fortran/decl.c:9027
+#: fortran/decl.c:9046
 #, gcc-internal-format, gfc-internal-format
 msgid "SAVE statement at %C follows blanket SAVE statement"
 msgstr "%C处 SAVE 语句跟随空白 SAVE 语句"
 
-#: fortran/decl.c:9073
+#: fortran/decl.c:9092
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SAVE statement at %C"
 msgstr "%C SAVE 语句语法错误"
 
-#: fortran/decl.c:9087
+#: fortran/decl.c:9106
 #, gcc-internal-format, gfc-internal-format
 msgid "VALUE is not allowed inside of BLOCK at %C"
 msgstr "VALUE 不能用在%C处 BLOCK 内"
 
-#: fortran/decl.c:9091
+#: fortran/decl.c:9110
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VALUE statement at %C"
 msgstr "%C处 VALUE 语句语法错误"
 
-#: fortran/decl.c:9129
+#: fortran/decl.c:9148
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VALUE statement at %C"
 msgstr "%C处 VALUE 语句语法错误"
 
-#: fortran/decl.c:9141
+#: fortran/decl.c:9160
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "VOLATILE statement at %C"
 msgstr "%C处的 VOLATILE 语句语法错误"
 
-#: fortran/decl.c:9168
+#: fortran/decl.c:9187
 #, fuzzy, gcc-internal-format
 msgid "Specifying VOLATILE for coarray variable %qs at %C, which is use-/host-associated"
 msgstr "指定易变的用于 coarray 变量‘%s’于 %C, 该项是 use-/ host-associated"
 
-#: fortran/decl.c:9193
+#: fortran/decl.c:9212
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in VOLATILE statement at %C"
 msgstr "%C处的 VOLATILE 语句语法错误"
 
-#: fortran/decl.c:9205
+#: fortran/decl.c:9224
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS statement at %C"
 msgstr "%C处 ASYNCHRONOUS 语句语法错误"
 
-#: fortran/decl.c:9249
+#: fortran/decl.c:9268
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ASYNCHRONOUS statement at %C"
 msgstr "%C处 ASYNCHRONOUS 语句语法错误"
 
-#: fortran/decl.c:9274
+#: fortran/decl.c:9293
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE declaration at %C"
 msgstr "%C处需要实参列表"
 
-#: fortran/decl.c:9367
+#: fortran/decl.c:9386
 #, gcc-internal-format, gfc-internal-format
 msgid "MODULE PROCEDURE at %C must be in a generic module interface"
 msgstr "%C处的 MODULE PROCEDURE 必须在一个泛型接口内"
 
-#: fortran/decl.c:9425
+#: fortran/decl.c:9444
 #, gcc-internal-format, gfc-internal-format
 msgid "Intrinsic procedure at %L cannot be a MODULE PROCEDURE"
 msgstr "%L处内建过程不能是 MODULE PROCEDURE"
 
-#: fortran/decl.c:9474
+#: fortran/decl.c:9493
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous symbol in TYPE definition at %C"
 msgstr "%C处 TYPE 定义中的歧义符号"
 
-#: fortran/decl.c:9483
+#: fortran/decl.c:9502
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C has not been previously defined"
 msgstr "%2$C处符号‘%1$s’已经与主机相关联"
 
-#: fortran/decl.c:9489
+#: fortran/decl.c:9508
 #, fuzzy, gcc-internal-format
 msgid "%qs in EXTENDS expression at %C is not a derived type"
 msgstr "C++ 不允许在%qs表达式中定义类型"
 
-#: fortran/decl.c:9496
+#: fortran/decl.c:9515
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is BIND(C)"
 msgstr "%2$C 处‘%1$s’不能被扩展，因为它是 BIND(C)"
 
-#: fortran/decl.c:9503
+#: fortran/decl.c:9522
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot be extended at %C because it is a SEQUENCE type"
 msgstr "%2$C 处‘%1$s’不能被扩展，因为它是 SEQUENCE 类型"
 
-#: fortran/decl.c:9526
+#: fortran/decl.c:9545
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PRIVATE in the specification part of a module"
 msgstr "%C处的派生类型在模块规格说明部分内只能是 PRIVATE"
 
-#: fortran/decl.c:9538
+#: fortran/decl.c:9557
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type at %C can only be PUBLIC in the specification part of a module"
 msgstr "%C处的派生类型在模块规格说明部分内只能是 PUBLIC"
 
-#: fortran/decl.c:9559
+#: fortran/decl.c:9578
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ABSTRACT type at %C"
 msgstr "%q+D的抽象类型无效"
 
-#: fortran/decl.c:9605
+#: fortran/decl.c:9624
 #, gcc-internal-format, gfc-internal-format
 msgid "Failed to create structure type '%s' at %C"
 msgstr ""
 
-#: fortran/decl.c:9611
+#: fortran/decl.c:9630
 #, fuzzy, gcc-internal-format
 msgid "Type definition of %qs at %C was already defined at %L"
 msgstr "%2$C处的派生类型‘%1$s’定义已经被定义"
 
-#: fortran/decl.c:9658
+#: fortran/decl.c:9677
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Junk after MAP statement at %C"
 msgstr "%C处 ELSE 语句后有非预期的垃圾字符"
 
-#: fortran/decl.c:9691
+#: fortran/decl.c:9710
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Junk after UNION statement at %C"
 msgstr "%C处 ELSE 语句后有非预期的垃圾字符"
 
-#: fortran/decl.c:9726
+#: fortran/decl.c:9745
 #, fuzzy, gcc-internal-format
 msgid "%s at %C is a DEC extension, enable with %<-fdec-structure%>"
 msgstr "为结构字段%2$qE指定了%1$qs"
 
-#: fortran/decl.c:9740
+#: fortran/decl.c:9759
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected junk after function declaration at %C"
 msgid "Structure name expected in non-nested structure declaration at %C"
 msgstr "%C处的函数声明后有非预期的垃圾字符"
 
-#: fortran/decl.c:9758
+#: fortran/decl.c:9777
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Junk after non-nested STRUCTURE statement at %C"
 msgstr "%C处 ELSE 语句后有非预期的垃圾字符"
 
-#: fortran/decl.c:9765
+#: fortran/decl.c:9784
 #, fuzzy, gcc-internal-format
 msgid "Structure name %qs at %C cannot be the same as an intrinsic type"
 msgstr "类型‘%s’(位于 %C)不能与内建类型重名"
 
-#: fortran/decl.c:9926
+#: fortran/decl.c:9947
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected :: in TYPE definition at %C"
 msgstr "%C 在 TYPE 定义中需要 ::"
 
-#: fortran/decl.c:9954
+#: fortran/decl.c:9975
 #, fuzzy, gcc-internal-format
 msgid "Type name %qs at %C cannot be the same as an intrinsic type"
 msgstr "类型‘%s’(位于 %C)不能与内建类型重名"
 
-#: fortran/decl.c:9964
+#: fortran/decl.c:9986
 #, fuzzy, gcc-internal-format
 msgid "Derived type name %qs at %C already has a basic type of %s"
 msgstr "%2$C处的派生类型名“%1$s”已经有一个基本类型 %3$s"
 
-#: fortran/decl.c:9981
+#: fortran/decl.c:9989
 #, fuzzy, gcc-internal-format
+msgid "Derived type name %qs at %C already has a basic type"
+msgstr "%2$C处的派生类型名“%1$s”已经有一个基本类型 %3$s"
+
+#: fortran/decl.c:10006
+#, fuzzy, gcc-internal-format
 msgid "Derived type definition of %qs at %C has already been defined"
 msgstr "%2$C处的派生类型‘%1$s’定义已经被定义"
 
-#: fortran/decl.c:10042
+#: fortran/decl.c:10067
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in CHARACTER declaration at %C"
 msgid "Garbage after PARAMETERIZED TYPE declaration at %C"
 msgstr "%C处 CHARACTER 声明语法错误"
 
-#: fortran/decl.c:10126
+#: fortran/decl.c:10151
 #, gcc-internal-format, gfc-internal-format
 msgid "Cray Pointee at %C cannot be assumed shape array"
 msgstr "%C处 Cray 指针不能指向假定外形数组"
 
-#: fortran/decl.c:10146
+#: fortran/decl.c:10171
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENUM and ENUMERATOR at %C"
 msgstr "C++ 禁止在赋值时进行枚举转换"
 
-#: fortran/decl.c:10178
+#: fortran/decl.c:10203
 #, gcc-internal-format, gfc-internal-format
 msgid "Enumerator exceeds the C integer type at %C"
 msgstr "%C处：枚举量超过 C 整数类型"
 
-#: fortran/decl.c:10257
+#: fortran/decl.c:10282
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUMERATOR %L not initialized with integer expression"
 msgstr "ENUMERATOR %L没有用整数表达式初始化"
 
-#: fortran/decl.c:10305
+#: fortran/decl.c:10330
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM definition statement expected before %C"
 msgstr "%C 前需要 ENUM 定义语句"
 
-#: fortran/decl.c:10341
+#: fortran/decl.c:10366
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in ENUMERATOR definition at %C"
 msgstr "%C处 ENUMERATOR 定义中语法错误"
 
-#: fortran/decl.c:10388 fortran/decl.c:10403
+#: fortran/decl.c:10413 fortran/decl.c:10428
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate access-specifier at %C"
 msgstr "%C处重复访问限定符"
 
-#: fortran/decl.c:10423
+#: fortran/decl.c:10448
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal NOPASS at %C"
 msgstr "捆绑属性已经指定传递，%C处 NOPASS 非法"
 
-#: fortran/decl.c:10443
+#: fortran/decl.c:10468
 #, gcc-internal-format, gfc-internal-format
 msgid "Binding attributes already specify passing, illegal PASS at %C"
 msgstr "捆绑属性已经指定传递， %C处 PASS 非法"
 
-#: fortran/decl.c:10470
+#: fortran/decl.c:10495
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate POINTER attribute at %C"
 msgstr "%C处 POINTER 属性重复"
 
-#: fortran/decl.c:10488
+#: fortran/decl.c:10513
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NON_OVERRIDABLE at %C"
 msgstr "%C处 NON_OVERRIDABLE 重复"
 
-#: fortran/decl.c:10504
+#: fortran/decl.c:10529
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate DEFERRED at %C"
 msgstr "%C处重复的 DEFERRED 语句"
 
-#: fortran/decl.c:10517
+#: fortran/decl.c:10542
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected access-specifier at %C"
 msgstr "%C需要访问限定符"
 
-#: fortran/decl.c:10519
+#: fortran/decl.c:10544
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding attribute at %C"
 msgstr "%C处需要绑定属性"
 
-#: fortran/decl.c:10527
+#: fortran/decl.c:10552
 #, gcc-internal-format, gfc-internal-format
 msgid "NON_OVERRIDABLE and DEFERRED can't both appear at %C"
 msgstr "NON_OVERRIDABLE 和 DEFERRED 不能同时出现在%C处"
 
-#: fortran/decl.c:10539
+#: fortran/decl.c:10564
 #, gcc-internal-format, gfc-internal-format
 msgid "POINTER attribute is required for procedure pointer component at %C"
 msgstr "%C处的过程指针组件需要 POINTER 属性"
 
-#: fortran/decl.c:10581
+#: fortran/decl.c:10606
 #, fuzzy, gcc-internal-format
 msgid "Interface-name expected after %<(%> at %C"
 msgstr "%C 需要一个无名接口"
 
-#: fortran/decl.c:10587
+#: fortran/decl.c:10612
 #, fuzzy, gcc-internal-format
 msgid "%<)%> expected at %C"
 msgstr "在%C处需要“,”"
 
-#: fortran/decl.c:10607
+#: fortran/decl.c:10632
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface must be specified for DEFERRED binding at %C"
 msgstr "%C处必须为 DEFERRED 绑定指定接口"
 
-#: fortran/decl.c:10612
+#: fortran/decl.c:10637
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE(interface) at %C should be declared DEFERRED"
 msgstr "%C处的 PROCEDURE(接口) 需要声明为 DEFERRED"
 
-#: fortran/decl.c:10635
+#: fortran/decl.c:10660
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected binding name at %C"
 msgstr "%C处需要绑定名"
 
-#: fortran/decl.c:10639
+#: fortran/decl.c:10664
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE list at %C"
 msgstr "%C处需要实参列表"
 
-#: fortran/decl.c:10651
+#: fortran/decl.c:10676
 #, fuzzy, gcc-internal-format
 msgid "%<=> target%> is invalid for DEFERRED binding at %C"
 msgstr "%C处必须为 DEFERRED 绑定指定接口"
 
-#: fortran/decl.c:10657
+#: fortran/decl.c:10682
 #, fuzzy, gcc-internal-format
 msgid "%<::%> needed in PROCEDURE binding with explicit target at %C"
 msgstr "%C处与显式目标捆绑的 PROCEDURE 中需要‘::’"
 
-#: fortran/decl.c:10667
+#: fortran/decl.c:10692
 #, fuzzy, gcc-internal-format
 msgid "Expected binding target after %<=>%> at %C"
 msgstr "%C 处的泛型绑定后有垃圾字符"
 
-#: fortran/decl.c:10684
+#: fortran/decl.c:10709
 #, fuzzy, gcc-internal-format
 msgid "Type %qs containing DEFERRED binding at %C is not ABSTRACT"
 msgstr "%2$C处包含 DEFERRED 绑定的类型‘%1$s’不能是 ABSTRACT"
 
-#: fortran/decl.c:10695
+#: fortran/decl.c:10720
 #, fuzzy, gcc-internal-format
 msgid "There is already a procedure with binding name %qs for the derived type %qs at %C"
 msgstr "在 %3$C 处对于派生类型“%2$s”已经有一个非普通的过程用限定名“%1$s”"
 
-#: fortran/decl.c:10746
+#: fortran/decl.c:10771
 #, gcc-internal-format, gfc-internal-format
 msgid "GENERIC at %C must be inside a derived-type CONTAINS"
 msgstr "%C处的 GENERIC 必须是在派生类型 CONTAINS 内"
 
-#: fortran/decl.c:10766
+#: fortran/decl.c:10791
 #, fuzzy, gcc-internal-format
 msgid "Expected %<::%> at %C"
 msgstr "在%C处需要“,”"
 
-#: fortran/decl.c:10778
+#: fortran/decl.c:10803
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected generic name or operator descriptor at %C"
 msgstr "%C处需要泛型名或运算符描述子"
 
-#: fortran/decl.c:10799
+#: fortran/decl.c:10824
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Malformed GENERIC statement at %C"
 msgstr "%C处的 USE 语句缺少泛型规格"
 
-#: fortran/decl.c:10810
+#: fortran/decl.c:10835
 #, fuzzy, gcc-internal-format
 msgid "Expected %<=>%> at %C"
 msgstr "在%C处需要“,”"
 
-#: fortran/decl.c:10846
+#: fortran/decl.c:10871
 #, fuzzy, gcc-internal-format
 msgid "There's already a non-generic procedure with binding name %qs for the derived type %qs at %C"
 msgstr "%3$C处派生类型‘%2$s’已经有一个绑定名为‘%1$s’的非泛型过程"
 
-#: fortran/decl.c:10854
+#: fortran/decl.c:10879
 #, fuzzy, gcc-internal-format
 msgid "Binding at %C must have the same access as already defined binding %qs"
 msgstr "%C处的绑定必须有与已经定义的绑定‘%s’相同的访问权限"
 
-#: fortran/decl.c:10902
+#: fortran/decl.c:10927
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected specific binding name at %C"
 msgstr "%C处需要特定的绑定名"
 
-#: fortran/decl.c:10912
+#: fortran/decl.c:10937
 #, fuzzy, gcc-internal-format
 msgid "%qs already defined as specific binding for the generic %qs at %C"
 msgstr "%3$C处‘%1$s’已经定义为泛型的‘%2$s’特定的限定"
 
-#: fortran/decl.c:10930
+#: fortran/decl.c:10955
 #, gcc-internal-format, gfc-internal-format
 msgid "Junk after GENERIC binding at %C"
 msgstr "%C 处的泛型绑定后有垃圾字符"
 
-#: fortran/decl.c:10965
+#: fortran/decl.c:10990
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside a derived type CONTAINS section"
 msgstr "%C处的 FINAL 声明必须在一个派生类型的 CONTAINS 节内"
 
-#: fortran/decl.c:10976
+#: fortran/decl.c:11001
 #, gcc-internal-format, gfc-internal-format
 msgid "Derived type declaration with FINAL at %C must be in the specification part of a MODULE"
 msgstr "%C处带有 FINAL 的派生类型声明必须在 MODULE 的规格说明部分内"
 
-#: fortran/decl.c:10998
+#: fortran/decl.c:11023
 #, gcc-internal-format, gfc-internal-format
 msgid "Empty FINAL at %C"
 msgstr "%C处的 FINAL 为空"
 
-#: fortran/decl.c:11005
+#: fortran/decl.c:11030
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected module procedure name at %C"
 msgstr "%C处期待模块过程名"
 
-#: fortran/decl.c:11015
+#: fortran/decl.c:11040
 #, fuzzy, gcc-internal-format
 msgid "Expected %<,%> at %C"
 msgstr "在%C处需要“,”"
 
-#: fortran/decl.c:11021
+#: fortran/decl.c:11046
 #, fuzzy, gcc-internal-format
 msgid "Unknown procedure name %qs at %C"
 msgstr "未知的 C++ 编码名称"
 
-#: fortran/decl.c:11034
+#: fortran/decl.c:11059
 #, fuzzy, gcc-internal-format
 msgid "%qs at %C is already defined as FINAL procedure"
 msgstr "%2$C处的过程‘%1$s’已经在%3$L处被定义"
 
-#: fortran/decl.c:11104
+#: fortran/decl.c:11129
 #, gcc-internal-format, gfc-internal-format
 msgid "Unknown attribute in !GCC$ ATTRIBUTES statement at %C"
 msgstr "%C处 !GCC$ ATTRIBUTES 语句中有未知的属性"
 
-#: fortran/decl.c:11150
+#: fortran/decl.c:11175
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !GCC$ ATTRIBUTES statement at %C"
 msgstr "%C处 !GCC$ ATTRIBUTES 语句中的语法错误"
 
-#: fortran/decl.c:11170
+#: fortran/decl.c:11195
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive requires a non-negative integral constant less than or equal to %u at %C"
 msgstr ""
 
-#: fortran/decl.c:11184
+#: fortran/decl.c:11209
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in FORALL iterator at %C"
 msgid "Syntax error in !GCC$ UNROLL directive at %C"
@@ -57513,27 +57590,27 @@
 msgid "BOZ literal at %L used to initialize non-integer variable %qs"
 msgstr "扩展：%L处 BOZ 字面量被用来初始化非整数变量‘%s’"
 
-#: fortran/expr.c:3369 fortran/resolve.c:10197
+#: fortran/expr.c:3369 fortran/resolve.c:10210
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BOZ literal at %L outside a DATA statement and outside INT/REAL/DBLE/CMPLX"
 msgstr "扩展：在 %L处的 BOZ 字面量在一个 DATA 语句之外并且也在 INT/REAL/DBLE/CMPLX 之外"
 
-#: fortran/expr.c:3380 fortran/resolve.c:10208
+#: fortran/expr.c:3380 fortran/resolve.c:10221
 #, fuzzy, gcc-internal-format
 msgid "BOZ literal at %L is bitwise transferred non-integer symbol %qs"
 msgstr "%L处 BOZ 字面量按位转换后是非整数符号‘%s’"
 
-#: fortran/expr.c:3388 fortran/resolve.c:10217
+#: fortran/expr.c:3388 fortran/resolve.c:10230
 #, fuzzy, gcc-internal-format
 msgid "Arithmetic underflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "%L处按位转换 BOZ 时算术下溢。这一检查可用 -fno-range-check 选项禁用"
 
-#: fortran/expr.c:3392 fortran/resolve.c:10221
+#: fortran/expr.c:3392 fortran/resolve.c:10234
 #, fuzzy, gcc-internal-format
 msgid "Arithmetic overflow of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "%L处按位转换 BOZ 时算术上溢。这一检查可用 -fno-range-check 选项禁用"
 
-#: fortran/expr.c:3396 fortran/resolve.c:10225
+#: fortran/expr.c:3396 fortran/resolve.c:10238
 #, fuzzy, gcc-internal-format
 msgid "Arithmetic NaN of bit-wise transferred BOZ at %L. This check can be disabled with the option %<-fno-range-check%>"
 msgstr "%L处按位转换 BOZ 时产生算术 NaN。这一检查可用 -fno-range-check 选项禁用"
@@ -57543,148 +57620,148 @@
 msgid "The assignment to a KIND or LEN component of a parameterized type at %L is not allowed"
 msgstr "%L处指针赋值时参数种别类型不同"
 
-#: fortran/expr.c:3426
+#: fortran/expr.c:3429
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible types in DATA statement at %L; attempted conversion of %s to %s"
 msgstr "%L处 DATA 语句中类型不兼容；试图从 %s 转换到 %s"
 
-#: fortran/expr.c:3465
+#: fortran/expr.c:3468
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is not a POINTER at %L"
 msgstr "%L处指针赋值的目标不是一个 POINTER"
 
-#: fortran/expr.c:3473
+#: fortran/expr.c:3476
 #, fuzzy, gcc-internal-format
 msgid "%qs in the pointer assignment at %L cannot be an l-value since it is a procedure"
 msgstr "%2$L处指针赋值中的‘%1$s’不能是一个左值，因为它是一个过程"
 
-#: fortran/expr.c:3496
+#: fortran/expr.c:3499
 #, fuzzy, gcc-internal-format
 msgid "Expected bounds specification for %qs at %L"
 msgstr "%2$L处‘%1$s’需要边界规格"
 
-#: fortran/expr.c:3501
+#: fortran/expr.c:3504
 #, fuzzy, gcc-internal-format
 msgid "Bounds specification for %qs in pointer assignment at %L"
 msgstr "Fortran 2003：%2$L处指针赋值语句中‘%1$s’的边界规格"
 
-#: fortran/expr.c:3514
+#: fortran/expr.c:3517
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Lower bound has to be present at %L"
 msgstr "%L处数据元素低于数组下限"
 
-#: fortran/expr.c:3520
+#: fortran/expr.c:3523
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Stride must not be present at %L"
 msgstr "%L 零间隔非法"
 
-#: fortran/expr.c:3532
+#: fortran/expr.c:3535
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the upper bounds must be specified at %L"
 msgstr "还是所有或没有任何上限必须被指定的于 %L"
 
-#: fortran/expr.c:3558
+#: fortran/expr.c:3561
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer object at %L shall not have a coindex"
 msgstr "外部对象‘%s’在%L处不能有初始值设定"
 
-#: fortran/expr.c:3579
+#: fortran/expr.c:3582
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid procedure pointer assignment at %L"
 msgstr "%L处过程指针赋值非法"
 
-#: fortran/expr.c:3603
+#: fortran/expr.c:3606
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs is invalid as proc-target in procedure pointer assignment at %L"
 msgstr "语句函数‘%s’在%L处的过程指针赋值中是非法的"
 
-#: fortran/expr.c:3612
+#: fortran/expr.c:3615
 #, fuzzy, gcc-internal-format
 msgid "Abstract interface %qs is invalid in procedure pointer assignment at %L"
 msgstr "抽象接口‘%s’在%L处的过程指针赋值中是非法的"
 
-#: fortran/expr.c:3622
+#: fortran/expr.c:3625
 #, fuzzy, gcc-internal-format
 msgid "Statement function %qs is invalid in procedure pointer assignment at %L"
 msgstr "语句函数‘%s’在%L处的过程指针赋值中是非法的"
 
-#: fortran/expr.c:3628
+#: fortran/expr.c:3631
 #, fuzzy, gcc-internal-format
 msgid "Internal procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "内部过程‘%s’在%L处的过程指针赋值中是非法的"
 
-#: fortran/expr.c:3635
+#: fortran/expr.c:3638
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic %qs at %L is invalid in procedure pointer assignment"
 msgstr "%L处过程指针赋值非法"
 
-#: fortran/expr.c:3643
+#: fortran/expr.c:3646
 #, fuzzy, gcc-internal-format
 msgid "Nonintrinsic elemental procedure %qs is invalid in procedure pointer assignment at %L"
 msgstr "内部过程‘%s’在%L处的过程指针赋值中是非法的"
 
-#: fortran/expr.c:3666
+#: fortran/expr.c:3669
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in the procedure pointer assignment at %L: mismatch in the calling convention"
 msgstr "%L处过程指针赋值不匹配：调用约定不匹配"
 
-#: fortran/expr.c:3719
+#: fortran/expr.c:3722
 #, fuzzy, gcc-internal-format
 #| msgid "Interface mismatch in procedure pointer assignment at %L: %s"
 msgid "Interface mismatch in procedure pointer assignment at %L: %qs is not a subroutine"
 msgstr "%L处过程指针赋值中接口不匹配：%s"
 
-#: fortran/expr.c:3729 fortran/expr.c:3744
+#: fortran/expr.c:3732 fortran/expr.c:3747
 #, fuzzy, gcc-internal-format
 msgid "Explicit interface required for component %qs at %L: %s"
 msgstr "%C处需要 NOPASS 或显式接口"
 
-#: fortran/expr.c:3735 fortran/expr.c:3750 fortran/resolve.c:2566
+#: fortran/expr.c:3738 fortran/expr.c:3753 fortran/resolve.c:2566
 #, fuzzy, gcc-internal-format
 msgid "Explicit interface required for %qs at %L: %s"
 msgstr "%C处需要 NOPASS 或显式接口"
 
-#: fortran/expr.c:3762
+#: fortran/expr.c:3765
 #, gcc-internal-format, gfc-internal-format
 msgid "Interface mismatch in procedure pointer assignment at %L: %s"
 msgstr "%L处过程指针赋值中接口不匹配：%s"
 
-#: fortran/expr.c:3771
+#: fortran/expr.c:3774
 #, gcc-internal-format
 msgid "Procedure pointer target %qs at %L must be either an intrinsic, host or use associated, referenced or have the EXTERNAL attribute"
 msgstr ""
 
-#: fortran/expr.c:3788
+#: fortran/expr.c:3791
 #, gcc-internal-format, gfc-internal-format
 msgid "Data-pointer-object at %L must be unlimited polymorphic, or of a type with the BIND or SEQUENCE attribute, to be compatible with an unlimited polymorphic target"
 msgstr ""
 
-#: fortran/expr.c:3793
+#: fortran/expr.c:3796
 #, gcc-internal-format, gfc-internal-format
 msgid "Different types in pointer assignment at %L; attempted assignment of %s to %s"
 msgstr "%L处指针赋值时类型不同；试图将 %s 赋值给 %s"
 
-#: fortran/expr.c:3802
+#: fortran/expr.c:3805
 #, gcc-internal-format, gfc-internal-format
 msgid "Different kind type parameters in pointer assignment at %L"
 msgstr "%L处指针赋值时参数种别类型不同"
 
-#: fortran/expr.c:3809
+#: fortran/expr.c:3812
 #, gcc-internal-format, gfc-internal-format
 msgid "Different ranks in pointer assignment at %L"
 msgstr "%L处指针赋值时秩不同"
 
-#: fortran/expr.c:3828
+#: fortran/expr.c:3831
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is smaller than size of the pointer (%ld < %ld) at %L"
 msgstr "分级重新映射目标是小于大小的指标 (%ld<%ld) 于 %L"
 
-#: fortran/expr.c:3841
+#: fortran/expr.c:3844
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target must be rank 1 or simply contiguous at %L"
 msgstr "分级重新映射目标必须是分级 1 或仅需 contiguous 于 %L"
 
-#: fortran/expr.c:3845
+#: fortran/expr.c:3848
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Rank remapping target is not rank 1 at %L"
 msgstr "Fortran 2008：%L处格式中的‘G0’"
@@ -57692,147 +57769,152 @@
 #. The test above might need to be extend when F08, Note 5.4 has to be
 #. interpreted in the way that target and pointer with the same coindex
 #. are allowed.
-#: fortran/expr.c:3877 fortran/expr.c:3925
+#: fortran/expr.c:3880 fortran/expr.c:3928
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data target at %L shall not have a coindex"
 msgstr "%L处数据传输元素不能有 POINTER 组件"
 
-#: fortran/expr.c:3880
+#: fortran/expr.c:3883
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Target expression in pointer assignment at %L must deliver a pointer result"
 msgstr "%L处计算转移 GOTO 语句的选择表达式必须是一个标量整数表达式"
 
-#: fortran/expr.c:3888
+#: fortran/expr.c:3891
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target is neither TARGET nor POINTER at %L"
 msgstr "%L处指针赋值的目标既不是 TARGET 也不是 POINTER"
 
-#: fortran/expr.c:3895
+#: fortran/expr.c:3898
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad target in pointer assignment in PURE procedure at %L"
 msgstr "%L处 PURE 过程中指针赋值目标错误"
 
-#: fortran/expr.c:3904
+#: fortran/expr.c:3907
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment with vector subscript on rhs at %L"
 msgstr "%L处指针赋值的右手边带有向量下标"
 
-#: fortran/expr.c:3912
+#: fortran/expr.c:3915
 #, gcc-internal-format, gfc-internal-format
 msgid "Pointer assignment target has PROTECTED attribute at %L"
 msgstr "%L处指针赋值目标对象有 PROTECTED 属性"
 
-#: fortran/expr.c:3936
+#: fortran/expr.c:3939
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to contiguous pointer from non-contiguous target at %L"
 msgstr ""
 
-#: fortran/expr.c:3975
+#: fortran/expr.c:3978
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer at %L in pointer assignment might outlive the pointer target"
 msgstr "%L处指针赋值的目标既不是 TARGET 也不是 POINTER"
 
-#: fortran/expr.c:4051 fortran/resolve.c:1452
+#: fortran/expr.c:4054 fortran/resolve.c:1452
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must not be ALLOCATABLE"
 msgstr "%L处的分配对象必须是 ALLOCATABLE 或 POINTER"
 
-#: fortran/expr.c:4057
+#: fortran/expr.c:4060
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the TARGET attribute"
 msgstr "%L 处指针赋值目标对象有 PROTECTED 属性"
 
-#: fortran/expr.c:4072 fortran/resolve.c:1458
+#: fortran/expr.c:4075 fortran/resolve.c:1458
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer initialization target at %L must have the SAVE attribute"
 msgstr "%2$L 处的对象“%1$s”对于成分的默认初始化必须有 SAVE 属性，"
 
-#: fortran/expr.c:4084
+#: fortran/expr.c:4087
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr "%L处 PURE 过程中指针赋值目标错误"
 
-#: fortran/expr.c:5512
+#: fortran/expr.c:4557
+#, gcc-internal-format
+msgid "generate_isocbinding_initializer(): bad iso_c_binding type, expected %<c_ptr%> or %<c_funptr%>"
+msgstr ""
+
+#: fortran/expr.c:5568
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr "Fortran 2003：%L处初始化表达式中非整数指数"
 
-#: fortran/expr.c:5520
+#: fortran/expr.c:5576
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr "Non-variable 运算式在中变量定义语境 (%s) 于 %L"
 
-#: fortran/expr.c:5528
+#: fortran/expr.c:5584
 #, fuzzy, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr "变量‘%s’在%L处上下文中必须是常量"
 
-#: fortran/expr.c:5537
+#: fortran/expr.c:5593
 #, fuzzy, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr "%L处的属性不允许出现在 TYPE 定义中"
 
-#: fortran/expr.c:5548
+#: fortran/expr.c:5604
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr "Non-POINTER 在中指标关联语境 (%s) 于 %L"
 
-#: fortran/expr.c:5557
+#: fortran/expr.c:5613
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr "变量‘%s’在%L处上下文中必须是常量"
 
-#: fortran/expr.c:5570
+#: fortran/expr.c:5626
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr "变量‘%s’在%L处上下文中必须是常量"
 
-#: fortran/expr.c:5583
+#: fortran/expr.c:5639
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr "变量‘%s’在%L处上下文中必须是常量"
 
-#: fortran/expr.c:5613
+#: fortran/expr.c:5669
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr "虚参‘%s’不能出现在%L处的表达式中"
 
-#: fortran/expr.c:5621
+#: fortran/expr.c:5677
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr "虚参‘%s’不能出现在%L处的表达式中"
 
-#: fortran/expr.c:5634
+#: fortran/expr.c:5690
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a pointer association context (%s) at %L"
 msgstr "变量‘%s’不能出现在%L处的表达式中"
 
-#: fortran/expr.c:5642
+#: fortran/expr.c:5698
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a variable definition context (%s) at %L"
 msgstr "变量‘%s’不能出现在%L处的表达式中"
 
-#: fortran/expr.c:5654
+#: fortran/expr.c:5710
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs can not appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr "变量‘%s’不能出现在%L处的表达式中"
 
-#: fortran/expr.c:5713
+#: fortran/expr.c:5769
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
 msgstr "变量‘%s’在%L处上下文中必须是常量"
 
-#: fortran/expr.c:5717
+#: fortran/expr.c:5773
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L associated to expression can not be used in a variable definition context (%s)"
 msgstr "变量‘%s’不能出现在%L处的表达式中"
 
-#: fortran/expr.c:5728
+#: fortran/expr.c:5784
 #, fuzzy, gcc-internal-format
 msgid "Associate-name %qs can not appear in a variable definition context (%s) at %L because its target at %L can not, either"
 msgstr "Associate-name‘%s’无法出现在中变量定义语境 (%s) 于 %L 因为它的目标于 %L 无法，还是"
 
-#: fortran/expr.c:5770
+#: fortran/expr.c:5826
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr "‘%s’于 %L 关联的到运算式无法已用于变量定义语境 (%s)"
@@ -57842,24 +57924,24 @@
 msgid "can't open input file: %s"
 msgstr "不能打开输入文件：%s"
 
-#: fortran/frontend-passes.c:190
+#: fortran/frontend-passes.c:192
 #, fuzzy, gcc-internal-format
 #| msgid "in statement"
 msgid "No location in statement"
 msgstr "在语句中"
 
-#: fortran/frontend-passes.c:205
+#: fortran/frontend-passes.c:207
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected exponent in expression at %C"
 msgid "No location in expression near %L"
 msgstr "%C处表达式中需要指数部分"
 
-#: fortran/frontend-passes.c:409
+#: fortran/frontend-passes.c:414
 #, gcc-internal-format
 msgid "Illegal id in copy_walk_reduction_arg"
 msgstr ""
 
-#: fortran/frontend-passes.c:817 fortran/trans-array.c:1182
+#: fortran/frontend-passes.c:822 fortran/trans-array.c:1182
 #: fortran/trans-array.c:6440 fortran/trans-array.c:7864
 #: fortran/trans-intrinsic.c:7307
 #, gcc-internal-format, gfc-internal-format
@@ -57866,69 +57948,69 @@
 msgid "Creating array temporary at %L"
 msgstr "在%L处建立临时数组"
 
-#: fortran/frontend-passes.c:842 fortran/frontend-passes.c:846
+#: fortran/frontend-passes.c:847 fortran/frontend-passes.c:851
 #, fuzzy, gcc-internal-format
 msgid "Removing call to function %qs at %L"
 msgstr "%2$L处函数‘%1$s’的返回值没有设置"
 
-#: fortran/frontend-passes.c:1273 fortran/frontend-passes.c:1312
+#: fortran/frontend-passes.c:1278 fortran/frontend-passes.c:1317
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "bad expression"
 msgstr "需要表达式"
 
-#: fortran/frontend-passes.c:1308
+#: fortran/frontend-passes.c:1313
 #, fuzzy, gcc-internal-format
 #| msgid "bad move"
 msgid "bad op"
 msgstr "错误的移动"
 
-#: fortran/frontend-passes.c:2161
+#: fortran/frontend-passes.c:2166
 #, fuzzy, gcc-internal-format
 msgid "illegal OP in optimize_comparison"
 msgstr "gimple 比较中操作数无效"
 
-#: fortran/frontend-passes.c:2407
+#: fortran/frontend-passes.c:2412
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L set to undefined value inside loop  beginning at %L as INTENT(OUT) argument to subroutine %qs"
 msgstr "变量‘%s’(位于 %C)不能在从 %L 开始的循环的内部重定义"
 
-#: fortran/frontend-passes.c:2414
+#: fortran/frontend-passes.c:2419
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to subroutine %qs"
 msgstr "变量‘%s’(位于 %C)不能在从 %L 开始的循环的内部重定义"
 
-#: fortran/frontend-passes.c:2637 fortran/frontend-passes.c:2661
+#: fortran/frontend-passes.c:2642 fortran/frontend-passes.c:2666
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L out of bounds (%ld < %ld) in loop beginning at %L"
 msgstr "%1$L处数组引用在第 %4$d 维中越界(%2$ld < %3$ld)"
 
-#: fortran/frontend-passes.c:2646 fortran/frontend-passes.c:2670
+#: fortran/frontend-passes.c:2651 fortran/frontend-passes.c:2675
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L out of bounds (%ld > %ld) in loop beginning at %L"
 msgstr "%1$L处数组引用在第 %4$d 维中越界(%2$ld < %3$ld)"
 
-#: fortran/frontend-passes.c:2730
+#: fortran/frontend-passes.c:2735
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L set to undefined value inside loop beginning at %L as INTENT(OUT) argument to function %qs"
 msgstr "变量‘%s’(位于 %C)不能在从 %L 开始的循环的内部重定义"
 
-#: fortran/frontend-passes.c:2736
+#: fortran/frontend-passes.c:2741
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L not definable inside loop beginning at %L as INTENT(INOUT) argument to function %qs"
 msgstr "变量‘%s’(位于 %C)不能在从 %L 开始的循环的内部重定义"
 
-#: fortran/frontend-passes.c:3128 fortran/trans-expr.c:1581
+#: fortran/frontend-passes.c:3133 fortran/trans-expr.c:1581
 #, gcc-internal-format, gfc-internal-format
 msgid "Code for reallocating the allocatable array at %L will be added"
 msgstr ""
 
-#: fortran/frontend-passes.c:3637
+#: fortran/frontend-passes.c:3642
 #, gcc-internal-format
 msgid "Scalarization using DIMEN_RANGE unimplemented"
 msgstr ""
 
-#: fortran/frontend-passes.c:4429
+#: fortran/frontend-passes.c:4434
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Interchanging loops at %L"
 msgstr "循环变量"
@@ -58048,12 +58130,12 @@
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "%L处定义赋值的第二个参数必须是 INTENT(IN)"
 
-#: fortran/interface.c:970 fortran/resolve.c:16351
+#: fortran/interface.c:970 fortran/resolve.c:16378
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "%L处运算符接口的第一个参数必须是 INTENT(IN)"
 
-#: fortran/interface.c:977 fortran/resolve.c:16369
+#: fortran/interface.c:977 fortran/resolve.c:16396
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "%L处运算符接口的第二个参数必须是 INTENT(IN)"
@@ -59252,7 +59334,7 @@
 msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
 msgstr "%3$L处 NAMELIST 数组对象‘%1$s’在名字列表‘%2$s’不能有 POINTER 组件"
 
-#: fortran/io.c:3369 fortran/resolve.c:14263
+#: fortran/io.c:3369 fortran/resolve.c:14283
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
 msgstr "%3$L处 NAMELIST 数组对象‘%1$s’在名字列表‘%2$s’必须有 ALLOCATABLE 组件"
@@ -59419,7 +59501,7 @@
 msgid "Integer too large at %C"
 msgstr "%C处整数太大"
 
-#: fortran/match.c:580 fortran/parse.c:1132
+#: fortran/match.c:580 fortran/parse.c:1136
 #, gcc-internal-format, gfc-internal-format
 msgid "Too many digits in statement label at %C"
 msgstr "%C处语句标号中数字太多"
@@ -60189,57 +60271,57 @@
 msgid "Expected block name %qs of SELECT construct at %C"
 msgstr "%2$C处需要 SELECT 构造的块名‘%1$s’"
 
-#: fortran/match.c:6186
+#: fortran/match.c:6201
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "parse error in SELECT TYPE statement at %C"
 msgstr "%C处 PROTECTED 语句语法错误"
 
-#: fortran/match.c:6211
+#: fortran/match.c:6226
 #, gcc-internal-format, gfc-internal-format
 msgid "Selector in SELECT TYPE at %C is not a named variable; use associate-name=>"
 msgstr "%C处 SELECT TYPE 中的选择子不是一个有名变量；请使用 associate-name=>"
 
-#: fortran/match.c:6249
+#: fortran/match.c:6264
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected CASE statement at %C"
 msgstr "%C处非预期的 CASE 语句"
 
-#: fortran/match.c:6301
+#: fortran/match.c:6316
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CASE specification at %C"
 msgstr "%C处 CASE 规格语法错误"
 
-#: fortran/match.c:6319
+#: fortran/match.c:6334
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected TYPE IS statement at %C"
 msgstr "%C处非预期的 TYPE IS 语句"
 
-#: fortran/match.c:6351
+#: fortran/match.c:6366
 #, gcc-internal-format, gfc-internal-format
 msgid "The type-spec shall not specify a sequence derived type or a type with the BIND attribute in SELECT TYPE at %C [F2003:C815]"
 msgstr ""
 
-#: fortran/match.c:6362
+#: fortran/match.c:6377
 #, gcc-internal-format, gfc-internal-format
 msgid "All the LEN type parameters in the TYPE IS statement at %C must be ASSUMED"
 msgstr ""
 
-#: fortran/match.c:6373
+#: fortran/match.c:6388
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in TYPE IS specification at %C"
 msgstr "%C处 TYPE IS 规格语法错误"
 
-#: fortran/match.c:6449
+#: fortran/match.c:6464
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in CLASS IS specification at %C"
 msgstr "%C处 CLASS IS 规格语法错误"
 
-#: fortran/match.c:6572
+#: fortran/match.c:6587
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C not enclosed in WHERE block"
 msgstr "%C处的 ELSEWHERE 语句不在 WHERE 块中"
 
-#: fortran/match.c:6610
+#: fortran/match.c:6625
 #, fuzzy, gcc-internal-format
 msgid "Label %qs at %C doesn't match WHERE label %qs"
 msgstr "%2$C处的标号‘%1$s’不匹配 WHERE 标号‘%3$s’"
@@ -60392,182 +60474,182 @@
 msgid "mio_array_ref(): Unknown array ref"
 msgstr ""
 
-#: fortran/module.c:3716
+#: fortran/module.c:3718
 #, gcc-internal-format, gfc-internal-format
 msgid "Namelist %s cannot be renamed by USE association to %s"
 msgstr "名字列表 %s 不能为对 %s 的 USE 关联来更名"
 
-#: fortran/module.c:4832
+#: fortran/module.c:4834
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4835
+#: fortran/module.c:4837
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:5029
+#: fortran/module.c:5031
 #, fuzzy, gcc-internal-format
 msgid "%qs of module %qs, imported at %C, is also the name of the current program unit"
 msgstr "%2$C处的名字‘%1$s’是从当前程序单元对‘%3$s’有歧义的引用"
 
-#: fortran/module.c:5381
+#: fortran/module.c:5383
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in module %qs"
 msgstr "%2$L处引用的符号‘%1$s’在模块‘%3$s’中找不到"
 
-#: fortran/module.c:5388
+#: fortran/module.c:5390
 #, fuzzy, gcc-internal-format
 msgid "User operator %qs referenced at %L not found in module %qs"
 msgstr "%2$L处引用的用户运算符‘%1$s’在模块‘%3$s’中找不到"
 
-#: fortran/module.c:5393
+#: fortran/module.c:5395
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic operator %qs referenced at %L not found in module %qs"
 msgstr "%2$L处引用的内建运算符‘%1$s’在模块‘%3$s’中找不到"
 
-#: fortran/module.c:5628
+#: fortran/module.c:5630
 #, gcc-internal-format
 msgid "write_symbol(): bad module symbol %qs"
 msgstr ""
 
-#: fortran/module.c:5961
+#: fortran/module.c:5963
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr ""
 
-#: fortran/module.c:6148
+#: fortran/module.c:6150
 #, fuzzy, gcc-internal-format
 msgid "Can't open module file %qs for writing at %C: %s"
 msgstr "不能打开模块文件‘%s’写入，在%C处：%s"
 
-#: fortran/module.c:6169
+#: fortran/module.c:6171
 #, fuzzy, gcc-internal-format
 msgid "Error writing module file %qs for writing: %s"
 msgstr "写入到输出文件 '%s' 时出错\n"
 
-#: fortran/module.c:6180
+#: fortran/module.c:6182
 #, fuzzy, gcc-internal-format
 msgid "Can't delete module file %qs: %s"
 msgstr "%s：无法找到模块文件 %s\n"
 
-#: fortran/module.c:6183
+#: fortran/module.c:6185
 #, fuzzy, gcc-internal-format
 msgid "Can't rename module file %qs to %qs: %s"
 msgstr "无法将模块文件‘%s’重命名为‘%s’：%s"
 
-#: fortran/module.c:6189
+#: fortran/module.c:6191
 #, fuzzy, gcc-internal-format
 msgid "Can't delete temporary module file %qs: %s"
 msgstr "无法删除临时模块文件‘%s’：%s"
 
-#: fortran/module.c:6246
+#: fortran/module.c:6248
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C already declared"
 msgstr "`%.*s' 已被定义为对照符号"
 
-#: fortran/module.c:6317
+#: fortran/module.c:6319
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr ""
 
-#: fortran/module.c:6425 fortran/module.c:6769
+#: fortran/module.c:6427 fortran/module.c:6771
 #, fuzzy, gcc-internal-format
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr "%2$L处引用的符号‘%1$s’在模块‘%3$s’中找不到"
 
-#: fortran/module.c:6553
+#: fortran/module.c:6555
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr "%2$L处引用的符号‘%1$s’在内建模块 ISO_C_BINDING 中找不到"
 
-#: fortran/module.c:6574 fortran/module.c:6607 fortran/module.c:6649
+#: fortran/module.c:6576 fortran/module.c:6609 fortran/module.c:6651
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs already declared"
 msgstr "`%.*s' 已被定义为对照符号"
 
-#: fortran/module.c:6754
+#: fortran/module.c:6756
 #, fuzzy, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr "%2$C处对内建模块‘%1$s’的使用与以前使用的非内建模块名字冲突"
 
-#: fortran/module.c:6776
+#: fortran/module.c:6778
 #, fuzzy, gcc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr "%C处在内建模块 ISO_FORTRAN_ENV 中对 NUMERIC_STORAGE_SIZE 命名常数的使用与选项 %s 不兼容"
 
-#: fortran/module.c:6844
+#: fortran/module.c:6846
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr "%C处在内建模块 ISO_FORTRAN_ENV 中对 NUMERIC_STORAGE_SIZE 命名常数的使用与选项 %s 不兼容"
 
-#: fortran/module.c:6898
+#: fortran/module.c:6900
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr "%2$L处引用的符号‘%1$s’在内建模块 ISO_FORTRAN_ENV 中找不到"
 
-#: fortran/module.c:6924
+#: fortran/module.c:6926
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr "%C处非预期的 CASE 语句"
 
-#: fortran/module.c:6953
+#: fortran/module.c:6955
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr "Fortran 2003：%C 处的 ISO_FORTRAN_ENV 内建模块"
 
-#: fortran/module.c:6965
+#: fortran/module.c:6967
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
 msgstr "%C处需要绑定名"
 
-#: fortran/module.c:6978
+#: fortran/module.c:6980
 #, fuzzy, gcc-internal-format
 msgid "Can't find an intrinsic module named %qs at %C"
 msgstr "%2$C处无法找到名为‘%1$s’的内建模块"
 
-#: fortran/module.c:6984
+#: fortran/module.c:6986
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr "使用了传统 C 不支持的特性时给出警告"
 
-#: fortran/module.c:6990
+#: fortran/module.c:6992
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr "模块间优化未为 C++ 实现"
 
-#: fortran/module.c:6996
+#: fortran/module.c:6998
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr "模块间优化未为 C++ 实现"
 
-#: fortran/module.c:7006
+#: fortran/module.c:7008
 #, fuzzy, gcc-internal-format
 msgid "Can't open module file %qs for reading at %C: %s"
 msgstr "无法打开模块文件‘%s’读取，在%C处：%s"
 
-#: fortran/module.c:7009
+#: fortran/module.c:7011
 #, gcc-internal-format
 msgid "Module file %qs has not been generated, either because the module does not contain a MODULE PROCEDURE or there is an error in the module."
 msgstr ""
 
-#: fortran/module.c:7020
+#: fortran/module.c:7022
 #, fuzzy, gcc-internal-format
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr "%2$C处对非内建模块‘%1$s’的使用与之前对内建模块名字的使用相冲突"
 
-#: fortran/module.c:7043
+#: fortran/module.c:7045
 #, fuzzy, gcc-internal-format
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr "%2$C处打开的文件的‘%1$s’并非一个 GFORTRAN 模块文件"
 
-#: fortran/module.c:7051
+#: fortran/module.c:7053
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr ""
 
-#: fortran/module.c:7066
+#: fortran/module.c:7068
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Can't USE the same module we're building!"
 msgid "Can't USE the same %smodule we're building"
@@ -60574,7 +60656,7 @@
 msgstr "不能 USE 我们正在构建的模块！"
 
 #: fortran/openmp.c:296 fortran/openmp.c:397 fortran/openmp.c:692
-#: fortran/openmp.c:3167
+#: fortran/openmp.c:3166
 #, gcc-internal-format, gfc-internal-format
 msgid "COMMON block /%s/ not found at %C"
 msgstr "%2$C处未发现 COMMON 块 /%1$s/"
@@ -60655,862 +60737,862 @@
 
 #: fortran/openmp.c:2180
 #, fuzzy, gcc-internal-format, gfc-internal-format
-msgid "Invalid argument to !$ACC WAIT at %L"
+msgid "Invalid argument to !$ACC WAIT at %C"
 msgstr "%L过程参数无效"
 
-#: fortran/openmp.c:2188
+#: fortran/openmp.c:2187
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "WAIT clause at %L requires a scalar INTEGER expression"
 msgstr "%L处的 NUM_THREADS 分句需要一个标量 INTEGER 表达式"
 
-#: fortran/openmp.c:2221
+#: fortran/openmp.c:2220
 #, gcc-internal-format, gfc-internal-format
 msgid "ACC CACHE directive must be inside of loop %C"
 msgstr ""
 
-#: fortran/openmp.c:2252
+#: fortran/openmp.c:2251
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specified for typename"
 msgid "Multiple loop axes specified for routine"
 msgstr "为类型名指定了存储类"
 
-#: fortran/openmp.c:2278
+#: fortran/openmp.c:2277
 #, gcc-internal-format, gfc-internal-format
 msgid "Only the !$ACC ROUTINE form without list is allowed in interface block at %C"
 msgstr ""
 
-#: fortran/openmp.c:2306
+#: fortran/openmp.c:2305
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$ACC ROUTINE ( NAME ) at %C, invalid function name %s"
 msgstr "%C处公共块名语法错误"
 
-#: fortran/openmp.c:2315
+#: fortran/openmp.c:2314
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$ACC ROUTINE ( NAME ) at %C"
 msgstr "%C处公共块名语法错误"
 
-#: fortran/openmp.c:2322
+#: fortran/openmp.c:2321
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$ACC ROUTINE ( NAME ) at %C, expecting ')' after NAME"
 msgstr ""
 
-#: fortran/openmp.c:2457 fortran/openmp.c:2481
+#: fortran/openmp.c:2456 fortran/openmp.c:2480
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP CRITICAL statement at %C"
 msgstr "%C处 ELSE IF 语句后有非预期的垃圾字符"
 
-#: fortran/openmp.c:2548
+#: fortran/openmp.c:2547
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP FLUSH statement at %C"
 msgstr "%C处 ELSE IF 语句后有非预期的垃圾字符"
 
-#: fortran/openmp.c:2942 fortran/openmp.c:6225
+#: fortran/openmp.c:2941 fortran/openmp.c:6230
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined %s !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2946 fortran/openmp.c:6229
+#: fortran/openmp.c:2945 fortran/openmp.c:6234
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of predefined !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2951
+#: fortran/openmp.c:2950
 #, gcc-internal-format, gfc-internal-format
 msgid "Redefinition of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2953
+#: fortran/openmp.c:2952
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:2973
+#: fortran/openmp.c:2972
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after !$OMP DECLARE REDUCTION at %C"
 msgstr "%C处 ELSE IF 语句后有非预期的垃圾字符"
 
-#: fortran/openmp.c:3010
+#: fortran/openmp.c:3009
 #, gcc-internal-format, gfc-internal-format
 msgid "Only the !$OMP DECLARE TARGET form without clauses is allowed in interface block at %C"
 msgstr ""
 
-#: fortran/openmp.c:3025
+#: fortran/openmp.c:3024
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after !$OMP DECLARE TARGET at %C"
 msgstr "%C处 ELSE IF 语句后有非预期的垃圾字符"
 
-#: fortran/openmp.c:3048
+#: fortran/openmp.c:3047
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET variable at %L is an element of a COMMON block"
 msgstr " %C 处线程局部变量是个 COMMON 块的元素"
 
-#: fortran/openmp.c:3053
+#: fortran/openmp.c:3052
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET variable at %L previously mentioned in LINK clause and later in TO clause"
 msgstr ""
 
-#: fortran/openmp.c:3059
+#: fortran/openmp.c:3058
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET variable at %L previously mentioned in TO clause and later in LINK clause"
 msgstr ""
 
-#: fortran/openmp.c:3063
+#: fortran/openmp.c:3062
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable at %L mentioned multiple times in clauses of the same OMP DECLARE TARGET directive"
 msgstr ""
 
-#: fortran/openmp.c:3078
+#: fortran/openmp.c:3077
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET COMMON at %L previously mentioned in LINK clause and later in TO clause"
 msgstr ""
 
-#: fortran/openmp.c:3084
+#: fortran/openmp.c:3083
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP DECLARE TARGET COMMON at %L previously mentioned in TO clause and later in LINK clause"
 msgstr ""
 
-#: fortran/openmp.c:3088
+#: fortran/openmp.c:3087
 #, gcc-internal-format, gfc-internal-format
 msgid "COMMON at %L mentioned multiple times in clauses of the same OMP DECLARE TARGET directive"
 msgstr ""
 
-#: fortran/openmp.c:3115
+#: fortran/openmp.c:3114
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$OMP DECLARE TARGET list at %C"
 msgstr "%C处 !$OMP THREADPRIVATE 列表语法错误"
 
-#: fortran/openmp.c:3147
+#: fortran/openmp.c:3146
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate variable at %C is an element of a COMMON block"
 msgstr " %C 处线程局部变量是个 COMMON 块的元素"
 
-#: fortran/openmp.c:3184
+#: fortran/openmp.c:3183
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after OMP THREADPRIVATE at %C"
 msgstr "%C处 ELSE IF 语句后有非预期的垃圾字符"
 
-#: fortran/openmp.c:3191
+#: fortran/openmp.c:3190
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in !$OMP THREADPRIVATE list at %C"
 msgstr "%C处 !$OMP THREADPRIVATE 列表语法错误"
 
-#: fortran/openmp.c:3405
+#: fortran/openmp.c:3404
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after TASKWAIT clause at %C"
 msgstr "%C处 ELSE 语句后有非预期的垃圾字符"
 
-#: fortran/openmp.c:3419
+#: fortran/openmp.c:3418
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after TASKYIELD clause at %C"
 msgstr "%C处 ELSE IF 语句后有非预期的垃圾字符"
 
-#: fortran/openmp.c:3478
+#: fortran/openmp.c:3477
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP WORKSHARE statement at %C"
 msgstr "%C处 ELSE IF 语句后有非预期的垃圾字符"
 
-#: fortran/openmp.c:3492
+#: fortran/openmp.c:3491
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP MASTER statement at %C"
 msgstr "%C处 ELSE IF 语句后有非预期的垃圾字符"
 
-#: fortran/openmp.c:3551
+#: fortran/openmp.c:3550
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP ATOMIC statement at %C"
 msgstr "%C处 ELSE IF 语句后有非预期的垃圾字符"
 
-#: fortran/openmp.c:3578
+#: fortran/openmp.c:3577
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP BARRIER statement at %C"
 msgstr "%C处 ELSE IF 语句后有非预期的垃圾字符"
 
-#: fortran/openmp.c:3592
+#: fortran/openmp.c:3591
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP TASKGROUP statement at %C"
 msgstr "%C处 ELSE 语句后有非预期的垃圾字符"
 
-#: fortran/openmp.c:3642
+#: fortran/openmp.c:3641
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after $OMP CANCELLATION POINT statement at %C"
 msgstr "%C处 ELSE IF 语句后有非预期的垃圾字符"
 
-#: fortran/openmp.c:3662
+#: fortran/openmp.c:3661
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unexpected junk after NOWAIT clause at %C"
 msgstr "%C处 ELSE 语句后有非预期的垃圾字符"
 
-#: fortran/openmp.c:3704
+#: fortran/openmp.c:3703
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s clause at %L requires a scalar INTEGER expression"
 msgstr "%L处的 NUM_THREADS 分句需要一个标量 INTEGER 表达式"
 
-#: fortran/openmp.c:3715
+#: fortran/openmp.c:3714
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "INTEGER expression of %s clause at %L must be positive"
 msgstr "%L处的表达式必须具有 INTEGER 类型而不是 %s"
 
-#: fortran/openmp.c:3726
+#: fortran/openmp.c:3725
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "INTEGER expression of %s clause at %L must be non-negative"
 msgstr "%L处的表达式必须具有 INTEGER 类型而不是 %s"
 
-#: fortran/openmp.c:3737
+#: fortran/openmp.c:3736
 #, fuzzy, gcc-internal-format
 msgid "POINTER object %qs of derived type in %s clause at %L"
 msgstr "%3$L处 %2$s 分句中的 POINTER 对象‘%1$s’"
 
-#: fortran/openmp.c:3740
+#: fortran/openmp.c:3739
 #, fuzzy, gcc-internal-format
 msgid "Cray pointer object %qs of derived type in %s clause at %L"
 msgstr "%3$L处 %2$s 分句中的 Cray 指针‘%1$s’"
 
-#: fortran/openmp.c:3743
+#: fortran/openmp.c:3742
 #, fuzzy, gcc-internal-format
 msgid "Cray pointee object %qs of derived type in %s clause at %L"
 msgstr "%3$L处 %2$s 分句中 的Cray 指针目标‘%1$s’"
 
-#: fortran/openmp.c:3749 fortran/openmp.c:4687
+#: fortran/openmp.c:3748 fortran/openmp.c:4686
 #, fuzzy, gcc-internal-format
 msgid "POINTER object %qs of polymorphic type in %s clause at %L"
 msgstr "%3$L处 %2$s 分句中的 POINTER 对象‘%1$s’"
 
-#: fortran/openmp.c:3754
+#: fortran/openmp.c:3753
 #, fuzzy, gcc-internal-format
 msgid "Cray pointer object %qs of polymorphic type in %s clause at %L"
 msgstr "%3$L处 %2$s 分句中的 Cray 指针‘%1$s’"
 
-#: fortran/openmp.c:3759
+#: fortran/openmp.c:3758
 #, fuzzy, gcc-internal-format
 msgid "Cray pointee object %qs of polymorphic type in %s clause at %L"
 msgstr "%3$L处 %2$s 分句中 的Cray 指针目标‘%1$s’"
 
-#: fortran/openmp.c:3769 fortran/openmp.c:4385 fortran/openmp.c:4490
+#: fortran/openmp.c:3768 fortran/openmp.c:4384 fortran/openmp.c:4489
 #, fuzzy, gcc-internal-format
 msgid "Assumed size array %qs in %s clause at %L"
 msgstr "%3$L处 %2$s 分句中假定大小的数组‘%1$s’"
 
-#: fortran/openmp.c:3772
+#: fortran/openmp.c:3771
 #, fuzzy, gcc-internal-format
 msgid "Assumed rank array %qs in %s clause at %L"
 msgstr "%3$L处 %2$s 分句中假定大小的数组‘%1$s’"
 
-#: fortran/openmp.c:3776
+#: fortran/openmp.c:3775
 #, fuzzy, gcc-internal-format
 msgid "Noncontiguous deferred shape array %qs in %s clause at %L"
 msgstr "%3$L处 %2$s 分句中假定大小的数组‘%1$s’"
 
-#: fortran/openmp.c:3784
+#: fortran/openmp.c:3783
 #, fuzzy, gcc-internal-format
 msgid "ALLOCATABLE object %qs of derived type in %s clause at %L"
 msgstr "%3$L处 %2$s 分句中的 POINTER 对象‘%1$s’"
 
-#: fortran/openmp.c:3789
+#: fortran/openmp.c:3788
 #, fuzzy, gcc-internal-format
 msgid "ALLOCATABLE object %qs of polymorphic type in %s clause at %L"
 msgstr "%3$L处 %2$s 分句中的 POINTER 对象‘%1$s’"
 
-#: fortran/openmp.c:3801 fortran/openmp.c:4480
+#: fortran/openmp.c:3800 fortran/openmp.c:4479
 #, fuzzy, gcc-internal-format
 msgid "POINTER object %qs in %s clause at %L"
 msgstr "%3$L处 %2$s 分句中的 POINTER 对象‘%1$s’"
 
-#: fortran/openmp.c:3806 fortran/openmp.c:4691
+#: fortran/openmp.c:3805 fortran/openmp.c:4690
 #, fuzzy, gcc-internal-format
 msgid "Cray pointer object %qs in %s clause at %L"
 msgstr "%3$L处 %2$s 分句中的 Cray 指针‘%1$s’"
 
-#: fortran/openmp.c:3811 fortran/openmp.c:4694
+#: fortran/openmp.c:3810 fortran/openmp.c:4693
 #, fuzzy, gcc-internal-format
 msgid "Cray pointee object %qs in %s clause at %L"
 msgstr "%3$L处 %2$s 分句中 的Cray 指针目标‘%1$s’"
 
-#: fortran/openmp.c:3816 fortran/openmp.c:4682
+#: fortran/openmp.c:3815 fortran/openmp.c:4681
 #, fuzzy, gcc-internal-format
 msgid "ALLOCATABLE object %qs in %s clause at %L"
 msgstr "%3$L处 %2$s 分句中的 POINTER 对象‘%1$s’"
 
-#: fortran/openmp.c:3819
+#: fortran/openmp.c:3818
 #, fuzzy, gcc-internal-format
 msgid "VALUE object %qs in %s clause at %L"
 msgstr "%3$L处 %2$s 分句中的 POINTER 对象‘%1$s’"
 
-#: fortran/openmp.c:3862
+#: fortran/openmp.c:3861
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Implicitly declared function %s used in !$OMP DECLARE REDUCTION at %L"
 msgstr "%C处 ELSE IF 语句后有非预期的垃圾字符"
 
-#: fortran/openmp.c:3911
+#: fortran/openmp.c:3910
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Implicitly declared subroutine %s used in !$OMP DECLARE REDUCTION at %L"
 msgstr "%C处 ELSE IF 语句后有非预期的垃圾字符"
 
-#: fortran/openmp.c:3944
+#: fortran/openmp.c:3943
 #, gcc-internal-format, gfc-internal-format
 msgid "ORDERED clause parameter is less than COLLAPSE at %L"
 msgstr ""
 
-#: fortran/openmp.c:3952 fortran/openmp.c:3963 fortran/resolve.c:10028
-#: fortran/resolve.c:11295
+#: fortran/openmp.c:3951 fortran/openmp.c:3962 fortran/resolve.c:10041
+#: fortran/resolve.c:11315
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause at %L requires a scalar LOGICAL expression"
 msgstr "%L处的 IF 分句需要一个标量 LOGICAL 表达式"
 
-#: fortran/openmp.c:3967
+#: fortran/openmp.c:3966
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause without modifier at %L used together with IF clauses with modifiers"
 msgstr ""
 
-#: fortran/openmp.c:4044
+#: fortran/openmp.c:4043
 #, gcc-internal-format, gfc-internal-format
 msgid "IF clause modifier %s at %L not appropriate for the current OpenMP construct"
 msgstr ""
 
-#: fortran/openmp.c:4054
+#: fortran/openmp.c:4053
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FINAL clause at %L requires a scalar LOGICAL expression"
 msgstr "%L处的 IF 分句需要一个标量 LOGICAL 表达式"
 
-#: fortran/openmp.c:4064
+#: fortran/openmp.c:4063
 #, gcc-internal-format, gfc-internal-format
 msgid "SCHEDULE clause's chunk_size at %L requires a scalar INTEGER expression"
 msgstr "%L处的 SCHEDULE 分句的 chunk_size 需要一个标量 INTEGER 表达式"
 
-#: fortran/openmp.c:4069
+#: fortran/openmp.c:4068
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "INTEGER expression of SCHEDULE clause's chunk_size at %L must be positive"
 msgstr "%L处的表达式必须具有 INTEGER 类型而不是 %s"
 
-#: fortran/openmp.c:4084
+#: fortran/openmp.c:4083
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs is not a dummy argument at %L"
 msgstr "%L处的符号不是一个 DUMMY 变量"
 
-#: fortran/openmp.c:4116
+#: fortran/openmp.c:4115 fortran/openmp.c:5998
 #, fuzzy, gcc-internal-format
 msgid "Object %qs is not a variable at %L"
 msgstr "可变大小的对象不能被初始化"
 
-#: fortran/openmp.c:4132 fortran/openmp.c:4143 fortran/openmp.c:4151
-#: fortran/openmp.c:4162 fortran/openmp.c:4174 fortran/openmp.c:4189
-#: fortran/openmp.c:6023
+#: fortran/openmp.c:4131 fortran/openmp.c:4142 fortran/openmp.c:4150
+#: fortran/openmp.c:4161 fortran/openmp.c:4173 fortran/openmp.c:4188
+#: fortran/openmp.c:6028
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs present on multiple clauses at %L"
 msgstr "%2$L处符号‘%1$s’出现在多个分句上"
 
-#: fortran/openmp.c:4196
+#: fortran/openmp.c:4195
 #, fuzzy, gcc-internal-format
 msgid "Array %qs is not permitted in reduction at %L"
 msgstr "变量‘%s’不能出现在%L处的表达式中"
 
-#: fortran/openmp.c:4209
+#: fortran/openmp.c:4208
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs present on both FROM and TO clauses at %L"
 msgstr "%2$L处符号‘%1$s’出现在多个分句上"
 
-#: fortran/openmp.c:4231
+#: fortran/openmp.c:4230
 #, fuzzy, gcc-internal-format
 msgid "Non-THREADPRIVATE object %qs in COPYIN clause at %L"
 msgstr "%2$L处 COPYIN 分句中的非 THREADPRIVATE 对象‘%1$s’"
 
-#: fortran/openmp.c:4239
+#: fortran/openmp.c:4238
 #, fuzzy, gcc-internal-format
 msgid "Assumed size array %qs in COPYPRIVATE clause at %L"
 msgstr "%2$L处 COPYPRIVATE 分句中有假定大小的数组‘%1$s’"
 
-#: fortran/openmp.c:4242
+#: fortran/openmp.c:4241
 #, fuzzy, gcc-internal-format
 msgid "INTENT(IN) POINTER %qs in COPYPRIVATE clause at %L"
 msgstr "%2$L处 COPYPRIVATE 分句中有假定大小的数组‘%1$s’"
 
-#: fortran/openmp.c:4250
+#: fortran/openmp.c:4249
 #, fuzzy, gcc-internal-format
 msgid "THREADPRIVATE object %qs in SHARED clause at %L"
 msgstr "%2$L处 SHARED 分句中的 THREADPRIVATE 对象‘%1$s’"
 
-#: fortran/openmp.c:4253
+#: fortran/openmp.c:4252
 #, fuzzy, gcc-internal-format
 msgid "Cray pointee %qs in SHARED clause at %L"
 msgstr "%2$L处 SHARED 分句中为 Cray 指针引用的‘%1$s’"
 
-#: fortran/openmp.c:4256
+#: fortran/openmp.c:4255
 #, fuzzy, gcc-internal-format
 msgid "ASSOCIATE name %qs in SHARED clause at %L"
 msgstr "%2$L处 SHARED 分句中的 THREADPRIVATE 对象‘%1$s’"
 
-#: fortran/openmp.c:4271
+#: fortran/openmp.c:4270
 #, gcc-internal-format
 msgid "%qs in ALIGNED clause must be POINTER, ALLOCATABLE, Cray pointer or C_PTR at %L"
 msgstr ""
 
-#: fortran/openmp.c:4283
+#: fortran/openmp.c:4282
 #, fuzzy, gcc-internal-format
 msgid "%qs in ALIGNED clause at %L requires a scalar positive constant integer alignment expression"
 msgstr "%H折叠变量需要正整常数表达式"
 
-#: fortran/openmp.c:4302
+#: fortran/openmp.c:4301
 #, gcc-internal-format, gfc-internal-format
 msgid "SINK dependence type only allowed on ORDERED directive at %L"
 msgstr ""
 
-#: fortran/openmp.c:4306
+#: fortran/openmp.c:4305
 #, gcc-internal-format, gfc-internal-format
 msgid "DEPEND SINK used together with DEPEND SOURCE on the same construct at %L"
 msgstr ""
 
-#: fortran/openmp.c:4316
+#: fortran/openmp.c:4315
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "accumulator is not a constant integer"
 msgid "SINK addend not a constant integer at %L"
 msgstr "累加数不是一个整常量"
 
-#: fortran/openmp.c:4322
+#: fortran/openmp.c:4321
 #, gcc-internal-format, gfc-internal-format
 msgid "Only SOURCE or SINK dependence types are allowed on ORDERED directive at %L"
 msgstr ""
 
-#: fortran/openmp.c:4333 fortran/openmp.c:4354
+#: fortran/openmp.c:4332 fortran/openmp.c:4353
 #, gcc-internal-format
 msgid "%qs in %s clause at %L is not a proper array section"
 msgstr ""
 
-#: fortran/openmp.c:4337
+#: fortran/openmp.c:4336
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coarrays not supported in %s clause at %L"
 msgstr "%3$L处 %2$s 分句中 的Cray 指针目标‘%1$s’"
 
-#: fortran/openmp.c:4346
+#: fortran/openmp.c:4345
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Stride should not be specified for array section in %s clause at %L"
 msgstr "使用了变长数组"
 
-#: fortran/openmp.c:4367
+#: fortran/openmp.c:4366
 #, gcc-internal-format
 msgid "%qs in DEPEND clause at %L is a zero size array section"
 msgstr ""
 
-#: fortran/openmp.c:4403
+#: fortran/openmp.c:4402
 #, gcc-internal-format, gfc-internal-format
 msgid "TARGET%s with map-type other than TO, FROM, TOFROM, or ALLOC on MAP clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4419
+#: fortran/openmp.c:4418
 #, gcc-internal-format, gfc-internal-format
 msgid "TARGET ENTER DATA with map-type other than TO, or ALLOC on MAP clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4434
+#: fortran/openmp.c:4433
 #, gcc-internal-format, gfc-internal-format
 msgid "TARGET EXIT DATA with map-type other than FROM, RELEASE, or DELETE on MAP clause at %L"
 msgstr ""
 
-#: fortran/openmp.c:4450 fortran/openmp.c:4466
+#: fortran/openmp.c:4449 fortran/openmp.c:4465
 #, fuzzy, gcc-internal-format
 msgid "THREADPRIVATE object %qs in %s clause at %L"
 msgstr "%3$L处 %2$s 分句中的 THREADPRIVATE 对象‘%1$s’"
 
-#: fortran/openmp.c:4453 fortran/openmp.c:4469
+#: fortran/openmp.c:4452 fortran/openmp.c:4468
 #, fuzzy, gcc-internal-format
 msgid "Cray pointee %qs in %s clause at %L"
 msgstr "%3$L处 %2$s 分句中 的Cray 指针目标‘%1$s’"
 
-#: fortran/openmp.c:4472
+#: fortran/openmp.c:4471
 #, fuzzy, gcc-internal-format
 msgid "ASSOCIATE name %qs in %s clause at %L"
 msgstr "%3$L处 %2$s 分句中的 POINTER 对象‘%1$s’"
 
-#: fortran/openmp.c:4477
+#: fortran/openmp.c:4476
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer %qs in %s clause at %L"
 msgstr "%L处过程指针赋值中接口不匹配：%s"
 
-#: fortran/openmp.c:4483
+#: fortran/openmp.c:4482
 #, fuzzy, gcc-internal-format
 msgid "Cray pointer %qs in %s clause at %L"
 msgstr "%3$L处 %2$s 分句中的 Cray 指针‘%1$s’"
 
-#: fortran/openmp.c:4493
+#: fortran/openmp.c:4492
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs in %s clause is used in NAMELIST statement at %L"
 msgstr "%2$s 分句中的变量‘%1$s’被用在%3$L处的 NAMELIST 语句中"
 
 #. case OMP_LIST_REDUCTION:
-#: fortran/openmp.c:4503
+#: fortran/openmp.c:4502
 #, fuzzy, gcc-internal-format
 msgid "INTENT(IN) POINTER %qs in %s clause at %L"
 msgstr "%3$L处 %2$s 分句中的 POINTER 对象‘%1$s’"
 
-#: fortran/openmp.c:4596
+#: fortran/openmp.c:4595
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP DECLARE REDUCTION %s not found for type %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:4622
+#: fortran/openmp.c:4621
 #, gcc-internal-format, gfc-internal-format
 msgid "LINEAR clause modifier used on DO or SIMD construct at %L"
 msgstr ""
 
-#: fortran/openmp.c:4627
+#: fortran/openmp.c:4626
 #, gcc-internal-format, gfc-internal-format
 msgid "LINEAR clause specified together with ORDERED clause with argument at %L"
 msgstr ""
 
-#: fortran/openmp.c:4632
+#: fortran/openmp.c:4631
 #, fuzzy, gcc-internal-format
 msgid "LINEAR variable %qs must be INTEGER at %L"
 msgstr "%L处 stat 变量必须是一个标量 INTEGER 变量"
 
-#: fortran/openmp.c:4637
+#: fortran/openmp.c:4636
 #, fuzzy, gcc-internal-format
 msgid "LINEAR dummy argument %qs with VALUE attribute with %s modifier at %L"
 msgstr "‘%s’的实参在%L处必须是一个指针"
 
-#: fortran/openmp.c:4648
+#: fortran/openmp.c:4647
 #, fuzzy, gcc-internal-format
 msgid "%qs in LINEAR clause at %L requires a scalar integer linear-step expression"
 msgstr "%L处的 IF 分句需要一个标量 LOGICAL 表达式"
 
-#: fortran/openmp.c:4665
+#: fortran/openmp.c:4664
 #, fuzzy, gcc-internal-format
 msgid "%qs in LINEAR clause at %L requires a constant integer linear-step expression or dummy argument specified in UNIFORM clause"
 msgstr "%L处的 IF 分句需要一个标量 LOGICAL 表达式"
 
-#: fortran/openmp.c:4699
+#: fortran/openmp.c:4698
 #, fuzzy, gcc-internal-format
 msgid "%s clause variable %qs at %L is neither a POINTER nor an array"
 msgstr "向量 delete 的实参类型既非指针也非数组"
 
-#: fortran/openmp.c:4731
+#: fortran/openmp.c:4730
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DIST_SCHEDULE clause's chunk_size at %L requires a scalar INTEGER expression"
 msgstr "%L处的 SCHEDULE 分句的 chunk_size 需要一个标量 INTEGER 表达式"
 
-#: fortran/openmp.c:4763
+#: fortran/openmp.c:4762
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Incompatible ranks in %s (%d and %d) at %L"
 msgid "Incompatible use of TILE and COLLAPSE at %L"
 msgstr "%4$L%1$s 中秩(%2$d 和 %3$d)不兼容"
 
-#: fortran/openmp.c:4765
+#: fortran/openmp.c:4764
 #, gcc-internal-format, gfc-internal-format
 msgid "SOURCE dependence type only allowed on ORDERED directive at %L"
 msgstr ""
 
-#: fortran/openmp.c:4778
+#: fortran/openmp.c:4777
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s must contain at least one MAP clause at %L"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: fortran/openmp.c:4875
+#: fortran/openmp.c:4874
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unexpected !$OMP ATOMIC expression at %L"
 msgstr "%C处 ELSE IF 语句后有非预期的垃圾字符"
 
-#: fortran/openmp.c:4904
+#: fortran/openmp.c:4903
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC statement must set a scalar variable of intrinsic type at %L"
 msgstr "%L处 !$OMP ATOMIC 语句必须设定一个内建类型的标量值"
 
-#: fortran/openmp.c:4929
+#: fortran/openmp.c:4928
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC READ statement must read from a scalar variable of intrinsic type at %L"
 msgstr "%L处 !$OMP ATOMIC 语句必须设定一个内建类型的标量值"
 
-#: fortran/openmp.c:4934
+#: fortran/openmp.c:4933
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "expr in !$OMP ATOMIC WRITE assignment var = expr must be scalar and cannot reference var at %L"
 msgstr "%L处 !$OMP ATOMIC 赋值“变量 = 变量 运算符 表达式”中的“表达式”必须是标量并且不能引用“变量”"
 
-#: fortran/openmp.c:4956 fortran/openmp.c:5247
+#: fortran/openmp.c:4955 fortran/openmp.c:5246
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE capture statement must read from a scalar variable of intrinsic type at %L"
 msgstr "%L处 !$OMP ATOMIC 语句必须设定一个内建类型的标量值"
 
-#: fortran/openmp.c:4971
+#: fortran/openmp.c:4970
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE update statement must set a scalar variable of intrinsic type at %L"
 msgstr "%L处 !$OMP ATOMIC 语句必须设定一个内建类型的标量值"
 
-#: fortran/openmp.c:4978 fortran/openmp.c:5254
+#: fortran/openmp.c:4977 fortran/openmp.c:5253
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE capture statement reads from different variable than update statement writes into at %L"
 msgstr "!$OMP 基元的截取截取叙述读取从不同的变量比更新叙述写入进入于 %L"
 
-#: fortran/openmp.c:4994
+#: fortran/openmp.c:4993
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC with ALLOCATABLE variable at %L"
 msgstr "%L处 !$OMP ATOMIC 内建函数的实参必须是标量"
 
-#: fortran/openmp.c:5036
+#: fortran/openmp.c:5035
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment operator must be binary +, *, -, /, .AND., .OR., .EQV. or .NEQV. at %L"
 msgstr "%L处 !$OMP ATOMIC 赋值运算符必须是 +、*、-、/、.AND.、.OR.、.EQV. 或 .NEQV."
 
-#: fortran/openmp.c:5084
+#: fortran/openmp.c:5083
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment must be var = var op expr or var = expr op var at %L"
 msgstr "%L处 !$OMP ATOMIC 赋值形式必须为“变量 = 变量 运算符 表达式”或“变量 = 表达式 运算符 变量”"
 
-#: fortran/openmp.c:5098
+#: fortran/openmp.c:5097
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC var = var op expr not mathematically equivalent to var = var op (expr) at %L"
 msgstr "%L处 !$OMP ATOMIC“变量 = 变量 运算符 表达式”与“变量 = 变量 运算符 (表达式)”在数学上不等价"
 
-#: fortran/openmp.c:5130
+#: fortran/openmp.c:5129
 #, gcc-internal-format, gfc-internal-format
 msgid "expr in !$OMP ATOMIC assignment var = var op expr must be scalar and cannot reference var at %L"
 msgstr "%L处 !$OMP ATOMIC 赋值“变量 = 变量 运算符 表达式”中的“表达式”必须是标量并且不能引用“变量”"
 
-#: fortran/openmp.c:5154
+#: fortran/openmp.c:5153
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment intrinsic IAND, IOR or IEOR must have two arguments at %L"
 msgstr "%L处 !$OMP ATOMIC 赋值内建函数 IAND、IOR 或 IEOR 必须带两个实参"
 
-#: fortran/openmp.c:5161
+#: fortran/openmp.c:5160
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment intrinsic must be MIN, MAX, IAND, IOR or IEOR at %L"
 msgstr "%L处!$OMP ATOMIC 赋值内建函数必须是 MIN、MAX、IAND、IOR 或 IEOR"
 
-#: fortran/openmp.c:5178
+#: fortran/openmp.c:5177
 #, fuzzy, gcc-internal-format
 msgid "!$OMP ATOMIC intrinsic arguments except one must not reference %qs at %L"
 msgstr "!$OMP ATOMIC 内建函数的实参除一个以外不能在%2$L处引用‘%1$s’"
 
-#: fortran/openmp.c:5185
+#: fortran/openmp.c:5184
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC intrinsic arguments must be scalar at %L"
 msgstr "%L处 !$OMP ATOMIC 内建函数的实参必须是标量"
 
-#: fortran/openmp.c:5193
+#: fortran/openmp.c:5192
 #, fuzzy, gcc-internal-format
 msgid "First or last !$OMP ATOMIC intrinsic argument must be %qs at %L"
 msgstr "第一个或最后一个 !$OMP ATOMIC 内建函数实参在%2$L处必须是‘%1$s’"
 
-#: fortran/openmp.c:5211
+#: fortran/openmp.c:5210
 #, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC assignment must have an operator or intrinsic on right hand side at %L"
 msgstr "%L处 !$OMP ATOMIC 赋值的右手边必须有一个运算符或内建函数"
 
-#: fortran/openmp.c:5225
+#: fortran/openmp.c:5224
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "!$OMP ATOMIC CAPTURE capture statement must set a scalar variable of intrinsic type at %L"
 msgstr "%L处 !$OMP ATOMIC 语句必须设定一个内建类型的标量值"
 
-#: fortran/openmp.c:5544
+#: fortran/openmp.c:5543
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s cannot be a DO WHILE or DO without loop control at %L"
 msgstr "%L处 !$OMP DO 不能是一个 DO WHILE 或不带循环控制的 DO"
 
-#: fortran/openmp.c:5550
+#: fortran/openmp.c:5549
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s cannot be a DO CONCURRENT loop at %L"
 msgstr "%L处的 DO 循环中的步进表达式不能为零"
 
-#: fortran/openmp.c:5556
+#: fortran/openmp.c:5555
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable must be of type integer at %L"
 msgstr "%L处的表达式必须具有 INTEGER 类型而不是 %s"
 
-#: fortran/openmp.c:5560
+#: fortran/openmp.c:5559
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable must not be THREADPRIVATE at %L"
 msgstr "%L处 !$OMP DO 迭代变量不能是 THREADPRIVATE"
 
-#: fortran/openmp.c:5573
+#: fortran/openmp.c:5572
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable present on clause other than PRIVATE or LASTPRIVATE at %L"
 msgstr "%L处 !$OMP DO 迭代变量出现在非 PRIVATE 或 LASTPRIVATE 分句中"
 
-#: fortran/openmp.c:5577
+#: fortran/openmp.c:5576
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable present on clause other than LASTPRIVATE at %L"
 msgstr "%L处 !$OMP DO 迭代变量出现在非 PRIVATE 或 LASTPRIVATE 分句中"
 
-#: fortran/openmp.c:5581
+#: fortran/openmp.c:5580
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s iteration variable present on clause other than LINEAR at %L"
 msgstr "%L处 !$OMP DO 迭代变量出现在非 PRIVATE 或 LASTPRIVATE 分句中"
 
-#: fortran/openmp.c:5599
+#: fortran/openmp.c:5598
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s collapsed loops don't form rectangular iteration space at %L"
 msgstr "%L处 !$OMP DO 折叠的循环不形成矩形迭代空间"
 
-#: fortran/openmp.c:5611
+#: fortran/openmp.c:5610
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "collapsed %s loops not perfectly nested at %L"
 msgstr "折叠的循环没有完美的嵌套"
 
-#: fortran/openmp.c:5620 fortran/openmp.c:5628
+#: fortran/openmp.c:5619 fortran/openmp.c:5627
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for collapsed %s at %L"
 msgstr "%L处折叠的 !$OMP DO 没有足够的 DO 循环"
 
-#: fortran/openmp.c:5712 fortran/openmp.c:5725
+#: fortran/openmp.c:5711 fortran/openmp.c:5724
 #, gcc-internal-format, gfc-internal-format
 msgid "The %s directive cannot be specified within a %s region at %L"
 msgstr ""
 
-#: fortran/openmp.c:5744
+#: fortran/openmp.c:5743
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP cannot be a DO WHILE or DO without loop control at %L"
 msgstr "%L处 !$OMP DO 不能是一个 DO WHILE 或不带循环控制的 DO"
 
-#: fortran/openmp.c:5750
+#: fortran/openmp.c:5749
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP iteration variable must be of type integer at %L"
 msgstr "%L处 !$OMP DO 迭代变量必须具有整数类型"
 
-#: fortran/openmp.c:5766
+#: fortran/openmp.c:5765
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s loops don't form rectangular iteration space at %L"
 msgstr "%L处 !$OMP DO 折叠的循环不形成矩形迭代空间"
 
-#: fortran/openmp.c:5778
+#: fortran/openmp.c:5777
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s !$ACC LOOP loops not perfectly nested at %L"
 msgstr "折叠的 !$OMP DO 循环没有完美的嵌套于%L处"
 
-#: fortran/openmp.c:5788 fortran/openmp.c:5797
+#: fortran/openmp.c:5787 fortran/openmp.c:5796
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "not enough DO loops for %s !$ACC LOOP at %L"
 msgstr "%L处折叠的 !$OMP DO 没有足够的 DO 循环"
 
-#: fortran/openmp.c:5812 fortran/openmp.c:5819
+#: fortran/openmp.c:5811 fortran/openmp.c:5818
 #, gcc-internal-format, gfc-internal-format
 msgid "!$ACC LOOP %s in PARALLEL region doesn't allow %s arguments at %L"
 msgstr ""
 
-#: fortran/openmp.c:5841
+#: fortran/openmp.c:5840
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside another loop parallelized across gangs at %L"
 msgstr ""
 
-#: fortran/openmp.c:5845 fortran/openmp.c:5849
+#: fortran/openmp.c:5844 fortran/openmp.c:5848
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across gangs is not allowed inside loop parallelized across workers at %L"
 msgstr ""
 
-#: fortran/openmp.c:5856
+#: fortran/openmp.c:5855
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across workers at %L"
 msgstr ""
 
-#: fortran/openmp.c:5860
+#: fortran/openmp.c:5859
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across workers is not allowed inside another loop parallelized across vectors at %L"
 msgstr ""
 
-#: fortran/openmp.c:5866
+#: fortran/openmp.c:5865
 #, gcc-internal-format, gfc-internal-format
 msgid "Loop parallelized across vectors is not allowed inside another loop parallelized across vectors at %L"
 msgstr ""
 
-#: fortran/openmp.c:5878
+#: fortran/openmp.c:5877
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with INDEPENDENT at %L"
 msgstr "INTENT (%s) 与 INTENT(%s) 在 %L 冲突"
 
-#: fortran/openmp.c:5880
+#: fortran/openmp.c:5879
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with GANG at %L"
 msgstr "%s 属性与 %s 属性在%L处冲突"
 
-#: fortran/openmp.c:5882
+#: fortran/openmp.c:5881
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with WORKER at %L"
 msgstr "%L处的 SOURCE 标记与%L处的类型指定冲突"
 
-#: fortran/openmp.c:5884
+#: fortran/openmp.c:5883
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with VECTOR at %L"
 msgstr "%L处的 SOURCE 标记与%L处的类型指定冲突"
 
-#: fortran/openmp.c:5886
+#: fortran/openmp.c:5885
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Clause SEQ conflicts with AUTO at %L"
 msgstr "%L处的 SOURCE 标记与%L处的类型指定冲突"
 
-#: fortran/openmp.c:5891
+#: fortran/openmp.c:5890
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with GANG at %L"
 msgstr "%s 属性与 %s 属性在%L处冲突"
 
-#: fortran/openmp.c:5893
+#: fortran/openmp.c:5892
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with WORKER at %L"
 msgstr "%L处的 SOURCE 标记与%L处的类型指定冲突"
 
-#: fortran/openmp.c:5895
+#: fortran/openmp.c:5894
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Clause AUTO conflicts with VECTOR at %L"
 msgstr "%L处的 SOURCE 标记与%L处的类型指定冲突"
 
-#: fortran/openmp.c:5899
+#: fortran/openmp.c:5898
 #, gcc-internal-format, gfc-internal-format
 msgid "Tiled loop cannot be parallelized across gangs, workers and vectors at the same time at %L"
 msgstr ""
 
-#: fortran/openmp.c:5934
+#: fortran/openmp.c:5933
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "TILE requires constant expression at %L"
 msgstr "%L处的 IF 分句需要一个标量 LOGICAL 表达式"
 
-#: fortran/openmp.c:5999
+#: fortran/openmp.c:6004
 #, fuzzy, gcc-internal-format
 msgid "PARAMETER object %qs is not allowed at %L"
 msgstr "%3$L处 %2$s 分句中的 POINTER 对象‘%1$s’"
 
-#: fortran/openmp.c:6006
+#: fortran/openmp.c:6011
 #, fuzzy, gcc-internal-format
 msgid "Array sections: %qs not allowed in !$ACC DECLARE at %L"
 msgstr "%L过程参数无效"
 
-#: fortran/openmp.c:6133
+#: fortran/openmp.c:6138
 #, gcc-internal-format, gfc-internal-format
 msgid "OMP TARGET UPDATE at %L requires at least one TO or FROM clause"
 msgstr ""
 
-#: fortran/openmp.c:6155
+#: fortran/openmp.c:6160
 #, gcc-internal-format
 msgid "!$OMP DECLARE SIMD should refer to containing procedure %qs at %L"
 msgstr ""
 
-#: fortran/openmp.c:6179
+#: fortran/openmp.c:6184
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_PRIV or OMP_ORIG used in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6187
+#: fortran/openmp.c:6192
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable other than OMP_OUT or OMP_IN used in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6216
+#: fortran/openmp.c:6221
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid operator for !$OMP DECLARE REDUCTION %s at %L"
 msgstr ""
 
-#: fortran/openmp.c:6238
+#: fortran/openmp.c:6243
 #, gcc-internal-format, gfc-internal-format
 msgid "CHARACTER length in !$OMP DECLARE REDUCTION %s not constant at %L"
 msgstr ""
 
-#: fortran/openmp.c:6254
+#: fortran/openmp.c:6259
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in combiner of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6269
+#: fortran/openmp.c:6274
 #, gcc-internal-format, gfc-internal-format
 msgid "Subroutine call with alternate returns in INITIALIZER clause of !$OMP DECLARE REDUCTION at %L"
 msgstr ""
 
-#: fortran/openmp.c:6279
+#: fortran/openmp.c:6284
 #, gcc-internal-format, gfc-internal-format
 msgid "One of actual subroutine arguments in INITIALIZER clause of !$OMP DECLARE REDUCTION must be OMP_PRIV at %L"
 msgstr ""
 
-#: fortran/openmp.c:6287
+#: fortran/openmp.c:6292
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing INITIALIZER clause for !$OMP DECLARE REDUCTION of derived type without default initializer at %L"
 msgstr ""
@@ -61620,499 +61702,499 @@
 msgid "Unclassifiable statement at %C"
 msgstr "%C语句无法归类"
 
-#: fortran/parse.c:629
+#: fortran/parse.c:631
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "OpenACC directives at %C may not appear in PURE procedures"
 msgstr "%C处的 OpenMP 指示不能出现在 PURE 或 ELEMENTAL 过程中"
 
-#: fortran/parse.c:705
+#: fortran/parse.c:707
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable OpenACC directive at %C"
 msgstr "%C处的 OpenMP 指示无法分类"
 
-#: fortran/parse.c:831 fortran/parse.c:1040
+#: fortran/parse.c:835 fortran/parse.c:1044
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "OpenMP directives at %C may not appear in PURE or ELEMENTAL procedures"
 msgid "OpenMP directives other than SIMD or DECLARE TARGET at %C may not appear in PURE or ELEMENTAL procedures"
 msgstr "%C处的 OpenMP 指示不能出现在 PURE 或 ELEMENTAL 过程中"
 
-#: fortran/parse.c:1024
+#: fortran/parse.c:1028
 #, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable OpenMP directive at %C"
 msgstr "%C处的 OpenMP 指示无法分类"
 
-#: fortran/parse.c:1076
+#: fortran/parse.c:1080
 #, gcc-internal-format, gfc-internal-format
 msgid "Unclassifiable GCC directive at %C"
 msgstr "%C处的 GCC 指示无法分类"
 
-#: fortran/parse.c:1135 fortran/parse.c:1362
+#: fortran/parse.c:1139 fortran/parse.c:1366
 #, gcc-internal-format, gfc-internal-format
 msgid "Zero is not a valid statement label at %C"
 msgstr "零不是%C处的一个有效的语句标号"
 
-#: fortran/parse.c:1142 fortran/parse.c:1354
+#: fortran/parse.c:1146 fortran/parse.c:1358
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-numeric character in statement label at %C"
 msgstr "%C处语句标号中出现非数字字符"
 
-#: fortran/parse.c:1154 fortran/parse.c:1403
+#: fortran/parse.c:1158 fortran/parse.c:1407
 #, gcc-internal-format, gfc-internal-format
 msgid "Semicolon at %C needs to be preceded by statement"
 msgstr "%C处分号前必须是一个语句"
 
-#: fortran/parse.c:1161 fortran/parse.c:1418
+#: fortran/parse.c:1165 fortran/parse.c:1422
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Ignoring statement label in empty statement at %L"
 msgid "Statement label without statement at %L"
 msgstr "忽略%L处空语句中的语句标号"
 
-#: fortran/parse.c:1224 fortran/parse.c:1405
+#: fortran/parse.c:1228 fortran/parse.c:1409
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Semicolon at %C without preceding statement"
 msgstr "Fortran 2008：%C 处 CONTAINS 语句没有 FUNCTION 或 SUBROUTINE 语句"
 
-#: fortran/parse.c:1247 fortran/parse.c:1381
+#: fortran/parse.c:1251 fortran/parse.c:1385
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad continuation line at %C"
 msgstr "%C处错误的续行"
 
-#: fortran/parse.c:1679
+#: fortran/parse.c:1683
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT statement at %L does not have a statement label"
 msgstr "%L处 FORMAT 语句没有语句标号"
 
-#: fortran/parse.c:2435
+#: fortran/parse.c:2439
 #, fuzzy, gcc-internal-format
 msgid "gfc_ascii_statement(): Bad statement code"
 msgstr "gfc_trans_omp_workshare()：错误的语句代码"
 
-#: fortran/parse.c:2577
+#: fortran/parse.c:2581
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement at %C"
 msgstr "%2$C处有非预期的 %1$s 语句"
 
-#: fortran/parse.c:2732
+#: fortran/parse.c:2736
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot follow %s statement at %L"
 msgstr "%s 语句在%C处不能跟随 %s 语句在%L处"
 
-#: fortran/parse.c:2749
+#: fortran/parse.c:2753
 #, fuzzy, gcc-internal-format
 msgid "Unexpected end of file in %qs"
 msgstr "脚本“%s”: 未预期结束的文件%s\n"
 
-#: fortran/parse.c:2784
+#: fortran/parse.c:2788
 #, fuzzy, gcc-internal-format
 msgid "Derived-type %qs with SEQUENCE must not have a CONTAINS section at %C"
 msgstr "%2$C处带有 SEQUENCE 派生类型‘%1$s’不能有 CONTAINS 节"
 
-#: fortran/parse.c:2787
+#: fortran/parse.c:2791
 #, fuzzy, gcc-internal-format
 msgid "Derived-type %qs with BIND(C) must not have a CONTAINS section at %C"
 msgstr "带 BIND(C) 的派生类‘%s’在%C处不能有 CONTAINS 节"
 
-#: fortran/parse.c:2807
+#: fortran/parse.c:2811
 #, gcc-internal-format, gfc-internal-format
 msgid "Components in TYPE at %C must precede CONTAINS"
 msgstr "%C处 TYPE 中的组件必须先于 CONTAINS"
 
-#: fortran/parse.c:2811
+#: fortran/parse.c:2815
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type-bound procedure at %C"
 msgstr "Fortran 2003：%C处的类型限定过程"
 
-#: fortran/parse.c:2819
+#: fortran/parse.c:2823
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "GENERIC binding at %C"
 msgstr "%C 处的泛型绑定后有垃圾字符"
 
-#: fortran/parse.c:2827
+#: fortran/parse.c:2831
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure declaration at %C"
 msgstr "%C处的 FINAL 声明必须在 CONTAINS 内"
 
-#: fortran/parse.c:2839
+#: fortran/parse.c:2843
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Derived type definition at %C with empty CONTAINS section"
 msgstr "%C处的 FINAL 声明必须在一个派生类型的 CONTAINS 节内"
 
-#: fortran/parse.c:2849 fortran/parse.c:3304
+#: fortran/parse.c:2853 fortran/parse.c:3308
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement in TYPE at %C must be inside a MODULE"
 msgstr "%C处 TYPE 中的 PRIVATE 语句必须在 MODULE 中"
 
-#: fortran/parse.c:2856
+#: fortran/parse.c:2860
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede procedure bindings"
 msgstr "%C处 PRIVATE 语句必须先于过程绑定"
 
-#: fortran/parse.c:2863 fortran/parse.c:3317
+#: fortran/parse.c:2867 fortran/parse.c:3321
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate PRIVATE statement at %C"
 msgstr "%C处重复的 PRIVATE 语句"
 
-#: fortran/parse.c:2873
+#: fortran/parse.c:2877
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede CONTAINS"
 msgstr "%C处 SEQUENCE 语句必须先于 CONTAINS"
 
-#: fortran/parse.c:2877
+#: fortran/parse.c:2881
 #, gcc-internal-format, gfc-internal-format
 msgid "Already inside a CONTAINS block at %C"
 msgstr "%C处已在一个 CONTAINS 块内部 "
 
-#: fortran/parse.c:2996
+#: fortran/parse.c:3000
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component %s at %L of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray, which is not possible as the component has the pointer attribute"
 msgstr "成分 %s 于 %L 的类型 LOCK_TYPE 必须有 codimension 或是 subcomponent 的 coarray，该项不是可能的作为成分有指标属性"
 
-#: fortran/parse.c:3002
+#: fortran/parse.c:3006
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer component %s at %L has a noncoarray subcomponent of type LOCK_TYPE, which must have a codimension or be a subcomponent of a coarray"
 msgstr "指标成分 %s 于 %L 有 noncoarray subcomponent 的类型 LOCK_TYPE，该项必须有 codimension 或是 subcomponent 的 coarray"
 
-#: fortran/parse.c:3007
+#: fortran/parse.c:3011
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L of type LOCK_TYPE must have a codimension"
 msgstr "%C处可分配的组件必须有延迟的外形"
 
-#: fortran/parse.c:3011
+#: fortran/parse.c:3015
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L must have a codimension as it has a noncoarray subcomponent of type LOCK_TYPE"
 msgstr "Allocatable 成分 %s 于 %L 必须有 codimension 作为它有 noncoarray subcomponent 的类型 LOCK_TYPE"
 
-#: fortran/parse.c:3016
+#: fortran/parse.c:3020
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as already a coarray subcomponent exists)"
 msgstr "Noncoarray 成分 %s 于 %L 的类型 LOCK_TYPE 或与 subcomponent 的类型 LOCK_TYPE 必须有 codimension 或是 subcomponent 的 coarray。(变量的类型 %s 可能无法有 codimension 作为已经 coarray subcomponent 存在)"
 
-#: fortran/parse.c:3023
+#: fortran/parse.c:3027
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as %s at %L has a codimension or a coarray subcomponent)"
 msgstr "Noncoarray 成分 %s 于 %L 的类型 LOCK_TYPE 或与 subcomponent 的类型 LOCK_TYPE 必须有 codimension 或是 subcomponent 的 coarray。(变量的类型 %s 可能无法有 codimension 作为 %s 于 %L 有 codimension 或 coarray subcomponent)"
 
-#: fortran/parse.c:3033
+#: fortran/parse.c:3037
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Component %s at %L of type EVENT_TYPE must have a codimension or be a subcomponent of a coarray, which is not possible as the component has the pointer attribute"
 msgstr "成分 %s 于 %L 的类型 LOCK_TYPE 必须有 codimension 或是 subcomponent 的 coarray，该项不是可能的作为成分有指标属性"
 
-#: fortran/parse.c:3039
+#: fortran/parse.c:3043
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Pointer component %s at %L has a noncoarray subcomponent of type EVENT_TYPE, which must have a codimension or be a subcomponent of a coarray"
 msgstr "指标成分 %s 于 %L 有 noncoarray subcomponent 的类型 LOCK_TYPE，该项必须有 codimension 或是 subcomponent 的 coarray"
 
-#: fortran/parse.c:3044
+#: fortran/parse.c:3048
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L of type EVENT_TYPE must have a codimension"
 msgstr "%C处可分配的组件必须有延迟的外形"
 
-#: fortran/parse.c:3048
+#: fortran/parse.c:3052
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocatable component %s at %L must have a codimension as it has a noncoarray subcomponent of type EVENT_TYPE"
 msgstr "Allocatable 成分 %s 于 %L 必须有 codimension 作为它有 noncoarray subcomponent 的类型 LOCK_TYPE"
 
-#: fortran/parse.c:3053
+#: fortran/parse.c:3057
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as already a coarray subcomponent exists)"
 msgstr "Noncoarray 成分 %s 于 %L 的类型 LOCK_TYPE 或与 subcomponent 的类型 LOCK_TYPE 必须有 codimension 或是 subcomponent 的 coarray。(变量的类型 %s 可能无法有 codimension 作为已经 coarray subcomponent 存在)"
 
-#: fortran/parse.c:3060
+#: fortran/parse.c:3064
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Noncoarray component %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must have a codimension or be a subcomponent of a coarray. (Variables of type %s may not have a codimension as %s at %L has a codimension or a coarray subcomponent)"
 msgstr "Noncoarray 成分 %s 于 %L 的类型 LOCK_TYPE 或与 subcomponent 的类型 LOCK_TYPE 必须有 codimension 或是 subcomponent 的 coarray。(变量的类型 %s 可能无法有 codimension 作为 %s 于 %L 有 codimension 或 coarray subcomponent)"
 
-#: fortran/parse.c:3112
+#: fortran/parse.c:3116
 #, gcc-internal-format, gfc-internal-format
 msgid "failed to create map component '%s'"
 msgstr ""
 
-#: fortran/parse.c:3145
+#: fortran/parse.c:3149
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "failed to find class '%s'"
 msgid "failed to create union component '%s'"
 msgstr "找不到类‘%s’"
 
-#: fortran/parse.c:3200
+#: fortran/parse.c:3204
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in data declaration at %C"
 msgid "Syntax error in nested structure declaration at %C"
 msgstr "%C处数据声明语法错误"
 
-#: fortran/parse.c:3287
+#: fortran/parse.c:3291
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL declaration at %C must be inside CONTAINS"
 msgstr "%C处的 FINAL 声明必须在 CONTAINS 内"
 
-#: fortran/parse.c:3295
+#: fortran/parse.c:3299
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Derived type definition at %C without components"
 msgstr "Fortran 2003：%C处的派生类型定义没有组件"
 
-#: fortran/parse.c:3311
+#: fortran/parse.c:3315
 #, gcc-internal-format, gfc-internal-format
 msgid "PRIVATE statement at %C must precede structure components"
 msgstr "%C处 PRIVATE 语句必须先于结构组件"
 
-#: fortran/parse.c:3328
+#: fortran/parse.c:3332
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE statement at %C must precede structure components"
 msgstr "%C处 SEQUENCE 语句必须先于结构组件"
 
-#: fortran/parse.c:3334
+#: fortran/parse.c:3338
 #, gcc-internal-format, gfc-internal-format
 msgid "SEQUENCE attribute at %C already specified in TYPE statement"
 msgstr "%C处 SEQUENCE 属性已经在 TYPE 语句中指定"
 
-#: fortran/parse.c:3339
+#: fortran/parse.c:3343
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate SEQUENCE statement at %C"
 msgstr "%C处重复的 SEQUENCE 语句"
 
-#: fortran/parse.c:3349
+#: fortran/parse.c:3353
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS block in derived type definition at %C"
 msgstr "%C处的 GENERIC 必须是在派生类型 CONTAINS 内"
 
-#: fortran/parse.c:3407
+#: fortran/parse.c:3411
 #, gcc-internal-format, gfc-internal-format
 msgid "ENUM declaration at %C has no ENUMERATORS"
 msgstr "%C处的 ENUM 声明没有 ENUMERATORS"
 
-#: fortran/parse.c:3494
+#: fortran/parse.c:3498
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in INTERFACE block at %C"
 msgstr "非预期的 %s 语句出现在%C处的 INTERFACE 块中"
 
-#: fortran/parse.c:3518
+#: fortran/parse.c:3522
 #, fuzzy, gcc-internal-format
 msgid "Name %qs of ABSTRACT INTERFACE at %C cannot be the same as an intrinsic type"
 msgstr "%2$C处的 ABSTRACT INTERFACE 的名字‘%1$s’不能与内建类型一样"
 
-#: fortran/parse.c:3552
+#: fortran/parse.c:3556
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement at %C in INTERFACE body"
 msgstr "非预期的 %s 语句出现在%C处的 INTERFACE 体中"
 
-#: fortran/parse.c:3570
+#: fortran/parse.c:3574
 #, fuzzy, gcc-internal-format
 msgid "INTERFACE procedure %qs at %L has the same name as the enclosing procedure"
 msgstr "%2$L处 INTERFACE 过程‘%1$s’有与外围过程相同的名字"
 
-#: fortran/parse.c:3700
+#: fortran/parse.c:3704
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement is not allowed inside of BLOCK at %C"
 msgstr "%s 语句不能用在%C处 BLOCK 内"
 
-#: fortran/parse.c:3732
+#: fortran/parse.c:3736
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement is not allowed inside of BLOCK DATA at %C"
 msgstr "%s 语句不能用在%C处 BLOCK 内"
 
-#: fortran/parse.c:3822
+#: fortran/parse.c:3826
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement must appear in a MODULE"
 msgstr "%s 语句必须出现在 MODULE 中"
 
-#: fortran/parse.c:3830
+#: fortran/parse.c:3834
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C follows another accessibility specification"
 msgstr "%2$C处 %1$s 语句出现在其他访问规格之后"
 
-#: fortran/parse.c:3882
+#: fortran/parse.c:3886
 #, fuzzy, gcc-internal-format
 msgid "Bad kind expression for function %qs at %L"
 msgstr "%2$L 处初始化表达式中的函数 ‘%1$qs’ 必须是一个内建函数"
 
-#: fortran/parse.c:3886
+#: fortran/parse.c:3890
 #, fuzzy, gcc-internal-format
 msgid "The type for function %qs at %L is not accessible"
 msgstr "%2$L处函数‘%1$s’的类型是不可访问的"
 
-#: fortran/parse.c:3946
+#: fortran/parse.c:3950
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSEWHERE statement at %C follows previous unmasked ELSEWHERE"
 msgstr "%C处的 ELSEWHERE 语句出现在未屏蔽的 ELSEWHERE 之后"
 
-#: fortran/parse.c:3968
+#: fortran/parse.c:3972
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in WHERE block at %C"
 msgstr "非预期的 %s 语句出现在%C处的 WHERE 块中"
 
-#: fortran/parse.c:4027
+#: fortran/parse.c:4031
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in FORALL block at %C"
 msgstr "非预期的 %s 语句出现在%C处的 FORALL 块中"
 
-#: fortran/parse.c:4078
+#: fortran/parse.c:4082
 #, gcc-internal-format, gfc-internal-format
 msgid "ELSE IF statement at %C cannot follow ELSE statement at %L"
 msgstr "%C处的 ELSE IF 语句不能出现在%L处的 ELSE 语句之后"
 
-#: fortran/parse.c:4096
+#: fortran/parse.c:4100
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ELSE statements at %L and %C"
 msgstr "%L 和%C处重复的 ELSE 语句"
 
-#: fortran/parse.c:4157
+#: fortran/parse.c:4161
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected a CASE or END SELECT statement following SELECT CASE at %C"
 msgstr "%C处 SELECT CASE 之后需要 CASE 或 END SELECT 语句"
 
-#: fortran/parse.c:4241
+#: fortran/parse.c:4245
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected TYPE IS, CLASS IS or END SELECT statement following SELECT TYPE at %C"
 msgstr "%C处的 SELECT TYPE 之后需要 TYPE IS、CLASS IS 或 END SELECT 语句"
 
-#: fortran/parse.c:4303
+#: fortran/parse.c:4307
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %C cannot be redefined inside loop beginning at %L"
 msgid "Variable %qs at %C cannot be redefined inside loop beginning at %L"
 msgstr "变量‘%s’(位于 %C)不能在从 %L 开始的循环的内部重定义"
 
-#: fortran/parse.c:4336
+#: fortran/parse.c:4340
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is within another block"
 msgstr "%C处结束的非块 DO 语句在另一个块当中"
 
-#: fortran/parse.c:4346
+#: fortran/parse.c:4350
 #, gcc-internal-format, gfc-internal-format
 msgid "End of nonblock DO statement at %C is interwoven with another DO loop"
 msgstr "%C处结束的非块 DO 语句与另一个 DO 循环交错"
 
-#: fortran/parse.c:4372
+#: fortran/parse.c:4376
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL block inside of OpenACC region at %C"
 msgstr "Fortran 2003：%C处的派生类型定义中的 CONTAINS 块"
 
-#: fortran/parse.c:4373
+#: fortran/parse.c:4377
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CRITICAL block inside of OpenMP region at %C"
 msgstr "Fortran 2003：%C处的派生类型定义中的 CONTAINS 块"
 
-#: fortran/parse.c:4399
+#: fortran/parse.c:4403
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Statement label in END CRITICAL at %C does not match CRITICAL label"
 msgstr "%C处 ENDDO 中的语句标号与 DO 标号不匹配"
 
-#: fortran/parse.c:4468
+#: fortran/parse.c:4472
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BLOCK construct at %C"
 msgstr "位置错误的%<@%D%>Objective-C++ 构造"
 
-#: fortran/parse.c:4502
+#: fortran/parse.c:4506
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASSOCIATE construct at %C"
 msgstr "位置错误的%<@%D%>Objective-C++ 构造"
 
-#: fortran/parse.c:4690
+#: fortran/parse.c:4694
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement label in ENDDO at %C doesn't match DO label"
 msgstr "%C处 ENDDO 中的语句标号与 DO 标号不匹配"
 
-#: fortran/parse.c:4706
+#: fortran/parse.c:4710
 #, gcc-internal-format, gfc-internal-format
 msgid "Named block DO at %L requires matching ENDDO name"
 msgstr "%L处有名的块 DO 需要匹配的 ENDDO 名"
 
-#: fortran/parse.c:4897
+#: fortran/parse.c:4901
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing !$OMP END ATOMIC after !$OMP ATOMIC CAPTURE at %C"
 msgstr "缺少!$OMP 结束基元的之后 !$OMP 基元的截取于 %C"
 
-#: fortran/parse.c:4913 fortran/parse.c:4972
+#: fortran/parse.c:4917 fortran/parse.c:4976
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "OpenACC directive inside of CRITICAL block at %C"
 msgstr "没有在%C处发现 COMMON 块 /%s/"
 
-#: fortran/parse.c:4947
+#: fortran/parse.c:4951
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expecting %s at %C"
 msgstr "%C处需要有名实体列表"
 
-#: fortran/parse.c:4991
+#: fortran/parse.c:4995
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected DO loop at %C"
 msgstr "DO 循环中的开始表达式"
 
-#: fortran/parse.c:5011
+#: fortran/parse.c:5015
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Redundant !$ACC END LOOP at %C"
 msgstr "%L有多余的 SOURCE 标记"
 
-#: fortran/parse.c:5225
+#: fortran/parse.c:5229
 #, gcc-internal-format, gfc-internal-format
 msgid "Name after !$omp critical and !$omp end critical does not match at %C"
 msgstr "%C处 !$omp critical 和 !$omp end critical 后的名字不匹配"
 
-#: fortran/parse.c:5283
+#: fortran/parse.c:5287
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement at %C cannot terminate a non-block DO loop"
 msgstr "%2$C处的 %1$s 语句不能终止一个不成块的 DO 循环"
 
-#: fortran/parse.c:5297
+#: fortran/parse.c:5301
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %C after the first executable statement"
 msgstr "%L处 FORMAT 语句没有语句标号"
 
-#: fortran/parse.c:5423
+#: fortran/parse.c:5427
 #, gcc-internal-format
 msgid "%<GCC unroll%> directive does not commence a loop at %C"
 msgstr ""
 
-#: fortran/parse.c:5538
+#: fortran/parse.c:5542
 #, fuzzy, gcc-internal-format
 msgid "Contained procedure %qs at %C is already ambiguous"
 msgstr "%2$C处包含的过程‘%1$s’已经有歧义"
 
-#: fortran/parse.c:5595
+#: fortran/parse.c:5599
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in CONTAINS section at %C"
 msgstr "非预期的 %s 语句出现在%C处的 CONTAINS 段中"
 
-#: fortran/parse.c:5620
+#: fortran/parse.c:5624
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS statement without FUNCTION or SUBROUTINE statement at %L"
 msgstr "Fortran 2008：%C处 CONTAINS 语句没有 FUNCTION 或 SUBROUTINE 语句"
 
-#: fortran/parse.c:5732
+#: fortran/parse.c:5736
 #, gcc-internal-format, gfc-internal-format
 msgid "CONTAINS statement at %C is already in a contained program unit"
 msgstr "%C处的 CONTAINS 语句已经在包含的程序单元中"
 
-#: fortran/parse.c:5784
+#: fortran/parse.c:5788
 #, fuzzy, gcc-internal-format
 msgid "Global binding name %qs at %L is already being used as a %s at %L"
 msgstr "%2$L处的名字‘%1$s’已经在%4$L处被用作 %3$s"
 
-#: fortran/parse.c:5788
+#: fortran/parse.c:5792
 #, fuzzy, gcc-internal-format
 #| msgid "Global name '%s' at %L is already being used as a %s at %L"
 msgid "Global name %qs at %L is already being used as a %s at %L"
 msgstr "%2$L处的名字‘%1$s’已经在%4$L处被用作 %3$s"
 
-#: fortran/parse.c:5794
+#: fortran/parse.c:5798
 #, fuzzy, gcc-internal-format
 msgid "Global binding name %qs at %L is already being used at %L"
 msgstr "%2$L处的名字‘%1$s’已经在%4$L处被用作 %3$s"
 
-#: fortran/parse.c:5797
+#: fortran/parse.c:5801
 #, fuzzy, gcc-internal-format
 #| msgid "Global name '%s' at %L is already being used as a %s at %L"
 msgid "Global name %qs at %L is already being used at %L"
 msgstr "%2$L处的名字‘%1$s’已经在%4$L处被用作 %3$s"
 
-#: fortran/parse.c:5819
+#: fortran/parse.c:5823
 #, gcc-internal-format, gfc-internal-format
 msgid "Blank BLOCK DATA at %C conflicts with prior BLOCK DATA at %L"
 msgstr "%C处空白 BLOCK DATA 与%L处先前的 BLOCK DATA 冲突"
 
-#: fortran/parse.c:5845
+#: fortran/parse.c:5849
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in BLOCK DATA at %C"
 msgstr "非预期的 %s 语句出现在%C处的 BLOCK DATA 块中"
 
-#: fortran/parse.c:5949
+#: fortran/parse.c:5953
 #, gcc-internal-format, gfc-internal-format
 msgid "Unexpected %s statement in MODULE at %C"
 msgstr "非预期的 %s 语句出现在%C处的 MODULE 中"
@@ -62120,7 +62202,7 @@
 #. If we see a duplicate main program, shut down.  If the second
 #. instance is an implied main program, i.e. data decls or executable
 #. statements, we're in for lots of errors.
-#: fortran/parse.c:6333
+#: fortran/parse.c:6337
 #, gcc-internal-format, gfc-internal-format
 msgid "Two main PROGRAMs at %L and %C"
 msgstr "%L 和%C处有两个主 PROGRAM"
@@ -62872,7 +62954,7 @@
 msgid "Non-RECURSIVE procedure %qs at %L is possibly calling itself recursively.  Declare it RECURSIVE or use %<-frecursive%>"
 msgstr "%2$L处非 RECURSIVE 过程‘%1$s’可能递归地调用它自己。请将它声明为 RECURSIVE 或使用 -frecursive"
 
-#: fortran/resolve.c:1893 fortran/resolve.c:9560 fortran/resolve.c:11225
+#: fortran/resolve.c:1893 fortran/resolve.c:9573 fortran/resolve.c:11245
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d referenced at %L is never defined"
 msgstr "标号 %d(引用自 %L)从未被定义"
@@ -62982,7 +63064,7 @@
 msgid "Function %qs at %L has no IMPLICIT type; did you mean %qs?"
 msgstr "%2$L处的函数‘%1$s’没有隐式类型"
 
-#: fortran/resolve.c:2905 fortran/resolve.c:16283
+#: fortran/resolve.c:2905 fortran/resolve.c:16310
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr "%2$L处的函数‘%1$s’没有隐式类型"
@@ -63104,197 +63186,197 @@
 msgid "logical_to_bitwise(): Bad intrinsic"
 msgstr "%L处内建运算符接口必须是一个 FUNCTION"
 
-#: fortran/resolve.c:4059
+#: fortran/resolve.c:4065
 #, fuzzy, gcc-internal-format
 msgid "resolve_operator(): Bad intrinsic"
 msgstr "%L处内建运算符接口必须是一个 FUNCTION"
 
-#: fortran/resolve.c:4229 fortran/resolve.c:4252
+#: fortran/resolve.c:4235 fortran/resolve.c:4258
 #, gcc-internal-format
 msgid "compare_bound_int(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:4347
+#: fortran/resolve.c:4353
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "%1$L处数组引用在第 %4$d 维中越界(%2$ld < %3$ld)"
 
-#: fortran/resolve.c:4352
+#: fortran/resolve.c:4358
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld < %ld) in codimension %d"
 msgstr "%1$L处数组引用在第 %4$d 维中越界(%2$ld < %3$ld)"
 
-#: fortran/resolve.c:4362
+#: fortran/resolve.c:4368
 #, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "%1$L处数组引用在第 %4$d 维中越界(%2$ld > %3$ld)"
 
-#: fortran/resolve.c:4367
+#: fortran/resolve.c:4373
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Array reference at %L is out of bounds (%ld > %ld) in codimension %d"
 msgstr "%1$L处数组引用在第 %4$d 维中越界(%2$ld < %3$ld)"
 
-#: fortran/resolve.c:4387
+#: fortran/resolve.c:4393
 #, gcc-internal-format, gfc-internal-format
 msgid "Illegal stride of zero at %L"
 msgstr "%L 零间隔非法"
 
-#: fortran/resolve.c:4404
+#: fortran/resolve.c:4410
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "%1$L处数组下限引用在第 %4$d 维中越界(%2$ld < %3$ld)"
 
-#: fortran/resolve.c:4412
+#: fortran/resolve.c:4418
 #, gcc-internal-format, gfc-internal-format
 msgid "Lower array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "%1$L处数组下限引用在第 %4$d 维中越界(%2$ld > %3$ld)"
 
-#: fortran/resolve.c:4428
+#: fortran/resolve.c:4434
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld < %ld) in dimension %d"
 msgstr "%1$L处数组上限引用在第 %4$d 维中越界(%2$ld < %3$ld)"
 
-#: fortran/resolve.c:4437
+#: fortran/resolve.c:4443
 #, gcc-internal-format, gfc-internal-format
 msgid "Upper array reference at %L is out of bounds (%ld > %ld) in dimension %d"
 msgstr "%1$L处数组上限引用在第 %4$d 维中越界(%2$ld > %3$ld)"
 
-#: fortran/resolve.c:4453
+#: fortran/resolve.c:4459
 #, fuzzy, gcc-internal-format
 msgid "check_dimension(): Bad array reference"
 msgstr "%L处数组引用错误"
 
-#: fortran/resolve.c:4476
+#: fortran/resolve.c:4482
 #, gcc-internal-format, gfc-internal-format
 msgid "Rightmost upper bound of assumed size array section not specified at %L"
 msgstr "%L处未指定假定大小数组段的最右端上限"
 
-#: fortran/resolve.c:4486
+#: fortran/resolve.c:4492
 #, gcc-internal-format, gfc-internal-format
 msgid "Rank mismatch in array reference at %L (%d/%d)"
 msgstr "%L处数组引用中秩不匹配(%d/%d)"
 
-#: fortran/resolve.c:4494
+#: fortran/resolve.c:4500
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindex rank mismatch in array reference at %L (%d/%d)"
 msgstr "%L处数组引用中秩不匹配(%d/%d)"
 
-#: fortran/resolve.c:4510
+#: fortran/resolve.c:4516
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindex of codimension %d must be a scalar at %L"
 msgstr "%3$L处内建函数‘%2$s’的实参‘%1$s’必须是一个标量"
 
-#: fortran/resolve.c:4538
+#: fortran/resolve.c:4544
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be scalar"
 msgstr "%L处数组索引必须是标量"
 
-#: fortran/resolve.c:4544
+#: fortran/resolve.c:4550
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L must be of INTEGER type, found %s"
 msgstr "%L处数组索引必须具有 INTEGER 类型而不是 %s"
 
-#: fortran/resolve.c:4550
+#: fortran/resolve.c:4556
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "REAL array index at %L"
 msgstr "%L处数组索引是一个秩为 %d 的数组"
 
-#: fortran/resolve.c:4589
+#: fortran/resolve.c:4595
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be scalar"
 msgstr "%L 实参维数必须是标量"
 
-#: fortran/resolve.c:4596
+#: fortran/resolve.c:4602
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument dim at %L must be of INTEGER type"
 msgstr "%L处实参维数必须具有 INTEGER 类型"
 
-#: fortran/resolve.c:4641
+#: fortran/resolve.c:4647
 #, fuzzy, gcc-internal-format
 msgid "find_array_spec(): Missing spec"
 msgstr "%C处 Cray 指针重复指定了数组"
 
-#: fortran/resolve.c:4652
+#: fortran/resolve.c:4658
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(1)"
 msgstr ""
 
-#: fortran/resolve.c:4663
+#: fortran/resolve.c:4669
 #, gcc-internal-format
 msgid "find_array_spec(): unused as(2)"
 msgstr ""
 
-#: fortran/resolve.c:4706
+#: fortran/resolve.c:4712
 #, gcc-internal-format, gfc-internal-format
 msgid "Array index at %L is an array of rank %d"
 msgstr "%L处数组索引是一个秩为 %d 的数组"
 
-#: fortran/resolve.c:4804
+#: fortran/resolve.c:4810
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be of type INTEGER"
 msgstr "%L处的子字符串起始索引类型必须为 INTEGER"
 
-#: fortran/resolve.c:4811
+#: fortran/resolve.c:4817
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L must be scalar"
 msgstr "%L处的子字符串起始索引必须是标量"
 
-#: fortran/resolve.c:4820
+#: fortran/resolve.c:4826
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring start index at %L is less than one"
 msgstr "%L处的子字符串起始索引小于 1"
 
-#: fortran/resolve.c:4833
+#: fortran/resolve.c:4839
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be of type INTEGER"
 msgstr "%L处的子字符串终止索引类型必须为 INTEGER"
 
-#: fortran/resolve.c:4840
+#: fortran/resolve.c:4846
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L must be scalar"
 msgstr "%L处的子字符串终止索引必须是标量"
 
-#: fortran/resolve.c:4850
+#: fortran/resolve.c:4856
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L exceeds the string length"
 msgstr "%L处的子字符串终止索引超过了字符串长度"
 
-#: fortran/resolve.c:4860
+#: fortran/resolve.c:4866
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring end index at %L is too large"
 msgstr "%L处子串结束索引太大"
 
-#: fortran/resolve.c:5013
+#: fortran/resolve.c:5019
 #, fuzzy, gcc-internal-format
 msgid "resolve_ref(): Bad array reference"
 msgstr "%L处数组引用错误"
 
-#: fortran/resolve.c:5027
+#: fortran/resolve.c:5033
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the POINTER attribute at %L"
 msgstr "%L处对有非零秩的部分引用的右侧的组件不能有 POINTER 属性"
 
-#: fortran/resolve.c:5037
+#: fortran/resolve.c:5043
 #, gcc-internal-format, gfc-internal-format
 msgid "Component to the right of a part reference with nonzero rank must not have the ALLOCATABLE attribute at %L"
 msgstr "%L处对有非零秩的部分引用的右侧的组件不能有 ALLOCATABLE 属性"
 
-#: fortran/resolve.c:5056
+#: fortran/resolve.c:5062
 #, gcc-internal-format, gfc-internal-format
 msgid "Two or more part references with nonzero rank must not be specified at %L"
 msgstr "%L处不能指定两个或以上秩不为零的部分引用"
 
-#: fortran/resolve.c:5154
+#: fortran/resolve.c:5160
 #, gcc-internal-format
 msgid "expression_rank(): Two array specs"
 msgstr ""
 
-#: fortran/resolve.c:5236
+#: fortran/resolve.c:5242
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may only be used as actual argument"
 msgstr "假定外形的数组在 %L 处必须是哑参数"
 
-#: fortran/resolve.c:5246
+#: fortran/resolve.c:5252
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may only be used as actual argument"
 msgstr "%L处假定外形的数组必须是一个虚参"
@@ -63303,12 +63385,12 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5256
+#: fortran/resolve.c:5262
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5271
+#: fortran/resolve.c:5277
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L may only be used as actual argument"
 msgstr "%L处假定外形的数组必须是一个虚参"
@@ -63317,269 +63399,269 @@
 #. for all inquiry functions in resolve_function; the reason is
 #. that the function-name resolution happens too late in that
 #. function.
-#: fortran/resolve.c:5281
+#: fortran/resolve.c:5287
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L as actual argument to an inquiry function shall be the first argument"
 msgstr ""
 
-#: fortran/resolve.c:5292
+#: fortran/resolve.c:5298
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall not have a subobject reference"
 msgstr "“%s”是必须是一个模块过程或有显式接口的外部过程于 %L 处"
 
-#: fortran/resolve.c:5301
+#: fortran/resolve.c:5307
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not have a subobject reference"
 msgstr "数组‘%s’在%L处不能有延迟的外形"
 
-#: fortran/resolve.c:5316
+#: fortran/resolve.c:5322
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank variable %s at %L shall not have a subobject reference"
 msgstr "数组‘%s’在%L处不能有延迟的外形"
 
-#: fortran/resolve.c:5478
+#: fortran/resolve.c:5484
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs, used in a specification expression, is referenced at %L before the ENTRY statement in which it is a parameter"
 msgstr "用在一个规格说明表达式中的变量‘%s’在%L处的引用出现在该变量是其参数的 ENTRY 语句之前"
 
-#: fortran/resolve.c:5483
+#: fortran/resolve.c:5489
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs is used at %L before the ENTRY statement in which it is a parameter"
 msgstr "变量‘%s’在%L处的使用出现在该变量是其参数的 ENTRY 语句之前"
 
-#: fortran/resolve.c:5553
+#: fortran/resolve.c:5559
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic subobject of coindexed object at %L"
 msgstr "%2$L处非多态的传递对象哑元实参‘%1$s’"
 
-#: fortran/resolve.c:5566
+#: fortran/resolve.c:5572
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed object with polymorphic allocatable subcomponent at %L"
 msgstr "Coindexed 对象与 polymorphic allocatable subcomponent 于 %L"
 
-#: fortran/resolve.c:5919
+#: fortran/resolve.c:5925
 #, gcc-internal-format, gfc-internal-format
 msgid "Passed-object at %L must be scalar"
 msgstr "%L处传递的对象必须是标量"
 
-#: fortran/resolve.c:5926
+#: fortran/resolve.c:5932
 #, fuzzy, gcc-internal-format
 msgid "Base object for procedure-pointer component call at %L is of ABSTRACT type %qs"
 msgstr "%L处类型限定过程调用的基类型是 ABSTRACT 类型‘%s’"
 
-#: fortran/resolve.c:5961
+#: fortran/resolve.c:5967
 #, fuzzy, gcc-internal-format
 msgid "Base object for type-bound procedure call at %L is of ABSTRACT type %qs"
 msgstr "%L处 NOPASS 类型限定过程调用的基对象必须是标量"
 
-#: fortran/resolve.c:5970
+#: fortran/resolve.c:5976
 #, gcc-internal-format, gfc-internal-format
 msgid "Base object for NOPASS type-bound procedure call at %L must be scalar"
 msgstr "%L处 NOPASS 类型限定过程调用的基对象必须是标量"
 
 #. Nothing matching found!
-#: fortran/resolve.c:6158
+#: fortran/resolve.c:6164
 #, fuzzy, gcc-internal-format
 msgid "Found no matching specific binding for the call to the GENERIC %qs at %L"
 msgstr "%2$L处对 GENERIC‘%1$s’的调用没有找到匹配特别的限定"
 
-#: fortran/resolve.c:6185
+#: fortran/resolve.c:6191
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L should be a SUBROUTINE"
 msgstr "%L处的运算符接口必须是一个 SUBROUTINE"
 
-#: fortran/resolve.c:6236
+#: fortran/resolve.c:6242
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L should be a FUNCTION"
 msgstr "在函数%qs中"
 
-#: fortran/resolve.c:6786
+#: fortran/resolve.c:6792
 #, fuzzy, gcc-internal-format
 msgid "gfc_resolve_expr(): Bad expression type"
 msgstr "需要表达式类型"
 
-#: fortran/resolve.c:6812
+#: fortran/resolve.c:6818
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be a scalar"
 msgstr "%s (%L处)必须是一个标量"
 
-#: fortran/resolve.c:6822
+#: fortran/resolve.c:6828
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be integer"
 msgstr "%s (%L处)必须是 INTEGER"
 
-#: fortran/resolve.c:6826 fortran/resolve.c:6833
+#: fortran/resolve.c:6832 fortran/resolve.c:6839
 #, gcc-internal-format, gfc-internal-format
 msgid "%s at %L must be INTEGER"
 msgstr "%s (%L处)必须是 INTEGER"
 
-#: fortran/resolve.c:6875
+#: fortran/resolve.c:6881
 #, gcc-internal-format, gfc-internal-format
 msgid "Step expression in DO loop at %L cannot be zero"
 msgstr "%L处的 DO 循环中的步进表达式不能为零"
 
-#: fortran/resolve.c:6911
+#: fortran/resolve.c:6917
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L will be executed zero times"
 msgstr "%L处的 DO 循环中的步进表达式不能为零"
 
-#: fortran/resolve.c:6928
+#: fortran/resolve.c:6934
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it overflows"
 msgstr ""
 
-#: fortran/resolve.c:6934
+#: fortran/resolve.c:6940
 #, gcc-internal-format, gfc-internal-format
 msgid "DO loop at %L is undefined as it underflows"
 msgstr ""
 
-#: fortran/resolve.c:6995
+#: fortran/resolve.c:7001
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgstr "%L处 FORALL 索引名必须是一个标量整数"
 
-#: fortran/resolve.c:7000
+#: fortran/resolve.c:7006
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL start expression at %L must be a scalar INTEGER"
 msgstr "%L处 FORALL 起始表达式必须是一个标量整数"
 
-#: fortran/resolve.c:7007
+#: fortran/resolve.c:7013
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL end expression at %L must be a scalar INTEGER"
 msgstr "%L处 FORALL 结束表达式必须是一个标量整数"
 
-#: fortran/resolve.c:7015
+#: fortran/resolve.c:7021
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L must be a scalar %s"
 msgstr "%L处 FORALL 间隔表达式必须是一个标量 %s"
 
-#: fortran/resolve.c:7020
+#: fortran/resolve.c:7026
 #, gcc-internal-format, gfc-internal-format
 msgid "FORALL stride expression at %L cannot be zero"
 msgstr "%L处 FORALL 间隔表达式不能是零"
 
-#: fortran/resolve.c:7033
+#: fortran/resolve.c:7039
 #, fuzzy, gcc-internal-format
 msgid "FORALL index %qs may not appear in triplet specification at %L"
 msgstr "FORALL 索引‘%s’不能出现在%L处的三元组规格说明中"
 
-#: fortran/resolve.c:7136 fortran/resolve.c:7428
+#: fortran/resolve.c:7142 fortran/resolve.c:7434
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L must be ALLOCATABLE or a POINTER"
 msgstr "%L处的分配对象必须是 ALLOCATABLE 或 POINTER"
 
-#: fortran/resolve.c:7144 fortran/resolve.c:7393
+#: fortran/resolve.c:7150 fortran/resolve.c:7399
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed allocatable object at %L"
 msgstr "%L处的分配对象必须是 ALLOCATABLE 或 POINTER"
 
-#: fortran/resolve.c:7250
+#: fortran/resolve.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L must be scalar or have the same rank as the allocate-object at %L"
 msgstr "%L处的源表达式必须是标量或者与%L处的分配对象有相同的秩"
 
-#: fortran/resolve.c:7281
+#: fortran/resolve.c:7287
 #, gcc-internal-format, gfc-internal-format
 msgid "Source-expr at %L and allocate-object at %L must have the same shape"
 msgstr "%L处的源表达式和%L处的分配对象必须有相同的外形"
 
-#: fortran/resolve.c:7439
+#: fortran/resolve.c:7445
 #, gcc-internal-format, gfc-internal-format
 msgid "Type of entity at %L is type incompatible with source-expr at %L"
 msgstr "%L处实体的类型与%L处的源表达式类型不兼容"
 
-#: fortran/resolve.c:7451
+#: fortran/resolve.c:7457
 #, gcc-internal-format, gfc-internal-format
 msgid "The allocate-object at %L and the source-expr at %L shall have the same kind type parameter"
 msgstr "%L处的分配对象和%L处的源表达式应该有相同的种别类型参数"
 
-#: fortran/resolve.c:7465
+#: fortran/resolve.c:7471
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type LOCK_TYPE nor have a LOCK_TYPE component if allocate-object at %L is a coarray"
 msgstr "source-expr 于 %L 应该 neither 是的类型 LOCK_TYPE nor 有 LOCK_TYPE 成分如果 allocate-object 于 %L 是 coarray"
 
-#: fortran/resolve.c:7480
+#: fortran/resolve.c:7486
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The source-expr at %L shall neither be of type EVENT_TYPE nor have a EVENT_TYPE component if allocate-object at %L is a coarray"
 msgstr "source-expr 于 %L 应该 neither 是的类型 LOCK_TYPE nor 有 LOCK_TYPE 成分如果 allocate-object 于 %L 是 coarray"
 
-#: fortran/resolve.c:7493
+#: fortran/resolve.c:7499
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s of ABSTRACT base type at %L requires a type-spec or source-expr"
 msgstr "%2$L处分配具有 ABSTRACT 基类型的 %1$s 需要一个类型指定或 SOURCE="
 
-#: fortran/resolve.c:7511
+#: fortran/resolve.c:7517
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocating %s at %L with type-spec requires the same character-length parameter as in the declaration"
 msgstr "配置 %s 于 %L 与 type-spec 需求相同 character-length 参数作为在中声明"
 
-#: fortran/resolve.c:7592 fortran/resolve.c:7607
+#: fortran/resolve.c:7598 fortran/resolve.c:7613
 #, gcc-internal-format, gfc-internal-format
 msgid "Array specification required in ALLOCATE statement at %L"
 msgstr "%L处的 ALLOCATE 语句中需要数组规格说明"
 
-#: fortran/resolve.c:7599
+#: fortran/resolve.c:7605
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Array specification required in ALLOCATE statement at %L"
 msgid "Array specification or array-valued SOURCE= expression required in ALLOCATE statement at %L"
 msgstr "%L处的 ALLOCATE 语句中需要数组规格说明"
 
-#: fortran/resolve.c:7622
+#: fortran/resolve.c:7628
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coarray specification required in ALLOCATE statement at %L"
 msgstr "%L处的 ALLOCATE 语句中需要数组规格说明"
 
-#: fortran/resolve.c:7649
+#: fortran/resolve.c:7655
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad array specification in ALLOCATE statement at %L"
 msgstr "%L处的 ALLOCATE 语句中有错误的数组规格"
 
-#: fortran/resolve.c:7668
+#: fortran/resolve.c:7674
 #, fuzzy, gcc-internal-format
 msgid "%qs must not appear in the array specification at %L in the same ALLOCATE statement where it is itself allocated"
 msgstr "‘%s’不能出现在%L处其自身被分配的 ALLOCATE 语句的数组规格说明中"
 
-#: fortran/resolve.c:7683
+#: fortran/resolve.c:7689
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected '*' in coindex specification in ALLOCATE statement at %L"
 msgstr "%L处的 ALLOCATE 语句中需要数组规格说明"
 
-#: fortran/resolve.c:7694
+#: fortran/resolve.c:7700
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad coarray specification in ALLOCATE statement at %L"
 msgstr "%L处的 ALLOCATE 语句中有错误的数组规格"
 
-#: fortran/resolve.c:7726
+#: fortran/resolve.c:7732
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L must be a scalar INTEGER variable"
 msgstr "%L处 stat 变量必须是一个标量 INTEGER 变量"
 
-#: fortran/resolve.c:7749
+#: fortran/resolve.c:7755
 #, gcc-internal-format, gfc-internal-format
 msgid "Stat-variable at %L shall not be %sd within the same %s statement"
 msgstr "%1$L处的统计变量不能在同一个 %3$s 语句中被 %2$s"
 
-#: fortran/resolve.c:7760
+#: fortran/resolve.c:7766
 #, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG at %L is useless without a STAT tag"
 msgstr "%L处的 ERRMSG 没有 STAT 标记所以不起作用"
 
-#: fortran/resolve.c:7771
-#, gcc-internal-format, gfc-internal-format
-msgid "Errmsg-variable at %L must be a scalar CHARACTER variable"
+#: fortran/resolve.c:7782
+#, fuzzy, gcc-internal-format, gfc-internal-format
+msgid "ERRMSG variable at %L shall be a scalar default CHARACTER variable"
 msgstr "%L处错误信息变量必须是一个标量 CHARACTER 变量"
 
-#: fortran/resolve.c:7794
+#: fortran/resolve.c:7805
 #, gcc-internal-format, gfc-internal-format
 msgid "Errmsg-variable at %L shall not be %sd within the same %s statement"
 msgstr "%1$L处的错误信息变量不能在同一 %3$s 语句中被 %2$s"
 
-#: fortran/resolve.c:7824
+#: fortran/resolve.c:7835
 #, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L also appears at %L"
 msgstr "%L处分配的对象也出现在%L处"
 
-#: fortran/resolve.c:7830 fortran/resolve.c:7836
+#: fortran/resolve.c:7841 fortran/resolve.c:7847
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Allocate-object at %L is subobject of object at %L"
 msgstr "%L处的分配对象必须是 ALLOCATABLE 或 POINTER"
@@ -63588,233 +63670,233 @@
 #. element in the list.  Either way, we must
 #. issue an error and get the next case from P.
 #. FIXME: Sort P and Q by line number.
-#: fortran/resolve.c:8064
+#: fortran/resolve.c:8075
 #, gcc-internal-format, gfc-internal-format
 msgid "CASE label at %L overlaps with CASE label at %L"
 msgstr "%L处的 CASE 标号与%L处的 CASE 标号重叠"
 
-#: fortran/resolve.c:8115
+#: fortran/resolve.c:8126
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of type %s"
 msgstr "%L处 CASE 语句中的表达式必须具有 %s 类型"
 
-#: fortran/resolve.c:8126
+#: fortran/resolve.c:8137
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be of kind %d"
 msgstr "%L 处 CASE 语句中的表达式种别必须为 %d"
 
-#: fortran/resolve.c:8139
+#: fortran/resolve.c:8150
 #, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L must be scalar"
 msgstr "%L处 CASE 语句中的表达式必须为标量"
 
-#: fortran/resolve.c:8185
+#: fortran/resolve.c:8196
 #, gcc-internal-format, gfc-internal-format
 msgid "Selection expression in computed GOTO statement at %L must be a scalar integer expression"
 msgstr "%L处计算转移 GOTO 语句的选择表达式必须是一个标量整数表达式"
 
-#: fortran/resolve.c:8204
+#: fortran/resolve.c:8215
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L cannot be %s"
 msgstr "%L处 SELECT 语句的实参不能是 %s"
 
-#: fortran/resolve.c:8214
+#: fortran/resolve.c:8225
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgstr "%L处 SELECT 语句中的实参必须为标量"
 
-#: fortran/resolve.c:8232 fortran/resolve.c:8240
+#: fortran/resolve.c:8243 fortran/resolve.c:8251
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expression in CASE statement at %L is not in the range of %s"
 msgstr "%L处 CASE 语句中的表达式必须具有 %s 类型"
 
-#: fortran/resolve.c:8302 fortran/resolve.c:8873
+#: fortran/resolve.c:8313 fortran/resolve.c:8884
 #, gcc-internal-format, gfc-internal-format
 msgid "The DEFAULT CASE at %L cannot be followed by a second DEFAULT CASE at %L"
 msgstr "%L处的 DEFAULT CASE 为%L处的第二个 DEFAULT CASE 所跟随"
 
-#: fortran/resolve.c:8328
+#: fortran/resolve.c:8339
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical range in CASE statement at %L is not allowed"
 msgstr "%L处 CASE 语句中的逻辑范围是不被允许的"
 
-#: fortran/resolve.c:8340
+#: fortran/resolve.c:8351
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Constant logical value in CASE statement is repeated at %L"
 msgstr "%L 处 CASE 语句中的常量逻辑值被重复了"
 
-#: fortran/resolve.c:8355
+#: fortran/resolve.c:8366
 #, gcc-internal-format, gfc-internal-format
 msgid "Range specification at %L can never be matched"
 msgstr "%L处范围规格无法匹配"
 
-#: fortran/resolve.c:8458
+#: fortran/resolve.c:8469
 #, gcc-internal-format, gfc-internal-format
 msgid "Logical SELECT CASE block at %L has more that two cases"
 msgstr "%L处逻辑 SELECT CASE 块有多于两个的情况"
 
-#: fortran/resolve.c:8518
+#: fortran/resolve.c:8529
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L cannot be NULL()"
 msgstr "选择子必须是立即数"
 
-#: fortran/resolve.c:8523
+#: fortran/resolve.c:8534
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L has no type"
 msgstr "选择子必须是立即数"
 
-#: fortran/resolve.c:8545
+#: fortran/resolve.c:8556
 #, fuzzy, gcc-internal-format
 msgid "Associate-name %qs at %L is used as array"
 msgstr "%2$L 处的名字“%1$s”已经在 %4$L 处被用作 %3$s"
 
-#: fortran/resolve.c:8556
+#: fortran/resolve.c:8567
 #, gcc-internal-format, gfc-internal-format
 msgid "CLASS selector at %L needs a temporary which is not yet implemented"
 msgstr ""
 
-#: fortran/resolve.c:8763
+#: fortran/resolve.c:8774
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector shall be polymorphic in SELECT TYPE statement at %L"
 msgstr "%C处 SELECT TYPE 语句中的选择子应该是多态的"
 
-#: fortran/resolve.c:8783 fortran/resolve.c:8795
+#: fortran/resolve.c:8794 fortran/resolve.c:8806
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Selector at %L must not be coindexed"
 msgstr "选择子必须是立即数"
 
-#: fortran/resolve.c:8824
+#: fortran/resolve.c:8835
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CASE label at %L overlaps with CASE label at %L"
 msgid "TYPE IS at %L overlaps with TYPE IS at %L"
 msgstr "%L处的 CASE 标号与%L处的 CASE 标号重叠"
 
-#: fortran/resolve.c:8836
+#: fortran/resolve.c:8847
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L must be extensible"
 msgstr "%2$L处派生类型‘%1$s’必须是可扩展的"
 
-#: fortran/resolve.c:8848
+#: fortran/resolve.c:8859
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L must be an extension of %qs"
 msgstr "%2$L处派生类型‘%1$s’必须是‘%3$s’的一个扩展"
 
-#: fortran/resolve.c:8851
+#: fortran/resolve.c:8862
 #, fuzzy, gcc-internal-format
 msgid "Unexpected intrinsic type %qs at %L"
 msgstr "对子进程名‘%s’非预期的使用，在%C处"
 
-#: fortran/resolve.c:8861
+#: fortran/resolve.c:8872
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The type-spec at %L shall specify that each length type parameter is assumed"
 msgstr "数组‘%s’在%L处不能有延迟的外形"
 
-#: fortran/resolve.c:9108
+#: fortran/resolve.c:9119
 #, gcc-internal-format, gfc-internal-format
 msgid "Double CLASS IS block in SELECT TYPE statement at %L"
 msgstr "%L处 SELECT TYPE 语句中有双重的 CLASS IS 块"
 
-#: fortran/resolve.c:9204
+#: fortran/resolve.c:9215
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid context for NULL () intrinsic at %L"
 msgstr "%%L处 NULL() 指针上下文无效"
 
-#: fortran/resolve.c:9257
+#: fortran/resolve.c:9268
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DTIO %s procedure at %L must be recursive"
 msgstr "%L处的表达式必须具有标量类型"
 
-#: fortran/resolve.c:9267
+#: fortran/resolve.c:9278
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be polymorphic unless it is processed by a defined input/output procedure"
 msgstr "数据转移组件于 %L 无法 polymorphic 除非它被处理由定义的输入/输出进程"
 
-#: fortran/resolve.c:9280
+#: fortran/resolve.c:9291
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have POINTER components unless it is processed by a defined input/output procedure"
 msgstr "%L处数据传输元素不能有 POINTER 组件"
 
-#: fortran/resolve.c:9289
+#: fortran/resolve.c:9300
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have procedure pointer components"
 msgstr "%L处数据传输元素不能有 PRIVATE 组件"
 
-#: fortran/resolve.c:9296
+#: fortran/resolve.c:9307
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have ALLOCATABLE components unless it is processed by a defined input/output procedure"
 msgstr "%L处数据传输元素不能有 ALLOCATABLE 组件"
 
-#: fortran/resolve.c:9307
+#: fortran/resolve.c:9318
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components"
 msgstr "%L处数据传输元素不能有 PRIVATE 组件"
 
-#: fortran/resolve.c:9313
+#: fortran/resolve.c:9324
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot have PRIVATE components unless it is processed by a defined input/output procedure"
 msgstr "%L处数据传输元素不能有 POINTER 组件"
 
-#: fortran/resolve.c:9328
+#: fortran/resolve.c:9339
 #, gcc-internal-format, gfc-internal-format
 msgid "Data transfer element at %L cannot be a full reference to an assumed-size array"
 msgstr "%L处数据传输元素不能是对一个假定大小数组的全引用"
 
-#: fortran/resolve.c:9388
+#: fortran/resolve.c:9399
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Lock variable at %L must be a scalar of type LOCK_TYPE"
 msgstr "%L处 !$OMP ATOMIC 语句必须设定一个内建类型的标量值"
 
-#: fortran/resolve.c:9398
+#: fortran/resolve.c:9409
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable at %L must be a scalar of type EVENT_TYPE"
 msgstr "%L处 !$OMP ATOMIC 语句必须设定一个内建类型的标量值"
 
-#: fortran/resolve.c:9402
+#: fortran/resolve.c:9413
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray or coindexed"
 msgstr "‘%s’的实参在%L处必须是一个指针"
 
-#: fortran/resolve.c:9405
+#: fortran/resolve.c:9416
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Event variable argument at %L must be a coarray but not coindexed"
 msgstr "‘%s’的实参在%L处必须是一个指针"
 
-#: fortran/resolve.c:9412 fortran/resolve.c:9533
+#: fortran/resolve.c:9423 fortran/resolve.c:9545
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "STAT= argument at %L must be a scalar INTEGER variable"
 msgstr "%L处 stat 变量必须是一个标量 INTEGER 变量"
 
-#: fortran/resolve.c:9424 fortran/resolve.c:9540
+#: fortran/resolve.c:9435 fortran/resolve.c:9553
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERRMSG= argument at %L must be a scalar CHARACTER variable"
 msgstr "%L处错误信息变量必须是一个标量 CHARACTER 变量"
 
-#: fortran/resolve.c:9436
+#: fortran/resolve.c:9447
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ACQUIRED_LOCK= argument at %L must be a scalar LOGICAL variable"
 msgstr "%L处 stat 变量必须是一个标量 INTEGER 变量"
 
-#: fortran/resolve.c:9449
+#: fortran/resolve.c:9460
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNTIL_COUNT= argument at %L must be a scalar INTEGER expression"
 msgstr "%L处 SELECT 语句中的实参必须为标量"
 
-#: fortran/resolve.c:9510
+#: fortran/resolve.c:9521
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must be a scalar or rank-1 INTEGER expression"
 msgstr "%L处 SELECT 语句中的实参必须为标量"
 
-#: fortran/resolve.c:9514 fortran/resolve.c:9524
+#: fortran/resolve.c:9525 fortran/resolve.c:9535
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Imageset argument at %L must between 1 and num_images()"
 msgstr "%L处 ACOS 的参数必须在 -1 和 1 之间"
 
-#: fortran/resolve.c:9567
+#: fortran/resolve.c:9580
 #, gcc-internal-format, gfc-internal-format
 msgid "Statement at %L is not a valid branch target statement for the branch statement at %L"
 msgstr "%L处的语句对%L处的分支语句而言不是一个有效的分支目标语句"
 
-#: fortran/resolve.c:9577
+#: fortran/resolve.c:9590
 #, gcc-internal-format, gfc-internal-format
 msgid "Branch at %L may result in an infinite loop"
 msgstr "%L处的分支可能导致无穷循环"
@@ -63821,12 +63903,12 @@
 
 #. Note: A label at END CRITICAL does not leave the CRITICAL
 #. construct as END CRITICAL is still part of it.
-#: fortran/resolve.c:9594 fortran/resolve.c:9617
+#: fortran/resolve.c:9607 fortran/resolve.c:9630
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves CRITICAL construct for label at %L"
 msgstr "前往叙述于 %L 树叶重要建构用于标贴于 %L"
 
-#: fortran/resolve.c:9598 fortran/resolve.c:9623
+#: fortran/resolve.c:9611 fortran/resolve.c:9636
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "GOTO statement at %L leaves DO CONCURRENT construct for label at %L"
 msgstr "%s 语句在%C处离开 OpenMP 结构块"
@@ -63834,109 +63916,109 @@
 #. The label is not in an enclosing block, so illegal.  This was
 #. allowed in Fortran 66, so we allow it as extension.  No
 #. further checks are necessary in this case.
-#: fortran/resolve.c:9638
+#: fortran/resolve.c:9651
 #, gcc-internal-format, gfc-internal-format
 msgid "Label at %L is not in the same block as the GOTO statement at %L"
 msgstr "%L处的标号与%L处 GOTO 语句不在相同的块中"
 
-#: fortran/resolve.c:9710
+#: fortran/resolve.c:9723
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE mask at %L has inconsistent shape"
 msgstr "%L处的 WHERE 掩码外形不一致"
 
-#: fortran/resolve.c:9726
+#: fortran/resolve.c:9739
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE assignment target at %L has inconsistent shape"
 msgstr "%L处 WHERE 赋值目标外形不一致"
 
-#: fortran/resolve.c:9734 fortran/resolve.c:9821
+#: fortran/resolve.c:9747 fortran/resolve.c:9834
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-ELEMENTAL user-defined assignment in WHERE at %L"
 msgstr "%L处 WHERE 中用户定义的非 ELEMENTAL 用户赋值"
 
-#: fortran/resolve.c:9744 fortran/resolve.c:9831
+#: fortran/resolve.c:9757 fortran/resolve.c:9844
 #, gcc-internal-format, gfc-internal-format
 msgid "Unsupported statement inside WHERE at %L"
 msgstr "%L处在 WHERE 内不支持的语句"
 
-#: fortran/resolve.c:9775
+#: fortran/resolve.c:9788
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to a FORALL index variable at %L"
 msgstr "%L处向 FORALL 索引变量赋值"
 
-#: fortran/resolve.c:9784
+#: fortran/resolve.c:9797
 #, fuzzy, gcc-internal-format
 msgid "The FORALL with index %qs is not used on the left side of the assignment at %L and so might cause multiple assignment to this object"
 msgstr "%2$L处带索引‘%1$s’的 FORALL 没有被用在赋值的左侧，所以可能导致对这个对象的多个赋值"
 
-#: fortran/resolve.c:9949
+#: fortran/resolve.c:9962
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORALL index-name at %L must be a scalar INTEGER"
 msgid "FORALL index-name at %L must be a scalar variable of type integer"
 msgstr "%L处 FORALL 索引名必须是一个标量整数"
 
-#: fortran/resolve.c:9959
+#: fortran/resolve.c:9972
 #, gcc-internal-format, gfc-internal-format
 msgid "An outer FORALL construct already has an index with this name %L"
 msgstr "%L处外部 FORALL 构造已经有一个同名的索引"
 
-#: fortran/resolve.c:10036
+#: fortran/resolve.c:10049
 #, gcc-internal-format, gfc-internal-format
 msgid "WHERE/ELSEWHERE clause at %L requires a LOGICAL array"
 msgstr "%L处的 WHERE/ELSEWHERE 子句需要一个 LOGICAL 数组"
 
-#: fortran/resolve.c:10138
+#: fortran/resolve.c:10151
 #, gcc-internal-format
 msgid "gfc_resolve_blocks(): Bad block type"
 msgstr ""
 
-#: fortran/resolve.c:10251
+#: fortran/resolve.c:10264
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CHARACTER expression will be truncated in assignment (%d/%d) at %L"
 msgid "CHARACTER expression will be truncated in assignment (%ld/%ld) at %L"
 msgstr "CHARACTER 表达式在%3$L处赋值时将被截断(%1$d/%2$d)"
 
-#: fortran/resolve.c:10283
+#: fortran/resolve.c:10296
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed expression at %L is assigned to a derived type variable with a POINTER component in a PURE procedure"
 msgstr "%L处一个非纯变量在 PURE 过程中被赋值给带有 POINTER 组件派生类型变量(12.6)"
 
-#: fortran/resolve.c:10288
+#: fortran/resolve.c:10301
 #, gcc-internal-format, gfc-internal-format
 msgid "The impure variable at %L is assigned to a derived type variable with a POINTER component in a PURE procedure (12.6)"
 msgstr "%L处一个非纯变量在 PURE 过程中被赋值给带有 POINTER 组件派生类型变量(12.6)"
 
-#: fortran/resolve.c:10298
+#: fortran/resolve.c:10311
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to coindexed variable at %L in a PURE procedure"
 msgstr "%L处 PURE 过程中指针赋值目标错误"
 
-#: fortran/resolve.c:10330
+#: fortran/resolve.c:10343
 #, gcc-internal-format, gfc-internal-format
 msgid "Assignment to polymorphic coarray at %L is not permitted"
 msgstr ""
 
-#: fortran/resolve.c:10334
+#: fortran/resolve.c:10347
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L"
 msgstr "%L处赋值中的变量类型是 UNKNOWN"
 
-#: fortran/resolve.c:10339
+#: fortran/resolve.c:10352
 #, fuzzy, gcc-internal-format
 msgid "Assignment to an allocatable polymorphic variable at %L requires %<-frealloc-lhs%>"
 msgstr "%L处向 FORALL 索引变量赋值"
 
-#: fortran/resolve.c:10346
+#: fortran/resolve.c:10359
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Nonallocatable variable must not be polymorphic in intrinsic assignment at %L - check that there is a matching specific subroutine for '=' operator"
 msgstr "变量必须不是 polymorphic 在中 intrinsic 指派于 %L - 检查该有匹配特定的副常式用于‘=’运算符"
 
-#: fortran/resolve.c:10357
+#: fortran/resolve.c:10370
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Coindexed variable must not have an allocatable ultimate component in assignment at %L"
 msgstr "%L处赋值中的变量类型不能是多态的"
 
-#: fortran/resolve.c:10663
+#: fortran/resolve.c:10683
 #, gcc-internal-format, gfc-internal-format
 msgid "TODO: type-bound defined assignment(s) at %L not done because multiple part array references would occur in intermediate expressions."
 msgstr ""
@@ -63943,70 +64025,70 @@
 
 #. Even if standard does not support this feature, continue to build
 #. the two statements to avoid upsetting frontend_passes.c.
-#: fortran/resolve.c:10905
+#: fortran/resolve.c:10925
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid procedure pointer assignment at %L"
 msgid "Pointer procedure assignment at %L"
 msgstr "%L处过程指针赋值非法"
 
-#: fortran/resolve.c:10917
+#: fortran/resolve.c:10937
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The function result on the lhs of the assignment at %L must have the pointer attribute."
 msgstr "%L处计算转移 GOTO 语句的选择表达式必须是一个标量整数表达式"
 
-#: fortran/resolve.c:11157
+#: fortran/resolve.c:11177
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgstr "ASSIGNED GOTO 语句在%L处需要一个 INTEGER 变量"
 
-#: fortran/resolve.c:11160
+#: fortran/resolve.c:11180
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs has not been assigned a target label at %L"
 msgstr "变量‘%s’在 %L 尚未指派目标标号"
 
-#: fortran/resolve.c:11171
+#: fortran/resolve.c:11191
 #, gcc-internal-format, gfc-internal-format
 msgid "Alternate RETURN statement at %L requires a SCALAR-INTEGER return specifier"
 msgstr "%L处的替代 RETURN 语句需要一个 SCALAR-INTEGER 返回限定符"
 
-#: fortran/resolve.c:11233
+#: fortran/resolve.c:11253
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGN statement at %L requires a scalar default INTEGER variable"
 msgstr "%L处的 ASSIGN 语句需要一个默认标量 INTEGER 变量"
 
-#: fortran/resolve.c:11278
+#: fortran/resolve.c:11298
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid kind for %s at %L"
 msgid "Invalid NULL at %L"
 msgstr "%2$L处 %1$s 种别无效"
 
-#: fortran/resolve.c:11282
+#: fortran/resolve.c:11302
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Arithmetic IF statement at %L requires a numeric expression"
 msgid "Arithmetic IF statement at %L requires a scalar REAL or INTEGER expression"
 msgstr "%L处的算术 IF 语句要求一个数字表达式"
 
-#: fortran/resolve.c:11339
+#: fortran/resolve.c:11359
 #, gcc-internal-format
 msgid "gfc_resolve_code(): No expression on DO WHILE"
 msgstr ""
 
-#: fortran/resolve.c:11344
+#: fortran/resolve.c:11364
 #, gcc-internal-format, gfc-internal-format
 msgid "Exit condition of DO WHILE loop at %L must be a scalar LOGICAL expression"
 msgstr "%L处 DO WHILE 循环的退出条件必须是一个标量 LOGICAL 表达式"
 
-#: fortran/resolve.c:11428
+#: fortran/resolve.c:11448
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORALL mask clause at %L requires a scalar LOGICAL expression"
 msgstr "%L处的 IF 分句需要一个标量 LOGICAL 表达式"
 
-#: fortran/resolve.c:11507
+#: fortran/resolve.c:11527
 #, fuzzy, gcc-internal-format
 msgid "gfc_resolve_code(): Bad statement code"
 msgstr "gfc_trans_code()：错误的语句代码"
 
-#: fortran/resolve.c:11617
+#: fortran/resolve.c:11637
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "%2$L处的绑定标号‘%1$s’与 %4$L 处的全局实体‘%3$s’冲突"
@@ -64013,7 +64095,7 @@
 
 #. This can only happen if the variable is defined in a module - if it
 #. isn't the same module, reject it.
-#: fortran/resolve.c:11630
+#: fortran/resolve.c:11650
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs from module %qs with binding label %qs at %L uses the same global identifier as entity at %L from module %qs"
 msgstr "%2$L处的绑定标号‘%1$s’与 %4$L 处的全局实体‘%3$s’冲突"
@@ -64021,58 +64103,58 @@
 #. Print an error if the procedure is defined multiple times; we have to
 #. exclude references to the same procedure via module association or
 #. multiple checks for the same procedure.
-#: fortran/resolve.c:11647
+#: fortran/resolve.c:11667
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with binding label %qs at %L uses the same global identifier as entity at %L"
 msgstr "%2$L处的绑定标号‘%1$s’与 %4$L 处的全局实体‘%3$s’冲突"
 
-#: fortran/resolve.c:11732
+#: fortran/resolve.c:11752
 #, gcc-internal-format, gfc-internal-format
 msgid "String length at %L is too large"
 msgstr "%L处字符串太长"
 
-#: fortran/resolve.c:11961
+#: fortran/resolve.c:11981
 #, fuzzy, gcc-internal-format
 msgid "Allocatable array %qs at %L must have a deferred shape or assumed rank"
 msgstr "可分配的数组‘%s’在%L处必须有延迟的外形"
 
-#: fortran/resolve.c:11965
+#: fortran/resolve.c:11985
 #, fuzzy, gcc-internal-format
 msgid "Scalar object %qs at %L may not be ALLOCATABLE"
 msgstr "%2$L处标量对象‘%1$s’不能为 ALLOCATABLE"
 
-#: fortran/resolve.c:11973
+#: fortran/resolve.c:11993
 #, fuzzy, gcc-internal-format
 msgid "Array pointer %qs at %L must have a deferred shape or assumed rank"
 msgstr "数组指针‘%s’在%L处必须有延迟的外形"
 
-#: fortran/resolve.c:11983
+#: fortran/resolve.c:12003
 #, fuzzy, gcc-internal-format
 msgid "Array %qs at %L cannot have a deferred shape"
 msgstr "数组‘%s’在%L处不能有延迟的外形"
 
-#: fortran/resolve.c:11998
+#: fortran/resolve.c:12018
 #, fuzzy, gcc-internal-format
 msgid "Type %qs of CLASS variable %qs at %L is not extensible"
 msgstr "%3$L处 CLASS 变量‘%2$s’的类型‘%1$s’不能被扩展"
 
-#: fortran/resolve.c:12010
+#: fortran/resolve.c:12030
 #, fuzzy, gcc-internal-format
 msgid "CLASS variable %qs at %L must be dummy, allocatable or pointer"
 msgstr "%2$L处的 CLASS 变量‘%1$s’必须是哑元、可分配的或者指针"
 
-#: fortran/resolve.c:12041
+#: fortran/resolve.c:12061
 #, fuzzy, gcc-internal-format
 #| msgid "The type '%s' cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgid "The type %qs cannot be host associated at %L because it is blocked by an incompatible object of the same name declared at %L"
 msgstr "‘%s’在%L处不能是主机相关的，因为它被在%L处声明的一个不兼容的同名对象所阻碍"
 
-#: fortran/resolve.c:12063
+#: fortran/resolve.c:12083
 #, fuzzy, gcc-internal-format
 msgid "Implied SAVE for module variable %qs at %L, needed due to the default initialization"
 msgstr "Fortran 2008：%2$L处模块变量‘%1$s’隐含使用了 SAVE，因为默认初始化有此需求"
 
-#: fortran/resolve.c:12090
+#: fortran/resolve.c:12110
 #, fuzzy, gcc-internal-format
 msgid "Entity %qs at %L has a deferred type parameter and requires either the POINTER or ALLOCATABLE attribute"
 msgstr "语句函数‘%s’在%L处不允许用作实参"
@@ -64079,894 +64161,900 @@
 
 #. F08:C541. The shape of an array defined in a main program or module
 #. * needs to be constant.
-#: fortran/resolve.c:12131
+#: fortran/resolve.c:12151
 #, fuzzy, gcc-internal-format
 #| msgid "The module or main program array '%s' at %L must have constant shape"
 msgid "The module or main program array %qs at %L must have constant shape"
 msgstr "%2$L处的模块或主程序数组‘%1$s’必须有常量外形"
 
-#: fortran/resolve.c:12150
+#: fortran/resolve.c:12170
 #, gcc-internal-format, gfc-internal-format
 msgid "Entity with assumed character length at %L must be a dummy argument or a PARAMETER"
 msgstr "%L处假定字符长度的实体必须是个虚参或是个 PARAMETER"
 
-#: fortran/resolve.c:12171
+#: fortran/resolve.c:12191
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must have constant character length in this context"
 msgid "%qs at %L must have constant character length in this context"
 msgstr "变量‘%s’在%L处上下文中字符长度必须为常量"
 
-#: fortran/resolve.c:12178
+#: fortran/resolve.c:12198
 #, fuzzy, gcc-internal-format
 msgid "COMMON variable %qs at %L must have constant character length"
 msgstr "变量‘%s’在%L处上下文中字符长度必须为常量"
 
-#: fortran/resolve.c:12225
+#: fortran/resolve.c:12245
 #, fuzzy, gcc-internal-format
 msgid "Allocatable %qs at %L cannot have an initializer"
 msgstr "可分配的‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.c:12228
+#: fortran/resolve.c:12248
 #, fuzzy, gcc-internal-format
 msgid "External %qs at %L cannot have an initializer"
 msgstr "外部‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.c:12232
+#: fortran/resolve.c:12252
 #, fuzzy, gcc-internal-format
 msgid "Dummy %qs at %L cannot have an initializer"
 msgstr "哑元‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.c:12235
+#: fortran/resolve.c:12255
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic %qs at %L cannot have an initializer"
 msgstr "内建函数‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.c:12238
+#: fortran/resolve.c:12258
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L cannot have an initializer"
 msgstr "函数结果‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.c:12241
+#: fortran/resolve.c:12261
 #, fuzzy, gcc-internal-format
 msgid "Automatic array %qs at %L cannot have an initializer"
 msgstr "自动数组‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.c:12283
+#: fortran/resolve.c:12303
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "in %s, at %s:%d"
 msgid "%s at %L"
 msgstr "在 %s 中，于 %s:%d"
 
-#: fortran/resolve.c:12310
+#: fortran/resolve.c:12330
 #, fuzzy, gcc-internal-format
 msgid "Character-valued statement function %qs at %L must have constant length"
 msgstr "%2$L处有字符值的语句函数‘%1$s’必须有常量长度"
 
-#: fortran/resolve.c:12332
+#: fortran/resolve.c:12352
 #, fuzzy, gcc-internal-format
 msgid "%qs is of a PRIVATE type and cannot be a dummy argument of %qs, which is PUBLIC at %L"
 msgstr "Fortran 2003：%3$L处‘%1$s’是 PRIVATE 类型因而不能是 PUBLIC 类型‘%2$s’的虚参"
 
-#: fortran/resolve.c:12354
+#: fortran/resolve.c:12374
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs in PUBLIC interface %qs at %L takes dummy arguments of %qs which is PRIVATE"
 msgstr "Fortran 2003: %3$L处 PUBLIC 接口‘%2$s’中的过程‘%1$s’有 PRIVATE 的虚参‘%4$s’"
 
-#: fortran/resolve.c:12372
+#: fortran/resolve.c:12392
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L cannot have an initializer"
 msgstr "函数‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.c:12381
+#: fortran/resolve.c:12401
 #, fuzzy, gcc-internal-format
 msgid "External object %qs at %L may not have an initializer"
 msgstr "外部对象‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.c:12389
+#: fortran/resolve.c:12409
 #, fuzzy, gcc-internal-format
 msgid "ELEMENTAL function %qs at %L must have a scalar result"
 msgstr "%2$L处 ELEMENTAL 函数‘%1$s’必须有一个标量返回值"
 
-#: fortran/resolve.c:12399
+#: fortran/resolve.c:12419
 #, fuzzy, gcc-internal-format
 msgid "Statement function %qs at %L may not have pointer or allocatable attribute"
 msgstr "语句函数‘%s’在%L处不允许用作实参"
 
-#: fortran/resolve.c:12418
+#: fortran/resolve.c:12438
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be array-valued"
 msgstr "CHARACTER(*) 函数‘%s’在%L处不能为数组值"
 
-#: fortran/resolve.c:12422
+#: fortran/resolve.c:12442
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pointer-valued"
 msgstr "指定CHARACTER(*) 函数‘%s’在%L处不能为指针值"
 
-#: fortran/resolve.c:12426
+#: fortran/resolve.c:12446
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be pure"
 msgstr "CHARACTER(*) 函数‘%s’在%L处不能为纯函数"
 
-#: fortran/resolve.c:12430
+#: fortran/resolve.c:12450
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L cannot be recursive"
 msgstr "CHARACTER(*) 函数‘%s’在%L处不能是递归的"
 
-#: fortran/resolve.c:12443
+#: fortran/resolve.c:12463
 #, fuzzy, gcc-internal-format
 msgid "CHARACTER(*) function %qs at %L"
 msgstr "在函数%qs中"
 
-#: fortran/resolve.c:12452
+#: fortran/resolve.c:12472
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer %qs at %L shall not be elemental"
 msgstr "%2$L处的具有 PASS 的过程指针组件‘%1$s’必须至少有一个实参"
 
-#: fortran/resolve.c:12458
+#: fortran/resolve.c:12478
 #, fuzzy, gcc-internal-format
 msgid "Dummy procedure %qs at %L shall not be elemental"
 msgstr "哑过程‘%s’在%C处不能有泛型接口"
 
-#: fortran/resolve.c:12470
+#: fortran/resolve.c:12490
 #, fuzzy, gcc-internal-format
 msgid "Function result variable %qs at %L of elemental function %qs shall not have an ALLOCATABLE or POINTER attribute"
 msgstr "%2$L处变量‘%1$s’不能既有 ALLOCATABLE 又有 BIND(C) 属性"
 
-#: fortran/resolve.c:12527
+#: fortran/resolve.c:12547
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with SAVE attribute in %qs at %L"
 msgstr "%L处 PURE 过程不能指定 SAVE 属性"
 
-#: fortran/resolve.c:12533
+#: fortran/resolve.c:12553
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with INTENT attribute in %qs at %L"
 msgstr "PROCEDURE 属性与%2$L处‘%1$s’中的 INTENT 属性冲突"
 
-#: fortran/resolve.c:12539
+#: fortran/resolve.c:12559
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with RESULT attribute in %qs at %L"
 msgstr "PROCEDURE 属性与在%2$L处‘%1$s’中的 RESULT 属性冲突"
 
-#: fortran/resolve.c:12547
+#: fortran/resolve.c:12567
 #, fuzzy, gcc-internal-format
 msgid "EXTERNAL attribute conflicts with FUNCTION attribute in %qs at %L"
 msgstr "EXTERNAL 属性与在%2$L处‘%1$s’中的 FUNCTION 属性冲突"
 
-#: fortran/resolve.c:12553
+#: fortran/resolve.c:12573
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer result %qs at %L is missing the pointer attribute"
 msgstr "%2$L处过程指针结果‘%1$s’缺少指针属性"
 
-#: fortran/resolve.c:12596
+#: fortran/resolve.c:12616
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in ELEMENTAL attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12604
+#: fortran/resolve.c:12624
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in PURE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12612
+#: fortran/resolve.c:12632
 #, gcc-internal-format, gfc-internal-format
 msgid "Mismatch in RECURSIVE attribute between MODULE PROCEDURE at %L and its interface in %s"
 msgstr ""
 
-#: fortran/resolve.c:12621
+#: fortran/resolve.c:12641
 #, gcc-internal-format
 msgid "%s between the MODULE PROCEDURE declaration in MODULE %qs and the declaration at %L in (SUB)MODULE %qs"
 msgstr ""
 
-#: fortran/resolve.c:12705
+#: fortran/resolve.c:12725
 #, fuzzy, gcc-internal-format
 msgid "FINAL procedure %qs at %L is not a SUBROUTINE"
 msgstr "%L处 FINAL 过程的参数必须不是 OPTIONAL"
 
-#: fortran/resolve.c:12714
+#: fortran/resolve.c:12734
 #, gcc-internal-format, gfc-internal-format
 msgid "FINAL procedure at %L must have exactly one argument"
 msgstr "%L处的 FINAL 过程有且只有一个参数"
 
-#: fortran/resolve.c:12723
+#: fortran/resolve.c:12743
 #, fuzzy, gcc-internal-format
 msgid "Argument of FINAL procedure at %L must be of type %qs"
 msgstr "%L处 FINAL 过程的参数必须不是 OPTIONAL"
 
-#: fortran/resolve.c:12731
+#: fortran/resolve.c:12751
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be a POINTER"
 msgstr "%L处 FINAL 过程的参数必须不是 POINTER"
 
-#: fortran/resolve.c:12737
+#: fortran/resolve.c:12757
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be ALLOCATABLE"
 msgstr "%L处 FINAL 过程的参数必须不是 ALLOCATABLE"
 
-#: fortran/resolve.c:12743
+#: fortran/resolve.c:12763
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be OPTIONAL"
 msgstr "%L处 FINAL 过程的参数必须不是 OPTIONAL"
 
-#: fortran/resolve.c:12751
+#: fortran/resolve.c:12771
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of FINAL procedure at %L must not be INTENT(OUT)"
 msgstr "%L处 FINAL 过程的参数必须不是 INTENT(OUT)"
 
-#: fortran/resolve.c:12760
+#: fortran/resolve.c:12780
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-scalar FINAL procedure at %L should have assumed shape argument"
 msgstr "%L处的非标量 FINAL 过程应当有假定外形的参数"
 
-#: fortran/resolve.c:12782
+#: fortran/resolve.c:12802
 #, fuzzy, gcc-internal-format
 msgid "FINAL procedure %qs declared at %L has the same rank (%d) as %qs"
 msgstr "%2$L处声明的 FINAL 过程‘%1$s’有与‘%4$s’相同的秩(%3$d)"
 
-#: fortran/resolve.c:12819
+#: fortran/resolve.c:12839
 #, fuzzy, gcc-internal-format
 msgid "Only array FINAL procedures declared for derived type %qs defined at %L, suggest also scalar one"
 msgstr "仅为定义在%2$L处的派生类型‘%1$s’声明了数组 FINAL 过程，建议也定义一个标量过程"
 
-#: fortran/resolve.c:12859
+#: fortran/resolve.c:12879
 #, fuzzy, gcc-internal-format
 msgid "%qs and %qs can't be mixed FUNCTION/SUBROUTINE for GENERIC %qs at %L"
 msgstr "%4$L处‘%1$s’和‘%2$s’对 GENERIC‘%3$s’不能是混合的 FUNCTION/SUBROUTINE"
 
-#: fortran/resolve.c:12895
+#: fortran/resolve.c:12915
 #, fuzzy, gcc-internal-format
 msgid "%qs and %qs for GENERIC %qs at %L are ambiguous"
 msgstr "引用%qs有歧义：出现在接口%qs和接口%qs中"
 
-#: fortran/resolve.c:12954
+#: fortran/resolve.c:12974
 #, fuzzy, gcc-internal-format
 msgid "Undefined specific binding %qs as target of GENERIC %qs at %L"
 msgstr "未定义的指定绑定‘%1$s’用作%3$L处的 GENERIC‘%2$s’的目标"
 
-#: fortran/resolve.c:12966
+#: fortran/resolve.c:12986
 #, fuzzy, gcc-internal-format
 msgid "GENERIC %qs at %L must target a specific binding, %qs is GENERIC, too"
 msgstr "%2$L处 GENERIC‘%1$s’必须定位一个特定的绑定，‘%3$s’也是 GENERIC"
 
-#: fortran/resolve.c:12994
+#: fortran/resolve.c:13014
 #, fuzzy, gcc-internal-format
 msgid "GENERIC %qs at %L can't overwrite specific binding with the same name"
 msgstr "%2$L处 GENERIC‘%1$s’无法覆盖同名的特定绑定"
 
-#: fortran/resolve.c:13050
+#: fortran/resolve.c:13070
 #, gcc-internal-format, gfc-internal-format
 msgid "Type-bound operator at %L can't be NOPASS"
 msgstr "%L处类型限定的操作数不能是 NOPASS"
 
-#: fortran/resolve.c:13242
+#: fortran/resolve.c:13262
 #, fuzzy, gcc-internal-format
 msgid "%qs must be a module procedure or an external procedure with an explicit interface at %L"
 msgstr "%2$L处的‘%1$s’必须是一个模块过程或带有显式接口的外部过程"
 
-#: fortran/resolve.c:13284
+#: fortran/resolve.c:13304
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with PASS(%s) at %L has no argument %qs"
 msgstr "%3$L处有 PASS(%2$s)的过程‘%1$s’没有参数‘%4$s’"
 
-#: fortran/resolve.c:13298
+#: fortran/resolve.c:13318
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs with PASS at %L must have at least one argument"
 msgstr "%2$L处有 PASS 的过程‘%1$s’必须至少带一个参数"
 
-#: fortran/resolve.c:13312 fortran/resolve.c:13778
+#: fortran/resolve.c:13332 fortran/resolve.c:13798
 #, fuzzy, gcc-internal-format
 msgid "Non-polymorphic passed-object dummy argument of %qs at %L"
 msgstr "%2$L处非多态的传递对象虚参‘%1$s’"
 
-#: fortran/resolve.c:13320
+#: fortran/resolve.c:13340
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived-type %qs"
 msgstr " %4$L处的具有 PASS(%3$s) 的‘%2$s’的参数‘%1$s’必须具有派生类型‘%5$s’"
 
-#: fortran/resolve.c:13329
+#: fortran/resolve.c:13349
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must be scalar"
 msgstr "%2$L处‘%1$s’的传递对象虚参必须是标量"
 
-#: fortran/resolve.c:13335
+#: fortran/resolve.c:13355
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be ALLOCATABLE"
 msgstr "%2$L处‘%1$s’的传递对象虚参不能是 ALLOCATABLE"
 
-#: fortran/resolve.c:13341
+#: fortran/resolve.c:13361
 #, fuzzy, gcc-internal-format
 msgid "Passed-object dummy argument of %qs at %L must not be POINTER"
 msgstr "%2$L处‘%1$s’的传递对象虚参不能是 POINTER"
 
-#: fortran/resolve.c:13370
+#: fortran/resolve.c:13390
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as a component of %qs"
 msgstr "%2$L处过程‘%1$s’和‘%3$s’的组件重名"
 
-#: fortran/resolve.c:13380
+#: fortran/resolve.c:13400
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L has the same name as an inherited component of %qs"
 msgstr "%2$L处过程‘%1$s’和‘%3$s’的继承组件重名"
 
-#: fortran/resolve.c:13472
+#: fortran/resolve.c:13492
 #, fuzzy, gcc-internal-format
 msgid "Derived-type %qs declared at %L must be ABSTRACT because %qs is DEFERRED and not overridden"
 msgstr "%2$L处声明的派生类型‘%1$s’必须是 ABSTRACT，因为‘%3$s’是 DEFERRED 且没有被覆盖"
 
-#: fortran/resolve.c:13574
+#: fortran/resolve.c:13594
 #, fuzzy, gcc-internal-format
 msgid "Coarray component %qs at %L must be allocatable with deferred shape"
 msgstr "数组指针‘%s’在%L处必须有延迟的外形"
 
-#: fortran/resolve.c:13583
+#: fortran/resolve.c:13603
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "成分‘%s’于 %L 的类型 (C_PTR) 或类型 (C_FUNPTR) 不应该是 coarray"
 
-#: fortran/resolve.c:13593
+#: fortran/resolve.c:13613
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgstr "成分‘%s’于 %L 与 coarray 成分应该是 nonpointer，nonallocatable 纯量"
 
-#: fortran/resolve.c:13602
+#: fortran/resolve.c:13622
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %L has the CONTIGUOUS attribute but is not an array pointer"
 msgstr "%2$L 处的“%1$s”不能有 VALUE 属性，因为它不是个虚参"
 
-#: fortran/resolve.c:13613
+#: fortran/resolve.c:13633
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ICHAR at %L must be of length one"
 msgid "Component %qs of BIND(C) type at %L must have length one"
 msgstr "%L处 ICHAR 的参数长度必须为 1"
 
-#: fortran/resolve.c:13711
+#: fortran/resolve.c:13731
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS(%s) at %L has no argument %qs"
 msgstr "%3$L处带有 PASS(%2$s)的过程指针组件‘%1$s’没有参数‘%4$s’"
 
-#: fortran/resolve.c:13725
+#: fortran/resolve.c:13745
 #, fuzzy, gcc-internal-format
 msgid "Procedure pointer component %qs with PASS at %L must have at least one argument"
 msgstr "%2$L处的具有 PASS 的过程指针组件‘%1$s’必须至少有一个实参"
 
-#: fortran/resolve.c:13741
+#: fortran/resolve.c:13761
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be of the derived type %qs"
 msgstr "%4$L处具有 PASS(%3$s) 的‘%2$s’的参数‘%1$s’必须有派生类型‘%5$s’"
 
-#: fortran/resolve.c:13751
+#: fortran/resolve.c:13771
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L must be scalar"
 msgstr "%4$L 处的具有 PASS(%3$s) 的‘%2$s’的参数‘%1$s’必须是标量"
 
-#: fortran/resolve.c:13760
+#: fortran/resolve.c:13780
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not have the POINTER attribute"
 msgstr "%4$L处带 PASS(%3$s) 的‘%2$s’的参数‘%1$s’不能有 POINTER 属性"
 
-#: fortran/resolve.c:13769
+#: fortran/resolve.c:13789
 #, fuzzy, gcc-internal-format
 msgid "Argument %qs of %qs with PASS(%s) at %L may not be ALLOCATABLE"
 msgstr "%4$L处带 PASS(%3$s) 的‘%2$s’的参数‘%1$s’不能是 ALLOCATABLE"
 
-#: fortran/resolve.c:13811
+#: fortran/resolve.c:13831
 #, fuzzy, gcc-internal-format
 msgid "Component %qs of %qs at %L has the same name as an inherited type-bound procedure"
 msgstr "%3$L处‘%2$s’的组件‘%1$s’与一个继承的类型限定过程同名"
 
-#: fortran/resolve.c:13824
+#: fortran/resolve.c:13844
 #, fuzzy, gcc-internal-format
 msgid "Character length of component %qs needs to be a constant specification expression at %L"
 msgstr "%2$L处组件‘%1$s’的字符长度必须是一个常量规格表达式"
 
-#: fortran/resolve.c:13835
+#: fortran/resolve.c:13855
 #, fuzzy, gcc-internal-format
 msgid "Character component %qs of %qs at %L with deferred length must be a POINTER or ALLOCATABLE"
 msgstr "字符成分‘%s’的‘%s’于 %L 与已推迟长度必须是指标或 ALLOCATABLE"
 
-#: fortran/resolve.c:13868
+#: fortran/resolve.c:13888
 #, fuzzy, gcc-internal-format
 msgid "the component %qs is a PRIVATE type and cannot be a component of %qs, which is PUBLIC at %L"
 msgstr "Fortran 2003：%3$L处组合‘%1$s’是一个 PRIVATE 类型，因此不能是 PUBLIC‘%2$s’的组合"
 
-#: fortran/resolve.c:13876
+#: fortran/resolve.c:13896
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Polymorphic component %s at %L in SEQUENCE or BIND(C) type %s"
 msgstr "Polymorphic 成分 %s 于 %L 在中串行或绑定©类型 %s"
 
-#: fortran/resolve.c:13885
+#: fortran/resolve.c:13905
 #, gcc-internal-format, gfc-internal-format
 msgid "Component %s of SEQUENCE type declared at %L does not have the SEQUENCE attribute"
 msgstr "%2$L处声明的有 SEQUENCE 类型的组件 %1$s 没有 SEQUENCE 属性"
 
-#: fortran/resolve.c:13903 fortran/resolve.c:13915
+#: fortran/resolve.c:13923 fortran/resolve.c:13935
 #, fuzzy, gcc-internal-format
 msgid "The pointer component %qs of %qs at %L is a type that has not been declared"
 msgstr "%3$L处‘%2$s’的指针组件‘%1$s’类型尚未声明"
 
-#: fortran/resolve.c:13989
+#: fortran/resolve.c:14009
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "non-constant initialization expression at %L"
 msgid "Conflicting initializers in union at %L and %L"
 msgstr "%L处非常量初始化表达式"
 
-#: fortran/resolve.c:14034
+#: fortran/resolve.c:14054
 #, fuzzy, gcc-internal-format
 msgid "As extending type %qs at %L has a coarray component, parent type %qs shall also have one"
 msgstr "作为延伸类型‘%s’于 %L 有 coarray 成分，亲代类型‘%s’应该也有一个"
 
-#: fortran/resolve.c:14047
+#: fortran/resolve.c:14067
 #, fuzzy, gcc-internal-format
 msgid "Non-extensible derived-type %qs at %L must not be ABSTRACT"
 msgstr "%2$L处不能扩展的派生类型‘%1$s’不能是 ABSTRACT"
 
-#: fortran/resolve.c:14111
+#: fortran/resolve.c:14131
 #, gcc-internal-format
 msgid "Parameterized type %qs does not have a component corresponding to parameter %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14144
+#: fortran/resolve.c:14164
 #, fuzzy, gcc-internal-format
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr "%3$L处‘%2$s’的组件‘%1$s’与一个继承的类型限定过程同名"
 
-#: fortran/resolve.c:14216
+#: fortran/resolve.c:14236
 #, fuzzy, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "不允许 %3$L 处 %2$s 名字列表中假定大小的数组“%1$s”"
 
-#: fortran/resolve.c:14222
+#: fortran/resolve.c:14242
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "%3$L处 NAMELIST 数组对象‘%1$s’在名字列表‘%2$s’不能有假定外形"
 
-#: fortran/resolve.c:14228
+#: fortran/resolve.c:14248
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "%3$L处 NAMELIST 数组对象‘%1$s’在名字列表‘%2$s’必须有常外形"
 
-#: fortran/resolve.c:14236
+#: fortran/resolve.c:14256
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "%3$L处 NAMELIST 数组对象‘%1$s’在名字列表‘%2$s’必须有常外形"
 
-#: fortran/resolve.c:14253
+#: fortran/resolve.c:14273
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "%3$L处 NAMELIST 对象‘%1$s’声明为 PRIVATE 因此不能是 PUBLIC 名字列表‘%2$s’的成员"
 
-#: fortran/resolve.c:14275
+#: fortran/resolve.c:14295
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "%3$L处 NAMELIST 对象‘%1$s’有使用相关的 PRIVATE 组件因此不能是 NAMELIST‘%2$s’的成员"
 
-#: fortran/resolve.c:14286
+#: fortran/resolve.c:14306
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "%3$L处 NAMELIST 对象‘%1$s’有 PRIVATE 组件因此不能是 PUBLIC 名字列表‘%2$s’的成员"
 
-#: fortran/resolve.c:14313
+#: fortran/resolve.c:14333
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "PROCEDURE 属性与%2$L处‘%1$s’中的 NAMELIST 属性冲突"
 
-#: fortran/resolve.c:14337
+#: fortran/resolve.c:14357
 #, fuzzy, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "%2$L处的参数数组‘%1$s’不能是自动的或有延迟的外形"
 
-#: fortran/resolve.c:14353
+#: fortran/resolve.c:14373
 #, fuzzy, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "%2$L处隐式类型的 PARAMETER‘%1$s’与随后的 IMPLICIT 类型不匹配"
 
-#: fortran/resolve.c:14364
+#: fortran/resolve.c:14384
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "%L处 PARAMETER 中派生类型不兼容"
 
-#: fortran/resolve.c:14372
+#: fortran/resolve.c:14392
 #, fuzzy, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "%2$L处变量‘%1$s’不能既有 POINTER 又有 BIND(C) 属性"
 
-#: fortran/resolve.c:14423
+#: fortran/resolve.c:14443
 #, fuzzy, gcc-internal-format
 msgid "The object %qs at %L has a deferred LEN parameter %qs and is neither allocatable nor a pointer"
 msgstr "语句函数‘%s’在%L处不允许用作实参"
 
-#: fortran/resolve.c:14434
+#: fortran/resolve.c:14454
 #, gcc-internal-format
 msgid "The AUTOMATIC object %qs at %L must not have the SAVE attribute or be a variable declared in the main program, a module or a submodule(F08/C513)"
 msgstr ""
 
-#: fortran/resolve.c:14441
+#: fortran/resolve.c:14461
 #, gcc-internal-format
 msgid "The object %qs at %L with ASSUMED type parameters must be a dummy or a SELECT TYPE selector(F08/4.2)"
 msgstr ""
 
-#: fortran/resolve.c:14480
+#: fortran/resolve.c:14500
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:14544
+#: fortran/resolve.c:14564
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "%s 属性与 %s 属性在%L处冲突"
 
-#: fortran/resolve.c:14547
+#: fortran/resolve.c:14567
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "%s 属性与 %s 属性在%L处冲突"
 
-#: fortran/resolve.c:14643
+#: fortran/resolve.c:14663
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr "%2$L 处的“%1$s”不能有 VALUE 属性，因为它不是个虚参"
 
-#: fortran/resolve.c:14664
+#: fortran/resolve.c:14684
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad specification for assumed size array at %C"
 msgid "Bad specification for assumed size array at %L"
 msgstr "%C处假定大小数组的规格说明错误"
 
-#: fortran/resolve.c:14677
+#: fortran/resolve.c:14697
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "%L处假定大小的数组必须是一个虚参"
 
-#: fortran/resolve.c:14680
+#: fortran/resolve.c:14700
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "%L处假定外形的数组必须是一个虚参"
 
-#: fortran/resolve.c:14688
+#: fortran/resolve.c:14708
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "%L处假定大小的数组必须是一个虚参"
 
-#: fortran/resolve.c:14695
+#: fortran/resolve.c:14715
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:14708
+#: fortran/resolve.c:14728
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "%L处的符号不是一个 DUMMY 变量"
 
-#: fortran/resolve.c:14714
+#: fortran/resolve.c:14734
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "%2$L 处的“%1$s”不能有 VALUE 属性，因为它不是个虚参"
 
-#: fortran/resolve.c:14724
+#: fortran/resolve.c:14744
 #, fuzzy, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "%2$L处带 VALUE 属性的字符哑元‘%1$s’必须具有常数长度"
 
-#: fortran/resolve.c:14733
+#: fortran/resolve.c:14753
 #, fuzzy, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "%2$L处带 VALUE 属性与 C 可互操作的字符哑元‘%1$s’长度必须为 1"
 
-#: fortran/resolve.c:14746 fortran/resolve.c:14923
+#: fortran/resolve.c:14766 fortran/resolve.c:14943
 #, fuzzy, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "%2$L处派生类型‘%1$s’的类型‘%3$s’尚未定义"
 
-#: fortran/resolve.c:14760
+#: fortran/resolve.c:14780
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14769
+#: fortran/resolve.c:14789
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:14778
+#: fortran/resolve.c:14798
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "%2$L处变量‘%1$s’不能既有 ALLOCATABLE 又有 BIND(C) 属性"
 
-#: fortran/resolve.c:14786
+#: fortran/resolve.c:14806
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "%2$L处变量‘%1$s’不能既有 POINTER 又有 BIND(C) 属性"
 
-#: fortran/resolve.c:14793
+#: fortran/resolve.c:14813
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:14813
+#: fortran/resolve.c:14833
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "%2$L处假定外形数组‘%1$s’不能用在初始化表达式中"
 
-#: fortran/resolve.c:14820
+#: fortran/resolve.c:14840
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "%2$L处变量‘%1$s’不能既有 ALLOCATABLE 又有 BIND(C) 属性"
 
-#: fortran/resolve.c:14827
+#: fortran/resolve.c:14847
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "%2$L处变量‘%1$s’不能既有 POINTER 又有 BIND(C) 属性"
 
-#: fortran/resolve.c:14834
+#: fortran/resolve.c:14854
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr "%C处的循环变量不能是一个子组件"
 
-#: fortran/resolve.c:14860
+#: fortran/resolve.c:14880
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr "%2$L处变量‘%1$s’不能是 BIND(C) 因为它既不是一个 COMMON 块也不是于模块级作用域声明的"
 
-#: fortran/resolve.c:14870
+#: fortran/resolve.c:14890
 #, fuzzy, gcc-internal-format
 msgid "BIND(C) Variable %qs at %L must have length one"
 msgstr "变量‘%s’在%L处上下文中字符长度必须为常量"
 
-#: fortran/resolve.c:14949
+#: fortran/resolve.c:14969
 #, fuzzy, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "Fortran 2003：%3$L处 PUBLIC %1$s‘%2$s’具有 PRIVATE 派生类型‘%4$s’"
 
-#: fortran/resolve.c:14964
+#: fortran/resolve.c:14984
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr "变量 %s 于 %L 的类型 LOCK_TYPE 或与 subcomponent 的类型 LOCK_TYPE 必须是 coarray"
 
-#: fortran/resolve.c:14977
+#: fortran/resolve.c:14997
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type EVENT_TYPE must be a coarray"
 msgstr "变量 %s 于 %L 的类型 LOCK_TYPE 或与 subcomponent 的类型 LOCK_TYPE 必须是 coarray"
 
-#: fortran/resolve.c:14995
+#: fortran/resolve.c:15015
 #, fuzzy, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "%2$L处INTENT(OUT) 虚参‘%1$s’是 ASSUMED SIZE，所以不能有一个默认初始值设定"
 
-#: fortran/resolve.c:15007
+#: fortran/resolve.c:15027
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "%2$L处的‘%1$s’虚参不能是 INTENT(OUT)"
 
-#: fortran/resolve.c:15016
+#: fortran/resolve.c:15036
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "%2$L处的‘%1$s’虚参不能是 INTENT(OUT)"
 
-#: fortran/resolve.c:15028
+#: fortran/resolve.c:15048
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "函数结果‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.c:15037
+#: fortran/resolve.c:15057
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "变量‘%s’于 %L 的类型 (C_PTR) 或类型 (C_FUNPTR) 不应该是 coarray"
 
-#: fortran/resolve.c:15049
+#: fortran/resolve.c:15069
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr "变量‘%s’于 %L 与 coarray 成分应该是 nonpointer，nonallocatable 纯量"
 
-#: fortran/resolve.c:15065
+#: fortran/resolve.c:15085
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr "变量‘%s’于 %L 是 coarray 和不是 ALLOCATABLE，保存 nor 虚参数"
 
-#: fortran/resolve.c:15073
+#: fortran/resolve.c:15093
 #, fuzzy, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "数组‘%s’在%L处不能有延迟的外形"
 
-#: fortran/resolve.c:15080
+#: fortran/resolve.c:15100
 #, fuzzy, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "%C处可分配的组件必须有延迟的外形"
 
-#: fortran/resolve.c:15092
+#: fortran/resolve.c:15112
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "函数结果‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.c:15101
+#: fortran/resolve.c:15121
 #, fuzzy, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "%L处的哑过程不允许出现在 ELEMENTAL 过程中"
 
-#: fortran/resolve.c:15117
+#: fortran/resolve.c:15137
 #, fuzzy, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "%L处的哑过程不允许出现在 ELEMENTAL 过程中"
 
-#: fortran/resolve.c:15123
+#: fortran/resolve.c:15143
 #, fuzzy, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "%L处的哑过程不允许出现在 ELEMENTAL 过程中"
 
-#: fortran/resolve.c:15148
+#: fortran/resolve.c:15168
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist %s cannot be renamed by USE association to %s"
 msgid "Namelist %qs can not be an argument to subroutine or function at %L"
 msgstr "名字列表 %s 不能为对 %s 的 USE 关联来更名"
 
-#: fortran/resolve.c:15218
+#: fortran/resolve.c:15238
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "%L处的线程私有变量未被保存"
 
-#: fortran/resolve.c:15229
+#: fortran/resolve.c:15249
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:15333
+#: fortran/resolve.c:15353
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:15339
+#: fortran/resolve.c:15359
 #, fuzzy, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "%2$L处 BLOCK DATA 元素‘%1$s’必须在 COMMON 中"
 
-#: fortran/resolve.c:15345
+#: fortran/resolve.c:15365
 #, fuzzy, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "%2$L处 BLOCK DATA 元素‘%1$s’必在前一个声明中指定"
 
-#: fortran/resolve.c:15354
+#: fortran/resolve.c:15374
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "%L处数据传输元素不能有 PRIVATE 组件"
 
-#: fortran/resolve.c:15368
+#: fortran/resolve.c:15388
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr "%2$L处的 DATA 元素‘%1$s’是一个指针所以必须是一个完全的数组"
 
-#: fortran/resolve.c:15414
+#: fortran/resolve.c:15434
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "%L处 DATA 语句中有非常量数组段"
 
-#: fortran/resolve.c:15427
+#: fortran/resolve.c:15447
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "%L处的 DATA 语名中变量比值多"
 
-#: fortran/resolve.c:15526
+#: fortran/resolve.c:15546
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr "开始的 implied-do 循环于 %L 无法被简化到常数"
 
-#: fortran/resolve.c:15534
+#: fortran/resolve.c:15554
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr "结束的 implied-do 循环于 %L 无法被简化到常数"
 
-#: fortran/resolve.c:15542
+#: fortran/resolve.c:15562
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr "步骤的 implied-do 循环于 %L 无法被简化到常数"
 
-#: fortran/resolve.c:15667
+#: fortran/resolve.c:15687
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "%L处的 DATA 语句中值比变量多"
 
-#: fortran/resolve.c:15832
+#: fortran/resolve.c:15852
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "标号 %d 于 %L 经定义但未被使用"
 
-#: fortran/resolve.c:15838
+#: fortran/resolve.c:15858
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "标号 %d 于 %L 经定义但无法被使用"
 
-#: fortran/resolve.c:15922
+#: fortran/resolve.c:15942
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "%2$L处的派生类型变量‘%1$s’必须有 SEQUENCE 属性方能成为 EQUIVALENCE 对象"
 
-#: fortran/resolve.c:15931
+#: fortran/resolve.c:15951
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "%2$L处的派生类型变量‘%1$s’必须没有 ALLOCATABLE 组件方能成为一个 EQUIVALENCE 对象"
 
-#: fortran/resolve.c:15939
+#: fortran/resolve.c:15959
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "%2$L处的默认初始化的派生类型变量‘%1$s’不能成为 EQUIVALENCE 对象，因为它在 COMMON 中有变量"
 
-#: fortran/resolve.c:15955
+#: fortran/resolve.c:15975
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "%2$L处的带指针组件的派生类型变量‘%1$s’不能成为一个 EQUIVALENCE 对象"
 
-#: fortran/resolve.c:16058
+#: fortran/resolve.c:16078
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "%L处 EQUIVALENCE 语句语法错误"
 
-#: fortran/resolve.c:16073
+#: fortran/resolve.c:16093
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr "%L处 EQUIVALENCE 集中的对象必须都带有或者都不带有 PROTECTED 属性"
 
-#: fortran/resolve.c:16098
+#: fortran/resolve.c:16118
 #, fuzzy, gcc-internal-format
 msgid "COMMON block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "%2$L处的公共块成员‘%1$s’不能在纯过程‘%3$s’中成为一个 EQUIVALENCE 对象"
 
-#: fortran/resolve.c:16107
+#: fortran/resolve.c:16127
 #, fuzzy, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "%2$L处的有名常量‘%1$s’不能是一个 EQUIVALENCE 对象"
 
-#: fortran/resolve.c:16180
+#: fortran/resolve.c:16200
 #, fuzzy, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "%2$L处有非常量界限的数组‘%1$s’不能是一个 EQUIVALENCE 对象"
 
-#: fortran/resolve.c:16191
+#: fortran/resolve.c:16211
 #, fuzzy, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "%2$L处结构组件‘%1$s’不能是一个 EQUIVALENCE 对象"
 
-#: fortran/resolve.c:16202
+#: fortran/resolve.c:16222
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "%L 的子字符串长度为零"
 
-#: fortran/resolve.c:16293
+#: fortran/resolve.c:16253
 #, fuzzy, gcc-internal-format
+#| msgid "Syntax error in character length specification at %C"
+msgid "Self reference in character length expression for %qs at %L"
+msgstr "%C处字符长度规格语法错误"
+
+#: fortran/resolve.c:16320
+#, fuzzy, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "Fortran 2003：%2$L处 PRIVATE 类型‘%3$s’的 PUBLIC 函数‘%1$s’"
 
-#: fortran/resolve.c:16306
+#: fortran/resolve.c:16333
 #, fuzzy, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "%2$L处的 ENTRY‘%1$s’没有隐式类型"
 
-#: fortran/resolve.c:16326
+#: fortran/resolve.c:16353
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "%2$L处的用户运算符‘%1$s’必须是一个 FUNCTION"
 
-#: fortran/resolve.c:16336
+#: fortran/resolve.c:16363
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "%2$L处用户运算符过程‘%1$s’不能有假定字符长度"
 
-#: fortran/resolve.c:16344
+#: fortran/resolve.c:16371
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "%2$L处的用户运算符‘%1$s’必须至少有一个实参"
 
-#: fortran/resolve.c:16358
+#: fortran/resolve.c:16385
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "%L处运算符接口的第一个参数不能是可选的"
 
-#: fortran/resolve.c:16376
+#: fortran/resolve.c:16403
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "%L处运算符接口的第二个参数不能是可选的"
 
-#: fortran/resolve.c:16383
+#: fortran/resolve.c:16410
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "%L处的运算符接口必须有至多两个实参"
 
-#: fortran/resolve.c:16461
+#: fortran/resolve.c:16488
 #, fuzzy, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr "%2$L处 PURE 过程中包含的过程‘%1$s’必须也是 PURE"
@@ -65300,19 +65388,12 @@
 msgid "simplify_min_max(): Bad type in arglist"
 msgstr ""
 
-#. Result is processor-dependent.
-#: fortran/simplify.c:5472
-#, gcc-internal-format, gfc-internal-format
-msgid "Second argument MOD at %L is zero"
-msgstr "%L处 MOD 的第二个参数为 0"
+#: fortran/simplify.c:5470 fortran/simplify.c:5478
+#, fuzzy, gcc-internal-format
+msgid "Argument %qs of MOD at %L shall not be zero"
+msgstr "%L处 NEAREST 的第二个参数不能为 0"
 
-#. Result is processor-dependent.
-#: fortran/simplify.c:5483
-#, gcc-internal-format, gfc-internal-format
-msgid "Second argument of MOD at %L is zero"
-msgstr "%L处 MOD 的第二个参数为 0"
-
-#: fortran/simplify.c:5494
+#: fortran/simplify.c:5484
 #, fuzzy, gcc-internal-format
 msgid "gfc_simplify_mod(): Bad arguments"
 msgstr "gfc_trans_code()：错误的语句代码"
@@ -65320,97 +65401,97 @@
 #. Result is processor-dependent. This processor just opts
 #. to not handle it at all.
 #. Result is processor-dependent.
-#: fortran/simplify.c:5520 fortran/simplify.c:5532
+#: fortran/simplify.c:5525 fortran/simplify.c:5537
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of MODULO at %L is zero"
 msgstr "%L处 MODULO 的第二个参数为 0"
 
-#: fortran/simplify.c:5552
+#: fortran/simplify.c:5557
 #, gcc-internal-format
 msgid "gfc_simplify_modulo(): Bad arguments"
 msgstr ""
 
-#: fortran/simplify.c:5600
+#: fortran/simplify.c:5605
 #, gcc-internal-format, gfc-internal-format
 msgid "Result of NEAREST is NaN at %L"
 msgstr "NEAREST 的结果在%L处为 NaN"
 
-#: fortran/simplify.c:6081
+#: fortran/simplify.c:6086
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument NCOPIES of REPEAT intrinsic is negative at %L"
 msgstr "%L处内建 REPEAT 的 NCOPIES 实参是负的"
 
-#: fortran/simplify.c:6137
+#: fortran/simplify.c:6142
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument NCOPIES of REPEAT intrinsic is too large at %L"
 msgstr "%L处内建 REPEAT 的 NCOPIES 实参太大"
 
-#: fortran/simplify.c:6174
+#: fortran/simplify.c:6179
 #, gcc-internal-format, gfc-internal-format
 msgid "Evaluation of string longer than 2**28 at %L deferred to runtime, expect bugs"
 msgstr ""
 
-#: fortran/simplify.c:6302
+#: fortran/simplify.c:6307
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Reshaped array too large at %C"
 msgstr "%C处整数太大"
 
-#: fortran/simplify.c:6416
+#: fortran/simplify.c:6421
 #, gcc-internal-format, gfc-internal-format
 msgid "Result of SCALE overflows its kind at %L"
 msgstr "%L处 SCALE 的结果上溢其种别"
 
-#: fortran/simplify.c:6995
+#: fortran/simplify.c:7000
 #, fuzzy, gcc-internal-format
 msgid "Bad type in gfc_simplify_sign"
 msgstr "常量表达式中类型错误"
 
-#: fortran/simplify.c:7024
+#: fortran/simplify.c:7029
 #, gcc-internal-format
 msgid "in gfc_simplify_sin(): Bad type"
 msgstr ""
 
-#: fortran/simplify.c:7151 fortran/simplify.c:7431
+#: fortran/simplify.c:7156 fortran/simplify.c:7436
 #, gcc-internal-format
 msgid "Failure getting length of a constant array."
 msgstr ""
 
-#: fortran/simplify.c:7161
+#: fortran/simplify.c:7166
 #, fuzzy, gcc-internal-format
 msgid "The number of elements (%d) in the array constructor at %L requires an increase of the allowed %d upper limit.  See %<-fmax-array-constructor%> option."
 msgstr "%L处数组构造函数中的元素数超过容许的上限 %d。请参见 -fmax-array-constructor 选项"
 
-#: fortran/simplify.c:7227
+#: fortran/simplify.c:7232
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Simplification of SPREAD at %C not yet implemented"
 msgstr "尚未描述"
 
-#: fortran/simplify.c:7251
+#: fortran/simplify.c:7256
 #, gcc-internal-format, gfc-internal-format
 msgid "Argument of SQRT at %L has a negative value"
 msgstr "%L处 SQRT 的参数为负"
 
-#: fortran/simplify.c:7267
+#: fortran/simplify.c:7272
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid argument of SQRT at %L"
 msgstr "%L处 SQRT 的参数为负"
 
-#: fortran/simplify.c:7598
+#: fortran/simplify.c:7603
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY lower bound is %ld)"
 msgstr "发信匣的边界在中 IMAGE_INDEX 于 %L 用于尺寸 %d，子有 %ld 和 COARRAY 下限是 %ld)"
 
-#: fortran/simplify.c:7621
+#: fortran/simplify.c:7626
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Out of bounds in IMAGE_INDEX at %L for dimension %d, SUB has %ld and COARRAY upper bound is %ld)"
 msgstr "发信匣的边界在中 IMAGE_INDEX 于 %L 用于尺寸 %d，子有 %ld 和 COARRAY 上限是 %ld)"
 
-#: fortran/simplify.c:7993
+#: fortran/simplify.c:7998
 #, fuzzy, gcc-internal-format
 msgid "gfc_convert_constant(): Unexpected type"
 msgstr "gfc_conv_constant_to_tree()：无效类型；%s"
 
-#: fortran/simplify.c:8078
+#: fortran/simplify.c:8083
 #, fuzzy, gcc-internal-format
 msgid "Character %qs in string at %L cannot be converted into character kind %d"
 msgstr "%2$L处字符串中的字符‘%1$s’不能被转换到字符种别 %3$d"
@@ -65514,7 +65595,7 @@
 msgid "BIND(C) applied to %s %s at %L"
 msgstr "BIND(C) 应用于%3$L处的 %1$s %2$s"
 
-#: fortran/symbol.c:901 fortran/symbol.c:912 fortran/symbol.c:1762
+#: fortran/symbol.c:901 fortran/symbol.c:912 fortran/symbol.c:1776
 #, gcc-internal-format, gfc-internal-format
 msgid "%s attribute conflicts with %s attribute at %L"
 msgstr "%s 属性与 %s 属性在%L处冲突"
@@ -65590,17 +65671,23 @@
 msgid "Duplicate VOLATILE attribute specified at %L"
 msgstr "%L处指定了重复的 VOLATILE 属性"
 
-#: fortran/symbol.c:1367
+#: fortran/symbol.c:1360
+#, fuzzy, gcc-internal-format, gfc-internal-format
+#| msgid "SAVE attribute at %L cannot be specified in a PURE procedure"
+msgid "VOLATILE attribute at %L cannot be specified in a PURE procedure"
+msgstr "%L处 PURE 过程不能指定 SAVE 属性"
+
+#: fortran/symbol.c:1381
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate ASYNCHRONOUS attribute specified at %L"
 msgstr "%L处指定了重复的 ASYNCHRONOUS 属性"
 
-#: fortran/symbol.c:1758
+#: fortran/symbol.c:1772
 #, fuzzy, gcc-internal-format
 msgid "%s attribute of %qs conflicts with %s attribute at %L"
 msgstr "%s 属性与 %s 属性在%L处冲突"
 
-#: fortran/symbol.c:1794
+#: fortran/symbol.c:1808
 #, gcc-internal-format, gfc-internal-format
 msgid ""
 "%s procedure at %L is already declared as %s procedure. \n"
@@ -65607,212 +65694,212 @@
 "F2008: A pointer function assignment is ambiguous if it is the first executable statement after the specification block. Please add any other kind of executable statement before it. FIXME"
 msgstr ""
 
-#: fortran/symbol.c:1802
+#: fortran/symbol.c:1816
 #, gcc-internal-format, gfc-internal-format
 msgid "%s procedure at %L is already declared as %s procedure"
 msgstr "%2$L处的 %1$s 过程已经被声明为 %3$s 过程"
 
-#: fortran/symbol.c:1837
+#: fortran/symbol.c:1851
 #, gcc-internal-format, gfc-internal-format
 msgid "INTENT (%s) conflicts with INTENT(%s) at %L"
 msgstr "INTENT (%s) 与 INTENT(%s) 在 %L 冲突"
 
-#: fortran/symbol.c:1861
+#: fortran/symbol.c:1875
 #, gcc-internal-format, gfc-internal-format
 msgid "ACCESS specification at %L was already specified"
 msgstr "%L处的 ACCESS 规格已经被指定"
 
-#: fortran/symbol.c:1878
+#: fortran/symbol.c:1892
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate BIND attribute specified at %L"
 msgstr "%L处指定了重复的 BIND 属性"
 
-#: fortran/symbol.c:1885
+#: fortran/symbol.c:1899
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BIND(C) at %L"
 msgstr "%L处指定了重复的 BIND 属性"
 
-#: fortran/symbol.c:1901
+#: fortran/symbol.c:1915
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate EXTENDS attribute specified at %L"
 msgstr "%L处指定了重复的 EXTENDS 属性"
 
-#: fortran/symbol.c:1905
+#: fortran/symbol.c:1919
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "EXTENDS at %L"
 msgstr "Fortran 2003：%L处的 EXTENDS"
 
-#: fortran/symbol.c:1931
+#: fortran/symbol.c:1945
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L already has an explicit interface"
 msgstr "符号‘%s’在%L处已经有了显式接口"
 
-#: fortran/symbol.c:1938
+#: fortran/symbol.c:1952
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L has attributes specified outside its INTERFACE body"
 msgstr "%2$L处的‘%1$s’有在其 INTERFACE 体外指定的属性"
 
-#: fortran/symbol.c:1976
+#: fortran/symbol.c:1990
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L conflicts with symbol from module %qs, use-associated at %L"
 msgstr "符号‘%s’于 %L 冲突与符号从模块‘%s’，use-associated 于 %L"
 
-#: fortran/symbol.c:1980
+#: fortran/symbol.c:1994
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L already has basic type of %s"
 msgstr "符号‘%s’在%L处已经有了基本类型 %s"
 
-#: fortran/symbol.c:1987
+#: fortran/symbol.c:2001
 #, fuzzy, gcc-internal-format
 msgid "Procedure %qs at %L may not have basic type of %s"
 msgstr "%2$L处过程‘%1$s’不能有基本类型 %3$s"
 
-#: fortran/symbol.c:1999
+#: fortran/symbol.c:2013
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %L cannot have a type"
 msgstr "%2$L处的符号‘%1$s’不能有类型"
 
-#: fortran/symbol.c:2242
+#: fortran/symbol.c:2256
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C already in the parent type at %L"
 msgid "Component %qs at %C already in the parent type at %L"
 msgstr "%2$C处的组件‘%1$s’已在%3$L处的父类中"
 
-#: fortran/symbol.c:2327
+#: fortran/symbol.c:2341
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C is ambiguous"
 msgstr "%C处 TYPE 定义中的歧义符号"
 
-#: fortran/symbol.c:2359
+#: fortran/symbol.c:2373
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %C is being used before it is defined"
 msgstr "%2$C处的派生类型‘%1$s’在定义前使用"
 
-#: fortran/symbol.c:2508
+#: fortran/symbol.c:2522
 #, fuzzy, gcc-internal-format
 msgid "Component %qs at %C is a PRIVATE component of %qs"
 msgstr "组件‘%s’在%C处是‘%s’的 PRIVATE 组件"
 
-#: fortran/symbol.c:2529
+#: fortran/symbol.c:2543
 #, fuzzy, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure; did you mean %qs?"
 msgstr "为结构字段%2$qE指定了%1$qs"
 
-#: fortran/symbol.c:2533
+#: fortran/symbol.c:2547
 #, fuzzy, gcc-internal-format
 msgid "%qs at %C is not a member of the %qs structure"
 msgstr "为结构字段%2$qE指定了%1$qs"
 
-#: fortran/symbol.c:2697
+#: fortran/symbol.c:2711
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate statement label %d at %L and %L"
 msgstr "重复的语句标号 %d 出现在 %L 和%L处"
 
-#: fortran/symbol.c:2708
+#: fortran/symbol.c:2722
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as branch target"
 msgstr "%2$C处的标号 %1$d 已作为分支目标引用"
 
-#: fortran/symbol.c:2718
+#: fortran/symbol.c:2732
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C already referenced as a format label"
 msgstr "%2$C处的标号 %1$d 已作为格式标号引用"
 
-#: fortran/symbol.c:2724
+#: fortran/symbol.c:2738
 #, gcc-internal-format, gfc-internal-format
 msgid "DO termination statement which is not END DO or CONTINUE with label %d at %C"
 msgstr ""
 
-#: fortran/symbol.c:2766
+#: fortran/symbol.c:2780
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as a FORMAT label"
 msgstr "%2$C处的标号 %1$d 先前用作 FORMAT 标号"
 
-#: fortran/symbol.c:2775
+#: fortran/symbol.c:2789
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %C previously used as branch target"
 msgstr "%2$C处的标号 %1$d 先前用作分支目标"
 
-#: fortran/symbol.c:2781
+#: fortran/symbol.c:2795
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Shared DO termination label %d at %C"
 msgstr "%C处需要结束名"
 
-#: fortran/symbol.c:3110
+#: fortran/symbol.c:3124
 #, fuzzy, gcc-internal-format
 msgid "new_symbol(): Symbol name too long"
 msgstr "%s:%d: 缺少新的符号名称"
 
-#: fortran/symbol.c:3135
+#: fortran/symbol.c:3149
 #, fuzzy, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from module %qs"
 msgstr "%2$C处的名字‘%1$s’是从模块‘%4$s’对‘%3$s’有歧义的引用"
 
-#: fortran/symbol.c:3138
+#: fortran/symbol.c:3152
 #, fuzzy, gcc-internal-format
 msgid "Name %qs at %C is an ambiguous reference to %qs from current program unit"
 msgstr "%2$C处的名字‘%1$s’是从当前程序单元对‘%3$s’有歧义的引用"
 
 #. Symbol is from another namespace.
-#: fortran/symbol.c:3381
+#: fortran/symbol.c:3395
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C has already been host associated"
 msgstr "%2$C处符号‘%1$s’已经与主机相关联"
 
-#: fortran/symbol.c:4397
+#: fortran/symbol.c:4411
 #, gcc-internal-format
 msgid "verify_bind_c_derived_type(): Given symbol is unexpectedly NULL"
 msgstr ""
 
-#: fortran/symbol.c:4410
+#: fortran/symbol.c:4424
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs declared at %L must have the BIND attribute to be C interoperable"
 msgstr "%2$L处声明的派生类型‘%1$s’必须使用 BIND 属性方可与 C 互操作"
 
-#: fortran/symbol.c:4428
+#: fortran/symbol.c:4442
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs with BIND(C) attribute at %L is empty, and may be inaccessible by the C companion processor"
 msgstr "衍生类型‘%s’与绑定©属性于 %L 是空的，而也许会是不可访问由 C companion 处理器"
 
-#: fortran/symbol.c:4449
+#: fortran/symbol.c:4463
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type '%s' at %L"
 msgid "Component %qs at %L cannot have the POINTER attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr "%2$L处的组件‘%1$s’不能有 POINTER 属性，因为它是%4$L处派生类型 BIND(C)‘%3$s’的成员"
 
-#: fortran/symbol.c:4459
+#: fortran/symbol.c:4473
 #, fuzzy, gcc-internal-format
 #| msgid "Procedure pointer component '%s' at %L cannot be a member of the BIND(C) derived type '%s' at %L"
 msgid "Procedure pointer component %qs at %L cannot be a member of the BIND(C) derived type %qs at %L"
 msgstr "%2$L 处的过程指针组件‘%1$s’不能是%4$L处 BIND(C) 派生类型‘%3$s’的成员"
 
-#: fortran/symbol.c:4470
+#: fortran/symbol.c:4484
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type '%s' at %L"
 msgid "Component %qs at %L cannot have the ALLOCATABLE attribute because it is a member of the BIND(C) derived type %qs at %L"
 msgstr "%2$L处的组件‘%1$s’不能有 ALLOCATABLE 属性，因为它是%4$L处派生类型 BIND(C)‘%3$s’的成员"
 
-#: fortran/symbol.c:4509
+#: fortran/symbol.c:4523
 #, fuzzy, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable, even though derived type %qs is BIND(C)"
 msgstr "%3$L处的派生类型‘%2$s’的组件‘%1$s’不能与 C 互操作，即使派生类型‘%4$s’是 BIND(C)"
 
-#: fortran/symbol.c:4519
+#: fortran/symbol.c:4533
 #, fuzzy, gcc-internal-format
 msgid "Component %qs in derived type %qs at %L may not be C interoperable"
 msgstr "%3$L处派生类型‘%2$s’中的组件‘%1$s’不能与 C 互操作"
 
-#: fortran/symbol.c:4533
+#: fortran/symbol.c:4547
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L cannot be declared with both PRIVATE and BIND(C) attributes"
 msgstr "%2$L处派生类型‘%1$s’不能同时被声明为具有 PRIVATE 和 BIND(C)属性"
 
-#: fortran/symbol.c:4541
+#: fortran/symbol.c:4555
 #, fuzzy, gcc-internal-format
 msgid "Derived type %qs at %L cannot have the SEQUENCE attribute because it is BIND(C)"
 msgstr "%2$L处派生类型‘%1$s’不能有 SEQUENCE 属性，因为它是 BIND(C)"
 
-#: fortran/symbol.c:5018 fortran/symbol.c:5023
+#: fortran/symbol.c:5032 fortran/symbol.c:5037
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs is used before it is typed at %L"
 msgstr "%2$L处符号‘%1$s’在指定类型之前被使用"
@@ -65860,7 +65947,7 @@
 msgid "Creating array temporary at %L for argument %qs"
 msgstr "在%L处建立临时数组"
 
-#: fortran/trans-array.c:10693
+#: fortran/trans-array.c:10724
 #, gcc-internal-format, gfc-internal-format
 msgid "bad expression type during walk (%d)"
 msgstr "走过错误的表达式类型(%d)"
@@ -66064,12 +66151,12 @@
 msgid "%<dim%> argument of %s intrinsic at %L is not a valid dimension index"
 msgstr "%2$L处‘%1$s’内建函数的‘dim’实参不是一个有效的维数索引"
 
-#: fortran/trans-intrinsic.c:10572 fortran/trans-stmt.c:1050
+#: fortran/trans-intrinsic.c:10574 fortran/trans-stmt.c:1050
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Sorry, the event component of derived type at %L is not yet supported"
 msgstr "%L处指针赋值时参数种别类型不同"
 
-#: fortran/trans-intrinsic.c:10579
+#: fortran/trans-intrinsic.c:10581
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The event variable at %L shall not be coindexed"
 msgstr "外部对象‘%s’在%L处不能有初始值设定"
@@ -66110,7 +66197,7 @@
 msgid "Sorry, only support for integer kind %d implemented for image-set at %L"
 msgstr "抱歉，只有支持用于整数 kind %d 实现的用于 image-set 于 %L"
 
-#: fortran/trans-stmt.c:3346
+#: fortran/trans-stmt.c:3343
 #, fuzzy, gcc-internal-format
 msgid "gfc_trans_select(): Bad type for case expr."
 msgstr "gfc_trans_code()：错误的语句代码"
@@ -66237,7 +66324,7 @@
 msgid "two or more sections for %s"
 msgstr "两个文件在同一列中：%s\n"
 
-#: lto/lto-partition.c:516
+#: lto/lto-partition.c:570
 #, gcc-internal-format
 msgid "min partition size cannot be greater than max partition size"
 msgstr ""
@@ -66373,58 +66460,58 @@
 msgid "Cannot read %s"
 msgstr "无法读取 %s"
 
-#: lto/lto.c:2369
+#: lto/lto.c:2337
 #, gcc-internal-format
 msgid "lto_obj_file_open() failed"
 msgstr "lto_obj_file_open() 失败"
 
-#: lto/lto.c:2394
+#: lto/lto.c:2362
 #, gcc-internal-format
 msgid "waitpid failed"
 msgstr "waitpid 失败"
 
-#: lto/lto.c:2397
+#: lto/lto.c:2365
 #, fuzzy, gcc-internal-format
 msgid "streaming subprocess failed"
 msgstr "%s 子进程失败"
 
-#: lto/lto.c:2400
+#: lto/lto.c:2368
 #, fuzzy, gcc-internal-format
 msgid "streaming subprocess was killed by signal"
 msgstr "子进程收到致命信号 %d"
 
-#: lto/lto.c:2476
+#: lto/lto.c:2445
 #, fuzzy, gcc-internal-format
 msgid "no LTRANS output list filename provided"
 msgstr "打开 LTRANS 输出列表 %s：%m"
 
-#: lto/lto.c:2564
+#: lto/lto.c:2525
 #, gcc-internal-format
 msgid "opening LTRANS output list %s: %m"
 msgstr "打开 LTRANS 输出列表 %s：%m"
 
-#: lto/lto.c:2570
+#: lto/lto.c:2532
 #, gcc-internal-format
 msgid "writing to LTRANS output list %s: %m"
 msgstr "写入 LTRANS 输出列表 %s：%m"
 
-#: lto/lto.c:2581
+#: lto/lto.c:2542
 #, gcc-internal-format
 msgid "closing LTRANS output list %s: %m"
 msgstr "关闭 LTRANS 输出列表 %s：%m"
 
-#: lto/lto.c:2833
+#: lto/lto.c:2794
 #, fuzzy, gcc-internal-format
 msgid "could not open symbol resolution file: %m"
 msgstr "无法打开符号解析文件：%s"
 
-#: lto/lto.c:2954
+#: lto/lto.c:2915
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "missing braces around initializer for %qT"
 msgid "missing resolution data for %s"
 msgstr "%qT的初始值设定周围缺少花括号"
 
-#: lto/lto.c:2986
+#: lto/lto.c:2947
 #, fuzzy, gcc-internal-format
 msgid "errors during merging of translation units"
 msgstr "错误在的期间合并的转译单位"
@@ -67937,6 +68024,9 @@
 #~ msgid "Enable coverage-guided fuzzing code instrumentation."
 #~ msgstr "启用用户自定义指令"
 
+#~ msgid "Warn if the loop cannot be optimized due to nontrivial assumptions."
+#~ msgstr "当循环因为不平凡的假定而不能被优化时给出警告"
+
 #, fuzzy
 #~| msgid "Perform DWARF2 duplicate elimination"
 #~ msgid "Perform DWARF duplicate elimination."
@@ -68998,6 +69088,9 @@
 #~ msgid "Pointer initialization target at %L must not be ALLOCATABLE "
 #~ msgstr "%L处的分配对象必须是 ALLOCATABLE 或 POINTER"
 
+#~ msgid "Errmsg-variable at %L must be a scalar CHARACTER variable"
+#~ msgstr "%L处错误信息变量必须是一个标量 CHARACTER 变量"
+
 #, fuzzy
 #~ msgid "Assignment to an allocatable polymorphic variable at %L is not yet supported"
 #~ msgstr "不能在%2$C处的 PURE 过程中读取变量‘%1$s’"
Index: gcc/tree-vect-stmts.c
===================================================================
--- gcc/tree-vect-stmts.c	(.../tags/gcc_8_2_0_release)
+++ gcc/tree-vect-stmts.c	(.../branches/gcc-8-branch)
@@ -3745,7 +3745,7 @@
 	dump_printf_loc (MSG_MISSED_OPTIMIZATION, vect_location,
 			 "not considering SIMD clones; not yet supported"
 			 " for variable-width vectors.\n");
-      return NULL;
+      return false;
     }
 
   unsigned int badness = 0;
@@ -9602,7 +9602,7 @@
       if (gimple_code (stmt) == GIMPLE_PHI)
         scalar_dest = PHI_RESULT (stmt);
       else
-        scalar_dest = gimple_assign_lhs (stmt);
+        scalar_dest = gimple_get_lhs (stmt);
 
       FOR_EACH_IMM_USE_FAST (use_p, imm_iter, scalar_dest)
        {
Index: gcc/tree-inline.c
===================================================================
--- gcc/tree-inline.c	(.../tags/gcc_8_2_0_release)
+++ gcc/tree-inline.c	(.../branches/gcc-8-branch)
@@ -1961,8 +1961,7 @@
 		   && id->call_stmt
 		   && (decl = gimple_call_fndecl (stmt))
 		   && DECL_BUILT_IN_CLASS (decl) == BUILT_IN_NORMAL
-		   && DECL_FUNCTION_CODE (decl) == BUILT_IN_VA_ARG_PACK_LEN
-		   && ! gimple_call_va_arg_pack_p (id->call_stmt))
+		   && DECL_FUNCTION_CODE (decl) == BUILT_IN_VA_ARG_PACK_LEN)
 	    {
 	      /* __builtin_va_arg_pack_len () should be replaced by
 		 the number of anonymous arguments.  */
@@ -1980,10 +1979,28 @@
 		if (POINTER_BOUNDS_P (gimple_call_arg (id->call_stmt, i)))
 		  nargs--;
 
-	      count = build_int_cst (integer_type_node, nargs);
-	      new_stmt = gimple_build_assign (gimple_call_lhs (stmt), count);
-	      gsi_replace (&copy_gsi, new_stmt, false);
-	      stmt = new_stmt;
+	      if (!gimple_call_lhs (stmt))
+		{
+		  /* Drop unused calls.  */
+		  gsi_remove (&copy_gsi, false);
+		  continue;
+		}
+	      else if (!gimple_call_va_arg_pack_p (id->call_stmt))
+		{
+		  count = build_int_cst (integer_type_node, nargs);
+		  new_stmt = gimple_build_assign (gimple_call_lhs (stmt), count);
+		  gsi_replace (&copy_gsi, new_stmt, false);
+		  stmt = new_stmt;
+		}
+	      else if (nargs != 0)
+		{
+		  tree newlhs = create_tmp_reg_or_ssa_name (integer_type_node);
+		  count = build_int_cst (integer_type_node, nargs);
+		  new_stmt = gimple_build_assign (gimple_call_lhs (stmt),
+						  PLUS_EXPR, newlhs, count);
+		  gimple_call_set_lhs (stmt, newlhs);
+		  gsi_insert_after (&copy_gsi, new_stmt, GSI_NEW_STMT);
+		}
 	    }
 	  else if (call_stmt
 		   && id->call_stmt
Index: gcc/gimple-loop-jam.c
===================================================================
--- gcc/gimple-loop-jam.c	(.../tags/gcc_8_2_0_release)
+++ gcc/gimple-loop-jam.c	(.../branches/gcc-8-branch)
@@ -161,7 +161,7 @@
   gimple_stmt_iterator gsi;
   /* BB is duplicated by outer unrolling and then all N-1 first copies
      move into the body of the fused inner loop.  If BB exits the outer loop
-     the last copy still doess so, and the first N-1 copies are cancelled
+     the last copy still does so, and the first N-1 copies are cancelled
      by loop unrolling, so also after fusion it's the exit block.
      But there might be other reasons that prevent fusion:
        * stores or unknown side-effects prevent fusion
@@ -227,6 +227,33 @@
       || !expr_invariant_in_loop_p (outer, niter.niter))
     return false;
 
+  /* If the inner loop produces any values that are used inside the
+     outer loop (except the virtual op) then it can flow
+     back (perhaps indirectly) into the inner loop.  This prevents
+     fusion: without fusion the value at the last iteration is used,
+     with fusion the value after the initial iteration is used.
+
+     If all uses are outside the outer loop this doesn't prevent fusion;
+     the value of the last iteration is still used (and the values from
+     all intermediate iterations are dead).  */
+  gphi_iterator psi;
+  for (psi = gsi_start_phis (single_exit (loop)->dest);
+       !gsi_end_p (psi); gsi_next (&psi))
+    {
+      imm_use_iterator imm_iter;
+      use_operand_p use_p;
+      tree op = gimple_phi_result (psi.phi ());
+      if (virtual_operand_p (op))
+	continue;
+      FOR_EACH_IMM_USE_FAST (use_p, imm_iter, op)
+	{
+	  gimple *use_stmt = USE_STMT (use_p);
+	  if (!is_gimple_debug (use_stmt)
+	      && flow_bb_inside_loop_p (outer, gimple_bb (use_stmt)))
+	    return false;
+	}
+    }
+
   /* And check blocks belonging to just outer loop.  */
   bbs = XNEWVEC (basic_block, n_basic_blocks_for_fn (cfun));
   n = get_loop_body_with_size (outer, bbs, n_basic_blocks_for_fn (cfun));
@@ -245,7 +272,6 @@
      body would be the after-iter value of the first body) if it's over
      an associative and commutative operation.  We wouldn't
      be able to handle unknown cycles.  */
-  gphi_iterator psi;
   for (psi = gsi_start_phis (loop->header); !gsi_end_p (psi); gsi_next (&psi))
     {
       affine_iv iv;
Index: gcc/combine.c
===================================================================
--- gcc/combine.c	(.../tags/gcc_8_2_0_release)
+++ gcc/combine.c	(.../branches/gcc-8-branch)
@@ -4007,8 +4007,11 @@
      other insns to combine, but the destination of that SET is still live.
 
      Also do this if we started with two insns and (at least) one of the
-     resulting sets is a noop; this noop will be deleted later.  */
+     resulting sets is a noop; this noop will be deleted later.
 
+     Also do this if we started with two insns neither of which was a simple
+     move.  */
+
   else if (insn_code_number < 0 && asm_noperands (newpat) < 0
 	   && GET_CODE (newpat) == PARALLEL
 	   && XVECLEN (newpat, 0) == 2
@@ -4035,7 +4038,8 @@
 	 one which uses any regs/memory set in between i2 and i3 can't
 	 be first.  The PARALLEL might also have been pre-existing in i3,
 	 so we need to make sure that we won't wrongly hoist a SET to i2
-	 that would conflict with a death note present in there.  */
+	 that would conflict with a death note present in there, or would
+	 have its dest modified between i2 and i3.  */
       if (!modified_between_p (SET_SRC (set1), i2, i3)
 	  && !(REG_P (SET_DEST (set1))
 	       && find_reg_note (i2, REG_DEAD, SET_DEST (set1)))
@@ -4042,6 +4046,7 @@
 	  && !(GET_CODE (SET_DEST (set1)) == SUBREG
 	       && find_reg_note (i2, REG_DEAD,
 				 SUBREG_REG (SET_DEST (set1))))
+	  && !modified_between_p (SET_DEST (set1), i2, i3)
 	  && (!HAVE_cc0 || !reg_referenced_p (cc0_rtx, set0))
 	  /* If I3 is a jump, ensure that set0 is a jump so that
 	     we do not create invalid RTL.  */
@@ -4057,6 +4062,7 @@
 	       && !(GET_CODE (SET_DEST (set0)) == SUBREG
 		    && find_reg_note (i2, REG_DEAD,
 				      SUBREG_REG (SET_DEST (set0))))
+	       && !modified_between_p (SET_DEST (set0), i2, i3)
 	       && (!HAVE_cc0 || !reg_referenced_p (cc0_rtx, set1))
 	       /* If I3 is a jump, ensure that set1 is a jump so that
 		  we do not create invalid RTL.  */
@@ -6455,7 +6461,7 @@
 			  pc_rtx, pc_rtx, 0, 0, 0);
       if (reg_mentioned_p (from, false_rtx))
 	false_rtx = subst (known_cond (copy_rtx (false_rtx), false_code,
-				   from, false_val),
+				       from, false_val),
 			   pc_rtx, pc_rtx, 0, 0, 0);
 
       SUBST (XEXP (x, 1), swapped ? false_rtx : true_rtx);
@@ -9294,6 +9300,7 @@
 
 	  if (COMPARISON_P (cond0)
 	      && COMPARISON_P (cond1)
+	      && SCALAR_INT_MODE_P (mode)
 	      && ((GET_CODE (cond0) == reversed_comparison_code (cond1, NULL)
 		   && rtx_equal_p (XEXP (cond0, 0), XEXP (cond1, 0))
 		   && rtx_equal_p (XEXP (cond0, 1), XEXP (cond1, 1)))
@@ -9474,12 +9481,12 @@
 	  if (COMPARISON_P (x))
 	    {
 	      if (comparison_dominates_p (cond, code))
-		return const_true_rtx;
+		return VECTOR_MODE_P (GET_MODE (x)) ? x : const_true_rtx;
 
 	      code = reversed_comparison_code (x, NULL);
 	      if (code != UNKNOWN
 		  && comparison_dominates_p (cond, code))
-		return const0_rtx;
+		return CONST0_RTX (GET_MODE (x));
 	      else
 		return x;
 	    }
@@ -9522,7 +9529,7 @@
 	  /* We must simplify subreg here, before we lose track of the
 	     original inner_mode.  */
 	  new_rtx = simplify_subreg (GET_MODE (x), r,
-				 inner_mode, SUBREG_BYTE (x));
+				     inner_mode, SUBREG_BYTE (x));
 	  if (new_rtx)
 	    return new_rtx;
 	  else
@@ -9547,7 +9554,7 @@
 	  /* We must simplify the zero_extend here, before we lose
 	     track of the original inner_mode.  */
 	  new_rtx = simplify_unary_operation (ZERO_EXTEND, GET_MODE (x),
-					  r, inner_mode);
+					      r, inner_mode);
 	  if (new_rtx)
 	    return new_rtx;
 	  else
Index: gcc/tree-core.h
===================================================================
--- gcc/tree-core.h	(.../tags/gcc_8_2_0_release)
+++ gcc/tree-core.h	(.../branches/gcc-8-branch)
@@ -1796,8 +1796,8 @@
   unsigned pure_flag : 1;
   unsigned looping_const_or_pure_flag : 1;
   unsigned has_debug_args_flag : 1;
-  unsigned tm_clone_flag : 1;
   unsigned versioned_function : 1;
+  unsigned lambda_function: 1;
   /* No bits left.  */
 };
 
Index: gcc/tree-cfg.c
===================================================================
--- gcc/tree-cfg.c	(.../tags/gcc_8_2_0_release)
+++ gcc/tree-cfg.c	(.../branches/gcc-8-branch)
@@ -9297,20 +9297,16 @@
   tree type = TREE_TYPE (index);
   tree utype = unsigned_type_for (type);
 
-  low = fold_convert (type, low);
-  high = fold_convert (type, high);
+  low = fold_convert (utype, low);
+  high = fold_convert (utype, high);
 
-  tree tmp = make_ssa_name (type);
-  gassign *sub1
-    = gimple_build_assign (tmp, MINUS_EXPR, index, low);
+  gimple_seq seq = NULL;
+  index = gimple_convert (&seq, utype, index);
+  *lhs = gimple_build (&seq, MINUS_EXPR, utype, index, low);
+  *rhs = const_binop (MINUS_EXPR, utype, high, low);
 
-  *lhs = make_ssa_name (utype);
-  gassign *a = gimple_build_assign (*lhs, NOP_EXPR, tmp);
-
-  *rhs = fold_build2 (MINUS_EXPR, utype, high, low);
   gimple_stmt_iterator gsi = gsi_last_bb (bb);
-  gsi_insert_before (&gsi, sub1, GSI_SAME_STMT);
-  gsi_insert_before (&gsi, a, GSI_SAME_STMT);
+  gsi_insert_seq_before (&gsi, seq, GSI_SAME_STMT);
 }
 
 /* Emit return warnings.  */
Index: gcc/config/s390/s390.md
===================================================================
--- gcc/config/s390/s390.md	(.../tags/gcc_8_2_0_release)
+++ gcc/config/s390/s390.md	(.../branches/gcc-8-branch)
@@ -405,6 +405,10 @@
    ; Bitposition of operand types
    (PFPO_OP0_TYPE_SHIFT          16)
    (PFPO_OP1_TYPE_SHIFT           8)
+   ; Decide whether current DFP or BFD rounding mode should be used
+   ; for the conversion.
+   (PFPO_RND_MODE_DFP             0)
+   (PFPO_RND_MODE_BFP             1)
   ])
 
 ; Immediate operands for tbegin and tbeginc
@@ -5378,9 +5382,13 @@
 {
   HOST_WIDE_INT flags;
 
+  /* According to IEEE 754 2008 4.3 'Rounding-direction attributes' the
+     rounding mode of the target format needs to be used.  */
+
   flags = (PFPO_CONVERT |
            PFPO_OP_TYPE_<DFP_ALL:MODE> << PFPO_OP0_TYPE_SHIFT |
-           PFPO_OP_TYPE_<BFP:MODE> << PFPO_OP1_TYPE_SHIFT);
+           PFPO_OP_TYPE_<BFP:MODE> << PFPO_OP1_TYPE_SHIFT |
+	   PFPO_RND_MODE_DFP);
 
   operands[2] = GEN_INT (flags);
 })
@@ -5400,9 +5408,13 @@
 {
   HOST_WIDE_INT flags;
 
+  /* According to IEEE 754 2008 4.3 'Rounding-direction attributes' the
+     rounding mode of the target format needs to be used.  */
+
   flags = (PFPO_CONVERT |
            PFPO_OP_TYPE_<BFP:MODE> << PFPO_OP0_TYPE_SHIFT |
-           PFPO_OP_TYPE_<DFP_ALL:MODE> << PFPO_OP1_TYPE_SHIFT);
+           PFPO_OP_TYPE_<DFP_ALL:MODE> << PFPO_OP1_TYPE_SHIFT |
+	   PFPO_RND_MODE_BFP);
 
   operands[2] = GEN_INT (flags);
 })
@@ -5443,9 +5455,13 @@
 {
   HOST_WIDE_INT flags;
 
+  /* According to IEEE 754 2008 4.3 'Rounding-direction attributes' the
+     rounding mode of the target format needs to be used.  */
+
   flags = (PFPO_CONVERT |
            PFPO_OP_TYPE_<DFP_ALL:MODE> << PFPO_OP0_TYPE_SHIFT |
-           PFPO_OP_TYPE_<BFP:MODE> << PFPO_OP1_TYPE_SHIFT);
+           PFPO_OP_TYPE_<BFP:MODE> << PFPO_OP1_TYPE_SHIFT |
+	   PFPO_RND_MODE_DFP);
 
   operands[2] = GEN_INT (flags);
 })
@@ -5465,9 +5481,13 @@
 {
   HOST_WIDE_INT flags;
 
+  /* According to IEEE 754 2008 4.3 'Rounding-direction attributes' the
+     rounding mode of the target format needs to be used.  */
+
   flags = (PFPO_CONVERT |
            PFPO_OP_TYPE_<BFP:MODE> << PFPO_OP0_TYPE_SHIFT |
-           PFPO_OP_TYPE_<DFP_ALL:MODE> << PFPO_OP1_TYPE_SHIFT);
+           PFPO_OP_TYPE_<DFP_ALL:MODE> << PFPO_OP1_TYPE_SHIFT |
+	   PFPO_RND_MODE_BFP);
 
   operands[2] = GEN_INT (flags);
 })
Index: gcc/config/i386/i386.h
===================================================================
--- gcc/config/i386/i386.h	(.../tags/gcc_8_2_0_release)
+++ gcc/config/i386/i386.h	(.../branches/gcc-8-branch)
@@ -1536,10 +1536,10 @@
 #define FIRST_FLOAT_REG FIRST_STACK_REG
 #define STACK_TOP_P(X) (REG_P (X) && REGNO (X) == FIRST_FLOAT_REG)
 
-#define SSE_REGNO(N) \
-  ((N) < 8 ? FIRST_SSE_REG + (N) \
-         : (N) <= LAST_REX_SSE_REG ? (FIRST_REX_SSE_REG + (N) - 8) \
-                                   : (FIRST_EXT_REX_SSE_REG + (N) - 16))
+#define GET_SSE_REGNO(N)			\
+  ((N) < 8 ? FIRST_SSE_REG + (N)		\
+   : (N) < 16 ? FIRST_REX_SSE_REG + (N) - 8	\
+   : FIRST_EXT_REX_SSE_REG + (N) - 16)
 
 /* The class value for index registers, and the one for base regs.  */
 
@@ -2635,6 +2635,9 @@
   /* Nonzero if the function places outgoing arguments on stack.  */
   BOOL_BITFIELD outgoing_args_on_stack : 1;
 
+  /* If true, ENDBR is queued at function entrance.  */
+  BOOL_BITFIELD endbr_queued_at_entrance : 1;
+
   /* The largest alignment, in bytes, of stack slot actually used.  */
   unsigned int max_used_stack_alignment;
 
Index: gcc/config/i386/i386.md
===================================================================
--- gcc/config/i386/i386.md	(.../tags/gcc_8_2_0_release)
+++ gcc/config/i386/i386.md	(.../branches/gcc-8-branch)
@@ -13345,7 +13345,10 @@
      stack address we wish to restore.  */
   tmp = gen_rtx_PLUS (Pmode, arg_pointer_rtx, sa);
   tmp = plus_constant (Pmode, tmp, -UNITS_PER_WORD);
-  tmp = gen_rtx_MEM (Pmode, tmp);
+  /* Return address is always in word_mode.  */
+  tmp = gen_rtx_MEM (word_mode, tmp);
+  if (GET_MODE (ra) != word_mode)
+    ra = convert_to_mode (word_mode, ra, 1);
   emit_move_insn (tmp, ra);
 
   emit_jump_insn (gen_eh_return_internal ());
Index: gcc/config/i386/djgpp.c
===================================================================
--- gcc/config/i386/djgpp.c	(.../tags/gcc_8_2_0_release)
+++ gcc/config/i386/djgpp.c	(.../branches/gcc-8-branch)
@@ -47,3 +47,20 @@
 
   fprintf (asm_out_file, "\t.section\t%s,\"%s\"\n", name, flagchars);
 }
+
+/* Kludge because of missing COFF support for early LTO debug.  */
+
+static enum debug_info_levels saved_debug_info_level;
+
+void
+i386_djgpp_asm_lto_start (void)
+{
+  saved_debug_info_level = debug_info_level;
+  debug_info_level = DINFO_LEVEL_NONE;
+}
+
+void
+i386_djgpp_asm_lto_end (void)
+{
+  debug_info_level = saved_debug_info_level;
+}
Index: gcc/config/i386/djgpp.h
===================================================================
--- gcc/config/i386/djgpp.h	(.../tags/gcc_8_2_0_release)
+++ gcc/config/i386/djgpp.h	(.../branches/gcc-8-branch)
@@ -160,8 +160,19 @@
 #undef MAKE_DECL_ONE_ONLY
 #define MAKE_DECL_ONE_ONLY(DECL) (DECL_WEAK (DECL) = 1)
 
+#undef TARGET_COFF
+#define TARGET_COFF 1
+
+/* Kludge because of missing COFF support for early LTO debug.  */
+#undef  TARGET_ASM_LTO_START
+#define TARGET_ASM_LTO_START i386_djgpp_asm_lto_start
+#undef  TARGET_ASM_LTO_END
+#define TARGET_ASM_LTO_END i386_djgpp_asm_lto_end
+
 /* Function protypes for gcc/i386/djgpp.c */
 
 void
 i386_djgpp_asm_named_section(const char *name, unsigned int flags,
 			     tree decl);
+void i386_djgpp_asm_lto_start (void);
+void i386_djgpp_asm_lto_end (void);
Index: gcc/config/i386/predicates.md
===================================================================
--- gcc/config/i386/predicates.md	(.../tags/gcc_8_2_0_release)
+++ gcc/config/i386/predicates.md	(.../branches/gcc-8-branch)
@@ -1517,7 +1517,7 @@
       if (GET_CODE (elt) != SET
 	  || GET_CODE (SET_DEST (elt)) != REG
 	  || GET_MODE (SET_DEST (elt)) != V8SImode
-	  || REGNO (SET_DEST (elt)) != SSE_REGNO (i)
+	  || REGNO (SET_DEST (elt)) != GET_SSE_REGNO (i)
 	  || SET_SRC (elt) != CONST0_RTX (V8SImode))
 	return false;
     }
Index: gcc/config/i386/gnu-user.h
===================================================================
--- gcc/config/i386/gnu-user.h	(.../tags/gcc_8_2_0_release)
+++ gcc/config/i386/gnu-user.h	(.../branches/gcc-8-branch)
@@ -67,7 +67,7 @@
 
 #undef  ASM_SPEC
 #define ASM_SPEC \
-  "--32 %{!mno-sse2avx:%{mavx:-msse2avx}} %{msse2avx:%{!mavx:-msse2avx}}"
+  "--32 %{msse2avx:%{!mavx:-msse2avx}}"
 
 #undef  SUBTARGET_EXTRA_SPECS
 #define SUBTARGET_EXTRA_SPECS \
Index: gcc/config/i386/sse.md
===================================================================
--- gcc/config/i386/sse.md	(.../tags/gcc_8_2_0_release)
+++ gcc/config/i386/sse.md	(.../branches/gcc-8-branch)
@@ -17475,7 +17475,7 @@
 
   for (regno = 0; regno < nregs; regno++)
     XVECEXP (operands[0], 0, regno + 1)
-      = gen_rtx_SET (gen_rtx_REG (V8SImode, SSE_REGNO (regno)),
+      = gen_rtx_SET (gen_rtx_REG (V8SImode, GET_SSE_REGNO (regno)),
 		     CONST0_RTX (V8SImode));
 })
 
Index: gcc/config/i386/gnu-user64.h
===================================================================
--- gcc/config/i386/gnu-user64.h	(.../tags/gcc_8_2_0_release)
+++ gcc/config/i386/gnu-user64.h	(.../branches/gcc-8-branch)
@@ -50,7 +50,7 @@
 #define ASM_SPEC "%{" SPEC_32 ":--32} \
  %{" SPEC_64 ":--64} \
  %{" SPEC_X32 ":--x32} \
- %{!mno-sse2avx:%{mavx:-msse2avx}} %{msse2avx:%{!mavx:-msse2avx}}"
+ %{msse2avx:%{!mavx:-msse2avx}}"
 
 #define GNU_USER_TARGET_LINK_SPEC				   \
                   "%{" SPEC_64 ":-m " GNU_USER_LINK_EMULATION64 "} \
Index: gcc/config/i386/avx512fintrin.h
===================================================================
--- gcc/config/i386/avx512fintrin.h	(.../tags/gcc_8_2_0_release)
+++ gcc/config/i386/avx512fintrin.h	(.../branches/gcc-8-branch)
@@ -3762,7 +3762,7 @@
     (__m512d)__builtin_ia32_vfmaddsubpd512_mask(A, B, C, -1, R)
 
 #define _mm512_mask_fmaddsub_round_pd(A, U, B, C, R)    \
-    (__m512d)__builtin_ia32_vfmaddpd512_mask(A, B, C, U, R)
+    (__m512d)__builtin_ia32_vfmaddsubpd512_mask(A, B, C, U, R)
 
 #define _mm512_mask3_fmaddsub_round_pd(A, B, C, U, R)   \
     (__m512d)__builtin_ia32_vfmaddsubpd512_mask3(A, B, C, U, R)
@@ -7727,7 +7727,7 @@
 
 extern __inline __m512d
 __attribute__ ((__gnu_inline__, __always_inline__, __artificial__))
-_mm512_abs_pd (__m512 __A)
+_mm512_abs_pd (__m512d __A)
 {
   return (__m512d) _mm512_and_epi64 ((__m512i) __A,
 				     _mm512_set1_epi64 (0x7fffffffffffffffLL));
@@ -7735,7 +7735,7 @@
 
 extern __inline __m512d
 __attribute__ ((__gnu_inline__, __always_inline__, __artificial__))
-_mm512_mask_abs_pd (__m512d __W, __mmask8 __U, __m512 __A)
+_mm512_mask_abs_pd (__m512d __W, __mmask8 __U, __m512d __A)
 {
   return (__m512d)
 	 _mm512_mask_and_epi64 ((__m512i) __W, __U, (__m512i) __A,
Index: gcc/config/i386/i386.c
===================================================================
--- gcc/config/i386/i386.c	(.../tags/gcc_8_2_0_release)
+++ gcc/config/i386/i386.c	(.../branches/gcc-8-branch)
@@ -2606,11 +2606,17 @@
 			 TYPE_ATTRIBUTES (TREE_TYPE (cfun->decl)))
       && !cgraph_node::get (cfun->decl)->only_called_directly_p ())
     {
-      cet_eb = gen_nop_endbr ();
+      /* Queue ENDBR insertion to x86_function_profiler.  */
+      if (crtl->profile && flag_fentry)
+	cfun->machine->endbr_queued_at_entrance = true;
+      else
+	{
+	  cet_eb = gen_nop_endbr ();
 
-      bb = ENTRY_BLOCK_PTR_FOR_FN (cfun)->next_bb;
-      insn = BB_HEAD (bb);
-      emit_insn_before (cet_eb, insn);
+	  bb = ENTRY_BLOCK_PTR_FOR_FN (cfun)->next_bb;
+	  insn = BB_HEAD (bb);
+	  emit_insn_before (cet_eb, insn);
+	}
     }
 
   bb = 0;
@@ -8193,7 +8199,7 @@
       case X86_64_SSEDF_CLASS:
 	if (mode != BLKmode)
 	  return gen_reg_or_parallel (mode, orig_mode,
-				      SSE_REGNO (sse_regno));
+				      GET_SSE_REGNO (sse_regno));
 	break;
       case X86_64_X87_CLASS:
       case X86_64_COMPLEX_X87_CLASS:
@@ -8209,7 +8215,7 @@
       && regclass[1] == X86_64_SSEUP_CLASS
       && mode != BLKmode)
     return gen_reg_or_parallel (mode, orig_mode,
-				SSE_REGNO (sse_regno));
+				GET_SSE_REGNO (sse_regno));
   if (n == 4
       && regclass[0] == X86_64_SSE_CLASS
       && regclass[1] == X86_64_SSEUP_CLASS
@@ -8217,7 +8223,7 @@
       && regclass[3] == X86_64_SSEUP_CLASS
       && mode != BLKmode)
     return gen_reg_or_parallel (mode, orig_mode,
-				SSE_REGNO (sse_regno));
+				GET_SSE_REGNO (sse_regno));
   if (n == 8
       && regclass[0] == X86_64_SSE_CLASS
       && regclass[1] == X86_64_SSEUP_CLASS
@@ -8229,7 +8235,7 @@
       && regclass[7] == X86_64_SSEUP_CLASS
       && mode != BLKmode)
     return gen_reg_or_parallel (mode, orig_mode,
-				SSE_REGNO (sse_regno));
+				GET_SSE_REGNO (sse_regno));
   if (n == 2
       && regclass[0] == X86_64_X87_CLASS
       && regclass[1] == X86_64_X87UP_CLASS)
@@ -8238,9 +8244,22 @@
   if (n == 2
       && regclass[0] == X86_64_INTEGER_CLASS
       && regclass[1] == X86_64_INTEGER_CLASS
-      && (mode == CDImode || mode == TImode)
+      && (mode == CDImode || mode == TImode || mode == BLKmode)
       && intreg[0] + 1 == intreg[1])
-    return gen_rtx_REG (mode, intreg[0]);
+    {
+      if (mode == BLKmode)
+	{
+	  /* Use TImode for BLKmode values in 2 integer registers.  */
+	  exp[0] = gen_rtx_EXPR_LIST (VOIDmode,
+				      gen_rtx_REG (TImode, intreg[0]),
+				      GEN_INT (0));
+	  ret = gen_rtx_PARALLEL (mode, rtvec_alloc (1));
+	  XVECEXP (ret, 0, 0) = exp[0];
+	  return ret;
+	}
+      else
+	return gen_rtx_REG (mode, intreg[0]);
+    }
 
   /* Otherwise figure out the entries of the PARALLEL.  */
   for (i = 0; i < n; i++)
@@ -8276,7 +8295,7 @@
 	    exp [nexps++]
 	      = gen_rtx_EXPR_LIST (VOIDmode,
 				   gen_rtx_REG (SFmode,
-						SSE_REGNO (sse_regno)),
+						GET_SSE_REGNO (sse_regno)),
 				   GEN_INT (i*8));
 	    sse_regno++;
 	    break;
@@ -8284,7 +8303,7 @@
 	    exp [nexps++]
 	      = gen_rtx_EXPR_LIST (VOIDmode,
 				   gen_rtx_REG (DFmode,
-						SSE_REGNO (sse_regno)),
+						GET_SSE_REGNO (sse_regno)),
 				   GEN_INT (i*8));
 	    sse_regno++;
 	    break;
@@ -8330,7 +8349,7 @@
 	    exp [nexps++]
 	      = gen_rtx_EXPR_LIST (VOIDmode,
 				   gen_rtx_REG (tmpmode,
-						SSE_REGNO (sse_regno)),
+						GET_SSE_REGNO (sse_regno)),
 				   GEN_INT (pos*8));
 	    sse_regno++;
 	    break;
@@ -9766,7 +9785,7 @@
 	  set_mem_alias_set (mem, set);
 	  set_mem_align (mem, GET_MODE_ALIGNMENT (smode));
 
-	  emit_move_insn (mem, gen_rtx_REG (smode, SSE_REGNO (i)));
+	  emit_move_insn (mem, gen_rtx_REG (smode, GET_SSE_REGNO (i)));
 	}
 
       emit_label (label);
@@ -13438,12 +13457,14 @@
 	  recompute_frame_layout_p = true;
 	}
     }
-  else if (crtl->max_used_stack_slot_alignment
-	   > crtl->preferred_stack_boundary)
+  else if (crtl->max_used_stack_slot_alignment >= 128)
     {
-      /* We don't need to realign stack.  But we still need to keep
-	 stack frame properly aligned to satisfy the largest alignment
-	 of stack slots.  */
+      /* We don't need to realign stack.  max_used_stack_alignment is
+	 used to decide how stack frame should be aligned.  This is
+	 independent of any psABIs nor 32-bit vs 64-bit.  It is always
+	 safe to compute max_used_stack_alignment.  We compute it only
+	 if 128-bit aligned load/store may be generated on misaligned
+	 stack slot which will lead to segfault.   */
       if (ix86_find_max_used_stack_alignment (stack_alignment, true))
 	cfun->machine->max_used_stack_alignment
 	  = stack_alignment / BITS_PER_UNIT;
@@ -41972,6 +41993,10 @@
 {
   const char *mcount_name = (flag_fentry ? MCOUNT_NAME_BEFORE_PROLOGUE
 					 : MCOUNT_NAME);
+
+  if (cfun->machine->endbr_queued_at_entrance)
+    fprintf (file, "\t%s\n", TARGET_64BIT ? "endbr64" : "endbr32");
+
   if (TARGET_64BIT)
     {
 #ifndef NO_PROFILE_COUNTERS
Index: gcc/config/xtensa/xtensa.c
===================================================================
--- gcc/config/xtensa/xtensa.c	(.../tags/gcc_8_2_0_release)
+++ gcc/config/xtensa/xtensa.c	(.../branches/gcc-8-branch)
@@ -1614,9 +1614,9 @@
       break;
 
     case MULT: /* NAND */
-      tmp = expand_simple_binop (SImode, XOR, old, ac.modemask,
+      tmp = expand_simple_binop (SImode, AND, old, val,
 				 NULL_RTX, 1, OPTAB_DIRECT);
-      tmp = expand_simple_binop (SImode, AND, tmp, val,
+      tmp = expand_simple_binop (SImode, XOR, tmp, ac.modemask,
 				 new_rtx, 1, OPTAB_DIRECT);
       break;
 
Index: gcc/config/m68k/m68k.md
===================================================================
--- gcc/config/m68k/m68k.md	(.../tags/gcc_8_2_0_release)
+++ gcc/config/m68k/m68k.md	(.../branches/gcc-8-branch)
@@ -3240,7 +3240,10 @@
 	  (const_int 32))))
    (clobber (match_operand:SI 1 "register_operand" "=d"))]
   "TARGET_68020 && !TUNE_68060 && !TARGET_COLDFIRE"
-  "mulu%.l %3,%0:%1")
+{
+  CC_STATUS_INIT;
+  return "mulu%.l %3,%0:%1";
+})
 
 (define_insn "const_umulsi3_highpart"
   [(set (match_operand:SI 0 "register_operand" "=d")
@@ -3251,7 +3254,10 @@
 	  (const_int 32))))
    (clobber (match_operand:SI 1 "register_operand" "=d"))]
   "TARGET_68020 && !TUNE_68060 && !TARGET_COLDFIRE"
-  "mulu%.l %3,%0:%1")
+{
+  CC_STATUS_INIT;
+  return "mulu%.l %3,%0:%1";
+})
 
 (define_expand "smulsi3_highpart"
   [(parallel
@@ -3283,7 +3289,10 @@
 	  (const_int 32))))
    (clobber (match_operand:SI 1 "register_operand" "=d"))]
   "TARGET_68020 && !TUNE_68060 && !TARGET_COLDFIRE"
-  "muls%.l %3,%0:%1")
+{
+  CC_STATUS_INIT;
+  return "muls%.l %3,%0:%1";
+})
 
 (define_insn "const_smulsi3_highpart"
   [(set (match_operand:SI 0 "register_operand" "=d")
@@ -3294,7 +3303,10 @@
 	  (const_int 32))))
    (clobber (match_operand:SI 1 "register_operand" "=d"))]
   "TARGET_68020 && !TUNE_68060 && !TARGET_COLDFIRE"
-  "muls%.l %3,%0:%1")
+{
+  CC_STATUS_INIT;
+  return "muls%.l %3,%0:%1";
+})
 
 (define_expand "mul<mode>3"
   [(set (match_operand:FP 0 "nonimmediate_operand" "")
Index: gcc/config/aarch64/falkor.md
===================================================================
--- gcc/config/aarch64/falkor.md	(.../tags/gcc_8_2_0_release)
+++ gcc/config/aarch64/falkor.md	(.../branches/gcc-8-branch)
@@ -322,6 +322,12 @@
        (eq_attr "type" "neon_from_gp_q"))
   "falkor_gtov,falkor_gtov")
 
+;; DUP  does not use vector pipes in Q mode, only gtov+gtov.
+(define_insn_reservation "falkor_am_1_gtov_gtov" 1
+  (and (eq_attr "tune" "falkor")
+       (eq_attr "type" "neon_dup_q"))
+  "falkor_gtov*2")
+
 ;; neon_to_gp_q is used for 32-bit ARM instructions that move 64-bits of data
 ;; so no use needed here.
 
@@ -337,7 +343,7 @@
 
 (define_insn_reservation "falkor_am_1_vxvy_vxvy" 1
   (and (eq_attr "tune" "falkor")
-       (eq_attr "type" "neon_bsl_q,neon_dup_q,neon_ext_q,neon_move_q,neon_rev_q,neon_tbl1_q,neon_permute_q"))
+       (eq_attr "type" "neon_bsl_q,neon_ext_q,neon_move_q,neon_rev_q,neon_tbl1_q,neon_permute_q"))
   "falkor_vxvy+falkor_vxvy")
 
 (define_insn_reservation "falkor_am_2_vxvy" 2
Index: gcc/config/aarch64/aarch64.c
===================================================================
--- gcc/config/aarch64/aarch64.c	(.../tags/gcc_8_2_0_release)
+++ gcc/config/aarch64/aarch64.c	(.../branches/gcc-8-branch)
@@ -325,7 +325,7 @@
   1, /* pre_modify  */
   1, /* post_modify  */
   3, /* register_offset  */
-  4, /* register_sextend  */
+  3, /* register_sextend  */
   3, /* register_zextend  */
   2, /* imm_offset  */
 };
@@ -426,6 +426,26 @@
   1 /* cond_not_taken_branch_cost  */
 };
 
+/* QDF24XX costs for vector insn classes.  */
+static const struct cpu_vector_cost qdf24xx_vector_cost =
+{
+  1, /* scalar_int_stmt_cost  */
+  1, /* scalar_fp_stmt_cost  */
+  1, /* scalar_load_cost  */
+  1, /* scalar_store_cost  */
+  1, /* vec_int_stmt_cost  */
+  3, /* vec_fp_stmt_cost  */
+  2, /* vec_permute_cost  */
+  1, /* vec_to_scalar_cost  */
+  1, /* scalar_to_vec_cost  */
+  1, /* vec_align_load_cost  */
+  1, /* vec_unalign_load_cost  */
+  1, /* vec_unalign_store_cost  */
+  1, /* vec_store_cost  */
+  3, /* cond_taken_branch_cost  */
+  1 /* cond_not_taken_branch_cost  */
+};
+
 /* ThunderX costs for vector insn classes.  */
 static const struct cpu_vector_cost thunderx_vector_cost =
 {
@@ -874,7 +894,7 @@
   &qdf24xx_extra_costs,
   &qdf24xx_addrcost_table,
   &qdf24xx_regmove_cost,
-  &generic_vector_cost,
+  &qdf24xx_vector_cost,
   &generic_branch_cost,
   &generic_approx_modes,
   4, /* memmov_cost  */
@@ -16498,8 +16518,6 @@
   if (aarch64_fusion_enabled_p (AARCH64_FUSE_CMP_BRANCH)
       && any_condjump_p (curr))
     {
-      enum attr_type prev_type = get_attr_type (prev);
-
       unsigned int condreg1, condreg2;
       rtx cc_reg_1;
       aarch64_fixed_condition_code_regs (&condreg1, &condreg2);
@@ -16509,6 +16527,8 @@
 	  && prev
 	  && modified_in_p (cc_reg_1, prev))
 	{
+	  enum attr_type prev_type = get_attr_type (prev);
+
 	  /* FIXME: this misses some which is considered simple arthematic
 	     instructions for ThunderX.  Simple shifts are missed here.  */
 	  if (prev_type == TYPE_ALUS_SREG
Index: gcc/config/rs6000/xmmintrin.h
===================================================================
--- gcc/config/rs6000/xmmintrin.h	(.../tags/gcc_8_2_0_release)
+++ gcc/config/rs6000/xmmintrin.h	(.../branches/gcc-8-branch)
@@ -57,6 +57,9 @@
 #ifndef _XMMINTRIN_H_INCLUDED
 #define _XMMINTRIN_H_INCLUDED
 
+/* Define four value permute mask */
+#define _MM_SHUFFLE(w,x,y,z) (((w) << 6) | ((x) << 4) | ((y) << 2) | (z))
+
 #include <altivec.h>
 
 /* Avoid collisions between altivec.h and strict adherence to C++ and
Index: gcc/config/rs6000/rs6000.c
===================================================================
--- gcc/config/rs6000/rs6000.c	(.../tags/gcc_8_2_0_release)
+++ gcc/config/rs6000/rs6000.c	(.../branches/gcc-8-branch)
@@ -8519,7 +8519,9 @@
     *tocrel_offset_ret = tocrel_offset;
 
   return (GET_CODE (tocrel_base) == UNSPEC
-	  && XINT (tocrel_base, 1) == UNSPEC_TOCREL);
+	  && XINT (tocrel_base, 1) == UNSPEC_TOCREL
+	  && REG_P (XVECEXP (tocrel_base, 0, 1))
+	  && REGNO (XVECEXP (tocrel_base, 0, 1)) == TOC_REGISTER);
 }
 
 /* Return true if X is a constant pool address, and also for cmodel=medium
@@ -25226,6 +25228,12 @@
 {
   tree fntype;
 
+  /* The sibcall epilogue may clobber the static chain register.
+     ??? We could work harder and avoid that, but it's probably
+     not worth the hassle in practice.  */
+  if (CALL_EXPR_STATIC_CHAIN (exp))
+    return false;
+
   if (decl)
     fntype = TREE_TYPE (decl);
   else
Index: gcc/config/rs6000/emmintrin.h
===================================================================
--- gcc/config/rs6000/emmintrin.h	(.../tags/gcc_8_2_0_release)
+++ gcc/config/rs6000/emmintrin.h	(.../branches/gcc-8-branch)
@@ -85,6 +85,9 @@
 typedef long long __m128i_u __attribute__ ((__vector_size__ (16), __may_alias__, __aligned__ (1)));
 typedef double __m128d_u __attribute__ ((__vector_size__ (16), __may_alias__, __aligned__ (1)));
 
+/* Define two value permute mask */
+#define _MM_SHUFFLE2(x,y) (((x) << 1) | (y))
+
 /* Create a vector with element 0 as F and the rest zero.  */
 extern __inline __m128d __attribute__((__gnu_inline__, __always_inline__, __artificial__))
 _mm_set_sd (double __F)
Index: gcc/config/rs6000/rs6000.md
===================================================================
--- gcc/config/rs6000/rs6000.md	(.../tags/gcc_8_2_0_release)
+++ gcc/config/rs6000/rs6000.md	(.../branches/gcc-8-branch)
@@ -1008,7 +1008,7 @@
 		     "=r, r,   wl,    wu,    wj,    wK,     wH,    wr")
 
 	(sign_extend:EXTSI (match_operand:SI 1 "lwa_operand"
-		     "Y,  r,   Z,     Z,     r,     wK,     wH,    ?wIwH")))]
+		     "YZ, r,   Z,     Z,     r,     wK,     wH,    ?wIwH")))]
   ""
   "@
    lwa%U1%X1 %0,%1
@@ -7433,8 +7433,8 @@
 ; ld/std require word-aligned displacements -> 'Y' constraint.
 ; List Y->r and r->Y before r->r for reload.
 (define_insn "*mov<mode>_hardfloat64"
-  [(set (match_operand:FMOVE64 0 "nonimmediate_operand" "=m,d,d,<f64_p9>,wY,<f64_av>,Z,<f64_vsx>,<f64_vsx>,!r,Y,r,!r,*c*l,!r,*h,r,wg,r,<f64_dm>")
-	(match_operand:FMOVE64 1 "input_operand" "d,m,d,wY,<f64_p9>,Z,<f64_av>,<f64_vsx>,<zero_fp>,<zero_fp>,r,Y,r,r,h,0,wg,r,<f64_dm>,r"))]
+  [(set (match_operand:FMOVE64 0 "nonimmediate_operand" "=m,d,d,<f64_p9>,wY,<f64_av>,Z,<f64_vsx>,<f64_vsx>,!r,YZ,r,!r,*c*l,!r,*h,r,wg,r,<f64_dm>")
+	(match_operand:FMOVE64 1 "input_operand" "d,m,d,wY,<f64_p9>,Z,<f64_av>,<f64_vsx>,<zero_fp>,<zero_fp>,r,YZ,r,r,h,0,wg,r,<f64_dm>,r"))]
   "TARGET_POWERPC64 && TARGET_HARD_FLOAT && TARGET_DOUBLE_FLOAT
    && (gpc_reg_operand (operands[0], <MODE>mode)
        || gpc_reg_operand (operands[1], <MODE>mode))"
Index: gcc/config/arm/arm.c
===================================================================
--- gcc/config/arm/arm.c	(.../tags/gcc_8_2_0_release)
+++ gcc/config/arm/arm.c	(.../branches/gcc-8-branch)
@@ -18483,12 +18483,18 @@
       gcc_assert ((REGNO (operands[1]) != IP_REGNUM)
                   || (TARGET_ARM && TARGET_LDRD));
 
+      /* For TARGET_ARM the first source register of an STRD
+	 must be even.  This is usually the case for double-word
+	 values but user assembly constraints can force an odd
+	 starting register.  */
+      bool allow_strd = TARGET_LDRD
+			 && !(TARGET_ARM && (REGNO (operands[1]) & 1) == 1);
       switch (GET_CODE (XEXP (operands[0], 0)))
         {
 	case REG:
 	  if (emit)
 	    {
-	      if (TARGET_LDRD)
+	      if (allow_strd)
 		output_asm_insn ("strd%?\t%1, [%m0]", operands);
 	      else
 		output_asm_insn ("stm%?\t%m0, %M1", operands);
@@ -18496,7 +18502,7 @@
 	  break;
 
         case PRE_INC:
-	  gcc_assert (TARGET_LDRD);
+	  gcc_assert (allow_strd);
 	  if (emit)
 	    output_asm_insn ("strd%?\t%1, [%m0, #8]!", operands);
 	  break;
@@ -18504,7 +18510,7 @@
         case PRE_DEC:
 	  if (emit)
 	    {
-	      if (TARGET_LDRD)
+	      if (allow_strd)
 		output_asm_insn ("strd%?\t%1, [%m0, #-8]!", operands);
 	      else
 		output_asm_insn ("stmdb%?\t%m0!, %M1", operands);
@@ -18514,7 +18520,7 @@
         case POST_INC:
 	  if (emit)
 	    {
-	      if (TARGET_LDRD)
+	      if (allow_strd)
 		output_asm_insn ("strd%?\t%1, [%m0], #8", operands);
 	      else
 		output_asm_insn ("stm%?\t%m0!, %M1", operands);
@@ -18522,7 +18528,7 @@
 	  break;
 
         case POST_DEC:
-	  gcc_assert (TARGET_LDRD);
+	  gcc_assert (allow_strd);
 	  if (emit)
 	    output_asm_insn ("strd%?\t%1, [%m0], #-8", operands);
 	  break;
@@ -18533,8 +18539,8 @@
 	  otherops[1] = XEXP (XEXP (XEXP (operands[0], 0), 1), 0);
 	  otherops[2] = XEXP (XEXP (XEXP (operands[0], 0), 1), 1);
 
-	  /* IWMMXT allows offsets larger than ldrd can handle,
-	     fix these up with a pair of ldr.  */
+	  /* IWMMXT allows offsets larger than strd can handle,
+	     fix these up with a pair of str.  */
 	  if (!TARGET_THUMB2
 	      && CONST_INT_P (otherops[2])
 	      && (INTVAL(otherops[2]) <= -256
@@ -18599,7 +18605,7 @@
 		  return "";
 		}
 	    }
-	  if (TARGET_LDRD
+	  if (allow_strd
 	      && (REG_P (otherops[2])
 		  || TARGET_THUMB2
 		  || (CONST_INT_P (otherops[2])
@@ -30059,7 +30065,6 @@
   rtx dst, addr, mem;
   rtx val_vec, reg;
   machine_mode mode;
-  unsigned HOST_WIDE_INT v = value;
   unsigned int offset = 0;
 
   gcc_assert ((align & 0x3) == 0);
@@ -30078,10 +30083,8 @@
 
   dst = copy_addr_to_reg (XEXP (dstbase, 0));
 
-  v = sext_hwi (v, BITS_PER_WORD);
-
   reg = gen_reg_rtx (mode);
-  val_vec = gen_const_vec_duplicate (mode, GEN_INT (v));
+  val_vec = gen_const_vec_duplicate (mode, gen_int_mode (value, QImode));
   /* Emit instruction loading the constant value.  */
   emit_move_insn (reg, val_vec);
 
Index: gcc/config/pa/pa.md
===================================================================
--- gcc/config/pa/pa.md	(.../tags/gcc_8_2_0_release)
+++ gcc/config/pa/pa.md	(.../branches/gcc-8-branch)
@@ -84,6 +84,7 @@
    UNSPEC_TLSGD_PIC
    UNSPEC_TLSLDM_PIC
    UNSPEC_TLSIE_PIC
+   UNSPEC_MEMORY_BARRIER
   ])
 
 ;; UNSPEC_VOLATILE:
@@ -9955,14 +9956,8 @@
 ;; doubleword loads and stores are not guaranteed to be atomic
 ;; when referencing the I/O address space.
 
-;; The kernel cmpxchg operation on linux is not atomic with respect to
-;; memory stores on SMP machines, so we must do stores using a cmpxchg
-;; operation.
-
 ;; These patterns are at the bottom so the non atomic versions are preferred.
 
-;; Implement atomic QImode store using exchange.
-
 (define_expand "atomic_storeqi"
   [(match_operand:QI 0 "memory_operand")                ;; memory
    (match_operand:QI 1 "register_operand")              ;; val out
@@ -10015,26 +10010,8 @@
   FAIL;
 })
 
-;; Implement atomic SFmode store using exchange.
+;; Implement atomic DImode load.
 
-(define_expand "atomic_storesf"
-  [(match_operand:SF 0 "memory_operand")                ;; memory
-   (match_operand:SF 1 "register_operand")              ;; val out
-   (match_operand:SI 2 "const_int_operand")]            ;; model
-  ""
-{
-  if (TARGET_SYNC_LIBCALL)
-    {
-      rtx mem = operands[0];
-      rtx val = operands[1];
-      if (pa_maybe_emit_compare_and_swap_exchange_loop (NULL_RTX, mem, val))
-	DONE;
-    }
-  FAIL;
-})
-
-;; Implement atomic DImode load using 64-bit floating point load.
-
 (define_expand "atomic_loaddi"
   [(match_operand:DI 0 "register_operand")              ;; val out
    (match_operand:DI 1 "memory_operand")                ;; memory
@@ -10048,29 +10025,27 @@
 
   model = memmodel_from_int (INTVAL (operands[2]));
   operands[1] = force_reg (SImode, XEXP (operands[1], 0));
-  expand_mem_thread_fence (model);
-  emit_insn (gen_atomic_loaddi_1 (operands[0], operands[1]));
   if (is_mm_seq_cst (model))
     expand_mem_thread_fence (model);
+  emit_insn (gen_atomic_loaddi_1 (operands[0], operands[1]));
+  expand_mem_thread_fence (model);
   DONE;
 })
 
 (define_insn "atomic_loaddi_1"
-  [(set (match_operand:DI 0 "register_operand" "=f,r")
-        (mem:DI (match_operand:SI 1 "register_operand" "r,r")))
-   (clobber (match_scratch:DI 2 "=X,f"))]
+  [(set (match_operand:DI 0 "register_operand" "=r")
+        (mem:DI (match_operand:SI 1 "register_operand" "r")))
+   (clobber (match_scratch:DI 2 "=f"))]
   "!TARGET_64BIT && !TARGET_DISABLE_FPREGS && !TARGET_SOFT_FLOAT"
-  "@
-   {fldds|fldd} 0(%1),%0
-   {fldds|fldd} 0(%1),%2\n\t{fstds|fstd} %2,-16(%%sp)\n\t{ldws|ldw} -16(%%sp),%0\n\t{ldws|ldw} -12(%%sp),%R0"
-  [(set_attr "type" "move,move")
-   (set_attr "length" "4,16")])
+  "{fldds|fldd} 0(%1),%2\n\t{fstds|fstd} %2,-16(%%sp)\n\t{ldws|ldw} -16(%%sp),%0\n\t{ldws|ldw} -12(%%sp),%R0"
+  [(set_attr "type" "move")
+   (set_attr "length" "16")])
 
 ;; Implement atomic DImode store.
 
 (define_expand "atomic_storedi"
   [(match_operand:DI 0 "memory_operand")                ;; memory
-   (match_operand:DI 1 "register_operand")              ;; val out
+   (match_operand:DI 1 "reg_or_cint_move_operand")      ;; val out
    (match_operand:SI 2 "const_int_operand")]            ;; model
   ""
 {
@@ -10089,6 +10064,8 @@
 
   model = memmodel_from_int (INTVAL (operands[2]));
   operands[0] = force_reg (SImode, XEXP (operands[0], 0));
+  if (operands[1] != CONST0_RTX (DImode))
+    operands[1] = force_reg (DImode, operands[1]);
   expand_mem_thread_fence (model);
   emit_insn (gen_atomic_storedi_1 (operands[0], operands[1]));
   if (is_mm_seq_cst (model))
@@ -10098,87 +10075,33 @@
 
 (define_insn "atomic_storedi_1"
   [(set (mem:DI (match_operand:SI 0 "register_operand" "r,r"))
-        (match_operand:DI 1 "register_operand" "f,r"))
+        (match_operand:DI 1 "reg_or_0_operand" "M,r"))
    (clobber (match_scratch:DI 2 "=X,f"))]
-  "!TARGET_64BIT && !TARGET_DISABLE_FPREGS
-   && !TARGET_SOFT_FLOAT && !TARGET_SYNC_LIBCALL"
+  "!TARGET_64BIT && !TARGET_DISABLE_FPREGS && !TARGET_SOFT_FLOAT"
   "@
-   {fstds|fstd} %1,0(%0)
+   {fstds|fstd} %%fr0,0(%0)
    {stws|stw} %1,-16(%%sp)\n\t{stws|stw} %R1,-12(%%sp)\n\t{fldds|fldd} -16(%%sp),%2\n\t{fstds|fstd} %2,0(%0)"
   [(set_attr "type" "move,move")
    (set_attr "length" "4,16")])
 
-;; Implement atomic DFmode load using 64-bit floating point load.
+;; PA 2.0 hardware supports out-of-order execution of loads and stores, so
+;; we need a memory barrier to enforce program order for memory references.
+;; Since we want PA 1.x code to be PA 2.0 compatible, we also need the
+;; barrier when generating PA 1.x code.
 
-(define_expand "atomic_loaddf"
-  [(match_operand:DF 0 "register_operand")              ;; val out
-   (match_operand:DF 1 "memory_operand")                ;; memory
-   (match_operand:SI 2 "const_int_operand")]            ;; model
+(define_expand "memory_barrier"
+  [(set (match_dup 0)
+        (unspec:BLK [(match_dup 0)] UNSPEC_MEMORY_BARRIER))]
   ""
 {
-  enum memmodel model;
-
-  if (TARGET_64BIT || TARGET_DISABLE_FPREGS || TARGET_SOFT_FLOAT)
-    FAIL;
-
-  model = memmodel_from_int (INTVAL (operands[2]));
-  operands[1] = force_reg (SImode, XEXP (operands[1], 0));
-  expand_mem_thread_fence (model);
-  emit_insn (gen_atomic_loaddf_1 (operands[0], operands[1]));
-  if (is_mm_seq_cst (model))
-    expand_mem_thread_fence (model);
-  DONE;
+  operands[0] = gen_rtx_MEM (BLKmode, gen_rtx_SCRATCH (Pmode));
+  MEM_VOLATILE_P (operands[0]) = 1;
 })
 
-(define_insn "atomic_loaddf_1"
-  [(set (match_operand:DF 0 "register_operand" "=f,r")
-        (mem:DF (match_operand:SI 1 "register_operand" "r,r")))
-   (clobber (match_scratch:DF 2 "=X,f"))]
-  "!TARGET_64BIT && !TARGET_DISABLE_FPREGS && !TARGET_SOFT_FLOAT"
-  "@
-   {fldds|fldd} 0(%1),%0
-   {fldds|fldd} 0(%1),%2\n\t{fstds|fstd} %2,-16(%%sp)\n\t{ldws|ldw} -16(%%sp),%0\n\t{ldws|ldw} -12(%%sp),%R0"
-  [(set_attr "type" "move,move")
-   (set_attr "length" "4,16")])
-
-;; Implement atomic DFmode store using 64-bit floating point store.
-
-(define_expand "atomic_storedf"
-  [(match_operand:DF 0 "memory_operand")                ;; memory
-   (match_operand:DF 1 "register_operand")              ;; val out
-   (match_operand:SI 2 "const_int_operand")]            ;; model
+(define_insn "*memory_barrier"
+  [(set (match_operand:BLK 0 "" "")
+        (unspec:BLK [(match_dup 0)] UNSPEC_MEMORY_BARRIER))]
   ""
-{
-  enum memmodel model;
-
-  if (TARGET_SYNC_LIBCALL)
-    {
-      rtx mem = operands[0];
-      rtx val = operands[1];
-      if (pa_maybe_emit_compare_and_swap_exchange_loop (NULL_RTX, mem, val))
-	DONE;
-    }
-
-  if (TARGET_64BIT || TARGET_DISABLE_FPREGS || TARGET_SOFT_FLOAT)
-    FAIL;
-
-  model = memmodel_from_int (INTVAL (operands[2]));
-  operands[0] = force_reg (SImode, XEXP (operands[0], 0));
-  expand_mem_thread_fence (model);
-  emit_insn (gen_atomic_storedf_1 (operands[0], operands[1]));
-  if (is_mm_seq_cst (model))
-    expand_mem_thread_fence (model);
-  DONE;
-})
-
-(define_insn "atomic_storedf_1"
-  [(set (mem:DF (match_operand:SI 0 "register_operand" "r,r"))
-        (match_operand:DF 1 "register_operand" "f,r"))
-   (clobber (match_scratch:DF 2 "=X,f"))]
-  "!TARGET_64BIT && !TARGET_DISABLE_FPREGS
-   && !TARGET_SOFT_FLOAT && !TARGET_SYNC_LIBCALL"
-  "@
-   {fstds|fstd} %1,0(%0)
-   {stws|stw} %1,-16(%%sp)\n\t{stws|stw} %R1,-12(%%sp)\n\t{fldds|fldd} -16(%%sp),%2\n\t{fstds|fstd} %2,0(%0)"
-  [(set_attr "type" "move,move")
-   (set_attr "length" "4,16")])
+  "sync"
+  [(set_attr "type" "binary")
+   (set_attr "length" "4")])
Index: gcc/config/pa/pa.c
===================================================================
--- gcc/config/pa/pa.c	(.../tags/gcc_8_2_0_release)
+++ gcc/config/pa/pa.c	(.../branches/gcc-8-branch)
@@ -10680,6 +10680,8 @@
 {
   int idx, vlen = XVECLEN (body, 0);
 
+  if (!TARGET_SOM)
+    fputs ("\t.align 4\n", asm_out_file);
   targetm.asm_out.internal_label (asm_out_file, "L", CODE_LABEL_NUMBER (lab));
   if (TARGET_GAS)
     fputs ("\t.begin_brtab\n", asm_out_file);
Index: gcc/config/pa/pa.h
===================================================================
--- gcc/config/pa/pa.h	(.../tags/gcc_8_2_0_release)
+++ gcc/config/pa/pa.h	(.../branches/gcc-8-branch)
@@ -1143,22 +1143,24 @@
 #define ASM_OUTPUT_ASCII(FILE, P, SIZE)  \
   pa_output_ascii ((FILE), (P), (SIZE))
 
-/* Jump tables are always placed in the text section.  Technically, it
-   is possible to put them in the readonly data section.  This has the
-   benefit of getting the table out of .text and reducing branch lengths
-   as a result.
+/* Jump tables are always placed in the text section.  We have to do
+   this for the HP-UX SOM target as we can't switch sections in the
+   middle of a function.
 
-   The downside is that an additional insn (addil) is needed to access
+   On ELF targets, it is possible to put them in the readonly-data section.
+   This would get the table out of .text and reduce branch lengths.
+
+   A downside is that an additional insn (addil) is needed to access
    the table when generating PIC code.  The address difference table
-   also has to use 32-bit pc-relative relocations.  Currently, GAS does
-   not support these relocations, although it is easily modified to do
-   this operation.
+   also has to use 32-bit pc-relative relocations.
 
    The table entries need to look like "$L1+(.+8-$L0)-$PIC_pcrel$0"
    when using ELF GAS.  A simple difference can be used when using
-   SOM GAS or the HP assembler.  The final downside is GDB complains
-   about the nesting of the label for the table when debugging.  */
+   the HP assembler.
 
+   The final downside is GDB complains about the nesting of the label
+   for the table.  */
+
 #define JUMP_TABLES_IN_TEXT_SECTION 1
 
 /* This is how to output an element of a case-vector that is absolute.  */
Index: gcc/config/pa/pa32-linux.h
===================================================================
--- gcc/config/pa/pa32-linux.h	(.../tags/gcc_8_2_0_release)
+++ gcc/config/pa/pa32-linux.h	(.../branches/gcc-8-branch)
@@ -67,3 +67,12 @@
    layout compatibility with the original linux thread implementation.  */
 #undef MALLOC_ABI_ALIGNMENT
 #define MALLOC_ABI_ALIGNMENT 128
+
+/* Place jump tables in the text section except when generating non-PIC
+   code.  When generating non-PIC code, the relocations needed to load the
+   address of the jump table result in a text label in the final executable
+   if the jump table is placed in the text section.  This breaks the unwind
+   data for the function.  Thus, the jump table needs to be placed in
+   rodata when generating non-PIC code.  */
+#undef JUMP_TABLES_IN_TEXT_SECTION
+#define JUMP_TABLES_IN_TEXT_SECTION (flag_pic)
Index: gcc/config/mmix/mmix.c
===================================================================
--- gcc/config/mmix/mmix.c	(.../tags/gcc_8_2_0_release)
+++ gcc/config/mmix/mmix.c	(.../branches/gcc-8-branch)
@@ -60,19 +60,16 @@
 
 /* We have no means to tell DWARF 2 about the register stack, so we need
    to store the return address on the stack if an exception can get into
-   this function.  FIXME: Narrow condition.  Before any whole-function
-   analysis, df_regs_ever_live_p () isn't initialized.  We know it's up-to-date
-   after reload_completed; it may contain incorrect information some time
-   before that.  Within a RTL sequence (after a call to start_sequence,
-   such as in RTL expanders), leaf_function_p doesn't see all insns
-   (perhaps any insn).  But regs_ever_live is up-to-date when
-   leaf_function_p () isn't, so we "or" them together to get accurate
-   information.  FIXME: Some tweak to leaf_function_p might be
-   preferable.  */
+   this function.  We'll have an "initial value" recorded for the
+   return-register if we've seen a call instruction emitted.  This note
+   will be inaccurate before instructions are emitted, but the only caller
+   at that time is looking for modulo from stack-boundary, to which the
+   return-address does not contribute, and which is always 0 for MMIX
+   anyway.  Beware of calling leaf_function_p here, as it'll abort if
+   called within a sequence.  */
 #define MMIX_CFUN_NEEDS_SAVED_EH_RETURN_ADDRESS			\
  (flag_exceptions						\
-  && ((reload_completed && df_regs_ever_live_p (MMIX_rJ_REGNUM))	\
-      || !leaf_function_p ()))
+  && has_hard_reg_initial_val (Pmode, MMIX_INCOMING_RETURN_ADDRESS_REGNUM))
 
 #define IS_MMIX_EH_RETURN_DATA_REG(REGNO)	\
  (crtl->calls_eh_return		\
@@ -1373,8 +1370,14 @@
       case 1:
 	if (GET_CODE (x) != CONST_INT)
 	  {
-	    aligned_p = 0;
-	    break;
+	    /* There is no "unaligned byte" op or generic function to
+	       which we can punt, so we have to handle this here.  As
+	       the expression isn't a plain literal, the generated
+	       assembly-code can't be mmixal-equivalent (i.e. "BYTE"
+	       won't work) and thus it's ok to emit the default op
+	       ".byte". */
+	    assemble_integer_with_op ("\t.byte\t", x);
+	    return true;
 	  }
 	fputs ("\tBYTE\t", asm_out_file);
 	mmix_print_operand (asm_out_file, x, 'B');
Index: libgo/go/cmd/go/internal/work/buildid.go
===================================================================
--- libgo/go/cmd/go/internal/work/buildid.go	(.../tags/gcc_8_2_0_release)
+++ libgo/go/cmd/go/internal/work/buildid.go	(.../branches/gcc-8-branch)
@@ -337,8 +337,12 @@
 	}
 	fmt.Fprintf(&buf, "\n")
 	if cfg.Goos != "solaris" {
-		fmt.Fprintf(&buf, "\t"+`.section .note.GNU-stack,"",@progbits`+"\n")
-		fmt.Fprintf(&buf, "\t"+`.section .note.GNU-split-stack,"",@progbits`+"\n")
+		secType := "@progbits"
+		if cfg.Goarch == "arm" {
+			secType = "%progbits"
+		}
+		fmt.Fprintf(&buf, "\t"+`.section .note.GNU-stack,"",%s`+"\n", secType)
+		fmt.Fprintf(&buf, "\t"+`.section .note.GNU-split-stack,"",%s`+"\n", secType)
 	}
 
 	if cfg.BuildN || cfg.BuildX {
Index: libgfortran/m4/matmul_internal.m4
===================================================================
--- libgfortran/m4/matmul_internal.m4	(.../tags/gcc_8_2_0_release)
+++ libgfortran/m4/matmul_internal.m4	(.../branches/gcc-8-branch)
@@ -233,8 +233,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
Index: libgfortran/ChangeLog
===================================================================
--- libgfortran/ChangeLog	(.../tags/gcc_8_2_0_release)
+++ libgfortran/ChangeLog	(.../branches/gcc-8-branch)
@@ -1,3 +1,49 @@
+2018-10-05  Gerald Pfeifer  <gerald@pfeifer.com>
+
+	Backport from trunk
+	* io/close.c [!HAVE_UNLINK_OPEN_FILE]: Include <string.h>.
+
+2018-09-18  Kyrylo Tkachov  <kyrylo.tkachov@arm.com>
+
+	Backport from trunk
+	2018-09-14  Kyrylo Tkachov  <kyrylo.tkachov@arm.com>
+
+	* io/unix.c (fallback_access): Avoid calling close on
+	uninitialized file descriptor.
+
+2018-08-26  Thomas Koenig  <tkoenig@gcc.gnu.org>
+
+	Backport from trunk
+	PR libfortran/86704
+	* m4/matmul_internal.m4: Correct calculation of needed buffer size
+	for arrays of shape (1,n).
+	* generated/matmul_c10.c: Regenerated
+	* generated/matmul_c16.c: Regenerated
+	* generated/matmul_c4.c: Regenerated
+	* generated/matmul_c8.c: Regenerated
+	* generated/matmul_i1.c: Regenerated
+	* generated/matmul_i16.c: Regenerated
+	* generated/matmul_i2.c: Regenerated
+	* generated/matmul_i4.c: Regenerated
+	* generated/matmul_i8.c: Regenerated
+	* generated/matmul_r10.c: Regenerated
+	* generated/matmul_r16.c: Regenerated
+	* generated/matmul_r4.c: Regenerated
+	* generated/matmul_r8.c: Regenerated
+	* generated/matmulavx128_c10.c: Regenerated
+	* generated/matmulavx128_c16.c: Regenerated
+	* generated/matmulavx128_c4.c: Regenerated
+	* generated/matmulavx128_c8.c: Regenerated
+	* generated/matmulavx128_i1.c: Regenerated
+	* generated/matmulavx128_i16.c: Regenerated
+	* generated/matmulavx128_i2.c: Regenerated
+	* generated/matmulavx128_i4.c: Regenerated
+	* generated/matmulavx128_i8.c: Regenerated
+	* generated/matmulavx128_r10.c: Regenerated
+	* generated/matmulavx128_r16.c: Regenerated
+	* generated/matmulavx128_r4.c: Regenerated
+	* generated/matmulavx128_r8.c: Regenerated
+
 2018-07-26  Release Manager
 
 	* GCC 8.2.0 released.
Index: libgfortran/generated/matmulavx128_i1.c
===================================================================
--- libgfortran/generated/matmulavx128_i1.c	(.../tags/gcc_8_2_0_release)
+++ libgfortran/generated/matmulavx128_i1.c	(.../branches/gcc-8-branch)
@@ -282,8 +282,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
@@ -835,8 +840,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
Index: libgfortran/generated/matmul_r16.c
===================================================================
--- libgfortran/generated/matmul_r16.c	(.../tags/gcc_8_2_0_release)
+++ libgfortran/generated/matmul_r16.c	(.../branches/gcc-8-branch)
@@ -317,8 +317,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
@@ -869,8 +874,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
@@ -1421,8 +1431,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
@@ -1987,8 +2002,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
@@ -2613,8 +2633,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
Index: libgfortran/generated/matmulavx128_i16.c
===================================================================
--- libgfortran/generated/matmulavx128_i16.c	(.../tags/gcc_8_2_0_release)
+++ libgfortran/generated/matmulavx128_i16.c	(.../branches/gcc-8-branch)
@@ -282,8 +282,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
@@ -835,8 +840,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
Index: libgfortran/generated/matmulavx128_r4.c
===================================================================
--- libgfortran/generated/matmulavx128_r4.c	(.../tags/gcc_8_2_0_release)
+++ libgfortran/generated/matmulavx128_r4.c	(.../branches/gcc-8-branch)
@@ -282,8 +282,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
@@ -835,8 +840,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
Index: libgfortran/generated/matmul_c8.c
===================================================================
--- libgfortran/generated/matmul_c8.c	(.../tags/gcc_8_2_0_release)
+++ libgfortran/generated/matmul_c8.c	(.../branches/gcc-8-branch)
@@ -317,8 +317,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
@@ -869,8 +874,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
@@ -1421,8 +1431,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
@@ -1987,8 +2002,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
@@ -2613,8 +2633,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
Index: libgfortran/generated/matmulavx128_i2.c
===================================================================
--- libgfortran/generated/matmulavx128_i2.c	(.../tags/gcc_8_2_0_release)
+++ libgfortran/generated/matmulavx128_i2.c	(.../branches/gcc-8-branch)
@@ -282,8 +282,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
@@ -835,8 +840,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
Index: libgfortran/generated/matmul_c16.c
===================================================================
--- libgfortran/generated/matmul_c16.c	(.../tags/gcc_8_2_0_release)
+++ libgfortran/generated/matmul_c16.c	(.../branches/gcc-8-branch)
@@ -317,8 +317,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
@@ -869,8 +874,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
@@ -1421,8 +1431,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
@@ -1987,8 +2002,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
@@ -2613,8 +2633,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
Index: libgfortran/generated/matmulavx128_r16.c
===================================================================
--- libgfortran/generated/matmulavx128_r16.c	(.../tags/gcc_8_2_0_release)
+++ libgfortran/generated/matmulavx128_r16.c	(.../branches/gcc-8-branch)
@@ -282,8 +282,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
@@ -835,8 +840,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
Index: libgfortran/generated/matmul_i1.c
===================================================================
--- libgfortran/generated/matmul_i1.c	(.../tags/gcc_8_2_0_release)
+++ libgfortran/generated/matmul_i1.c	(.../branches/gcc-8-branch)
@@ -317,8 +317,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
@@ -869,8 +874,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
@@ -1421,8 +1431,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
@@ -1987,8 +2002,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
@@ -2613,8 +2633,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
Index: libgfortran/generated/matmulavx128_i4.c
===================================================================
--- libgfortran/generated/matmulavx128_i4.c	(.../tags/gcc_8_2_0_release)
+++ libgfortran/generated/matmulavx128_i4.c	(.../branches/gcc-8-branch)
@@ -282,8 +282,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
@@ -835,8 +840,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
Index: libgfortran/generated/matmul_r4.c
===================================================================
--- libgfortran/generated/matmul_r4.c	(.../tags/gcc_8_2_0_release)
+++ libgfortran/generated/matmul_r4.c	(.../branches/gcc-8-branch)
@@ -317,8 +317,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
@@ -869,8 +874,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
@@ -1421,8 +1431,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
@@ -1987,8 +2002,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
@@ -2613,8 +2633,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
Index: libgfortran/generated/matmul_i2.c
===================================================================
--- libgfortran/generated/matmul_i2.c	(.../tags/gcc_8_2_0_release)
+++ libgfortran/generated/matmul_i2.c	(.../branches/gcc-8-branch)
@@ -317,8 +317,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
@@ -869,8 +874,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
@@ -1421,8 +1431,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
@@ -1987,8 +2002,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
@@ -2613,8 +2633,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
Index: libgfortran/generated/matmulavx128_c16.c
===================================================================
--- libgfortran/generated/matmulavx128_c16.c	(.../tags/gcc_8_2_0_release)
+++ libgfortran/generated/matmulavx128_c16.c	(.../branches/gcc-8-branch)
@@ -282,8 +282,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
@@ -835,8 +840,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
Index: libgfortran/generated/matmulavx128_r8.c
===================================================================
--- libgfortran/generated/matmulavx128_r8.c	(.../tags/gcc_8_2_0_release)
+++ libgfortran/generated/matmulavx128_r8.c	(.../branches/gcc-8-branch)
@@ -282,8 +282,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
@@ -835,8 +840,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
Index: libgfortran/generated/matmul_i4.c
===================================================================
--- libgfortran/generated/matmul_i4.c	(.../tags/gcc_8_2_0_release)
+++ libgfortran/generated/matmul_i4.c	(.../branches/gcc-8-branch)
@@ -317,8 +317,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
@@ -869,8 +874,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
@@ -1421,8 +1431,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
@@ -1987,8 +2002,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
@@ -2613,8 +2633,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
Index: libgfortran/generated/matmulavx128_i8.c
===================================================================
--- libgfortran/generated/matmulavx128_i8.c	(.../tags/gcc_8_2_0_release)
+++ libgfortran/generated/matmulavx128_i8.c	(.../branches/gcc-8-branch)
@@ -282,8 +282,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
@@ -835,8 +840,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
Index: libgfortran/generated/matmul_r8.c
===================================================================
--- libgfortran/generated/matmul_r8.c	(.../tags/gcc_8_2_0_release)
+++ libgfortran/generated/matmul_r8.c	(.../branches/gcc-8-branch)
@@ -317,8 +317,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
@@ -869,8 +874,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
@@ -1421,8 +1431,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
@@ -1987,8 +2002,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
@@ -2613,8 +2633,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
Index: libgfortran/generated/matmul_i8.c
===================================================================
--- libgfortran/generated/matmul_i8.c	(.../tags/gcc_8_2_0_release)
+++ libgfortran/generated/matmul_i8.c	(.../branches/gcc-8-branch)
@@ -317,8 +317,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
@@ -869,8 +874,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
@@ -1421,8 +1431,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
@@ -1987,8 +2002,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
@@ -2613,8 +2633,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
Index: libgfortran/generated/matmulavx128_c4.c
===================================================================
--- libgfortran/generated/matmulavx128_c4.c	(.../tags/gcc_8_2_0_release)
+++ libgfortran/generated/matmulavx128_c4.c	(.../branches/gcc-8-branch)
@@ -282,8 +282,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
@@ -835,8 +840,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
Index: libgfortran/generated/matmul_r10.c
===================================================================
--- libgfortran/generated/matmul_r10.c	(.../tags/gcc_8_2_0_release)
+++ libgfortran/generated/matmul_r10.c	(.../branches/gcc-8-branch)
@@ -317,8 +317,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
@@ -869,8 +874,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
@@ -1421,8 +1431,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
@@ -1987,8 +2002,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
@@ -2613,8 +2633,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
Index: libgfortran/generated/matmul_c10.c
===================================================================
--- libgfortran/generated/matmul_c10.c	(.../tags/gcc_8_2_0_release)
+++ libgfortran/generated/matmul_c10.c	(.../branches/gcc-8-branch)
@@ -317,8 +317,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
@@ -869,8 +874,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
@@ -1421,8 +1431,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
@@ -1987,8 +2002,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
@@ -2613,8 +2633,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
Index: libgfortran/generated/matmulavx128_r10.c
===================================================================
--- libgfortran/generated/matmulavx128_r10.c	(.../tags/gcc_8_2_0_release)
+++ libgfortran/generated/matmulavx128_r10.c	(.../branches/gcc-8-branch)
@@ -282,8 +282,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
@@ -835,8 +840,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
Index: libgfortran/generated/matmul_c4.c
===================================================================
--- libgfortran/generated/matmul_c4.c	(.../tags/gcc_8_2_0_release)
+++ libgfortran/generated/matmul_c4.c	(.../branches/gcc-8-branch)
@@ -317,8 +317,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
@@ -869,8 +874,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
@@ -1421,8 +1431,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
@@ -1987,8 +2002,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
@@ -2613,8 +2633,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
Index: libgfortran/generated/matmulavx128_c8.c
===================================================================
--- libgfortran/generated/matmulavx128_c8.c	(.../tags/gcc_8_2_0_release)
+++ libgfortran/generated/matmulavx128_c8.c	(.../branches/gcc-8-branch)
@@ -282,8 +282,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
@@ -835,8 +840,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
Index: libgfortran/generated/matmulavx128_c10.c
===================================================================
--- libgfortran/generated/matmulavx128_c10.c	(.../tags/gcc_8_2_0_release)
+++ libgfortran/generated/matmulavx128_c10.c	(.../branches/gcc-8-branch)
@@ -282,8 +282,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
@@ -835,8 +840,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
Index: libgfortran/generated/matmul_i16.c
===================================================================
--- libgfortran/generated/matmul_i16.c	(.../tags/gcc_8_2_0_release)
+++ libgfortran/generated/matmul_i16.c	(.../branches/gcc-8-branch)
@@ -317,8 +317,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
@@ -869,8 +874,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
@@ -1421,8 +1431,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
@@ -1987,8 +2002,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
@@ -2613,8 +2633,13 @@
 	return;
 
       /* Adjust size of t1 to what is needed.  */
-      index_type t1_dim;
-      t1_dim = (a_dim1 - (ycount > 1)) * 256 + b_dim1;
+      index_type t1_dim, a_sz;
+      if (aystride == 1)
+        a_sz = rystride;
+      else
+        a_sz = a_dim1;
+
+      t1_dim = a_sz * 256 + b_dim1;
       if (t1_dim > 65536)
 	t1_dim = 65536;
 
Index: libgfortran/io/close.c
===================================================================
--- libgfortran/io/close.c	(.../tags/gcc_8_2_0_release)
+++ libgfortran/io/close.c	(.../branches/gcc-8-branch)
@@ -25,6 +25,9 @@
 #include "io.h"
 #include "unix.h"
 #include <limits.h>
+#if !HAVE_UNLINK_OPEN_FILE
+#include <string.h>
+#endif
 
 typedef enum
 { CLOSE_DELETE, CLOSE_KEEP, CLOSE_UNSPECIFIED }
Index: libgfortran/io/unix.c
===================================================================
--- libgfortran/io/unix.c	(.../tags/gcc_8_2_0_release)
+++ libgfortran/io/unix.c	(.../branches/gcc-8-branch)
@@ -149,13 +149,21 @@
 {
   int fd;
 
-  if ((mode & R_OK) && (fd = open (path, O_RDONLY)) < 0)
-    return -1;
-  close (fd);
+  if (mode & R_OK)
+    {
+      if ((fd = open (path, O_RDONLY)) < 0)
+	return -1;
+      else
+	close (fd);
+    }
 
-  if ((mode & W_OK) && (fd = open (path, O_WRONLY)) < 0)
-    return -1;
-  close (fd);
+  if (mode & W_OK)
+    {
+      if ((fd = open (path, O_WRONLY)) < 0)
+	return -1;
+      else
+	close (fd);
+    }
 
   if (mode == F_OK)
     {
